import wx
import flags_iso3166svg as flags


class MyFrame(wx.Frame):
    def __init__(self, parent, id, title):
        wx.Frame.__init__(self, parent, -1, title)

        self.tree = wx.TreeCtrl(self, wx.ID_ANY,
                                wx.DefaultPosition,
                                wx.DefaultSize)
        self.tree.SetBackgroundColour('#f1f2f2')
        self.tree.Bind(wx.EVT_TREE_ITEM_ACTIVATED, self.OnTreeCtrl)

        self.choices = {"Australia":"AU","Canada":"CA","Germany":"DE","Spain":"ES","France":"FR",\
                        "United Kingdom":"GB","Italy":"IT","Japan":"JP",\
                        "Russia":"RU","United States of America":"US"}

        self.imagelist = [flags.catalog["Flags"].ScaledBitmap,] # First image for root is Flags

        # Turn cairo Off, even if it's available, as it's slow loading all the images in one go
        #flags.Use_Cairo = False


        # Build tree image list
        self.data = sorted([item for item in flags.catalog.keys() if len(item) > 3 and item in self.choices])
        tree_list = []
        for i in self.data:
            subdata = sorted([item for item in flags.catalog.keys() if len(item) > 3 and item.startswith(i)])
            for i in subdata:
                tree_list.append(i)
                iso2, iso3, name, regional = flags.lookup.get(i)
                self.imagelist.append(wx.BitmapBundle.FromBitmap(flags.catalog[iso2].ScaledBitmap))

        self.tree.SetImages(self.imagelist)
        self.root = self.tree.AddRoot('Flags', 0)

        # Add items to Tree
        for idx1, flag in enumerate(tree_list):
            if not flags.isregional(flag):
                x = self.tree.AppendItem(self.root, flag, idx1+1)
            else:
                y = self.tree.AppendItem(x, flag, idx1+1)

        self.tree.Expand(self.root)

        self.Show()

        # Turn cairo On, if it's available, for high quality flags
        # wx.svg fails with some svg files rendering the image only partially or not at all
        # for example Gibraltar GI is missing the entire 3rd castle turret and China CN has no yellow stars
        # wx.svg also fails entirely with Inkscape svg files that have base64 embedded images
        # whereas cairo seeems to cope with most things but its slow in comparison.

        flags.Use_Cairo = True

    def OnTreeCtrl(self, event):
        item = event.GetItem()
        id = self.tree.GetItemText(item)
        FlagPopup(parent=self, flag=id)


class FlagPopup(wx.Frame):
    def __init__(self, parent, flag="Flags"):
        wx.Frame.__init__(self, parent, wx.ID_ANY, "Full Size Flag - "+flag)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)
        panel = wx.Panel(self)
        panel.Bind(wx.EVT_KEY_DOWN, self.OnKey)
    # Use the png option
        self.flag = wx.GenericStaticBitmap(panel, bitmap=wx.Bitmap.FromPNGData(flags.catalog[flag].Png))
        self.flag.SetScaleMode(2)
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.flag, 1, wx.ALL | wx.EXPAND)
        panel.SetSizerAndFit(sizer)
        self.SetToolTip("Try resizing the window\nPress Q to Quit")
        self.Show()

    def OnKey(self, event):
        keycode = event.GetUnicodeKey()
        if chr(keycode) == 'Q':
            self.OnQuit(None)
        event.Skip()

    def OnQuit(self, event=None):
        self.Destroy()


#---------------------------------------------------------------------------

class MyApp(wx.App):
    def OnInit(self):
        frame = MyFrame(None, -1, 'SVG Image TreeCtrl')
        frame.Show(True)
        self.SetTopWindow(frame)

        return True

#---------------------------------------------------------------------------

app = MyApp(0)
app.MainLoop()
