import wx
import flags_iso3166svg as flags
import time
try:
    from datetime import datetime, timezone
    from zoneinfo import ZoneInfo               # zoneinfo introduced with python3.9
    tzones = True
except Exception as e:
    tzones = False


class Myframe(wx.Frame):
    def __init__(self):
        wx.Frame.__init__(self, None, -1, "Search "+flags.__version__, size=(1300, 500))

        panel = wx.Panel(self)
        panel.SetBackgroundColour('#aaf09e')
        txt1 = wx.StaticText(panel, -1, 'Search')
        self.search = wx.SearchCtrl(panel, -1)
        txt2 = wx.StaticText(panel, -1, 'Results')

        self.res = wx.ListCtrl(panel, -1, style=wx.LC_REPORT)
        self.res.SetMinSize((-1, 400))
        self.res.InsertColumn(1, "Country")
        self.res.InsertColumn(2, "Region")
        self.res.InsertColumn(3, "Code")
        self.res.InsertColumn(4, "Local Time")
        self.res.InsertColumn(5, "Capital")
        self.res.InsertColumn(6, "Aka")
        self.res.SetColumnWidth(0, 300)
        self.res.SetColumnWidth(1, 300)
        self.res.SetColumnWidth(3, 200)
        self.res.SetColumnWidth(4, 150)
        self.res.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self.OnResult)


        sizer1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer1.Add(txt1, 0, wx.ALL, border=5)
        sizer1.Add(self.search, 1, wx.ALL|wx.EXPAND, border=5)
        sizer2 = wx.BoxSizer(wx.HORIZONTAL)
        sizer2.Add(txt2, 0, wx.ALL, border=5)
        sizer2.Add(self.res, 1, wx.ALL|wx.EXPAND, border=5)

        main_sizer = wx.BoxSizer(wx.VERTICAL)
        main_sizer.Add(sizer1, 1, wx.ALL|wx.EXPAND, 10)
        main_sizer.Add(sizer2, 1, wx.ALL|wx.EXPAND, 10)

        panel.SetSizer(main_sizer)
        panel.Layout()

        sizer = wx.BoxSizer(wx.HORIZONTAL)
        sizer.Add(panel, 1, wx.EXPAND, 0)
        self.SetSizer(sizer)
        self.ico = flags.catalog['Flags'].GetIcon()
        self.SetIcon(self.ico)
        self.search.Bind(wx.EVT_SEARCH, self.OnSelect)
        self.Layout()
        self.Show()

    def OnSelect(self, event):
        Choice = event.GetString()
        self.GetData(Choice)

    def GetData(self, choice):
        self.res.DeleteAllItems()

        # pre-load images for the res
        self.imagelist = []
        query = choice.casefold()
        data = [k for k in flags.lookup.keys() if query in k.casefold()]
        if not data:
            return

        clean_data = [] # prevent duplicate entries when there's more than 1 hit on a search item
        for i in data:
            iso2, iso3, name, regional = flags.lookup.get(i)
            if iso2 not in clean_data:
                clean_data.append(iso2)
        clean_data = sorted(clean_data)

        for i in clean_data:
            self.imagelist.append(wx.BitmapBundle.FromBitmap(flags.catalog[i].ScaledBitmap))
        self.res.SetSmallImages(self.imagelist)

        index = 0
        for i in clean_data:
            alt = timenow = ''
            det = flags.details.get(i)
            b_iso2, b_iso3, base_country, b_regional = flags.lookupbasecountry(i)
            if tzones:                                      # Were datetime and zoneinfo imports successful
                regzone = flags.timezone.get(i)             # get regional timezone
                if not regzone:
                    regzone = flags.timezone.get(b_iso2)    # no zone get base country timezone
                if regzone:
                    zone = regzone[0]
                    timenow = datetime.now(ZoneInfo(zone)).strftime('%H:%M:%S - %d %b %Y')
            name = flags.lookupname(i)
            capital = det.get('capital', '')
            if not capital:
                base = flags.details.get(b_iso2)
                capital = base.get('capital', '')
            aka = det.get('altname', '')
            self.res.Append([base_country, "", i, timenow, capital, aka])
            self.res.SetItem(index, 1, name, imageId=index)
            index += 1
        self.Refresh()


    def OnResult(self, event):
        item = event.GetIndex()
        id = self.res.GetItem(item, 2)
        FlagPopup(parent=self, flag=id.GetText())

class FlagPopup(wx.Frame):
    def __init__(self, parent, flag="Flags"):
        wx.Frame.__init__(self, parent, wx.ID_ANY, "Full Size Flag - "+flag)
        self.Bind(wx.EVT_CLOSE, self.OnQuit)
        panel = wx.Panel(self)
        panel.Bind(wx.EVT_KEY_DOWN, self.OnKey)
    # Use the png option
        self.flag = wx.GenericStaticBitmap(panel, bitmap=wx.Bitmap.FromPNGData(flags.catalog[flag].Png))
        self.flag.SetScaleMode(2)
        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.flag, 1, wx.ALL | wx.EXPAND)
        panel.SetSizerAndFit(sizer)
        self.SetToolTip("Try resizing the window\nPress Q to Quit")
        self.Show()

    def OnKey(self, event):
        keycode = event.GetUnicodeKey()
        if chr(keycode) == 'Q':
            self.OnQuit(None)
        event.Skip()

    def OnQuit(self, event=None):
        self.Destroy()


if __name__ == "__main__":
    App = wx.App()
    Myframe()
    App.MainLoop()
