#----------------------------------------------------------------------
# This file was generated by RolfofSaxony 06/10/2023
# rolfofsaxony@gmx.com
#
# Rolf presents: Fun with SVG Flags - A homage to The Big Bang Theory.
#
# Based on the idea of img2py by Robin Dunn - Copyright: (c) 2002-2020 by Total Control Software
#

from base64 import b64decode
import wx.svg
import wx

try:
    import cairosvg
    Cairo = True
except Exception:
    Cairo = False
Use_Cairo = True
if Cairo == False:
    Use_Cairo = False

small_flag_size = (24, 16)
medium_flag_size = (32, 24)
large_flag_size = (48, 32)

bitmaps = {}

class EmbeddedSvgImage(object):    #SVG embedded image
    def __init__(self, data, id=None, isBase64=True):
        self.id = id
        self.data = data
        self.isBase64 = isBase64

    def GetData(self):
        data = self.data
        if self.isBase64:
            data = b64decode(data)
        self.width = 640
        self.height = 480
        return data

    def GetBitmap(self, tx=0.0, ty=0.0, scale=1.0, width=-1, height=-1, stride=-1):
        data = self.GetData()
        if width < 0:
            width = self.width
        if height < 0:
            height = self.height
        if Cairo and Use_Cairo:
            try:
                png = cairosvg.svg2png(data, output_width=width, output_height=height)
                bmp = wx.Bitmap().FromPNGData(png)
            except Exception:
                bmp = wx.svg.SVGimage.CreateFromBytes(data).ConvertToBitmap(tx, ty, scale, width, height, stride)
        else:
            bmp = wx.svg.SVGimage.CreateFromBytes(data).ConvertToBitmap(tx, ty, scale, width, height, stride)
        return bmp

    def GetScaledBitmap(self, size=small_flag_size, window=None):
        # Use cached small flag bitmap
        if size == small_flag_size and bitmaps.get(self.id, ''):
            return bitmaps.get(self.id)
        data = self.GetData()
        if Cairo and Use_Cairo:
            try:
                if size == small_flag_size:
                    png = cairosvg.svg2png(data, output_width=size[0], output_height=size[1])
                    bmp = wx.Bitmap().FromPNGData(png)
                else:
                    png = cairosvg.svg2png(data)
                    bmp = wx.Bitmap().FromPNGData(png)
                    bmp = bmp.ConvertToImage()
                    bmp.Rescale(size[0], size[1], wx.IMAGE_QUALITY_HIGH)
                    bmp = bmp.ConvertToBitmap()
            except Exception:
                bmp = wx.svg.SVGimage.CreateFromBytes(data).ConvertToScaledBitmap(wx.Size(size), window)
        else:
            bmp = wx.svg.SVGimage.CreateFromBytes(data).ConvertToScaledBitmap(wx.Size(size), window)
        # If this is a small flag bitmap, cache it to speed up loading menus etc
        if size == small_flag_size and not bitmaps.get(self.id, ''):
            bitmaps[self.id] = bmp
        return bmp

    @property
    def MediumScaledBitmap(self):
        return self.GetScaledBitmap(size=(medium_flag_size))

    @property
    def LargeScaledBitmap(self):
        return self.GetScaledBitmap(size=(large_flag_size))

    def GetIcon(self):
        data = self.GetData()
        bmp = wx.svg.SVGimage.CreateFromBytes(data).ConvertToScaledBitmap(wx.Size(small_flag_size))
        bmp.SetMaskColour(wx.WHITE)     # Just in case for MSW
        ico = wx.Icon()
        ico.CopyFromBitmap(bmp)
        return ico

    def GetImage(self):
        data = self.GetData()
        if Cairo and Use_Cairo:
            png = cairosvg.svg2png(data)
            bmp = wx.Bitmap().FromPNGData(png)
            img = bmp.ConvertToImage()
        else:
            bmp = wx.svg.SVGimage.CreateFromBytes(data).ConvertToScaledBitmap(wx.Size(self.width, self.height))
            img = bmp.ConvertToImage()
        return img

    def GetPng(self):
        data = self.GetData()
        if Cairo and Use_Cairo:
            png = cairosvg.svg2png(data)
        else:
            png = None
        return png

    # define properties

    Bitmap = property(GetBitmap)
    ScaledBitmap = property(GetScaledBitmap)
    Data = property(GetData)
    Icon = property(GetIcon)
    Image = property(GetImage)
    Png = property(GetPng)

__version__ = 'flags_iso3166svg'

catalog = {}
lookup = {}
index = []
country = {}
regional = {}
details = {}

b64_Flags = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEu'
    b'MS8iCiAgIHhtbG5zOmNjPSJodHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9ucyMiCiAgIHht'
    b'bG5zOnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5OS8wMi8yMi1yZGYtc3ludGF4LW5zIyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3Nv'
    b'ZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOmlu'
    b'a3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgog'
    b'ICB3aWR0aD0iMjc2LjEwMzgybW0iCiAgIGhlaWdodD0iMTc1LjcwMzQ5bW0iCiAgIHZpZXdC'
    b'b3g9IjAgMCA5NzguMzIwNjIgNjIyLjU3MTQyIgogICBpZD0ic3ZnMiIKICAgdmVyc2lvbj0i'
    b'MS4xIgogICBpbmtzY2FwZTp2ZXJzaW9uPSIwLjkxIHIxMzcyNSIKICAgc29kaXBvZGk6ZG9j'
    b'bmFtZT0icGlyYXRlIGZsYWcuc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzNCIgLz4KICA8'
    b'c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9ImJhc2UiCiAgICAgcGFnZWNvbG9yPSIjZmZm'
    b'ZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEu'
    b'MCIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6em9vbT0iMC4zNSIKICAgICBpbmtzY2FwZTpjeD0i'
    b'NTU1LjMzMzI1IgogICAgIGlua3NjYXBlOmN5PSIxNjYuNzY2NTQiCiAgICAgaW5rc2NhcGU6'
    b'ZG9jdW1lbnQtdW5pdHM9InB4IgogICAgIGlua3NjYXBlOmN1cnJlbnQtbGF5ZXI9ImxheWVy'
    b'MSIKICAgICBzaG93Z3JpZD0iZmFsc2UiCiAgICAgaW5rc2NhcGU6d2luZG93LXdpZHRoPSIx'
    b'OTIwIgogICAgIGlua3NjYXBlOndpbmRvdy1oZWlnaHQ9IjEwMTgiCiAgICAgaW5rc2NhcGU6'
    b'd2luZG93LXg9Ii04IgogICAgIGlua3NjYXBlOndpbmRvdy15PSItOCIKICAgICBpbmtzY2Fw'
    b'ZTp3aW5kb3ctbWF4aW1pemVkPSIxIgogICAgIGZpdC1tYXJnaW4tdG9wPSIwIgogICAgIGZp'
    b'dC1tYXJnaW4tbGVmdD0iMCIKICAgICBmaXQtbWFyZ2luLXJpZ2h0PSIwIgogICAgIGZpdC1t'
    b'YXJnaW4tYm90dG9tPSIwIiAvPgogIDxtZXRhZGF0YQogICAgIGlkPSJtZXRhZGF0YTciPgog'
    b'ICAgPHJkZjpSREY+CiAgICAgIDxjYzpXb3JrCiAgICAgICAgIHJkZjphYm91dD0iIj4KICAg'
    b'ICAgICA8ZGM6Zm9ybWF0PmltYWdlL3N2Zyt4bWw8L2RjOmZvcm1hdD4KICAgICAgICA8ZGM6'
    b'dHlwZQogICAgICAgICAgIHJkZjpyZXNvdXJjZT0iaHR0cDovL3B1cmwub3JnL2RjL2RjbWl0'
    b'eXBlL1N0aWxsSW1hZ2UiIC8+CiAgICAgICAgPGRjOnRpdGxlPjwvZGM6dGl0bGU+CiAgICAg'
    b'IDwvY2M6V29yaz4KICAgIDwvcmRmOlJERj4KICA8L21ldGFkYXRhPgogIDxnCiAgICAgaW5r'
    b'c2NhcGU6bGFiZWw9IkxheWVyIDEiCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIK'
    b'ICAgICBpZD0ibGF5ZXIxIgogICAgIHRyYW5zZm9ybT0idHJhbnNsYXRlKDE4MC4zMzMyNSwt'
    b'NzYuNTU3MzM5KSI+CiAgICA8cGF0aAogICAgICAgc3R5bGU9ImZpbGw6IzAwMDAwMCIKICAg'
    b'ICAgIGQ9Im0gLTExNi44NTUxLDY5OC45NTM5MiBjIC0yLjQwNTU2LC0wLjM4ODU3IC02LjQ2'
    b'ODMxLC0yLjg1NDc5IC05LjAyODE5LC01LjQ4MDUyIC00LjM3NjEzLC00LjQ4ODYgLTQuNTE1'
    b'NDMsLTUuNDYwMjEgLTIuMzI3MTcsLTE2LjI1MTc1IDcuNDY1MjMsLTM2LjgxNTAxIDEwLjIx'
    b'ODk0LC0xMzEuNjEwOTcgNC42NTUzNiwtMTYwLjI2MjM0IC0xLjI3OTAxLC02LjU4NzYyIC0y'
    b'LjMwMjg4LC0xNC4xNzE1IC0yLjI3NDksLTE2Ljg1MzA1IDAuMDI4OCwtMi42ODE1NCAtMC44'
    b'Nzk0MiwtMTguMjU4ODUgLTIuMDE2MDUsLTM0LjYxNjIzIC0yLjc0NDA0LC0zOS40ODE2NSAt'
    b'Mi44NTA4MywtMzcuNjQ4NzggMi42ODQxNiwtNDYuMDc1OTUgbCA0Ljg1Mjg4LC03LjM4ODg3'
    b'IC00LjE5Nzk0LC05LjczMzc5IGMgLTIuMzA4ODUsLTUuMzUzNTYgLTYuNzkwNzUsLTE0LjI5'
    b'MTE1IC05Ljk1OTY4LC0xOS44NjEzIC0xNC4yNTAyMiwtMjUuMDQ4MzYgLTE0LjkyNzM4LC0y'
    b'Ny4xMDE2NSAtMTUuMTA5MjgsLTQ1LjgxNjM0IC0wLjE1MDIsLTE1LjM3Mzg2IC0wLjk0NzEy'
    b'LC0xOS4yNjkwMiAtNS43NjIzNCwtMjguMTM0MjYgLTcuNjU0NzQsLTE0LjA5Mjk2IC0xNi40'
    b'NTA2MywtNDEuMDMxMzEgLTE4LjY1MTQ2LC01Ny4xMjIzMyAtMC4yOTgzNSwtMi4xODEgLTEu'
    b'MTE4OTIsLTUuMzAzNzYgLTEuODIzNDYsLTYuOTM5NSAtMC43MDQzMiwtMS42MzU3NCAtMi4x'
    b'OTAxMiwtMTAuNTU3OTQgLTMuMzAxNjUsLTE5LjgyNzEyIC0xLjk5OTE4LC0xNi42NzIxMiAt'
    b'MS45NjI5NiwtMTYuOTExNTcgMy4zNzAzOCwtMjIuMzA1NSAyLjk2NTIzLC0yLjk5ODg1IDYu'
    b'Mzg0NzgsLTUuNDUyNDYgNy41OTkxOSwtNS40NTI0NiAxLjIxNDYsMCA0LjcwNDUzLC0yLjIz'
    b'MDU1IDcuNzU1NzUsLTQuOTU2NzcgMy4wNTEyNCwtMi43MjYyNCA2LjIyMTYyLC00Ljk1Njc5'
    b'IDcuMDQ1NDgsLTQuOTU2NzkgMC44MjM2NywwIDUuNzI1MzIsLTEuODY0OCAxMC44OTIyLC00'
    b'LjE0Mzk4IDEzLjExODczLC01Ljc4NjcxIDE2LjUzNzA1LC03LjEzNTk2IDI1LjM0MDk3LC0x'
    b'MC4wMDIyNSA0LjI0MzgzLC0xLjM4MTYzIDcuNzE2MDUsLTMuMjI1MDUgNy43MTYwNSwtNC4w'
    b'OTY0OCAwLC0wLjg3MTQyIDEuMzg1MTksLTEuNTg0NCAzLjA3ODM5LC0xLjU4NDQgMS42OTMw'
    b'MSwwIDguNDA1OTgxLC0xLjc3NTUgMTQuOTE3NzIxLC0zLjk0NTU4IDYuNTExNTMsLTIuMTcw'
    b'MDYgMTkuOTU5NDgsLTQuNzM3NjEgMjkuODg0MTcsLTUuNzA1NjcgMTQuNDE2NjcsLTEuNDA2'
    b'MjEgMTkuNjY0NDIsLTIuODQxNTggMjYuMDk5NjEsLTcuMTM4OCA5LjQ3MDU5LC02LjMyNDI3'
    b'IDIyLjQ1NjE5LC05LjY4ODEzIDI2LjExMjM2MDQsLTYuNzY0MjkgMS43MTM1OSwxLjM3MDMz'
    b'IDYuOTY2NjcsMC43MTM0IDE2Ljc1MzEsLTIuMDk1MDEgOC42MDk2ODk2LC0yLjQ3MDcgMjAu'
    b'MjgxOTA5NiwtNC4xMTkzIDI5LjQ2NzEwOTYsLTQuMTYxOTUgMTYuODQ2MSwtMC4wNzgzIDMy'
    b'LjcxNjQ4LC0zLjI3MzE2IDQ3Ljc4ODMxLC05LjYyMDUgMTAuNjczODcsLTQuNDk1MSAzMC44'
    b'OTI2MDksLTUuNjcyNjEgMzYuMzUyMDc5LC0yLjExNzEgMi41ODc2NSwxLjY4NTE1IDIuMDA1'
    b'NTUsMi45MDUzMyAtMy42MDA4Myw3LjU0OTIgLTMuNjc3OTgsMy4wNDY1MyAtNi42OTA3NCw2'
    b'LjM2NjQxIC02LjY5NDg2LDcuMzc3NDkgMCwxLjAxMTA3IC00LjE3MDk5LDMuNDg4MDYgLTku'
    b'MjU5MjYsNS41MDQ0NyAtMTAuNjU3NjI5LDQuMjIzMzEgLTEyLjQ4NzY1OSw3Ljg1NjI1IC0y'
    b'LjU3Nzk4OSw1LjExNzYzIDMuNjcwNTc5LC0xLjAxNDM2IDYuOTMxMDY5LC0xLjg0NDMgNy4y'
    b'NDU4OTksLTEuODQ0MyAwLjMxNDYsMCA1LjMzMTA3LC00LjUzNzkxIDExLjE0Nzk1LC0xMC4w'
    b'ODQyMyAxMy40NzE4MSwtMTIuODQ1NTcgMTcuOTA2OCwtMTQuNDgyNzkgMzAuMTY2NjgsLTEx'
    b'LjEzNjM0IDYuMTM2ODMsMS42NzUxNCAxMy40Mjg2MSwyLjEyMTIzIDIwLjI4NTYyLDEuMjQx'
    b'IDI4LjI0NjExLC0zLjYyNjAzIDgzLjU1MjMyLDIuMjIzMDQgODIuNzIyNDksOC43NDg1OSAt'
    b'MS40MTE5NCwxMS4xMDQ0NiAzLjkyNTkzLDE1Ljc5MjExIDE1Ljk5NjMxLDE0LjA0NzkyIDgu'
    b'MjE1MjMsLTEuMTg3MTEgMTAuMTQzNDIsLTAuNjM4NTMgMTguNzkzMDEsNS4zNDcwNiA5LjI5'
    b'MDE0LDYuNDI4NzQgMTAuMzg0NzksNi42ODIzIDMwLjI4NDE4LDcuMDE0NSAxNS4zNzA4LDAu'
    b'MjU2NTcgMjMuNzgzMTUsMS40NDU4MiAzMi45MjQzMSw0LjY1NDYgNi43NTMzLDIuMzcwNTIg'
    b'MjMuMzUzOTMsNi4zOTY3NSAzNi44OTAxNSw4Ljk0NzIzIDIxLjU3ODgyLDQuMDY1ODMgMjYu'
    b'OTAzMTEsNC40MDE2OCA0My4yMDk5MSwyLjcyNTY3IDMwLjk4OTEyLC0zLjE4NTA2IDQ0LjUy'
    b'OTQ2LC04LjI2NTQgNTcuMjAzNzUsLTIxLjQ2MjczIDkuMTg4MjgsLTkuNTY3NzMgMTYuMTY4'
    b'MTIsLTEwLjM1MDY3IDMwLjAxODUzLC0zLjM2NzI2IGwgOC45NTI5LDQuNTE0MTIgNi4wMjQ2'
    b'OSwtNS44MDUyNCBjIDYuNTg2NjQsLTYuMzQ2ODQgMTAuMTQyNCwtNi41MDU5NSAyOS4wNjQy'
    b'MiwtMS4zMDA0NCA4LjY2NDIsMi4zODM2MyAxMC4xNjQ4MiwyLjMyNTY4IDEzLjEwMzUyLC0w'
    b'LjUwNjAxIDQuMzQxMzYsLTQuMTgzMzkgMS45OTQ2NCwtNy41NDM4NiAtNS4yNjgxMiwtNy41'
    b'NDM4NiAtMy4xODk3MSwwIC02LjkzOTUxLC0xLjMyMzU0IC04LjMzMjczLC0yLjk0MTIyIC0y'
    b'LjEwMTY0LC0yLjQ0MDAyIC0xLjU5NTY3LC0zLjI4NDY2IDIuOTY4MzIsLTQuOTU2NzcgMy4w'
    b'MjU5MywtMS4xMDg1NiA4LjYyMDE3LC0yLjAxNTU3IDEyLjQzMTcsLTIuMDE1NTcgNS43ODgy'
    b'OCwwIDguMjIzODgsLTEuNTQ3ODIgMTQuNzgzNzUsLTkuMzk1MjggMTUuMDU3MjIsLTE4LjAx'
    b'MjUyIDI1LjQwMzcyLC0yMy40NTUzNCA0Ny45NzcyMSwtMjUuMjM4ODEgMzUuNTUxNDYsLTIu'
    b'ODA4ODA0IDQzLjkxMTM1LC00LjM3MzgwNCA1OS4wNzEyMywtMTEuMDU4NDM0IDQuNzYyNzYs'
    b'LTIuMTAwMTIgMTIuMTcwMTgsLTQuNzAwMTggMTYuNDYwODgsLTUuNzc3OSA0LjI5MDgsLTEu'
    b'MDc3NzMgMTMuNDAwMywtMy40MDAyOSAyMC4yNDMzLC01LjE2MTI1IDExLjcxMjUsLTMuMDE0'
    b'MDQgMTMuNTIyLC0yLjk3OTUzIDMwLjg2NDIsMC41ODg3MiAyMi4wNTgyLDQuNTM4NTQgMjMu'
    b'NjYyMSw3LjY0MDAzIDYuOTM3NCwxMy40MTQ2NSAtNi4zMTY0LDIuMTgwOTkgLTE0Ljc5MTcs'
    b'Ni40NTkxNiAtMTguODMzOSw5LjUwNzA4NCAtNC4wOTM0LDMuMDg2NDkgLTExLjc2NzUsNi4z'
    b'MTgzMyAtMTcuMzIxOSw3LjI5NDcyIC0zMC42MjIyLDUuMzgzMDggLTQyLjEyMDk3LDExLjI5'
    b'NjEyIC0xNy42NzI0LDkuMDg3ODIgMTcuMzY3NSwtMS41Njg3MyAyMC44MTUsMS4xNzMwNSAx'
    b'My4xMzkzLDEwLjQ0OTY3IC04LjY3MDQsMTAuNDc4NzkgLTEwLjU5MiwxNS44NzU1IC0xMC44'
    b'MjEyLDMwLjM5MTI1IC0wLjI3NjUsMTcuNTA0MzcgLTIuNzUyNywyMy4zNjUxOSAtMTAuNTAy'
    b'NDYsMjQuODU4NzIgLTUuNDUsMS4wNTAzMiAtOC4xODYwMSwzLjQ5OTcxIC0xNS45OTc3NCwx'
    b'NC4zMjIxIC0xLjY5MTU3LDIuMzQzMzUgLTYuNjE1NjUsNS4yODI2NiAtMTAuOTQyNCw2LjUz'
    b'MTc4IC00LjMyNjc1LDEuMjQ5MTYgLTkuNjc0NSw0LjQ4NTUzIC0xMS44ODM3Niw3LjE5MTk3'
    b'IC01Ljg2ODk0LDcuMTg5NTkgLTIyLjg2NzA5LDEyLjQ2OTA0IC0zOS42MTI3OCwxMi4zMDMy'
    b'NSAtNy43NDA1NSwtMC4wNzY1IC0xNS44NDI0LC0xLjA1MTQxIC0xOC4wMDQxNCwtMi4xNjYx'
    b'NSAtMy4yMTM5OSwtMS42NTc1MSAtMy45MzAyNSwtMS4zNTQ1NCAtMy45MzAyNSwxLjY2Mjc0'
    b'IDAsNC45MDc3NiAtNy43NzM4NiwxMS42NzYzIC0xNS40MzIxLDEzLjQzNjQgLTcuNTUzNzEs'
    b'MS43MzYwNiAtMjIuNjEyOTgsMTIuMDc4MDggLTM2LjMxODk2LDI0Ljk0MjE1IC01LjYzODQ4'
    b'LDUuMjkyMDMgLTExLjE0NzEzLDkuNjIxOSAtMTIuMjQxNTgsOS42MjE5IC0xLjA5NDQ0LDAg'
    b'LTkuMTM0NTcsNC40ODY2OCAtMTcuODY2ODgsOS45NzA0MSAtMTQuODYyMzYsOS4zMzMxOSAt'
    b'MTUuNDE2ODgsOS45MjY2MiAtOC42NzU1Miw5LjI4NTY5IDkuMTgyOTMsLTAuODczMDUgMTUu'
    b'MzYxNTQsLTQuMDY4ODQgMjYuMDcwMTgsLTEzLjQ4NDIyIDYuMTQ1OSwtNS40MDM3MSAxMi44'
    b'NTk2OCwtOC43NjA4MSAyMy42NjI1NywtMTEuODMyMTEgMjEuNzUxMDUsLTYuMTgzODggNDEu'
    b'NjA0MTUsLTEzLjA2ODkzIDUwLjk5MjIzLC0xNy42ODQwNyA0LjQ5MDUzLC0yLjIwNzUxIDku'
    b'ODM4NDcsLTQuMDEzNjYgMTEuODg0MzYsLTQuMDEzNjYgMi4wNDU2OSwwIDYuOTQzNjMsLTIu'
    b'MDkxODYgMTAuODg0MzcsLTQuNjQ4NTYgNi41NTU1NiwtNC4yNTMyIDIxLjA0ODE2LC05LjIw'
    b'NjY3IDM1LjUzNDE5LC0xMi4xNDUyMSA3LjM5MDU0LC0xLjQ5OTIxIDIyLjU1OTI3LDIuMzc5'
    b'NzcgMjEuNTIzODgsNS41MDQxMyAtMC40MzE0NywxLjMwMjA5IC01LjE4MjkyLDUuNDkwMjEg'
    b'LTEwLjU1ODg1LDkuMzA2OTMgLTEwLjI3NzU4LDcuMjk2ODUgLTEwLjY2NDgyLDguNzI3NiAt'
    b'Ni4yNzg4MiwyMy4yMDA1NiAwLjk2Mzc5LDMuMTgwMzkgLTAuMTAyOTIsNS42Mzc5OCAtMy45'
    b'MzEwNyw5LjA1NjczIC02LjY4MTQ4LDUuOTY2NzMgLTM1LjM3NTMzLDQ2Ljk2ODM1IC0zOS40'
    b'NTY4MSw1Ni4zODEyNCAtMi40NzczOCw1LjcxMzQgLTIuNjE2ODgsOC4zNzQ1NiAtMC43MDYx'
    b'OSwxMy40NjYyNiAzLjQ4NjIzLDkuMjg5OSAxLjAwNTE2LDE2LjAxMzkgLTYuOTUzMDgsMTgu'
    b'ODQ0NzYgLTkuOTEwNywzLjUyNTI4IC0zMy4xNzYxNiw3LjcxNTE5IC0zOS4yNjQ0NCw3LjA3'
    b'MTE5IGwgLTUuMzA3ODIsLTAuNTYxNDUgNi4zNjMxNyw1LjcyNzc0IGMgNS45ODYwMSw1LjM4'
    b'ODE3IDYuODAzNzEsNS41ODQwNCAxMy43OTIyLDMuMzAzNzIgOS43MjgyLC0zLjE3NDIxIDI5'
    b'LjE1NjgxLC0yLjM4MDIgMzkuNTE5MzcsMS42MTUxMSA2LjEzNDk5LDIuMzY1MzcgOC41Mjky'
    b'Miw0LjU2MDY5IDkuMzY0ODIsOC41ODY5OCAwLjg1NDMyLDQuMTE2NDEgNC42NDA1NCw3LjQ1'
    b'MDk2IDE1Ljg0MTk5LDEzLjk1MjMgMTIuMzMzNTUsNy4xNTg0MyAxNy4wNTM5Miw4Ljc0NDE3'
    b'IDI5LjEyMjY1LDkuNzgzNTcgMTUuNzM2MjcsMS4zNTUyMyAyNS42Mzc4Nyw1LjE0NjQzIDM0'
    b'Ljc4MzM3LDEzLjMxNzk0IGwgNS45MzMxLDUuMzAxMzIgLTQuMjkwOSwzLjM0ODI0IGMgLTIu'
    b'MzYwMSwxLjg0MTU0IC03LjgxNzcsMy45MTYxOSAtMTIuMTI3OCw0LjYxMDM2IC00LjMxMDMs'
    b'MC42OTQxNyAtOC44MDIzLDEuOTMxODQgLTkuOTgyNSwyLjc1MDM3IC01LjM1OTkxLDMuNzE3'
    b'ODMgLTIxLjY1NzQ1LDI1LjIxMTgxIC0yMi42OTk4NSwyOS45Mzc2IC0zLjU1NzQsMTYuMTI5'
    b'MjIgLTExLjU0OTU5LDE5LjAzOTkgLTMzLjgxNTQ1LDEyLjMxNTQ3IC0xOC4yNTgwNCwtNS41'
    b'MTQwNyAtMjIuNjcyMjQsLTUuMTc5OSAtNDAuNzQ2MTIsMy4wODQ3NSBsIC0xNS42Nzg4Miw3'
    b'LjE2OTM3IDUuODM3NjYsNC44Mzg1NyBjIDQuOTMyNzEsNC4wODg0MyA3LjQ5NTI3LDQuNzIw'
    b'MyAxNi41MzAyNiw0LjA3NTgyIDUuODgwODcsLTAuNDE5NTIgMTEuNTU1NTYsLTEuMjcxMSAx'
    b'Mi42MTA1LC0xLjg5MjQxIDIuMjM1NCwtMS4zMTY0OSA1NS45OTIwMiwxLjkzNzMzIDYwLjU2'
    b'MDEzLDMuNjY1NjcgNy44ODcwNCwyLjk4MzkxIDUwLjg1MTY5LDQuMjgyMTIgODMuNjYxMTks'
    b'Mi41Mjc4NiA4LjEwMTgsLTAuNDMzMjEgMTUuMzIyOCwtMC4yMjM3NiAxNi4wNDY1LDAuNDY1'
    b'NDQgMy41MDU0LDMuMzM4NDYgLTEuODg1LDEyLjAxODQ2IC05LjkzMDksMTUuOTkxNDggLTEw'
    b'LjYyNzUsNS4yNDgwMiAtMTEuMTUxLDUuMzExMzkgLTU0Ljc5NzMsNi42MzQ0MiAtMzYuNDE1'
    b'MjksMS4xMDM4OCAtNTEuOTQ0MzEsMy4xNDAwNiAtNjIuMjQyODksOC4xNjEzOCAtNy4wMzA0'
    b'NSwzLjQyNzkzIC03LjMxMDA4LDUuMTE0ODMgLTAuNTc3OTgsMy40ODY2NiA3LjA3Njc1LC0x'
    b'LjcxMTQ4IDE5LjU4MTkxLDUuNzg5MDcgMTguMTkxNzgsMTAuOTExMyAtMC42NjAwOCwyLjQz'
    b'MjMzIC0xMS4xNDM0Miw4LjYyNzgzIC0zMC4xNDYzMiwxNy44MTU5OSAtMjIuMDI4NCwxMC42'
    b'NTExNyAtMzIuMzk2MTEsMTYuOTk2NTYgLTQyLjUwODY3LDI2LjAxNjk5IC0xNS41ODE3LDEz'
    b'Ljg5ODk2IC0yNi4yMTcxLDE3LjkzMjA0IC00MC45MTQ0MywxNS41MTUyNyAtMjQuNzkyMjEs'
    b'LTQuMDc2OCAtMjcuMDkwNzcsLTQuMTE2NyAtNDIuMDE2NywtMC43Mjk2NiAtMTMuODkzODQs'
    b'My4xNTI4NSAtMTUuODU3NjIsMy4xODcyNSAtMjIuMjI0NzEsMC4zODkyNyAtMTYuNjIyMDMs'
    b'LTcuMzA0NDkgLTU2LjE4MzE3LC0xNy4xNTQzNiAtNjUuNjI2MTksLTE2LjMzOTQzIC03Ljg0'
    b'MzQxLDAuNjc2OSAtNi4xMzU4LDMuODc1NzEgMy4wODY0Myw1Ljc4MTcyIDQuNTI2NzUsMC45'
    b'MzU1NiAxMS43NDg1NywzLjA5ODUzIDE2LjA0ODU3LDQuODA2NTcgNi41NDA1NCwyLjU5ODA3'
    b'IDcuNzE3NSwzLjk0MDExIDcuMjAxNjUsOC4yMTI1MyAtMC40NTc2MiwzLjc5MTQ4IC0xLjk0'
    b'MTU2LDUuMjQxMTQgLTUuNzYwNDksNS42Mjc3NyAtOS43NjQ4MywwLjk4ODYxIC0yMS4xMDM3'
    b'Miw0Ljc1NTIzIC0yNS4wOTEzOCw4LjMzNDk5IC04LjI4Nzg3LDcuNDQwMzIgLTI2LjA0NTI5'
    b'LDYuNTM3NTMgLTM3LjE2Mjk5LC0xLjg4OTQzIC02Ljk4OTkzLC01LjI5ODEgLTI2LjAzMzk3'
    b'LC05Ljg1MzQ0IC0zNS44NzU1NCwtOC41ODE0NiAtOS41MDU1NywxLjIyODU2IC0xNC40NDMw'
    b'MiwtMC4wNjY2IC00Ni45MzE5MywtMTIuMzEwOTkgLTYwLjg5NDcxLC0yMi45NTAwMiAtNjIu'
    b'MDk4NCwtMjMuMjc3ODQgLTgwLjk2NDY3LC0yMi4wNTI0NyAtMTMuNjA3NDMsMC44ODM4MiAt'
    b'MTguMjA1NzksMC40NjcyNyAtMjIuMTE5MzcsLTIuMDAzNjUgLTQuNjg5NSwtMi45NjA4IC02'
    b'LjgzOTMxLC04LjYxMTQ5IC0zLjI3NjMzLC04LjYxMTQ5IDAuOTE1NDIsMCAzLjMyNTUyLC0x'
    b'LjE3MDQ4IDUuMzU1NzYsLTIuNjAxMDYgNi43NjIxNSwtNC43NjQ0NSAtMTcuMjQ2NTIsLTEu'
    b'NjQ0NyAtMjkuMjI2NzgsMy43OTc4NyAtOS42OTQyMyw0LjQwMzk5IC0xMS42NTc0LDQuNjc5'
    b'NjkgLTE3Ljg4MDY2LDIuNTExMjQgLTYuNTE0NjEsLTIuMjY5OTUgLTcuODA1MTUsLTEuOTYw'
    b'NjEgLTE4Ljk0NTcsNC41NDE0OSAtNi41NzUxMSwzLjgzNzU1IC0xNy45NzMyNiw5LjA0NzI4'
    b'IC0yNS4zMjkyNCwxMS41NzcxOCAtNy4zNTU5NywyLjUyOTkgLTE0LjgyNDA4LDUuNzg0OTEg'
    b'LTE2LjU5NTg5LDcuMjMzMzUgLTEuNzcxODIsMS40NDg0MyAtNi40MDE0NSwzLjIxNTc1IC0x'
    b'MC4yODgwNywzLjkyNzQxIC0zLjg4NjYzOSwwLjcxMTY0IC03Ljk5MjU5OSwxLjk2MDY3IC05'
    b'LjEyNDI4OSwyLjc3NTYgLTEuMTMxNjksMC44MTQ5NiAtNy4xNTAyMSwyLjA5ODc2IC0xMy4z'
    b'NzQ1LDIuODUyOTIgLTYuMjI0MjgsMC43NTQxOSAtMTQuMDk0NjYsMi4xNDgxNyAtMTcuNDg5'
    b'NzIsMy4wOTc3OCAtMjcuNDkxNzksNy42ODk0MiAtMzguNjY0NjQsMTAuOTE5ODIgLTQ5LjE4'
    b'MjM1LDE0LjIyMDAyIC0xMy4xODIxMDk2LDQuMTM2MTkgLTE3LjQxMTk0OTYsMi41NDI4MSAt'
    b'MTMuMjMxNDg5NiwtNC45ODQyNiAxLjYyODQwMDAzLC0yLjkzMTc3IDEuNDc3MTYwMDMsLTMu'
    b'NjE1MDcgLTAuNjU4MDIsLTIuOTc0ODggLTEuNTI0NDksMC40NTcxIC02LjYwNTk3LDYuMjk0'
    b'NjggLTExLjI5MjIwMDQsMTIuOTcyMzggLTQuNjg2MjEsNi42Nzc3MiAtMTEuMjU5MDUsMTQu'
    b'NzIwOTkgLTE0LjYwNjE4LDE3Ljg3MzkyIC0zLjM0NzMyLDMuMTUyOTQgLTYuOTIwNTgsNy4w'
    b'MDk5NSAtNy45NDA1NCw4LjU3MTE2IC02LjgzNzQ2LDEwLjQ2NDg1IC00Ni45NzY3OCwzNC4x'
    b'MDQ5IC02Mi40NzQ1MywzNi43OTQzNSAtNC4wMDQ3NDEsMC42OTQ5OCAtOC42NzAzODEsMS44'
    b'NjI2NSAtMTAuMzY3OTExLDIuNTk0ODUgLTEuNjk3NTQsMC43MzIxNyAtNS4wNTQ3MywxLjAx'
    b'MzMyIC03LjQ2MDMsMC42MjQ3OCB6IG0gNTguMDIxMjQxLC00OS4wNzkwMiBjIDMuODc4ODIs'
    b'LTMuNTI0OTggNy4wNTIyNywtOC4yNDg5MiA3LjA1MjI3LC0xMC40OTc2MyAwLC0zLjU1NTg3'
    b'IC0wLjc2Njg3LC0zLjg3NjY1IC01Ljg4NjAxLC0yLjQ2MTk1IC0xMy4wNjExMywzLjYwOTU1'
    b'IC0xNi43NDc3Niw3LjMzMTU0IC0xNi43NDc3NiwxNi45MDg4NiAwLDYuMTk0MDQgNi4xMjk4'
    b'NSw0LjY0MDQyIDE1LjU4MTUsLTMuOTQ5MjggeiBNIDU4MS45NjM3Niw1ODcuNjM4OTQgYyAw'
    b'LC0yLjMyODQyIC02LjAxNzA5LC00LjUwNDM1IC04LjQ0OTYsLTMuMDU1NjUgLTEuMDQ4MTQs'
    b'MC42MjQxNCAtMS4zNzI4NCwxLjk2NTM3IC0wLjcyMTgxLDIuOTgwNTIgMS41MTMxNywyLjM1'
    b'ODkyIDkuMTcxNDEsMi40MjE2NiA5LjE3MTQxLDAuMDc1MSB6IG0gMzEuNjAxNjcsLTE4Ljg2'
    b'OTM3IGMgMy40MzA2NiwtMi43MDM4OSA0Ljk5MDMyLC01LjE2NjM0IDMuNzQzLC01LjkwOTE4'
    b'IC0xLjE3NjEzLC0wLjcwMDQzIC0yLjcxOTk2LC0wLjM2Njc0IC0zLjQzMDg2LDAuNzQxNTMg'
    b'LTAuNzEwOTEsMS4xMDgyOCAtNC4wMTU0MywyLjAxNTA2IC03LjM0Mzg0LDIuMDE1MDYgLTUu'
    b'NjkwNTQsMCAtOC4wNjIzNSwzLjM0OTUzIC00LjY3OTYyLDYuNjA5MDIgMi4zNzY5NSwyLjI5'
    b'MDQ1IDUuNjQzLDEuMzI2NTIgMTEuNzExMzIsLTMuNDU2NDMgeiBNIDEwOS4xNzU5NCw1MzYu'
    b'MjIyNjQgYyAxLjExMDA5LC0xLjA2OTUzIDEuNjkxMzYsLTYuNDA4MyAxLjI5MTc4LC0xMS44'
    b'NjM5MyAtMC4zOTk2LC01LjQ1NTYzIC0wLjAzMDgsLTkuNTAzNDQgMC44MjA1NywtOC45OTUx'
    b'MyAwLjg1MDgzLDAuNTA4MzMgMi40MzU1OSwtMS4zMjc1NSAzLjUyMTQsLTQuMDc5NjkgMS4y'
    b'MTE5NCwtMy4wNzE1OSA1Ljk3MjQzLC02Ljk1NjE2IDEyLjMyNzc5LC0xMC4wNTk0NSA1LjY5'
    b'NDQ1LC0yLjc4MDU1IDEwLjY2NjQ3LC00LjgyMDUyIDExLjA0ODk3LC00LjUzMzI3IDAuMzgy'
    b'NTEsMC4yODcyNSA1LjcxMjk4LC0xLjU4OTcyIDExLjg0NTI5LC00LjE3MSAyNi44OTExNiwt'
    b'MTEuMzE5MjMgMzEuNDU5OSwtMTMuMTQzMSAzMi41ODc2NywtMTMuMDA5NTMgMC42NTc4Myww'
    b'LjA3NzkgMi40MTk1NiwtMS4wMzczOSAzLjkxNTAzLC0yLjQ3ODM5IDEuNDk1MjcsLTEuNDQx'
    b'MDEgMy45MjgxOSwtMi42MjAwMSA1LjQwNjM4LC0yLjYyMDAxIDEuNDc4MTksMCAzLjc3NDA4'
    b'LC0xLjI2MTQyIDUuMTAxODYsLTIuODAzMTYgMi4zMzI3MiwtMi43MDgzMiAxOS42MTUyMywt'
    b'MTEuNDg4MzEgMjMuODA5NjksLTEyLjA5NTk3IDguMjMwMDQsLTEuMTkyMjggMTUuMTg0Mzgs'
    b'LTMuNzEwMjggMTQuMjUzOTEsLTUuMTYwOTYgLTAuNjExMzEsLTAuOTUzMDkgMS4yNTU1Niwt'
    b'Mi43NzIxIDQuMTQ4NTYsLTQuMDQyMjcgMi44OTMyMiwtMS4yNzAxNyA1LjI2MDA5LC0zLjA2'
    b'NTYzIDUuMjYwMDksLTMuOTg5OSAwLC0wLjkyNDI5IDMuNzAzNzIsLTMuMTA4NSA4LjIzMDQ3'
    b'LC00Ljg1MzgyIDQuNTI2NzQsLTEuNzQ1MyA4LjIzMDQ2LC0zLjgyNTgzIDguMjMwNDYsLTQu'
    b'NjIzMzcgMCwtMC43OTc1NSAzLjkzNTE4LC0yLjYyMTc4IDguNzQ0ODYsLTQuMDUzODUgNC44'
    b'MDk2NywtMS40MzIwOCAxMC4xMzM3NSwtNC4wMjg0NyAxMS44MzEyOCwtNS43Njk4MSAxLjY5'
    b'NzUzLC0xLjc0MTMyIDQuMDEyMzUsLTMuMTkyOTMgNS4xNDQwNCwtMy4yMjU3NyAxLjEzMTY4'
    b'LC0wLjAzMjkgOS45MjQwOCwtMy44MjQ4MiAxOS41Mzg2OSwtOC40MjY1MyA5LjYxNDQyLC00'
    b'LjYwMTczIDE4LjkxMDczLC04LjM2Njc5IDIwLjY1ODI2LC04LjM2Njc5IDEuNzQ3NTMsMCA4'
    b'LjUyMDE2LDEuMzQwOTkgMTUuMDUwMiwyLjk3OTk2IDEzLjY3Mjg2LDMuNDMxNjcgMTguMDg1'
    b'ODMsMi4xMDQyNyAyMi45MTQwMSwtNi44OTI3MiAzLjY4NTIsLTYuODY2OTYgMS40MjE2Miwt'
    b'MTQuOTA2MzYgLTQuNzI2NTQsLTE2Ljc4NjY3IC03LjA1MTI0LC0yLjE1NjUxIC0xMC40MTMz'
    b'OCwtNy44NjQzOCAtMTEuNzY2ODcsLTE5Ljk3NjQzIC0xLjUzMTcsLTEzLjcwNzE4IC0wLjg5'
    b'MTE2LC0xMi4zNTYxOCAtNi4xMTIxNiwtMTIuODkxNzkgLTEyLjk5NjMxLC0xLjMzMzM0IC0y'
    b'Mi43NDkzOSwyLjc4NDQgLTIwLjQyNDA5LDguNjIzMTUgMC41NTMxLDEuMzg5MjEgLTAuNDQx'
    b'NTUsNS44NjM3NyAtMi4yMTA0OSw5Ljk0MzQ2IC0xLjc2OTE0LDQuMDc5NzEgLTIuNjY5MzQs'
    b'OC4yNzA1OCAtMi4wMDA4Myw5LjMxMzA3IDAuNjY4NzMsMS4wNDI0OSAtMC4yNTY3OCwxLjg5'
    b'NTQzIC0yLjA1NjU4LDEuODk1NDMgLTEuOCwwIC0zLjg1NDc0LDEuNTYxMzkgLTQuNTY2MjYs'
    b'My40Njk3NSAtMi42ODM3NCw3LjE5ODIgLTEyLjA1MzMxLDEzLjA4NTA1IC01MS45ODc5LDMy'
    b'LjY2Mzg4IC0xMi45NjY0Nyw2LjM1NzA5IC0yNC4xODEwOCwxMi41MDI3MiAtMjQuOTIxNDIs'
    b'MTMuNjU2OTYgLTAuNzQwMzMsMS4xNTQyNCAtMS45Mzc4NiwyLjAyMDY4IC0yLjY2MTEsMS45'
    b'MjU0NiAtMS4zMjUzMiwtMC4xNzQ0OCAtMTIuMTgwNjcsNC44NjAwNiAtMzEuMTQ2NzQsMTQu'
    b'NDQ1NDIgLTUuNjU4NDUsMi44NTk3NiAtMTEuMzMyMTEsNS4yMDMyOCAtMTIuNjA4MDMsNS4y'
    b'MDc4NSAtMS4yNzYxNCwwLjAwNCAtMy4zOTIzOSwxLjI1MzMxIC00LjcwMjg5LDIuNzc0OTYg'
    b'LTEuMzEwNywxLjUyMTY3IC01LjcwODAyLDMuMzY3NzMgLTkuNzcyMDIsNC4xMDIzOSAtNy4x'
    b'MzQ1OCwxLjI4OTczIC0yOS41Mjg4MywxMC44NjU2MiAtMzQuMzQ5LDE0LjY4Nzc4IC0xLjI5'
    b'NDY1LDEuMDI2NjUgLTEwLjY3MzY4LDUuMTgwMjIgLTIwLjg0MTk5LDkuMjMwMTIgbCAtMTgu'
    b'NDg4MDg5LDcuMzYzNDggLTkuNTkzLC01LjE5NjI0IGMgLTEzLjQwMjY5LC03LjI1OTczIC0x'
    b'OC44OTExNywtNi44Mzg5NCAtMjQuMjE1NDUsMS44NTY2IC0yLjM3NTExLDMuODc5MDYgLTQu'
    b'MzE4NTMsNy44ODY0MiAtNC4zMTg1Myw4LjkwNTI0IDAsMS4wMTg4NCA1LjA5MjYsNC42MjE4'
    b'OCAxMS4zMTY4OCw4LjAwNjc1IDYuMjI0MjgsMy4zODQ4OSAxMS43ODMzNCw2Ljg4MTcgMTIu'
    b'MzUzNTEsNy43NzA2OCAxLjYwOTQ3LDIuNTA5MjcgMS42MzAyNSwxMC4yNzgyNiAwLjA0NTIs'
    b'MTYuOTU2OTMgLTEuMjE3MjgsNS4xMjk4NyAtMC43MDQxMSw2LjM4MDAxIDMuMzI5ODUsOC4x'
    b'MTQ0OCA1LjAzNjQyLDIuMTY1NTUgMTcuMjQ1ODg5LDAuNDQyNDggMjAuNzQzMDA5LC0yLjky'
    b'NzM1IHogbSAyNDguMTUwNiwtMTMuMjQ4NjIgNi4xMzE1LC00Ljk3MTQzIC0yLjk2ODMzLC0x'
    b'MC45NTM1MyBjIC0yLjYwMDIsLTkuNTk0MzUgLTIuNTkzNjIsLTExLjMxNDc0IDAuMDUxNCwt'
    b'MTMuODY0MzMgMS42NjEzMywtMS42MDA5NCAzLjc4MTI5LC0yLjkzODk5IDQuNzEwOTEsLTIu'
    b'OTczNDUgMC45Mjk2MywtMC4wMzQ1IDQuMjM2NDIsLTIuMjIyMjMgNy4zNDg1NywtNC44NjE2'
    b'OSA3LjI0MzIyLC02LjE0MzA3IDcuMDgxNDgsLTEyLjY1Njc0IC0wLjQ1NjU5LC0xOC4zODYz'
    b'NCAtNi43NjY4OCwtNS4xNDMzNyAtMTEuNzk0MDQsLTQuMTU2MTggLTIzLjgxMDUxLDQuNjc1'
    b'NjQgLTcuMjAwNjMsNS4yOTIxOSAtMTkuMTg1NDEsNi45MzY4NSAtMjQuMTQyNDEsMy4zMTMw'
    b'NSAtMS4zODQxNSwtMS4wMTE3OSAtNy4xNDYwOSwtMy40ODA1MiAtMTIuODA0NTMsLTUuNDg2'
    b'MTMgLTUuNjU4NDQsLTIuMDA1NTkgLTEzLjUyODgyLC01LjAwNDc0IC0xNy40ODk3MywtNi42'
    b'NjQ3NyAtMy45NjA5LC0xLjY2IC03LjY2NDYyLC0zLjEwNzcgLTguMjMwNDYsLTMuMjE3MDcg'
    b'LTAuNTY1ODQsLTAuMTA5NDQgLTYuMzg3NjUsLTIuMTcxMDggLTEyLjkzNzI1LC00LjU4MTU3'
    b'IC0xNS4wMDk4OSwtNS41MjQxNCAtMjEuMDcxODMsLTUuNDQyOTggLTMwLjk2MjE2LDAuNDE0'
    b'NjUgLTguOTIyNjUsNS4yODQ0OCAtOC41ODc4Nyw1LjY4ODc5IDkuNDAwMjEsMTEuMzUxMzQg'
    b'Ny4wOTE3OCwyLjIzMjQ2IDE3Ljc4MjcyLDYuMjAzOTMgMjMuNzU3NjMsOC44MjU0OCA1Ljk3'
    b'NDksMi42MjE1OCAxMi4xNzAzOSw0Ljc2NjUgMTMuNzY3NSw0Ljc2NjUgMS41OTczMywwIDMu'
    b'NDEyOTcsMC43OTMzOCA0LjAzNDc3LDEuNzYzMDcgMC42MjIwMiwwLjk2OTY4IDMuNDAzOTIs'
    b'Mi4zMTI4MSA2LjE4MjMxLDIuOTg0NzQgMi43NzgxOSwwLjY3MTkyIDExLjY0MTU4LDQuMDc2'
    b'OTEgMTkuNjk2MzIsNy41NjY2NiBsIDE0LjY0NTA3LDYuMzQ0OTcgLTAuNDc5NDIsMTAuMDAx'
    b'NzEgYyAtMC4yNjM1OCw1LjUwMDk2IDAuNjM2NjIsMTIuMDA5MjMgMi4wMDA0MSwxNC40NjI4'
    b'MyAzLjQ5MTk4LDYuMjgyIDE0LjQ4MzU1LDYuMDMzMjkgMjIuNTUzOTMsLTAuNTEwMzMgeiBt'
    b'IDIxNy42MTEwOCwtNDEuOTQ4NDUgYyA5LjE3MTQxLC00LjU4NjM0IDEwLjY4NDc4LC05LjU3'
    b'ODk1IDIuOTEwOTEsLTkuNjAzOTEgLTYuODgyOTQsLTAuMDIyIC0yMi44NjkxNSw0Ljg2MTcx'
    b'IC0yNi45MTA5Myw4LjIyMTI3IC0xLjc4NjYzLDEuNDg1MDkgLTQuNTY0NDEsMi43Mjg1MyAt'
    b'Ni4xNzI4NSwyLjc2MzIxIC0yLjIyMjQyLDAuMDQ4IC0yLjA3MDU4LDAuNjg3OTMgMC42MzI3'
    b'MywyLjY2NjE1IDQuNTcyMDEsMy4zNDU4NSAxOC41OTk1OSwxLjQyNDIgMjkuNTQwMTQsLTQu'
    b'MDQ2NzIgeiBNIDIwOS42MTc1OSw0MzguNjgzMTQgYyA0LjQ4MTY5LC0yLjIwMzE1IDguMTQ4'
    b'MzUsLTQuNzEzMzQgOC4xNDgzNSwtNS41NzgyIDAsLTAuODY0ODggLTYuNzEyOTcsLTQuMDkx'
    b'NTMgLTE0LjkxNzcsLTcuMTcwMzIgLTguMjA0NzQsLTMuMDc4ODEgLTE5LjU0NzM1LC03LjYw'
    b'MzE4IC0yNS4yMDU3OSwtMTAuMDU0MTUgLTUuNjU4NDQsLTIuNDUwOTcgLTE3LjIzMjUyLC03'
    b'LjM1ODM4IC0yNS43MjAxOCwtMTAuOTA1MzMgLTMyLjI4MTUxLC0xMy40OTAzNyAtMzcuMDM4'
    b'NzEsLTE1Ljk1NDYgLTM3LjM1MDQ0LC0xOS4zNDczNiAtMC40ODkzLC01LjMyNTggLTAuOTMz'
    b'OTUsLTYuOTgxODIgLTMuNDgwODYsLTEyLjk1ODU5IC0xLjMwODIzLC0zLjA2OTgzIC0yLjM3'
    b'ODYxLC02LjM5NTA5IC0yLjM3ODYxLC03LjM4OTQ2IDAsLTAuOTk0MzYgLTIuMzQzODIsLTMu'
    b'Mjg3ODQgLTUuMjA4NjQsLTUuMDk2NjMgLTMuOTQ3MzI5LC0yLjQ5MjIyIC02Ljc2MDkxOSwt'
    b'Mi44NTk4IC0xMS42MTY4ODksLTEuNTE3NzkgLTEwLjgwNTM1LDIuOTg2MTIgLTExLjgyMzI1'
    b'LDcuMTE3NTUgLTQuODk2NzEsMTkuODcyNjkgbCA2LjA1NTc3LDExLjE1MDk4IC00LjIyNjk2'
    b'LDMuMjAzMDcgYyAtMi4zMjQ2OSwxLjc2MTY5IC02LjYyODYsNC45ODc1MiAtOS41NjQ0MSw3'
    b'LjE2ODUgLTIuOTM1OCwyLjE4MDk5IC01LjYxMDUsNS43NDk4NiAtNS45NDQwMyw3LjkzMDg1'
    b'IC0wLjMzMzU1LDIuMTgwOTkgLTEuMjg2NDMsNC40NTU2OSAtMi4xMTc5MSw1LjA1NDkgLTIu'
    b'NDA2OCwxLjczNDg3IDQuMjcyNDMsOS41NTE0IDExLjA0NTksMTIuOTI2NTkgOC4wNjc2OSw0'
    b'LjAyMDAyIDE2LjA4ODY5LDIuMjQ3MjYgMjMuNDgzMzQ5LC01LjE5MDIgMy4yLC0zLjIxODQ4'
    b'IDcuMjg1OCwtNS44NTE4IDkuMDc5NjMsLTUuODUxOCAxLjc5MzYyLDAgMTMuNjU3NDIsMy40'
    b'OTc4OCAyNi4zNjQwMiw3Ljc3MzA5IDEyLjcwNjM4LDQuMjc1MiAyMy4xMDI0OCw3LjI4ODcy'
    b'IDIzLjEwMjQ4LDYuNjk2NzIgMCwtMC41OTIgMS4zOTU2OCwwLjAzOTggMy4xMDE2NCwxLjQw'
    b'Mzk5IDMuMzgyMzEsMi43MDQ5NyAyNy4xNjI3OCwxMS42MTQxNiAzMS40NDU1LDExLjc4MDg2'
    b'IDEuNDU5NjcsMC4wNTY3IDYuMzIwNzksLTEuNjk5MjggMTAuODAyNDksLTMuOTAyNDEgeiBt'
    b'IDQ2NC40MjQ0MiwtMS4yMDkzOSBjIDYuNTY3NSwtMS42OTU5NSA1Ljc0MTk5LC00LjY5ODQ1'
    b'IC0xLjI5MTk3LC00LjY5ODQ1IC01LjYyNDI5LDAgLTE1LjkxMjc3LC0zLjI2NjI3IC0yNi44'
    b'MjI0NSwtOC41MTU0IC0zLjkxNjg3LC0xLjg4NDU0IC01LjE0ODc3LC0xLjg2NTc3IC01Ljgy'
    b'OTg0LDAuMDg4OCAtMC40NzUxLDEuMzYzMTIgLTMuMjE0NjEsMi40NzgzOSAtNi4wODgwOCwy'
    b'LjQ3ODM5IC05LjA5NzUyLDAgLTEuODg5NSw1LjA0MDA1IDExLjE5OTgyLDcuODMxMzUgNi41'
    b'MjE2MSwxLjM5MDcgMTIuNzgzMTMsMi44MDM4IDEzLjkxNDgyLDMuMTQwMiAzLjU2MDUsMS4w'
    b'NTg0MSAxMC4xMTM1OCwwLjkxNTY4IDE0LjkxNzcsLTAuMzI0OTYgeiBNIDYyOS42NDk1OSw0'
    b'MTEuNzQyIGMgMy4yNDczNCwtMS45MzM4NiAtMy45Mzc4NiwtNi43MjQ2NyAtMTAuMDg1Niwt'
    b'Ni43MjQ2NyAtMi42NTI2OCwwIC03LjMwMTAzLC0xLjU2MTM5IC0xMC4zMjk2NCwtMy40Njk3'
    b'NCAtMy4wMjgzOSwtMS45MDgzNiAtNC44NzgxOSwtMi40ODY5MyAtNC4xMTAwOSwtMS4yODU3'
    b'NSAwLjg1ODQ0LDEuMzQyODcgLTEuNzQ3NzMsMy4wOTE2NCAtNi43NjY4Nyw0LjU0MDY4IC05'
    b'LjA4Mzc1LDIuNjIyNDkgLTEwLjU3NDI4LDUuNTkxNjUgLTMuNTMzNTQsNy4wMzkzMiAyLjU0'
    b'NjMsMC41MjM1OCA2LjQ4MTQ5LDEuMzc4MDUgOC43NDQ4NiwxLjg5ODgzIDUuMjAyNjgsMS4x'
    b'OTcxIDIzLjAwNTU4LC0wLjE2NzE0IDI2LjA4MDg4LC0xLjk5ODY3IHogTSAyMzAuMDMxOCw0'
    b'MDQuODQ4NjQgYyAxMC4zNTQ1MywtMi4xMzk4NCAxMy44MTc0OSwtNS4yMzE1OCAxNS41NDU4'
    b'OSwtMTMuODc5NzEgMC40MjYxNCwtMi4xMzI2MyAyLjcyODQxLC02LjUyMTA4IDUuMTE2MDYs'
    b'LTkuNzUyMTIgMy40MjU3MiwtNC42MzU3NCA0LjQzMjEsLTkuMjI2NTIgNC43NzI4NCwtMjEu'
    b'NzY5MDggMC4yMzc2NSwtOC43NDE5NSAtMC4xNjQ2MSwtMTUuODk0NDYgLTAuODkyNiwtMTUu'
    b'ODk0NDYgLTMuMzA5ODcsMCAtNi4zMjc3OCw2LjQzMTIyIC01LjM0NDIzLDExLjM4ODcgMS42'
    b'NzQ5LDguNDQyODggLTMuNDM1MTksMTcuNTIzOTIgLTEzLjIwNTc3LDIzLjQ2NzMgLTUuNTYx'
    b'MTIsMy4zODI2OCAtOS4wOTQwNCw0LjUyMjk1IC05LjU4ODA4LDMuMDk0NTkgLTEuNDU5ODgs'
    b'LTQuMjIwNDQgLTguNzE4NTMsLTIuMzk2OTQgLTEwLjcyNzU4LDIuNjk1IC0xLjA3NTUyLDIu'
    b'NzI2MjMgLTIuNDY0NDEsNC45NTY3OCAtMy4wODY0Miw0Ljk1Njc4IC0wLjYyMTgyLDAgLTIu'
    b'MDEwNzEsLTIuMjMwNTUgLTMuMDg2NDIsLTQuOTU2NzggLTEuOTQzNDIsLTQuOTI1NDYgLTEw'
    b'LjI4ODA3LC03LjIwOTk1IC0xMC4yODgwNywtMi44MTY1MiAwLDMuNTYzOTYgLTEzLjAxNDQy'
    b'LC0wLjEyNDcyIC0xNi45ODcyNiwtNC44MTQ4IC0xLjk4NzI1LC0yLjM0NTcyIC00LjY0Njcy'
    b'LC04LjA2OTM0IC01LjkxMDA5LC0xMi43MTkxNiAtMi4zODg2OSwtOC43OTIwMSAtMTQuMjI1'
    b'OTQsLTIxLjAzNzA0IC0xNS44MzYyMywtMTYuMzgxOTUgLTAuNDUzMjksMS4zMTAwOCAwLjIw'
    b'NjE3LDMuMzc0NTMgMS40NjUwMiw0LjU4NzcyIDEuMjU5MDYsMS4yMTMxOCAyLjI4OTEsNi40'
    b'NDQwOSAyLjI4OTEsMTEuNjI0MjYgMCw1LjU5Mzg2IDEuMDg2NDMsMTAuMDYyMzYgMi42NzUz'
    b'MSwxMS4wMDQwNSA0LjI5Nzc1LDIuNTQ3MTMgMTEuMjUyMjcsMTMuMTI1MDMgMTIuMDM1NDEs'
    b'MTguMzA1OTQgMS42NzY3NSwxMS4wOTE2NyAyNi42NzI2NSwxNi44OTg1MyA1MS4wNTMxMiwx'
    b'MS44NjAyNCB6IG0gLTM1LjQ1MTI3LC0zMi43MjI1MyBjIDIuOTg3NjYsLTIuODc4OTIgMy40'
    b'MjczNywtMi44Nzg5MiA1LjA5OTQsMCAyLjAxMjc1LDMuNDY1NzQgOC45MDM3MSw0LjI1NTkz'
    b'IDEwLjgzNjQyLDEuMjQyNiAwLjc2ODczLC0xLjE5ODMzIDMuMDg3MDMsLTEuMDg5OTIgNi4y'
    b'MzMzNCwwLjI5MTUgNS44MzMxMywyLjU2MTAxIDEyLjI2NTQ0LC0xLjA0MTMyIDEwLjM2Nzkx'
    b'LC01LjgwNjM3IC0wLjY3MTgxLC0xLjY4NjkxIC0wLjA4ODUsLTIuNDkzNTkgMS40NDk1OSwt'
    b'Mi4wMDU0MyAxLjQxNTIzLDAuNDQ5MTYgMi44NjkxNCwyLjc1NDI3IDMuMjMwODcsNS4xMjI0'
    b'NSAwLjgzNDU2LDUuNDY1MDUgMy4yMjA3Nyw1LjQ0ODk5IDguNTQ0NjUsLTAuMDU3NSAzLjE5'
    b'OTU5LC0zLjMwOTI3IDQuMTMyNzIsLTYuNzAxOTUgMy44NjI5NiwtMTQuMDQ0NzggLTAuMzEx'
    b'OTMsLTguNDk1NTUgMC4zNzg0MSwtMTAuMjU5NjQgNS42MzU0LC0xNC40MDExOSAzLjI5NDg2'
    b'LC0yLjU5NTgzIDcuMjMzNzUsLTQuNzUxNzkgOC43NTI2OCwtNC43OTEwMSA0LjE3MzA2LC0w'
    b'LjEwNzY2IDExLjczMjkzLC02LjYxMjQyIDExLjYwNDU0LC05Ljk4NDg1IC0wLjA2MTgsLTEu'
    b'NjM1NzQgMC42Mjg0LC02Ljk3OTM0IDEuNTM0NzcsLTExLjg3NDcgMS4wMzUxOSwtNS41OTAz'
    b'NCAwLjgwMTQ0LC0xMS4xMjA4NSAtMC42Mjg1OSwtMTQuODcwMzQgLTQuMTcxNDEsLTEwLjkz'
    b'Nzg1IC00LjQxMzgsLTE4LjMyMzE0IC0wLjc3NzE3LC0yMy42NzEzMSAyLjY2Mjc2LC0zLjkx'
    b'NTg2IDMuMjY4NzMsLTguMjAwNDIgMi41OTczMywtMTguMzYwOTMgLTAuNTE4NTIsLTcuODQ4'
    b'NDIgLTEuODgwMDUsLTEzLjU3NTc0IC0zLjMzODY4LC0xNC4wNDQyMSAtMS4zNTQ1MywtMC40'
    b'MzUxMSAtMS45Mzk1MiwtMS42MDcxMSAtMS4yOTk4LC0yLjYwNDQ2IDAuNjM5NzIsLTAuOTk3'
    b'MyAwLjEyNzU3LC0xLjgxMzMyIC0xLjEzNzQ1LC0xLjgxMzMyIC0xLjI2NTIzLDAgLTEuNzAw'
    b'NjIsLTAuOTM1MjEgLTAuOTY3NSwtMi4wNzgyNCAxLjYxNjY3LC0yLjUyMDUgLTEyLjQ4OTMs'
    b'LTE1Ljc2NjE3IC0xNi43OTAxMywtMTUuNzY2MTcgLTEuNjgzNzQsMCAtMi41Njk1NCwtMC43'
    b'NjY2NyAtMS45Njg1MiwtMS43MDM3MiAxLjMwMTY1LC0yLjAyOTM4IC0xNS4wMzQxNywtOC41'
    b'NzQzNiAtMTcuNTk0NjYsLTcuMDQ5NDIgLTAuOTc1NTEsMC41ODA5OCAtMS43NzM4NywtMC4z'
    b'MzQ2NiAtMS43NzM4NywtMi4wMzQ3NSAwLC0xLjcwMDEgLTEuMTU3NDEsLTMuMjA2MjYgLTIu'
    b'NTcyMDIsLTMuMzQ3MDQgLTE2LjQ2OTk3LC0xLjYzOTA1IC0yMi44MTg3NCwtMS4xODc2MiAt'
    b'MzUuNDkzODYsMi41MjM3NiAtNy45MjE4MSwyLjMxOTU5IC0xNi4wMTExMiw0Ljk4ODggLTE3'
    b'Ljk3NjE0LDUuOTMxNTkgLTEuOTY1MDMsMC45NDI3OSAtNC40NDcxMiwxLjcxNDE2IC01LjUx'
    b'NTg1LDEuNzE0MTYgLTMuMzUyMjcsMCAtMTUuNDgzNTUsOC41NTEwOSAtMjAuNjM1ODIsMTQu'
    b'NTQ1ODMgLTguNzU3MjEsMTAuMTg5MTcgLTE1LjAwMzkyLDM1LjI0MTE1IC04LjcxNzA5LDM0'
    b'Ljk1ODkxIDMuODgyOTMsLTAuMTc0MjggOC42MDYxOSwtNS45MTY0OSA4LjYwNjE5LC0xMC40'
    b'NjI2MSAwLC02LjM3NTg3IDcuMzU5MDUsLTE0LjE4MzM3IDE1LjA5MzIyLC0xNi4wMTI3NiAz'
    b'LjIwODQ0LC0wLjc1ODk0IDcuNzcwNzksLTMuMTE4ODQgMTAuMTM4MjgsLTUuMjQ0MjEgNC44'
    b'ODU2LC00LjM4NTkgNi41Njk1NSwtMy44OTUzMSA0Ljc5NDg2LDEuMzk2ODYgLTEuMzc3OTks'
    b'NC4xMDk1OSAtMTAuNTE4MTIsOC44MTc0MyAtMTQuMzYwMzEsNy4zOTY2OSAtMS40MDMwOCwt'
    b'MC41MTg4MiAtNC4yNjk5NiwwLjg4Njc5IC02LjM3MDU4LDMuMTIzNTggLTMuNzIzNjYsMy45'
    b'NjQ2MyAtMy43MjAzNiw0LjEzOTI2IDAuMTI5NjQsNi45NDYzNSAzLjU1NTU2LDIuNTkyMzkg'
    b'My41OTQyNCwyLjg4NTc2IDAuMzg3NjUsMi45NDI1NCAtMi4wNjMzNywwLjAzNjUgLTQuMTEw'
    b'NSwyLjE3MDMgLTQuODY2MjUsNS4wNzIxNCAtMC43MTc3LDIuNzU0OTkgLTMuMDUwMjIsNS45'
    b'MDkxNSAtNS4xODMzNCw3LjAwOTI0IC00LjMzMjExLDIuMjM0MDQgLTUuNDIwNTgsMTMuNDYw'
    b'NjYgLTEuNjU2OCwxNy4wODc0MiAxLjU5MDU0LDEuNTMyNjggMC45NzMwNSw0Ljc4MjIyIC0y'
    b'LjE3Mzg2LDExLjQzODcgLTMuODg0MTYsOC4yMTU5OCAtNC4xMzQ1OCwxMC40OTMwNCAtMi4x'
    b'NTE0NSwxOS41Njk4MiAzLjAzNzA0LDEzLjg5OTgyIDcuMTI0MDgsMTguMjE2OSAyMS42NTA4'
    b'NCwyMi44NjkzMyAxMi43MDQ1NCw0LjA2ODc2IDE5LjY3MDgsMTEuMjAxMzUgMTkuMDM2NjQs'
    b'MTkuNDkwOTEgLTAuMzE3MDgsNC4xNDU3NiA2LjE5OTgsMTQuNTA1NDggOS4xMjQ5MSwxNC41'
    b'MDU0OCAxLjA4MjMsMCAzLjQzOTEsLTEuNDE3NzQgNS4yMzc0NCwtMy4xNTA1NSB6IG0gLTEu'
    b'NTA1OTcsLTMxLjM4MjUyIGMgMCwtNC42NTEgNy41MjY3NiwtMjQuMzk5MjcgMTAuNTg3NDYs'
    b'LTI3Ljc3ODQ2IDIuMTcyMjMsLTIuMzk4MzUgMjAuMTcxNjIsMTYuNTUyMjcgMjAuMjMxNTEs'
    b'MjEuMzAwNjEgMC4wMjQ2LDEuOTgwMDUgLTAuOTU5NjgsNS40MDk3NCAtMi4xODgyOCw3LjYy'
    b'MTU0IC0yLjIyMDU4LDMuOTk4MzkgLTIuMjYxOTMsMy45OTU2IC03LjIxNzMsLTAuNDkwMTMg'
    b'bCAtNC45ODM3NCwtNC41MTE1OCAtOC4yMTQ4Myw0LjIyNTIgLTguMjE0ODIsNC4yMjUyIDAs'
    b'LTQuNTkyMzggeiBtIDQyLjE4MTExLC0yOC45MTM3IGMgLTAuNjk5MzksLTEuMDkwNSAtMy43'
    b'OTUwNywtMS45ODI3MiAtNi44Nzk0MywtMS45ODI3MiAtMy45NDc1MywwIC02LjU4MjcyLC0x'
    b'LjYxNDI4IC04LjkwMDg0LC01LjQ1MjQ1IC03LjgwNzgxLC0xMi45Mjc5NCA4LjYyMDc5LC0y'
    b'Ny42OTM3IDI2LjEwNzI0LC0yMy40NjQ2NCAxMy40MDA0MSwzLjI0MDg2IDE3Ljk2NzksMTgu'
    b'Njg1NTQgOC4yODUxOCwyOC4wMTU4NiAtNS4xNzU1MSw0Ljk4NzE3IC0xNi4xNzAzNyw2LjY5'
    b'MDgxIC0xOC42MTIxNSwyLjg4Mzk1IHogbSAtNjYuODMwMSwtNC4xOTU1MSBjIC05LjAwMDgy'
    b'LC0zLjQ2MDQ1IC0xMi4zODgwNywtNy44NDMyMSAtMTIuMzg4MDcsLTE2LjAyOTAyIDAsLTEx'
    b'LjcxMTU5IDYuOTUzNzEsLTE3LjQ0NyAyMS4xNTI5LC0xNy40NDcgMTIuMTg3MDUsMCAxOC4y'
    b'OTUyOCw0LjE2NTAxIDIwLjczNjIzLDE0LjEzOTY1IDEuMzc0MDgsNS42MTQ3OSAtMi4wNTMz'
    b'LDE3LjY1MjggLTUuNzAzNSwyMC4wMzE3NyAtMy4xNjE5NCwyLjA2MDkgLTE3LjczNjAyLDEu'
    b'NjM1MDIgLTIzLjc5NzU2LC0wLjY5NTQgeiBtIDMyNS4xNzcwMSwtMjYuMDQwODUgYyA1Ljgz'
    b'NzY1LC02Ljc0MzAyIDQuOTQ2NzEsLTExLjk1MjY3IC0xLjM1MTQ1LC03LjkwMDQ4IC0yLjI0'
    b'MjU5LDEuNDQyOTEgLTYuOTk1MjcsOS4wNzk0MiAtNi45OTUyNywxMS4yMzk4OSAwLDIuNjc4'
    b'MzYgNC43OTg5OCwwLjc1ODMyIDguMzQ2NzIsLTMuMzM5NDEgeiBtIDQzLjEzMTcyLC0yNS43'
    b'NzUyNSA0LjMxMzM3LC00LjQ2MTA5IC00Ljc0NzczLC0xLjI4OTQxIGMgLTkuMjUyMDcsLTIu'
    b'NTEyNjkgLTE1LjAzODUsLTEuNzQwNTggLTE3LjY5NjkzLDIuMzYxNDIgLTMuNTYyOTcsNS40'
    b'OTc0NiAtMS41MTk3Niw3Ljg1MDE4IDYuODE3NjksNy44NTAxOCA0LjYwOTQ4LDAgOC40NzMw'
    b'NiwtMS41MjM0NyAxMS4zMTM2LC00LjQ2MTEgeiBNIDI0MC4zNDIxLDE2OS4xNTA5NSBjIDMu'
    b'NDU4NDMsLTIuMTA3NDcgMy43NTUxNCwtMS45NjU5NSAtMTIuNzE4OTUsLTYuMDY1ODQgLTEz'
    b'LjA5MzAxLC0zLjI1ODUgLTI0LjA4NDc5LC0wLjMxNjM5IC0yNC4yMjkwMyw2LjQ4NTIyIC0w'
    b'LjA0NTIsMi4xNTE1MiAzMy4zNTEyNiwxLjc3MjQ2IDM2Ljk0Nzk4LC0wLjQxOTM4IHoiCiAg'
    b'ICAgICBpZD0icGF0aDMzNDQiCiAgICAgICBpbmtzY2FwZTpjb25uZWN0b3ItY3VydmF0dXJl'
    b'PSIwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'Flags')

Flags = b64_Flags
index.append("Flags")
index.append("Flags")
index.append("None")
catalog["Flags"] = Flags
catalog["Flags"] = Flags
catalog["None"] = Flags
country["None"] = ('Flags', 'Flags', 0)
lookup["Flags"] = ('Flags', 'Flags', 'None', 0)
lookup["Flags"] = ('Flags', 'Flags', 'None', 0)
lookup["None"] = ('Flags', 'Flags', 'None', 0)
#----------------------------------------------------------------------
b64_FlagsLoading = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjxzdmcgaGVpZ2h0PSIxMDAiIHdpZHRoPSI1MDAiPgogICAgPHJlY3Qgd2lkdGg9IjEwMCUi'
    b'IGhlaWdodD0iMTAwJSIgZmlsbD0iZ3JlZW4iIC8+CiAgICA8cmVjdCB4PSI1IiB5PSI1IiB3'
    b'aWR0aD0iOTglIiBoZWlnaHQ9IjkwJSIgZmlsbD0iZ29sZCIgLz4KICAgIDx0ZXh0IHg9IjIw'
    b'IiB5PSI4MCIgZm9udC1zaXplPSIzZW0iIHN0eWxlPSJmaWxsOnJlZDsiPkxvYWRpbmcgRmxh'
    b'Z3MuLi4uPC90ZXh0Pgo8L3N2Zz4K', 'FlagsLoading')

FlagsLoading = b64_FlagsLoading
index.append("FlagsLoading")
index.append("FlagsLoading")
index.append("None")
catalog["FlagsLoading"] = FlagsLoading
catalog["FlagsLoading"] = FlagsLoading
catalog["None"] = FlagsLoading
country["None"] = ('FlagsLoading', 'FlagsLoading', 0)
lookup["FlagsLoading"] = ('FlagsLoading', 'FlagsLoading', 'None', 0)
lookup["FlagsLoading"] = ('FlagsLoading', 'FlagsLoading', 'None', 0)
lookup["None"] = ('FlagsLoading', 'FlagsLoading', 'None', 0)
#----------------------------------------------------------------------
b64_AD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1hZCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNkMDEwM2EiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZWRmMDAiIGQ9Ik0wIDBoNDM1LjJ2NDgwSDB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzAwMThhOCIgZD0iTTAgMGgyMDQuOHY0ODBIMHoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjYzdiMzdmIiBkPSJNMzAwLjQgMTM2LjZjNy43IDAgMTAuOSA2LjYgMTguNiA2'
    b'LjYgNC43IDAgNy41LTEuNSAxMS43LTMuOSAyLjktMS42IDQuNy0yLjUgOC0yLjUgMy40IDAg'
    b'NS41IDEgNy4zIDQgMSAxLjYgMS44IDQuOSAxLjMgNi43YTQwIDQwIDAgMCAxLTIuNyA4LjNj'
    b'LS43IDEuNi0xLjMgMi41LTEuMyA0LjIgMCA0LjEgNS42IDUuNSA5LjQgNS42LjggMCA3Ljcg'
    b'MCAxMi00LjItMi4zLS4xLTQuOS0yLTQuOS00LjMgMC0yLjYgMS44LTQuMyA0LjMtNS4xLjUt'
    b'LjEgMS4zLjMgMS43IDAgLjctLjMuNC0xIDEtMS40IDEuMi0xIDItMS42IDMuNi0xLjYgMSAw'
    b'IDEuNi4xIDIuNS43LjQuNC42LjggMSAuOCAxLjIgMCAxLjgtLjggMy0uOGE1IDUgMCAwIDEg'
    b'Mi4zLjZjLjYuMy42IDEuNSAxLjQgMS41LjQgMCAyLjQtLjkgMy41LS45IDIuMiAwIDMuNC44'
    b'IDQuOCAyLjUuNC41LjYgMS40IDEgMS40YTYuMiA2LjIgMCAwIDEgNC44IDNjLjMuNC43IDEu'
    b'NCAxLjEgMS41LjYuMyAxIC4yIDEuNy43YTYgNiAwIDAgMSAyLjggNC44YzAgLjctLjMgMS42'
    b'LS41IDIuMi0xLjggNi41LTYuMyA4LjYtMTAuOCAxNC4zLTIgMi40LTMuNSA0LjMtMy41IDcu'
    b'NCAwIC43IDEgMi4xIDEuMyAyLjctLjItMS40LjUtMy4yIDItMy4zYTQgNCAwIDAgMSA0IDMu'
    b'NiA0LjUgNC41IDAgMCAxLS4zIDEuOCA5LjYgOS42IDAgMCAxIDQtMS40aDEuOWMzLjMgMCA3'
    b'IDEuOSA5LjMgMy44YTIxIDIxIDAgMCAxIDcuMyAxNi44Yy0uOCA1LjItLjMgMTQuOC0xMy44'
    b'IDE4LjYgMi41IDEgNC4yIDMgNC4yIDUuMmE0LjUgNC41IDAgMCAxLTQuNCA0LjcgNC40IDQu'
    b'NCAwIDAgMS0zLjUtMS40Yy0yLjggMi44LTMuMyA1LjctMy4zIDkuNyAwIDIuNC40IDMuOCAx'
    b'LjQgNiAxIDIuMiAxLjggMy41IDMuNyA1LjEgMS0xLjUgMi4xLTIuNiA0LTIuNiAxLjcgMCAz'
    b'LjIuNiAzLjkgMi4yLjIuNSAwIC45LjMgMS40LjMuNi44LjcgMS4xIDEuMy41IDEgMCAxLjgu'
    b'NSAyLjcuMy43LjkuOCAxLjIgMS40LjQgMSAuNSAxLjYuNSAyLjcgMCAzLTIuNyA1LjItNS43'
    b'IDUuMi0xIDAtMS40LS40LTIuMy0uMyAxLjcgMS43IDMgMi41IDQuMyA0LjVhMTcuNyAxNy43'
    b'IDAgMCAxIDMgMTAuMyAyMiAyMiAwIDAgMS0yLjggMTEuMiAyMCAyMCAwIDAgMS03IDguNSAz'
    b'NSAzNSAwIDAgMS0xNiA2LjQgNzQuNCA3NC40IDAgMCAxLTExIDEuNGwtMTQuMS44Yy03LjIu'
    b'NC0xMi4yIDEuNS0xNy4zIDYuNiAyLjQgMS43IDQgMy41IDQgNi40IDAgMy0xLjggNS4zLTQu'
    b'NyA2LjItLjcuMi0xLjIgMC0xLjkuNHMtLjcgMS4zLTEuNCAxLjdhNi4yIDYuMiAwIDAgMS0z'
    b'LjggMSA4IDggMCAwIDEtNi40LTIuNWMtMi4yIDEuOC0zIDMuNC01LjUgNC45LS44LjQtMS4y'
    b'IDEtMi4xIDEtMS41IDAtMi4yLTEtMy40LTEuOGEyMyAyMyAwIDAgMS00LjQtNGMtMi4zIDEu'
    b'My0zLjYgMi40LTYuMyAyLjRhNyA3IDAgMCAxLTQtMWMtLjYtLjUtLjgtMS4yLTEuNS0xLjYt'
    b'LjctLjUtMS4zLS4zLTIuMS0uNy0zLTEuMy01LTMuNS01LTYuOCAwLTIuOSAxLjgtNC43IDQu'
    b'NC02LTUtNS0xMC01LjgtMTctNi4ybC0xNC0uOGMtNC40LS4zLTYuOC0uNy0xMS0xLjQtMy4z'
    b'LS41LTUuMi0uNy04LjItMi4xLTEwLjItNC44LTE2LjgtMTEuMy0xOC0yMi41LS4yLTEtLjIt'
    b'MS41LS4yLTIuNSAwLTUuOCAyLjMtOS40IDYuNC0xMy41LTEtLjMtMS43IDAtMi44LS4zLTIu'
    b'NS0xLTQuNC0yLjctNC40LTUuNSAwLTEgMC0xLjcuNS0yLjYuNC0uNiAxLS43IDEuMi0xLjQu'
    b'Mi0xIDAtMS42LjQtMi41LjMtLjUuOC0uNiAxLTEuMiAxLTEuOSAyLTMuNCA0LjEtMy40IDEu'
    b'OCAwIDMgMSAzLjggMi41IDEuOC0uOCAyLjItMi4xIDMuMi0zLjdhMTUuNSAxNS41IDAgMCAw'
    b'IDEuNC0xMy4zYy0uNC0xLjUtLjYtMi41LTEuOC0zLjctMSAxLTIgMS40LTMuNCAxLjQtMi45'
    b'IDAtNS0yLjUtNS01LjNhNC44IDQuOCAwIDAgMSAzLTQuNmMtMS42LTEuNC0zLTEuNS00Ljct'
    b'Mi42LTIuNi0xLjYtMy41LTMuNC01LjItNi0xLjItMS42LTEuNS0yLjgtMi00LjdhMTkgMTkg'
    b'MCAwIDEtMS03LjhjLjYtNSAxLjUtOCA0LjYtMTEuOSAxLjgtMi4zIDMtMy43IDUuOC00Ljkg'
    b'Mi4zLTEgMy43LTEuNyA2LjItMS43bDIgLjFhNi45IDYuOSAwIDAgMSAyLjguOGMuNC4yIDEu'
    b'MS45IDEuMS40cy0uMy0uOC0uMy0xLjNjMC0yIDEuNS00IDMuNi00IDEuNSAwIDIuMSAxLjQg'
    b'Mi45IDIuNy40LS44LjctMS40LjctMi4zIDAtMy40LTEuOS01LjItNC03LjktNC43LTUuOC0x'
    b'MC41LTguNS0xMC41LTE2IDAtMi4yIDEtMy43IDMtNC45LjUtLjMgMS4zIDAgMS44LS4zcy40'
    b'LTEgLjctMS40Yy41LS43IDEtMSAxLjYtMS42IDEtMSAyLS42IDMuMS0xLjUuNi0uNC44LTEg'
    b'MS4yLTEuNCAxLjMtMS42IDIuNS0yLjQgNC42LTIuNCAxIDAgMS42IDAgMi41LjRsMSAuNWMu'
    b'My0uMi44LS44IDEuNS0xLjFhNCA0IDAgMCAxIDIuMi0uNmMxLjEgMCAxLjguNiAzIC42LjMg'
    b'MCAuNC0uNC44LS42IDEtLjcgMS41LTEgMi43LTEgMS4yIDAgMS44LjMgMi44IDEgMSAuNSAx'
    b'IDEuMyAyIDEuOC41LjMgMSAuMiAxLjUuNCAyLjYuOSA0LjUgMi42IDQuNSA1LjMgMCAxLjUt'
    b'LjMgMi41LTEuNCAzLjUtLjkuNy0xLjcuNi0yLjggMWExNiAxNiAwIDAgMCAxMS4zIDMuNWM0'
    b'LjIgMCA5LjMtMS43IDkuMy01LjkgMC0yLTEtMy0xLjgtNC44YTE4LjggMTguOCAwIDAgMS0y'
    b'LjEtOC41YzAtMi44LjMtNC41IDEuOS02LjcgMS42LTIuMyAzLjYtMi45IDYuNS0yLjl6Ii8+'
    b'CiAgPGcgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNzAzZDI5Ij4KICAgIDxwYXRoIHN0cm9rZS1s'
    b'aW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0yNzIuNCAxNTlhMy42IDMu'
    b'NiAwIDAgMCAyLjQgMi40Yy44LjMgMi43LjIgMy44LTEuNCAxLTEuMiAxLTIuOC42LTRhNC43'
    b'IDQuNyAwIDAgMC0xLjctMi4ybC01LjEgNS4yeiIvPgogICAgPHBhdGggc3Ryb2tlLWxpbmVj'
    b'YXA9InJvdW5kIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNNDAxIDIzNi4xYy0xLjItMi45LTQu'
    b'My0xLjYtNC40IDAtLjUgMy43IDIuNyA0LjggNSA0LjJhNCA0IDAgMCAwIDIuNS0yYy42LTEg'
    b'LjgtMi40LjQtMy43YTQuOSA0LjkgMCAwIDAtLjgtMS42IDUgNSAwIDAgMC0xLjMtMS4yYy0u'
    b'OS0uNi0xLjktLjYtMy40LS42LTUuNSAwLTEwLjQgNi41LTEyIDEzLjQtLjYgMi4yLTEuMyA3'
    b'LjMtLjMgMTJhMjIuNCAyMi40IDAgMCAwIDUuOSAxMS4zIDI1LjcgMjUuNyAwIDAgMCA5Ljkg'
    b'NS44IDcuOSA3LjkgMCAwIDAgNCAuMWMzLjItLjcgNC43LTMuOCAzLTctMS4zLTIuNS01LjMt'
    b'NC03LjItLjYtLjEuMy0uNC45LS40IDEuNSAwIC45LjQgMiAxIDIuNCAxLjUuOSAzLjguNiAz'
    b'LjctMiIvPgogICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuOCIgZD0iTTM4My44IDI3NGExMS4z'
    b'IDExLjMgMCAwIDEgNi42LTMuN2MzLS40IDUuNi41IDguMiAyYTE4LjUgMTguNSAwIDAgMSAx'
    b'MC44IDE3YzAgMy42LTEgNy41LTIgOS40LS44IDEuNy0zIDktMTUuMyAxNC03LjEgMy0xOCAz'
    b'LjYtMjUuNyA0LTEwLjQuMy0yMCAuNy0yNS41IDcuNiIvPgogICAgPGcgc3Ryb2tlLXdpZHRo'
    b'PSIuNyI+CiAgICAgIDxwYXRoIGQ9Ik0zODYuNCAyODUuN2MtLjMtMSAwLTIuMS44LTMuMyAx'
    b'LjItMS42IDMuNy0yLjEgNi0xYTcuNCA3LjQgMCAwIDEgMi41IDIuMmwxLjEgMS42Yy43IDEu'
    b'MSAxIDIgMSAyLjUgMi41IDctMS40IDE0LjUtNi41IDE3LjYtNCAyLjQtOC43IDMuNC0xNC40'
    b'IDQtMi41LjQtNCAuMy02LjUuNWgtOS42YTcwLjEgNzAuMSAwIDAgMC03LjIgMGMtMi45LjMt'
    b'NSAuNC03LjYuOC0xLjYuMi0zLjQuNS01LjQgMS0uNiAwLTEuMi4yLTEuOC40bC0xLjIuM2Mt'
    b'My42IDEuMS03IDIuNC05LjggNC4yLS44LjUtMS44IDEtMi41IDEuN2wtMS4zIDEuMmMtMiAy'
    b'LTMuOSA0LTQuNCA2Ljd2MS42YzAgMS44IDEuNCA0LjMgNS40IDVtNS41LTE3MGMuOCAxLjQg'
    b'MS4zIDIuMy44IDMuOS0uNiAxLjctMS44IDIuOC0zLjYgMi44LTQgMC02LjMtNC44LTQuNS03'
    b'LjggMy4yLTUuMyA5LjMtMi4zIDE1IC4zLS4zLTEuMy0uOC0xLjgtLjctMy41LjEtNC4yIDMu'
    b'Mi02IDQuNS0xMCAuNy0yLjMgMS00LjMtLjctNi0xLjUtMS4zLTMuMi0xLjMtNS4xLS42LTMu'
    b'OCAxLjUtOC41IDUuOS0xNi42IDYtOC4yLS4xLTEyLjgtNC41LTE2LjctNi0yLS43LTMuNi0u'
    b'Ny01LjEuNy0xLjcgMS42LTEuNCAzLjYtLjcgNiAxLjMgMy44IDQuNCA1LjcgNC41IDEwIDAg'
    b'MS42LS40IDItLjcgMy40IDUuNy0yLjYgMTItNS45IDE1LS4zIDEuNyAzLjItLjUgNy43LTQu'
    b'NSA3LjctMS44IDAtMy0xLTMuNi0yLjctLjQtMS41IDAtMi44LjgtNCIvPgogICAgICA8cGF0'
    b'aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0zMTQuNiAxNTkuOWE1LjMgNS4zIDAgMCAx'
    b'IDIuNCA1Yy0uMiAyLjUtLjggMy4xLTIuOCA0LjVtMi40LTMuOGMtLjEgMS41LS43IDIuNS0y'
    b'LjMgMy4xIi8+CiAgICA8L2c+CiAgICA8cGF0aCBmaWxsPSIjYzdiMzdmIiBzdHJva2U9Im5v'
    b'bmUiIGQ9Im0yNzYuNyAxNTMuMy43LjUuOC44LjUgMSAuMi44djEuOWwtLjIuOC0uNS42LS42'
    b'LjYtLjkuNS0xIC4yLTEgLjItMS0uNS0uOS0uNi0uNS0uOC0uNC0xdi0uNGw0LjgtNC42eiIv'
    b'PgogICAgPHBhdGggc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9Ii43IiBk'
    b'PSJNMjc1LjIgMTU3LjJjLS4zLTEuNy0yLjItMi0zLTEtMS4xIDEuNS0uMyA0IDIgNC43YTQg'
    b'NCAwIDAgMCAzLjktMS40YzEtMS4zLjktMi44LjUtNGE0LjUgNC41IDAgMCAwLTEuNy0yLjJj'
    b'LTIuNy0yLTcuMS0xLjYtOC42IDItMS44IDQuNCAyLjIgNy44IDYgMTAuMyA0LjYgMy4yIDEw'
    b'IDMuOCAxNCAzLjggOS4yLS4xIDE2LjItNC41IDIwLjctNyAxLS42IDIuMS0uNSAyLjcuMmEy'
    b'IDIgMCAwIDEtLjMgMi43Ii8+CiAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii43IiBkPSJtMjQ4'
    b'IDI4MS4yLTIgLjctMiAxLjYtMSAxLjMtMS4xIDItLjUgMS41LS40IDEuOC0uMiAxLjRtMTkt'
    b'MTAuMS0uMSAxLjgtLjMgMS4yLTEgMi4yLTEuMyAxLjgtMS41IDEuMi0xLjEuNS0xLjYuNCIv'
    b'PgogICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuOCIgZD0iTTMxOS43IDMyOS4xYy0uMyAxLjct'
    b'MS45IDMuNi01LjMgNC4ybC0uNi4yIi8+CiAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii45IiBk'
    b'PSJNNDA0LjIgMjc2LjJhMTguMyAxOC4zIDAgMCAxIDUuNiAxMy41YzAgMy42LTEgNy41LTIg'
    b'OS40LS44IDEuNy0zIDktMTUuMyAxNGE4NSA4NSAwIDAgMS0yNS42IDRjLTEwLjMuMy0xOS44'
    b'LjctMjUuNCA3LjMiLz4KICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjYiIGQ9Ik0zODcuNSAy'
    b'ODIuOWMuOC0xIDMuNS0yLjQgNS44LTEuMWE2LjIgNi4yIDAgMCAxIDIuMyAyIi8+CiAgICA8'
    b'cGF0aCBzdHJva2Utd2lkdGg9Ii45IiBkPSJtNDAxLjYgMjczLjggMS40LjVhNyA3IDAgMCAw'
    b'IDQgMGMyLjgtLjggNC42LTMuNCAzLjItNi45YTYgNiAwIDAgMC0xLjgtMi4xIi8+CiAgICA8'
    b'cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0yNDAu'
    b'MyAxOTkuOGMtMiAxLjEtMy4zIDEuNC00LjggMy4xYTI4LjEgMjguMSAwIDAgMC0yLjYgNi44'
    b'bTQ2LTUxLjdjMCAxLjgtMS4yIDIuOC0zIDMuMiIvPgogICAgPHBhdGggc3Ryb2tlLXdpZHRo'
    b'PSIuNiIgZD0iTTM5Ny4xIDE5MmExOSAxOSAwIDAgMSAxOC42IDE5LjhjMCAxNi05LjkgMTgu'
    b'NS0xMy44IDE5LjYiLz4KICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0zOTguNCAx'
    b'OTJjOC4xLS4zIDE2LjUgNS43IDE2LjkgMjAuNy4zIDExLjctOCAxNy0xMiAxOCIvPgogICAg'
    b'PHBhdGggc3Ryb2tlLXdpZHRoPSIuNiIgZD0ibTM5My44IDI0OC40LjEtMS42LjYtMi41Ljct'
    b'MiAuOS0xLjYgMS0xLjNtNy44LTMuNHYxLjVsLS41IDEtLjcgMS4xLS44LjYtMS4yLjVoLTEu'
    b'MWwtLjgtLjFtLTE0LjMtNTIuOC4zLTEuNy44LTEuNiAxLTEuNSAxLjYtMi4yIDEuNC0xLjQg'
    b'Mi0yLjIgMi0xLjkgMS4xLTEuMyAxLjUtMS45IDEuNC0yIC44LTEuNy41LTIuMi4xLTIuNy0u'
    b'Mi0uOG0tMTIuMyAxMjguMiAxLjYtLjQgMS4yLS42LjctLjcuNS0uOC4zLTEuMnYtLjltLTE1'
    b'OC4yLTEyLjFoMi43bDEuNi0uNm01LTM2LjUtLjIgMS40LS40LjYtLjQuNi0uNy41LS43LjMt'
    b'MSAuMWgtLjZtOS45LTE1LjUtLjMgMi4xLS41IDEtLjggMS4yLTEuMi45LTEuMi42LTIuMy41'
    b'bTE1LjMtMzkuNy0uNSAxLjMtLjUgMS0uOCAxLTEgMS0xLjIuNS0xLjEuMy0uNi0uMW0uMy02'
    b'LjJ2MSIvPgogICAgPGcgc3Ryb2tlLXdpZHRoPSIuNiI+CiAgICAgIDxwYXRoIHN0cm9rZS1s'
    b'aW5lY2FwPSJyb3VuZCIgZD0iTTI1NC4zIDIyNGE2LjkgNi45IDAgMCAxLTIuMSAxLjRtMTUw'
    b'LjUgNDQuOC41LjJjMS40LjggNC4yLS4yIDMuNC0yLjQiLz4KICAgICAgPHBhdGggZD0iTTM5'
    b'Ny44IDIzOS42YzEgMS4zIDIuOSAxLjcgNC40IDEuM2E0IDQgMCAwIDAgMi41LTJjLjYtMSAu'
    b'OC0yLjQuNC0zLjdhNC45IDQuOSAwIDAgMC0uOS0xLjYgNi44IDYuOCAwIDAgMC0xLjMtMS41'
    b'bC0uNC0uMm02LjQgMzRhNCA0IDAgMCAwIC4xLS43IDQgNCAwIDAgMC0xLjMtM2wtLjgtLjht'
    b'LjQuNWMwLTEuOC0xLjUtMy4yLTMuNC0zLjVtLTQuMiAyLjgtMS4zLTFhMTUuNyAxNS43IDAg'
    b'MCAxLTQuMy0xMC43YzAtNC4yIDEuNi04LjQgMy42LTEwTTM0MS4yIDMyNGwxLjgtMS42IDEu'
    b'Mi0xIDIuMy0xLjQgMi4yLTEgMS42LS41IDMtLjYgMy42LS42bS0yOS41IDE5LjRhMTcgMTcg'
    b'MCAwIDEtNy42IDYuMSAxNy43IDE3LjcgMCAwIDEtNy42LTYuMSIvPgogICAgICA8cGF0aCBz'
    b'dHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0zMTQuNCAzMzIuNmExMCAxMCAwIDAgMS0yLjIg'
    b'NC4yIi8+CiAgICAgIDxwYXRoIGQ9Im0zMTQuNyAzMzAuNS0uNCAyLjJNMzEyIDMzN2wtMSAx'
    b'LTEuNy45LTIgLjZtLTUuNi0xNzcuOGMuMy0uOC41LTEuNC41LTIuNi0uMS00LjItMy4yLTYu'
    b'MS00LjUtMTAtLjctMi4zLTEtNC4zLjctNiAxLjQtMS40IDMuMi0xLjQgNS0uNiA0IDEuNSA4'
    b'LjYgNS44IDE2LjcgNi04LjEtLjItMTIuOC00LjUtMTYuNi02LTItLjgtMy44LTEtNS4zLjUt'
    b'MS43IDEuNi0xLjIgMy44LS41IDYuMSAxLjMgMy45IDQuMiA1LjggNC4zIDEwIDAgMS4yLS4z'
    b'IDEuOC0uNSAyLjZNMzIwIDE0OGM4LS40IDE0LjktNS44IDE3LjEtNi4zIDItLjQgMy0uMiA0'
    b'LjUgMS4xLTEuNC0xLjMtMy0xLjItNS0uNS0zLjggMS41LTguNCA1LjgtMTYuNiA2bTc5LjYg'
    b'MTEyLjlhMTUuNSAxNS41IDAgMCAxLTYuMi0xMi40YzAtNC4xIDEuNy04LjQgMy42LTEwbS03'
    b'MCA5Ny42Yy0xLjMgMi00LjMgNS03LjYgNi4yYTE3LjcgMTcuNyAwIDAgMS03LjYtNi4yIi8+'
    b'CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0ibTMwNi43IDE2My43IDIu'
    b'My0xLjNjMS0uNiAyLjMtLjUgMi45LjIuNi43LjcgMi0uMiAyLjgiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTTI5NC43IDE2OS4zYzUuNS0xLjIgMTAtMy42IDEzLjQtNS41TTM0MC4zIDMyOGMuNS4z'
    b'LjggMSAuOCAxIC4xLjIuMy41LjMuOC4zIDEuNS0uNyAyLjQtMiAyLjYtMS43LjItMy0uOC0z'
    b'LjUtMk0yOTQuNCAxNjljNS41LTEuMSAxMC0zLjYgMTMuNC01LjVtOTcuNiAxMDYuOWMtMSAu'
    b'NC0xLjYuMy0zLS4ybC0xLjgtMWEyMC43IDIwLjcgMCAwIDEtOC40LTkgMTguOCAxOC44IDAg'
    b'MCAxLTEuNy00LjYgMTIgMTIgMCAwIDEtLjUtMy4zIDI1LjYgMjUuNiAwIDAgMSA0LjctMTUu'
    b'M2MxLjEtMS42IDIuMS0yLjUgNC4yLTIuNm0tMTQzLjctMzkuM2E3LjEgNy4xIDAgMCAxIDIu'
    b'NyA1LjdjMCAzLjEtMi42IDguMi05IDEwYTguMyA4LjMgMCAwIDEtNi4zLS44Ii8+CiAgICAg'
    b'IDxwYXRoIGQ9Ik0yNTYuMyAyMDUuNmMxLjEuOCAxLjYgMS43IDEuNiAzLjMgMCAxLS43IDIu'
    b'NC0xLjkgMy43YTEyLjQgMTIuNCAwIDAgMS04LjggNGMtMiAwLTQtLjQtNi0xLjdhOSA5IDAg'
    b'MCAxLTMuOC01LjQiLz4KICAgICAgPHBhdGggZD0iTTI1Ni4yIDIxMi4zYzEuMyAxLjIgMS43'
    b'IDIuNyAxLjcgNC42IDAgMi43LTEuMSA0LjgtMy43IDctLjYuNi0xLjIgMS0yIDEuNW0xMjku'
    b'NS0yMi4xdjMuNW0tLjMtNC40djVtLjMtMTUuOHY2LjZtLS4zLTh2OC45bS0xLjkgODJhMTgu'
    b'NyAxOC43IDAgMCAxLTQuMiA1LjYgMTkuNiAxOS42IDAgMCAxLTUuOCA0LjEgMjQuNiAyNC42'
    b'IDAgMCAxLTYuNiAyLjIgMzMgMzMgMCAwIDEtNi44LjljLTIuNSAwLTMuOSAwLTYuNC0uMi0y'
    b'LjYtLjItNC0uNi02LjctLjgtMi4yLS4yLTMuNC0uNC01LjYtLjNhMjguMyAyOC4zIDAgMCAw'
    b'LTExIDEuOGMtMi42IDEtNS43IDMtNi4zIDMuOGEyMiAyMiAwIDAgMC02LjQtMy44IDIyIDIy'
    b'IDAgMCAwLTUuMS0xLjRjLTIuMy0uNC0zLjUtLjQtNS44LS40LTIuMiAwLTMuNC4xLTUuNi4z'
    b'LTIuNi4zLTQgLjYtNi43LjgtMi41LjItMy45LjMtNi40LjJhMzMgMzMgMCAwIDEtMTMuNC0z'
    b'IDE5LjUgMTkuNSAwIDAgMS02LjQtNC44bTQyLjEgNTMuNCAxLjgtLjJtMzAuMy0yLjQgMS44'
    b'LS4xIDEuNy0uNyAxLjItLjggMS43LTIgLjMtLjYuMy0xLjd2LS44bTQ3LTEzNi43Yy43LTIu'
    b'Ni0uMi01LjQtMi44LTUuM20tMTMyIDQ2LjVhOC4yIDguMiAwIDAgMS0zLjUgNC43bTMuNi00'
    b'Ni43YTYuNSA2LjUgMCAwIDEtMy42IDRjLTEuOS44LTQgMC01LjItLjgiLz4KICAgICAgPHBh'
    b'dGggc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBkPSJNMjQzLjggMjAyLjRjMS41LjggMy4xLS40'
    b'IDIuOC0yLjRhMi45IDIuOSAwIDAgMC0yLjUtMi4yIi8+CiAgICAgIDxwYXRoIGQ9Ik0yNTAu'
    b'MiAyODYuNmMuMy4zLjQuNy44LjguNy4yIDEuMi40IDEuOS0uNS44LTEuMS4zLTIuOC0uNS0z'
    b'LjlhNSA1IDAgMCAwLTUuOC0xYy0uOC41LTEuNyAxLTIuNiAyLjJsLTEuMSAxLjZjLS43IDEu'
    b'MS0xIDItMS4xIDIuNC0yIDUuOS40IDEyIDQuMSAxNS43Ii8+CiAgICAgIDxwYXRoIHN0cm9r'
    b'ZS1saW5lY2FwPSJyb3VuZCIgZD0ibTM0MC4yIDMyNy44LjcuOC4yLjljLjMgMS41LS43IDIu'
    b'NC0yIDIuNi0xLjYuMi0yLjgtLjgtMy4zLTIiLz4KICAgICAgPHBhdGggZD0iTTM4OS40IDE1'
    b'NC44YTcuNCA3LjQgMCAwIDEgNi4zIDdjMCA0LjQtMS41IDYtMy44IDkuMi0yLjUgMy40LTEw'
    b'LjcgOS42LTEwLjcgMTYuNyAwIDQuMyAxLjIgNyA0LjMgOC40IDIgMSA0LjMgMCA1LjQtMSAy'
    b'LjYtMi40IDEuNS02LjUtMS4yLTctMy4yLS42LTMuOSA0LjYtLjcgNC4zbTE3LjkgNjlhMy43'
    b'IDMuNyAwIDAgMC0zLjYtMyAzLjcgMy43IDAgMCAwLTMuNyAzLjdjMCAxIC40IDIgMSAyLjYi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTM4My45IDE5NS4xYTcuMSA3LjEgMCAwIDAtMi43IDUuN2Mw'
    b'IDMuMSAyLjYgOC4yIDkgMTAgMi40LjcgNC44LjYgNi4yLS4zbS0xNTYtMTAuM2E5LjQgOS40'
    b'IDAgMCAwLTQuOCAzLjUgMTYuOSAxNi45IDAgMCAwLTIuMiAxMi43IDE1LjggMTUuOCAwIDAg'
    b'MCAyLjMgNS42IDggOCAwIDAgMCAxIDEuMmwxLjIgMW02NCA5MmM0LjkgMi4xIDguNCAzLjcg'
    b'MTEuNCA4LjVhMTAgMTAgMCAwIDEgMS4yIDQuOWMwIDIuNy0xIDUuNy0zLjMgNy42YTguMyA4'
    b'LjMgMCAwIDEtNi43IDJjLTEuOS0uMi0zLjctMS42LTQtMi42TTI1NCAyMjQuMWMyLjcgMi4y'
    b'IDMuOSA0LjIgMy45IDcuNWE4LjQgOC40IDAgMCAxLTQgNy41Ii8+CiAgICAgIDxwYXRoIHN0'
    b'cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTI1MS41IDIzNi40YzQgNS4xIDYuMyA4LjEgNi40'
    b'IDE0LjEuMSA1LjctMS43IDkuNi01IDEzLjciLz4KICAgICAgPHBhdGggZD0iTTMyOS44IDE2'
    b'OS4zYTQuMSA0LjEgMCAwIDAgMS41LTIuMmMuNS0xLjUuNS0yLjgtLjItNCAxIDEuNCAxIDIu'
    b'NS43IDQtLjEgMS0uOCAxLjUtMS42IDIuM201MS41IDg2LjF2MTYuMmwtLjEgMi41YTM0LjQg'
    b'MzQuNCAwIDAgMS0uMyAxLjciLz4KICAgICAgPHBhdGggZD0iTTM4MS40IDI1NHYxOS45bC0u'
    b'NSAyLjZtLjUtNDN2MTQuNm0uMy0xMy40djExLjhtMC0yNi44djguOG0tLjMtOS45djExbS4z'
    b'LTE5djMuNW0tLjMtNC4ydjVtLTEuOCA2NS4yLS40LjdhMTguNyAxOC43IDAgMCAxLTQuMSA1'
    b'LjcgMTkuNiAxOS42IDAgMCAxLTUuOSA0IDI0LjYgMjQuNiAwIDAgMS02LjUgMi4yYy0yLjcu'
    b'Ni00LjIuOC02LjkuOS0yLjUgMC0zLjkgMC02LjMtLjItMi43LS4yLTQuMS0uNS02LjgtLjgt'
    b'Mi4yLS4yLTMuNC0uMy01LjYtLjMtMi4yIDAtMy41IDAtNS43LjRhMjIgMjIgMCAwIDAtNS4y'
    b'IDEuNGMtMi43IDEuMS01LjcgMy02LjQgMy44LS42LS44LTMuNy0yLjctNi4zLTMuOGEyMiAy'
    b'MiAwIDAgMC01LjItMS40Yy0yLjItLjQtMy41LS40LTUuOC0uNC0yLjIgMC0zLjQuMS01LjYu'
    b'My0yLjYuMy00IC42LTYuNy44LTIuNS4yLTMuOS4zLTYuMy4yYTMzIDMzIDAgMCAxLTEzLjUt'
    b'MyAxOS41IDE5LjUgMCAwIDEtNS44LTQuMSAyMiAyMiAwIDAgMS0yLjUtMi44bS0yLTMuMmEx'
    b'MC4xIDEwLjEgMCAwIDEtMi4zIDcuN2MtLjguOS0yLjYgMi42LTUgMi42LTMuNyAwLTQuOC0y'
    b'LjUtNS0zLjIiLz4KICAgICAgPHBhdGggZD0iTTI1NS42IDI3OC45Yy43LjcgMS4zIDEuNSAx'
    b'LjkgMi41IDEgMS44LjYgNC44LS4xIDYuMmE0LjQgNC40IDAgMCAxLS4zLjRtLTIwLjMgMThj'
    b'Mi4zIDIuNCA1LjcgNSAxMC45IDcuMSA3LjEgMyAxOC4xIDMuNiAyNS43IDQgMTAgLjMgMTku'
    b'My43IDI1IDdtMTcuMy00YTEyIDEyIDAgMCAxIDQgNS41bS03LjMgMTEuNWE4LjIgOC4yIDAg'
    b'MCAxLS43LjcgOC4zIDguMyAwIDAgMS02LjYgMmMtMi0uMi0zLjgtMS42LTQuMy0yLjZtLTUu'
    b'NC0yLjkuMy40YTcuNiA3LjYgMCAwIDAgNS4xIDIuNG0yNyAwYTE4IDE4IDAgMCAxLTcuNyA2'
    b'LjEgMTcuNyAxNy43IDAgMCAxLTcuNi02LjFsLS4zLS41bTE1LjYuNC43LjdhOC4zIDguMyAw'
    b'IDAgMCA2LjcgMiA1LjUgNS41IDAgMCAwIDQtMi41bC41LS43Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Im0zMzkgMzM2LjYtLjcgMS4yLTEuMSAxLTEuNy43aC0xLjYiLz4KICAgICAgPHBhdGggZD0i'
    b'TTM0MyAzMjUuM2E3LjcgNy43IDAgMCAxIDIuNCAyLjljLjMuNy40IDEuNS41IDIuM2E1Ljgg'
    b'NS44IDAgMCAxLTEuNSA0LjIgNy41IDcuNSAwIDAgMS01LjQgMi40IDUuNSA1LjUgMCAwIDEt'
    b'LjQgMG0uMi0uMmE2LjggNi44IDAgMCAxLTUuMi0yLjJtNjMuNy02Ny45YTIzLjggMjMuOCAw'
    b'IDAgMS00LjgtNi40IDE4LjggMTguOCAwIDAgMS0xLjctNC41IDEyIDEyIDAgMCAxLS41LTMu'
    b'MyAyNiAyNiAwIDAgMSA0LjYtMTUuM2MuNy0uOCAxLjQtMS44IDIuMS0yLjJtLTEuMy03NS45'
    b'YzIuNS4yIDQuOCAzIDQuOCA1LjcgMCAzLjgtMS4zIDUuNS00LjQgOS4zLTIuNiAzLjItMTAu'
    b'NiA5LTEwLjMgMTQuNSAwIDEgLjUgMiAxLjEgMi44bS0zLjIgMy41YTcgNyAwIDAgMCAyIDEu'
    b'NCA1IDUgMCAwIDAgNC4zLS4zTTM2OSAxNTNhNiA2IDAgMCAxIDIuMiAyLjZjMS44IDQuNS0y'
    b'LjIgNy45LTYgMTAuNGEyMS4zIDIxLjMgMCAwIDEtOC4zIDMuMyIvPgogICAgICA8cGF0aCBk'
    b'PSJNMzY0LjYgMTYxLjZhNC4yIDQuMiAwIDAgMS0zLjEtMS41IDMuNCAzLjQgMCAwIDEtLjct'
    b'MW0tMTUgNC45YTQuNiA0LjYgMCAwIDEtMS4yLTFjLTEtMS0xLjUtMi4zLS44LTQuNC42LTEu'
    b'OSAzLjctNy4yIDMuOC0xMC45LjItNS42LTItOS01LjMtMTAuMiIvPgogICAgICA8cGF0aCBz'
    b'dHJva2UtbGluZWNhcD0icm91bmQiIGQ9Im0zNDcuMyAxNDYuNS0uMSAyLS42IDIuMi0xIDMt'
    b'MSAxLjktLjggMS45LS40IDEuMy0uMiAxIC4xLjltMzggMTI2LjMuNi44Yy43IDEgMy4yIDMg'
    b'NS41IDMgMy43IDAgNC42LTIuNiA0LjctMy4yLjUtMi45LS41LTMuNi0yLTQuNSAwIDAtLjgt'
    b'LjQtMS45LS4yIi8+CiAgICAgIDxwYXRoIGQ9Ik0yMzcgMjc0LjRhNi45IDYuOSAwIDAgMS0z'
    b'LjcgMGMtMi45LS45LTUuMi0zLjYtNC03bTEzLjQtMzEuOGMuMy4zLjQuNy40IDEgLjQgMy44'
    b'LTIuOCA0LjgtNSA0LjJhNS42IDUuNiAwIDAgMS0zLTIuMyA0LjcgNC43IDAgMCAxLS43LTIu'
    b'M20yMi0yMy42Yy42LjUgMSAxIDEuMyAxLjdtLTEuMS04LjVjLjUuNC45LjkgMS4xIDEuMyIv'
    b'PgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0yNTcuOSAyMTAuNWE4'
    b'LjUgOC41IDAgMCAxLTEuNiAyLjQgMTIuNCAxMi40IDAgMCAxLTguOCA0Yy0yIDAtNC0uNC02'
    b'LTEuN2E5LjUgOS41IDAgMCAxLTQtNS42Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNTUuNCAxOTUu'
    b'M2E3LjggNy44IDAgMCAxIDIuNCAzLjQiLz4KICAgICAgPHBhdGggc3Ryb2tlLWxpbmVjYXA9'
    b'InJvdW5kIiBkPSJNMjU3LjggMjAzLjJjLS45IDMtMy41IDYuNi04LjYgNy45LTIuNC42LTUu'
    b'Ni0uMi02LjYtMSIvPgogICAgICA8cGF0aCBkPSJNMjQwIDIwMi42Yy4zIDIuNiAyIDQuNiA1'
    b'LjQgNC42IDQuNy4xIDcuNi02LjcgMy40LTExLjUiLz4KICAgICAgPHBhdGggc3Ryb2tlLWxp'
    b'bmVjYXA9InJvdW5kIiBkPSJNMjI5LjQgMjI1LjVjLjcuOSAxLjUgMS43IDIuNCAyLjRhMTYu'
    b'OCAxNi44IDAgMCAwIDYgMy4zbTUuMi41YzQuMi0uNSA2LjYtMy43IDYtNy4zLS4zLTIuOC0y'
    b'LjgtNS00LjYtNS4xIi8+CiAgICAgIDxwYXRoIGQ9Ik0yNDkuOCAxODguMWMxLjkgMCAzIDEu'
    b'NiAyLjkgMyIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0yNDku'
    b'NCAxNjNhMTEuNSAxMS41IDAgMCAwIDUgNS45bTE0NC4yIDMxYzEuNyAyLjMuNiA3LTQgN2E1'
    b'LjIgNS4yIDAgMCAxLTQuNS0yLjUiLz4KICAgICAgPHBhdGggZD0iTTM4MS43IDE2OS4xVjE4'
    b'NSIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0yNDMuOCAyMDIu'
    b'M2MxLjQgMSAzLjMtLjcgMi41LTIuNi0uNS0xLjItMi4yLTIuNi00LjctLjktMi44IDEuOS0y'
    b'IDcuOCAzLjIgNy45IDQuNyAwIDcuNi02LjggMy40LTExLjYtNC00LjYtMTEuMy0zLjYtMTYg'
    b'LjJBMjEuNCAyMS40IDAgMCAwIDIyNSAyMDdhMjIuNSAyMi41IDAgMCAwIDAgOS4yIDIwLjkg'
    b'MjAuOSAwIDAgMCAzIDcuNWwxLjMgMS43Yy44LjggMSAxLjIgMiAyYTE1IDE1IDAgMCAwIDEw'
    b'LjQgMy43YzQuNi0uMiA3LjMtMy40IDYuOC03LjMtLjQtMy44LTQuMi01LjctNi43LTMuOS0x'
    b'LjcgMS4yLTIuMyA0LjkuNyA1LjggMS42LjUgMy4xLTEuNyAyLTNNMzc0IDE1MC45YzIuNy0x'
    b'LjQgNC44LTEuMiA2LjMgMWE5LjkgOS45IDAgMCAxIDEuNiA3LjIgOS4yIDkuMiAwIDAgMS0z'
    b'LjUgNS44Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTM4MC41'
    b'IDE1MmMzLjEtMiA2LjUtMS4xIDguMyAxLjYgMS4zIDIgMS43IDMuNiAxLjYgNi4xYTExLjIg'
    b'MTEuMiAwIDAgMS01LjcgOS4yIi8+CiAgICAgIDxwYXRoIGQ9Ik0zOTUgMTU5LjJjMi42LjIg'
    b'NC42IDIuNSA0LjYgNS4xIDAgMy44LTEgNS41LTQgOS4zLTIuNyAzLjMtMTAuNiA5LTEwLjQg'
    b'MTQuNiAwIDIuMSAxLjggNCAzLjMgNC4yIi8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2Fw'
    b'PSJyb3VuZCIgZD0iTTM5NS40IDIwMi4zYy0xLjUgMS0zLjMtLjYtMi41LTIuNC41LTEuMiAy'
    b'LjItMi44IDQuNy0xLjEgMi43IDEuOSAyIDcuOC0zLjMgNy45LTQuNyAwLTgtNi42LTMuNC0x'
    b'MS42IDQtNC42IDExLjctMy43IDE2LjUuMSAyIDEuNiA2LjEgNiA3IDEyIDEgNyAuOSAxNS42'
    b'LTYuNCAyMS0zIDIuMS03IDMuMS0xMC42IDMtNC42LS4yLTcuMy0zLjUtNi44LTcuNC41LTMu'
    b'OCA0LTUuNCA2LjctMy45IDIuOCAxLjUgMi4zIDUuNC0uNyA1LjgtMS43LjItMy4xLTEuNy0y'
    b'LTMiLz4KICAgICAgPHBhdGggZD0iTTM5Mi45IDE5OS45Yy44LTMuNSAzLjctMy44IDYuMi0z'
    b'LjggNi41LjEgMTEuMSA4IDExLjIgMTUuNSAwIDkuNS00IDE1LjItMTEgMTUuNS0xLjkgMC01'
    b'LS44LTUtMyIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0ic3F1YXJlIiBkPSJNMzk3'
    b'IDE5OC4zYzYuOSAxLjYgOS4zIDcuOCA5LjMgMTMuOCAwIDQuOS0uNSAxMS42LTEwIDEzLjki'
    b'Lz4KICAgICAgPHBhdGggZD0iTTQwOC40IDI2NS4zYTMuOSAzLjkgMCAxIDAtNi4zIDIuNCIv'
    b'PgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0zOTQuNCAyNTkuNGMx'
    b'LjQgMiAzIDQuMSA2LjMgNm0tMS4zIDEwLjVjLTMuMi0yLjItOS41LTUtMTUtMi4yYTcuNiA3'
    b'LjYgMCAwIDAtNC40IDQuNCAxMCAxMCAwIDAgMCAxLjggOS41Yy45IDEgMi43IDIuNiA1IDIu'
    b'NyAzLjggMCA0LjctMi42IDQuOC0zLjIuNC0yLjgtMS4yLTMuOS0yLTQuMS0uNy0uMy0yLjgt'
    b'LjItMy4yIDEuMy0uMi41LS4yIDEuMy4yIDIiLz4KICAgICAgPHBhdGggc3Ryb2tlLWxpbmVj'
    b'YXA9InJvdW5kIiBkPSJNMzQwLjUgMzI4LjRjMSAyLjItLjIgMy4yLTEuNiAzLjQtMi4yLjMt'
    b'My4zLTEuNC0zLjQtM2E0LjQgNC40IDAgMCAxIDQuMy00LjdjMi4zIDAgNC4xIDEuNSA1IDMu'
    b'NS4zLjcuNSAxLjUuNSAyLjRhNS44IDUuOCAwIDAgMS0xLjQgNC4xIDcuNSA3LjUgMCAwIDEt'
    b'NS40IDIuNWMtNC4yLjEtNy41LTMuOC03LjUtNy44IDAtNy43IDExLjQtMTIgMTYtMTNhODQg'
    b'ODQgMCAwIDEgMTcuOS0yLjRjMy41LS4xIDYuMiAwIDEwLjEtLjUgMy41LS4zIDUuNC0uNSA5'
    b'LTEuM2EyNy4yIDI3LjIgMCAwIDAgMTIuNi02LjRjMi45LTIuNyA0LjUtNC41IDUuOS04LjJh'
    b'MTcgMTcgMCAwIDAtMS4zLTEzLjkgMTQuMyAxNC4zIDAgMCAwLTEwLjMtNi44Yy0zLjctLjUt'
    b'NyAxLjEtOSA0LjgtMSAxLjgtLjYgNC44LjEgNi4yYTYgNiAwIDAgMCA0LjggM2MzLjggMCA0'
    b'LjctMi42IDQuOC0zLjIuNC0yLjgtMS4yLTMuOS0yLTQuMi0uNy0uMi0yLjgtLjEtMy4yIDEu'
    b'NC0uMi41LS4yIDEuMy4yIDIiLz4KICAgICAgPHBhdGggc3Ryb2tlLWxpbmVjYXA9InJvdW5k'
    b'IiBkPSJNMzM3LjIgMzE2LjJjLTQuOCAyLjEtOC40IDMuNy0xMS40IDguNWE5LjkgOS45IDAg'
    b'MCAwLTEuMiA0LjljMCAyLjcgMS4xIDUuNyAzLjMgNy42YTguMyA4LjMgMCAwIDAgNi43IDJj'
    b'Mi0uMiAzLjctMS42IDQtMi42Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zODUuMSAyMjQuMWMtMi4z'
    b'LjgtMy45IDQuMi0zLjkgNy41YTguNCA4LjQgMCAwIDAgNCA3LjUiLz4KICAgICAgPHBhdGgg'
    b'c3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBkPSJNMzg3LjYgMjM2LjRjLTQgNS4xLTYuMyA4LjEt'
    b'Ni40IDE0LjEgMCA1LjcgMS43IDkuNiA1LjEgMTMuNyIvPgogICAgICA8cGF0aCBkPSJtMzY1'
    b'LjkgMTUyIC4zLS41YzEuNy0yLjQgNC43LTMuMSA2LjktMS41IDIuNiAyIDMuMyA1LjQgMi42'
    b'IDktLjUgMi4yLTIgNC4xLTQgNS41Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJy'
    b'b3VuZCIgZD0iTTI2NS4xIDE1MC44Yy0yLjYtMS4yLTQuNy0xLTYuMyAxYTguNyA4LjcgMCAw'
    b'IDAtMS42IDcuMmMuNiAyLjcgMS40IDMuOCAzLjUgNS44Ii8+CiAgICAgIDxwYXRoIGQ9Ik0y'
    b'NTguNiAxNTJhNS44IDUuOCAwIDAgMC04LjMgMS42IDkuMSA5LjEgMCAwIDAtMS42IDYuMWMu'
    b'MiA0LjIgMi44IDcuNiA1LjggOS4yIi8+CiAgICAgIDxwYXRoIGQ9Ik0yNDkuNyAxNTQuOGE2'
    b'LjggNi44IDAgMCAwLTYgNi42YzAgNC41IDEgNi4zIDMuNSA5LjYgMi41IDMuNCAxMC43IDku'
    b'NiAxMC43IDE2LjcgMCA0LjMtMS4yIDctNC4zIDguNC0yIDEtNC4zIDAtNS40LTEtMi42LTIu'
    b'NC0xLjUtNi41IDEuMi03IDMuMy0uNiAzLjkgNC42LjcgNC4zIi8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik0yNDQgMTU5LjJjLTIuNS4yLTUgMi4zLTUgNSAwIDMuOCAxLjUgNS42IDQuNiA5LjQgMi42'
    b'IDMuMyAxMC4xIDkgOS45IDE0LjUgMCAyLTEuNSA0LjYtMi45IDQuMyIvPgogICAgICA8cGF0'
    b'aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0yMzggMjM2LjFjMS4zLTIuOSA0LjQtMS42'
    b'IDQuNiAwIC40IDMuNy0yLjggNC44LTUuMSA0LjJhNCA0IDAgMCAxLTIuNS0yIDQuOCA0Ljgg'
    b'MCAwIDEtLjQtMy43IDQuOSA0LjkgMCAwIDEgLjktMS42IDUgNSAwIDAgMSAxLjItMS4yYzEt'
    b'LjYgMS45LS42IDMuNC0uNiA1LjUgMCAxMC40IDYuNSAxMiAxMy40LjYgMi4yIDEuMyA3LjMu'
    b'MyAxMmEyMi40IDIyLjQgMCAwIDEtNS44IDExLjMgMjUuOCAyNS44IDAgMCAxLTEwIDUuOCA3'
    b'IDcgMCAwIDEtMy45LjFjLTIuOC0uOS00LjYtMy41LTMuMi03IDEuMi0yLjYgNS40LTQgNy4z'
    b'LS42LjIuMy40LjkuNCAxLjUgMCAuOS0uNCAyLTEgMi40LTEuNC45LTMuNy42LTMuNi0yIi8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik0yMzMuOCAyNzAuNGMxIC40IDEuNi4zIDIuOS0uMmwxLjgtMWMy'
    b'LjYtMS41IDUuNi0zLjggOC40LTkuMWExOC44IDE4LjggMCAwIDAgMS43LTQuNWMuMy0xIC41'
    b'LTIuMi42LTMuM2EyNS42IDI1LjYgMCAwIDAtNC44LTE1LjNjLTEuMS0xLjYtMi0yLjUtNC4y'
    b'LTIuNm0tOS41IDMxYTMuOSAzLjkgMCAxIDEgNi4zIDIuMyIvPgogICAgICA8cGF0aCBkPSJN'
    b'MjMyLjIgMjYxLjRhMy43IDMuNyAwIDAgMSAzLjctMyAzLjcgMy43IDAgMCAxIDMuNiAzLjcg'
    b'My44IDMuOCAwIDAgMS0xIDIuNiIvPgogICAgICA8cGF0aCBkPSJNMjM5LjQgMjYxLjNhMTUu'
    b'NSAxNS41IDAgMCAwIDYuMi0xMi40YzAtNC4xLTEuNi04LjQtMy42LTEwIi8+CiAgICAgIDxw'
    b'YXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTI0NC43IDI1OS40YTE2LjUgMTYuNSAw'
    b'IDAgMS02LjMgNiIvPgogICAgICA8cGF0aCBkPSJNMjU0LjYgMjczLjdjLTEtMi4yLTIuOC0z'
    b'LjItNS44LTMuNS0zLS4zLTUuNS41LTguMiAxLjlhMTguNiAxOC42IDAgMCAwLTEwLjggMTcg'
    b'MjUgMjUgMCAwIDAgMiA5LjVjLjkgMS42IDMgOSAxNS4zIDE0YTg2LjEgODYuMSAwIDAgMCAy'
    b'NS43IDMuOWMxMC40LjQgMjAgLjggMjUuNiA3LjYiLz4KICAgICAgPHBhdGggc3Ryb2tlLWxp'
    b'bmVjYXA9InJvdW5kIiBkPSJNMjM5LjcgMjc1LjljMy4zLTIuMiA5LjUtNSAxNS4xLTIuMmE4'
    b'IDggMCAwIDEgNC4zIDQuNCAxMCAxMCAwIDAgMS0xLjggOS41Yy0uOSAxLTIuNyAyLjYtNSAy'
    b'LjctMy44IDAtNC43LTIuNi00LjgtMy4yLS40LTIuOCAxLjItMy45IDItNC4yLjctLjIgMi44'
    b'LS4xIDMuMiAxLjQuMi41LjIgMS4zLS4yIDIiLz4KICAgICAgPHBhdGggZD0iTTI1Mi43IDI4'
    b'NS43Yy4zLTEgLjItMi4yLS44LTMuM2E1LjEgNS4xIDAgMCAwLTYtMWMtLjcuNS0xLjYgMS0y'
    b'LjQgMi4yLS40LjQtMSAxLjEtMS4yIDEuNi0uNyAxLjEtMSAyLTEgMi41LTIuNSA3IDEuNSAx'
    b'NC40IDYuNSAxNy42IDQuNCAyLjggOC44IDMuNiAxNC40IDQgMi41LjMgNCAuMyA2LjUuNWg5'
    b'LjZhNzAuMSA3MC4xIDAgMCAxIDcuMiAwYzMgLjMgNS4xLjQgNy42LjggMS42LjIgMy41LjUg'
    b'NS40IDEgLjYgMCAxLjIuMiAxLjguNGwxLjIuM2MzLjYgMS4xIDcgMi40IDkuOCA0LjIuOC41'
    b'IDEuOCAxIDIuNSAxLjdsMS4zIDEuMmMyIDIgNCA0IDQuNCA2Ljd2MS42YzAgMS44LTEuNCA0'
    b'LjMtNS4zIDUiLz4KICAgICAgPHBhdGggZD0iTTI5OC42IDMyOC40Yy0xIDIuMi4yIDMuMiAx'
    b'LjYgMy40IDIuMi4zIDMuMy0xLjQgMy41LTNhNC40IDQuNCAwIDAgMC00LjQtNC43IDUuNSA1'
    b'LjUgMCAwIDAtNSAzLjUgNi45IDYuOSAwIDAgMC0uNSAyLjQgNS44IDUuOCAwIDAgMCAxLjQg'
    b'NC4xIDcuNSA3LjUgMCAwIDAgNS40IDIuNWM0LjIuMSA3LjUtMy44IDcuNS03LjggMC03Ljct'
    b'MTEuNC0xMi0xNi0xM2E4NCA4NCAwIDAgMC0xNy45LTIuNGMtMy41LS4xLTYuMiAwLTEwLjEt'
    b'LjUtMy41LS4zLTUuNC0uNS05LTEuM2EyNy4yIDI3LjIgMCAwIDEtMTIuNS02LjQgMTcgMTcg'
    b'MCAwIDEtNC43LTIyIDE0LjMgMTQuMyAwIDAgMSAxMC4zLTYuOWMzLjgtLjUgNyAxLjEgOSA0'
    b'LjggMSAxLjguNiA0LjgtLjEgNi4yYTYgNiAwIDAgMS00LjggM2MtMy44IDAtNC43LTIuNi00'
    b'LjgtMy4yLS40LTIuOCAxLjItMy45IDItNC4yLjctLjIgMi44LS4xIDMuMiAxLjQuMi41LjIg'
    b'MS4zLS4yIDIiLz4KICAgICAgPHBhdGggc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBkPSJtMjcz'
    b'LjMgMTUyLS40LS41Yy0xLjctMi40LTQuNy0zLjEtNi45LTEuNS0yLjYgMi0zLjMgNS40LTIu'
    b'NSA5YTkgOSAwIDAgMCA0IDUuNSIvPgogICAgICA8cGF0aCBkPSJNMzY2LjggMTU5LjZjLTQg'
    b'NC40LTguMSA1LjgtMTQuMSA2LTIgMC01LjUtLjYtNy42LTIuMS0xLjMtMS0yLjgtMi42LTEu'
    b'OS01LjUuNi0xLjkgMy43LTcuMiAzLjgtMTAuOS4zLTUuNi0xLjktOC43LTUuMy05LjktNi4y'
    b'LTIuMi0xMyA0LTE3IDUuNC0yLjEuNy0zLjIuOC01LjEuOC0yIDAtMy0uMS01LjItLjgtNC0x'
    b'LjQtMTAuNy03LjYtMTctNS40LTMuNCAxLjItNS41IDQuMy01LjMgMTAgLjEgMy42IDMuMiA5'
    b'IDMuOCAxMC44IDEgMi45LS41IDQuNS0xLjkgNS41LTIgMS41LTUuNyAyLjEtNy41IDItNi0u'
    b'MS0xMC4xLTEuNS0xNC4xLTUuOSIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91'
    b'bmQiIGQ9Ik0yOTcuMyAzMTQuNGMuOC4zLjItLjIgNS4zIDJhMjIgMjIgMCAwIDEgMTEuMyA4'
    b'LjkgMTAuNSAxMC41IDAgMCAxIC45IDcuMyIvPgogICAgICA8cGF0aCBkPSJNMjk3LjcgMzM2'
    b'YTggOCAwIDAgMCAzLjIuOWM0LjIuMSA3LjUtMy44IDcuNS03LjggMC0yLjgtMS41LTUuMi0z'
    b'LjYtNyIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0yOTguNiAz'
    b'MjguNGMtMSAyLjMuNCAzLjUgMS44IDMuNyAyLjIuMiAzLjQtMS40IDMuNi0zYTQuNSA0LjUg'
    b'MCAwIDAtMi4yLTQuMiIvPgogICAgICA8cGF0aCBkPSJNMzkwLjEgMTU0LjhjMy4yIDAgNiAz'
    b'LjYgNiA3LjIgMCA0LjMtMi4yIDYuOS0zLjkgOC44LTEuMyAxLjYtMi43IDMtNC40IDQuNyIv'
    b'PgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0zODYuMyAxNTEuNGE5'
    b'IDkgMCAwIDEgMi44IDIuNGMxLjMgMiAxLjcgMy43IDEuNiA2LjItLjIgNC4yLTMuMiA3LjEt'
    b'NiA5bS00LjctMTcuNi42LjdjMS45IDIuMiAyIDUuNCAxLjYgNy4yYTguMiA4LjIgMCAwIDEt'
    b'My44IDUuNG0tNS0xNC40YzIuNiAyIDMuNCA1LjQgMi41IDktLjYgMi41LTIuMiA0LTQuMiA1'
    b'LjJtMTEuMSA0MS4xYy4zIDEgLjkgMS4zIDEuNSAyYTEzLjUgMTMuNSAwIDAgMCA2LjIgMy41'
    b'YzIuNC43IDQuNi4yIDYuMy0uOW0tMTYzIDU0YzEuMiAwIDIuNS45IDMuMyAyLjMuMS4yLjQu'
    b'OC40IDEuNSAwIC45LS40IDEuOC0xIDIuMi0xLjUgMS00IC41LTQtMiIvPgogICAgICA8cGF0'
    b'aCBkPSJNMjQxLjUgMjMxLjNjNSAxIDkuNyA2LjkgMTEuMiAxMy4zLjYgMi4zIDEuMyA3LjMu'
    b'MyAxMmEyMi40IDIyLjQgMCAwIDEtNiAxMS40IDE2LjUgMTYuNSAwIDAgMS0yLjEgMS45bC0x'
    b'IC43bS04LTEyLjFjMiAwIDMuOCAxLjkgMy44IDRhMy44IDMuOCAwIDAgMS0xIDIuNiIvPgog'
    b'ICAgICA8cGF0aCBkPSJNMjM0LjYgMjYwLjdjMi4xIDAgNC4xIDIgNC4xIDQuMmEzLjkgMy45'
    b'IDAgMCAxLTEuNCAzIi8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0i'
    b'TTI1NCAyMzkuNWExOCAxOCAwIDAgMSAzLjggNy43bTAgOC41YTE3LjMgMTcuMyAwIDAgMS0x'
    b'LjUgNCAxNy44IDE3LjggMCAwIDEtMy42IDQuNyIvPgogICAgICA8cGF0aCBkPSJNMjU0LjMg'
    b'MjI0LjNjMS44IDEuNSAzIDMgMy41IDQuOCIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNh'
    b'cD0icm91bmQiIGQ9Ik0yNTcuOSAyMTkuNWExMCAxMCAwIDAgMS0zLjQgNC42bS05LjItMTcu'
    b'MiAyLjItLjYgMS4zLTEgLjgtMS4xLjctMS44LjMtMS41Ii8+CiAgICAgIDxwYXRoIGQ9Ik0y'
    b'NDEgMTk5LjNjLS43LjItMS42LjQtMi41LjhhOSA5IDAgMCAwLTMuNSAzIDE3IDE3IDAgMCAw'
    b'LTIuMiAxMi43IDE1LjggMTUuOCAwIDAgMCAyLjMgNS42bDEgMS40YzEuNCAxLjMgMi42IDIg'
    b'NC42IDEuNyIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0yNTMg'
    b'MTg5LjhjLS4zIDEuMy0xIDIuOS0zIDIuNyIvPgogICAgICA8cGF0aCBkPSJNMjQ1LjcgMTk4'
    b'LjVjLTItMS45LTYtMi40LTEwLjEuMkwyMzQgMjAwYTguOCA4LjggMCAwIDAtMS40IDEuNiAx'
    b'Ny41IDE3LjUgMCAwIDAtMi40IDVjLS43IDMtLjcgNS42LS42IDYuMyAwIDEgLjIgMS45LjMg'
    b'Mi43LjYgMi44IDEuNCA0LjggMi4zIDYuMi45IDEuNSAzIDUgNy43IDUuNCAxLjguMSA0Ljgt'
    b'LjcgNS0zIi8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTM2My44'
    b'IDE1N2MuMy0xLjYgMi4zLTEuOSAzLTEgMS4yIDEuNi40IDQuMi0yIDQuOWE0IDQgMCAwIDEt'
    b'My44LTEuNGMtMS0xLjMtLjktMi44LS41LTQgLjItLjguOS0xLjUgMS43LTIuMiAyLjctMiA3'
    b'LjEtMS42IDguNiAyIDEuOCA0LjQtMi4yIDcuOC02IDEwLjMtNC42IDMuMi0xMCAzLjgtMTQg'
    b'My43LTkuMiAwLTE2LjEtNC40LTIwLjctNy0xLS41LTIuMS0uNC0yLjcuM2EyIDIgMCAwIDAg'
    b'LjMgMi43Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTM2NS42'
    b'IDE1NS41YzEgMCAxLjIuNCAxLjUuOCAxLjIgMS41LjMgNC4xLTIgNC45bTE3LjggNTEuNWMt'
    b'My41IDMuOC0uMiAxMC4zIDIuNCAxMS44LjkuNyAxLjMuMyAyIC43Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0zODMuMSAyMDUuNGMtMS4xLjgtMS41IDEuNy0xLjYgMy4zYTUuMyA1LjMgMCAwIDAg'
    b'MS40IDQgMTQgMTQgMCAwIDAgOS4zIDMuN2MyIDAgNC0uNCA2LTEuN2E5IDkgMCAwIDAgMy44'
    b'LTUuNG0tMjAuOCA2MS44LS4yIDIuNWExOC45IDE4LjkgMCAwIDEtMiA3IDE4LjcgMTguNyAw'
    b'IDAgMS00LjIgNS42IDE5LjYgMTkuNiAwIDAgMS01LjkgNCAyNC42IDI0LjYgMCAwIDEtNi41'
    b'IDIuMyA0My44IDQzLjggMCAwIDEtMTMuMi42Yy0yLjctLjItNC4xLS41LTYuOC0uOC0yLjIt'
    b'LjEtMy40LS4zLTUuNi0uM2EyOC4zIDI4LjMgMCAwIDAtMTAuOSAxLjljLTIuNyAxLTUuNyAz'
    b'LTYuNCAzLjgtLjYtLjktMy43LTIuOC02LjMtMy44YTIyIDIyIDAgMCAwLTUuMi0xLjVjLTIu'
    b'Mi0uNC0zLjUtLjQtNS44LS40LTIuMiAwLTMuNC4yLTUuNi40LTIuNi4yLTQgLjYtNi43Ljct'
    b'Mi41LjItMy45LjMtNi4zLjJhMzMgMzMgMCAwIDEtNy0uOCAyNC42IDI0LjYgMCAwIDEtNi41'
    b'LTIuMiAxOS42IDE5LjYgMCAwIDEtNS44LTQuMSAxOC43IDE4LjcgMCAwIDEtNC4yLTUuNyAx'
    b'OSAxOSAwIDAgMS0yLTYuOWMtLjItMS0uMi0yLjUtLjItMi41VjE2OS4zaDEyMy4ydjEwMS44'
    b'eiIvPgogICAgPC9nPgogICAgPGcgZmlsbD0iI2M3YjM3ZiIgc3Ryb2tlPSIjYzdiMzdmIj4K'
    b'ICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTI0OCAyODUuNmEyLjUgMi41IDAg'
    b'MSAxIDUgMCAyLjUgMi41IDAgMCAxLTUgMHpNMjMyLjUgMjY4YzAtMS4zLjgtMi4zIDEuOC0y'
    b'LjNzMS43IDEgMS43IDIuM2MwIDEuMi0uOCAyLjItMS43IDIuMi0xIDAtMS44LTEtMS44LTIu'
    b'MnoiLz4KICAgICAgPHBhdGggc3Ryb2tlPSJub25lIiBkPSJNMjQxLjMgMjIzLjZjMC0xIC44'
    b'LTEuOCAxLjctMS44IDEgMCAxLjcuOCAxLjcgMS44cy0uNyAxLjgtMS43IDEuOC0xLjctLjgt'
    b'MS43LTEuOHpNMjcyIDE1OGMwLTEgLjUtMiAxLjQtMiAuOS0uMSAxLjcuNiAxLjggMS42IDAg'
    b'MS0uNSAyLTEuNCAyLS45LjEtMS42LS42LTEuOC0xLjZ6Ii8+CiAgICA8L2c+CiAgICA8ZyBz'
    b'dHJva2U9IiNjN2IzN2YiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIu'
    b'NiI+CiAgICAgIDxwYXRoIGQ9Ik0yMzkuMyAyMzRjLS40LjEtLjYuMi0uOC41LS4zLjMtLjQu'
    b'NC0uNi45bC0uMiAxLjJtNC43IDI2LjcgMS0xIC42LTEgLjUtMSAuNy0xLjNtLTEuMyAxNC0x'
    b'LjUuNy0xLjEuNmExNy40IDE3LjQgMCAwIDAtMS4zLjhsLTEuMiAxbTE1LTM3LjktLjgtLjgt'
    b'MS0uOC0uOS0uOCIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0iYnV0dCIgZD0ibTI1'
    b'NC4yIDIyNS0xLjIuNWE1LjEgNS4xIDAgMCAxLTEuNS4zIi8+CiAgICAgIDxwYXRoIGQ9Ik0y'
    b'MzcuNCAyMDguNGMuMi42LjIgMSAuNSAxLjUuMi43LjUgMS4xLjkgMS43YTguMyA4LjMgMCAw'
    b'IDAgMi42IDIuN2wxLjUuOG0tMS01LjggMS4zLjZhNy40IDcuNCAwIDAgMCAzIC42bDEuOC0u'
    b'MW03LjItNDAuNy0yLTEuMmMtLjktLjUtMS4zLS45LTItMS41YTkuMyA5LjMgMCAwIDEtMS4x'
    b'LTEuM2wtLjgtMS4zbTcuNS00LjYuNiAxLjdhNy44IDcuOCAwIDAgMCAxLjQgMmMxIDEgMS43'
    b'IDEuMyAyLjggMi4ybTEuNC02Yy4zLjcuMyAxIC43IDEuNi4yLjUuNC44LjggMS4ybDEuMyAx'
    b'LjNjLjcuNiAxLjIuNyAyIDEuMSIvPgogICAgPC9nPgogICAgPHBhdGggZmlsbD0iIzcwM2Qy'
    b'OSIgc3Ryb2tlLXdpZHRoPSIuMiIgZD0iTTMzMy4zIDE1MS42YzAtMS43LTEuNy0xLjgtMi40'
    b'LTEuOC0xLjggMC0yLjMgMS4xLTQuNiAyLjNhMTEuOSAxMS45IDAgMCAxLTYuNyAyIDEyIDEy'
    b'IDAgMCAxLTYuNy0yYy0yLjMtMS4yLTIuNy0yLjMtNC42LTIuM2EyLjMgMi4zIDAgMCAwLTIu'
    b'MiAyLjR2LjlsLjMuMmMwLS44LjEtMS4yLjUtMS43YTIuMiAyLjIgMCAwIDEgMS42LS44YzEu'
    b'OCAwIDIuNSAxLjIgNC44IDIuNCAzIDEuNiA0LjIgMS45IDYuNyAyYTEyIDEyIDAgMCAwIDYu'
    b'OC0yYzIuMy0xLjIgMy0yLjUgNC44LTIuNS42IDAgMSAuNCAxLjMgMXYuOWwuMi4xYzAtLjMu'
    b'Mi0uNC4yLTF6Ii8+CiAgPC9nPgogIDxnIGZpbGw9IiM3MDNkMjkiPgogICAgPHBhdGggZD0i'
    b'TTI2NC40IDI5NGMuNS0uNS45LS4zIDEtLjYgMC0uMiAwLS4yLS4zLS4zbC0uOS0uMi0uOC0u'
    b'NGMtLjEgMC0uNC0uMi0uNSAwLS4xLjQgMSAuNC42IDEuNGEzLjcgMy43IDAgMCAxLS44IDEu'
    b'MmwtMi42IDMtLjIuMXYtNC4zbC4xLTEuOGMuMi0uNC44IDAgLjktLjQgMC0uMSAwLS4yLS4z'
    b'LS4zLS4yIDAtLjUgMC0xLjEtLjNsLTEtLjVjLS4yIDAtLjUtLjItLjYgMGwuMS4zYy40LjIu'
    b'NS40LjUgMXY3LjRjMCAuNS4xLjYuMi43LjEgMCAuMiAwIC40LS4zbDUuMy01Ljd6Ii8+CiAg'
    b'ICA8cGF0aCBkPSJNMjY3LjUgMjk1LjJjLjMtMS4xIDEtLjQgMS0uOC4xLS4yIDAtLjItLjIt'
    b'LjNsLTEuMy0uNGMtLjQgMC0uOC0uMy0xLjItLjQgMCAwLS4zLS4xLS40IDAtLjEuNSAxLjEu'
    b'NS44IDEuNWwtMS43IDUuNWMtLjMgMS0xIC42LTEuMSAxdi4xbDEuMi40IDEuNi41aC4zYy4y'
    b'LS40LTEuMi0uMy0uNy0xLjdsMS43LTUuNHptMy43IDFjLjItLjYuNS0uNS45LS40IDEgLjMg'
    b'MS40IDEuMyAxIDIuNS0uMi42LS40IDEuMi0yIC44LS4zLS4xLS43LS4yLS42LS41bC43LTIu'
    b'M3ptLTIuOCA1Yy0uNSAxLjQtMS4yLjgtMS4zIDEuMiAwIC4yLjIuMi4zLjNsMS42LjQuOC4z'
    b'aC40Yy4xLS41LTEtLjMtLjctMS41bC42LTJjLjEtLjQuMS0uNS42LS4zLjYuMS43LjMuOC44'
    b'bC4zIDJjLjIuOS4zIDEuNyAxIDIgLjUgMCAxLjIgMCAxLjQtLjRsLS4yLS4yaC0uM3MtLjMg'
    b'MC0uMy0uM2wtLjctMy42YzAtLjIuNC0uMi44LS4zYTIgMiAwIDAgMCAxLTEuM2MuMS0uNS40'
    b'LTIuMi0xLjgtMi45bC0yLjEtLjUtMS4yLS40aC0uM2MtLjEuNSAxLjEuNC43IDEuN2wtMS41'
    b'IDV6bTguNCAyLjVjLS40IDEuNC0xLjQuNS0xLjUgMSAwIC4yLjEuMy4zLjNsMS41LjMgMS40'
    b'LjRjLjMgMCAuNS4yLjYtLjEgMC0uMy0xLjMtLjMtMS0xLjhsMS4zLTUuMmMwLS42LjItLjYu'
    b'Ni0uNWwxIC4yYzEuMS4zLjUgMS41IDEgMS42LjIgMCAuMi0uNC4yLS42bC4xLTF2LS40bC0z'
    b'LjMtLjctMy4yLS44Yy0uMSAwLS4yIDAtLjIuMmwtLjUgMS41Yy0uMS4xLS4yLjQgMCAuNC41'
    b'LjEuNS0xLjUgMS43LTEuMmwuOS4yYy40LjEuNS4yLjQuOGwtMS4zIDUuNHptMTIuNy0zLjNj'
    b'LjQtLjYuOC0uNS45LS43IDAtLjItLjItLjItLjQtLjNoLS45bC0uOS0uM2MtLjEgMC0uNC0u'
    b'MS0uNC4xLS4xLjQgMSAuMi44IDEuMyAwIC4yLS4xLjYtLjYgMS4zbC0yIDMuMy0uMy4ydi0u'
    b'MmwtLjctNGE1LjQgNS40IDAgMCAxLS4xLTEuOGMwLS41LjctLjIuNy0uNSAwLS4yIDAtLjIt'
    b'LjQtLjNsLTEuMS0uMWMtLjQgMC0uNy0uMi0xLS4zLS4yIDAtLjUtLjEtLjYuMWwuMS4yYy41'
    b'LjIuNi40LjcuOWwxLjMgNy4zYy4xLjUuMi43LjMuNy4xIDAgLjIgMCAuNC0uM2w0LjItNi42'
    b'em0uNiA2LjhjMCAuMyAwIC4zLjIuNS42LjIgMSAuNiAxLjcuNyAxLjQuMiAyLjYtLjcgMi44'
    b'LTIuMi4zLTEuNS0uMy0yLjEtMS40LTIuOS0xLjMtLjktMS44LTEuMS0xLjctMiAuMS0uNy43'
    b'LTEgMS40LTEgMS44LjMgMS42IDIuNiAxLjggMi42LjMgMCAuMy0uMS4zLS40bC4yLTEuNnYt'
    b'LjRoLS42Yy0uNCAwLS43LS41LTEuNi0uNy0xLjItLjItMi4zLjctMi41IDItLjIgMS4yLjQg'
    b'MS44IDEuMiAyLjQgMS42IDEuMSAyLjIgMS40IDIgMi40LS4xIDEtLjkgMS40LTEuNyAxLjMt'
    b'MS4yLS4yLTEuNi0xLjQtMS44LTIuNiAwLS4yIDAtLjMtLjItLjNzLS4yLjMtLjIuNXYxLjd6'
    b'bTE1LjgtNC41Yy4zLS43LjgtLjYuOC0uOSAwLS4yLS4xLS4xLS40LS4yaC0uOWwtLjktLjFj'
    b'LS4xIDAtLjQgMC0uNC4yIDAgLjQgMSAwIDEgMS4xIDAgLjItLjEuNi0uNSAxLjRsLTEuOCAz'
    b'LjUtLjEuMy0uMS0uMy0xLjEtNGE1LjQgNS40IDAgMCAxLS4zLTEuNmMwLS41LjctLjMuNy0u'
    b'NiAwLS4yIDAtLjItLjQtLjJoLTEuMmwtMS0uMmMtLjIgMC0uNS0uMS0uNi4xbC4yLjJjLjQu'
    b'Mi42LjMuNy44bDIuMSA3LjEuNC43Yy4xIDAgLjIgMCAuMy0uNGwzLjUtN3oiLz4KICAgIDxw'
    b'YXRoIGQ9Ik0zMDcuNiAzMDguNWMwIDEuMi0xIDEtMSAxLjUgMCAuMi4xLjEuMy4xaDIuMmwu'
    b'NC0uMWMwLS42LTEuNC4yLTEuNC0ydi00LjJsLjEtLjEuMi4xIDUuMSA2LjMuMy4xLjItLjN2'
    b'LTYuN2MwLTEuMyAxLTEgMS0xLjMgMCAwIDAtLjItLjMtLjJoLTIuM2MtLjIgMC0uMi4xLS4y'
    b'LjIgMCAuNCAxLjMuMiAxLjMgMS4zdjRsLS4xLjQtLjQtLjMtNC4yLTUuM2MtLjItLjMtLjEt'
    b'LjMtLjQtLjNoLTEuOGwtLjIuMWMwIC42IDEuMi0uMiAxLjIgMi4xdjQuNnpNMzE4IDMwM2Mw'
    b'LTEuMS44LS43LjgtMS4xIDAtLjEgMC0uMi0uNC0uMmgtMi42cy0uMyAwLS4zLjJjMCAuNCAx'
    b'LjEgMCAxLjEgMS4ydjUuN2MwIDEuMS0uOC44LS44IDEuMiAwIDAgMCAuMi4yLjJoMi44Yy4y'
    b'IDAgLjMgMCAuMy0uMiAwLS40LTEuMi4yLTEuMi0xLjNsLjEtNS43em00LjUgNS41YzAgMS41'
    b'LTEuMiAxLTEuMiAxLjQgMCAuMi4yLjIuNC4yaDNjLjMgMCAuNSAwIC41LS4zcy0xLjQgMC0x'
    b'LjQtMS40VjMwM2MwLS42IDAtLjYuNS0uNmgxYzEuMi0uMS44IDEuMiAxLjMgMS4yLjIgMCAu'
    b'MS0uNC4xLS42bC0uMS0xYzAtLjIgMC0uNC0uMi0uNGwtMy4zLjFoLTMuM2wtLjIuMy0uMSAx'
    b'LjYuMS40Yy41IDAgLjItMS42IDEuNC0xLjZoLjljLjQgMCAuNSAwIC42LjZ2NS42em02LjMt'
    b'Mi4yaC0uNGwuMS0uNS43LTIuMnYtLjJsLjIuMSAxIDIuMS4yLjRjMCAuMi0uMi4yLS40LjJo'
    b'LTEuNHptMS44LjVjLjMgMCAuMyAwIC44IDFsLjIuOGMwIC43LS43LjYtLjcgMSAwIC4xLjIu'
    b'MS40IDBoMS4ybDEuMy0uMWMuMyAwIC40IDAgLjQtLjIgMC0uNC0uNiAwLTEtLjdsLTMuNC03'
    b'LS4zLS40Yy0uMiAwLS4yLjItLjMuNEwzMjcgMzA5Yy0uMi43LS44LjctLjcgMWgyLjNjLjIt'
    b'LjEuNSAwIC41LS4zcy0xLjIgMC0xLjMtLjlsLjItMWMuMi0uOC40LS44LjYtLjhsMi4xLS4y'
    b'em04LjMtNWMtLjEtLjggMC0uOCAxLjItMSAyLS4yIDEuNCAxLjMgMiAxLjIuMiAwIDAtLjQg'
    b'MC0uNmwtLjEtMS4xYzAtLjEtLjEtLjItLjMtLjItMSAwLTEuNy4yLTIuNC4zbC0yLjguNGMt'
    b'LjIgMC0uMyAwLS4zLjIuMS41IDEuMyAwIDEuNCAxbC43IDUuNWMuMiAxLjUtLjcgMS0uNiAx'
    b'LjUgMCAwIDAgLjEuMiAwbDEuNC0uMSAxLjItLjFjLjMgMCAuNSAwIC41LS4zcy0xLjIuMS0x'
    b'LjQtMS4ybC0uMi0xLjdjLS4xLS43LS4xLS45LjMtMWguOGMxLjEtLjIgMSAxLjEgMS4zIDEg'
    b'LjMgMCAuMi0uNC4xLS41bC0uMy0yLjFjMC0uMy0uMi0uMy0uMi0uMy0uMyAwLS4xIDEuMS0x'
    b'IDEuMmwtLjcuMWMtLjUuMS0uNSAwLS42LS41bC0uMi0xLjd6bTQgMi44Yy40IDIuMyAyLjEg'
    b'My43IDQuMiAzLjMgMy40LS43IDMuNS0zLjYgMy4yLTUuMy0uNS0yLjUtMi4zLTMuNy00LjQt'
    b'My4zLTIuNS41LTMuNSAyLjctMyA1LjN6bTEuMS0xYy0uMy0xLjYgMC0zLjQgMS43LTMuNyAx'
    b'LjQtLjMgMyAuOCAzLjQgMy40LjMgMiAwIDMuNi0xLjggNC0xLjkuNC0zLTItMy4zLTMuNnpt'
    b'OC4zLTQuMWMtLjEtLjcuMi0uOC42LS45IDEtLjIgMS44LjUgMi4xIDEuNi4yLjcuMyAxLjQt'
    b'MS4zIDEuOC0uMyAwLS43LjEtLjgtLjJsLS41LTIuM3ptMCA1LjdjLjQgMS40LS41IDEuMy0u'
    b'NSAxLjYuMS4zLjMuMi40LjEuNiAwIDEtLjMgMS42LS40bDEtLjJjLjIgMCAuMi0uMS4yLS4y'
    b'IDAtLjQtMSAuMy0xLjMtMWwtLjUtMmMwLS40LS4yLS40LjQtLjUuNS0uMi43LS4xIDEuMS4z'
    b'bDEuMyAxLjZjLjUuNiAxIDEuMyAxLjggMS4xLjUtLjEgMS0uNSAxLS45bC0uMi0uMS0uMy4x'
    b'cy0uMy4xLS40IDBsLTIuNC0yLjkuNS0uNmMuMi0uNC40LS45LjItMS42LS4xLS41LS43LTIu'
    b'MS0zLTEuNmwtMi4xLjYtMS4yLjJjLS4yIDAtLjMuMS0uMi4yIDAgLjUgMS4xLS4yIDEuNCAx'
    b'bDEuMiA1LjJ6bTguNy0yYy4zIDEuNC0xIDEuMi0uOSAxLjYgMCAuMy4zLjIuNS4ybDEuNC0u'
    b'NSAxLjUtLjNjLjMgMCAuNSAwIC40LS40IDAtLjMtMS4zLjQtMS43LTFsLTEuMy01LjNjLS4y'
    b'LS41IDAtLjYuMy0uN2wxLS4yYzEuMS0uNCAxLjEgMSAxLjUuOS4zIDAgMC0uNSAwLS43bC0u'
    b'NC0xczAtLjMtLjItLjJsLTMuMi45LTMuMi43di4zbC4xIDEuNmMwIC4yIDAgLjQuMy40LjUt'
    b'LjEtLjMtMS42IDEtMS45bC44LS4yYy40LS4xLjYgMCAuNy41bDEuNCA1LjN6bTUuNS03LjNj'
    b'LS4zLTEgLjYtLjkuNC0xLjNoLS4zbC0xLjQuNC0xLjIuM3MtLjMgMC0uMy4yYy4xLjQgMS4y'
    b'LS4yIDEuNS44bDEuNiA1LjZjLjIgMS0uNiAxLS41IDEuMyAwIC4xIDAgLjIuMi4xbDEuMS0u'
    b'MyAxLjYtLjRjLjMgMCAuMy0uMS4zLS4zLS4xLS4zLTEuMS41LTEuNS0uOWwtMS41LTUuNXpt'
    b'Mi4zIDIuN2MuNyAyLjMgMi42IDMuNCA0LjcgMi43IDMuMi0xLjEgMy00LjEgMi40LTUuNy0u'
    b'OC0yLjQtMi44LTMuMy00LjgtMi43LTIuNC45LTMuMiAzLjItMi4zIDUuN3ptMS0xYy0uNi0x'
    b'LjctLjYtMy41IDEuMS00IDEuMy0uNSAzIC40IDMuOSAyLjkuNiAxLjguNSAzLjYtMS4yIDQu'
    b'Mi0xLjguNi0zLjItMS41LTMuOC0zLjJ6bTcuNi01LjVjLS4yLS43IDAtLjguNC0xIDEtLjMg'
    b'MiAuMyAyLjQgMS40LjIuNi40IDEuMy0xLjEgMS45LS4zIDAtLjcuMi0uOCAwbC0uOS0yLjN6'
    b'bS44IDUuNmMuNiAxLjQtLjQgMS40LS4yIDEuNyAwIC4zLjIuMS40LjFsMS41LS43LjktLjJj'
    b'LjItLjEuMi0uMi4yLS4zLS4yLS40LTEgLjQtMS40LS44bC0uOC0xLjljLS4yLS40LS4yLS41'
    b'LjMtLjcuNS0uMi43LS4xIDEuMS4zbDEuNiAxLjRjLjUuNSAxLjEgMS4xIDIgLjguMy0uMi45'
    b'LS43LjctMWwtLjItLjEtLjIuMmgtLjVsLTIuOC0yLjUuNC0uN2EyIDIgMCAwIDAgMC0xLjZj'
    b'LS4xLS42LTEtMi0zLjEtMS4ybC0yIC45LTEuMi40LS4yLjJjLjIuNCAxLjEtLjQgMS42Ljhs'
    b'MiA1eiIvPgogIDwvZz4KICA8ZyBmaWxsPSIjZmVkZjAwIiB0cmFuc2Zvcm09Im1hdHJpeCgu'
    b'NjQgMCAwIC42NCAwIDE2KSI+CiAgICA8cGF0aCBmaWxsPSIjZDUyYjFlIiBkPSJNNDEyLjcg'
    b'MjQ5LjNoODIuMXY4MmgtODIuMXoiLz4KICAgIDxwYXRoIGlkPSJhZC1hIiBmaWxsPSIjZmZm'
    b'IiBkPSJNNDUxLjIgMzEzLjhzMCAzLS44IDUuM2MtMSAyLjctMSAyLjctMS45IDRhMTMuMiAx'
    b'My4yIDAgMCAxLTMuOCA0Yy0yIDEuMi00IDEuOC02IDEuNi01LjQtLjQtOC02LjQtOS4yLTEx'
    b'LjItMS4zLTUuMS01LTgtNy41LTYtMS40IDEtMS40IDIuOC0uMyA0LjZhOSA5IDAgMCAwIDQu'
    b'MSAyLjhsLTIuOSAzLjdzLTYuMy0uOC03LjUtNy40Yy0uNS0yLjUuNy03LjEgNC45LTguNSA1'
    b'LjMtMS44IDguNiAyIDEwLjMgNS4yIDIuMiA0LjQgMy4yIDEyLjQgOS40IDExLjIgMy40LS43'
    b'IDUtNS42IDUtNy45bDIuNC0yLjYgMy43IDEuMmguMXoiLz4KICAgIDx1c2UgeGxpbms6aHJl'
    b'Zj0iI2FkLWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4'
    b'KC0xIDAgMCAxIDkwNy41IDApIi8+CiAgICA8cGF0aCBkPSJtNDYxLjEgMjc5IDEwLjgtMTEu'
    b'N3MxLjYtMS4zIDEuNi0zLjRsLTIuMi40LS41LTEuMi0uMS0xLjEgMy0uN1YyNjBsLjMtMS4z'
    b'LTMuMi4yLjMtMS40LjUtMSAxLjktLjRoMS45YzEuOC0zLjQgOS4yLTYuNCAxNC40LTEgMy44'
    b'IDQgMyAxMS4yLTIgMTMuMmE2LjMgNi4zIDAgMCAxLTYuOC0xLjFsMi00YzIuNyAxLjcgNS0u'
    b'MyA0LjgtMi40LS4yLTIuNy0yLTQuMy00LjMtNC41LTIuMy0uMi00IDEtNSAzLS42IDEuMy0u'
    b'MyAyLjItLjUgMy42LS4yIDEuNSAwIDIuMy0uNSAzLjhhOC44IDguOCAwIDAgMS0yLjQgMy42'
    b'bC0xMSAxMi00MyA0Ni40LTMuMi0zIDQzLjItNDYuN3oiLz4KICAgIDxwYXRoIGZpbGw9IiNm'
    b'ZmYiIGQ9Ik00MjkuNSAyODNzMi43IDEzLjQgMTEuOSAzMy41YzQuNy0xLjcgNy40LTIuOCAx'
    b'Mi40LTIuOCA0LjkgMCA3LjYgMSAxMi4zIDIuOEExNzEgMTcxIDAgMCAwIDQ3OCAyODNsLTI0'
    b'LjItMzEtMjQuNCAzMXoiLz4KICAgIDxwYXRoIGQ9Im00NTYuMSAyNjIuNCAxNi44IDIxLjdz'
    b'LTIuMiAxMC41LTkgMjYuM2MtMi43LS42LTUtMS4xLTcuOC0xLjN2LTQ2Ljd6bS00LjcgMC0x'
    b'Ni44IDIxLjdzMi4yIDEwLjUgOSAyNi4zYzIuNy0uNiA1LTEuMSA3LjgtMS4zdi00Ni43eiIv'
    b'PgogIDwvZz4KICA8ZyBmaWxsPSIjZDUyYjFlIj4KICAgIDxwYXRoIGZpbGw9IiNmZWRmMDAi'
    b'IGQ9Ik0zMjIuMyAxNzUuNWg1Mi42VjIyOGgtNTIuNnoiLz4KICAgIDxwYXRoIGQ9Ik0zMjku'
    b'NyAxNzUuNWg3LjhWMjI4aC03Ljh6bTE1IDBoNy44VjIyOGgtNy44em0xNSAwaDcuOVYyMjho'
    b'LTcuOXoiLz4KICA8L2c+CiAgPGcgZmlsbD0iI2Q1MmIxZSIgc3Ryb2tlPSIjZDUyYjFlIiBz'
    b'dHJva2Utd2lkdGg9Ii41Ij4KICAgIDxwYXRoIGZpbGw9IiNmZWRmMDAiIHN0cm9rZT0ibm9u'
    b'ZSIgZD0iTTI2NC4zIDI3My41Yy4xIDEgLjUgMi42IDEuNCA0LjMgMSAxLjUuNiAxLjQgMi43'
    b'IDMuOGExNS4zIDE1LjMgMCAwIDAgNCAyLjkgMzIuNyAzMi43IDAgMCAwIDE1IDIuNmMyLjct'
    b'LjEgNC44LS40IDYuNi0uN2E3MSA3MSAwIDAgMSAxMS0uNmMxLjUgMCAzIC4zIDQuNy42IDMu'
    b'NS43IDcgMiA3IDJ2LTU0LjdoLTUyLjZWMjcxbC4yIDIuNHoiLz4KICAgIDxwYXRoIHN0cm9r'
    b'ZS13aWR0aD0iLjMiIGQ9Im0yNzAuNCAyODMuMSAyLjUgMS41IDMuNCAxLjJ2LTUyLjJoLTUu'
    b'OXptMjkuMiAyLjR2LTUxLjloLTUuOHY1Mi44bDUuOC0uN3ptMTEuNy01MS45aC01Ljh2NTIu'
    b'MWMxLjkuMiAzLjguNiA1LjggMXYtNTN6bS0yMy40IDBWMjg3cy0zLjguMi01LjggMHYtNTMu'
    b'NHoiLz4KICA8L2c+CiAgPGcgdHJhbnNmb3JtPSJtYXRyaXgoLjY0IDAgMCAuNjQgMCAxNiki'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZlZGYwMCIgZD0iTTU4NS41IDQwMi40YTIwLjggMjAuOCAw'
    b'IDAgMS0yLjIgNi42Yy0xLjUgMi4zLTEgMi4zLTQuMyA2YTI2LjMgMjYuMyAwIDAgMS0xMyA3'
    b'IDUxLjggNTEuOCAwIDAgMS0xNi42IDEuNmMtNC4zLS4yLTcuNS0uNy0xMC4zLTEtMy44LS42'
    b'LTYuNy0uOS0xMS0xYTYyLjkgNjIuOSAwIDAgMC02LjIgMCA4My4zIDgzLjMgMCAwIDAtMTgu'
    b'MyA0LjJWMzQwaDgyLjJ2NTguNWwtLjMgMy44eiIvPgogICAgPGcgaWQ9ImFkLWIiPgogICAg'
    b'ICA8cGF0aCBmaWxsPSIjZDUyYjFlIiBkPSJtNTI0LjYgMzQ3LS42LjItLjguOGMtLjQuNC0u'
    b'Ny41LTEuMi44bC0uNi41Yy0uMy4zIDAgLjYtLjMgMS0uMS40LS4zLjYtLjYgMS0uNC40LS43'
    b'LjUtMSAxbC0xLjIgMS0uMy4xaC0uNmMtLjQuMi0uNS42LS44LjhsLjMuNi44IDEuNGMuMi4z'
    b'LjIuNy41LjguNS4yLjkuMiAxLjMuMS44LjIgMS4zLjIgMiAuNWwxLjUuOGMuNS4zLjguNCAx'
    b'LjMuNWgxLjh2LjNsMiAxYTEuNyAxLjcgMCAwIDAtLjEuNGMtLjEuMy0uMi43LS4xLjguNiAx'
    b'LjkgMS4yIDMgMS41IDMuMi42LjIuOC45IDEuMSAxLjVsLS4zLjNjLS42LjYtMS4yIDEtMS43'
    b'IDEuOC0uNyAxLjItMS4yIDEuMi0uMyAyLjhsMS41IDIuNGMuNC43LjYgMS4yLjggMiAuMi43'
    b'LjMgMS4yLjMgMmwxIC4zLjctLjYuNi0xLjJ2LTFjLS4yLS4xLS4zLS40LS4yLS43IDAtLjQu'
    b'NS0uMy43LS42LjMtLjUtLjQtLjgtLjctMS4xLS42LS43LTEuNC0uOS0xLjYtMS45IDAtLjIg'
    b'MC0uNC40LS43bDItMS44Yy4yLjEuNi4yIDEgLjFsMS4zLjRjLjYuMi45IDAgMS4yIDBoLjRs'
    b'LjEuNmMuMSAxLS4xIDMgLjIgMy41bC4zLjYuMi42djJsLS4yIDEuN2MwIC40LS4yLjctLjUg'
    b'MS0uMi40LS42LjQtMSAuN3YxbDEuMS41IDEuMy4zLjctLjMuMS0uNi41LS41Yy40LS4yLjgg'
    b'MCAuOS0uMS4yLS4zIDAtLjQgMC0uOCAwLS42LS4yLTEtLjMtMS42YTExLjggMTEuOCAwIDAg'
    b'MS0uMS0yLjhjMC0uNiAwLTEgLjItMS41LjEtMSAuNC0xLjQuNi0yLjIuMy0xIC4zLTEuNi40'
    b'LTIuNWEyNC40IDI0LjQgMCAwIDAgMTAuMS0uNmMuOC43IDEuNyAxLjIgMi43IDEuNnYxYzAg'
    b'LjMgMCAuNC4yLjdsLjMuM2MuMyAwIC41IDAgLjctLjIuMi0uMi4yLS40LjItLjd2LS43aDEu'
    b'OHYxLjFjLjEuMy4zLjQuNS40YS43LjcgMCAwIDAgLjYgMGMuMy0uMi4yLS42LjMtMXYtLjds'
    b'MS0uNGE1LjEgNS4xIDAgMCAxIDAgLjlsLS4zLjljLS4yLjYtLjUuOC0uOCAxLjQtLjQuNi0u'
    b'NSAxLTEgMS41bC0uNi43LS42LjktLjkgMWMtLjcuNi0xLjIuMi0yIC45bC0uMyAxIDEuNC42'
    b'IDEuMy4yLjQtLjJjMC0uMyAwLS42LjMtLjguMi0uMy40LS4zLjctLjQuNCAwIC44IDAgMS0u'
    b'Mi40LS4zLjQtMSAuNy0xLjVhMTIuNyAxMi43IDAgMCAxIDMtMy45bDEuNy0xLjRjLjItLjQu'
    b'NS0uNS41LTFsLS4yLS42LS4yLTFjMS41LjcgMSAuNyAxLjIgMS40LjMuNiAwIDEgLjEgMS43'
    b'LjEuOC41IDEuMS41IDEuOS4xLjktLjEgMS40LS4zIDIuMy0uMS44LS4xIDEuMy0uNSAyYTMu'
    b'OCAzLjggMCAwIDEtMS4xIDEuNWwtLjYuNS0uMSAxIDEuMS40IDEuNi40LjQtLjNjLjItLjcg'
    b'MC0xLjcuNC0xLjcuNC0uMS43IDAgLjgtLjN2LS43bC43LTQuNS40LTEuOS40LTEuN2MuNy0y'
    b'LS4yLTIuMy0xLTMuNi0uNS0uNy0uNy0xLS43LTEuNVYzNjJhNDIuNyA0Mi43IDAgMCAxIDAt'
    b'Mi44bC40LS4yYzEuMi0uNyAxLjctLjkgMi40LTIuNWEzLjQgMy40IDAgMCAwIC4zLTEuNXYt'
    b'MWwtLjQtMWEzLjIgMy4yIDAgMCAwLS42LS44Yy0uNy0xLTEuNy0xLjEtMi43LTEuNS0xLjUt'
    b'LjUtMi41LS40LTQtLjUtMS44LS4yLTIuNy0uMi00LjQgMC0yIDAtMy4xLjQtNS4xLjdsLTQu'
    b'OS40Yy0yLjMgMC00LjQtLjUtNS44LS40LTIuNC4yLTIuNS44LTYuMiAxLjFhNjcgNjcgMCAw'
    b'IDEtMy44LjJsLTIuMi0uN2MuOS0uMyAxLjEtLjUgMS41LTEgLjMtLjQuMi0uNy42LTEuMWwu'
    b'Ny0xYTIuMiAyLjIgMCAwIDAtLjktLjRoLTFhMyAzIDAgMCAwLTEuMi4zbC0uOC42LTIuMi0x'
    b'LjJhOC44IDguOCAwIDAgMC0zLS45em0yIDExLjh6Ii8+CiAgICAgIDxnIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iI2ZlZGYwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIj4KICAgICAgICA8cGF0'
    b'aCBkPSJtNTY4LjggMzU5LjUtLjguM2MtLjkuNC0xLjYuNC0yLjYuNS0yLjYuMi00LjMtMS4x'
    b'LTctLjktMS40LjEtMiAxLjItMy41IDEuNmE5LjMgOS4zIDAgMCAxLTEuNy4ybC41LTFzLTEu'
    b'Mi4zLTIgLjNhNy41IDcuNSAwIDAgMS0xLjYtLjJsMS0xLTEuMy0uMmE0IDQgMCAwIDEtMS0u'
    b'NyAyMC41IDIwLjUgMCAwIDAgMS43LS4zYzEuNS0uNCAyLTEuMiAzLjktMS40IDEuMSAwIDMg'
    b'MCA3LjYuOCAzIC41IDQuNC4yIDUuNS0uMy44LS4zIDEtMSAxLjEtMS44LjEtLjgtLjQtMS40'
    b'LS44LTEuOC0uMSAwLS41LS4zLTEuMS0uNCIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNmY2Q5'
    b'MDAiIHN0cm9rZS1saW5lY2FwPSJidXR0IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNTI0Ljgg'
    b'MzUwLjZjLS41IDAtLjkgMC0xLjMuMy0uNS4zLS42LjctMSAxLjEuNS4xLjguNCAxLjIuMy40'
    b'IDAgLjUtLjIuOC0uNS4zLS40LjQtLjcuNC0xLjJoLS4xeiIvPgogICAgICAgIDxwYXRoIGQ9'
    b'Ik01MzYgMzYzLjhhMTMuNiAxMy42IDAgMCAwIDEgMi4zYy4yLjggMCAxLjIuMiAydjEuNm02'
    b'LjgtNy0uMyAxLjMtMSAzLjV2LjdtLTExLTRjLjkuMi42IDMuMyAxLjkgNCIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZS1saW5lY2FwPSJidXR0IiBkPSJtNTYwLjEgMzY5LjguNC0uM2E4LjIg'
    b'OC4yIDAgMCAwIDIuNy0xLjgiLz4KICAgICAgICA8cGF0aCBkPSJNNTUyLjQgMzY4YzMuNS0u'
    b'OSA1LjktMi42IDcuNi0yLjltLTQtMS41aC44YzEuNS0uMyAxLjcuNiAyLjcgMS4yIDEuOSAx'
    b'IDIuMSAyLjMgNC4zIDMuNGwuNC4xLjguNCIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNmY2Q5'
    b'MDAiIHN0cm9rZS1saW5lY2FwPSJidXR0IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNTE3Ljcg'
    b'MzU0LjVoLjdsLjgtLjJjLjMgMCAuNSAwIC43LjIuMiAwIC4yLjEuMy4zIDAgLjIuMi4zLjEu'
    b'NSAwIC4yLS4zLjQtLjYuNC0uMiAwLS40IDAtLjUtLjNhLjUuNSAwIDAgMSAwLS40IDEgMSAw'
    b'IDAgMS0uOSAwIDEgMSAwIDAgMS0uNi0uNXoiLz4KICAgICAgPC9nPgogICAgICA8cGF0aCBm'
    b'aWxsPSIjMDA2NWJkIiBkPSJtNTI1LjEgMzY0LjItMi0uOWMuNC0uMi43LS4yIDEtLjUuMy0u'
    b'NC4zLS44LjUtMS4zcy4yLTEgLjctMS40Yy4zLS4yLjgtLjIgMS4xLS4xLjQgMCAuOC40Ljku'
    b'NyAwIC42LS4yIDEtLjMgMS41IDAgLjYtLjMuOS0uMiAxLjQgMCAuNC4yLjYuNCAxbC0yLS40'
    b'em0tMSAxYS42LjYgMCAxIDEgLjcuNS42LjYgMCAwIDEtLjctLjZ6bS0xLjctMTYuNmgtLjJj'
    b'LS40LS40LS40LS44LS42LTEuMmE0IDQgMCAwIDEtLjMtMS4ydi0yYzAtLjMgMC0uNi0uMi0u'
    b'OSAwLS4yLS40LS4zLS4zLS40IDAtLjEuMyAwIC40IDAgLjQgMCAuNi4xIDEgLjQuMy4zLjUu'
    b'Ni42IDFsLjQgMS41LjMuOC41LjYtLjcuOC0uOS42em0zLjYgMTAuNiAyLjIgMWE5LjIgOS4y'
    b'IDAgMCAwIDMuNS0zLjhjLjktMS44IDEtMi43IDEuNC00LjRsLTEuOC0uNWgtLjRjLS41IDEu'
    b'OC0uNyAyLjctMS42IDQuMi0uOCAxLjMtMS43IDIuMy0yLjYgM2wtLjcuNXptNSAxOC4yLjgt'
    b'MS4zIDEuNC0xLjFoLjRhOC43IDguNyAwIDAgMS0uNSAyLjhsLS40IDEtLjUuNWMtLjUtLjgt'
    b'MS4zLTEuMy0xLjMtMnptMzMgMS44IDEuNC42IDEuNS45di41bC0xLjUuMmE4LjQgOC40IDAg'
    b'MCAxLTEuMyAwaC0xbC0uNi0uNGMuNS0uNy44LTEuNiAxLjQtMS44em0tOS44LTIgMS40LjUg'
    b'MS41IDFjMCAuMS4xLjMgMCAuNGE5IDkgMCAwIDEtMi43LjNsLTEtLjEtLjctLjNjLjYtLjcu'
    b'OS0xLjcgMS41LTEuOHptLTE3LjQgMi4xIDEuNS41IDEuNSAxdi41YTkgOSAwIDAgMS0yLjgu'
    b'MmgtMWwtLjYtLjRjLjUtLjcuOC0xLjYgMS40LTEuOHptLTktMjkuOGMtLjYtLjMtMS0xLS42'
    b'LTEuNi4xLS4yLjQtLjIuNi0uNC4yLS4zLjEtLjUgMC0uOGwtLjEtMS0uMi0xYzAtLjYgMC0x'
    b'IC40LTEuNi4yLS4zLjctLjYuOC0uNi4yLjEgMCAuNSAwIC44IDAgLjUuMS43LjMgMS4ybC43'
    b'IDEuM2MuMi42LjQuOC40IDEuNCAwIC41IDAgLjctLjIgMS4yYTIgMiAwIDAgMS0uNi44IDIg'
    b'MiAwIDAgMS0uOC40IDEuMSAxLjEgMCAwIDEtLjYgMHoiLz4KICAgIDwvZz4KICAgIDx1c2Ug'
    b'eGxpbms6aHJlZj0iI2FkLWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHk9IjM2LjYi'
    b'Lz4KICA8L2c+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNzAzZDI5IiBzdHJva2Ut'
    b'd2lkdGg9Ii41IiBkPSJNMjY0LjEgMTc1LjVoNTIuNlYyMjhoLTUyLjZ6bTU4LjIgMGg1Mi42'
    b'VjIyOGgtNTIuNnptLTU4IDk4Yy4xIDEgLjUgMi42IDEuNCA0LjMgMSAxLjUuNiAxLjQgMi43'
    b'IDMuOGExNS4zIDE1LjMgMCAwIDAgNCAyLjkgMzIuNyAzMi43IDAgMCAwIDE1IDIuNmMyLjct'
    b'LjEgNC44LS40IDYuNi0uN2E3MSA3MSAwIDAgMSAxMS0uNmMxLjUgMCAzIC4zIDQuNy42IDMu'
    b'NS43IDcgMiA3IDJ2LTU0LjdoLTUyLjZWMjcxbC4yIDIuNHptMTEwLjQgMGExMyAxMyAwIDAg'
    b'MS0xLjQgNC4zYy0xIDEuNS0uNiAxLjQtMi43IDMuOGExNS40IDE1LjQgMCAwIDEtNCAyLjlj'
    b'LTEuMy43LTIuMyAxLTQuNCAxLjZhMzIuNiAzMi42IDAgMCAxLTEwLjYgMWMtMi43LS4xLTQu'
    b'OC0uNS02LjUtLjdhNzEgNzEgMCAwIDAtNy4yLS42IDQwLjUgNDAuNSAwIDAgMC0zLjkgMGMt'
    b'MS41IDAtMyAuMy00LjcuNi0zLjUuNy03IDItNyAydi01NC44SDM3NXYzNy41bC0uMiAyLjR6'
    b'Ii8+Cjwvc3ZnPgo=', 'AD')

AD = b64_AD
index.append("AD")
index.append("AND")
index.append("Andorra")
catalog["AD"] = AD
catalog["AND"] = AD
catalog["Andorra"] = AD
country["Andorra"] = ('AD', 'AND', 0)
lookup["AD"] = ('AD', 'AND', 'Andorra', 0)
lookup["Andorra la Vella Andorra"] = ('AD', 'AND', 'Andorra', 0)
lookup["AND"] = ('AD', 'AND', 'Andorra', 0)
lookup["Andorra"] = ('AD', 'AND', 'Andorra', 0)
details["AD"] = {"continent":"Europe","capital":"Andorra la Vella","currency":"Euro","web":".ad","lang":"ca","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_AE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWFlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwNzMyZiIgZD0i'
    b'TTAgMGg2NDB2MTYwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMTYwaDY0MHYx'
    b'NjBIMHoiLz4KICA8cGF0aCBkPSJNMCAzMjBoNjQwdjE2MEgweiIvPgogIDxwYXRoIGZpbGw9'
    b'InJlZCIgZD0iTTAgMGgyMjB2NDgwSDB6Ii8+Cjwvc3ZnPgo=', 'AE')

AE = b64_AE
index.append("AE")
index.append("ARE")
index.append("United Arab Emirates")
catalog["AE"] = AE
catalog["ARE"] = AE
catalog["United Arab Emirates"] = AE
country["United Arab Emirates"] = ('AE', 'ARE', 0)
lookup["AE"] = ('AE', 'ARE', 'United Arab Emirates', 0)
lookup["Abu Dhabi United Arab Emirates"] = ('AE', 'ARE', 'United Arab Emirates', 0)
lookup["ARE"] = ('AE', 'ARE', 'United Arab Emirates', 0)
lookup["United Arab Emirates"] = ('AE', 'ARE', 'United Arab Emirates', 0)
details["AE"] = {"continent":"Asia","capital":"Abu Dhabi","currency":"UAE Dirham","web":".ae","lang":"Ar-AE | fa | en | hi | ur","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_AF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1hZiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRo'
    b'PSIxcHQiPgogICAgPHBhdGggZD0iTTAgMGg2NDB2NDgwSDB6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjMDkwIiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQyNi43eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2JmMDAwMCIgZD0iTTIxMy4zIDBoMjEzLjR2NDgwSDIxMy4zeiIvPgogIDwvZz4KICA8ZyBm'
    b'aWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2JkNmIwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIuNSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMSAyNy4zKSBzY2FsZSgxLjA2MzQ2'
    b'KSI+CiAgICA8cGF0aCBkPSJNMzE5LjUgMjI1LjhoOC4zYzAgMy4yIDIgNi42IDQuNSA4LjVo'
    b'LTE2YzIuNS0yLjIgMy4yLTUgMy4yLTguNXoiLz4KICAgIDxwYXRoIHN0cm9rZT0ibm9uZSIg'
    b'ZD0ibTI2Ni43IDE3OC41IDQuNiA1IDU3IC4yIDQuNi01LTE0LjYtLjMtNy01aC0yM2wtNi42'
    b'IDUuMWgtMTV6Ii8+CiAgICA8cGF0aCBkPSJNMjkwIDE3Mi43aDE5LjdjMi42LTEuNCAzLjUt'
    b'NS45IDMuNS04LjQgMC03LjQtNS4zLTExLTEwLjUtMTEuMi0uOCAwLTEuNy0uNi0xLjktMS4z'
    b'LS41LTEuNi0uNC0yLjctMS0yLjYtLjQgMC0uMyAxLS43IDIuNC0uMy44LTEuMSAxLjUtMiAx'
    b'LjYtNi40LjMtMTAuNiA1LTEwLjUgMTEuMS4xIDQgLjYgNi40IDMuNCA4LjR6Ii8+CiAgICA8'
    b'cGF0aCBzdHJva2U9Im5vbmUiIGQ9Ik0yNTcuNyAyNDIuOEgzNDJsLTcuNS02LjFoLTY5LjRs'
    b'LTcuNSA2LjF6Ii8+CiAgICA8cGF0aCBkPSJtMjk2LjQgMjE5LjcgMS41IDQuNmgzLjVsLTIu'
    b'OC00LjZoLTIuMnptLTIgNC42IDEgNC42aDRsLTEuNS00LjZoLTMuNXptNyAwIDIuOCA0LjZo'
    b'NS45bC00LjYtNC42aC00LjF6bS0zNC41IDEwLjRjMy4xLTIuOSA1LjEtNS4zIDUuMS04Ljho'
    b'Ny42YzAgMiAuNyAzLjEgMS44IDNoNy43di00LjVoLTUuNnYtMjQuN2MtLjItOC44IDEwLjYt'
    b'MTMuOCAxNS0xMy44aC0yNi4zdi0uOGg1NS4zdi44SDMwMWM3LjkgMCAxNS41IDcuNSAxNS42'
    b'IDEzLjh2N2gtMWwtLjEtNi45YzAtNi45LTguNy0xMy4zLTE1LjctMTMuMS02IC4xLTE1LjQg'
    b'NS45LTE1LjMgMTN2Mi4ybDE0LjMuMS0uMSAyLjUgMi4yIDEuNCA0LjUgMS40djMuOGwzLjIu'
    b'OXYzLjdsMy44IDEuN3YzLjhsMi41IDEuNS0uMSAzLjkgMy4zIDIuM2gtNy44bDQuOSA1LjVo'
    b'LTcuM2wtMy42LTUuNWgtNC43bDIuMSA1LjRoLTVsLTEuMy01LjRoLTYuMnY1LjhIMjY3em0y'
    b'Mi4yLTE1djQuNmg1LjNsLTEtNC42SDI4OXoiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9'
    b'Ik0yODkuNCAyMTEuN2gzLjN2Ny42aC0zLjN6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBk'
    b'PSJNMjg0LjcgMjE5LjhoMy4ydi01LjZjMC0yLjQgMi4yLTQuOSAzLjItNSAxLjIgMCAyLjkg'
    b'Mi4zIDMgNC44djUuOGgzLjR2LTE0LjRoLTEyLjh2MTQuNHptMjUuNiAzLjNoNHYzLjJoLTR6'
    b'bS0yLjQtNS4zaDR2My4xaC00em0tMy45LTUuNGg0djMuMWgtNHptLTMuMy00LjVoNHYzLjFo'
    b'LTR6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJtMjk4IDIxOS44IDQuMi4yIDcuMyA2'
    b'LjR2LTMuOGwtMi41LTEuOHYtM2wtMy42LTJ2LTMuM2wtMy41LTEuMlYyMDdsLTEuNy0xLjUt'
    b'LjEgMTQuNHoiLz4KICAgIDxwYXRoIGQ9Ik0zMTUuNCAyMTAuM2gxdjcuMWgtMXoiLz4KICAg'
    b'IDxnIGlkPSJhZi1hIj4KICAgICAgPHBhdGggZD0iTTI1Ny4zIDE4Ni41Yy0xLjItMi0yLjcg'
    b'Mi44LTcuOCA2LjMtMi4zIDEuNi00IDUuOS00IDguNyAwIDIgLjIgMy45IDAgNS44LS4xIDEu'
    b'MS0xLjQgMy44LS41IDQuNSAyLjIgMS42IDUuMSA1LjQgNi40IDYuNyAxLjIgMSAyLjItNS4z'
    b'IDMtOCAxLTMgLjYtNi43IDMuMi05LjQgMS44LTIgNi40LTMuOCA2LTQuNmwtNi4zLTEweiIv'
    b'PgogICAgICA8cGF0aCBmaWxsPSIjYmYwMDAwIiBkPSJNMjU3IDIwMS45YTEwIDEwIDAgMCAw'
    b'LTEuNi0yLjYgNi4xIDYuMSAwIDAgMC0yLjQtMS44IDUuMyA1LjMgMCAwIDEtMi40LTEuNSAz'
    b'LjYgMy42IDAgMCAxLS44LTEuNSA1LjkgNS45IDAgMCAxIDAtMmwtLjMuM2MtMi4zIDEuNi00'
    b'IDUuOS00IDguN2EyOC41IDI4LjUgMCAwIDAgMCAyLjNjLjIuNS4zIDEgLjYgMS4zbDEuMS44'
    b'IDIuNy43YTcuMSA3LjEgMCAwIDEgMi42IDIgMTAuNSAxMC41IDAgMCAxIDEuOCAyLjZsLjIt'
    b'LjhjLjgtMi43LjctNS45IDIuNi04LjV6Ii8+CiAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9'
    b'Ik0yNDkuOCAxOTIuNGMtLjUgMy4zIDEuNCA0LjUgMy4yIDUuMSAxLjguNyAzLjMgMi42IDQg'
    b'NC40bS0xMS43IDEuNWMuOCAzIDIuOCAyLjYgNC42IDMuMiAxLjguNyAzLjcgMyA0LjUgNC44'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Im0yNTUuNiAxODQuNSAxLS42IDE3LjcgMjkuOS0xIC42LTE3'
    b'LjctMzB6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNTcuNSAxODMuM2EyIDIgMCAxIDEtNCAwIDIg'
    b'MiAwIDEgMSA0IDB6bTE1LjItMjRoNy4ydjEuNmgtNy4yem0wIDMuMWg3LjJ2MTMuOGgtNy4y'
    b'em0tLjQtNWg4Yy4yLTIuNy0yLjUtNS42LTQtNS42LTEuNi4xLTQuMSAzLTQgNS42eiIvPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjYmQ2YjAwIiBzdHJva2U9Im5vbmUiIGQ9Ik0yOTIuNiAxNTUu'
    b'OGMtMS41LjYtMi43IDIuMy0zLjQgNC4zLS43IDItMSA0LjMtLjYgNi4xIDAgLjcuMyAxLjEu'
    b'NSAxLjUuMi4zLjQuNS42LjUuMyAwIC42IDAgLjctLjNsLjItLjhjLS4xLTItLjEtMy44LjMt'
    b'NS40YTcuNyA3LjcgMCAwIDEgMy00LjRjLjMtLjIuNC0uNS41LS43YTEgMSAwIDAgMC0uMy0u'
    b'N2MtLjQtLjMtMS0uNC0xLjUtLjF6bS4yLjRjLjQtLjIuOCAwIDEgLjFsLjEuMmMwIC4xIDAg'
    b'LjItLjMuNGE4LjIgOC4yIDAgMCAwLTMuMSA0LjYgMTYuNyAxNi43IDAgMCAwLS4zIDUuNiAx'
    b'IDEgMCAwIDEtLjIuNnMwIC4xLS4yIDBjMCAwLS4yIDAtLjQtLjNhMy45IDMuOSAwIDAgMS0u'
    b'NC0xLjJjLS4zLTEuOCAwLTQgLjctNiAuNy0xLjggMS44LTMuNCAzLTR6Ii8+CiAgICAgIDxw'
    b'YXRoIGZpbGw9IiNiZDZiMDAiIHN0cm9rZT0ibm9uZSIgZD0iTTI5NS4yIDE1Ny43Yy0xLjUu'
    b'Ny0yLjUgMi4zLTMgNC4yYTEzLjYgMTMuNiAwIDAgMC0uMyA1LjljLjIgMS4zIDEgMiAxLjYg'
    b'MiAuMy4xLjYgMCAuOC0uMy4yLS4zLjMtLjYuMi0xLS40LTEuNi0uNS0zLjQtLjMtNS4xLjMt'
    b'MS43IDEtMy4yIDIuMi00LjEuMy0uMy41LS41LjUtLjhhLjguOCAwIDAgMC0uMi0uNmMtLjQt'
    b'LjMtMS0uNC0xLjUtLjJ6bS4yLjVjLjQtLjIuOC0uMSAxIDBsLjEuMy0uMy40YTYuNSA2LjUg'
    b'MCAwIDAtMi40IDQuNGMtLjMgMS44LS4xIDMuNy4yIDUuMi4xLjQgMCAuNiAwIC44bC0uNS4x'
    b'Yy0uMyAwLTEtLjUtMS4yLTEuNy0uMy0xLjctLjItMy45LjMtNS43LjUtMS44IDEuNS0zLjMg'
    b'Mi44LTMuOHoiLz4KICAgICAgPHBhdGggZD0iTTI3Mi4zIDE4Ny40aDh2MTFoLTh6bS41IDE3'
    b'LjRoNy43djIuNGgtNy43em0tLjIgNC4xaDh2OC43aC04em0tLjYgMTAuNWg4Ljd2NC45SDI3'
    b'MnptMS4xLTE2LjZoN2wxLjQtMi40aC05LjZsMS4yIDIuNHptOS40LTguNi4xLTZoNC44YTE3'
    b'LjQgMTcuNCAwIDAgMC00LjkgNnoiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgZD0iTTI3'
    b'My42IDE5Ni43YzAgMS4zIDEuNS44IDEuNS4xdi01LjZjMC0xIDIuNC0uOCAyLjQtLjF2NmMw'
    b'IDEgMS43LjkgMS42IDB2LTdjMC0yLjItNS41LTIuMS01LjUtLjF2Ni43em0wIDEzLjNoNS43'
    b'djdoLTUuN3oiLz4KICAgICAgPHBhdGggZD0iTTI3Ny4yIDIxM2gydjFoLTJ6bS0zLjUgMGgy'
    b'djFoLTJ6bTItM2gxLjV2M2gtMS41em0wIDRoMS41djMuMWgtMS41ek0yNDQgMTM5Yy40IDUu'
    b'NS0xLjQgOC42LTQuMyA4LjEtLjgtMyAxLTUuMSA0LjMtOC4xem0tNi41IDEyLjNjLTIuNi0x'
    b'LjMtLjctMTEuNS4zLTE1LjguNyA1LjUgMiAxMy4zLS4zIDE1Ljh6Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0yMzguNCAxNTEuOGM0LjQgMS41IDgtMy4yIDkuMS04LjctMy42IDUtOS41IDUtOSA4'
    b'Ljd6bS0zLjMgNS4xYy0zLjQtLjktMS40LTExLjctLjctMTYgLjcgNC41IDMuMSAxNC41Ljcg'
    b'MTZ6bTEuMi0uM2MuMi0zLjcgMy45LTIuNyA2LjUtNC43LS41IDItMiA1LjItNi41IDQuN3pt'
    b'LTQuMiA1Yy0zLjQtMS0xLjQtMTIuNi0xLjYtMTcuNCAxIDQuMiA0LjIgMTYuMyAxLjYgMTcu'
    b'NHptMS42LS41YzIuOC45IDYuNS0xIDYuOC00LjMtMi41IDEuNy02LjMuNC02LjggNC4zeiIv'
    b'PgogICAgICA8cGF0aCBkPSJNMjI5LjUgMTY2LjdjLTMuMi4zLTEuOC05LjYtMS44LTE4Ljgg'
    b'MS4yIDguNiA0LjUgMTYuNSAxLjggMTguOHoiLz4KICAgICAgPHBhdGggZD0iTTIzMC43IDE2'
    b'Ni4zYzIuMiAxIDYuMS0uNyA3LjItNC40LTQgMS43LTYuNiAwLTcuMiA0LjR6bTI1LjYtMjIu'
    b'MmMtLjYgNC45LTIuNiA3LjctNS41IDcuMi0uOC0zIDEuNi01IDUuNS03LjJ6bS03LjggMTIu'
    b'NGM0LjkuNyA2LjYtMyAxMC03LjktNC43IDMuNC0xMC4yIDQtMTAgOHoiLz4KICAgICAgPHBh'
    b'dGggZD0iTTI0NyAxNTZjLTIuNi0zLjIgMC03LjMgMi0xMC43LS40IDUuMSAxLjMgOC0yIDEw'
    b'Ljd6bS0xIDUuM2MtLjQtMy4yIDUtMy45IDcuNC01LjYtLjkgMS44LTIgNi43LTcuNSA1LjZ6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNDQuOCAxNjEuM2MtMy43LS40LTIuMi02LjcuNS0xMC4x'
    b'LTEuMSA0LjggMiA4LjEtLjUgMTAuMXoiLz4KICAgICAgPHBhdGggZD0iTTI0MiAxNjYuNmMt'
    b'NC4yLTItMS41LTcuMiAwLTEwLjMtLjYgNC4xIDIuOCA3LjIgMCAxMC4yeiIvPgogICAgICA8'
    b'cGF0aCBkPSJNMjQyLjggMTY2YzIuMiAzIDYuNS0uOCA3LjQtNS4yLTMuNyAzLjEtNi41IDIu'
    b'Ni03LjQgNS4zem0tOS42IDIwLjNjLS40LTQuMyAyLjgtMTIgLjUtMTYuMi0uMy0uNi43LTIu'
    b'MSAxLjQtMS4yIDEgMS41IDIgNS43IDIuNSA0LjEuNC0xLjcuNS00LjYgMi01LjIgMS0uMyAy'
    b'LjMtLjYgMS45IDEtLjQgMS40LTEuMiAzLjQtLjMgMy41LjUgMCAyLTIgMy4zLTMgMS0uOCAy'
    b'LjYuNiAxIDEuOC00LjggNC05LjUgNS45LTEyLjMgMTUuMnptLTguNyA2NC41Yy0uNiAwLTEu'
    b'My0uMy0uNi42IDUuNyA3IDcuMyA5IDE1LjYgOCA4LjMtMS4xIDEwLjMtMy40IDE2LjItNi43'
    b'YTE0LjYgMTQuNiAwIDAgMSAxMS4yLTFjMS42LjUgMi42LjUgMS40LS43LTEuMi0xLjEtMi41'
    b'LTIuNy00LTMuOGExNy41IDE3LjUgMCAwIDAtMTIuNy0yLjdjLTYgMS0xMS4xIDQuOS0xNy4y'
    b'IDYuNGEyNSAyNSAwIDAgMS05LjkgMHptNDcuOCAxMi41YzEgLjIgMS43IDIuMiAyLjMuOS44'
    b'LTIuMy4yLTQtLjgtMy45LTEuMi4zLTMuMSAzLTEuNSAzeiIvPgogICAgICA8cGF0aCBzdHJv'
    b'a2U9Im5vbmUiIGQ9Ik0yMjAuNiAxODNjLTEuMi0xLjQtLjktMS44IDEtMS45IDEuNCAwIDQu'
    b'MiAxIDUuMy4xIDEtLjcuNS0zLjcgMS01IC4yLS45LjctMiAyLS4yIDMuNiA1LjggOCAxMi44'
    b'IDEwIDE5LjYgMSAzLjggMCA5LjgtMy40IDEzLjggMC0zLjQtMS4yLTUuNy0yLjctOC42LTIt'
    b'My43LTkuMS0xNC0xMy4yLTE3Ljl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMzUuNSAyMTMuNGM0'
    b'IDAgNC43LTUuMyA0LjctNi44LTIgLjQtNS40IDMuNy00LjcgNi44em0zNC41IDUxLjljMi44'
    b'LjYgMi43LTYuMi0uMi05LjEgMS4zIDQuNC0yIDguNC4xIDl6bS0xLjItLjFjLjIgMy4yLTgt'
    b'LjQtMTAtMyA0LjggMi4xIDkuOC40IDEwIDN6bS0zLjUtNC42Yy4zIDMuMS03IC4zLTkuMy0y'
    b'LjEgNC45IDEuNiA5LS41IDkuMyAyem0xLjMuNGMyLjkuNyAyLjQtNi40LS40LTguOCAxLjQg'
    b'NC43LTEuOCA4LjEuNCA4Ljh6bS0zLTQuM2MyLjkuNyAxLjItNS40LS45LTcuOC40IDQuNC0x'
    b'IDcuNSAxIDcuOHptLTEuNSAwYy4zIDMuMi01LjQuOC03LjYtMi4zIDQuOCAxLjUgNy4zLS4z'
    b'IDcuNiAyLjN6bS0xLjUtMi41YzEuOC0xLjMtLjEtNC44LTMuNy00LjYuNCAyLjEgMS42IDUu'
    b'OSAzLjcgNC42em0xNCAxNC43Yy4xIDMuMi04IDEuNi0xMC42LTEuOCA1LjIgMSAxMC4zLS44'
    b'IDEwLjUgMS44em0tMzIuNC01LjhjLjMgMy4yLTguNi0uNC0xMC44LTMuNCA0LjcgMS42IDEw'
    b'LjUuOCAxMC44IDMuNHptNS40IDEuM2MxLjktMS4zLTEuOS00LjctNS01LjUuNCAyLjEgMyA2'
    b'LjggNSA1LjZ6bS42IDIuM2MuMiAyLjktOS41IDEuMy0xMi0xLjQgOC4zIDEuNSAxMS43LTEu'
    b'MSAxMiAxLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNTIuOCAyNjguNmMxIDIuNy04LjMgMi0x'
    b'MS42LjUgNS4zIDAgMTAuOC0yLjQgMTEuNi0uNXoiLz4KICAgICAgPHBhdGggZD0iTTI1Ny4x'
    b'IDI3MC42YzEgMi40LTcuNiAyLjQtMTEuOCAxIDUuNiAwIDEwLjgtMy40IDExLjgtMXptNi4z'
    b'IDEuM2MxLjYgMi45LTcuNiAzLjEtMTAuNSAxLjcgNS4yLS43IDkuMi00IDEwLjUtMS43em0t'
    b'MTAuNy00LjljLTIuOSAxLjgtMi43LTMuNi01LTcuMyAzLjYgMy4zIDcgNS42IDUgNy4zeiIv'
    b'PgogICAgICA8cGF0aCBkPSJNMjU3LjkgMjY5Yy0yLjQgMi4xLTQuNC01LjMtNi42LTkuNSAz'
    b'LjYgNCA4LjggNy43IDYuNiA5LjR6bTYuOCAyYy0yIDIuNC04LTctMTAuMi0xMiAzLjMgMy45'
    b'IDExLjggMTAgMTAuMiAxMnptLTUuOCA3LjJjLTEgMy42LTE2LjItMy40LTE4LTcuMSA4Ljgg'
    b'NC42IDE4LjIgMy42IDE4IDd6bS00OC43LTczLjhjLS40LS41LTEuNCAwLTEuMiAxLjEuMyAx'
    b'LjUgMi41IDkuMiA2LjMgMTEuOCAyLjcgMiAxNyA1LjEgMjMuNCA2LjUgMy42LjcgNi41IDIu'
    b'NSA4LjkgNS4zYTk0LjQgOTQuNCAwIDAgMC0zLTkuOGMtMS4yLTMtNC40LTYuMi03LjgtNi4z'
    b'LTYuMS0uMy0xNC4xLS44LTIwLTMuM2ExNiAxNiAwIDAgMS02LjctNS4zeiIvPgogICAgICA8'
    b'cGF0aCBkPSJNMjQ1LjUgMjM0LjljMiAxLjQgNC4xLTMuNyAxLjctOC42LS4xIDQuNy0zLjgg'
    b'Ni4zLTEuNyA4LjZ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNDcuNCAyMzkuNmMyLjcuOCAzLjUt'
    b'NCAxLjgtNy44LjMgNC4xLTQuMyA2LjYtMS44IDcuOHoiLz4KICAgICAgPHBhdGggZD0iTTI0'
    b'OS41IDI0My40YzIuNiAxLjMgMy41LTMuNiAxLjctNy4xLjIgNC41LTMuNyA1LjktMS43IDd6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNDguNCAyNDMuN2MtMSAzLTctMi43LTgtNS44IDMuNyAz'
    b'LjcgOC43IDMuMiA4IDUuN3oiLz4KICAgICAgPHBhdGggZD0iTTI0NS43IDIzOWMtMS4yIDMt'
    b'OC43LTUtMTAuNC04LjcgMy43IDMuNyAxMS4yIDYuNSAxMC40IDguNnoiLz4KICAgICAgPHBh'
    b'dGggZD0iTTI0NC4yIDIzNC4zYy0xLjIgMy41LTkuMy01LjgtMTEuNy05LjEgNCAzLjYgMTIu'
    b'NiA2LjYgMTEuNyA5LjF6bS0uMy0zLjRjMy0uNi0uMS0zLTMuNy02LjktLjEgNC4xLjUgNyAz'
    b'LjcgNi45eiIvPgogICAgICA8cGF0aCBkPSJNMjM5IDIyOC41YzEuMy0xLjMtMS4xLTEuOS00'
    b'LjEtNS4zLS41IDIuMyAyLjggNi41IDQuMiA1LjN6bTE0IDE1LjJjMS42IDEgMi42LTIuMy43'
    b'LTUuMi0uNSAzLjItMi4xIDQtLjcgNS4yem0tMzQuMi0yMC4zYy0zLjMgMi04LjYtNi0xMC05'
    b'LjMgMi45IDMuOCAxMC42IDcuMiAxMCA5LjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMjEuNyAy'
    b'MjhjLTEuOSAyLTcuNy0zLjUtOS43LTYuMyAzIDIuNyAxMC41IDMgOS43IDYuM3oiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTIyNC44IDIzMi4yYy0uNiAyLjgtOS0zLjUtMTEtNi41IDMuNiAzLjUg'
    b'MTEuNiAzLjIgMTEgNi41eiIvPgogICAgICA8cGF0aCBkPSJNMjIzLjUgMjM1LjNjLTEuMyAy'
    b'LjUtOC4yLTMuOC05LjktNyA0LjMgMy42IDExIDQuNSAxMCA3ek0yMjAgMjIzYzIuMS0yLjMg'
    b'MS4yLTMuNC0uNC03LS44IDMuNy0yLjEgNS4yLjQgN3ptMi45IDQuM2M0IC4yIDAtNC42LTEt'
    b'OC43LjQgNC42LTEgOC4zIDEgOC43eiIvPgogICAgICA8cGF0aCBkPSJNMjI1LjQgMjMxLjFj'
    b'Mi43LS42IDItNC41LS4yLTkuMi41IDUuMS0yLjMgOCAuMiA5LjJ6bS0xIDcuN2MtMSAzLTgu'
    b'OC00LTEwLTYuOCA0IDMuNCAxMC43IDQuNSAxMCA2Ljh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0y'
    b'MjkuMSAyNDMuNmMtMS4xIDMtOS4zLTMuMi0xMS44LTYuNiA0LjkgNCAxMi40IDMuNiAxMS44'
    b'IDYuNnoiLz4KICAgICAgPHBhdGggZD0iTTIzMy45IDI0OC41Yy0xLjMgNC4zLTkuOS0yLjYt'
    b'MTIuNC02IDUuNCA0LjIgMTMgMyAxMi40IDZ6bS04LTExYzIuMyAxLjEgMy4yLTUuNCAxLjkt'
    b'MTAuMSAwIDUtNC43IDguOC0yIDEweiIvPgogICAgICA8cGF0aCBkPSJNMjI5LjggMjQyLjdj'
    b'Mi44LjggMi02LjMtLjUtMTEtLjMgNC43LTIuMyA5IC41IDExem01IDQuOWMzIC4xIDEtNi4x'
    b'LTEuNi05LjYuNCA0LjUtMSA5IDEuNiA5LjZ6bS01LjUgMi42Yy0xIDEuNi0zLjItMS4zLTct'
    b'My41IDMuNCAxIDcuNCAyIDcgMy41em0tMS44LTUyLjdjMy0yLjIuNy02LjIgMC0xMC0xIDMu'
    b'Ni0zLjQgOC40IDAgMTB6bTAgNS4zYy00LjUtLjUtMy44LTYuMS00LTkuNyAxLjQgNC45IDUg'
    b'NS43IDQgOS44em0uNi0uN2MzLjctLjIgMy41LTQuNCAzLjctOC42LTEuOSAzLjktNCA0LjUt'
    b'My43IDguNnoiLz4KICAgICAgPHBhdGggZD0iTTIyOCAyMDcuM2MtMyAuMy00LjQtMi42LTUt'
    b'NyAyLjcgNC4xIDUuMSAyLjggNSA3em0xLS4zYzMuNy41IDMtMy44IDMtNy0xLjIgMy00LjIg'
    b'NC0zIDd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMjMuMiAyMDUuMmMuMyAyLjggMi4xIDcuNiA1'
    b'IDYuNSAxLjEtMy40LTIuNi00LjEtNS02LjV6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMjkgMjEy'
    b'Yy0xLjItMi40IDMtMy43IDMuOC02LjkuNSA0LjYuMSA3LjYtMy44IDd6bS0xMS45LTI5LjJj'
    b'Mi4zLTIuNC4zLTYuNC0uNC0xMC4yLTEgMy42LTIuNSA4LjQuNCAxMC4yem0wIDQuNmMtNCAu'
    b'NS01LTcuNy01LjUtMTEuMyAxLjQgNC45IDYgNyA1LjUgMTEuNHptLjggMGMyLjgtMS41IDIu'
    b'Mi00LjcgMy03LTEuOCAyLjktMy42IDMuMy0zIDd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMTcg'
    b'MTkyLjhjLTQuMS4zLTYuNi04LjgtNi44LTEyLjQgMS4zIDQuOSA3LjQgNy41IDYuOSAxMi40'
    b'em0uOS0uMmM0LS45IDMuNS0zLjUgMi45LTcuNi0xLjMgNC4yLTMuNSAzLjMtMi45IDcuNnoi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTIxNyAxOThjLTQuNi44LTQuMy02LjYtOC0xMS45IDMuMiA0'
    b'IDkgOSA4IDExLjl6bTEtLjNjMy42LjIgNC01LjEgMy44LTcuMy0uOSAyLjItNSA0LjItMy43'
    b'IDcuNHoiLz4KICAgICAgPHBhdGggZD0iTTIwOS44IDE5Mi4zYzEuNyA1LjcgNC4yIDExLjQg'
    b'Ny4yIDExIDEuNS0zLjMtMi45LTMuNy03LjItMTF6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMTgu'
    b'MSAyMDIuNGMtMS4yLTIuNSAzLTMuNyAzLjgtNi45LjUgNC42LjEgNy42LTMuOCA2Ljl6bS03'
    b'LjEtMy42YzIuNSA1LjEgMy42IDExIDcgMTAuMSAxLjMtNC0zLjgtNC44LTctMTAuMXoiLz4K'
    b'ICAgICAgPHBhdGggZD0iTTIxOC43IDIwOGMtMS41LTIuOCAyLjctMy43IDMuOC03LjQuNSA0'
    b'LjggMCA4LjMtMy44IDcuM3ptNy4yLTM0LjVjMi40LjYgNS0yLjEgNC4xLTYuMi0yLjguNi00'
    b'IDMuMi00LjEgNi4yem0tNy45LTIuMWMuMiAxLjIgMS43IDEuMyAxLjItLjRhNS4zIDUuMyAw'
    b'IDAgMSAwLTMuNCA3LjUgNy41IDAgMCAwIDAtNC42Yy0uNC0xLTEuOC0uNC0xLjIuNC42Ljku'
    b'NyAyLjguMiAzLjctLjYgMS4zLS40IDMtLjIgNC4zem0yMi45IDE2Yy0xIDEuMy0yLjkuNC0x'
    b'LjQtMS41IDEuMi0xLjUgMy0yLjggMy00LjQuMi0yIDEuMy01IDIuNC02LjEgMS4xLTEuMSAy'
    b'LjQuNCAxLjIgMS4yLTEuMy44LTIuMiA0LjQtMi4xIDUuOC0uMSAyLTIgMy41LTMuMSA1em0t'
    b'My0yLjNjLTEgMS40LTIuNC41LTEuNi0xLjcuNy0xLjUuOC0zLjUgMS42LTQuNiAxLjItMS43'
    b'IDMtMy4xIDQuMS00LjIgMS4yLTEgMiAwIDEgMWEyNyAyNyAwIDAgMC0zLjMgNGMtMS40IDIu'
    b'Mi0uOCA0LTEuOCA1LjV6bS0xNS43LTcuMmMtLjEgMiAxLjUgMi40IDEuNC0uNCAwLTMtMi4y'
    b'LTUuOC0xLTEwLjMuOC0yLjIuOC02LjMuNC04LjQtLjQtMi4yLTItLjgtMS4zLjkuNiAyLS4x'
    b'IDUuNi0uNiA3LjUtMS41IDUuNCAxLjIgOCAxIDEwLjd6bTQuMy0xMWMtLjIgMS45LTEuOCAy'
    b'LTEuMy0uNS40LTIgLjQtMy42IDAtNS4zLS42LTIuMS0uNC01LjcgMC03LjIuNS0xLjYgMi0u'
    b'NyAxLjQuNWE5LjkgOS45IDAgMCAwLS4zIDUuOWMuNiAyIC41IDQuOC4yIDYuN3pNMjEwLjkg'
    b'MjA0Yy44LjkgMiAuMyAxLTEtMS0xLS43LTEuMi0xLjMtMi40LS42LTEuNC0uNS0yLjEtMS4y'
    b'LTMtLjctMS0xLjYgMC0xIC43LjggMSAuNiAxLjYgMSAyLjUgMSAxLjUuNyAyLjMgMS41IDMu'
    b'MnptMjAuNCAyNC42YTguNiA4LjYgMCAwIDEgNC40IDYuNyAxNiAxNiAwIDAgMCAyIDcuMWMt'
    b'Mi0uNS0zLTMuNy0zLjMtNi44LS4zLTMuMi0yLTQuNS0zLTd6bTUuMSA1LjljMS43IDMuMSA0'
    b'IDQuMyA0LjIgNi42LjIgMi43LjQgMi44IDEuMSA1LjQtMi0uNS0yLjUtLjctMy00LjctLjMt'
    b'Mi44LTIuNi00LjctMi4zLTcuM3oiLz4KICAgICAgPHBhdGggc3Ryb2tlPSJub25lIiBkPSJN'
    b'Mjg5IDI2My4zYzEgMS44IDIgNC41IDQgNCAwLTEuMy0yLjEtMi4zLTQtNHptMyAuNmMzLjcg'
    b'MS42IDcgMS4yIDcuNSAzLjYtMy42LjQtNS0xLTcuNi0zLjZ6bS0xNi4xLTEyLjdhMTQgMTQg'
    b'MCAwIDEgNSA3LjcgMjkgMjkgMCAwIDAgMy42IDcuOCAxMyAxMyAwIDAgMS01LjMtNy40Yy0u'
    b'Ny0zLTEuNi01LjMtMy4zLTh6bTMuMSAwYzIuOCAyLjIgNS40IDQuOCA2LjIgNy45LjggMi45'
    b'IDEuMyA1LjEgMy4yIDgtMy0xLjktNC4xLTQuNy01LTcuOC0uNy0zLTIuNS01LjItNC40LTh6'
    b'bTkuMiA3LjNhMS4xIDEuMSAwIDAgMSAuNy0xLjIgMzMuNCAzMy40IDAgMCAxIDIuNi0uOGMx'
    b'LS4zIDEuNi40IDEuNi45djJjMCAuNy0uMi44LS43LjktLjcuMS0xLjcuMi0yLjQuNy0uNi40'
    b'LTEuMi4xLTEuNS0uNWwtLjMtMnptMTAuNiAwYzAtLjYtLjItMS4xLS42LTEuMmE1LjQgNS40'
    b'IDAgMCAwLTIuNC0uNGMtMSAwLTEuMS4yLTEuMS42djIuMWMwIC44IDAgLjguNCAxIC43IDAg'
    b'MS44IDAgMi41LjYuNS4zIDEgMCAxLjEtLjZsLjEtMi4xeiIvPgogICAgPC9nPgogICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjYWYtYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iLTYw'
    b'MCIgdHJhbnNmb3JtPSJzY2FsZSgtMSAxKSIvPgogICAgPGcgc3Ryb2tlPSJub25lIj4KICAg'
    b'ICAgPHBhdGggZD0iTTMyOC41IDI4Ni42YzAgMS4yLjIgMi4yIDEgMy4xYTE5IDE5IDAgMCAw'
    b'LTEzLjggMS4xYy0xLjguOC00LTEtMS45LTIuNyAzLTIuMyA5LjctMSAxNC43LTEuNXptLTU3'
    b'LjUgMGE3IDcgMCAwIDEtLjQgM2M0LjQtMS43IDkuMS0uMiAxMy42IDEuNiAzIDEuMyAzLjMt'
    b'MSAyLjgtMS43YTYuNSA2LjUgMCAwIDAtNS0yLjloLTExem0zLjgtMjEuN2MtMS4zLS41LTIu'
    b'NyAwLTQgMS40LTQuMyA0LjItOS40IDguMy0xMy41IDExLjYtMS41IDEuMy0zIDMuNyAzLjQg'
    b'NiAuMy4yIDUgMiA4IDIgMS4zIDAgMS4zIDEuOCAxIDIuMy0uNSAxLS4xIDEuNC0xLjEgMi4z'
    b'LTEuMSAxIDAgMi4xIDEgMS4zIDMuNi0zLjIgOS42LTEuMSAxNS4zLjcgMS40LjQgMy44LjMg'
    b'My44LTEuNiAwLTIgMS41LTMuNCAyLjQtMy41IDIuNC40IDE0IC41IDE3LjUuMSAyLS4zIDIu'
    b'MiAyLjkgMy4zIDQgLjguOSAzLjcgMS4xIDUuOC4yIDQtMS44IDEwLTEuOCAxMi41IDAgMSAu'
    b'NyAxLjkgMCAxLjMtLjctLjgtMS0uNy0xLjYtMS4xLTIuNC0xLTItLjItMi40LjgtMi41IDEx'
    b'LTEuNSAxNC42LTUuMiAxMS4yLTguMy00LjQtMy44LTkuMi03LjctMTMuNC0xMi4yLTEuMi0x'
    b'LjItMi0xLjctNC4zLS43YTY2LjUgNjYuNSAwIDAgMS0yNS4zIDUuOSA3NiA3NiAwIDAgMS0y'
    b'NC42LTUuOHoiLz4KICAgICAgPHBhdGggZmlsbD0iI2JkNmIwMCIgZD0ibTMyNi42IDI2NS41'
    b'LTEuNi40Yy05IDMuMi0xNy4yIDUuNC0yNS43IDUuNC04LjMgMC0xNy0yLjQtMjQuOS01LjZh'
    b'Mi4zIDIuMyAwIDAgMC0xLjUgMGMtLjUuMS0xIC40LTEuMy43YTExNS41IDExNS41IDAgMCAx'
    b'LTExLjggMTAuM2MtLjcuNS0uNiAxLjguNSAyLjIgOC4zIDMgMTYuNCA4LjUgMzkuNiA4LjMg'
    b'MjMuNS0uMiAzMS44LTUuNiAzOS4yLTguMS41LS4yIDEtLjUgMS4zLTFhMSAxIDAgMCAwIC4x'
    b'LS44IDIgMiAwIDAgMC0uNi0uOGMtNC4zLTMuNS04LjgtNi4zLTExLjgtMTAuNC0uMy0uNS0u'
    b'OS0uNi0xLjUtLjV6bTAgLjVjLjUgMCAxIDAgMS4xLjMgMyA0LjMgNy43IDcgMTEuOSAxMC41'
    b'bC40LjdhLjUuNSAwIDAgMSAwIC40Yy0uMS4zLS42LjYtMSAuNy03LjYgMi42LTE1LjcgOC0z'
    b'OSA4LjItMjMuMi4yLTMxLjItNS4zLTM5LjUtOC4zLS44LS40LS43LTEuMi0uNC0xLjQgNC4y'
    b'LTMuMiA4LjItNi44IDExLjgtMTAuNGEyLjUgMi41IDAgMCAxIDEuMS0uNmgxLjJhNjggNjgg'
    b'MCAwIDAgMjUgNS42YzguNyAwIDE3LTIuMiAyNi01LjNhNi43IDYuNyAwIDAgMSAxLjUtLjR6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNjkuNyAxMTQuNmMwLTEuNCAyLTEuNSAxLjguNC0uMyAy'
    b'LjMgNC41IDguMyA0LjkgMTIgLjMgMi41LTEuNSA0LjYtMy4yIDZhNi42IDYuNiAwIDAgMS02'
    b'LjguNWMtLjktLjgtMS43LTMuMy0xLTQuMy4yLS4zIDEuMyAzLjcgMy43IDMuNyAzLjMgMCA2'
    b'LTIuNSA2LTQuNy4yLTMuOC01LjMtOS44LTUuNC0xMy42em05LjUgOS40Yy42LS40IDEuNCAx'
    b'LjMuOCAxLjctLjUuMy0xLjUtMS4zLS44LTEuOHptMS41LTMuNWMtLjMuMi0uOCAwLS43LS4y'
    b'YTEyIDEyIDAgMCAxIDMuNi0zLjNjLjQtLjIgMSAuNC44LjdhMTEgMTEgMCAwIDEtMy43IDIu'
    b'OHptMTIuNi0xMGMuMy0uNiAyLjEtMS4zIDIuNi0xLjcuNC0uNS42LjQuNC43LS4zLjctMS45'
    b'IDEuNy0yLjYgMS44LS4zIDAtLjYtLjQtLjQtLjd6bTQuMy4zYTguMyA4LjMgMCAwIDEgMi41'
    b'LTMuNGMuNS0uMyAxLjMgMCAxLjEuNGE5IDkgMCAwIDEtMi45IDMuM2MtLjMuMy0uOCAwLS43'
    b'LS4zem0tMy43IDIuN2MtLjMuMi0uMS43LjEuOC42LjIgMS41LjIgMiAwIC42LS40LjMtMi45'
    b'LS41LTEuNi0uNi44LTEgLjYtMS42Ljh6bS03LjMgNS42Yy0xLjMtMSAuNC0yLjQgMS43LTEu'
    b'NCAyLjcgMi00IDkuOC03LjYgMTMuNC0uNy43LTEuMy0xLS40LTEuOWEzMy43IDMzLjcgMCAw'
    b'IDAgNi43LTcuNmMuNC0uNS43LTEuNi0uNC0yLjV6bTE1LjMtNi42Yy4xLTEtMS42IDAtMS42'
    b'LTEuMyAwLS43IDEuOS0xLjIgMi43LS40IDEuMyAxLjQuMyAzLjctMiAzLjktMS44IDAtNSAy'
    b'LjctNC41IDMuMi41LjcgNS40IDEuMSA4LjMuNyAxLjgtLjMgMS40IDEuMy0uNCAxLjUtMS44'
    b'LjItMy4yIDAtNC44LjYtMiAuNS0yLjggMy0zLjkgNC0uMi4yLS44LS44LS42LTEuMi44LTEu'
    b'MiAyLTMgMy40LTMuNi44LS4zLTIuNC0uNC0zLjQtLjctLjgtLjItLjYtMS4zLS4zLTEuOS40'
    b'LS44IDMuNC0zLjkgNC43LTMuOCAxLjEgMCAyLjMtLjMgMi40LTF6bTUgLjJjLjYtLjUgMS0x'
    b'LjMgMS41LTEuOC4zLS4zLjkgMCAuOC44LS4xLjctMSAxLjItMS41IDEuNy0uNS4zLTEtLjQt'
    b'LjctLjd6bTYuNS0yLjNjLjkgMCAxIDEuNi4yIDEuOC0uNi4yLTEtMS43LS4yLTEuOHptLTIu'
    b'MSA1YzAgMS41LjcgMS40IDIgMS4zIDEuMyAwIDIuNCAwIDIuNC0xLjIgMC0xLjMtLjctMi41'
    b'LTEtMS42LS4xLjgtLjMgMi4yLS44IDEuNi0uNC0uNS0uMi0uNi0xIC4yLS41LjUtLjUtLjIt'
    b'LjgtLjYtLjItLjMtLjguMi0uOC40em0tOS4yIDcuMmMtLjMgMS45IDAgNC41LjkgNC41IDEu'
    b'MiAwIDMuNi00IDQuOC02LjIuNy0xLjIgMS44LTEuNCAxLjMtLjEtLjcgMS45LS42IDYgMCA3'
    b'LjIuNC42IDMtLjYgMy40LTEuNS44LTEuNy4xLTQuOC40LTYuNy4xLTEuMiAxLjMtMS41IDEu'
    b'Mi0uM2E3NS42IDc1LjYgMCAwIDAtLjEgNy41YzAgMSAyLjkgMi40IDMuMy0uNi4yLTEuOCAx'
    b'LjItMy43IDAtNS43LS44LTEuMyAxLjEtMS4yIDIuMS42LjcgMS4yLS42IDMuMi0uNSA0Ljcg'
    b'MCAyLjQtMS44IDMuOC0zLjEgMy44LTEuMiAwLTItMS41LTMtMS41cy0yLjIgMS43LTMgMS42'
    b'Yy0zLjYtLjItMS43LTUuMy0yLjgtNS40LTEuMiAwLTIuNSA1LTQgNC45LTEuNC0uMi0zLTQu'
    b'Mi0yLjMtNS44LjUtMS42IDEuNS0yIDEuNC0xem0xNi45LThjLTEuNy0xIDAtMy43LjktMi44'
    b'IDEuNiAyIDMuMiA2LjUgNC40IDYuOS43LjIuNi0zLjQgMS4xLTUgLjQtMS4zIDEuOC0uOSAx'
    b'LjYuNy0uMS41LTIgNi40LTEuOCA2LjZhNDcuMSA0Ny4xIDAgMCAxIDMuMyA3LjhjLjMgMS4y'
    b'LTEuMS40LTEuMy4yLS45LTEuNC0yLjQtNi41LTIuNC02LjJsLTEuNyA3LjdjLS4yIDEtMS43'
    b'LjgtMS4zLTEgLjMtMS40IDIuMy04LjMgMi4yLTguNmExNy4yIDE3LjIgMCAwIDAtNS02LjN6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zMjIgMTMxLjJjLS40IDAtMS4yIDEgMS4yIDEuNSAzLjEu'
    b'NiA2LjYtLjUgNy42LTMuNiAxLjMtMy43IDItNy4yIDIuNy04LjUuOC0xLjUgMS44LTEuNCAx'
    b'LTMuNi0uNS0xLjctMS41LTEuMi0xLjctLjMtLjUgMi4zLTIuNiAxMC0zLjMgMTEuMy0xLjIg'
    b'Mi42LTMuNyAzLjYtNy41IDMuMnoiLz4KICAgICAgPHBhdGggZD0iTTMyOC40IDExOWMtLjQt'
    b'LjctMS4yIDAtMSAuN2ExLjIgMS4yIDAgMCAwIDEuMiAxYy43IDAgMi4yLjEgMi4yLTEgMC0u'
    b'OC0uNy0xLjUtMS4xLS42LS41LjgtMSAuNy0xLjMgMHptLjctM2MtLjIuMiAwIDEuMS4zIDFh'
    b'NyA3IDAgMCAwIDMuMy0uOGMuMi0uMi4xLS43LS4yLS43LTEgMC0yLjYgMC0zLjQuNXptOC44'
    b'IDIuM2MuOC0xLjIgMi44LTEuMyAyIC40YTYxNC4zIDYxNC4zIDAgMCAxLTYuMyAxMi4zYy0u'
    b'OCAxLjQtMS40LjctLjgtLjQuNy0xLjQgNC45LTEyIDUuMS0xMi4zeiIvPgogICAgICA8cGF0'
    b'aCBkPSJNMzMwLjIgMTMzYy0uMi0uOC0xLjUtMi0xLjMuMi4yIDMuOCA1LjUgMi42IDcgMS4z'
    b'cy4zIDQuMyAyLjIgNC45YzEgLjMgMy0xLjEgNC0yLjQgMi43LTMuNSA0LjUtOC42IDctMTIg'
    b'MS0xLjQtLjUtMi40LTEtMS4zLTIuNCAzLjgtNS4yIDExLjYtOC4zIDEzLjYtMi41IDEuNi0x'
    b'LjctMi0xLjgtMy4yLS4xLS44LTEuMS0yLTIuNC0uOWE1LjUgNS41IDAgMCAxLTMuNyAxLjJj'
    b'LS43IDAtMS40IDAtMS43LTEuNHoiLz4KICAgICAgPHBhdGggZD0iTTMzOS42IDEyNmMwLS4z'
    b'LTEuMS0uNC0xIC43IDAgLjggMSAxIDEuMSAxIDEuNS0xLjItLjMtLjYtLjEtMS44em0tMi4z'
    b'IDQuNGMtLjMgMC0uNiAxIC4yIDEuMWwzLjktLjJjLjQgMCAuNi0uOS0uNC0uOC0xLjIgMC0y'
    b'LjctLjMtMy43IDB6bS02Mi0xNi42Yy41IDAgMS42IDEuNCAxLjUgMS45IDAgLjItMS4yIDAt'
    b'MS41LS4zLS4zLS4zLS4yLTEuNiAwLTEuNnptLTUuMyAxMC40Yy0xIC42LjIgMS43IDEgMS4y'
    b'IDIuOC0xLjkgNy0zLjggOC03LjUuMy0xLjIgMS40LTMuMSAyLjUtMy41IDEtLjUgMi42IDEu'
    b'OSAzLjYgMCAuNi0xIDIuNy43IDMuMi0uNC42LTEuMy4zLTIgLjMtMy40IDAtLjgtLjctMS0x'
    b'LjIuMy0uMi42IDAgMS4yLS4xIDEuNi0uMi4yLS42LjQtMSAuMi0uMi0uMiAwLS43LS42LTEt'
    b'LjIgMC0uNi0uMS0uOC4yLS43IDEuMy0xIDIuNS0yLjEgMS0uOS0xLTEuNC0zLjEtMi0uMy0u'
    b'MiAxLTEuNyAyLjQtMi42IDIuNC0xLjEgMC0uOC0zLTMuMi0yLjUtMS4zLjMtMS4yIDIuNy0x'
    b'IDMuNS4zIDEuMyA0IC40IDMuNyAxLjItLjYgMi43LTQuNCA1LjQtNy43IDd6bS0yMi43IDEz'
    b'LjJjLS4xLjUuNSAxLjcgMS4xIDEuOC42IDAgMS0xLjMuOC0xLjgtLjItLjMtMS44LS4zLTEu'
    b'OSAwem0zLjMgNC45Yy0uNC0uNC0xLjYuNy0uNiAxLjUuNS41IDIuNSAxLjEgMyAuMi44LTEu'
    b'Mi0uNy01LjUgMC02IC41LS41IDIuOCAyLjggNCAzIDIuNy40IDItNC42IDUtNC4yIDEuOS4y'
    b'IDIuMS0yLjIgMS44LTMuOC0uMi0xLjUtMi42LTMuNi0zLjctNC42LTEuNC0xLjItMi4xIDEt'
    b'MS4yIDEuNiAxLjIgMSAzLjMgMi45IDMuNiA0LjEuMS42LTEuNCAxLjgtMiAxLjUtMS40LS44'
    b'LTIuNi00LTMuOC00LjctLjQtLjItMS40LjMtMSAxLjMuNiAxLjEgMyAyLjcgMy4xIDMuOS4x'
    b'IDEtMSAzLjItMS44IDMuMi0uOSAwLTMtMi43LTMuNy00LS40LS41LTEuNS0uNS0xLjcuNGEy'
    b'MiAyMiAwIDAgMCAuNSA1LjVjLjIgMS42LS45IDEuNy0xLjUgMS4xem0tNC04LjZjLS40LjQu'
    b'OCAxLjIgMSAxIC40LS40IDIuMS0yLjMgMS44LTMtLjMtLjYtMi42LTItMy0xLjMtLjcgMS4x'
    b'IDIuMiAxLjcgMS43IDJhNyA3IDAgMCAwLTEuNSAxLjN6bTQuMS04LjRzLjggMi41IDEuNCAx'
    b'LjRjLjQtLjctMS40LTEuNC0xLjQtMS40em0xLjIgNGMtLjIgMC0xIC43LS41IDEgLjguNCAy'
    b'LjkuOCAyLjQtLjctLjMtLjkgMy4yIDAgMi4zLTIuNGEzLjcgMy43IDAgMCAwLTEuNy0xLjdj'
    b'LS40IDAtMS41LjUtLjguOS41LjIgMiAxLjEgMS41IDEuNy0uNy42LTEuMS0uMy0xLjktLjEt'
    b'LjQgMC0uMSAxLjItLjQgMS41IDAgLjItLjctLjQtLjktLjN6bTUuNS05LjVhMy41IDMuNSAw'
    b'IDAgMC0xLjIgMmMwIC4yLjMuNi41LjVhMy4yIDMuMiAwIDAgMCAxLjItMS45YzAtLjMtLjIt'
    b'LjgtLjUtLjZ6bTIuOC0uM2MtLjgtMSAxLTIuNiAxLjctLjUuNSAxLjMgNS41IDcuOSA2LjUg'
    b'MTAuMS44IDEuNSAwIDIuMS0uOSAxLTIuNS0zLjItNC42LTcuMi03LjMtMTAuNnptNS4yLjFj'
    b'LjktMSAyLjctMyAyLjItNC0uNC0xLTEuNS0xLTEuNy0uNy0xIDEuMy44IDEgLjUgMS40LS41'
    b'IDEtMSAxLjYtMS4zIDIuNi0uMS4zLjEuOS4zLjd6bTc3LjggMy4yYy0uNy0uNS42LTMgMS41'
    b'LTIgMi4zIDIuNyAzLjQgMTEuNiA0LjEgMTguMyAwIDAtMSAuOS0xIC43IDAtMy41LTEuNS0x'
    b'NC40LTQuNi0xN3ptLTUzLjEtOC42Yy0uOC0xLjggMS4xLTIuNCAxLjQtMS4yIDEuMyA1Ljgg'
    b'NC41IDEwLjIgNyAxNC4xLjcgMS4yIDAgMi0xLjcuOC0xLjItLjgtMi41LTMuOS0zLTQtMS4y'
    b'LS4yLTMuOCA1LTkuMSAzLjUtMS40LS40LTEuMy00LjUtMS40LTYuMyAwLS45IDEtMSAxIDAg'
    b'MCAxLjcgMCA1LjIgMi4xIDUuNCAxLjggMCA1LjYtMi40IDYuNC00LjQuOC0yLTEuOS01Ljkt'
    b'Mi43LTh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNDQuNiAxMzguNGMuNC0xLjIgNi4xLTEwLjgg'
    b'Ni45LTEyLjkuNC0xIDIgMS44LjQgMy4zLTEuNCAxLjItNS41IDgtNi4zIDEwLjQtLjQgMS0x'
    b'LjQuNS0xLS44eiIvPgogICAgICA8cGF0aCBkPSJNMzU0LjMgMTI5LjNjMS00IDMuNi42IDEu'
    b'MyAyLjgtMy40IDMuNC00LjUgOS45LTEwIDEwLjktMS40LjMtNC0uNy00LjgtMS4zLS4zLS4y'
    b'LjItMS42IDEuMS0uOSAxLjMgMSA0LjEgMS4zIDUuNi4xYTI1LjQgMjUuNCAwIDAgMCA2Ljgt'
    b'MTEuNnptLTU3IDEyLjdjLS4zLjMtMSAuMy0xLjEuNy0uMyAxLjQgMCAyLjItLjMgMy42cy0x'
    b'LjMgMS40LTEuMi4zYzAtMS40IDEuMy0zLjUuNC0zLjYtLjYtLjEtMS0uOS0uNC0xLjMgMS4x'
    b'LS43IDEuNy0uNiAyLjQtLjQuMy4xLjQuNS4yLjd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yOTYu'
    b'NSAxNDBjLTEuNCAxLjQtMi44IDEuOS00LjEgMy41LS42LjYtLjUgMS41LS45IDIuNC0uMy45'
    b'LTEuNCAxLTEuNy45LS41LS40LS40LTItMS0xLjItLjYuOS0uOSAyLTEuNyAyLS43IDAtMi0x'
    b'LjUtMS4zLTEuNSAyLjMtLjMgMi4yLTIgMy0yLjIgMS0uMSAxIDEuNSAxLjcgMS4yLjQtLjIu'
    b'Ny0yLjEgMS4yLTIuNiAxLjUtMS42IDIuNy0yLjQgNC4zLTMuNi43LS42IDEuMy41LjUgMS4y'
    b'em01LjMgNWMtMS4yLjItMSAxLjctLjYgMS44LjUuMyAxLjQuNCAxLjctMS4zLjItLjcuMyAz'
    b'LjUgMS44IDEuOSAxLTEgMy4xLjIgNC0xIC43LS45IDEtMS41LjQtMi43LS4yLS4zLTEtLjIt'
    b'MSAuNyAwIC44LS41IDEuNy0xLjMgMS42LS40LS4xLjItMS45LS4yLTIuNGEuNS41IDAgMCAw'
    b'LS43IDBjLS4zLjQuMyAyLjItLjYgMi40LTEuMi4yLS42LTEuMi0xLTEuNC0xLjctLjgtMS44'
    b'LjItMi41LjN6bTktM2MuOS0uMi42LS4yIDItMS4zLjUtLjQuNi44LjUgMS4zIDAgLjctMSAu'
    b'Mi0xLjMuOS0uNC45LS4yIDMtLjQgMy44IDAgLjQtLjguNC0uOCAwLS4yLTEgLjEtMiAwLTMu'
    b'MyAwLS40LS41LTEuMSAwLTEuM3ptLTUtMi41Yy0uMi45LS4yIDEuNi0uMiAyLjMgMCAuNSAx'
    b'IC4yIDEgLjEgMC0uOC4yLTIgMC0yLjMtLjItLjEtLjctLjMtLjgtLjF6Ii8+CiAgICAgIDxw'
    b'YXRoIGQ9Im0yOTkuNSAxMzAuMi0xLjQgNS42LTItMy44djMuOWwtNC40LTUuMiAxLjUgNS42'
    b'LTQtMy40IDIuMiAzLjgtNy00LjUgNC40IDUuMi01LjYtMi44IDQgMy40LTktMy40IDguNyA0'
    b'LjNhMjkgMjkgMCAwIDEgMTIuNi0yLjZjNC45IDAgOS4zIDEgMTIuNSAyLjZsOC44LTQuMy05'
    b'IDMuNCA0LTMuNC01LjUgMi44IDQuMy01LjItNyA0LjUgMi4yLTMuOC00IDMuMyAxLjUtNS41'
    b'LTQuMyA1LjJWMTMybC0yIDMuOC0xLjUtNS42eiIvPgogICAgPC9nPgogIDwvZz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJtMzExLjMgMjk1LS4zIDIuNmgtLjRsLS4xLTEuOGE5LjMgOS4z'
    b'IDAgMCAwLS41LTEuNiA3LjMgNy4zIDAgMCAwLS41LTEuM2wtMS0xLjQuOC0yLjJhNi42IDYu'
    b'NiAwIDAgMSAxLjUgMi40IDkuNCA5LjQgMCAwIDEgLjUgMy4ybTctNC4yYzAgLjctLjIgMS4y'
    b'LS41IDEuNS0uMi4zLS42LjYtMS4zLjdsLjQgMS41YTYuNyA2LjcgMCAwIDEgMCAyIDIyLjUg'
    b'MjIuNSAwIDAgMS0uMSAxLjNoLS40YTguMiA4LjIgMCAwIDAtLjEtMS4zIDUuNSA1LjUgMCAw'
    b'IDAtLjItMWwtLjQtMWExMC41IDEwLjUgMCAwIDAtLjctMS40bC0xLTEuNy42LTIgMSAxYy4z'
    b'LjIuNi4zIDEgLjMuOCAwIDEuMi0uNCAxLjItMS4zaC40djEuNG02LjQgNC44LS41IDIuMWMt'
    b'LjQgMC0uNi0uMy0uOC0uN2wtLjQtMS4zYTEyLjQgMTIuNCAwIDAgMS0uMS0xLjcgNCA0IDAg'
    b'MCAxLTEgLjIgMiAyIDAgMCAxLTEuMy0uNCAxLjMgMS4zIDAgMCAxLS41LTFjMC0uOS4zLTEu'
    b'Ny43LTIuMy41LS43IDEtMSAxLjUtMS4xLjUgMCAuOC4xIDEgLjRhMiAyIDAgMCAxIC4zLjl2'
    b'MmMwIC45LjEgMS41LjMgMS45IDAgLjMuMy42LjggMW0tMi0zLjVjMC0uNi0uMy0uOC0uOC0u'
    b'OGExIDEgMCAwIDAtLjYuMWMtLjIuMS0uMi4yLS4yLjMgMCAuMy4zLjUgMSAuNWwuNi0uMW04'
    b'LjcgMy0uMyAyLjZjLS41LS40LTEtMS0xLjQtMmEyNS40IDI1LjQgMCAwIDEtMS4zLTQuMSA1'
    b'Mi44IDUyLjggMCAwIDEtMS44IDUuNSAyLjkgMi45IDAgMCAxLS44Ljd2LTIuNWMuNi0uNy45'
    b'LTEuMSAxLTEuNWE3LjYgNy42IDAgMCAwIC44LTEuN2wuNS0yLjdoLjRsLjkgMi43Yy4yLjYu'
    b'NSAxLjIuOSAxLjZsMSAxLjQiLz4KICA8cGF0aCBmaWxsPSIjYmYwMDAwIiBkPSJNMzUwLjgg'
    b'MzE5LjRjLjQuNC42LjguNyAxLjJsLjQgMS42LS44LjFhNy44IDcuOCAwIDAgMC0xLTEuNSAx'
    b'OC44IDE4LjggMCAwIDAtMS4xLTEuMiA0NiA0NiAwIDAgMC0xLjctMS41IDM0LjQgMzQuNCAw'
    b'IDAgMC0yLTEuN2MtLjQtLjItLjYtLjQtLjYtLjVhMS45IDEuOSAwIDAgMS0uMy0uOCAxMS4y'
    b'IDExLjIgMCAwIDEtLjItMS42bDIuNyAyLjJhNDQuMyA0NC4zIDAgMCAxIDIuNSAyLjJsMS40'
    b'IDEuNW0tOS41LTUuOC0uMiAySDMzOGwuMy0yaDNtOC40IDguOS03LjYgMi4zLTEuMy0yIDYu'
    b'NS0yLS43LS44YTIuOCAyLjggMCAwIDAtLjktLjYgMS40IDEuNCAwIDAgMS0uNCAxIDIgMiAw'
    b'IDAgMS0xIC42IDMuNCAzLjQgMCAwIDEtMS44IDAgMiAyIDAgMCAxLTEuMy0uNyA0IDQgMCAw'
    b'IDEtLjctMi4yYzAtMSAuMy0xLjYuOS0xLjguNy0uMiAxLjggMCAzIC43YTguMSA4LjEgMCAw'
    b'IDEgMyAyLjRsMi4zIDMuMW0tNS44LTRhMy44IDMuOCAwIDAgMC0uOC0uMyAxLjEgMS4xIDAg'
    b'MCAwLS42IDAgLjcuNyAwIDAgMC0uNS4zLjUuNSAwIDAgMCAwIC42bC41LjJoLjZsLjQtLjMu'
    b'NC0uNW0tOC0xLjYtLjUgMi0zLjItLjMuNS0yIDMuMS4zbTcuNSA3LjctMS43LjRhNS4zIDUu'
    b'MyAwIDAgMS0xLjcgMCAzLjYgMy42IDAgMCAxLTEuNS0uNGMtLjMuNS0uOCAxLTEuNSAxLjJh'
    b'Ny40IDcuNCAwIDAgMS0xLjYuNmwtMS4yLjMtMS0yIDEuMS0uM2E5LjEgOS4xIDAgMCAwIDEu'
    b'My0uNGwuOS0uNS0xLS41aC0uN2EuNC40IDAgMCAwLS4yIDAgLjYuNiAwIDAgMC0uMi4zaC0u'
    b'NWMtLjUtLjgtLjYtMS41LS4zLTJzLjktLjggMi0xYTYuOCA2LjggMCAwIDEgMi42LS4yYy44'
    b'LjEgMS4zLjQgMS41LjkuMi4yLjIuNS4yLjdsLS40IDEuMmguNWEyIDIgMCAwIDAgLjYgMGwx'
    b'LjctLjMgMSAybS04IDEuOC0xLjYuM2EzIDMgMCAwIDEtMi4yLS40IDUuNSA1LjUgMCAwIDEt'
    b'MS43LTIuNmwtLjgtMi4yYTIgMiAwIDAgMC0uOC0xIDQuNiA0LjYgMCAwIDAtLjktLjVsLjYt'
    b'Mi4xYy42LjMgMSAuNiAxLjQgMWwxIDEuNy41IDEuNSAxLjEgMi4yYy4zLjMuNy40IDEgLjNs'
    b'MS43LS4yLjcgMm0tNy03LjUtMSAxLjktMy0uNyAxLTEuOSAzIC43bTEuOCA4LjQtNy41Ljct'
    b'LjQtMiA2LjItLjdhMi4zIDIuMyAwIDAgMC0uNi0uOCA4LjMgOC4zIDAgMCAwLTEtLjZsLjUt'
    b'MmMuNy40IDEuMi45IDEuNiAxLjMuMy41LjYgMS4yLjggMi4xbC40IDJtLTYgMWExNyAxNyAw'
    b'IDAgMS0yLjItLjIgMTAuNSAxMC41IDAgMCAxLTEuNy0uNSA1LjYgNS42IDAgMCAxLTEuMy40'
    b'IDkuOSA5LjkgMCAwIDEtMS43IDBoLTJhMi41IDIuNSAwIDAgMS0xLjItLjNjLS4zLS4yLS41'
    b'LS41LS44LTFhNC4xIDQuMSAwIDAgMS0xLjUgMWwtMS43LjFoLTEuN2wuMi0yLjFoMS43Yy44'
    b'IDAgMS41IDAgMi4xLS40YTIgMiAwIDAgMCAxLjMtMS44bC43LjFhMzAuMiAzMC4yIDAgMCAw'
    b'LS4xIDEuM2MwIC4zIDAgLjUuMy43LjMuMi42LjMgMSAuM2gxLjVjMSAwIDEuNiAwIDItLjIu'
    b'Ni0uMi45LS41IDEtMS4xbC4xLS40cy4zIDAgLjUtLjJsLjUtLjJ2LjRhOC45IDguOSAwIDAg'
    b'MSAwIC4zbC0uMyAxLjFhMTIuNCAxMi40IDAgMCAwIDIgLjVjLjEtLjIgMC0uNC0uMS0uN2wt'
    b'LjMtLjZhLjUuNSAwIDAgMSAuMS0uM2wuMy0uMiAxLS45LjUgMXYxbC0uMiAyLjltLTExLjMt'
    b'OC43LTIgMS4zLTEuMy0uOS0xLjQgMS0xLjktMSAxLjgtMS4zIDEuNS44IDEuNS0xIDEuOCAx'
    b'bS0zIDguMi03LjMtMS4yLjgtMiA2LjIgMWMwLS40IDAtLjctLjItMWE1LjIgNS4yIDAgMCAw'
    b'LS41LS44bDEuNi0xLjdjLjQuNi42IDEgLjcgMS42IDAgLjUtLjIgMS4yLS41IDIuMWwtLjgg'
    b'Mm0tNi4xLTEtMS42LS4zYy0uOS0uMi0xLjQtLjYtMS41LTEuMi0uMi0uNi4xLTEuNS44LTIu'
    b'OGwxLjItMmMuMy0uNS40LS45LjMtMS4yYTIuMiAyLjIgMCAwIDAtLjMtLjdsMi4yLTEuNmMu'
    b'My41LjMgMSAuMyAxLjQgMCAuNS0uMyAxLjEtLjcgMS44bC0uOCAxLjRhNS44IDUuOCAwIDAg'
    b'MC0uOSAyLjJjMCAuNC4yLjYuNS43bDEuNi40LTEuMSAybS0zLjgtOC0yLjUgMS4xLTEuOC0x'
    b'LjcgMi42LTEgMS43IDEuN20tMSA2LjZhNi44IDYuOCAwIDAgMS0xLjYgMS40IDQuMiA0LjIg'
    b'MCAwIDEtMS43LjZsLTIuNC0uMWExNC44IDE0LjggMCAwIDEtMi44LS43IDcuNyA3LjcgMCAw'
    b'IDEtMy40LTJjLS42LS44LS42LTEuNSAwLTIuMmE3IDcgMCAwIDEgMi0xLjZjLjgtLjUgMi0x'
    b'IDMuOC0xLjZsLjQuNS0yLjggMS4yYy0uNS4zLTEgLjYtMS4zIDEtLjQuNC0uMyAxIC4yIDEu'
    b'NmExMC41IDEwLjUgMCAwIDAgNi4zIDIuMmMxLjIgMCAyLS4zIDIuMy0uNy4zLS4zLjQtLjYu'
    b'NS0xbC4yLTEuNiAyLjUtMS41YTggOCAwIDAgMS0uMSAxLjUgNC40IDQuNCAwIDAgMS0xIDEu'
    b'NmwtMS4yIDEuNCIvPgo8L3N2Zz4K', 'AF')

AF = b64_AF
index.append("AF")
index.append("AFG")
index.append("Afghanistan")
catalog["AF"] = AF
catalog["AFG"] = AF
catalog["Afghanistan"] = AF
country["Afghanistan"] = ('AF', 'AFG', 0)
lookup["AF"] = ('AF', 'AFG', 'Afghanistan', 0)
lookup["Kabul Afghanistan"] = ('AF', 'AFG', 'Afghanistan', 0)
lookup["AFG"] = ('AF', 'AFG', 'Afghanistan', 0)
lookup["Afghanistan"] = ('AF', 'AFG', 'Afghanistan', 0)
details["AF"] = {"continent":"Asia","capital":"Kabul","currency":"Afghani","web":".af","lang":"Fa-AF | ps | uz-AF | tk","tz":"+04:30","altname":""}
#----------------------------------------------------------------------
b64_AG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWFnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImFnLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTc5LjcgMEg2MDN2'
    b'NTEySC03OS43eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBjbGlwLXBhdGg9InVybCgjYWctYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRl'
    b'KDc0LjcpIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLTc5Ljcg'
    b'MEg2MDN2NTEySC03OS43VjBaIi8+CiAgICA8cGF0aCBkPSJNLTc5LjYgMEg2MDN2MjA0LjhI'
    b'LTc5LjdMLTc5LjYgMFoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDcyYzYiIGQ9Ik0yMS4zIDIw'
    b'My4yaDQ4MHYxMTJoLTQ4MHYtMTEyWiIvPgogICAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0i'
    b'TTYwMyAuMVY1MTJIMjYxLjZMNjAzIDB2LjFaTS03OS43LjFWNTEyaDM0MS4zTC03OS43IDB2'
    b'LjFaIi8+CiAgICA8cGF0aCBmaWxsPSIjZmNkMTE2IiBkPSJNNDQwLjQgMjAzLjMgMzY0IDE4'
    b'NGw2NC45LTQ5LTc5LjcgMTEuNCA0MS02OS41LTcwLjcgNDFMMzMyLjMgMzdsLTQ3LjkgNjMu'
    b'OC0xOS4zLTc0LTIxLjcgNzYuMy00Ny44LTY1IDEzLjcgODMuMkwxMzguNSA3OGw0MSA2OS41'
    b'LTc3LjQtMTIuNSA2My44IDQ3LjhMODYgMjAzLjNoMzU0LjN6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'AG')

AG = b64_AG
index.append("AG")
index.append("ATG")
index.append("Antigua and Barbuda")
catalog["AG"] = AG
catalog["ATG"] = AG
catalog["Antigua and Barbuda"] = AG
country["Antigua and Barbuda"] = ('AG', 'ATG', 0)
lookup["AG"] = ('AG', 'ATG', 'Antigua and Barbuda', 0)
lookup["St. John's Antigua and Barbuda"] = ('AG', 'ATG', 'Antigua and Barbuda', 0)
lookup["ATG"] = ('AG', 'ATG', 'Antigua and Barbuda', 0)
lookup["Antigua and Barbuda"] = ('AG', 'ATG', 'Antigua and Barbuda', 0)
details["AG"] = {"continent":"Americas","capital":"St. John's","currency":"East Caribbean Dollar","web":".ag","lang":"en-AG","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_AI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1haSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHBhdGggaWQ9ImFpLWIiIGZpbGw9IiNm'
    b'OTAiIGQ9Ik0yNzEgODdjMS41IDMuNiA2LjUgNy42IDcuOCA5LjYtMS43IDItMiAxLjgtMS44'
    b'IDUuNCAzLTMuMSAzLTMuNSA1LTMgNC4yIDQuMi44IDEzLjMtMi44IDE1LjMtMy40IDIuMS0y'
    b'LjggMC04IDIuNiAyLjMgMiA1LjEtLjMgNy40LjMgMS4yIDEuNS0uNiA0LjEuNCA2LjcgMi0u'
    b'MiAxLjgtNC4zIDIuMi01LjggMS41LTUuNCAxMC40LTkuMSAxMC44LTE0LjEgMS45LS45IDMu'
    b'Ny0uMyA2IDEtMS4xLTQuNi00LjktNC42LTUuOS02LTIuNC0zLjctNC41LTcuOC05LjYtOS0z'
    b'LjgtLjctMy41LjMtNi0xLjQtMS42LTEuMi02LjMtMy40LTUuNS0xLjZ6Ii8+CiAgPC9kZWZz'
    b'PgogIDxjbGlwUGF0aCBpZD0iYWktYSI+CiAgICA8cGF0aCBkPSJNMCAwdjEyMGgzNzMuM3Yx'
    b'MjBIMzIwTDAgMFptMzIwIDBIMTYwdjI4MEgwdi00MEwzMjAgMFoiLz4KICA8L2NsaXBQYXRo'
    b'PgogIDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9Ik0wIDBoNjQwdjQ4MEgwVjBaIi8+CiAgPHBh'
    b'dGggc3Ryb2tlPSIjZmZmIiBzdHJva2Utd2lkdGg9IjUwIiBkPSJtMCAwIDMyMCAyNDBtMC0y'
    b'NDBMMCAyNDAiLz4KICA8cGF0aCBzdHJva2U9IiNjODEwMmUiIHN0cm9rZS13aWR0aD0iMzAi'
    b'IGQ9Im0wIDAgMzIwIDI0MG0wLTI0MEwwIDI0MCIgY2xpcC1wYXRoPSJ1cmwoI2FpLWEpIi8+'
    b'CiAgPHBhdGggc3Ryb2tlPSIjZmZmIiBzdHJva2Utd2lkdGg9Ijc1IiBkPSJNMTYwIDB2Mjgw'
    b'TTAgMTIwaDM3My4zIi8+CiAgPHBhdGggc3Ryb2tlPSIjYzgxMDJlIiBzdHJva2Utd2lkdGg9'
    b'IjUwIiBkPSJNMTYwIDB2MjgwTTAgMTIwaDM3My4zIi8+CiAgPHBhdGggZmlsbD0iIzAxMjE2'
    b'OSIgZD0iTTAgMjQwaDMyMFYwaDEwNi43djMyMEgwdi04MFoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJNNDI0IDE5MS44YzAgOTAuNCA5LjcgMTIxLjUgMjkuMyAxNDIuNWExNzkuNCAx'
    b'NzkuNCAwIDAgMCAzNSAzMCAxNzkuNyAxNzkuNyAwIDAgMCAzNS0zMGMxOS41LTIxIDI5LjMt'
    b'NTIuMSAyOS4zLTE0Mi41LTE0LjIgNi41LTIyLjMgOS43LTM0IDkuNWE3OC40IDc4LjQgMCAw'
    b'IDEtMzAuMy05LjUgNzguNCA3OC40IDAgMCAxLTMwLjMgOS41Yy0xMS43LjItMTkuOC0zLTM0'
    b'LTkuNXoiLz4KICA8ZyB0cmFuc2Zvcm09Im1hdHJpeCgxLjk2IDAgMCAyLjAwMiAtNDAuOCA2'
    b'Mi45KSI+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNhaS1iIi8+CiAgICA8Y2lyY2xlIGN4PSIy'
    b'ODEuMyIgY3k9IjkxLjEiIHI9Ii44IiBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQi'
    b'Lz4KICA8L2c+CiAgPGcgdHJhbnNmb3JtPSJtYXRyaXgoLS45MTYgLTEuNzcgMS43MzMgLS45'
    b'MzUgNTYzLjQgODI5KSI+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNhaS1iIi8+CiAgICA8Y2ly'
    b'Y2xlIGN4PSIyODEuMyIgY3k9IjkxLjEiIHI9Ii44IiBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiLz4KICA8L2c+CiAgPGcgdHJhbnNmb3JtPSJtYXRyaXgoLTEuMDEgMS43MTYg'
    b'LTEuNjggLTEuMDMxIDkyNS40IC0xMDMuMikiPgogICAgPHVzZSB4bGluazpocmVmPSIjYWkt'
    b'YiIvPgogICAgPGNpcmNsZSBjeD0iMjgxLjMiIGN5PSI5MS4xIiByPSIuOCIgZmlsbD0iI2Zm'
    b'ZiIgZmlsbC1ydWxlPSJldmVub2RkIi8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiM5Y2YiIGQ9'
    b'Ik00NDAgMzE1LjFhNzggNzggMCAwIDAgMTMuMyAxOS4yIDE3OS40IDE3OS40IDAgMCAwIDM1'
    b'IDMwIDE4MCAxODAgMCAwIDAgMzUtMzAgNzggNzggMCAwIDAgMTMuMi0xOS4yeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZGMzMDEiIGQ9Ik00MjEuMiAxODguMmMwIDk0LjIgMTAuMiAxMjYuNiAz'
    b'MC42IDE0OC41YTE4NyAxODcgMCAwIDAgMzYuNSAzMS4xIDE4Ni4zIDE4Ni4zIDAgMCAwIDM2'
    b'LjQtMzEuMWMyMC40LTIxLjkgMzAuNi01NC4zIDMwLjYtMTQ4LjUtMTQuOCA2LjgtMjMuMyAx'
    b'MC4xLTM1LjUgMTAtMTEtLjMtMjIuNi01LjctMzEuNS0xMC05IDQuMy0yMC42IDkuNy0zMS41'
    b'IDEwLTEyLjMuMS0yMC43LTMuMi0zNS42LTEwem00IDVjMTQgNi41IDIyIDkuNiAzMy41IDku'
    b'NGE3Ni40IDc2LjQgMCAwIDAgMjkuNi05LjRjOC40IDQgMTkuMyA5LjIgMjkuNiA5LjQgMTEu'
    b'NS4yIDE5LjQtMyAzMy40LTkuNCAwIDg5LTkuNiAxMTkuNi0yOC44IDE0MC4yYTE3NiAxNzYg'
    b'MCAwIDEtMzQuMiAyOS40IDE3NS42IDE3NS42IDAgMCAxLTM0LjMtMjkuNGMtMTkuMi0yMC42'
    b'LTI4LjctNTEuMy0yOC43LTE0MC4yeiIvPgo8L3N2Zz4K', 'AI')

AI = b64_AI
index.append("AI")
index.append("AIA")
index.append("Anguilla")
catalog["AI"] = AI
catalog["AIA"] = AI
catalog["Anguilla"] = AI
country["Anguilla"] = ('AI', 'AIA', 0)
lookup["AI"] = ('AI', 'AIA', 'Anguilla', 0)
lookup["The Valley Anguilla"] = ('AI', 'AIA', 'Anguilla', 0)
lookup["AIA"] = ('AI', 'AIA', 'Anguilla', 0)
lookup["Anguilla"] = ('AI', 'AIA', 'Anguilla', 0)
details["AI"] = {"continent":"Americas","capital":"The Valley","currency":"East Caribbean Dollar","web":".ai","lang":"en-AI","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_AL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEu'
    b'MS8iCiAgIHhtbG5zOmNjPSJodHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9ucyMiCiAgIHht'
    b'bG5zOnJkZj0iaHR0cDovL3d3dy53My5vcmcvMTk5OS8wMi8yMi1yZGYtc3ludGF4LW5zIyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMTk5OS94bGluayIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5z'
    b'b3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczppbmtzY2FwZT0i'
    b'aHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgdmVyc2lv'
    b'bj0iMS4xIgogICB3aWR0aD0iNzAwIgogICBoZWlnaHQ9IjUwMCIKICAgdmlld0JveD0iMCAw'
    b'IDcuNzc3Nzc3OCA1LjU1NTU1NTYiCiAgIGlkPSJzdmcyIgogICB4bWw6c3BhY2U9InByZXNl'
    b'cnZlIgogICBzdHlsZT0iZmlsbC1ydWxlOmV2ZW5vZGQiCiAgIGlua3NjYXBlOnZlcnNpb249'
    b'IjAuNDguMy4xIHI5ODg2IgogICBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29mX0FsYmFuaWEu'
    b'c3ZnIj48c29kaXBvZGk6bmFtZWR2aWV3CiAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgYm9y'
    b'ZGVyY29sb3I9IiM2NjY2NjYiCiAgIGJvcmRlcm9wYWNpdHk9IjEiCiAgIG9iamVjdHRvbGVy'
    b'YW5jZT0iMTAiCiAgIGdyaWR0b2xlcmFuY2U9IjEwIgogICBndWlkZXRvbGVyYW5jZT0iMTAi'
    b'CiAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwIgogICBpbmtzY2FwZTpwYWdlc2hhZG93PSIy'
    b'IgogICBpbmtzY2FwZTp3aW5kb3ctd2lkdGg9IjEzNjYiCiAgIGlua3NjYXBlOndpbmRvdy1o'
    b'ZWlnaHQ9IjY4NiIKICAgaWQ9Im5hbWVkdmlldzgiCiAgIHNob3dncmlkPSJ0cnVlIgogICBp'
    b'bmtzY2FwZTp6b29tPSIwLjk5OTk5OTk5IgogICBpbmtzY2FwZTpjeD0iMzQ0LjY0Nzc3Igog'
    b'ICBpbmtzY2FwZTpjeT0iMjQ1LjMyODAzIgogICBpbmtzY2FwZTp3aW5kb3cteD0iLTkiCiAg'
    b'IGlua3NjYXBlOndpbmRvdy15PSIzNSIKICAgaW5rc2NhcGU6d2luZG93LW1heGltaXplZD0i'
    b'MSIKICAgaW5rc2NhcGU6Y3VycmVudC1sYXllcj0ic3ZnMiIKICAgaW5rc2NhcGU6c25hcC1n'
    b'cmlkcz0idHJ1ZSIKICAgc2hvd2d1aWRlcz0iZmFsc2UiPjxpbmtzY2FwZTpncmlkCiAgICAg'
    b'dHlwZT0ieHlncmlkIgogICAgIGlkPSJncmlkMjk4NSIgLz48L3NvZGlwb2RpOm5hbWVkdmll'
    b'dz48bWV0YWRhdGEKICAgaWQ9Im1ldGFkYXRhMTkiPjxyZGY6UkRGPjxjYzpXb3JrCiAgICAg'
    b'ICByZGY6YWJvdXQ9IiI+PGRjOmZvcm1hdD5pbWFnZS9zdmcreG1sPC9kYzpmb3JtYXQ+PGRj'
    b'OnR5cGUKICAgICAgICAgcmRmOnJlc291cmNlPSJodHRwOi8vcHVybC5vcmcvZGMvZGNtaXR5'
    b'cGUvU3RpbGxJbWFnZSIgLz48ZGM6dGl0bGUgLz48L2NjOldvcms+PC9yZGY6UkRGPjwvbWV0'
    b'YWRhdGE+CiA8ZGVmcwogICBpZD0iZGVmczQiPjxjb2xvci1wcm9maWxlCiAgICAgbmFtZT0i'
    b'Q29hdGVkLUZPR1JBMzktLUlTTy0xMjY0Ny0yOjIwMDQtIgogICAgIHhsaW5rOmhyZWY9Ii91'
    b'c3Ivc2hhcmUvY29sb3IvaWNjL0Fkb2JlX0lDQ19Qcm9maWxlc18oZW5kLXVzZXIpLTIwMTEv'
    b'Q29hdGVkRk9HUkEzOS5pY2MiCiAgICAgaWQ9ImNvbG9yLXByb2ZpbGUzNzUyIiAvPjxzdHls'
    b'ZQogICAgIHR5cGU9InRleHQvY3NzIgogICAgIGlkPSJzdHlsZTYiIC8+PC9kZWZzPgogPHBv'
    b'bHlnb24KICAgcG9pbnRzPSIyLjc5NjU0LDIuMDA0NDkgMi43OTY1NCwwLjAwNTA1MTE4IC0w'
    b'LjAwMjA2NjkzLDAuMDA1MDUxMTggLTAuMDAyMDY2OTMsMi4wMDQ0OSAiCiAgIHRyYW5zZm9y'
    b'bT0ibWF0cml4KDIuNzc5MTYwNSwwLDAsMi43Nzg1NTc0LDAuMDA1NzQ0MzMsLTAuMDE0MDM0'
    b'OTkpIgogICBpZD0iXzE0ODE3MTQyNCIKICAgc3R5bGU9ImZpbGw6I2U0MWUyMDtmaWxsLW9w'
    b'YWNpdHk6MTtmaWxsLXJ1bGU6bm9uemVybyIgLz48cGF0aAogICBzdHlsZT0iZmlsbDojMDAw'
    b'MDAwO2ZpbGwtcnVsZTpldmVub2RkIgogICBkPSJtIDMuMzM0Mzc1MSwxLjA4MDA0ODIgYyAt'
    b'MC4wNTQwMiwtOS4xMDZlLTQgLTAuMTQzNjc1OCwwLjAxNzIyMiAtMC4xNDE2NjY3LDAuMDU4'
    b'NjggLTAuMTUwNDY1NSwtMC4wMjU3ODggLTAuMTY2MTMzMSwwLjAzNjM2MyAtMC4xNTcyOTE2'
    b'LDAuMDkxNjY3IDAuMDE0MzE2LC0wLjAyMTk0OCAwLjAzMTc0NywtMC4wMzM4NjQgMC4wNDUx'
    b'MzksLTAuMDM2MTExIDAuMDIwMDY0LC0wLjAwMzMzIDAuMDQxMDYsMC4wMDMxNSAwLjA2MjUs'
    b'MC4wMTYzMTkgMC4wMjE0NDEsMC4wMTMxNyAwLjA0NTA2MiwwLjAzNDQyMiAwLjA1NTU1Niww'
    b'LjA0NzU2OSAtMC4wNTMxMDUsMC4wMTI2OTYgLTAuMDk0MTMsMC4wMDQ1IC0wLjEzNTc2Mzks'
    b'LTAuMDAyNzggLTAuMDIwNTI0LC0wLjAwMzU5IC0wLjA0OTI0NSwtMC4wMTUxMzYgLTAuMDY2'
    b'MzE5LC0wLjAyNzA4MyAtMC4wMTcwNzQsLTAuMDExOTQ5IC0wLjAyMjQ1LC0wLjAyMzE5NSAt'
    b'MC4wNDkzMDYsLTAuMDUwNjk0IC0wLjAzMTY2MywtMC4wMzI0MjIgLTAuMDY1MzYyLC0wLjAy'
    b'MzI5MyAtMC4wNTQ4NjEsMC4wMjcwODMgMC4wMjQyODQsMC4wNDY3ODggMC4wNjQ4NTEsMC4w'
    b'Njc2NTEgMC4xMTU5NzIyLDAuMDc2MDQyIDAuMDI0NiwwLjAwNDA0IDAuMDYxMjQ0LDAuMDEy'
    b'ODA3IDAuMTAyNzc3OCwwLjAxMjg0NyAwLjA0MTUzNCw0LjQ0ZS01IDAuMDg4MTY5LC0wLjAw'
    b'NiAwLjExMzU0MTcsLTYuOTQ0ZS00IC0wLjAxNTI0MywwLjAwOTU3IC0wLjAzMjQ5MiwwLjAy'
    b'NjA2OSAtMC4wNjY2NjcsMC4wMzI2MzkgLTAuMDM0NzUzLDAuMDA2NjggLTAuMDg3NTg5LC0w'
    b'LjAyMDY2NiAtMC4xMTk3OTE2LC0wLjAyODEyNSAwLjAwNDA5LDAuMDI3MDk1IDAuMDM4MjY3'
    b'LDAuMDUyNDI0IDAuMTA1NTU1NSwwLjA2NTYyNSAwLjExMDU3MjQsMC4wMjQwNzcgMC4yMDI0'
    b'NTMxLDAuMDQyMzc1IDAuMjYzMTk0NCwwLjA3NTM0NyAwLjA2MDc0MSwwLjAzMjk3MiAwLjA5'
    b'OTAzOCwwLjA3NDI1MiAwLjEyNjM4ODksMC4xMDY1OTcyIDAuMDU0NDI5LDAuMDY0MzY4IDAu'
    b'MDU3MjkyLDAuMTEzNzgwMyAwLjA2MDc2NCwwLjEyNDY1MjcgMC4wMTExOTgsMC4xMDI4NDEx'
    b'IC0wLjAyNDY2MiwwLjE2MDY5MDggLTAuMDkxMzE5LDAuMTc4NDcyMiAtMC4wMzMzMjksMC4w'
    b'MDg4OSAtMC4wOTI1MzIsLTAuMDA3ODUgLTAuMTE0MjM2MSwtMC4wMzMzMzMgLTAuMDIxNzA1'
    b'LC0wLjAyNTQ3NyAtMC4wNDI4MjMsLTAuMDY5MjY5IC0wLjAzNjgwNiwtMC4xMzc4NDcyIDAu'
    b'MDA1ODUsLTAuMDI2OTAzIDAuMDM2NjE0LC0wLjA5Njk3OSAwLjAxMDQxNywtMC4xMTE0NTgz'
    b'IEMgMy4yNDE0Njk2LDEuNDk4NzU5NiAzLjA5NDkxNzYsMS40MzEzMDI1IDIuOTg4ODg5LDEu'
    b'MzkxMTU5MiAyLjk1OTkwOTYsMS4zODAxODc1IDIuOTM2MDM2MiwxLjQxOTU3NDIgMi45MjY3'
    b'MzYyLDEuNDM0OTA5MiAyLjc0NjYxMjgsMS40MTI5NzM5IDIuNTg0MjEzOCwxLjI5MTA4MzUg'
    b'Mi41MTExMTEzLDEuMTYxMjk4MiBjIC0wLjA0OTc4OSwtMC4wODgzOTUgLTAuMTMxODUsMS44'
    b'MjRlLTQgLTAuMTE4MDU1NiwwLjA4MzY4IDAuMDIyMjcsMC4wOTMxOTYgMC4wOTMyNzgsMC4x'
    b'NjA1NzY5IDAuMTc4NDcyMiwwLjIwODMzMzMgMC4wODc0MzksMC4wNDgxNDYgMC4xOTY3MzIy'
    b'LDAuMDk1NTIyIDAuMzA3MjkxNywwLjA5MzA1NiAwLjA1OTU2MywwLjAxMTI2OCAwLjA1ODk3'
    b'NSwwLjA4ODMyNyAtMC4wMTI1LDAuMTAyNzc3NyAtMC4xMzk3ODgzLDguODQ1ZS00IC0wLjI1'
    b'MTMwNTMsLTAuMDAyNiAtMC4zNTY1OTcyLC0wLjEwNDE2NjYgLTAuMDc5ODY0LC0wLjA3Mjky'
    b'IC0wLjEyNDgyNDksMC4wMTM5NjYgLTAuMTAxNzM2MSwwLjA2MzE5NCAwLjAzOTEyNiwwLjE1'
    b'MTc1ODggMC4yNTU2MjU3LDAuMTk0MjU1OSAwLjQ3NDY1MjcsMC4xNDUxMzg5IDAuMDg0ODE2'
    b'LC0wLjAxNDA0NiAwLjAzNDAyOCwwLjA3NjgzOCAwLjAxMDA2OSwwLjA3Nzc3OCBDIDIuODAx'
    b'MTksMS44OTY3MDc1IDIuNjM3MzQ0OSwxLjk2MDkxMjQgMi40OTMwNTUyLDEuODMwMzk1IDIu'
    b'NDI3MDI4MiwxLjc3OTgzNyAyLjM4MjM4NjgsMS44MjIzMzUgMi40MDY5NDQyLDEuODk1MzI2'
    b'IDIuNDcwOTY4MiwyLjA4NTYzMDIgMi43MTU4NzQxLDIuMDQ1NjYxNCAyLjg4NDAyNzUsMS45'
    b'NTE5MjMgMi45MjczMDg1LDEuOTI3Nzk2IDIuOTY2NTg4NSwxLjk4MzkyOCAyLjkxMzg4ODUs'
    b'Mi4wMjY1NzYgMi43MDQ3NzU5LDIuMTcyNjkwOCAyLjYwMDIyMzUsMi4xNzQzNTI0IDIuNTA1'
    b'OTAyOSwyLjExODI0MjUgMi4zODc4MiwyLjA3MTY3MjUgMi4zNzc0MzI2LDIuMjAyNjQ2NiAy'
    b'LjQ0NzU2OTYsMi4yNDU2NzMgMi41MjU1MjQ2LDIuMjkzNDk1IDIuNzIzOTA0MywyLjI1NzY0'
    b'IDIuODY5NDQ0NiwyLjE2NjE1OSAyLjkzMTgzNzYsMi4xMTk3NzIgMi45MzQ2NjA2LDIuMTky'
    b'MzA0IDIuODk1MTM4NiwyLjIyMTAyIDIuNzIyNDI1MiwyLjM3MDI3OTQgMi42NTQzNSwyLjQw'
    b'OTU4NjYgMi40NzQzMDUzLDIuMzg1MjU2MSBjIC0wLjA4OTI3OSwtMC4wMDY5NiAtMC4wODc5'
    b'MzgsMC4xMDMxMSAtMC4wMTc3MDgsMC4xNDYxODA1IDAuMDk1ODg3LDAuMDU4ODA1IDAuMjgz'
    b'MTQwNywtMC4wMzg4MDUgMC40Mjg0NzIyLC0wLjE1OTM3NSAwLjA2MTE2OSwtMC4wMzI2ODUg'
    b'MC4wNzEyMTUsMC4wMjA5MTkgMC4wNDA5NzIsMC4wODQzNzUgLTAuMDg4ODAxLDAuMTEyMDM1'
    b'OCAtMC4xNzIxNDcsMC4xNzgwODk3IC0wLjI1MjQzMDUsMC4yMDg2ODA1IC0wLjA4MDI4NCww'
    b'LjAzMDU5MSAtMC4xNTc1MDU0LDAuMDI1NzE3IC0wLjIxMjE1MjgsMC4wMDY5NCAtMC4wNjY2'
    b'NjksLTAuMDIyOTA1IC0wLjA3NTAyOSwwLjA0NjM4MSAtMC4wMzgxOTQsMC4xMDkzNzUgMC4w'
    b'MjIyMDQsMC4wMzc5NzIgMC4xMTQyMTg3LDAuMDUwMTQ4IDAuMjEzNTQxNiwwLjAxNDkzMSAw'
    b'LjA5OTMyMywtMC4wMzUyMTIgMC4yMDU5NTM4LC0wLjExNzgwNjggMC4yNzkxNjY2LC0wLjIx'
    b'NDU4MzMgMC4wNjM2OTksLTAuMDU1NzY2IDAuMDU1Nzc3LDAuMDE5MTUyIDAuMDI2NzM2LDAu'
    b'MDcxODc1IC0wLjE0NjYwNDUsMC4yMzE3NjM0IC0wLjI4MDY4OSwwLjMxNzczNjkgLTAuNDU3'
    b'MjkxNywwLjMwMzEyNSAtMC4wNzgzMDYsLTAuMDEzMjk3IC0wLjA5NjA5LDAuMDQ3NTk2IC0w'
    b'LjA0NjE4LDAuMTAzODE5NCAwLjA4NzYzOCwwLjA3MjY3OSAwLjE5NzIxNDYsMC4wNzA0IDAu'
    b'MjkzMDU1NSwtMC4wMDEzOSAwLjA4NTIwMiwtMC4wODIxNDcgMC4yNDgxOTkzLC0wLjI1OTAz'
    b'NzYgMC4zMzM2ODA1LC0wLjM1MzgxOTQgMC4wNjAyMzcsLTAuMDQ4MDIxIDAuMDc5NDgsLTYu'
    b'OGUtNCAwLjA2MTgwNiwwLjA5Njg3NSAtMC4wMTYwNzQsMC4wNTU4NjcgLTAuMDU2MzE0LDAu'
    b'MTE0NzA0NCAtMC4xNjU5NzIyLDAuMTU3NjM4OSAtMC4wNzQ5MTQsMC4wNDI3NTYgLTAuMDE4'
    b'NjU2LDAuMTAxNjgyNCAwLjAzNzUsMC4xMDI3Nzc3IDAuMDMwOTA0LDYuMDI3ZS00IDAuMDkz'
    b'NjU4LC0wLjAzNTUyNCAwLjE0MTY2NjYsLTAuMDg5NTgzIDAuMDYzMTU4LC0wLjA3MTExNyAw'
    b'LjA2NjkxNCwtMC4xMTg4NjI0IDAuMTAxNzM2MSwtMC4yMjk1MTM4IDAuMDMyODk5LC0wLjA1'
    b'MzkzOCAwLjA5MTY2MSwtMC4wMjg3NjIgMC4wOTE2NjcsMC4wMjc3NzggLTAuMDI4MTgzLDAu'
    b'MTEwODM1NCAtMC4wNTIzOTgsMC4xMzA3MDg2IC0wLjEwOTM3NSwwLjE3NjA0MTcgLTAuMDU0'
    b'NDk4LDAuMDUxMTY2IDAuMDM3OTQ3LDAuMDY4MjE4IDAuMDY5MDk3LDAuMDQ3MjIyIDAuMDkw'
    b'MTE2LC0wLjA2MDc0MiAwLjEyMzAxNDcsLTAuMTM5MzE0IDAuMTUzMTI1LC0wLjIxMDc2Mzkg'
    b'MC4wMjE3MzQsLTAuMDUxNTc0IDAuMDg0NzgyLC0wLjAyNjU3MiAwLjA1NTU1NiwwLjA1NzYz'
    b'OSAtMC4wNjk4NDUsMC4yMDEyNTI4IC0wLjE4NDYxMjksMC4yODA0OTcxIC0wLjM4NTQxNjYs'
    b'MC4zMjExODA1IC0wLjAyMDM1MSwwLjAwMzYyIC0wLjAzMjc2NCwwLjAxNTYyOSAtMC4wMjU2'
    b'OTQsMC4wMzkyMzYgMC4wMjY5NTEsMC4wMjc5NzkgMC4wNTM5NTEsMC4wNTMzNjcgMC4wODA5'
    b'MDMsMC4wODEyNSBDIDMuMDQ4NDAzNCwzLjMxOTMyMDkgMi45NDc1MjY1LDMuMzM5NjMxMyAy'
    b'LjgyMzI2NCwzLjM3NTg4MTMgMi43NjIyOTksMy4zMzU5MTIzIDIuNzEzMDQ4NSwzLjMwMjAw'
    b'MjYgMi42NTIwODM1LDMuMjYxOTkyNCAyLjYzNjAwNzUsMy4yMjQ0MTE0IDIuNjI4NTExNCwz'
    b'LjE2NzA0NzUgMi41Mzg1NDE4LDMuMjA3NDc4NSBjIC0wLjA2MDk2NSwtMC4wMjgxNTcgLTAu'
    b'MDg5MDg3LC0wLjAxNzgzMiAtMC4xMjI5MTY2LDAuMDEwNDE3IDAuMDQ4ODM4LDAuMDAxODIg'
    b'MC4wNzAwODcsMC4wMTQ4OTkgMC4wODkyMzYsMC4wMzcxNTMgMC4wMjUwMDEsMC4wNjU4NDYg'
    b'MC4wODI2NTMsMC4wNzIyMDcgMC4xNDE2NjY2LDAuMDUzNDcyIDAuMDM4MzkyLDAuMDMyMzQy'
    b'IDAuMDU4ODM4LDAuMDU3MTUgMC4wOTcyMjIsMC4wODk1ODMgLTAuMDcxNjU4LC0wLjAwMjQ1'
    b'IC0wLjEyMTU4MDUsLTAuMDAzNzIgLTAuMTkzMDU1NSwtMC4wMDU5IC0wLjA2ODIzLC0wLjA3'
    b'MzI2IC0wLjEyMjY4ODgsLTAuMDY5MjQ3IC0wLjE3MTUyNzgsLTAuMDExODA1IC0wLjAzNzIy'
    b'MywwLjAwNTcyIC0wLjA1MzAwMiwwLjAwNjUyIC0wLjA3ODQ3MiwwLjA1MTczNiAwLjA0MDA1'
    b'NywtMC4wMTY0NCAwLjA2NTI1OCwtMC4wMjEzNjggMC4wODI2MzksLTAuMDAzNDcgMC4wNzI1'
    b'NDEsMC4wNDIwNTUgMC4xMTk5MzA4LDAuMDMyNjY4IDAuMTU1OTAyOCwwIDAuMDY5OTg2LDAu'
    b'MDA0MjggMC4xMzMwNTEsMC4wMDc5IDAuMjAzMTI1LDAuMDEyNSAtMC4wMjU3NCwwLjAyMTg3'
    b'OSAtMC4wNjEwNjUsMC4wMzM0ODUgLTAuMDg2ODA2LDAuMDU1NTU2IC0wLjEwNTExNDQsLTAu'
    b'MDMwMDcyIC0wLjE1OTk3NjIsMC4wMTA0MDcgLTAuMTc4NDcyMiwwLjA5NjE4MSAtMC4wMTQw'
    b'ODcsMC4wMzQ2MTkgLTAuMDIwNjgzLDAuMDcwMjYxIC0wLjAxNDU4MywwLjEwNzI5MTcgMC4w'
    b'MTAxNzQsLTAuMDMzODcxIDAuMDI2NTMyLC0wLjA2Mjk5MyAwLjA1NjU5NywtMC4wODEyNSAw'
    b'LjA5MzY4OSwwLjAyMzc5OCAwLjEyODkxNzgsLTAuMDE0NDUgMC4xMzQwMjc4LC0wLjA3MDQ4'
    b'NiAwLjA0NTE2MSwtMC4wMzY4NDggMC4xMTMyNjE2LC0wLjA0NDk3NCAwLjE1ODMzMzMsLTAu'
    b'MDgyMjkyIDAuMDUyNywwLjAxNjg3MSAwLjA3ODE3NSwwLjAyNzMyMSAwLjEzMTI1LDAuMDQ0'
    b'MDk3IDAuMDE4ODcsMC4wNTczNDIgMC4wNjE1NywwLjA4MDA0NyAwLjEzMDkwMjcsMC4wNjUy'
    b'NzggMC4wODI1MzMsMC4wMDI1OSAwLjA2Nzk2MywwLjAzNjQ1NSAwLjA3NDY1MywwLjA2MzU0'
    b'MiAwLjAyMTkzNCwtMC4wMzg5MDEgMC4wMjEzMjMsLTAuMDc2NzMyIC0wLjAyOTUxNCwtMC4x'
    b'MTExMTExIC0wLjAxODQ5NiwtMC4wNTAyNDkgLTAuMDU5NDc1LC0wLjA3MzEwMiAtMC4xMTMx'
    b'OTQ0LC0wLjA0NDA5NyAtMC4wNTA1NjYsLTAuMDE0MzU2IC0wLjA2Mzg2LC0wLjAzNDk5IC0w'
    b'LjExNDIzNjEsLTAuMDQ5MzA2IDAuMTI3NDIzMywtMC4wNDA2MTQgMC4yMTc4MTEsLTAuMDQ5'
    b'NzUzIDAuMzQ1MTM4OCwtMC4wOTAyNzggMC4wMzE4NzIsMC4wMzAwNjUgMC4wNTcxMzIsMC4w'
    b'NTE2NDkgMC4wODkyMzYsMC4wNzg0NzIgMC4wMTY5MiwwLjAxMDA5OSAwLjAzMzExNywwLjAx'
    b'MjY0MyAwLjA0MzA1NiwwIDAuMDc5Nzg3LC0wLjExNTQ4MDMgMC4xMTU0MjEzLC0wLjIxNzI1'
    b'MzUgMC4xODk1ODMzLC0wLjI5MzQwMjggMC4wMjgzMzMsLTAuMDMxNTA2IDAuMDY0MTI5LC0w'
    b'LjA3NDAxNSAwLjEwMzgxOTQsLTAuMDg0Mzc1IDAuMDE5ODQ1LC0wLjAwNTE4IDAuMDQ0MTgy'
    b'LC0wLjAwMjAyIDAuMDU5NzIyLDAuMDE0OTMxIDAuMDE1NTQsMC4wMTY5NDkgMC4wMjc3NDcs'
    b'MC4wNDgxODcgMC4wMjI1NywwLjA5NDc5MiAtMC4wMDc0MywwLjA2Njg5OCAtMC4wMjM1OTMs'
    b'MC4wODgwMiAtMC4wNDIzNjEsMC4xMjgxMjUgLTAuMDE4NzY4LDAuMDQwMTA2IC0wLjA0MTcw'
    b'NCwwLjA2NDc3NSAtMC4wNjUyNzgsMC4wOTU0ODYgLTAuMDQ3MTQ5LDAuMDYxNDIxIC0wLjEw'
    b'OTM2LDAuMDk3MTcxIC0wLjE0NjE4MDUsMC4xMjExODA2IC0wLjA3MzY0MSwwLjA0ODAyIC0w'
    b'LjEwNDc4NTksMC4wMjcwMDMgLTAuMTYxODA1NiwwLjAyMzk1OCAtMC4wNzM2OTcsMC4wMDgy'
    b'NyAtMC4wOTMzMDYsMC4wNDQxNjMgLTAuMDMyOTg2LDAuMDkzNzUgMC4wNTYzODgsMC4wMjkz'
    b'MzkgMC4xMDcwNzI1LDAuMDMyOTYxIDAuMTQ4MjYzOSwwLjAyNTM0NyAwLjAzNTM2OCwtMC4w'
    b'MDY1NCAwLjA3Njc1OSwtMC4wNTIxOSAwLjEwNjI1LC0wLjA3NjczNiAwLjAzMzE5NiwtMC4w'
    b'MzgzNSAwLjA4ODIzMywwLjAwNzEzIDAuMDUwNjk0LDAuMDUxNzM2IC0wLjA2ODIxNSwwLjA4'
    b'MTA1MyAtMC4xMzYzNzYxLDAuMTM0NDkzMyAtMC4yMjA0ODYxLDAuMTMzMzMzMyAtMC4wODgz'
    b'ODUsMC4wMTE4OTUgLTAuMDcxODUyLDAuMDYxNTU2IC0wLjAxMzE5NCwwLjA4NTc2NCAwLjEw'
    b'NTU2ODUsMC4wNDM1NjkgMC4yMDA4ODUsLTAuMDM4MDM5IDAuMjQ5MzA1NSwtMC4wOTE2Njcg'
    b'MC4wMzczNTgsLTAuMDQwODcxIDAuMDYzODkyLC0wLjA0MjQ2NSAwLjA1NzI5MiwwLjAyMDgz'
    b'MyAtMC4wMzcwODcsMC4xMTQ1OTU3IC0wLjA4Nzc2OCwwLjE1ODg2MzMgLTAuMTcwNDg2MSww'
    b'LjE2NDU4MzMgLTAuMDY3MDk1LC0wLjAwNjIzIC0wLjA2NzgyLDAuMDQ1NTYyIC0wLjAxODc1'
    b'LDAuMDgwNTU2IDAuMTExNzgxNSwwLjA3NzM2OSAwLjE5MjczMjYsLTAuMDU0Mzg2IDAuMjMw'
    b'NTU1NSwtMC4xMzQwMjc3IDAuMDI2OTUyLC0wLjA3MTg0MSAwLjA2ODI5MSwtMC4wMzc2Nzcg'
    b'MC4wNzI1NywwLjAyMTUyOCA1LjU3NmUtNCwwLjA3OTEwNCAtMC4wMzUxODYsMC4xNDM2ODk4'
    b'IC0wLjEzMDkwMjgsMC4yMjQ2NTI3IEMgMy43MzAxODA3LDQuMjM5NzkyMyAzLjgxNTU2MDUs'
    b'NC4zNTg0NzUzIDMuODg4ODkwMSw0LjQ3NTU0IDMuOTYyMjE4Niw0LjM1ODQ2OTIgNC4wNDc1'
    b'OTgzLDQuMjM5Nzg2MiA0LjEyMDgzMzMsNC4xMjMxMDM0IDQuMDI1MTE2Niw0LjA0MjE0MDUg'
    b'My45ODkzNzI5LDMuOTc3NTU0NiAzLjk4OTkzMDYsMy44OTg0NTA3IGMgMC4wMDQyOCwtMC4w'
    b'NTkyMDUgMC4wNDU2MTcsLTAuMDkzMzY5IDAuMDcyNTY5LC0wLjAyMTUyOCAwLjAzNzgyMyww'
    b'LjA3OTY0MiAwLjExODc3NCwwLjIxMTM5NjcgMC4yMzA1NTU1LDAuMTM0MDI3NyAwLjA0OTA3'
    b'LC0wLjAzNDk5MyAwLjA0ODM0NSwtMC4wODY3ODYgLTAuMDE4NzUsLTAuMDgwNTU2IC0wLjA4'
    b'MjcxOCwtMC4wMDU3MiAtMC4xMzMzOTkxLC0wLjA0OTk4OCAtMC4xNzA0ODYsLTAuMTY0NTgz'
    b'MyAtMC4wMDY2LC0wLjA2MzI5OCAwLjAxOTkzNCwtMC4wNjE3MDQgMC4wNTcyOTIsLTAuMDIw'
    b'ODMzIDAuMDQ4NDIxLDAuMDUzNjI4IDAuMTQzNzM3LDAuMTM1MjM1NyAwLjI0OTMwNTUsMC4w'
    b'OTE2NjcgMC4wNTg2NTgsLTAuMDI0MjA4IDAuMDc1MTkxLC0wLjA3Mzg2OSAtMC4wMTMxOTQs'
    b'LTAuMDg1NzY0IC0wLjA4NDExLDAuMDAxMTYgLTAuMTUyMjcxMSwtMC4wNTIyOCAtMC4yMjA0'
    b'ODYxLC0wLjEzMzMzMzMgLTAuMDM3NTM5LC0wLjA0NDYwNiAwLjAxNzQ5OCwtMC4wOTAwODYg'
    b'MC4wNTA2OTQsLTAuMDUxNzM2IDAuMDI5NDkxLDAuMDI0NTQ2IDAuMDcwODgyLDAuMDcwMTk2'
    b'IDAuMTA2MjQ5OSwwLjA3NjczNiAwLjA0MTE5MiwwLjAwNzYxIDAuMDkxODc2LDAuMDAzOTkg'
    b'MC4xNDgyNjM5LC0wLjAyNTM0NyAwLjA2MDMyLC0wLjA0OTU4NyAwLjA0MDcxMSwtMC4wODU0'
    b'OCAtMC4wMzI5ODYsLTAuMDkzNzUgLTAuMDU3MDIsMC4wMDMwNSAtMC4wODgxNjUsMC4wMjQw'
    b'NjIgLTAuMTYxODA1NSwtMC4wMjM5NTggLTAuMDM2ODIxLC0wLjAyNDAxIC0wLjA5OTAzMiwt'
    b'MC4wNTk3NiAtMC4xNDYxODA2LC0wLjEyMTE4MDYgLTAuMDIzNTc0LC0wLjAzMDcxMSAtMC4w'
    b'NDY1MSwtMC4wNTUzOCAtMC4wNjUyNzgsLTAuMDk1NDg2IC0wLjAxODc2OCwtMC4wNDAxMDUg'
    b'LTAuMDM0OTMxLC0wLjA2MTIyNyAtMC4wNDIzNjEsLTAuMTI4MTI1IC0wLjAwNTE4LC0wLjA0'
    b'NjYwNSAwLjAwNzAzLC0wLjA3Nzg0MyAwLjAyMjU3LC0wLjA5NDc5MiAwLjAxNTU0LC0wLjAx'
    b'Njk1MSAwLjAzOTg3NywtMC4wMjAxMTEgMC4wNTk3MjIsLTAuMDE0OTMxIDAuMDM5NjksMC4w'
    b'MTAzNiAwLjA3NTQ4NiwwLjA1Mjg2OSAwLjEwMzgxOTQsMC4wODQzNzUgMC4wNzQxNjIsMC4w'
    b'NzYxNDkgMC4xMDk3OTYxLDAuMTc3OTIyNSAwLjE4OTU4MzQsMC4yOTM0MDI4IDAuMDA5OTQs'
    b'MC4wMTI2NDMgMC4wMjYxMzYsMC4wMTAwOTkgMC4wNDMwNTYsMCAwLjAzMjEwNCwtMC4wMjY4'
    b'MjMgMC4wNTczNjQsLTAuMDQ4NDA3IDAuMDg5MjM2LC0wLjA3ODQ3MiAwLjEyNzMyNzksMC4w'
    b'NDA1MjUgMC4yMTc3MTU1LDAuMDQ5NjY0IDAuMzQ1MTM4OSwwLjA5MDI3OCAtMC4wNTAzNzYs'
    b'MC4wMTQzMTYgLTAuMDYzNjcsMC4wMzQ5NSAtMC4xMTQyMzYxLDAuMDQ5MzA2IC0wLjA1Mzcx'
    b'OSwtMC4wMjkwMDUgLTAuMDk0Njk4LC0wLjAwNjE1IC0wLjExMzE5NDUsMC4wNDQwOTcgLTAu'
    b'MDUwODM3LDAuMDM0MzggLTAuMDUxNDQ4LDAuMDcyMjEgLTAuMDI5NTE0LDAuMTExMTExMSAw'
    b'LjAwNjY5LC0wLjAyNzA4NyAtMC4wMDc4OCwtMC4wNjA5NTIgMC4wNzQ2NTMsLTAuMDYzNTQy'
    b'IDAuMDY5MzMzLDAuMDE0NzY5IDAuMTEyMDMyOCwtMC4wMDc5NCAwLjEzMDkwMjgsLTAuMDY1'
    b'Mjc4IDAuMDUzMDc1LC0wLjAxNjc3NiAwLjA3ODU1LC0wLjAyNzIyNiAwLjEzMTI1LC0wLjA0'
    b'NDA5NyAwLjA0NTA3MiwwLjAzNzMxOCAwLjExMzE3MjMsMC4wNDU0NDQgMC4xNTgzMzMzLDAu'
    b'MDgyMjkyIDAuMDA1MTEsMC4wNTYwMzYgMC4wNDAzMzksMC4wOTQyODQgMC4xMzQwMjc3LDAu'
    b'MDcwNDg2IDAuMDMwMDY1LDAuMDE4MjU3IDAuMDQ2NDIzLDAuMDQ3Mzc5IDAuMDU2NTk3LDAu'
    b'MDgxMjUgMC4wMDYxLC0wLjAzNzAzMSAtNC45NjRlLTQsLTAuMDcyNjczIC0wLjAxNDU4Mywt'
    b'MC4xMDcyOTE3IC0wLjAxODQ5NywtMC4wODU3NzQgLTAuMDczMzU5LC0wLjEyNjI1MyAtMC4x'
    b'Nzg0NzM0LC0wLjA5NjE4MSAtMC4wMjU3NDEsLTAuMDIyMDcxIC0wLjA2MTA2NSwtMC4wMzM2'
    b'NzcgLTAuMDg2ODA2LC0wLjA1NTU1NiAwLjA3MDA3NCwtMC4wMDQ2IDAuMTMzMTM5LC0wLjAw'
    b'ODIyIDAuMjAzMTI1LC0wLjAxMjUgMC4wMzU5NzIsMC4wMzI2NjggMC4wODMzNjIsMC4wNDIw'
    b'NTUgMC4xNTU5MDI3LDAgMC4wMTczODEsLTAuMDE3ODk2IDAuMDQyNTgyLC0wLjAxMjk2OCAw'
    b'LjA4MjYzOSwwLjAwMzQ3IEMgNS40NTE2MTMzLDMuMzg2OTEzIDUuNDM1ODM0MywzLjM4NjEx'
    b'MyA1LjM5ODYxMTMsMy4zODAzOTMgNS4zNDk3NzIzLDMuMzIyOTUxIDUuMjk1MzEzNSwzLjMx'
    b'ODkzOSA1LjIyNzA4MzUsMy4zOTIxOTggNS4xNTU2MDg1LDMuMzk0Mzc4IDUuMTA1Njg2LDMu'
    b'Mzk1NjQ4IDUuMDM0MDI4LDMuMzk4MDk4IDUuMDcyNDEyLDMuMzY1NjY1IDUuMDkyODU4LDMu'
    b'MzQwODU3IDUuMTMxMjUsMy4zMDg1MTUgNS4xOTAyNjQsMy4zMjcyNSA1LjI0NzkxNTcsMy4z'
    b'MjA4ODkgNS4yNzI5MTY3LDMuMjU1MDQzIDUuMjkyMDY1NywzLjIzMjc4OSA1LjMxMzMxNDcs'
    b'My4yMTk3MSA1LjM2MjE1MjcsMy4yMTc4OSA1LjMyODMyMjcsMy4xODk2NDEgNS4zMDAyMDA3'
    b'LDMuMTc5MzE2IDUuMjM5MjM2LDMuMjA3NDczIDUuMTQ5MjY3LDMuMTY3MDQyIDUuMTQxNzcs'
    b'My4yMjQ0MDYgNS4xMjU2OTQzLDMuMjYxOTg3IDUuMDY0NzI5MywzLjMwMTk5NyA1LjAxNTQ3'
    b'ODgsMy4zMzU5MDcgNC45NTQ1MTM4LDMuMzc1ODc1OSA0LjgzMDI1MTQsMy4zMzk2MjU5IDQu'
    b'NzI5Mzc0NCwzLjMxOTMxNTkgNC42MDUyMDgzLDMuMjgzMTY3OSBjIDAuMDI2OTUyLC0wLjAy'
    b'Nzg4MyAwLjA1Mzk1MiwtMC4wNTMyNzEgMC4wODA5MDMsLTAuMDgxMjUgMC4wMDcwNywtMC4w'
    b'MjM2MDcgLTAuMDA1MzQsLTAuMDM1NjE2IC0wLjAyNTY5NSwtMC4wMzkyMzYgQyA0LjQ1OTYx'
    b'MywzLjEyMjAwMzQgNC4zNDQ4NDUsMy4wNDI3NTkxIDQuMjc1LDIuODQxNTA2MyA0LjI0NTc3'
    b'NCwyLjc1NzI5NTMgNC4zMDg4MjEsMi43MzIyOTM0IDQuMzMwNTU1LDIuNzgzODY3MyBjIDAu'
    b'MDMwMTEsMC4wNzE0NSAwLjA2MzAwOSwwLjE1MDAyMTkgMC4xNTMxMjUsMC4yMTA3NjM5IDAu'
    b'MDMxMTUsMC4wMjA5OTYgMC4xMjM1OTUyLDAuMDAzOTQgMC4wNjkwOTcsLTAuMDQ3MjIyIEMg'
    b'NC40OTU4LDIuOTAyMDc2MiA0LjQ3MTU4NSwyLjg4MjIwMzIgNC40NDM0MDIxLDIuNzcxMzY3'
    b'NSBjIDZlLTYsLTAuMDU2NTQgMC4wNTg3NjgsLTAuMDgxNzE2IDAuMDkxNjY3LC0wLjAyNzc3'
    b'OCAwLjAzNDgyMiwwLjExMDY1MTQgMC4wMzg1NzgsMC4xNTgzOTY4IDAuMTAxNzM2MSwwLjIy'
    b'OTUxMzggMC4wNDgwMDksMC4wNTQwNTkgMC4xMTA3NjI3LDAuMDkwMTg2IDAuMTQxNjY2Nyww'
    b'LjA4OTU4MyAwLjA1NjE1NiwtMC4wMDExIDAuMTEyNDE0LC0wLjA2MDAyMiAwLjAzNzUsLTAu'
    b'MTAyNzc3NyBDIDQuNzA2MzEzOSwyLjkxNjk3NDYgNC42NjYwNzQsMi44NTgxMzcyIDQuNjUs'
    b'Mi44MDIyNzAyIDQuNjMyMzI2LDIuNzA0NzE1MiA0LjY1MTU3LDIuNjU3Mzc0MiA0LjcxMTgw'
    b'NSwyLjcwNTM5NTIgYyAwLjA4NTQ4MSwwLjA5NDc4MiAwLjI0ODQ3ODUsMC4yNzE2NzI0IDAu'
    b'MzMzNjgwNSwwLjM1MzgxOTQgMC4wOTU4NDEsMC4wNzE3ODkgMC4yMDU0MTc2LDAuMDc0MDY4'
    b'IDAuMjkzMDU1NiwwLjAwMTM5IDAuMDQ5OTEsLTAuMDU2MjIzIDAuMDMyMTI1LC0wLjExNzEx'
    b'NjQgLTAuMDQ2MTgxLC0wLjEwMzgxOTQgLTAuMTc2NjAyNiwwLjAxNDYxMiAtMC4zMTA2ODcy'
    b'LC0wLjA3MTM2MiAtMC40NTcyOTE2LC0wLjMwMzEyNSAtMC4wMjkwNDEsLTAuMDUyNzIzIC0w'
    b'LjAzNjk2MywtMC4xMjc2NDEgMC4wMjY3MzYsLTAuMDcxODc1IDAuMDczMjEzLDAuMDk2Nzc3'
    b'IDAuMTc5ODQzNiwwLjE3OTM3MTMgMC4yNzkxNjY2LDAuMjE0NTgzMyAwLjA5OTMyMywwLjAz'
    b'NTIxNyAwLjE5MTMzNzcsMC4wMjMwNDEgMC4yMTM1NDE3LC0wLjAxNDkzMSAwLjAzNjgzNSwt'
    b'MC4wNjI5OTQgMC4wMjg0NzQsLTAuMTMyMjggLTAuMDM4MTk1LC0wLjEwOTM3NSAtMC4wNTQ2'
    b'NDcsMC4wMTg3NzIgLTAuMTMxODY4NywwLjAyMzY0NiAtMC4yMTIxNTI3LC0wLjAwNjk0IEMg'
    b'NS4wMjM4ODMsMi42MzQ1MjY2IDQuOTQwNTM3LDIuNTY4NDcyNyA0Ljg1MTczNiwyLjQ1NjQz'
    b'NjkgNC44MjE0OTMsMi4zOTI5ODA5IDQuODMxNTM5LDIuMzM5Mzc2OSA0Ljg5MjcwOCwyLjM3'
    b'MjA2MTkgYyAwLjE0NTMzMTQsMC4xMjA1NyAwLjMzMjU4NTIsMC4yMTgxOCAwLjQyODQ3MjEs'
    b'MC4xNTkzNzUgMC4wNzAyMywtMC4wNDMwNyAwLjA3MTU3MSwtMC4xNTMxNDA1IC0wLjAxNzcw'
    b'OCwtMC4xNDYxODA1IC0wLjE4MDA0NDYsMC4wMjQzMzEgLTAuMjQ4MTE5OSwtMC4wMTQ5Nzcg'
    b'LTAuNDIwODMzMywtMC4xNjQyMzYxIC0wLjAzOTUyMiwtMC4wMjg3MTYgLTAuMDM2Njk4LC0w'
    b'LjEwMTI0ODEgMC4wMjU2OTUsLTAuMDU0ODYxIDAuMTQ1NTQwMywwLjA5MTQ4MSAwLjM0Mzkx'
    b'OTksMC4xMjczMzU4IDAuNDIxODc0OSwwLjA3OTUxNCAwLjA3MDEzNywtMC4wNDMwMjYgMC4w'
    b'NTk3NSwtMC4xNzQwMDA1IC0wLjA1ODMzMywtMC4xMjc0MzA1IC0wLjA5NDMyMSwwLjA1NjEx'
    b'IC0wLjE5ODg3MywwLjA1NDQ0OCAtMC40MDc5ODYxLC0wLjA5MTY2NyAtMC4wNTI3LC0wLjA0'
    b'MjY0OCAtMC4wMTM0MiwtMC4wOTg3OCAwLjAyOTg2MSwtMC4wNzQ2NTMgMC4xNjgxNTM1LDAu'
    b'MDkzNzM4IDAuNDEzMDU5MywwLjEzMzcwNyAwLjQ3NzA4MzMsLTAuMDU2NTk3IDAuMDI0NTU3'
    b'LC0wLjA3Mjk5MSAtMC4wMjAwODQsLTAuMTE1NDg4NiAtMC4wODYxMTEsLTAuMDY0OTMxIC0w'
    b'LjE0NDI4OTYsMC4xMzA1MTc0IC0wLjMwODEzNDcsMC4wNjYzMTIgLTAuMzk5NjUyNyw2Ljk0'
    b'NWUtNCAtMC4wMjM5NTksLTkuNGUtNCAtMC4wNzQ3NDcsLTAuMDkxODI0IDAuMDEwMDY5LC0w'
    b'LjA3Nzc3OCAwLjIxOTAyNywwLjA0OTExNyAwLjQzNTUyNjgsMC4wMDY2MiAwLjQ3NDY1Mjcs'
    b'LTAuMTQ1MTM4OSAwLjAyMzA4OCwtMC4wNDkyMjcgLTAuMDIxODcyLC0wLjEzNjExMzcgLTAu'
    b'MTAxNzM2NSwtMC4wNjMxOTQgLTAuMTA1MjkxOCwwLjEwMTU2NjUgLTAuMjE2ODA4OCwwLjEw'
    b'NTA1MTEgLTAuMzU2NTk3MSwwLjEwNDE2NjYgLTAuMDcxNDc1LC0wLjAxNDQ1MSAtMC4wNzIw'
    b'NjMsLTAuMDkxNTEgLTAuMDEyNSwtMC4xMDI3Nzc3IDAuMTEwNTU5NCwwLjAwMjQ3IDAuMjE5'
    b'ODUyNiwtMC4wNDQ5MSAwLjMwNzI5MTYsLTAuMDkzMDU2IDAuMDg1MTk0LC0wLjA0Nzc1NiAw'
    b'LjE1NjIwMjIsLTAuMTE1MTM3MyAwLjE3ODQ3MjIsLTAuMjA4MzMzMyAwLjAxMzc5NCwtMC4w'
    b'ODM0OTggLTAuMDY4MjY3LC0wLjE3MjA3NTUgLTAuMTE4MDU1NSwtMC4wODM2ODEgLTAuMDcz'
    b'MTAzLDAuMTI5Nzg1MyAtMC4yMzU1MDE2LDAuMjUxNjc2IC0wLjQxNTYyNSwwLjI3MzYxMSAt'
    b'MC4wMDkzLC0wLjAxNTMzNSAtMC4wMzMxNzQsLTAuMDU0NzIyIC0wLjA2MjE1MywtMC4wNDM3'
    b'NSAtMC4xMDYwMjg1LDAuMDQwMTQzIC0wLjI1MjU4MDYsMC4xMDc2MDA2IC0wLjM3MzI2Mzgs'
    b'MC4xNzQzMDU2IC0wLjAyNjE5NywwLjAxNDQ3OSAwLjAwNDU3LDAuMDg0NTU1IDAuMDEwNDE3'
    b'LDAuMTExNDU4MyAwLjAwNjAyLDAuMDY4NTc4IC0wLjAxNTEsMC4xMTIzNzAyIC0wLjAzNjgw'
    b'NSwwLjEzNzg0NzIgQyA0LjM2NzUzMiwxLjg0MDI1MzMgNC4zMDgzMjksMS44NTY5OTM2IDQu'
    b'Mjc1LDEuODQ4MTAzNiA0LjIwODM0MiwxLjgzMDMyMjIgNC4xNzI0ODI2LDEuNzcyNDcyNSA0'
    b'LjE4MzY4MDYsMS42Njk2MzE0IGMgMC4wMDM0NywtMC4wMTA4NzIgMC4wMDYzMywtMC4wNjAy'
    b'ODUgMC4wNjA3NjQsLTAuMTI0NjUyNyAwLjAyNzM1MSwtMC4wMzIzNDUgMC4wNjU2NDgsLTAu'
    b'MDczNjI1IDAuMTI2Mzg4OSwtMC4xMDY1OTcyIDAuMDYwNzQxLC0wLjAzMjk3MiAwLjE1MjYy'
    b'MiwtMC4wNTEyNyAwLjI2MzE5NDQsLTAuMDc1MzQ3IDAuMDY3Mjg5LC0wLjAxMzIwMSAwLjEw'
    b'MTQ2NTYsLTAuMDM4NTMgMC4xMDU1NTU2LC0wLjA2NTYyNSAtMC4wMzIyMDMsMC4wMDc0NiAt'
    b'MC4wODUwMzksMC4wMzQ4MDUgLTAuMTE5NzkxNywwLjAyODEyNSAtMC4wMzQxNzUsLTAuMDA2'
    b'NTcgLTAuMDUxNDI0LC0wLjAyMzA2OSAtMC4wNjY2NjcsLTAuMDMyNjM5IDAuMDI1MzczLC0w'
    b'LjAwNTMxIDAuMDcyMDA4LDcuMzg4ZS00IDAuMTEzNTQxNiw2Ljk0NGUtNCAwLjA0MTUzNCwt'
    b'NGUtNSAwLjA3ODE3OCwtMC4wMDg4MSAwLjEwMjc3NzgsLTAuMDEyODQ3IDAuMDUxMTIxLC0w'
    b'LjAwODM5IDAuMDkxNjg4LC0wLjAyOTI1NCAwLjExNTk3MjIsLTAuMDc2MDQyIDAuMDEwNTAx'
    b'LC0wLjA1MDM3NiAtMC4wMjMxOTgsLTAuMDU5NTA1IC0wLjA1NDg2MSwtMC4wMjcwODMgLTAu'
    b'MDI2ODU2LDAuMDI3NDk5IC0wLjAzMjIzMiwwLjAzODc0NSAtMC4wNDkzMDYsMC4wNTA2OTQg'
    b'LTAuMDE3MDc0LDAuMDExOTQ3IC0wLjA0NTc5NSwwLjAyMzQ5MyAtMC4wNjYzMTksMC4wMjcw'
    b'ODMgLTAuMDQxNjM0LDAuMDA3MjggLTAuMDgyNjU5LDAuMDE1NDc0IC0wLjEzNTc2MzksMC4w'
    b'MDI3OCAwLjAxMDQ5MywtMC4wMTMxNDcgMC4wMzQxMTUsLTAuMDM0Mzk5IDAuMDU1NTU2LC0w'
    b'LjA0NzU2OSAwLjAyMTQ0LC0wLjAxMzE3IDAuMDQyNDM2LC0wLjAxOTY0OSAwLjA2MjUsLTAu'
    b'MDE2MzE5IDAuMDEzMzkyLDAuMDAyMjUgMC4wMzA4MjMsMC4wMTQxNjMgMC4wNDUxMzksMC4w'
    b'MzYxMTEgMC4wMDg4NCwtMC4wNTUzMDQgLTAuMDA2ODMsLTAuMTE3NDU0NyAtMC4xNTcyOTE3'
    b'LC0wLjA5MTY2NyAwLjAwMjAxLC0wLjA0MTQ1OSAtMC4wODc2NDcsLTAuMDU5NTkxIC0wLjE0'
    b'MTY2NjYsLTAuMDU4NjggLTAuMDMwNTkzLDUuMTVlLTQgLTAuMDkzMzU0LDAuMDE4NDU0IC0w'
    b'LjEzODU0MTcsMC4wMzk1ODMgLTAuMDcxNDc0LDAuMDIxNjU3IC0wLjE0MjUxMDQsMC4wMzc1'
    b'MDMgLTAuMjI1Njk0NCwwLjA0MzQwMyAwLjA0ODAzOCwwLjA0MDM0OCAwLjA1NzQ3NSwwLjA0'
    b'MjY1NSAwLjEwNTkwMjcsMC4wNzcwODMgLTAuMDczMzMsMC4wMjY2NzIgLTAuMTMwMTI2NSww'
    b'LjA4MTk2MyAtMC4xNTU1NTU1LDAuMTE4MDU1NSAwLjA2NDA1MSwwLjAwMzA3IDAuMDg1MjAx'
    b'LC0wLjAwMjMyIDAuMTA2OTQ0NCwwLjAwNjk0IC0wLjA4OTIyMSwwLjAyNTg0MSAtMC4xMjk2'
    b'MDkxLDAuMDQwOTgxIC0wLjE3NjczNjEsMC4wODgxOTQgMC4wMTY2ODQsMC4wMDMwNCAwLjA0'
    b'MTQ4NywwLjAwNzQ5IDAuMDUyMDgzLDAuMDExNDU4IDAuMDEwOTU1LDAuMDA0MTEgMC4wMDY0'
    b'MiwwLjAwOTc0IC0wLjAwMTA0LDAuMDE3NzA4IC0wLjAyMDQ1MywwLjAxMjggLTAuMDk4NzMs'
    b'MC4xMDUwMjA5IC0wLjEyMTg3NSwwLjEyNjM4ODkgLTAuMDIzMTQ1LC0wLjAyMTM2OCAtMC4x'
    b'MDE0MjE0LC0wLjExMzU4ODUgLTAuMTIxODc1LC0wLjEyNjM4ODkgLTAuMDA3NDYsLTAuMDA3'
    b'OTcgLTAuMDExOTk3LC0wLjAxMzYwMSAtMC4wMDEwNCwtMC4wMTc3MDggMC4wMTA1OTYsLTAu'
    b'MDAzOTcgMC4wMzUzOTksLTAuMDA4NDIgMC4wNTIwODMsLTAuMDExNDU4IC0wLjA0NzEzLC0w'
    b'LjA0NzIxIC0wLjA4NzUxOCwtMC4wNjIzNTEgLTAuMTc2NzM5MSwtMC4wODgxOTIgMC4wMjE3'
    b'NDMsLTAuMDA5MjYgMC4wNDI4OTMsLTAuMDAzODcgMC4xMDY5NDQ0LC0wLjAwNjk0IEMgMy43'
    b'MjI4MzUsMS4zMjIwODEgMy42NjYwMzg2LDEuMjY2NzkwNiAzLjU5MjcwODQsMS4yNDAxMTc2'
    b'IDMuNjQxMTM2NCwxLjIwNTY4OTYgMy42NTA1NzM0LDEuMjAzMzgyMyAzLjY5ODYxMTIsMS4x'
    b'NjMwMzQzIDMuNjE1NDI3MiwxLjE1NzEzNDMgMy41NDQzOTA3LDEuMTQxMjg4NSAzLjQ3Mjkx'
    b'NjcsMS4xMTk2MzE1IDMuNDI3NzI4NywxLjA5ODUwMjUgMy4zNjQ5Njc5LDEuMDgwNTYzMiAz'
    b'LjMzNDM3NTEsMS4wODAwNDgyIHogbSAwLjAwNzk5LDAuMDk2ODc1IGMgMC4wNDM5NTgsMCAw'
    b'LjA3MTE4MSwwLjAxNTA2OCAwLjA3MTE4MSwwLjAzMzMzMyAwLDAuMDE4NTgyIC0wLjAyNzIy'
    b'MywwLjAzMzY4MSAtMC4wNzExODEsMC4wMzM2ODEgLTAuMDQzNzc1LDAgLTAuMDcxNTI4LC0w'
    b'LjAxNjQ3NyAtMC4wNzE1MjgsLTAuMDM1MDY5IDcuOWUtNiwtMC4wMTgyNjUgMC4wMjc3NTMs'
    b'LTAuMDMxOTQ1IDAuMDcxNTI4LC0wLjAzMTk0NSB6IG0gMS4wOTMwNTU0LDAgYyAwLjA0Mzc3'
    b'NSwwIDAuMDcxNTIsMC4wMTM2OCAwLjA3MTUyOCwwLjAzMTk0NSAwLDAuMDE4NTkyIC0wLjAy'
    b'Nzc1MywwLjAzNTA2OSAtMC4wNzE1MjgsMC4wMzUwNjkgLTAuMDQzOTU4LDAgLTAuMDcxMTgs'
    b'LTAuMDE1MDk5IC0wLjA3MTE4LC0wLjAzMzY4MSAwLC0wLjAxODI2NSAwLjAyNzIyMiwtMC4w'
    b'MzMzMzMgMC4wNzExOCwtMC4wMzMzMzMgeiIKICAgaWQ9InBhdGg5IgogICBpbmtzY2FwZTpj'
    b'b25uZWN0b3ItY3VydmF0dXJlPSIwIiAvPgo8L3N2Zz4=', 'AL')

AL = b64_AL
index.append("AL")
index.append("ALB")
index.append("Albania")
catalog["AL"] = AL
catalog["ALB"] = AL
catalog["Albania"] = AL
country["Albania"] = ('AL', 'ALB', 0)
lookup["AL"] = ('AL', 'ALB', 'Albania', 0)
lookup["Tirana Albania"] = ('AL', 'ALB', 'Albania', 0)
lookup["ALB"] = ('AL', 'ALB', 'Albania', 0)
lookup["Albania"] = ('AL', 'ALB', 'Albania', 0)
details["AL"] = {"continent":"Europe","capital":"Tirana","currency":"Lek","web":".al","lang":"sq el","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_AM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWFtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2Q5MDAxMiIgZD0i'
    b'TTAgMGg2NDB2MTYwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMzNhMCIgZD0iTTAgMTYwaDY0'
    b'MHYxNjBIMHoiLz4KICA8cGF0aCBmaWxsPSIjZjJhODAwIiBkPSJNMCAzMjBoNjQwdjE2MEgw'
    b'eiIvPgo8L3N2Zz4K', 'AM')

AM = b64_AM
index.append("AM")
index.append("ARM")
index.append("Armenia")
catalog["AM"] = AM
catalog["ARM"] = AM
catalog["Armenia"] = AM
country["Armenia"] = ('AM', 'ARM', 0)
lookup["AM"] = ('AM', 'ARM', 'Armenia', 0)
lookup["Yerevan Armenia"] = ('AM', 'ARM', 'Armenia', 0)
lookup["ARM"] = ('AM', 'ARM', 'Armenia', 0)
lookup["Armenia"] = ('AM', 'ARM', 'Armenia', 0)
details["AM"] = {"continent":"Asia","capital":"Yerevan","currency":"Armenian Dram","web":".am","lang":"hy","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_AO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWFvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSJyZWQiIGQ9Ik0wIDBoNjQwdjI0'
    b'My42SDB6Ii8+CiAgICA8cGF0aCBkPSJNMCAyMzYuNGg2NDBWNDgwSDB6Ii8+CiAgPC9nPgog'
    b'IDxwYXRoIGZpbGw9IiNmZmVjMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTIyOC43IDE0'
    b'OC4yYzE2NS4yIDQzLjMgNTkgMjU1LjYtNzEuMyAxNjcuMmwtOC44IDEzLjZjNzYuNyA1NC42'
    b'IDE1Mi42IDEwLjYgMTc0LTQ2LjQgMjIuMi01OC44LTcuNi0xNDEuNS05Mi42LTE1MGwtMS4z'
    b'IDE1LjZ6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZWMwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBk'
    b'PSJtMTcwIDMzMC44IDIxLjcgMTAuMS0xMC4yIDIxLjgtMjEuNy0xMC4yem0xNDktOTkuNWgy'
    b'NHYyNGgtMjR6bS0xMS43LTM4LjkgMjIuMy04LjYgOC43IDIyLjMtMjIuMyA4Ljd6bS0yNi0y'
    b'OS4xIDE3LjEtMTYuOSAxNi45IDE3LTE3IDE2Ljl6bS0yNi4yLTM5LjggMjIuNCA4LjQtOC41'
    b'IDIyLjQtMjIuNC04LjR6TTMxNiAyNzBsMjIuMyA4LjktOSAyMi4yLTIyLjItOC45em0tNjku'
    b'OSA3MCAyMi05LjMgOS41IDIyLTIyIDkuNHptLTM5LjUgMi44aDI0djI0aC0yNHptNDEuMy0x'
    b'MTYtMjAuMy0xNS0yMC4zIDE0LjYgOC0yMy0yMC4zLTE1aDI0LjVsOC41LTIyLjYgNy44IDIy'
    b'LjcgMjQuNy0uMy0xOS42IDE1LjMgNyAyMy40eiIvPgogIDxwYXRoIGZpbGw9IiNmZTAiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMzNiAzNDYuNGMtMS4yLjQtNi4yIDEyLjQtOS43IDE4'
    b'LjJsMy43IDFjMTMuNiA0LjggMjAuNCA5LjIgMjYuMiAxNy41YTcuOSA3LjkgMCAwIDAgMTAu'
    b'Mi43czIuOC0xIDYuNC01YzMtNC41IDIuMi04LTEuNC0xMS4xLTExLTgtMjIuOS0xNC0zNS40'
    b'LTIxLjN6Ii8+CiAgPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzY1LjMgMzcyLjhh'
    b'NC4zIDQuMyAwIDEgMS04LjcgMCA0LjMgNC4zIDAgMCAxIDguNiAwem0tMjEuNC0xMy42YTQu'
    b'MyA0LjMgMCAxIDEtOC43IDAgNC4zIDQuMyAwIDAgMSA4LjcgMHptMTAuOSA3YTQuMyA0LjMg'
    b'MCAxIDEtOC43IDAgNC4zIDQuMyAwIDAgMSA4LjcgMHoiLz4KICA8cGF0aCBmaWxsPSIjZmUw'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zMjQuNSAzNjMuN2MtNDIuNi0yNC4zLTg3LjMt'
    b'NTAuNS0xMzAtNzQuOC0xOC43LTExLjctMTkuNi0zMy40LTctNDkuOSAxLjItMi4zIDIuOC0x'
    b'LjggMy40LS41IDEuNSA4IDYgMTYuMyAxMS40IDIxLjVBNTI4OCA1Mjg4IDAgMCAxIDMzNCAz'
    b'NDUuNmMtMy40IDUuOC02IDEyLjMtOS41IDE4eiIvPgogIDxwYXRoIGZpbGw9IiNmZmVjMDAi'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTI5Ny4yIDMwNS41IDE3LjggMTYtMTYgMTcuOC0x'
    b'Ny44LTE2eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIzIiBkPSJtMzMxLjUgMzQ4LjgtMTI1LTc1LjVtMTA5LjYgNTguMUwyNzQgMzA0LjFt'
    b'MTguMiA0Mi43TDI0OS4zIDMyMiIvPgo8L3N2Zz4K', 'AO')

AO = b64_AO
index.append("AO")
index.append("AGO")
index.append("Angola")
catalog["AO"] = AO
catalog["AGO"] = AO
catalog["Angola"] = AO
country["Angola"] = ('AO', 'AGO', 0)
lookup["AO"] = ('AO', 'AGO', 'Angola', 0)
lookup["Luanda Angola"] = ('AO', 'AGO', 'Angola', 0)
lookup["AGO"] = ('AO', 'AGO', 'Angola', 0)
lookup["Angola"] = ('AO', 'AGO', 'Angola', 0)
details["AO"] = {"continent":"Africa","capital":"Luanda","currency":"Kwanza","web":".ao","lang":"pt-AO","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_AQ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWFxIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzNhN2RjZSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTE1Ny43IDIzMC44'
    b'Yy0zLjUtNy44LTMuNS03LjgtMy41LTE1LjYtMS44IDAtMiAuMy0zIDAtMS4xLS4zLTEuNSA3'
    b'LjItNC44IDUuOC0uNS0uOCAyLjQtNi4yLS43LTguNS0xLS43LjItNS4yLS4yLTcuMiAwIDAt'
    b'NCAyLjQtNy01LjgtMS41LTIuMi0zLjUgMi0zLjUgMnMuOSAyLjQtLjcgM2MtMi4yLTEuOC0z'
    b'LjktLjgtNi43LTMuNC0yLjgtMi41LjYtNS40LTQuOC03LjUgMy41LTkuOCAzLjUtNy45IDEy'
    b'LjItMTEuOC01LjItNC01LjItNC04LjctOS44LTUuMi0yLTctNC0xMi4yLTcuOC03LTkuOS0x'
    b'MC41LTI5LjUtMTAuNS00My4yIDQuNC00LjYgMTAuNSAxNS43IDE5LjIgMjEuNmwxMi4yIDUu'
    b'OWM3IDMuOSA4LjcgNy44IDE0IDExLjdsMTUuNiA2YzcgNS44IDEwLjUgMTMuNiAxNS43IDE1'
    b'LjYgNS43IDAgNi44LTMuNyA4LjYtMy45IDEwLjMtLjYgMTUuNS0yIDE3LjUtNS41IDIuMS0y'
    b'LjggNyAxLjYgMjEtNC4zbC0xLjctNy45czMuNy0zLjQgOC43LTJjLS4xLTMuNS0uNS0xMyA0'
    b'LjUtMTcuNC0zLTMuNSAxLjgtOSAyLTEwLjctMS40LTguNiAxLjQtOC43IDItMTEuMy42LTIu'
    b'NS0yLjQtMS43LTEuNi01LjIuOS0zLjUgNi00LjMgNi42LTcuMi43LTIuOS0xLjEtMTQuMy0x'
    b'LjMtMTYuOCA5LjQtMi44IDEyLjQtMTEuNCAxNS43LTcuOEMyNjQgNzAgMjY1LjggNjYgMjc2'
    b'LjMgNjZjMS40LTMuNi0zLjktNi43LTEuOC03LjkgMy41LS41IDYuMS0uMiAxMC4yIDUuNyAx'
    b'LjMgMiAxLjYtMi43IDIuOS0zLjIgMS4zLS41IDQuNC0uNSA0LjktMi44LjUtMi40IDEuMi01'
    b'LjYgMy05LjUgMS40LTMuMiAyLjUgMS4zIDMuOCA3LjUgNy40LjMgMjQgMi4xIDMxIDQuMyA1'
    b'LjIgMS41IDguNy0xLjUgMTMuNy0yLjIgMy43IDQuMiA3LjIgMSA5LjIgMTAgMi43IDQuOCA3'
    b'LjMuNCA4LjMgMS44IDUuOCAxOC4xIDI1LjggNS45IDI3LjQgNi4yIDIuNSAwIDUuNiA4IDcu'
    b'NyA3LjkgMy4yLS42IDIuMy0zLjEgNS4yLTIuMS0uOCA2LjggNS42IDE0LjYgNS42IDE5Ljcg'
    b'MCAwIDEuNS45IDMtLjYgMS40LTEuNiAyLjctNS40IDQtNS4zIDMgLjUgMjIgNiAyNS44IDcu'
    b'OSAxLjcgMy41IDMuMyA1LjMgNi44IDQuNyAyLjggMi4xLjggNSAyLjQgNS4xIDMuNS0yIDQu'
    b'Ny00IDguMi0yLjEgMy41IDIgNyA1LjkgOC43IDkuOCAwIDItMS44IDkuOCAwIDIxLjYuOSAz'
    b'LjkgOS43IDMyLjMgOS43IDM1LjIgMCA0LTIuNyA2LTQuNSA5LjkgNyA1LjkgMCAxNS43LTMu'
    b'NSAyMS42IDI2LjIgNS45IDE0IDE3LjYgMzQuOSAxMS43LTUuMiAxMy44LTMuNCAxMi43IDEu'
    b'OCAyNi40LTEwLjQgNy44LS4yIDEwLjItNy4xIDIwLS41LjcgNC4xIDguNiAxMC41IDguNi0x'
    b'LjcgMTUuNi03IDkuOC01LjIgMzMuMy0xMy43LS4zLTguMiAxNy42LTE3LjQgMTUuNy41IDEx'
    b'LjIgNS4yIDEyLjIgMy40IDIzLjUtNyAyLTcgMi0xMC40IDcuOWwtNS4yLTJjLTEuOCA5Ljgt'
    b'NS4zIDExLjggMCAyMS42IDAgMC02LjguMi04LjggMC0uMSAzLjQgMyA0LjMgMy41IDcuOC0u'
    b'MiAxLjQtOS45IDcuNi0xNy40IDcuOS0yIDQuOCA1LjIgMTAgNC44IDEyLjQtOC4yIDEuOC0x'
    b'MS44IDEzLTExLjggMTNzNC4yIDIgMy41IDRjLTIuMi0xLjgtMy41LTItNy0yLTEuNy41LTYg'
    b'MC0xMCA3LjctNC41IDEuNi02LjYgMS0xMCA2LTEuNS00LjctMy43LjEtNi4zIDItMi43IDEu'
    b'OC02LjIgNi41LTYuNyA2LjMuMS0xLjQgMS42LTYuMyAxLjYtNi4zTDM5OSA0MzdjLS43LjEt'
    b'LjUtNS43LTIuMi01LjUtMS43LjItNi40IDcuMy04IDcuNS0xLjYuMi0yLjEtMi4yLTMuNS0y'
    b'LTEuNC4yLTQgNy41LTUgNy43LTEgLjEtNS00LjUtOC4zLTMuOC0xNy4xIDYuOC0xOS45LTEz'
    b'LjQtMjIuNS0yLTMuNi0yLjItMy0xLTYuNy4xLTIuMy43LTIuNS0zLjQtNC42LTMuNC00LjEu'
    b'Mi00IDQuNi02LjIgMy4zLTEuOC05LjItMTMtNy42LTE0LTExLjUtMS00IDQuOC00IDYuNi02'
    b'LjggMS40LTQtMS41LTUuNiA0LjMtOS40IDcuNS01LjcgNi44LTE5LjggNC45LTI1LjMgMCAw'
    b'LTUuOS0xNy43LTctMTcuNy0zLjUtMS0zLjUgNi41LTguNiA4LjYtMTAuNSA0LTI5LTkuOS0z'
    b'Mi4yLTkuOS0yLjkgMC0xNi41IDMuNi0xNi00LTIgNy40LTkuNSAxLjctMTAgMS43LTcgMC00'
    b'LjMgNi4xLTkgNS45LTIuMS0uOC0yMy42LTIuMy0yMy42LTIuM3Y0bC0yNi4xLTExLjhjLTEw'
    b'LjUtNC01LjMtMTMuNy0yMi43LTcuOHYtMTEuOGgtOC43YzMuNS0yMy42IDAtMTEuOC0xLjgt'
    b'MzMuNGwtNyAyYy03LTEwLjYgOS44LTguNi01LjItMTUuNyAwIDAgLjMtMTEuNy0zLjUtNy44'
    b'LS43LjUgMS44IDUuOCAxLjggNS44LTE0LTItMTcuNC01LjgtMTcuNC0yMS41IDAgMCAxMS40'
    b'IDEuOCAxMC40IDAtMS42LTMtMy43LTIyLTMuNC0yMy40LS4xLTIuNiAxMC43LTkgOC42LTE1'
    b'LjIgMS40LS42IDUuMy0uNyA1LjMtLjciLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiNmZmYiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMi41IiBkPSJN'
    b'NTk1LjUgMjk3LjZjLS42IDEuMy0uNSAyLjYuMSAzLjYgMS4xLTEuNy4yLTIuNCAwLTMuNnpt'
    b'LTQ3Ni0xNDkuNHMtMy0uNC0yLjQgMi4zYzEtMiAyLjMtMi4yIDIuNC0yLjN6bS0uMy02LjRj'
    b'LTEuNyAwLTMuOC0uMi0zIDIuNSAxLTIuMSAzLTIuNCAzLTIuNXptMTIuNyAzNi4zczIuNi0u'
    b'MiAyIDIuNWMtMS0yLTItMi40LTItMi41eiIgdHJhbnNmb3JtPSJzY2FsZSguODYwMjEgLjk2'
    b'Nzc0KSIvPgo8L3N2Zz4K', 'AQ')

AQ = b64_AQ
index.append("AQ")
index.append("ATA")
index.append("Antarctica")
catalog["AQ"] = AQ
catalog["ATA"] = AQ
catalog["Antarctica"] = AQ
country["Antarctica"] = ('AQ', 'ATA', 0)
lookup["AQ"] = ('AQ', 'ATA', 'Antarctica', 0)
lookup["ATA"] = ('AQ', 'ATA', 'Antarctica', 0)
lookup["Antarctica"] = ('AQ', 'ATA', 'Antarctica', 0)
details["AQ"] = {"continent":"","capital":"","currency":"No universal currency","web":".aq","lang":"","tz":"","altname":""}
#----------------------------------------------------------------------
b64_AR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'Cjxzdmcgd2lkdGg9IjgwMCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4'
    b'bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgdmVyc2lvbj0iMS4w'
    b'IiBoZWlnaHQ9IjUwMCI+CiA8cmVjdCB3aWR0aD0iODAwIiBmaWxsPSIjNzRhY2RmIiBoZWln'
    b'aHQ9IjUwMCIvPgogPHJlY3QgeT0iMTY2LjY3IiB3aWR0aD0iODAwIiBmaWxsPSIjZmZmIiBo'
    b'ZWlnaHQ9IjE2Ni42NyIvPgogPGcgaWQ9InJheXMiPgogIDxwYXRoIGlkPSJyYXkxIiBzdHJv'
    b'a2Utd2lkdGg9IjEuMTExNiIgc3Ryb2tlPSIjODUzNDBhIiBmaWxsPSIjZjZiNDBlIiBkPSJt'
    b'Mzk2Ljg0IDI1MS4zMWwyOC40NTQgNjEuOTkyczAuNDg5NiAxLjE4NSAxLjI4IDAuODU4NmMw'
    b'Ljc5MDItMC4zMjY3IDAuMjk4OC0xLjUxMTYgMC4yOTg4LTEuNTExNmwtMjMuNzE1LTYzLjk1'
    b'Nm0tMC42OCAyNC4xMmMtMC4zNDY1IDkuNDI3OCA1LjQ1MjYgMTQuNjEzIDQuNjk0MyAyMy4w'
    b'MzItMC43NTY5IDguNDIgMy44NjczIDEzLjE4IDQuOTM5NiAxNi40NTQgMS4wNzMzIDMuMjc0'
    b'NC0xLjE2IDUuMjMyMy0wLjE5OCA1LjY5ODIgMC45NjMzNiAwLjQ2NjIgMy4wNy0yLjEyMDcg'
    b'Mi4zODMzLTYuNzc1Ni0wLjY4Njc1LTQuNjU0OS00LjIyMDQtNi4wMzY4LTMuMzg5OC0xNi4z'
    b'MiAwLjgzLTEwLjI4My00LjIwNi0xMi42NzgtMi45OC0yMi4wNTgiLz4KICA8dXNlIHhsaW5r'
    b'OmhyZWY9IiNyYXkxIiB0cmFuc2Zvcm09InJvdGF0ZSgyMi41IDQwMCwyNTApIi8+CiAgPHVz'
    b'ZSB4bGluazpocmVmPSIjcmF5MSIgdHJhbnNmb3JtPSJyb3RhdGUoNDUgNDAwLDI1MCkiLz4K'
    b'ICA8dXNlIHhsaW5rOmhyZWY9IiNyYXkxIiB0cmFuc2Zvcm09InJvdGF0ZSg2Ny41IDQwMCwy'
    b'NTApIi8+CiAgPHBhdGggaWQ9InJheTIiIGZpbGw9IiM4NTM0MGEiIGQ9Im00MDQuMzEgMjc0'
    b'LjQxYzAuNDUzMzQgOS4wNTM4IDUuNTg2NyAxMy4wNjMgNC41Nzg3IDIxLjMxNCAyLjIxMzMt'
    b'Ni41MjQ5LTMuMTIzMy0xMS41ODMtMi44Mi0yMS4yMm0tNy42NDg3LTIzLjc1N2wxOS40ODcg'
    b'NDIuNTc3LTE2LjMyOS00My44ODciLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNyYXkyIiB0cmFu'
    b'c2Zvcm09InJvdGF0ZSgyMi41IDQwMCwyNTApIi8+CiAgPHVzZSB4bGluazpocmVmPSIjcmF5'
    b'MiIgdHJhbnNmb3JtPSJyb3RhdGUoNDUgNDAwLDI1MCkiLz4KICA8dXNlIHhsaW5rOmhyZWY9'
    b'IiNyYXkyIiB0cmFuc2Zvcm09InJvdGF0ZSg2Ny41IDQwMCwyNTApIi8+CiA8L2c+CiA8dXNl'
    b'IHhsaW5rOmhyZWY9IiNyYXlzIiB0cmFuc2Zvcm09InJvdGF0ZSg5MCA0MDAsMjUwKSIvPgog'
    b'PHVzZSB4bGluazpocmVmPSIjcmF5cyIgdHJhbnNmb3JtPSJyb3RhdGUoMTgwIDQwMCwyNTAp'
    b'Ii8+CiA8dXNlIHhsaW5rOmhyZWY9IiNyYXlzIiB0cmFuc2Zvcm09InJvdGF0ZSgyNzAgNDAw'
    b'LDI1MCkiLz4KIDxjaXJjbGUgcj0iMjcuNzc4IiBzdHJva2U9IiM4NTM0MGEiIGN5PSIyNTAi'
    b'IGN4PSI0MDAiIHN0cm9rZS13aWR0aD0iMS41IiBmaWxsPSIjZjZiNDBlIi8+CiA8cGF0aCBp'
    b'ZD0ibG93ZXllY29udG91ciIgZmlsbD0iIzg0MzUxMSIgZD0ibTQwOS40NyAyNDQuMDZjLTEu'
    b'ODk2NyAwLjAwMDAzLTMuNzEzMSAwLjgyMTgzLTQuNzgxMiAyLjUzMTIgMi4xMzY3IDEuOTIy'
    b'NyA2Ljg1NjUgMi4xMzE4IDEwLjA2Mi0wLjIxODc1LTEuMzg4My0xLjQ5NTQtMy4zODQ1LTIu'
    b'MzEyNS01LjI4MTItMi4zMTI1em0tMC4wMzEyIDAuNDM3NWMxLjg0NjItMC4wMzM1IDMuNTcx'
    b'NyAwLjgxNDQ2IDMuODEyNSAxLjY1NjItMi4xMzY3IDIuMzUwNC01LjU1MDggMi4xNDYzLTcu'
    b'Njg3NSAwLjQzNzUgMC45MzQ4LTEuNDk1NyAyLjQzOTEtMi4wNjc3IDMuODc1LTIuMDkzOHoi'
    b'Lz4KIDx1c2UgeGxpbms6aHJlZj0iI3VwcGFscGVicmEiIHRyYW5zZm9ybT0ibWF0cml4KC0x'
    b'IDAgMCAxIDgwMC4yNSAwKSIvPgogPHVzZSB4bGluazpocmVmPSIjZXllYnJvd19ub3NlIiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgtMSAwIDAgMSA4MDAuMjUgMCkiLz4KIDx1c2UgeGxpbms6aHJl'
    b'Zj0iI3B1cGlsIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgxOC44NjIpIi8+CiA8dXNlIHhsaW5r'
    b'OmhyZWY9IiNsb3dwYWxwZWJyYSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEgODAwLjI1'
    b'IDApIi8+CiA8cGF0aCBkPSJtMzk1Ljc1IDI1My44NGMtMC45MTM0MSAwLjE2NjY4LTEuNTYy'
    b'NSAwLjk3NzI3LTEuNTYyNSAxLjkwNjIgMCAxLjA2MTQgMC44Nzc0OCAxLjkwNjIgMS45Mzc1'
    b'IDEuOTA2MiAwLjYyNjY3IDAgMS4yMDI1LTAuMjk2OCAxLjU2MjUtMC44MTI1IDAuNzM5NTIg'
    b'MC41NTYxNCAxLjc2NDYgMC42MTUxMSAyLjMxMjUgMC42MjUgMC4wODQzIDAuMDAyIDAuMTkz'
    b'MTIgMCAwLjI1IDAgMC41NDc5MS0wLjAxIDEuNTczLTAuMDY4OSAyLjMxMjUtMC42MjUgMC4z'
    b'NiAwLjUxNTcgMC45MzU4MyAwLjgxMjUgMS41NjI1IDAuODEyNSAxLjA2IDAgMS45Mzc1LTAu'
    b'ODQ0ODggMS45Mzc1LTEuOTA2MiAwLTAuOTI4OTgtMC42NDkxOC0xLjczOTYtMS41NjI1LTEu'
    b'OTA2MiAwLjUxMyAwLjE4MDkgMC44NDM3NSAwLjY3NjUgMC44NDM3NSAxLjIxODggMCAwLjcw'
    b'NzQtMC41NzEyNCAxLjI4MTItMS4yODEyIDEuMjgxMi0wLjY4MDQgMC0xLjI0MTMtMC41NDAx'
    b'NS0xLjI4MTItMS4yMTg4LTAuMjA4NjIgMC40MTYzNy0xLjAzNDEgMS42NTUxLTIuNjU2MiAx'
    b'LjcxODgtMS42MjIyLTAuMDYzNi0yLjQ0NzYtMS4zMDI0LTIuNjU2Mi0xLjcxODgtMC4wNCAw'
    b'LjY3ODYtMC42MDA4NSAxLjIxODgtMS4yODEyIDEuMjE4OC0wLjcxMDAxIDAtMS4yODEyLTAu'
    b'NTczODUtMS4yODEyLTEuMjgxMiAwLTAuNTQyMjUgMC4zMzA3NS0xLjAzNzggMC44NDM3NS0x'
    b'LjIxODh6IiBmaWxsPSIjODUzNDBhIi8+CiA8cGF0aCBkPSJtMzk3Ljg0IDI1OS41M2MtMi4x'
    b'MzggMC0yLjk4MjkgMS45MzY4LTQuOTA2MiAzLjIxODggMS4wNjg3LTAuNDI2MzMgMS45MDk2'
    b'LTEuMjY5MyAzLjQwNjItMi4xMjUgMS40OTYtMC44NTQ0MiAyLjc3MTcgMC4xODc1IDMuNjI1'
    b'IDAuMTg3NWgwLjAzMTJjMC44NTMyIDAgMi4xMjktMS4wNDE2IDMuNjI1LTAuMTg3NSAxLjQ5'
    b'NjcgMC44NTU5IDIuMzY4OCAxLjY5ODcgMy40Mzc1IDIuMTI1LTEuOTIzMy0xLjI4Mi0yLjc5'
    b'OTYtMy4yMTg4LTQuOTM3NS0zLjIxODgtMC40MjY2IDAtMS4yNzE2IDAuMjMwNTUtMi4xMjUg'
    b'MC42NTYyNWgtMC4wMzEyYy0wLjg1MzM0LTAuNDI2NDItMS42OTgzLTAuNjU2MjUtMi4xMjUt'
    b'MC42NTYyNXoiIGZpbGw9IiM4NTM0MGEiLz4KIDxwYXRoIGQ9Im0zOTcuMTIgMjYyLjA2Yy0w'
    b'Ljg0MzkgMC4wMzc0LTEuOTU5NiAwLjIwNjc1LTMuNTYyNSAwLjY4NzUgMy44NDczLTAuODU0'
    b'MzQgNC42OTYyIDAuNDM3NSA2LjQwNjIgMC40Mzc1aDAuMDMxMmMxLjcxIDAgMi41NTg4LTEu'
    b'MjkyIDYuNDA2Mi0wLjQzNzUtNC4yNzQ0LTEuMjgyLTUuMTI0Mi0wLjQzNzUtNi40MDYyLTAu'
    b'NDM3NWgtMC4wMzEyYy0wLjgwMTI1IDAtMS40MzcyLTAuMzEyNC0yLjg0MzgtMC4yNXoiIGZp'
    b'bGw9IiM4NTM0MGEiLz4KIDxwYXRoIGQ9Im0zOTMuNzUgMjYyLjcyYy0wLjI0ODE5IDAuMDAz'
    b'LTAuNTE4NzEgMC4wMDUtMC44MTI1IDAuMDMxMiA0LjQ4OCAwLjQyNzY2IDIuMzMwNiAzIDcu'
    b'MDMxMiAzaDAuMDMxMmM0LjcwMDcgMCAyLjU3NDUtMi41NzI0IDcuMDYyNS0zLTQuNzAwNy0w'
    b'LjQyNjYtMy4yMTQ2IDIuMzQzOC03LjA2MjUgMi4zNDM4aC0wLjAzMTJjLTMuNjA3NSAwLTIu'
    b'NDk1OS0yLjQyMTUtNi4yMTg4LTIuMzc1eiIgZmlsbD0iIzg1MzQwYSIvPgogPHBhdGggZD0i'
    b'bTQwMy44NSAyNjkuNjZjMC0yLjEyMzQtMS43MjMzLTMuODQ2NS0zLjg0NjMtMy44NDY1LTIu'
    b'MTIzMyAwLTMuODQ2MyAxLjcyMy0zLjg0NjMgMy44NDY1IDAuNDIzLTEuNzgxIDIuMDE2Ni0z'
    b'LjAzOTMgMy44NDYzLTMuMDM5MyAxLjgzMzMgMCAzLjQyNCAxLjI1ODYgMy44NDYzIDMuMDM5'
    b'M3YwIDB6IiBmaWxsPSIjODUzNDBhIi8+CiA8cGF0aCBpZD0iZXllYnJvd19ub3NlIiBmaWxs'
    b'PSIjODUzNDBhIiBkPSJtMzgyLjczIDI0NC4wMmM0LjkxNDYtNC4yNzI5IDExLjExLTQuOTE0'
    b'NyAxNC41My0xLjcwODYgMC44MzcgMS4xMjA3IDEuMzczMyAyLjMxOSAxLjU5MzQgMy41Njk2'
    b'IDAuNDMwMiAyLjQzMy0wLjMzMDMgNS4wNjE3LTIuMjM2NyA3Ljc1NTkgMC4yMTUxLTAuMDAx'
    b'IDAuNjQzNSAwLjIxMjQgMC44NTY4IDAuNDI2NiAxLjY5NjctMy4yNDQgMi4yOTY3LTYuNTc2'
    b'MSAxLjc0LTkuNzQ1NC0wLjE0NTgtMC44MjgtMC4zNzM1LTEuNjQzLTAuNjY5Ni0yLjQzNTct'
    b'NC43MDA3LTMuODQ1Mi0xMS4xMS00LjI3MjktMTUuODExIDIuMTM3N3oiLz4KIDxwYXRoIGlk'
    b'PSJ1cHBhbHBlYnJhIiBmaWxsPSIjODUzNDBhIiBkPSJtMzkwLjQyIDI0Mi43NGMyLjc3Njcg'
    b'MCAzLjQxODYgMC42NDE3IDQuNzAwNyAxLjcxIDEuMjgzMyAxLjA2ODMgMS45MjMzIDAuODU0'
    b'MSAyLjEzNjcgMS4wNjgzIDAuMjEyNCAwLjIxNDIgMCAwLjg1NDEtMC40MjY2IDAuNjM5OXMt'
    b'MS4yODMzLTAuNjM5OS0yLjU2MzMtMS43MDg2Yy0xLjI4MzMtMS4wNjk2LTIuNTYzMy0xLjA2'
    b'ODMtMy44NDYzLTEuMDY4My0zLjg0NjMgMC01Ljk4MyAzLjIwNDYtNi40MDk0IDIuOTkwNy0w'
    b'LjQyNjYtMC4yMTQyIDIuMTM2Ny0zLjYzMjUgNi40MDk0LTMuNjMyNXoiLz4KIDx1c2UgeGxp'
    b'bms6aHJlZj0iI2xvd2V5ZWNvbnRvdXIiIHRyYW5zZm9ybT0idHJhbnNsYXRlKC0xOS4xODEp'
    b'Ii8+CiA8Y2lyY2xlIGlkPSJwdXBpbCIgY3k9IjI0Ni4xNSIgY3g9IjM5MC41NCIgcj0iMS45'
    b'MjMiIGZpbGw9IiM4NTM0MGEiLz4KIDxwYXRoIGlkPSJsb3dwYWxwZWJyYSIgZmlsbD0iIzg1'
    b'MzQwYSIgZD0ibTM4NS4yOSAyNDcuNDRjMy42MzI3IDIuNzc4MyA3LjI2NSAyLjU2NDQgOS40'
    b'MDE3IDEuMjgyIDIuMTM2Ny0xLjI4MiAyLjEzNjctMS43MDg2IDEuNzEtMS43MDg2LTAuNDI2'
    b'NiAwLTAuODUzMiAwLjQyNjYtMi41NjMzIDEuMjgxLTEuNzEgMC44NTU5LTQuMjczIDAuODU1'
    b'OS04LjU0Ni0wLjg1NDF6Ii8+Cjwvc3ZnPgo=', 'AR')

AR = b64_AR
index.append("AR")
index.append("ARG")
index.append("Argentina")
catalog["AR"] = AR
catalog["ARG"] = AR
catalog["Argentina"] = AR
country["Argentina"] = ('AR', 'ARG', 0)
lookup["AR"] = ('AR', 'ARG', 'Argentina', 0)
lookup["Buenos Aires Argentina"] = ('AR', 'ARG', 'Argentina', 0)
lookup["ARG"] = ('AR', 'ARG', 'Argentina', 0)
lookup["Argentina"] = ('AR', 'ARG', 'Argentina', 0)
details["AR"] = {"continent":"Americas","capital":"Buenos Aires","currency":"Argentine Peso","web":".ar","lang":"Es-AR | en | it | de | fr | gn","tz":"-03:00","altname":""}
#----------------------------------------------------------------------
b64_AS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWFzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwNiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDBaIi8+CiAgPHBhdGggZmlsbD0iI2JkMTAyMSIgZD0ibS0uNiAyNDAgNjQw'
    b'LTI0MHY0ODBaIi8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTU5LjcgMjQwIDU4MC0yMTQu'
    b'M3Y0MjguNiIvPgogIDxwYXRoIGQ9Ik00NzQgMjcwLjRjNS4xLjMgNSA1LjQgNSA1LjRsMTgg'
    b'LjRjMi4zLTYuMyA0LjgtNS42IDkuMi0yLjRhMzIuOSAzMi45IDAgMCAwIDguNyA0LjJjMS43'
    b'LTkgMTQuNS03LjIgMTQuNS03LjIgNS42LTEzIDYtMTIuOSAyLjctMTQuNWExMC43IDEwLjcg'
    b'MCAwIDEtNC42LTQuNWMtMy0zLjctNC42LTkuMS01LTEyLjQtLjQtMy4zLTQuMiAxLjYtNSAu'
    b'Ni0uNi0xLTYuMy0uNC02LjMtLjQgMS40IDEuNS0zLjQuNi0zLjQuNi41LjQgMCAxLjcgMCAx'
    b'LjctLjQtLjYtNC4xLTEuMi00LjEtMS4yYTYuMSA2LjEgMCAwIDEtMS4xIDEuNmMtMi0uOC02'
    b'LS43LTYtLjdhMjAgMjAgMCAwIDAtMTAuOSAyLjhjLTEuNi45LTcuNCAzLjgtMTIuMyA4LjUt'
    b'NC43IDQuNi03LjQgNC03LjQgNC0xLjQgNS4yLTEyLjggMTEuNS0xMi44IDExLjUtMS44IDEu'
    b'Ni03LjYgMi40LTEwLjUgMC0yLjktMi40IDAtNi45IDAtNi45IDEuMi0yIDIuMi0xLjkgMi4z'
    b'LTkgLjEtNC43IDUtOC41IDEwLTE0IDYuMy02LjggMTUtMTggMTUtMTggMCAzLjQgMS44IDQg'
    b'MS44IDQgMS43LTMuNSA0LjItNi4zIDQuMi02LjMuMS4zLjUuNC41LjQgMi0yLjYgMy0zLjYg'
    b'My0zLjYtLjUtLjMtNiAwLTExIDQuNHMtOC40IDMtOC40IDNjLTMuNS0xLjItMy44LTQtMy44'
    b'LTQtMi41LTEwLjkgNy40LTE4LjcgNy40LTE4LjctMTMuNC0zLjItMy43LTIwLjMgMTMtMjcu'
    b'NSAxNi42LTcuMiAxNi40LTEwLjUgMTYuNC0xMC41YTEzIDEzIDAgMCAxIDEuOCAzYy4xIDAg'
    b'MS40LTEuOSAxMS02LjEgOS42LTQuMyAxNC4yLTggMTQuMi04IDEuMiAyLjQgMSA0IDEgNCAy'
    b'Ni4zLTkuMSA1Mi0zMC4yIDUyLTMwLjIuOCAxLjcuNSA0LjQuNSA0LjQgNC4yLTQgMTkuNy0x'
    b'My4yIDE5LjctMTMuMmE4LjYgOC42IDAgMCAxLTQuNiA4LjIgNy43IDcuNyAwIDAgMSAuOCAy'
    b'LjMgMzYwIDM2MCAwIDAgMCAxNC40LTkuNWM0LjMgMy43LjQgOS44LjQgOS44IDEuNi0uMyAy'
    b'LjYtMS42IDIuNi0xLjYgMS4yIDYuNC01LjkgMTItNS45IDEyIDEuMyAwIDMuMy0xLjMgMy4z'
    b'LTEuMy0xLjMgNy0xNC40IDE0LjYtMTQuNCAxNC42IDEuOSAxLjggMCA0LTEuNiA1LTEuNSAx'
    b'LTQuMyAzLjMtMy40IDQuMi44IDEgNi43LTMuMiA2LjctMy4yIDEgMi45LTYuNSA4LjYtNi41'
    b'IDguNiA1LjIuNyAxOS42LTUuOSAxOS42LTUuOS0xLjEgNS42LTYuNiAxMC0xMy4zIDEyLjUt'
    b'Ni43IDIuNS02LjQgMy02LjQgMyAxLjIuOCAxMC41LTEuOCAxMC41LTEuOC0yLjggNi4yLTEy'
    b'LjUgMTAuNS0xMi41IDEwLjUgMi43IDIuMyA2LjMtLjQgMTAtMi45YTU4LjIgNTguMiAwIDAg'
    b'MSAxNC02LjRjNS4zLTEuOSA5LjItLjUgOS4yLS41YTEyIDEyIDAgMCAxIDguNC42YzguNy43'
    b'IDkuNiAzLjkgOS42IDMuOSAxIC4yIDEuNy42IDQgMi4zIDIuMSAxLjYgMiA2LjYgMiA5LjIt'
    b'LjIgMi40LS45IDIuNC0xLjMgMy0uNC44LS41IDEuNi0uNSAyLjUgMCAxLTIuMiA2LjktMTUu'
    b'NyA2LjloLTIwLjNjLTEuMiAwLTIuNS43LTIuNS43LTUuNyAyLjgtMi43LTItOS40IDMuNi02'
    b'LjggNS41LTEwLjIgNC42LTEwLjIgNC42QTkwLjEgOTAuMSAwIDAgMSA1NjggMjIxYy00IDIu'
    b'Ni0zLjMgMi4zLjMgMy44czguOCAwIDguOCAwYy0zLjQgMi4zLTEgMy40LTEgMy40IDQuNC0y'
    b'LjcgNy4yLTEuNyA3LjItMS43IDEuNCAzLjktMy44IDEwLTMuOCAxMCAyIC4zIDUuOCAwIDUu'
    b'OCAwLTEgMi43LTQuNiA1LjYtNy40IDYuNC0yLjcgMS0yLjMgMS4zLTEuNCAzIC43IDEuNi4x'
    b'IDMuMy4xIDMuMy00LjgtMy4zLTUtLjQtNS0uNC0uNSA0LS40IDkuNi0uNCA5LjYtMy40LTEu'
    b'Ny0zLjUuNS0zLjUuNS0xIDMuNi01LjEgNy43LTUuMSA3LjctLjItMi4yLTIuMi0yLjgtMi4y'
    b'LTIuOC0yLjIgNC4yLTYuMSA2LjctNi4xIDYuNy0uNSAzLjUuNSA4LjYuNSA4LjYtMi42LS42'
    b'LTMuNS0uNi00IDAtLjMuNy42IDEgLjYgMWwzMy40LjhjLjUgMCAyLjUuMyAyLjUgMy44IDAg'
    b'My43LTMgMy45LTMgMy45bC0zNi40LS45cy4xIDEtMS44IDItMS4yLTEuMS0xLjcgMy40Yy0u'
    b'NiA0LjQtNy44LS40LTcuOC0uNC0xLjIgMS44LTQgNC00IDQtMS43LTUtMy40LTYuNC02LTIu'
    b'Mi0yLjYgNC4zIDQuOCAzLjYgNC44IDMuNnM0Mi44LTYuMyA0NS4xLTYuNWMyLjMtLjMgNC45'
    b'LS4xIDYgMy4xIDEgMy4zLTUuMyAzLjgtNS4zIDMuOGwtNDQgNC44Yy0uOSAyLjYtNC41IDIu'
    b'NC00LjUgMi40LjMgMi41LTIuMyA0LTMuNiA1LTEuNC44LTUuNi41LTUuNi41LTUgMy40LTcu'
    b'Ni43LTcuNi43LTMuMyAxLjQtNS40LjgtOC4xLS40LTIuOC0xLjItMi41LTQuNS0yLjUtNC41'
    b'bC0yNy44IDNhNi43IDYuNyAwIDAgMC0yLjIgMS4yYzEgMS4zLTIgNC4zLTIgNC4zLjkuNSAy'
    b'LjUgMi4xIDIuNyA1LjUuMiAzLjctNC41IDQuMy0yLjIgNyAyLjMgMi41IDYuNy4zIDExLjUt'
    b'MnM5LjUtMiAxMS41LTIgNy44IDEuNiAxMS40IDIuOGMzLjYgMS4yIDQuOC40IDUtMS40LjIt'
    b'MS43IDEuOS0yLjMgMS45LTIuMy0uNSAxLjguNSAyLjYuNSAyLjZhMTEgMTEgMCAwIDAgMy43'
    b'LTEuM2MtLjIgMS40LTIgMi4yLTIgMi4yLTMuNCAyLjMgMS40IDEuNSAxLjQgMS41YTQ0IDQ0'
    b'IDAgMCAxIDE1LjQtMS41IDEyMi41IDEyMi41IDAgMCAxIDE0LjMgNS4yYy40LTEuMi4xLTQg'
    b'LjEtNCAzIC44IDQuMiAyLjUgNC4yIDIuNSAxLjItMS4yLjQtMy40LjQtMy40IDkuNyA1LjUt'
    b'MiA4LTUuMSA5LTMgMS0zIDIuMy0zIDIuM2EyOCAyOCAwIDAgMSA2LjQtMS4zYzIuMi0uMiAx'
    b'LjQgMCA2LjUtMSA1LjItMSA3LjggMS4yIDcuOCAxLjItNC4zLjItNS41IDEuNS01LjUgMS41'
    b'IDIuNiAxLjcgMCAzLjQgMCAzLjQtMy44LTUtNy4yLjEtNy4yLjFhMTUuMyAxNS4zIDAgMCAx'
    b'IDYuNCAxLjRsNS40IDIuN2MzLjYgMS42IDIuOS42IDUuNiAxLjYgMi44IDEgMS43IDMuNyAx'
    b'LjcgMy43YTYuOCA2LjggMCAwIDAtMy43LTNjLS4yIDMtMy4xIDMuNS0zLjEgMy41IDMuNi00'
    b'LTQuMS01LjgtNy44LTUuNy0zLjYgMC02LjMgMi40LTYuMyAyLjQgNy4zIDYuOSAxMi4zIDQu'
    b'NiAxMi4zIDQuNi0uOSAyLjUtNi45IDEuNS02LjkgMS41IDIuOCAyLjIgMi41IDMuNiAyLjUg'
    b'My42LTEuNS0xLjQtNC0uNy05LjItNC01LjItMy41LTkuOS0yLjMtOS45LTIuMyA1LjIgNS4z'
    b'LTEuOCA4LjYtMS44IDguNi0yLjYgMS42IDEgMy41IDEgMy41LTMuMi42LTMuNi0yLjYtMy42'
    b'LTIuNi0xLjctLjQtNC4yIDEuNi00LjIgMS42LjItMy4yIDQuNi0xLjYgNC42LTUgLjItMy41'
    b'LTQtNi4yLTE2LjMtNC41LTEyLjQgMS43LTE2LTIuMi0xNi0yLjItMSAwLTEuMiAxLTEuMiAx'
    b'IDIgMiAyLjkgMi44IDIuNiA0LjItLjQgMS4zLjYgMS44LjYgMS44LTIuMy0uMi0yLjQtMi44'
    b'LTIuNC0yLjggMCAxLjEtLjUgMS4yLTEuMyAyLjNzMCAyLjcgMCAyLjdjLTEtLjgtMi43LTEu'
    b'OC0xLTQuMyAxLjItMS44LTIuNy00LjItMi43LTQuMi0xLjUtMS41LTUuNiAwLTUuNiAwYTE0'
    b'LjkgMTQuOSAwIDAgMS0xMy4zLTMuN2MtMSAwLTIuOS0uNi0yLjktLjYtOC45IDQtMTYuNy00'
    b'LjYtMTYuNy00LjYtNi43IDEuMy05LjgtMi0xMS44LTUuMmExMS41IDExLjUgMCAwIDAtNS4y'
    b'LTVjLTIuNi0xLjYtNS4yLTYuMi0yLjYtOC43IDItMi4xIDEuNS0yLjYgMS41LTIuNi0zLjUt'
    b'NS45IDYuMS03LjcgNi4zLTkuMi4zLTIgMi4zLTMuMyA0LjUtMy40IDIuMi0uMiAyLjIgMCAz'
    b'LjctMS40IDEuMy0xLjUgNCAuMyA0IC4zLjctLjQgNS41LTQuMSA5LjctMi4yIDQuMyAxLjkg'
    b'Ny45LjYgNy45LjYgMy0uNyAyOC00IDI4LTQgMS41LTIuNSAyLjctNS40IDkuNi03czEyLTYg'
    b'MTItNmMtMS4yLTEuMi0zLjItMS4yLTQuMi0xLjMtMS4xIDAtMy4yLTItMy4yLTItMS4zLjYt'
    b'MiAuMy0xMSA1LjgtOC4xIDUtOC4zLTQuOC04LjMtNC44SDQ3OWMtLjMgMy43LTMgNS4yLTMg'
    b'NS4ybC02LjUuM2MtMy42LTEuOC0zLjYtOC4yLTMuNi04LjItMTkuNC4zLTMwLjEgNy4yLTMw'
    b'LjEgNy4yLTIyLTExLjItMzkuMi0xMy44LTM5LjItMTMuOGExMjIuNCAxMjIuNCAwIDAgMCA0'
    b'MC44LTEwLjIgNjMuMyA2My4zIDAgMCAwIDI4LjUgOWMuNS01LjQgNC4xLTYuNyA0LjEtNi43'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik00NDIuMyAzMTQuNmMtNS41IDMuMi00'
    b'LjUgNS00IDZzLjUgMi0xIDMuNmMtMS41IDEuNS0xLjQgMi0xLjQgMiAuMyA1LjQgNCA2LjYg'
    b'NS43IDggMS40IDEgMy42IDQuNSAzLjYgNC41IDIuOSA0LjEgNS45IDQuMiA4LjEgNC4yIDIu'
    b'MyAwIDItLjMgMS0xLjNsLTMuNC0yLjdhMTcuNiAxNy42IDAgMCAxIDUuOSA0LjFjNS42IDYu'
    b'MiAxMC44IDUuNCAxMy4xIDUuMiAyLjMtLjMgMi0xLjcgMi0xLjdhOSA5IDAgMCAwLTIuNC0u'
    b'NGMtOC41LS44LTExLTYuNC0xMS02LjRhMjQuMSAyNC4xIDAgMCAwIDE1LjYgNmMyLjQtLjEg'
    b'Mi4zLjYgMS43LjhsLTIuNC0uMmMtMS4xIDAtMS4xLjMtLjkuOC4zLjQgMS40LjQgMi43LjQg'
    b'MS40IDAgLjMuMSAzLjggMi44IDMuNiAyLjggMTIuMy41IDEyLjMuNS01LjctMS4zLTYuNC00'
    b'LTYuNC00LTcuNyAxLTEwLjgtMy42LTEwLjgtMy42YTMyLjUgMzIuNSAwIDAgMC01LjYtMy41'
    b'IDguOSA4LjkgMCAwIDEtNS01LjhjMS4zIDEuOCAzLjcgMy44IDYuNyA0LjYgMyAuOCAzLjgg'
    b'MS4yIDMuOCAxLjJhMy44IDMuOCAwIDAgMS0yLjMtLjJjLTMtMS0xLjMuMy0xLjMuMyAzLjQg'
    b'Mi43IDQuMyAyLjUgNC4zIDIuNSA4LjYuOSA0LjMtMi42IDQuMy0yLjYgNi4yIDEuNSA3LjIt'
    b'LjggNy4yLS44IDEuMyAyLjcgNiAxLjcgNiAxLjctNi4yIDMtMS41IDIuMS0xLjUgMi4xIDYu'
    b'My0xLjEgNy42LjUgNy42LjUgMS42IDEuNSAzLjQgMS40IDMuNCAxLjRzMS4yIDAgMy41LjRj'
    b'Mi40LjUgNi4yIDIuNSA5LjYgMi4yIDMuNS0uNSA0IC42IDQgLjYtLjYtLjMtMi4yLS41LTQu'
    b'OC43LTIuNyAxLjMtNy40IDEuNi0xNC4yIDBzLTcuNC0xLjMtNy40LTEuM2E4LjcgOC43IDAg'
    b'MCAxIDMuNCA0Yy4zIDEuMiAxLjUgMS4yIDEuNSAxLjIuNS0xLjUgMi41LTIuMSAyLjUtMi4x'
    b'YTI3IDI3IDAgMCAwIDUgMi44Yy40LS43IDAtMS4zIDAtMS4zIDIuNiAyLjUgNS42IDEuNyA1'
    b'LjYgMS43LjgtLjUuNi0yIC42LTIgMSAwIDEuMi42IDIgMS4yLjcuNCAzIC4xIDMgLjEtLjgt'
    b'LjQtMS41LTEuNy0xLjUtMS43IDMuNS0yLjMgMTEtMS4zIDExLTEuMyA1LjMgMSA0LjcgNC41'
    b'IDQuNyA0LjVhMTAgMTAgMCAwIDEgMi41IDIuMWMuNS0xLjIgMC0yLjUgMC0yLjUgMi42IDEu'
    b'MiAzIDQgMyA0IDMtMy4yLTIuNy02LjgtMi43LTYuOCAyLjctLjQgNS43LS4yIDcuNSAwYTEz'
    b'LjggMTMuOCAwIDAgMSA2LjYgMy4xYzIuMSAxLjcgNS45IDIuNSA1LjkgMi41LS4xLS43LTIu'
    b'Mi0yLTIuNy0yLjItLjQtLjItLjYtLjktLjYtLjkgMS45LjQgMy4xLjIgMy4xLjItNi40LTQt'
    b'OC4xLTUuOS04LjEtNS45IDIuNC4zIDMuOC0xLjIgMy44LTEuMi01LjEgMC01LjQtMS4yLTUu'
    b'NC0xLjIuNy4xIDMuMS43IDYuMi4xczcuMiAwIDcuMiAwYy0yLjItMy42LTEwLjctMy0xMy41'
    b'LTIuOC0yLjguMi0zLjgtLjItMy44LS4yLjQtLjIuOS0uNiAzLS43IDIuMiAwIDQuMy4yIDYu'
    b'OC0xLjYgMi4zLTEuNiA1LjctMSA1LjctMS0uOC0xLjYtNC43LTIuMi04IDAtMy41IDIuMS02'
    b'LjUgMS41LTYuNSAxLjUgNS4zLS44IDYuOS0yLjcgNi45LTIuNy0xLjYtLjQtMi41LjEtNS44'
    b'LjgtMy4yLjYtNC0uNS00LS41IDMuNS0yLjEgNi0zIDYtMy0zLS42LTUuOC0yLTUuOC0yLTMu'
    b'MiAzLTUuNiA0LjYtMTEuNyAxLjYtNi0zLjItOS4yLTIuOC05LjItMi44YTE0LjIgMTQuMiAw'
    b'IDAgMSAxNC44LjZjNCAyLjMgNSAuNCA1IC40LTEuMi0uNy0xLTEuNS0xLTEuNSA5LjYgNC45'
    b'IDEzLjggMiAxNS45LjUgMi4xLTEuNS0xLTMuNC0xLTMuNC0uMiAzLTQgNC42LTcuMiAzLjUt'
    b'My0xLTYtMi40LTEwLjQtNC4zLTQuNC0xLjgtMTAtLjgtMTUuMS4yLTUuMiAxLjEtNS45LjYt'
    b'Ni40LjItLjUtLjQtLjctMS43LTMuNC0uNi0yLjYgMS4xLTguOC0xLjgtMTIuNi0yLjctMy44'
    b'LTEtMTAuMS0uNS0xNS41IDIuNS01LjQgMy4xLTguMiAyLjMtOS44IDEuNi0xLjYtLjgtMi43'
    b'LTIuOC0uOS00LjZzMi0yLjMgMS44LTVjLS4yLTIuNi0yLjgtNC4yLTIuOC00LjIgMi40LTIu'
    b'NSAzLTMgMi4yLTQtLjgtMS4yLjQtMS4yIDEuOC0xLjggMS40LS42LjgtLjcuNS0xLjUtLjQt'
    b'LjgtMS4yLS42LTEuMi0uNi0zLjEuMS00LjktLjgtNC45LS44LTUuMi0yLjQtMTAuMSAyLjMt'
    b'MTAuMSAyLjMtMy0yLjMtMy43LS43LTQuMi0uMi0uNS41LTEuNiAxLTMgMS0xLjIuMi0zLjEu'
    b'Ny0zLjggMS45IDAgMC0uNiAxIC4xIDIgMCAwIC44IDEuMi0uNiAyLjctMS41IDEuNS0yIDEu'
    b'OC0xLjUgMy4zLjQgMS4zLjMgMi40LS4zIDMuMyAwIDAtLjctLjctLjUtMS43LjItMSAuMi0x'
    b'LjYgMC0yIDAgMC0xLjUgMS40LTEuOCAyLjQgMCAwLS42LTEuNiAxLjYtMy43IDItMiAzLTMu'
    b'MiAyLjQtNC0uNC0uNi0yIC40LTIuMy42eiIvPgogIDxwYXRoIGQ9Ik00NDguNCAzMzhzLTIu'
    b'Ny0yLTIuNC00LjljLjMtMi43LjMtMyAwLTMuNyAwIDAtLjUuMy0uNCAxLjQgMCAxLS4yIDIu'
    b'MS0uMyAyLjMgMCAwLTEuMy0yLjMtMi0yLjggMCAwIC42LTIuNC0uMi0zLjQtLjctMS4xLTEu'
    b'NS0xLjItMi40LS44LTEuMi40LTIuMSAxLjUgMiA0LjggMCAwIDEuNSAxLjMgMi41IDMuOSAx'
    b'IDIuNiAyLjggMyAzLjEgMy4yem0xMy03LjhzLS4xLTEuNSAxLjMtNC4zYTYuMSA2LjEgMCAw'
    b'IDAgLjMtNS42Yy0uMy0uOC0uNi0uNS45LTEuNyAxLjctMS41LS43LTMuNCAyLjMtNiAwIDAg'
    b'MS44LTEuNiAyLjMtMi4zIDAgMC0zIDEuNi01LjIgMi41LTIgLjgtOS42IDQuNi04IDcuMSAx'
    b'LjggMi41IDEuNiAyLjcgMS4zIDMuOCAwIDAtNC42LTIuNS0zLTYuNCAwIDAgLjgtMS41IDIu'
    b'Ny0zLjQgMS44LTEuNi44LjQgNC4zLTEuNyAwIDAgMi43LTEuNiA0LjMtMy45IDAgMC0yIDEu'
    b'Mi0yLjYgMS40IDAgMC00IC44LTUuOCAyLjUtMS42IDEuNy01LjEgNC43LTQgOCAwIDAtNC0u'
    b'NC01LTQuNyAwIDAtNy42IDkuNCA4LjQgMTMuOCAwIDAgMyAuOCA1LjYgMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTMxLjYgMjk5YzYtMSA0MC40LTYuMiA0My42LTYuNSAz'
    b'LjQtLjMgNC43LS44IDUuOSAyIDEuMyAzLTQuOCAzLjEtNC44IDMuMWwtNDEuMSA0LjdjLTIg'
    b'LjItMi41LS42LTIuNS0uNmwtMS41LTJzLS41LS42LjQtLjh6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzVhMzcxOSIgZD0iTTQ0Ny4zIDMxNy43cy00LjQgOS4zIDEzIDExLjZjMCAwIC4xLTEgLjgt'
    b'Mi41LjgtMS41IDIuMy00LjUuOC02LjQtMS40LTEuOSAxLjItLjkgMS41LTMuNC41LTIuNS0u'
    b'Mi0yLjIgMS0zLjggMCAwLTUuNCAyLTcuNiA0LjUtMiAyLjQgMi45IDQuMiAwIDYuOSAwIDAt'
    b'Mi41LTEtNC0zLjYgMCAwLTMuMyAwLTUuNS0zLjN6Ii8+CiAgPHBhdGggZD0iTTQ2NC41IDMy'
    b'OS4yczQuMyAzLjcgOS40IDMuNmM1LjEtLjMgNy40LTEuNiA4LjctMy42IDAgMCAxIDEuNSAx'
    b'IDIuNiAwIDAgNC40LTMuNyAxMi0uNXM1LjQgMi4zIDcuMSAyLjVjMCAwLTMuMy0uNS0xMC43'
    b'IDIuOS03LjcgMy41LTI3LjcgMi4zLTI3LjYtNy41eiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3'
    b'MTkiIGQ9Ik00NTcuMyAzMTIuNnMxLjkuMyAzLjgtMS45YzAgMC0yLjYuNS0zLjggMnpNNDQy'
    b'LjYgMzMwcy0zLjYtMi44LTEuMy0zLjRjMCAwIDEuNy0uMyAxLjMgMy40eiIvPgogIDxwYXRo'
    b'IGQ9Ik01MjEuMiAzNDcuOHMyLTMuNSA3LjUtMy41IDYuMSAyLjYgMTMuMSAzYzAgMC04LjQg'
    b'Mi40LTE0LjIuMy0zLTEuMS01LjgtLjItNi40LjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcx'
    b'OSIgZD0iTTQ2Ni4zIDMzMS43czguNCA1IDE1LjctLjVjMCAwIC42LjYgMS4yIDIgMCAwIDUu'
    b'Ni01LjQgMTUuNS40IDAgMC0xLjItLjEtNS45IDEuOC02LjEgMi43LTIxLjQgNC41LTI2LjUt'
    b'My44eiIvPgogIDxwYXRoIGQ9Ik00OTguMyAzMzYuN3M4IDEgMTQuNy42YzQuMS0uMiA4LjYt'
    b'MSA2LjQuNC0yLjMgMS4zLTEuMSAxLjUgOC40LjcgOS40LTEtLjEgMS43IDYuNCAyLjYgMCAw'
    b'LTE1LjkgOC0zNS45LTQuM3oiLz4KICA8cGF0aCBmaWxsPSIjNWEzNzE5IiBkPSJNNTE5LjIg'
    b'MzMxLjdzNC42LTEuNyA5IC4zYzQuMyAyIDMuNiAyLjIgNi41IDIuNSAwIDAtMiAyLjktNi43'
    b'LjYtNC44LTIuMy02LTIuOC04LjgtMy40em01LjIgMTQuM3M0LjYtMi4zIDkuNiAwYy42LjQg'
    b'MiAxIDMuMyAxLjIgMCAwLTMuOCAxLjMtNy44IDAtMS43LS41LTMtLjktNS4xLTEuMnptLTIy'
    b'LjctOC4yczEwLjMgMSAxNS44LS4xYzAgMC02LjQgMyA5LjcgMS43IDAgMCAzLjUtLjQgMyAu'
    b'MS0uMy41LS42IDEgMS4yIDEuNSAwIDAtMTIgNS40LTI5LjctMy4yeiIvPgogIDxwYXRoIGQ9'
    b'Ik00NTAuNyAzMjkuMnMuMi43IDIuNCAxLjdhOC43IDguNyAwIDAgMSA0IDMuOSA1LjYgNS42'
    b'IDAgMCAwIDMuNSAyLjlzLTggMS43LTExLjYtMi42YzAgMC0yLjctMyAxLjYtNiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik01MTMuNyAzNDcuNnMtMy4xLS4yLTcuNS0xLjdjLTQu'
    b'My0xLjUtNS40LS4yLTcuOS0yLTIuNC0xLjktNy4zLS43LTguMi0uNi0xIC4xLTMuNiAwLS4z'
    b'LTIuMSAwIDAtMi42IDAtMy42LTEuNCAwIDAtMS4yIDEuMi01LjYuOCAwIDAgMiAzLTYgMi4x'
    b'YTEwLjMgMTAuMyAwIDAgMCAxMS4xIDNjMCAuMi0uNSAyLjUgMyAzLjUgMy44LjkgNC41IDEu'
    b'NiA2LjQgMi4zIDAgMCAuMy0xLjUtNC42LTUgMCAwIDIuNi0uMiA2LjQuN3MxMi4yIDMuMSAx'
    b'Ni44LjR6bTIgMy43cy44IDEuOCAzLjIgMS40YTE3IDE3IDAgMCAxIDEwLjIuOHMuNy0zLjIt'
    b'Ny0zLjRjMCAwLTQuOC4yLTYuNCAxLjJ6bS02NS4yLTIxcy0zIDIuNS0uMyA1YzIuNCAyLjMg'
    b'Ni4yIDIuMSA4IDIgMCAwLTEtLjYtMi0yLTEtMS41LTEtMi41LTMtMy40LTIuMS0uOS0yLjMt'
    b'MS4xLTIuNy0xLjZ6bS0zLTEyLjZzLTQuNiA5LjMgMTMgMTEuNmMwIDAgMC0xIC43LTIuNS42'
    b'LTEuNSAyLjEtNC41LjgtNi40LTEuNi0xLjkgMS4xLS45IDEuNS0zLjQuNC0yLjUtLjMtMi4y'
    b'IDEtMy44IDAgMC01LjUgMi03LjcgNC41LTIgMi40IDIuOSA0LjIgMCA2LjkgMCAwLTIuNS0x'
    b'LTQtMy42IDAgMC0zLjMgMC01LjUtMy4zeiIvPgogIDxwYXRoIGQ9Ik00OTMuMyAzMzkuM3Mz'
    b'LjctLjYgMTMgMi45YzkuNCAzLjQgMTMuMyAyLjYgMTQuNiAyLjUgMCAwLTUuMiAyLjgtMTMu'
    b'NC0uOC03LjItMy4yLTcuNi0yLTE0LjItNC42eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEi'
    b'IGQ9Ik01NTEuOCAzMzcuMnMyIDAgMy40LjVjMCAwIC43LS43IDIuNy0xIDAgMC0xLjMtMS4y'
    b'LTYuMS41em0tNi40LTUuMnMyLjEgMCAyLjgtMS4yYzAgMC0xLjEtMS4zLTIuOC0yIDAgMCAu'
    b'NCAxLjYgMCAzLjJ6bS03MS43LTIzLjhzLS41LTEgMS44LTEuNGwzMS4zLTQuNXMxLjUgMCAx'
    b'LjcgMWMuMyAxLjEtLjEgMS45LTcuMiAyLjdsLTI1LjYgMy4ycy0xLjkuMy0yLTF6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmYzIyMSIgZD0iTTUwMiAzMDYuOXMwIDQuMSA0LjIgNC43YzQgLjYg'
    b'NS41LS4yIDYuNS0yLjMuMy0uNyAxLjYtNS0uMi01LjMtLjgtLjEtMiAwLTIuOS4zLTEuNC43'
    b'LTIuNyAxLjQtMi4zIDIgMSAxLjYgMS4yIDIgMSAyLTEuMi4zLTEuOC0uNi0yLTEuMi0uMy0u'
    b'OC41LTEuMi0yLjItLjgtMS4yLjEtMiAuMS0yIC42em0xNy41LTMuMmMyIC4zIDEuOSA0Ljgt'
    b'LjYgNi45LTIuOCAyLjItNS40IDEuMy01LjQgMS4zLTEuNC0uNS0xLjItLjQtLjEtMiAxLTEu'
    b'NSAxLjUtMy42LjktNS0uMi0uNS4zLS45IDEtMSAwIDAgMi0uNCA0LjItLjJ6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZmYzIyMSIgZD0iTTUyMS4zIDMwNC4xczEuNiAyLS40IDUuNWMwIDAtLjgg'
    b'MSAxLjEuOSAxLjgtLjIgNi4xLTIuMiA1LjctNC44IDAgMC0uMi0uNi0xLjMtLjZzLS4yLS41'
    b'LjMtLjhjLjQgMCAxLjktLjYtMS45LTMgMCAwLS42LS42LTEuMy0uMy0uNi4yLTIuNiAxLTIu'
    b'NiAyLjIgMCAuNS40IDEgLjQgMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTI1'
    b'LjQgMzAwLjlzMyAyLjEgMyAyLjhjMCAuNi0uMyAxLjUuNSAxLjMuOCAwIDQtLjcgMy0yLjgt'
    b'LjgtMi4xLTEuNy0zLTMuMi0zLjQtMS41LS42LTEuOS4xLTMuMiAxLjEgMCAwLS45LjYtLjEg'
    b'MXptLTE2LjEgM3MuNS0xLjUtMi4yLTIuMmMwIDAgMS4xLTEgMy40LS40IDIuMi40IDIgMiAy'
    b'IDIuMSAwIDAtMS44IDAtMy4yLjV6bTUuOC0uNHMzLS41IDQuNS0uNGMwIDAtMS42LTMuMy01'
    b'LjctMi4zIDAgMCAxLjUgMS44IDEuMiAyLjd6bTUuMy0uOHMwLTEuMSAyLjYtMi4xYzAgMC0x'
    b'LjItMS4yLTMtMS0yIDAtMi41LjctMi41LjdzMi4zLjggMi45IDIuNHptMS0zLjZzMS43LjQg'
    b'Mi43IDEuM2MwIDAgMS41LTEuNyAyLjgtMiAwIDAtMi41LTEuNC01LjUuN3oiLz4KICA8cGF0'
    b'aCBmaWxsPSIjNWEzNzE5IiBkPSJNNDM1LjggMjkwLjlzNy4yLTYuMiAxMS4yLTUuNGM0IC44'
    b'IDIgLjIgNi40LS41IDQuNC0uNiA5LTEuMSAxMC44LS45IDAgMC01LjQtMy44LTE0LjktMy43'
    b'IDAgMC02LjYgMi4zLTExLjMgNS4zIDAgMC04LjktNC45LTE4LTIgMCAwIDkuOSAzLjcgMTUu'
    b'OCA3LjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmYzIyMSIgZD0ibTUxMi4yIDMwMS40IDEuMi0u'
    b'MnMyIDIuNS42IDIuNWMtMS4yIDAtLjgtLjMtMS0xYTIuMyAyLjMgMCAwIDAtLjgtMS4zem0t'
    b'OSAuMnMtLjggMSAuNi44YzEuNy0uMyAxLjQgMCAzLjEtMS4zIDAgMCAxLjItMS4xIDMuMi0u'
    b'NCAwIDAgMS44LjYgMy4yLS4xIDEuNC0uOCAxLjctLjcgMi41LS42LjggMCAuOC4yIDEuNy0u'
    b'NiAxLS43IDIuOC0uMSAzLjktMSAxLjEtMSAyLjUtLjIgMC0yIDAgMC0uNS0uNS0uNS0xIDAg'
    b'MCAxIC40IDEuOCAxIC44LjggMiAuNSAyLjIuNCAwIDAgLjItMi4zIDIuMy00LjMgMi4zLTIg'
    b'Mi4zLTIuMiAxLTIuMnMtMy41LS42LTQuMyAwLTcuMiA0LjgtMTEgNS41Yy0zLjguNy03LjMg'
    b'MS44LTkuNyA1Ljh6bS0xMDEuMy0yMy40czExLjcgMyAxNC4zIDQuMmMwIDAgLjYtMS45LTQu'
    b'Ny0zLjQgMCAwIDEyLjktLjQgMjYuNCA1LjggMCAwIDYuNi01LjYgMjcuNy0zLjkgMCAwIDAt'
    b'MS44LjItMy4zIDAgMC0xNC44LS40LTI4LjQtOC43IDAgMC0xMi4zIDYtMzUuNSA5LjN6bTY0'
    b'LjcgNS42Yy0uNy0xMS44IDMuOC0xMyAzLjgtMTNzMi4xIDAgNC40LjVjMCAwLTMuNiA0LjMt'
    b'Mi42IDEyLjggMCAwIC40IDEuMy0yLjcgMS4zcy0yLjktMS41LTIuOS0xLjV6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzVhMzcxOSIgZD0iTTQ2OS44IDI5MS43cy0yLjMtMi4zLTIuNS00LjljMCAw'
    b'IDAtLjYgMi4yLS42IDIuMyAwIDIuNS0uMiAzIDEuMS42IDEuMyAyIDQgMi4zIDQuM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNDc0LjUgMjg1LjdhMjguMyAyOC4zIDAgMCAx'
    b'LS4yLTQuNWMuMS02LjYgMS4yLTYgMS43LTUuMmgyLjNzLTEuNy03LjQtMy43LTNhMTkgMTkg'
    b'MCAwIDAtMS41IDEwLjRjLjEgMiAuMyAzLjMuNiA0eiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3'
    b'MTkiIGQ9Ik01MDAuMiAyODUuN3M0LjMuOC0yLjMgMi4zYzAgMCAuMyA4LjIgOC4yIDIuNSAw'
    b'IDAgNC43LTMgOC00LjIgMCAwIDEuNi0uNiAxLjQtMS44IDAgMCAuMi0xLjUtMS41LTEuMSAw'
    b'IDAtMS40IDAtMi4zLS4zIDAgMC0xLTEuMi0xLjYtLjgtLjYuNS0yLjEuMi0uOSAxLjcgMS4y'
    b'IDEuNCAxLjUgMSAyIC42LjYtLjQgMy4xLTEuNC45LjdzLTQuMi0xLjItNS0xLjh6bS0yMiAx'
    b'aC0ycy0xIDEuNi0xLjctMWwtLjcgMS42czIuMyA4LjggNC40LS42eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNmZmMyMjEiIGQ9Ik00NzUuNCAyNzYuNnMtMSA1LjguMyA5LjJsMjEuMS41cy0uMi00'
    b'IDAtOS43SDQ5NHMtLjUgNC42IDAgNy41aC0uNXMtLjQtNCAwLTcuNUg0OTFzLS40IDQuMyAw'
    b'IDcuNWgtLjVzLS40LTMuNyAwLTcuNUg0ODhzLS41IDMuOSAwIDcuNWgtLjZzLS41LTMuOSAw'
    b'LTcuNWgtMi43cy0uNiAzLjYgMCA3LjVoLS41cy0uNi0zLjYgMC03LjVoLTIuN3MtLjYgNC4y'
    b'IDAgNy41aC0uNnMtLjQtNCAuMS03LjVoLTIuNXMtLjcgMy41IDAgNy41aC0uN3MtLjQtMyAu'
    b'Mi03LjVoLTIuNnptMjIuMyAxMC40cy0uNS0xMC4yIDEuNC0xM2MyLTIuNiAyLjUtMiA1Ljgg'
    b'MCAzLjQgMi4yIDcuNyA0LjUgOC41IDQuOC42LjMgMS42LjUgMS42IDIuNHMuMyAyLjQtMi42'
    b'IDBhOSA5IDAgMCAwLTIuNy0xLjhjLTIuNi0uOS42LjUgMS41IDEuOS44IDEgMS41IDEtLjYg'
    b'MS41YTIxOSAyMTkgMCAwIDAtMTIuOSA0LjJ6Ii8+CiAgPHBhdGggZD0iTTUwNSAyNzkuNnMt'
    b'MS41LTEuOC41LTIuM2MyLS40IDIuMSAzIDIuNSA1LjEuMyAyLjItMi41LTIuMS0yLjgtMi43'
    b'em0tMi43IDlzLTIuMy45LS43IDEuNmMxLjQuNyA1LjUtMi43IDQuMi0yLjUtMS42LjMtMy41'
    b'IDEtMy41IDF6bTMtM3MyLS4zIDEuNi41Yy0uMyAxLTEgLjQtMS40LjItLjMtLjItMS42LS43'
    b'LS4xLS44eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik01MTYgMjgyLjhzLjYgNCA0'
    b'IDVjMCAwIDIgLjQgMS41LTEuMyAwIDAtLjMtMS41LS42LTItLjMtLjctMS42LTEtMS44LTEu'
    b'MS0uMiAwLS4zLS41LjYtLjIgMSAuMyAxIC40IDEtLjNzLS42LS40LTEuNC0uOGMtLjQtLjIg'
    b'MC0uNC4zLS4zLjQgMCAxLjMuMyAxLjMtMSAwIDAgLjEtLjgtLjktLjgtMS4xIDAtMS0uNi0u'
    b'Ny0uNy4zIDAgMS41LjggMS45LS42LjMtMS4zLTEuNi0uNS0xLjQtMS4yLjMtLjggMS43LjMg'
    b'MS43LS41LjItLjggMS4zLTEuMS0uNi0xLjQtLjktLjEgMC0uNiAxLS40IDEgLjEgMS42LTEu'
    b'MiAyLjMtMS42LjYtLjUgNC4yLTIuNi0uNi0xLjktNC43LjctNi4xIDMtNi4zIDMuNWExMyAx'
    b'MyAwIDAgMC0xLjMgNy42eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik01MjcgMjg1'
    b'LjhjLjcgMCAxLjIgMCAxLjQuNS44IDEuNi0xIDEtMiAyLjJzLTEgMS0yLjQuNWMtMS40LS40'
    b'LTItMi41LTItMi41IDAtLjcuNS0uOCAxLjItLjYgMCAwIDIuMy4yIDMuOSAwem0tNS0uOHMw'
    b'IC40LjkuNWMuNyAwIDMgLjMgNC41LS4xIDAgMCAuNC0uMS4yLTEgMCAwIDAtLjctMS4yLS40'
    b'LTEuMy4yLTMgMC0zLjctLjEtLjYtLjItMSAwLS44IDF6bS0uMi0yLjlzLS4xIDEuMyAxLjEg'
    b'MS40YzEuMy4yIDIuOS4yIDMuNSAwIC41IDAgMS40LS4yIDEuNS0xIDAtLjcuMi0xLjItMS4z'
    b'LS44cy0zLjQgMC0zLjYgMGMtLjEgMC0xLjItLjMtMS4yLjR6bS41LTIuNXMtLjMuNi0uMiAx'
    b'LjJjMCAuNS45LjcgMi41LjdzMy0uMiAzLjItLjdjLjEtLjcuNS0xLjMtLjctMS0xLjMuMS0z'
    b'IC4yLTMuNiAwLS42LS4zLTEuMS0uNC0xLjItLjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcx'
    b'OSIgZD0iTTU4Mi4xIDI4NnMwIDEgLjkgMi4ybC00NS4yLTEuM3MuNi0uNC44LTIuMnoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTIyLjcgMjc3LjhzLS40IDEuMS40IDEuNGMu'
    b'Ny4yIDIuMi40IDQgLjEgMCAwIDEgMCAxLjMtMSAuMy0xIC4zLS40LTIuMy0uOCAwIDAtLjgt'
    b'LjMgMS41LS4zIDAgMCAxLjQgMCAxLjUtLjIuMy0uMiAyLTEuNy0uMy0xLjUtMi4zIDAtMS4x'
    b'LS41IDAtLjUgMS4yIDAgMS42LjMgMiAwczAtLjItLjctLjgtLjEtLjUuMy0uMWMuNS4zLjgu'
    b'NSAxLjMgMHMtLjQtMS4yIDAtMWMuMyAwIC42LjggMiAwIDEuNi0uNyAzLjUtLjMgNCAwIC42'
    b'LjUgMi4yIDEgMy4xIDAgMS0uOC0xLjEtMS43LS4zLTEuOCAxLS4xIDEuNi4yIDEuOS0uNS40'
    b'LS44LTEuNC0xLjQuMy0xLjggMS42LS41LjItNS0uMy01LjUgMCAwLTEuOSAxLjEtMy44IDQu'
    b'My0yLjEgMy4zLTMuMyA1LjItNiA0LjItMy45LTEuNS02IC42LTYuNSAxLTEgLjYgMiAuOC4y'
    b'LjktMS43IDAtMS43LjItMS44LjQtLjIuMyAwIC41LjMuNi4zIDAgLjkuNi0uMS42cy0xLjgt'
    b'LjMtMS41LjljMCAwIDAgLjIuNi4zLjYgMCAuOC44LS4zLjgtLjggMC0uOC4yLS44LjN6bTQu'
    b'MSAxMS4zcy0uNy41LjMuNmMxLjIgMCAxLjcuMyAyLjEtLjNzMS44LS40LjgtMS4yYy0xLS44'
    b'LTEuNi0uMy0zLjIgMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTMxLjUgMjc1'
    b'LjVzMy44LTMuNSA2LjktMS4yYzMuMiAyLjUgMy40IDIuOCAzLjUgMi45IDAgMCAuNC4zLS40'
    b'IDEtLjkuOCAwIC44LjkuM3MxIDAgMS40LjVjLjUuNSAxLjEuOC0uMy44aC00LjZzLTIuMS4y'
    b'LTEtLjdjMS0uOS44LTEuOS4zLTItLjYgMCAwIC42LS4zIDEtLjQuNC0xLjEuNy0xLjkuN3Mt'
    b'MS40LjYtLjIgMWMxLjEuNC0uMi43LS44LjdzLTMuNS4yLS41LjZjMyAuMy0uMy4zIDIgMS41'
    b'IDIuNCAxLjQuNiA0LjMtLjMgNC42IDAgMC0xIC41LjIuNCAxLjMtLjIgMi0uMyAxIC40LS44'
    b'LjYtMi42IDIuOS01IDEuMiAwIDAtMS4yLS42LjgtLjcgMiAwLTEuNi0uNS0yLjMtMS0uNS0u'
    b'My0zLTIuNy0xLjUtMi41IDEuNi40IDEtLjUuMS0uOC0uOC0uMy0xLTEuNiAwLTEuNCAxIC4z'
    b'IDIgLjkgMyAuOC43IDAgLjUtLjMtMS4yLS44LTEuNy0uNi0yLjQtLjctMi0yIC40LTEuNSAy'
    b'LjMuNSAxLjgtLjYtLjQtMS0yLS41LTEuMi0xLjlzMS0uOCAxLjUtLjZjLjMuMSAxIDAtLjEt'
    b'LjgtLjgtLjUgMC0xLjMuMi0xLjR6Ii8+CiAgPHBhdGggZD0iTTUzNC4yIDI3Ni41czAtLjUu'
    b'OC0uNGMuNiAwIC40LS4yLjYtLjQuMiAwIDEuOS41LjMgMS0uNi4zLTEuNi4yLTEuNi0uMnoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTM3LjkgMjgwLjVzLTEuMy42LS4yIDJj'
    b'MSAxIDEgMS41IDEgMi4yLS4xLjggNDMuNCAxLjMgNDMuNCAxLjNzMC0yLjkgMS44LTQuNWwt'
    b'NDYtMXoiLz4KICA8cGF0aCBmaWxsPSIjNWEzNzE5IiBkPSJNNTgyLjggMjg1LjJzLjItMi40'
    b'IDEuNi0zLjFjLjctLjUgMS42LS4zIDIgMS42LjYgMi43LTEuNyA1LjEtMi43IDQtMS0xLS44'
    b'LTIuNS0uOC0yLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzdiM2MyMCIgZD0iTTUzMi45IDI5NS40'
    b'czIuOS0yLjUgMy40LTMuNmMwIDAgNy44IDUuNiA3LjMuNGwuMi0yLjZzMi45LjMgMy4zLTJs'
    b'LTcuMy0uM3MtLjgtLjEtMiAxLjFjLTEgMS4yLTMuNCAyLjUtNS41IDEuNCAwIDAtMS0uOC0x'
    b'LjkgMC0xIC41LTEgLjctLjIgMS41czIuNCAyLjkgMi43IDR6bTE2LjgtMTUuNC00LjMtLjJz'
    b'LTEuNS0yLjItNC42LTQuNmMwIDAtLjktLjQuOC0xLjggMS44LTEuNCAyLjMtMi44IDIuMy0z'
    b'LjUgMC0uNiAwLTEuNy42LTEgLjYuOCA1IDQuOSA1LjggMy43LjYtMS4yLjctMS43LjctMi4x'
    b'LjItLjQuMy0xLjUgMS0uMy42IDEuMSAxIC44IDEuMSAzLjggMCAwIDAgMyAuNSA0IDAgMC01'
    b'LjYtMS43LTMuOCAyem0tMTguNi05LjJzMy4zIDIgNS0uNmMxLjUtMi41IDIuNi0yLjggMS40'
    b'LTUuMy0xLjItMi4zIDAtMy40LjktNC40IDEtMSAxLjgtLjggMS44LTQuNi4yLTMuOSAyLjgt'
    b'NSA0LTYuMyAxLjItMS4yIDQuMi0zLS40LTMuNy00LjQtLjgtMTMuNC0zLTE1LjctNi41LTIu'
    b'My0zLjUtMy4zLTEuNS0zLjMtMS4zIDAgLjItLjggMi43IDEuNSA3LjNzNC4yIDcuNiA2LjUg'
    b'OWMyLjIgMS41IDQuMiAyLjMgMyA1LjRzLTMgOC42LTQuNyAxMXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjNWEzNzE5IiBkPSJNNTQzLjIgMjYxcy42IDggNi4zIDEwLjhjMCAwIDEuMy0zIC44LTYu'
    b'MSAwIDAgMS45LjEgMi40IDEgMCAwIDAtMi4zLTIuNi0zLjItMi43LS43LTEuNC02LS40LTYu'
    b'NS45LS42LjYtMS43IDAtMi42LS43LTEtLjgtMi4zIDEuNC0xLjcgMi4zLjYgMi0uNi41LTEu'
    b'Ny0xLjMtMS4xLTEuMy0yLjUuNy0yLjVzNS0xLjkgMy4yLTIuNGMtMi0uNi0yLjUtMS4zIDAt'
    b'MiAyLjctLjggNC0xLjcgMi0yLTItLjItMy4zLS45LTEuNC0xLjIgMS45LS4zLS4zLTIuMy0y'
    b'LjUtMi4zLTIuMy0uMi03IC43LTMuMy0yLjMgMy44LTMtNS40LS44LTEuNi0yLjggMy44LTIt'
    b'MS4zLTEuMS0yLTEuMXMtLjcgMC0uNC0xYy4yLTEtLjUtMS42LTEuNy0uOS0xIC42LTEgLjYt'
    b'MS0uNyAwLTEuNS0xLjMtLjQtMi4xIDAtLjkuMy0zIDEuOS0zLjkgMS0uNy0uOS0xLjItMS43'
    b'LTMuOC0uMi0yLjYgMS41LTIgLjItMi0uNXMxLTMuNC0yLjQtLjUtLjctMy0zLjUtMWMtMi43'
    b'IDItMyAyLjQtMy41IDEuNS0uNS0xLTEtMS43LTQgLjMtMy4xIDEuOS0uOC0xLjMtLjUtMiAu'
    b'NS0uNiAxLjgtNS0uOS0xLjYgMCAwLTEuMyAyLjQtNC4yLTEuOSAwIDAtMyA0LjMtMy45IDIu'
    b'NC0uOC0yLTEuNS0yLTIuNi0uOC0xIDEuMi0uMi0uMS0uNy0xLjItLjQtMS0uNy0yLjktNS44'
    b'LjgtNS4xIDMuOCAxLjggMS0yLjEgMi43cy0xMy41IDctNC44IDUuOWM4LjctMS4zLTQuMiAz'
    b'LjMtMS4yIDQuMiAzIC44IDIgMy41IDEzLjQuMyAxMS4yLTMgOS40LS40IDE1LjItMyA1Ljgt'
    b'Mi40LTEuNC45IDYuNC44IDcuNy0uMiAxLjMgMCAyLjggMS42IDEuNSAxLjYgOCA1LjMgMTQu'
    b'MSA2IDYuMS42IDcuNy0xLjcgNS45IDEtMS44IDIuNi0yLjQgMy42LTMuNCA0LjYtMSAuOC00'
    b'IDMtNCA2LjYgMCAzLjctNC44IDQuMy0zIDguM2w0LjEtNHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'NWEzNzE5IiBkPSJNNTUzLjMgMjY5LjlzLTEuNC0xLTEuNC0yLjhjMCAwIDEgLjIgMS40Ljgg'
    b'MCAwIDMuNS00LS44LTUuNC00LjEtMS40LTItNS4zLS42LTUuM3MxLjctLjMuNC0yYy0xLjIt'
    b'MS41LTEtMS42IDEuMy0yIDIuMy0uNCAyLjEtMSAxLTEuNWE3LjcgNy43IDAgMCAxLTEuOS0x'
    b'LjZzNi44LTIuOSA0LjYtNC4zYy0yLjItMS4zIDAtMSAyLTIuMyAyLTEuNCAyLjItMS43IDIu'
    b'NS0yLjMgMCAwLTIgLjMtMy40IDAgMCAwIDEuNy0uOSAwLTIuM3MtMi4zLTIuNi01LTJjLTIu'
    b'Ny43LTEuOC0uMi0uOC0xLjNzLjYtMS43LTEuMy0yYzAgMCAuMi0xLjIgMS43LTIuNSAwIDAt'
    b'My43LjItNS0uNCAwIDAgMS42LTEgMS42LTIuMyAwIDAtMiAuNy00LjUuNSAwIDAgMS41LTEu'
    b'MyAxLjUtMi40IDAgMC00LjQgMS02LjQgMi41IDAgMC0uNSAwLS44LS42LS40LS40LS42LTEt'
    b'NS41LjYgMCAwIC41LTIuMiAxLjctMyAxLjItLjggMS0yLjYtNi41IDIuMSAwIDAtMS0uNi0x'
    b'LjktMi45IDAgMC0xLjcgMi4zLTIuOSAzLjEgMCAwLTEgLjUtMS0xIC4yLTEuNS0uNy0uNS0x'
    b'LjQgMC0uOC40LTEuMyAxLjUtMS0xLjVzLTEtMy42LTEtMy42LTIuMyAzLjMtMy43IDMuN2Mw'
    b'IDAtMi41LTIuNC0zLjQtNC0uOC0xLjYtLjgtMi4yLTEuNy42LS45IDIuNy0yIDMtMiAzcy0x'
    b'LjUtMS4zLTEuNi0yYzAgMC0uMy43LS44IDEgMCAwLTEuMy0xLjUtMS4yLTMuNyAwIDAtOC4y'
    b'IDQuNS05LjIgNy4yIDAgMC03LjctLjUtMTAuOC4xIDAgMCAuNy0yLjQgMi43LTMuNyAwIDAt'
    b'Mi0uMi0yLTIuMyAwIDAgMS42LjIgMi42IDBzLTEuNC0zLjEgMS4xLTMuMmMyLjUtLjEgNC4y'
    b'IDEuMiAzLTIuMi0xLTMuMy0uNi0zLjMtLjYtMy4zczQuNCAyLjYgNS4xIDEuOWMuOC0uNi0u'
    b'NS0yIDMuNC0xLjQgMy45LjcgMi44LTEuNSA0LjQtMS43IDEuNSAwIDIuMyAxIDEuMy02LjFz'
    b'NC44IDMuNS45LTcuMmMwIDAtMS0zLjMtMy4zLTQuNyAwIDAtLjYgMi4zLTMuMi4zLTIuNi0y'
    b'LTcuOC0yLjgtNS42LTQuNCAyLjItMS43IDMuMi0zLjkgMi42LTUuMiAwIDAtMi42IDIuNi03'
    b'IC43LTMuNi0xLjUtNC40IDEuMy04IC41IDAgMCAwLTEgMy4xLTMuNCAzLTIuMy0xLjguOC0z'
    b'LjYgMS4zLTEuOS40LTIuNCAwIDEuNS0zLjEgNC0zIDEyLTguNSAxMS0xMyAwIDAgMS44IDIu'
    b'MyA2LjcuNiA1LTEuNyA4LjYtMi4zIDEwLTVhMjMgMjMgMCAwIDEgNi40LTUuNmMxLjEtLjUg'
    b'Mi40LTEgLjkgMS41LTEuNiAyLjQtNCA2LjYtMTAuOCA5LjQtNi44IDIuOC05LjUgNC44LTEw'
    b'LjcgNi4zLTEuMiAxLjUtNy40IDQuOC0zLjMgNC4zIDQtLjcgMTAuOSAwIDcuNi0xLTMuMi0u'
    b'OS02LjkuNi0zLjktMi4xIDMtMi43IDMuNS0zLjYgNy45LTUuNCA0LjQtMS45IDkuMi02LjEg'
    b'OC43LTEuNi0uNSA0LjQtOC42IDkuMS0xMC42IDEwLjYtMiAxLjQtMS4yIDEuMi0xLjIgMS44'
    b'IDAgLjYtLjQgMS44LTEuMiAyLjMtLjguNi0uNSAxLjItLjMgMi40LjIgMS4zLS4yIDEuOC40'
    b'IDIgLjYuMSAxLjIuMiAxLjQgMS4xLjIgMSAuNiAxIDEuOCAxIDEuMS0uMiAyIDAgMiAuNiAw'
    b'IC43IDEuMiAxLjcgMS4zLS40LjEtMi4yIDEtMi41LTEuMi0xLjUtMi4yLjktMi42LjYtMi42'
    b'LS40cy0uMi0uOC0xLS45Yy0xIDAtMS4zLTEuMy4zLTIuMiAxLjYtLjggMS42IDAgMy42LTEu'
    b'NiAyLTEuNyAyLTIgMi4zLTMgLjMtLjctMi45IDIuNC00LjQgMy0xLjUuOC0xLS41LS44LTIu'
    b'MS4zLTEuNyA0LTQgNS43LTQgMS44IDAgNS42IDEgNCAzLjMtMS43IDIuMy02LjQgNS4yLTQu'
    b'NSA1LjQgMi4xLjIgMi40LS42IDMuNi40IDEuMiAxIDAgMy4yLS40IDQuNGE4LjQgOC40IDAg'
    b'MCAxLTIuMiAyLjdzLTIuMi0zLjgtMi4xLS44YzAgMy4xLS41IDQuMiAwIDQuMy41LjEgMi44'
    b'IDEuNyAzLjYgMS43cy00LjEgMi4zLTIgMi41YzIgLjEgNS4zLTEgNi40LTMgMCAwLTQuMi0x'
    b'LTUuOS0yLjYgMCAwIDQuOS0xLjIgMy41LTUuOCAwIDAgNC45IDEuMyAyLjcgMy41LTIgMi4x'
    b'LTMuMyAxLjgtMS41IDIuNCAxLjkuNiAyLjcgMS4yIDIuNyAxLjJzMS4zLjYuNSAxLjZjLS43'
    b'IDEtLjcgMi42IDAgMi41LjUgMCAyLjYtMSAuOS0yLTEuOC0xIDEuOS0uOC40LTEuNy0xLjYt'
    b'MS0yLTEuMS0yLjQtMS42LS41LS4zIDE5LjctMTIuMiA5LjUtNy44IDAgMCAyLjEtNC42IDUu'
    b'MS00LjYgMyAwIDMuMiAyLjMgMS41IDQuMi0xLjcgMS43LTIuOCA0LjYtNi43IDUuMiAwIDAg'
    b'NS42IDIuNy0xIDcuMiAwIDAtMS41LjctMSAxLjJzNC41LTEuNyA1LTNhNS41IDUuNSAwIDAg'
    b'MSAzLTMgMzggMzggMCAwIDAgMTEuMi05LjZjMi4zLTMuOSAyLjgtNCA3LjItNy41czMuNi0y'
    b'LjggNC4yLTMuNmMuNS0uOS43LTIuMyAyLjctMy40IDItMS4yIDkuOC01LjQgMTIuMy03LjIg'
    b'Mi40LTEuOCA3LjQtNSA5LjYtNy44IDIuMS0yLjcgOC02LjIgOS40LTUuNiAxLjQuNy0uMiAy'
    b'LjgtMy41IDUuNC0zLjUgMi41LTEyIDkuMy0xMy4zIDEwLjRhNDQuNyA0NC43IDAgMCAxLTEx'
    b'LjIgNi42Yy0yLjcuMy0yLjQgMS4zLTQgM3MtNS4zIDUuNC02LjUgNi40Yy0xLjMgMS00LjMg'
    b'My00LjQgNC41LS4yIDEuNS41IDEuNi0xLjkgMy44YTUwIDUwIDAgMCAxLTExLjkgOC4xczQu'
    b'NSAxLjYgMS44IDQuNmMtMi42IDMtMi41IDIuNi0yLjYgMi44IDAgMCA2LjctMSAyIDQuMyAw'
    b'IDAtMSAxLjUgMS4xIDAgMi4zLTEuOSAxLjQtNC4xIDEtNC41IDAgMCAzLjctMi4zIDcuOS0y'
    b'LjMgNC4xIDAgNC0uMy4yLTEuNCAwIDAgMi43LTMuMiA1LTEuNiAyLjIgMS41IDEuNCAyLjUt'
    b'LjkgMy44LTIuNCAxLjItNS44IDEuNy04LjUgMy4yIDAgMCA1IDEgNy42LTEuMSAyLjYtMiAy'
    b'LjgtMSAzLS42LjUuNC44IDEtLjQgMi42LTEuMiAxLjctMS4zIDEuOC0xLjIgMi4yIDAgLjQt'
    b'LjEgMS41LTIuNSAyLTIuMy4zLTMuNSAxLjMtMi42IDIuNC43IDEuMi43IDQtMS4yIDMuNy0y'
    b'LS4zLTEuNi0xLjktMi4zLTIuNS0uOC0uNi0xLjktMS41LTUuNC4yLTMuNiAxLjktMy44LS4z'
    b'LTMuNy0xLjUgMCAwLTIuMyAyLTQuMi4yLTItMS45LS4yLTIuNiAxLTMuNSAxLTEgNS41LTMg'
    b'Mi44LTIuNS0yLjcuMy02LjcuNC03LjYtMS42LTEtMi4xIDItMS45IDIuNC0xLjcuNS4yIDIu'
    b'MyAxLjcgMi41LS4zIDAtMiAzLTIuMyAyLTIuNi0xLS40LTIuNS45LTIuOSAxLjMgMCAwLTIt'
    b'Mi45LTUuNC0yLTMuNCAxIDEgLjcgMiAuOC44LjIuMyAxLjgtMi43IDQuNi0zIDIuNy0xLjcg'
    b'MS44LjUgMS44IDIuMyAwIDcuOSAwIDQuNiAyLjYtMy4yIDIuNy00LjUgNC02IDMuNi0xLjgt'
    b'LjUgMC0xLjYuOC0yLjFzMS4yLTEuMi0uNC0uNmMtMS42LjUtMi4xLjctMy40LTEuNS0xLjIt'
    b'Mi4zLS44LTEuNi0uMi0zLjEuNi0xLjUgMS44LTMgLjQtMi41LTEuNi42LTEuNC43LTEuMy0x'
    b'IC4xLTEuNy0xLjctMi4xLTEuNy0yLjFzLjggMS43LjEgMi44Yy0uNiAxLS43IDEuNC40IDEu'
    b'NiAxIC40IDIgMS4zLjYgMi4zLTEuNC45LTEuMi43LS40IDEuMyAxIC43IDIuMyAxLjMuOSAy'
    b'LjctMS40IDEuNC0uMyAxIC40IDEgLjggMCAyLjMuNiAyLjMgMiAwIDEuMiAwIDEuNSAyLjMu'
    b'MyAyLjMtMS4zIDYuNy0xLjEgNi43LjYgMCAxLjgtLjYgMi4zIDEuOC44IDIuNC0xLjUgMy41'
    b'IDEuNCA1LjIgMCAxLjYtMS41IDIuNi0yLjggNC42LS40IDEuOSAyLjQgMS4zIDMtMSA0Ljgt'
    b'Mi4zIDEuNyAxLjEuNCAyLjktLjVzNi43LTEuNSA5LjUtLjJjMi45IDEuMiAzLjcgMSA1Ljgg'
    b'MCAyLjEtLjggMy4yLTEgNi4zIDEuMSAzLjMgMi4yIDUuNyAyLjYgNy40IDIuNSAwIDAtMy41'
    b'IDEuNC03LjUgMS42LTQgLjMtNiAxLTYuNyAxLjYgMCAwIDIuMyAxLjUgMi44IDMuMiAwIDAg'
    b'Mi42LS4zIDMuOC4yIDAgMC0uNiAxLjkgMSAyLjlzMi43IDEuNCAxLjUgMi43Yy0xLjIgMS40'
    b'IDEuOS44LjEgMi43LTEuNyAyLTIuMSAzLTIuMiA0LjUgMCAxLjYuNCAxLjgtMS4xIDItMS42'
    b'LjEuMiAxLjktLjUgNC0uNyAyLTUgMS43LTQuOCA3LjIgMCAwIDEuMi0yLjcgMy44LTUgMi41'
    b'LTIuNCAyLjYtMi42IDIuNS00IDAtMS40LS4xLTEuMSAxLjItMi4yIDEuNC0xLS42LTIgLjgt'
    b'My42IDEuMy0xLjUuMi0xLjIgMS44LTIuNyAxLjUtMS42LTEuNS0xLjcuMi0zLjMgMS41LTEu'
    b'Ni00LTMuNS0yLjMtNC41IDEuNS0xIDQuMy0yLjQtNS0yLjMgMCAwIDIuMy0zLjYgMTAtMi45'
    b'IDAgMC0yIDEuNi0yLjIgM2wxLjYuNXMtLjQgMS4xLTEuOSAyLjNjMCAwIDQuMiAyLjMgNC45'
    b'IDMuOCAwIDAtMi42LjgtMy4zIDEuOCAwIDAgMS4yIDEuMyAxLjYgMyAwIDAtMi45LS40LTMu'
    b'MiAxLjctLjQgMi4xLTEuMy43LTEuMyAycy4xIDEuNy0uOSAyYy0xIDAtLjEgMS4xIDAgMS44'
    b'LjIuNy42IDIuMy40IDIuOCAwIDAtMS41IDAtMi4xLjIgMCAwIC40IDMtMS4zIDMuNS0xLjcu'
    b'NCAxIDEtLjkgMS4zLTEuOC4zLTEuNS41LTMuNyA0LjUgMCAwIDEuOS0xIDMuOC0yLjQgMi0x'
    b'LjMtLjItMSAzLTQgMy4zLTMuMyAyLjctMy41IDIuNC01LjEtLjItMS42LS4zLTMgLjktNC41'
    b'czEuNS0zLjIgNS43LTNjMCAwLTEuMi0yLjgtMi43LTMuNSAwIDAgMi0xLjMgNC0xLjUgMCAw'
    b'LTEuOC0yLjMtNS42LTQuNCAwIDAgMy0yLjYgMy45LTMuOSAwIDAtMS41LjMtMi43IDAgMCAw'
    b'IC42LTEuMyAzLjQtMy4xIDAgMCAxLjUgMS40IDEuNCAyLjkgMCAwIDQuOC0yLjcgNy41LTIu'
    b'NCAwIDAgMS40IDMuNC01LjMgMTAgMCAwIDQuMi4zIDYgMCAwIDAtMSAzLjItNiA1LTUgMiAx'
    b'IDQuMi00LjEgMy44LTUtLjQtMy41IDEuMy0zLjQgMy45LjIgMi42LjMgNS4zLjIgNiAwIDAt'
    b'NC0xLjMtNCAyLjYuMSA0LTIgNC44LTIuNSA1LjEgMCAwLTEuMi0xLTMtMS43IDAgMC0yLjUg'
    b'NC45LTYuNSA3Ljd6Ii8+CiAgPHBhdGggZmlsbD0iIzdiM2MyMCIgZD0iTTU0Ny40IDIyMC41'
    b'czEuNC0uMiAzLjggMS4yYzIuMyAxLjUgNC42LTEuNSAyLTIuMy0yLjYtLjggMC0xLjggMi40'
    b'LjIgMi40IDEuOSAzLjMuOSA0LjIuMy44LS43IDEuOS0xLjEuMy0yLjItMS42LTEuMSAxLS42'
    b'IDIuMy4zIDEuMi43LjcgMS41LjYgMS43LS4yLjItLjMgMi45IDIgLjUgMi40LTIuNSAzLjct'
    b'NC44IDMuNi02IDAgMCAxLjMuOCAxLjUgMi4zLjIgMS41IDItLjggMi42LTEuNi42LS44IDEu'
    b'Ni0zIDEuNS00LjQgMCAwIDEuNiAyLjUgNCAwczEuNC0xIDQuMi0xLjdhMTcuNiAxNy42IDAg'
    b'MCAwIDguNS01LjJjMi0yLjUgMi4xLS44IDQuNi0xLjRzNy43LTQuMiA4LjItNi4xYy40LTEu'
    b'OS4zLTMuMS0uNC0yLjQtLjcuNi0uNCAwLTEuNS0uNi0xLjEtLjctMi43LjktMi43LjlzMS42'
    b'IDEuMi4zIDEuN2MtMS4yLjYtMi4zIDIuMy00LjYgMS42LTIuMy0uNi00LjggMi4yLTQuOCAy'
    b'LjJzMiAxLjYtLjcgMi43Yy0yLjcgMS0yLjMgMS40LTMuOS4yIDAgMC0yLjkgMy43LTQuNiA0'
    b'LjUgMCAwLS43IDAtMS4yLS44IDAgMC0yIDIuMS0yLjggMi41IDAgMC0xLjMtMS0yLjMtMS41'
    b'IDAgMC0yLjMgMi45LTQuMiAzLjcgMCAwLS42LTEtMS44LTEuNyAwIDAtLjYgMy42LTQuNiA1'
    b'LjggMCAwIC4yLTEtMS44LTIuMyAwIDAtNSA0LjMtNi45IDQuNy0yIC40LS4yLS45IDAtMS41'
    b'LjQtLjUgMS42LTIuMy0uOC0zcy0yIC41LTIuNS43Yy0uNi4yLS42LS40LTIuMi0uMnMtMS4z'
    b'LjktMiAxLjJjLS44LjItMy42LS41LTMuNCAxLjQuMSAxLjggMS41IDMuMS0xIDQuMi0yLjUg'
    b'MSAxIC44IDQuMS40eiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik01NTcuNSAyMTUu'
    b'M3MuNi0yLjUtMS41LTMuNWMwIDAgMTMuMi0yLjEgMy4yLTcuMiAwIDAgMTEuOS0yLjMgOS02'
    b'LjEtMi43LTMuOC01LjQtMy01LjgtMy0uNCAwIDIuNS0yLjEgMy4zLTEuOC43LjMgMTAuMiAz'
    b'LjkgNy44LjctMi40LTMtMi4yLTIuOS0yLjYtMy44IDAgMCAzLjEgMCA3LjkgNC42IDAgMCAx'
    b'LTEgLjktMi45IDAgMCAzLjMgMSA0LjQgMiAwIDAgLjYtMS4yLjMtMS44IDAgMCAzIDEuNSA0'
    b'IDMuMiAwIDAgMS4zLTEuMiAxLjUtMi42IDAgMCAzIDEuMyAzLjcgMi4yIDAgMCAxLTEuMy42'
    b'LTMgMCAwIDQuOSAxLjMgNS41LTEuNiAwIDAgNC45IDEgMS43IDIuOS00IDIuNS0uNC0uNi00'
    b'LjYgMi4zLTMuMiAyLjMtNSA0LjktNi42IDQuNC0xLjEtLjUtMi41IDIuOS00IDEuMy0xLjUt'
    b'MS43LTEuNS0xLTIuNy43YTI0LjUgMjQuNSAwIDAgMS0yLjggMy41cy0uOC0uNS0xLjYtMS4y'
    b'YzAgMC0uOCAxLjYtMiAyLjggMCAwLTEtMS4zLTIuNi0yIDAgMC0yLjMgMi43LTMuOCAzLjcg'
    b'MCAwLTEuNC0xLjQtMi45LTEuOSAwIDAtLjIgMy44LTMuMSA1LjcgMCAwLS42LTEuMi0yLjYt'
    b'MiAwIDAtMS40IDIuMy00LjYgNC4zeiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik01'
    b'NTAuNiAyMDkuNXMtMS42IDEuMi0uNiAyLjVjMSAxLjQgMS4xLS4yIDIuNC0uMyAxLjMtLjIg'
    b'MTcuNS0zIDIuOC03LjMgMCAwIC43LS42IDMuMS0uOCAyLjYtLjMgMTEuOC0yLjcgNy41LTYt'
    b'NC4zLTMuMi03LjkgMS4xLTQuMy0yLjggMy0zLjEuNi00LjYuNi00LjZzLTguNSA1LjYtMTAu'
    b'NCA2LjdjLTEuOCAxLTQuNiAzLTEuNCA0IDMuMyAxIDUuNC0zLjQgNS43LTIuNC4zIDEtNi40'
    b'IDQuOC01LjQgNi40LjkgMS44LjcgMy4zIDIuNCAyLjkgMS42LS4zIDYgLjggMi41LjctMy43'
    b'LS4xLTUgMS01IDF6Ii8+CiAgPHBhdGggZD0iTTU1Ni40IDIwMS4zcy0xLjUgMS4xLjUuNiA1'
    b'LjktMS40IDUuMi0yLjRjLS44LTEtMy40LjItNS43IDEuOHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'N2IzYzIwIiBkPSJNNTgyLjQgMTg0LjVzNy41LS4yIDEwLjUgMS45YzMgMiA0LjYgMy40IDUu'
    b'NSAzLjggMCAwLS4xIDIuOC01IC43IDAgMCAuNCAxLjQtLjIgMi44IDAgMC0xLjctMS4yLTMu'
    b'OC0xLjcgMCAwLS40IDEtMSAxLjcgMCAwLTIuMS0yLjItNC42LTIuOSAwIDAtLjQgMS4xLS44'
    b'IDEuNiAwIDAtMi42LTEuNi00LjYtMS42IDAgMCAuNCAxLjcgMCAyLjMgMCAwLTUuNC00LjMt'
    b'MTAuMy0zLjggMCAwIDIuMyAzLjUgMy44IDUuMSAwIDAtOS44LS43LTgtNiAxLjUtNS4zLS4y'
    b'LTQgNi4yLTRoMTIuM3oiLz4KICA8cGF0aCBmaWxsPSIjNWEzNzE5IiBkPSJNNTM2LjMgMTk5'
    b'LjFzLTEuMSAxIDAgMS43YzEuMS44IDUtMiA1LjUtMi40LjYtLjQgMi0uNCAwIDEuMXMtMy44'
    b'IDMtNSA0LjZjMCAwIDYuNC0xLjggMTAuNi01LjQgNC4zLTMuNy0uMS0xLjMgNy00LjggNy4z'
    b'LTMuNSAxMS4xLTkuMSA3LjItOC41LTMuOC42LTcuMyA1LTEwLjQgNi43LTMgMS43LTQuNyAy'
    b'LTQuMiAxIC40LTEgMi43LS42IDYuOS00IDQuMS0zLjMgMy4yLTMgMy4yLTQuMiAwLTEuMi0x'
    b'LjUtNCA0LjctNy40IDYuMi0zLjMgMjUuNi0xNC41IDI3LjMtMTguNSAwIDAtNS43LjYtMTMu'
    b'MiA2LjFhNjkuNyA2OS43IDAgMCAxLTEzLjQgOC44Yy0yIC44LTEuOC4yLTMuMSAxLjlhMTcx'
    b'LjggMTcxLjggMCAwIDEtMTAuMSA5LjhjLTEuMyAxLTEuOCAxLjYtMS45IDMuOCAwIDEtOC40'
    b'IDcuMy0xMSA5Ljd6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcxOSIgZD0iTTU2MiAxODQuM3Mt'
    b'MS41LjYtMyAwYy0xLjMtLjctLjgtMy42IDIuNS01LjVhNTAgNTAgMCAwIDEgMTIuNi00Ljhz'
    b'LS41IDMuOC0xMC4xIDcuMWMwIDAgLjYgMi0yIDMuMnoiLz4KICA8cGF0aCBmaWxsPSIjYWE1'
    b'MzIzIiBkPSJNNTY1LjQgMTgxLjhzLjMgMSAwIDEuOGMwIDAgMTcuOSAxLjcgMjcuMS05LjIg'
    b'MCAwLTEyLjcgMS4yLTE3LjcgNC4zIDAgMCAzLjItNCAxMi43LTcuM3MxMy40LTcuNCAxNC4y'
    b'LTkuN2MwIDAtMTIgNC4zLTE3LjcgNC4zIDAgMC0xLjIgMC0yLjMuNS0xLjEuNy04LjggNi4y'
    b'LTEwLjggNy4yIDAgMCA0LjMtLjQgNS45LTEuOCAwIDAtMyA4LTExLjQgMTB6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzVhMzcxOSIgZD0iTTUzMSAxOTJzLTIuMyAxLjctMS4zIDIuNGMxIC45IDIu'
    b'NiAxIDYtMS45IDMuNi0zIDEyLjEtMTAuMiA2LjgtMTAuNSAwIDAtNy0uNC02LjcgMy44LjIg'
    b'NC4yLTQuNCA2LTQuOCA2LjJ6bS0xNS45LTIuNXM0LjYgMi43IDIuOCA0LjljMCAwIDE0LTEx'
    b'LjggMTAtMTQuNC0zLjgtMi42LTYuOSAyLjMtNiAyLjcgMSAuNiAzLS40IDIuMy42YTc3LjQg'
    b'NzcuNCAwIDAgMS05IDYuMnptLTMuNi0zLjhzMyAxIDMuMiAyLjNjLjEgMS4yIDkuMi02LjQg'
    b'Ni44LTkuNy0xLjEtMS41LTYtMi02LjQuOC0uMiAzIDQuNi0uMyAzIDEuOC0yLjIgMi43LTUu'
    b'OSA0LjQtNi42IDQuOHptMzIuNi02LjRzLTEuOSAxLjQtLjEgMi4zYzEuOC43IDIuOC0uNiAz'
    b'LjctMS4zLjktLjggNS4zLTQgNi4yLTYgMS0yIDIuNS0yLjcgNC4xLTMuNyAxLjUtMSAxMi42'
    b'LTYuNiAxOS41LTEyLjcgNi44LTYuMSA0LTQuNSAxMS04LjRzMTEuNy03LjUgMTMuMi0xMS44'
    b'YzAgMC0zLjMgMS02LjIgM2EyNDMgMjQzIDAgMCAxLTEwLjcgNi41Yy0xLjMuNS0zIC42LTQg'
    b'MS42cy0xIDIuMy00LjMgNWMtMy41IDIuOS0yMSAxNS4zLTIzLjIgMTdhMzM0LjcgMzM0Ljcg'
    b'MCAwIDAtOS4yIDguNXoiLz4KICA8cGF0aCBmaWxsPSIjYWE1MzIzIiBkPSJNNTMwIDE4My40'
    b'czItMSA1LjYtLjhjMy42LjIgMTcuOC0xMy42IDIyLTE2LjNhMzQxLjYgMzQxLjYgMCAwIDAg'
    b'MTguNy0xMy44YzEuOC0xLjggMi0zLjYgMy42LTQuNiAxLjUtMSAzLS45IDYuNC0yLjkgMy41'
    b'LTIgMjAuMy0xMiAxOS4zLTE3LjggMCAwLTI1IDE1LTMwLjcgMTkuOGEzNzUgMzc1IDAgMCAx'
    b'LTI0LjcgMTcuN2MtMi44IDEuOS01IDUtOS45IDguOC00LjcgMy45LTkuNSA3LjItMTAuMyAx'
    b'MHoiLz4KICA8cGF0aCBmaWxsPSIjYWE1MzIzIiBkPSJNNTI0LjggMTc4czQuNi0uNCA1LjIg'
    b'MS45YzAgMCAxMC02LjggMTIuMi05LjYgMi4yLTIuOC0uOC0xLjIgNC45LTQuOWE1OTQuMyA1'
    b'OTQuMyAwIDAgMCAyNy0xOS4xYzIuNy0yLjMgNy44LTUuNSAxMS45LTguMiA0LTIuOCAxOS45'
    b'LTEwLjYgMTguMS0xN2wtMTQuMiA5LjVjLTIuNyAxLjgtMy45LjgtNi41IDIuOS0yLjYgMi4x'
    b'LTguNSA2LjMtOS41IDcuNmExNjEuMyAxNjEuMyAwIDAgMS0xNC40IDExYy00LjQgMy0xNC4x'
    b'IDguNi0xOC45IDEyLjhhNjAyLjggNjAyLjggMCAwIDEtMTUuOCAxMy4yeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNhYTUzMjMiIGQ9Ik01MTAuNCAxNzYuOHMyLjMgMCAzLjEuOWMwIDAgNC4zLTMu'
    b'OSA4LjkgMCAwIDAgMTYuOC0xMS41IDE4LjUtMTQuNCAxLjctMi44IDQuNS0yLjkgMTEtNy42'
    b'IDYuNi00LjggMTAuNy02LjkgMTUtMTAuMiA0LjQtMy40IDguMS03LjMgMTEuMi05LjMgMy4x'
    b'LTIgMTEtNy4yIDkuOC0xMS43IDAgMC02LjUgMy42LTEwLjYgOC4yLTQuMiA0LjYtMy44Ljct'
    b'OC4xIDQuNWE4Mi43IDgyLjcgMCAwIDEtMTYuMyAxMS43Yy01LjUgMi43LTIuMiAyLjQtNi4y'
    b'IDUtMy45IDIuNS0zLjYgMi01IDIuNWExMCAxMCAwIDAgMC01LjEgM2MtMS42IDEuNy01LjQg'
    b'NC05LjYgNi41YTEwNi41IDEwNi41IDAgMCAwLTE2LjYgMTAuOXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjYWE1MzIzIiBkPSJNNTE1LjUgMTY4cy0xLTEuOS43LTMuM2MxLjYtMS4zIDQuNi00Ljgg'
    b'NS03IC41LTIuMy4xLTEuOSA0LjgtMy44YTE4OC4yIDE4OC4yIDAgMCAwIDM4LjItMjEuNmMx'
    b'LjgtMS41IDYuNC00LjYgOC4zLTYuMiAwIDAgLjggMi41LTEuMiA0LjJhMjIyLjEgMjIyLjEg'
    b'MCAwIDEtMjEuNSAxNC45IDc2LjYgNzYuNiAwIDAgMC05LjYgNS41Yy0xLjkgMS42LTEuNiAy'
    b'LTEwLjIgNi4zLTguNSA0LjEtOSA0LjYtOC43IDQuOS4zLjQgNC4yLTEuMyA2LTIuNCAxLjgt'
    b'MSA4LjgtNC4zIDExLTZhNjkgNjkgMCAwIDEgNy01IDI5NiAyOTYgMCAwIDAgMTgtMTEuMmMz'
    b'LjUtMi43IDQuNS0zLjUgNS4zLTMgLjcuNCAyIC40LjQgMnMtNi43IDYtOC43IDcuM2MtMiAx'
    b'LjMtOC4xIDUtOS44IDUuOC0xLjcgMS0yLjQgMi41LTMuNCAzLjItLjkuOC0zLjcgMi43LTcg'
    b'My41cy00IDMuMy02LjMgNC44Yy0yLjMgMS40LTE4IDEwLTE4LjUgMTAuMyAwIDAgLjktMSAu'
    b'Mi0zLjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2FhNTMyMyIgZD0iTTU3MC4zIDEzMi40cy0uOS44'
    b'LS40IDEuMmMuNi42IDIuOCAyLjIgNS42LS42YTEwNi41IDEwNi41IDAgMCAxIDEyLjUtMTBj'
    b'Mi4zLTEuNSAzLjYtMi44IDMuNS00LjcgMCAwLTExLjQgNi0yMS4yIDE0LjF6bTE1LjYtMXMx'
    b'LjctMi45IDYtNS43YzQuMy0yLjcgMTAuOC02LjcgMTEuNS03LjYgMCAwIDEuNiAxLjctMS43'
    b'IDMuOGEzMTEuNyAzMTEuNyAwIDAgMC0xMC44IDdjLS43LjctMiAxLjYtNSAyLjV6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzdiM2MyMCIgZD0iTTQ5OSAxNjNzLTQuOCAyLjYtMy4xIDQuMmMxLjcg'
    b'MS41IDQuMiAxIDUuNC42bDMuMi0xYy40IDAgNC41LTEuMyA1LjYtMy4yIDEtMiAzLjgtNC4y'
    b'IDYtNS44IDIuMi0xLjUgMy0zLjIgMi43LTQuM0w0OTkgMTYzem0tMjguNCAyMnMzLjQtMiA4'
    b'LS43YzAgMC0uMi0xLjEtMS0xLjcgMCAwIDUuNy0xLjUgNi45LTQgMS4yLTIuNSAxLjUtMiAy'
    b'LjUtMi42IDEuMi0uOCA4LjctNi44IDcuOC04LjEtLjktMS4zLTEtMy4xLTEuNy0zLjcgMCAw'
    b'LTEuNSAyLjEtOSA1LjctNy4yIDMuNi0xNS40IDYuMi0yMS40IDE0LjItNS45IDgtNS4zIDEy'
    b'LjYgMiAxNC43IDAgMCA1LTMuMiAxNy42LTIuMSAxMi40IDEuMSAxNi42IDUuOCAxNy40IDYu'
    b'Ni44LjkgMy4zIDQgLjkgOS4xIDAgMCAyLjUgMS4xIDIuNi0xLjMuMy0yLjMuNC0xLjggMS0x'
    b'LjUuNi40IDEuMy41IDEtMS40YTE4IDE4IDAgMCAwLTIuMy03LjJjLTEuMS0xLjUuMi0uOC45'
    b'LS42LjcuMyAzLjMgMi41IDEuOC0xLjUtMS41LTMuOC0yLTItMi0xLjggMCAuMy0uNCAxLjIt'
    b'My44LTEuNGEyNi44IDI2LjggMCAwIDAtOC44LTQuNGMtMi4zLS42LS43LS42LjctMSAxLjQt'
    b'LjYgMy4xLS44IDMuOC0yLjQgMCAwLTEuNC4zLTMuOC0uNmExMy4yIDEzLjIgMCAwIDAtMTEu'
    b'NSAyczEuMi00LjUtMi41LTQuM2MtMy42LjMtNi4yLjItMTAgMy4yIDAgMC0uMy00LjYgMy40'
    b'LTcgMy43LTIuNSAzLjItMSA1LjItMS42IDItLjYgMi4zLTIuNyAxLjQtMy40IDAgMCA0Ljgu'
    b'OSAxMi44LTUuOCAwIDAtNC4zIDUuNy05LjUgNi44IDAgMC0uOSAzLTUuNyAzLjctNC44Ljct'
    b'NC42IDMuNC00LjYgNC4xeiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik00NTcgMjEy'
    b'LjdzMi4yLTE0LjEgMTUuNS0xNS4xYzExLjQtMSAxNS4xLjUgMTcuNCAxLjNzOCAyLjQgNS44'
    b'IDQuMmMtMi4yIDEuOC0zLjUgMS41LTMuNSAxLjVzMi41LTIuOS4yLTMuM2MtMi4zLS41LTIu'
    b'NC45LTIuNyAyLS40IDEuMy0uNSAyLjYtMS42IDMuNiAwIDAtMS4yLTEuNC0yLjktLjJzLS4y'
    b'IDEuMi41IDFjLjYtLjIgMS41LS41IDEuMy41LS4xIDEtMSAyLjgtMy44IDQuMi0yLjcgMS40'
    b'LTIuNiAxLjMtNS44IDEuOS0zLjMuNS02LjMgMS44LTEwLjUgNS4zLTQuMiAzLjYtOC43IDIu'
    b'NC05LjYtMS41LS44LTMuNC0uNC01LjQtLjQtNS40eiIvPgogIDxwYXRoIGQ9Ik00NzIgMjEy'
    b'LjJzMS4yLTIuNy0xLTRjMCAwLTYuOSAxLjItOS0uOSAwIDAgNy41LS40IDEyLjItMi4zIDQu'
    b'Ni0xLjcgMy4zLTMgMS43LTMuNC0xLjYtLjMtNC42LjUtNC45IDIgMCAwLTEtMS42LjItMi42'
    b'YTUgNSAwIDAgMSA0LjctLjhjMS43LjQgMy4xIDEuMiA4LjYtMS42IDAgMCAzLjEuNyAzLjMg'
    b'Mi44IDAgMi4yLS4zIDMtLjYgMy4zLS4yLjQtLjYgMS0xLjMgMS0uNi0uMi0xLjUtLjMtMi4z'
    b'IDEuMmE4LjkgOC45IDAgMCAxLTIuNiAzLjdzMS41LTQuNi0yLjUtNS43YzAgMC0zLjMgMi01'
    b'LjggMi4xIDAgMCAzLjIgMy0uOCA1LjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcxOSIgZD0i'
    b'TTQ3OS4zIDIwMy44cy0xLjYtMS42LjQtMS45YzItLjEgNC42IDEuNCA0LjIgMi43LS42IDEu'
    b'Mi0zIDEuMS00LjYtLjh6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTU5Mi42IDE4MS42'
    b'cy0zLjcgMS0uMiAzLjNjMy40IDIuMyA1IDQuMiA3LjUgNC44IDIuNS43IDUgMS41IDUgNHMt'
    b'LjUgMy41LTEuOSA1LjJjLTEuMyAxLjcuOCAyLjQgMi42IDEuNSAxLjgtMSAzLjMtMS41IDQu'
    b'NS0yLjIgMS4xLS43IDMtLjYgMS40LjMtMS45IDEtMy43IDEuNS0xLjQgMS41IDIuMy4xIDE2'
    b'LjIuNCAxOS4xLS42IDMtLjkgNi44LTEuMiA3LTUgMCAwIC4yLTEuNiAxLjMtMi40IDEtLjcg'
    b'MS44LTIuMy4yLTEuMi0xLjUgMS4xLTIuNyAxLjctMyAxLjMtLjMtLjMtLjUtLjYuNy0xLjEg'
    b'MS4yLS41IDEuOCAwIDIuOS0xLjUgMS0xLjYgMS0xLjQuNC0yLS42LS42LTEuOC0xLTEuMi0x'
    b'LjguNi0uOCAxLjItMy0xLjQtMS43LTIuNSAxLjMtNy42IDQuOC0xMCA1LjMtMi4yLjUtNCAx'
    b'LjItNy4xIDEuOC0zIC43LTUgMS40LTguNSAzLjMtMy4zIDEuOC0zLTEuMS0yLjUtMS41IDAg'
    b'MCAxLjMgMi4zIDQuNy0uNyAzLjQtMi45IDIuMy0uMSAxMC42LTIuOSA4LjMtMi43IDYuMy0z'
    b'LjEgOS41LTQuOCAzLjMtMS43IDYuNC0xLjggNC00LTIuMi0yLjQtMi40LTIuNS01LjMgMGEz'
    b'NC41IDM0LjUgMCAwIDEtMTYgNi40czE4LjgtOCAxNi45LTkuMmEyMC44IDIwLjggMCAwIDAt'
    b'NS4zLTIuNWMtMS4zLS4zLTEuNy0uNi00LjcuOC0zIDEuMy0zLjUgMS42LTQuMyAxLjctMSAw'
    b'LTMuNS42LTcgMi40LTMuNiAxLjktNS41IDIuNi04IDQgMCAwIDEuNy0zLjMgOS4xLTUuNSA3'
    b'LjQtMi4yIDExLjEtNC4yIDEwLjQtNC42cy0yLjctLjgtNC0uNWMtMS41LjMtMS0uMS01LjYg'
    b'MS43LTQuNSAxLjgtMi42IDEuNC02LjIgMi4yLTMuNy43LTUuMSAxLjUtNi45IDIuMyAwIDAg'
    b'LjgtMSAzLjEtMS45IDEuMy0uNC0xLjMtLjkgMi4yLTFoMWEzMi4yIDMyLjIgMCAwIDAgOC42'
    b'LTMuM2MtLjctLjEtNS4xLS42LTkuNSAxLjYtNC41IDItMi41IDEuMy00IDEuNS0xLjYuNC01'
    b'IDIuNC02IDMuNC0xLjEuOS0yLjcgMS41LTIuNyAxLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzVh'
    b'MzcxOSIgZD0iTTQ4Mi43IDIwMS44czEuOC41IDIuMiAxLjhjLjUgMS4yIDEuNi0uNiAxLjYt'
    b'MS4xLS4xLS42LTEuMi0zLTMtMS45LTIgMS4xLTEgMS4xLS44IDEuMnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjN2IzYzIwIiBkPSJNNDc3LjkgMjI2czMuNy0xLjggNi45LTEuNWMwIDAtMS4zLTQu'
    b'NC45LTMuNyAyLjEuOCAxLjUuNCAyIC40IDAgMCAuMS0yLjktLjUtNCAwIDAgMi4zLjUgNC42'
    b'LjUgMCAwLTIuMi00LjEuMi03YTYuOSA2LjkgMCAwIDAgNC4yIDMuNHYtMi4zczEuNy0uMyAz'
    b'IC40YzEuNC44IDIuNS03LjYtMS41LTkuMyAwIDAtMSAxLjUtNC43IDIuM3MtMy43IDEuNS01'
    b'LjIgNC4zLTMgMi45LTYuMiA1Yy0zIDItNSA2LTUgNi40IDAgMCAxLjUgMiAxLjMgNS4xeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiM5OTkiIGQ9Ik02MDMuMSAxNzcuOGMxLjMtLjItMS40LS45IDIt'
    b'MWgxYTMyLjIgMzIuMiAwIDAgMCA4LjctMy4zYy0uNy0uMS01LjEtLjYtOS41IDEuNXMtMi41'
    b'IDEuNC00IDEuN2MtMS42LjMtNSAyLjMtNiAzLjMtMS4xLjktMi43IDEuNS0yLjcgMS41cy0z'
    b'LjcgMS0uMiAzLjRjMy40IDIuMyA1IDQuMiA3LjUgNC44IDIuNS43IDUgMS41IDUgNGE3IDcg'
    b'MCAwIDEtMS45IDUuMmMtMS4zIDEuNy44IDIuNCAyLjYgMS41IDEuOC0xIDMuMy0xLjUgNC41'
    b'LTIuMiAxLjEtLjcgMy0uNiAxLjMuMy0xLjggMS0zLjYgMS41LTEuMyAxLjUgMi4zLjEgMTYu'
    b'Mi40IDE5LjEtLjYgMy0uOSA2LjgtMS4yIDctNSAwIDAgLjItMS42IDEuMy0yLjQgMS0uNyAx'
    b'LjgtMi4zLjItMS4yLTEuNSAxLjEtMi44IDEuNy0zIDEuMy0uMy0uMy0uNS0uNi43LTEuMSAx'
    b'LjItLjUgMS44IDAgMi45LTEuNSAxLTEuNiAxLTEuNC40LTJsLTEtLjlzLS45LS43LTEuOS0u'
    b'MWEyNy42IDI3LjYgMCAwIDEtNyAyLjdjLTEuNi4xLTMuNS45LTYuNSAyLjRzLTguMiA0LjYt'
    b'OSAxLjdsLTIuOCAxYy0zLjQgMS44LTMtLjctMi41LTEuNCAwIDAtMS44IDItMS43LjIgMC0x'
    b'LjggMS4yLTEuNSAzLjMtMi4xIDItLjYgNS0yIDMuOC0zLTEuMy0xLTIuNyAxLTQuMiAxLjgt'
    b'MS40LjctNC4zIDEuMi00LjgtLjktLjQtMi4xLS40LTMuNi00LjMtMy44LTQtLjItMy45LTIu'
    b'Ny0yLjgtMy44IDEuMS0xIDItMi44IDUuNy0zLjV6Ii8+CiAgPHBhdGggZD0iTTYxNS42IDE5'
    b'Ni45czYuMS0yLjggMTEuNy00LjFjNS43LTEuMyAxLjIuMi4zLjQtMSAuMy05LjcgMy4yLTEx'
    b'LjggNC4yLTIgMS0xLjcuMi0uMi0uNHptMS40IDEuM3M2LjktMi4zIDguMi0xLjRjMS4zIDEg'
    b'LjIuNi0xLjMuOC0xLjYuMS01LjcuOC02LjguOC0xLjEgMC0uMS0uMi0uMS0uMnptMTEtMi41'
    b'czEuNC0uMiAxLjUuNGMuMS40LS42LjUtMS4zLjQtLjctLjEtMS4zLS41LS4xLS44eiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00NDYgMjU1LjlzLS4zLTYuMiAyLjgtOS4yIDE3Ljgt'
    b'MTguNSAyMC4xLTIyLjhjMCAwIDIgMS4zIDIgMy44IDAgMCAyLjUtNC4zIDQuNS02IDAgMCAx'
    b'LjcgMS44IDEuNSA1LjQgMCAwIDMuNS0xLjkgOS0xLjkgMCAwLTIgMi40LTIuMSAzLjkgMCAw'
    b'IDcuNi0xIDExLjctLjMgMCAwLTEwLjYgNi03LjcgNi41IDMuMS41IDYuMiAwIDYuMiAwcy0z'
    b'LjQgMy4zLTguOCA0YzAgMCA2LjkgMCA4LjIgMS41IDAgMC02LjYgMS0xMiA1IDAgMC0uNC0u'
    b'Mi0uNC0xLjcgMCAwLS4zIDEuNC0xLjggMi43LTEuNSAxLjItNS4xIDQtNi41IDUuMy0xLjQg'
    b'MS4zLTMuOCA0LTYuNiA0IDAgMCAuNi0yLjEtMS40LTIuOGE1LjcgNS43IDAgMCAwLTYgMS41'
    b'cy03IC4xLTkuNC41YzAgMCAxLjYtMi42IDMtMi42IDEuNiAwIDcuNiAxIDguMS0zLjIuNi00'
    b'LTMuOC0zLTIuMi01LjQgMS43LTIuNCAxLjMtMi4yIDEuNC0yLjYgMCAwLTEuNC44LTIuMiAz'
    b'YTEwLjcgMTAuNyAwIDAgMS00LjIgNiAxNSAxNSAwIDAgMC00LjggNXMtMS4zIDAtMi40LjR6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQ1Mi44IDI1Mi4ycy4zLS44IDIuMy0xLjJj'
    b'Mi4yLS4zIDIuMy0xLjMgMi0xLjgtLjMtLjQtMS41LS40LjUtMi44IDAgMCAuOC4zIDEuMi44'
    b'LjYuNiAyLjkgNS41LTYgNXoiLz4KICA8cGF0aCBmaWxsPSIjOTk5IiBkPSJNNDQ3LjkgMjQ3'
    b'LjljMCA0IDUuMyAyLjUgNS4zIDIuNWEyMS40IDIxLjQgMCAwIDAtMy44IDMuNmMuNC0yLTMt'
    b'Mi41LTMtMi41YTEyLjMgMTIuMyAwIDAgMSAxLjUtMy42em0xOS4zLTIxLjUgMS43LTIuNXMy'
    b'IDEuMyAyIDMuOGMwIDAgMi41LTQuMyA0LjUtNiAwIDAgMS43IDEuOCAxLjUgNS40IDAgMCAz'
    b'LjUtMS45IDktMS45IDAgMC0yIDIuNC0yLjEgMy45IDAgMCA3LjYtMSAxMS43LS4zIDAgMC0x'
    b'MC42IDYtNy43IDYuNSAzLjEuNSA2LjIgMCA2LjIgMHMtMy40IDMuMy04LjggNGMwIDAgNi45'
    b'IDAgOC4yIDEuNSAwIDAtMiAuMy00LjYgMS4yIDAgMC0xLjktMS44LTcuNi0xLjUgMCAwIDQu'
    b'NC0yLjYgOC0zLjQgMCAwLTEuNi0yLTQtLjEgMCAwLTQuOS0zLjMtLjgtNi4yIDAgMC0yLjgt'
    b'LjUtNC43LjggMCAwIDAtMi4zIDIuMS0zLjMgMCAwLTUuNC0xLTYuNyAzIDAgMC0xLTEuNS0u'
    b'NS0zLjQgMCAwLTMuMyAxLjktNC44IDQgMCAwLS41LTQtMi42LTUuNU00NTYuOCAyNTJjLS45'
    b'LjItMi4zLjMtNCAuMiAwIDAgLjItLjUgMS4zLTEgMCAwIC40LjggMi43LjgiLz4KICA8cGF0'
    b'aCBkPSJNNDY2LjYgMjM2LjdzMi41IDIgMy4zIDNjMCAwIDIuMy0xLjQgMy0yLjcgMCAwIDEu'
    b'OSAxLjEgMi40IDIuOCAwIDAgMS4zLS44IDEuNS0yIDAgMCAzIC42IDQuMiAxLjYgMCAwIC40'
    b'LTMgMC00LjggMCAwIDIuMS4yIDMuNC43IDAgMC0xLjItMiA1LTQuNSAwIDAtNC43IDEuMS02'
    b'LjUgMyAwIDAtMiAuMi0yLjktLjR2NC41cy0xLjItLjYtMy41LTEuMWMwIDAtLjYgMS0xIDEu'
    b'MiAwIDAtMS41LTEuMi0yLjEtMi43IDAgMC0yLjMgMi4xLTMgMyAwIDAtMi4zLTEuNi0zLjgt'
    b'MS42eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik00NTIuNSAyNjcuM3MxIC40IDMu'
    b'My0xLjQgOC43LTUuOSA5LjItOS4yYy43LTMuMy0yLTMuNC00LTIuNS0yLjIgMS0xLjMgMi43'
    b'LTEuMiAzLjQgMCAuNi4yIDIuOS0zLjMgNmwtNCAzLjd6Ii8+CiAgPHBhdGggZmlsbD0iI2Zm'
    b'YzIyMSIgZD0iTTQ1MS45IDI2OC4zcy01LjItMi4yLS42LTQuNSA2LjctMi45IDcuMi00Ljlj'
    b'LjYtMS45LjItMS41LTEuNS0uNy0xLjcuNy04LjIgMy44LTkuMiAxIDAgMCAyLjcgMSA2LS42'
    b'IDMuNC0xLjcgNi4yLTIuMSA0LTIuOGEzNyAzNyAwIDAgMC0xMSAuNWMtMS40LjQtMSAuMy0x'
    b'LjMgMS42LS4yIDEuMy0xLjYgNC0yLjIgNC43LS41LjgtMS44IDQgLjYgNS41YTguNiA4LjYg'
    b'MCAwIDAgOCAuMnoiLz4KICA8cGF0aCBkPSJNNDQ5LjkgMjU3cy0xLjMuMi0xIC43Yy4yLjUu'
    b'NS40IDEgLjQuMyAwIDEtLjIgMS4xLS41IDAtLjMtLjgtLjctMS4xLS41eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNmZmYiIGQ9Ik00NTEuNSAyNjcuMXMtMi40LTEuMS40LTIuNmMyLjctMS41IDUu'
    b'Ni0zIDYtMy42IDAgMC0xLjMgMS45LTYuNCA2LjJ6Ii8+Cjwvc3ZnPgo=', 'AS')

AS = b64_AS
index.append("AS")
index.append("ASM")
index.append("American Samoa")
catalog["AS"] = AS
catalog["ASM"] = AS
catalog["American Samoa"] = AS
country["American Samoa"] = ('AS', 'ASM', 0)
lookup["AS"] = ('AS', 'ASM', 'American Samoa', 0)
lookup["Pago Pago American Samoa"] = ('AS', 'ASM', 'American Samoa', 0)
lookup["ASM"] = ('AS', 'ASM', 'American Samoa', 0)
lookup["American Samoa"] = ('AS', 'ASM', 'American Samoa', 0)
details["AS"] = {"continent":"Oceania","capital":"Pago Pago","currency":"US Dollar","web":".as","lang":"en-AS | sm | to","tz":"+13:00","altname":""}
#----------------------------------------------------------------------
b64_AT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWF0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik02NDAgNDgwSDBWMGg2NDB6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjYzgxMDJlIiBkPSJNNjQwIDQ4MEgwVjMyMGg2NDB6bTAtMzE5LjlIMFYuMWg2'
    b'NDB6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'AT')

AT = b64_AT
index.append("AT")
index.append("AUT")
index.append("Austria")
catalog["AT"] = AT
catalog["AUT"] = AT
catalog["Austria"] = AT
country["Austria"] = ('AT', 'AUT', 0)
lookup["AT"] = ('AT', 'AUT', 'Austria', 0)
lookup["Vienna Austria"] = ('AT', 'AUT', 'Austria', 0)
lookup["AUT"] = ('AT', 'AUT', 'Austria', 0)
lookup["Austria"] = ('AT', 'AUT', 'Austria', 0)
details["AT"] = {"continent":"Europe","capital":"Vienna","currency":"Euro","web":".at","lang":"de-AT | hr | hu | sl","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_AU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWF1IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwMDA4QiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTM3LjUgMCAxMjIg'
    b'OTAuNUwyODEgMGgzOXYzMWwtMTIwIDg5LjUgMTIwIDg5VjI0MGgtNDBsLTEyMC04OS41TDQw'
    b'LjUgMjQwSDB2LTMwbDExOS41LTg5TDAgMzJWMHoiLz4KICA8cGF0aCBmaWxsPSJyZWQiIGQ9'
    b'Ik0yMTIgMTQwLjUgMzIwIDIyMHYyMGwtMTM1LjUtOTkuNXptLTkyIDEwIDMgMTcuNS05NiA3'
    b'Mkgwek0zMjAgMHYxLjVsLTEyNC41IDk0IDEtMjJMMjk1IDB6TTAgMGwxMTkuNSA4OGgtMzBM'
    b'MCAyMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMTIwLjUgMHYyNDBoODBWMGgtODBa'
    b'TTAgODB2ODBoMzIwVjgwSDBaIi8+CiAgPHBhdGggZmlsbD0icmVkIiBkPSJNMCA5Ni41djQ4'
    b'aDMyMHYtNDh6TTEzNi41IDB2MjQwaDQ4VjB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0i'
    b'bTUyNyAzOTYuNy0yMC41IDIuNiAyLjIgMjAuNS0xNC44LTE0LjQtMTQuNyAxNC41IDItMjAu'
    b'NS0yMC41LTIuNCAxNy4zLTExLjItMTAuOS0xNy41IDE5LjYgNi41IDYuOS0xOS41IDcuMSAx'
    b'OS40IDE5LjUtNi43LTEwLjcgMTcuNiAxNy40IDExLjFabS0zLjctMTE3LjIgMi43LTEzLTku'
    b'OC05IDEzLjItMS41IDUuNS0xMi4xIDUuNSAxMi4xIDEzLjIgMS41LTkuOCA5IDIuNyAxMy0x'
    b'MS42LTYuNi0xMS42IDYuNlptLTEwNC4xLTYwLTIwLjMgMi4yIDEuOCAyMC4zLTE0LjQtMTQu'
    b'NS0xNC44IDE0LjEgMi40LTIwLjMtMjAuMi0yLjcgMTcuMy0xMC44LTEwLjUtMTcuNSAxOS4z'
    b'IDYuOEwzODcgMTc4bDYuNyAxOS4zIDE5LjQtNi4zLTEwLjkgMTcuMyAxNy4xIDExLjJaTTYy'
    b'MyAxODYuN2wtMjAuOSAyLjcgMi4zIDIwLjktMTUuMS0xNC43LTE1IDE0LjggMi4xLTIxLTIw'
    b'LjktMi40IDE3LjctMTEuNS0xMS4xLTE3LjkgMjAgNi43IDctMTkuOCA3LjIgMTkuOCAxOS45'
    b'LTYuOS0xMSAxOCAxNy44IDExLjNabS05Ni4xLTgzLjUtMjAuNyAyLjMgMS45IDIwLjgtMTQu'
    b'Ny0xNC44LTE1LjEgMTQuNCAyLjQtMjAuNy0yMC43LTIuOCAxNy43LTExTDQ2NyA3My41bDE5'
    b'LjcgNi45IDcuMy0xOS41IDYuOCAxOS43IDE5LjgtNi41LTExLjEgMTcuNiAxNy40IDExLjVa'
    b'TTIzNCAzODUuN2wtNDUuOCA1LjQgNC42IDQ1LjktMzIuOC0zMi40LTMzIDMyLjIgNC45LTQ1'
    b'LjktNDUuOC01LjggMzguOS0yNC44LTI0LTM5LjQgNDMuNiAxNSAxNS44LTQzLjQgMTUuNSA0'
    b'My41IDQzLjctMTQuNy0yNC4zIDM5LjIgMzguOCAyNS4xWiIvPgo8L3N2Zz4K', 'AU')

AU = b64_AU
index.append("AU")
index.append("AUS")
index.append("Australia")
catalog["AU"] = AU
catalog["AUS"] = AU
catalog["Australia"] = AU
country["Australia"] = ('AU', 'AUS', 0)
lookup["AU"] = ('AU', 'AUS', 'Australia', 0)
lookup["Canberra Australia"] = ('AU', 'AUS', 'Australia', 0)
lookup["AUS"] = ('AU', 'AUS', 'Australia', 0)
lookup["Australia"] = ('AU', 'AUS', 'Australia', 0)
details["AU"] = {"continent":"Oceania","capital":"Canberra","currency":"Australian Dollar","web":".au","lang":"en-AU","tz":"+08:00 | +10:00","altname":""}
#----------------------------------------------------------------------
b64_AU_ACT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNDc5MiIgd2lkdGg9IjIwMCIgaGVp'
    b'Z2h0PSIxMDAiIHZpZXdCb3g9IjAgMCAyMDAgMTAwIiB4bWxuczp4bGluaz0iaHR0cDovL3d3'
    b'dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3Zn'
    b'IiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcyBpZD0i'
    b'ZGVmczE0Nzk2IiAvPgogIDxnIGlkPSJnMTQ3OTgiPgogICAgPGltYWdlIHdpZHRoPSIyMDAi'
    b'IGhlaWdodD0iMTAwIiBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2Ut'
    b'cmVuZGVyaW5nOm9wdGltaXplUXVhbGl0eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7'
    b'YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFB'
    b'QUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4gQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFB'
    b'ZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBZiBS'
    b'a2xFUVZSNDJ1MWRkM3dVMWZhL3M3T3p2WmRrMDh0dWR0TWdIWktRQ29Fa1FKQVNlbEZRNE5u'
    b'eGlmMGhLdkxrUFJ1b0tNK2ZpcUtBIFNBbE42WkNFUUVoSVFrSWdwUGU2bTgzMjNuNS83TEpa'
    b'SUNJcVNSRG4rOWsvZHU3Y25UMTc1N3Zubm5QdXVXY2dFUGtlK09zak4vYmEgM2lkM0FoUVBE'
    b'RERvRUtCQWlZVUNKUllLbEZnb1VLREVRb0VTQ3dWS0xCUW9VR0toUUltRkFpVVdDaFFvc1ZD'
    b'Z3hBSUFBTUJqazlHeCBSb2wxLy9INTY1bm9XS1BFdXMvdzk2VFBUQmRHaXR6UjRVYUo5YWNR'
    b'RXNCMlBadzlTUVJCWVBZa29XdGpzRDhiSFgyVVdMOFBpUkhlIHRYbXIzdnBIa2krUEJnQ1lQ'
    b'VkVJQUppVkxnUUFNR21FVlhNaXkzYzlOaldaajQ3K1F3eG9PQkw5SUFnYysyeCtabUtBMldJ'
    b'OVdkeVMgbFJpSXdVQUFnRitLbWpMRysrTVF1UGhxVi9MeUh5eFcyLzM2UmpUUjcyK2hzV3cy'
    b'OFBqYnY4aFZlaXlNbVpyRXQ3TUtBREExaVk5RCBZSVBSOHNUYngrNGpxMUQ4all6M0xySHE1'
    b'YzM1UTU3NjE5YkNtdVorZE9oUll2MFJSQWpkbGswUEgvTFVvdXpReEFndmRPaFJZdjArIE1L'
    b'aUVMUzlubE85ZW5oVGxQV1NIcUdEM291MUxkN3c3M1IyTm1xTEV1a2Y0OG1oZnI4K2VraENn'
    b'VkJ2dTBrMmxOWXdMOC96cXpld2cgWHlaNkR4NUtZTy92NWRwN2xYUFc1dG5mNHhENHhhWGov'
    b'djFzcW11SC8yeS90SDdiZVlQUmdnNDlxckgrSUl3bUM0ZEJ0TCsvVk4xdCBmOE5sa2xCV29j'
    b'VDZzeEQ0TWdFQTJ3OWRUWHgweDMrMlh3SUE4SDBZNktDalUrR2ZCZCtidWU5MDdjcDNqdGxz'
    b'NExWUDgya1UvSXhVIEFUcm9LTEgrRkNBSVhHMFFQN3J1cUQwV2FyT0JwOTg3Z1dBeEpBS2kx'
    b'WnNlZ3JFem1yQjFZazZ2Z2tyRjYvbmNBUzVOODRBSU5xQ2ggWE94SU0wQitlTVNLbUJ0VEF2'
    b'S0ppT25oSVJhTXdTeGYvN1BKYkhXMjJHemd5WTBuc1BCZlBydlFhb1ZPMUFnL09wRjB1c2Fo'
    b'Z0JrayAzY3ZaaFhPaXJ3dDVrbEVVVEt4aUZIUXQ0Zmd2eUY2UUNHTWdBSURlYUQ1VGVCb2Uy'
    b'SllsT0RTU2tzQ0FsekZjbzIreldTeTJPeHZOIEZ1dDkvNjVRVC9HOHVPcVJHVEtiRGZyeS9M'
    b'akZYODV2bGd3bWFPaE55SmtiZ3UwWFlqUUduQTFBUEpvS3dWcEg4a1lXdEV5NG9saXQgWmEy'
    b'Zm1yMHl3TWNYQXptVzBiQXdSaGdvb0xwbkhiOGtDZVZlR1RGNW9BZS8yZ3lIUWV5WDYrN2Va'
    b'eVFYb1U5ZUQ4cmV2TnhxaFhCWSB5L0trc2pCUE1RYXlOWWpabjUrTk4xbGdlNTlwRWJVYlpw'
    b'Nks4dTBlQVhta1d0cXh0cGNtWno3anpuRTRSajBTV1ducEVRUlNHY3g0IGYzNUtWSmdRQU5E'
    b'VTNpMjVNanZlcCtSaE1ONy9QRWdFNU4yblUvK3g4ZmdESW8vRmh2bjBkS0xWQ2dFQXZuNXMz'
    b'NUtFU3VlcE9USFggNW4yK1dHMWl6VWdUSEQyUHovclFKLy9WTDBNOHhNT3RQbi9wZkdmcDR1'
    b'ZXJHeVJpbVdSTUVMZWs0cksyYWUwai9FSjdoN3FPZ0l2YSA3eFBqSnZCOVBhOVdMQUJnaElq'
    b'MW9KczdVNVA0OHpPRGNRajhnTWpUSm1FY3F4WUNBSWlJYVdKSXM1MXF6UktXUWs5SURtcjll'
    b'c1UrIHRjNG84R1crdmlLQnp2TDUrYXBvdU9XcDdBcEtUVjFTWHRQWDFxT2drSkRPbm41OXk0'
    b'dnBOMWtGQUJDNXRmUjNuckMvSnpLaW5EcjEgNzBVc0hBSjdjQ2l1TFRQVGd4aFVRbHFzcjJ1'
    b'alBYOXdWS0EyNGl3MmpKMVBSak1NQU5qMGN5ci8xWmY0TDcvMC92R1VHTCt1MWFrbCBoV1Vk'
    b'VnBzTmgyRDJsTVdhaC9sRy9sQ1crZU9KaHFyNlBod0MrM25RVDUvNXFzODY0M0Qvc1IrYnQw'
    b'clVqcG5SQ2h4aGFpS1JwamRoIC80N0VNcG9zN3oyWGVtcmJnbVhUdzRsNExJTEZURXZtQXdC'
    b'bVR4UUJBRHc0bE9jWHhWYnVXUkVTT0dwcHpXNVVEUmx2QkFBWXpmQTMgUmJGZE10cUdveE1C'
    b'QUZJTjZlVzkyYS91eTFxYmRaNXNQdm42cHdWVGsvai9XUHBZY2N2d3h1Mk9WSGkvc2lWL1Nr'
    b'SkFlcHpmajNuZiB3WWE2ZVhQWHpwaVN0U0QzcWIzVk0rVmF3b1cyeERIUnkreWRWWXBPQ3Q3'
    b'NE43V3gvdm5obVd2N252aHV3L1FQWDV4VWRLV0RRU1VBIEFHWlBFbnE1VWJJbUJHSmh6RmQ1'
    b'VlNjdXRveVdlRHk2Nm9ua3kxdE9Ud0FBdkhzMEhjWllCVzdTNjEyT2ZTSS9GRWU5bVhOMngr'
    b'TjcgTi8yU3lxS2xoZkU1cFFWVGtnVjFNZzFScGlYZVgwbThtUW9jMXJJbzA4ZmJKM1R1MnU5'
    b'ZnlpNFBvWlcwdUwzcDdEQjk5cGFQOTJiayBwSWJ6L1J4SlNnYkZKWWd6UXZtVjkrUVZzdWxF'
    b'cVVJM1lqZnZrYlNnZ3gvUEdmSlVaNThxUFBjcnhSMnBFeVBwRlZaMThOTGZYeVhUIE9JZ1M2'
    b'ZHNkeUpVcHRJVENldi9OQzQ0K05mRVNBRUJ2eHI1KzdJM1huMzlsNytHOVQ0WS8rdGFoakxj'
    b'UFR3SUFFSERZNEFDMlpFRGIgSlZIOVNUR3EzOW5Nb2hqYjZNVUFBc2JHNWFuODRrTnRiejB5'
    b'YXowQVFLclE1WmUxeTFXcVdlbGhMTHBEemd1WEwzbktjd1BZWFErSyB4c0xqNEUzUHA2MTg1'
    b'OWlJRWV0UWZzT3VZeldMc2tQdlBMVnF3ekhGWFJOeVJnQVJQcjA3SHQvN1RWR00yWXFCQUdn'
    b'ZllCd29ENk1UIGRkbGo2dHRsRExVUlQ4RVpDRmp6KzFNM2JQZ0tHeHMzczFmRkFBQmdNRkJt'
    b'UWtCaXBKY0hoNEpnNEcrUFhqMTN1ZjEzNjBzT2VXeVEgRzRMRi9GTFVCQUFvN1prUzVBV0xy'
    b'NjVLNXhjREFFVEVYUi8vajRXbkJBVUYrczlLRjFtc3RyT2xiU2F6eFdxenlSUUthOThYRTJL'
    b'NiBSbXlVZnB0WUUrUDhGbVNHUEx2cGxONW9IaG1aMG1KOXh3WnhoM0t0d2Z6TWtJcmF2ajdw'
    b'cUMyZWFBeTQveXVNZStOQXB0YUkyRnVDIDNQc1hqS3ZhYzNuczRjcVF3NVVobHhwOTFtYWZ6'
    b'd3h0UUxDV2RlbnJ0MWRqaXJFWkFNZ2hBSktqZkFBQWplMHlzOFUyaHUrV1g5WnUgdTdkNUNZ'
    b'ZURVNko4MHNmNXJwd1pxZFFZVjIwNFp2OWdrendLZitXbDdLQnpBSURTanBnMjYrckZ1ZlBk'
    b'MkRTN2FpK3E3TXhKRVpDSiBEam1iMnQvYlZlaWVLL3dJaHgySjdKTGJJKzlZR09QR0lxbDFn'
    b'MHRMcnl5UGp4L3JkZmw2VDEzYndPQUU3MDVWYXU2L0dlamxSdjF5IFhmWUhMMHgwWXcyUlhB'
    b'cEJJRkxrdm5KMnBNNWdMcS9wdGJyY2xwR0p2QnROMkRjUFRsNS9hTEtyMHo2Z0liVkptVlBI'
    b'MXRYMnVBRUEgMnFUTTNTV1JIUVAwQ044ZUZsa1h5aTRzYVE1UWFzem5hZ05vVklJUGoxcFpK'
    b'MzVsZVh4cnQrTDV4Ykg5TWwxUHY4YTVGSUZENE1kbiBSWmJmNkhWZVhPakxmRFJueklwSHhr'
    b'Nkk4c1pBME81ak5TOXZ5YTl1bEFBQVZxVmVGc3V0Q3lNUG1TendudG8xd3ZoUGsrTFR5Q1E4'
    b'IEFNQnNzUjY3MEx3d0s5UTFUTU9pVTROREorMHBNRVp3ejQ4Q3NhdzIyd2YvbkxRNk45Smdz'
    b'alIxeWdFQVg2N0xKaE1SbzhseThGd0QgbDBsYU5TZnlmK3V5NmxvSDZsb0g3cThvQ1dPOXZu'
    b'bHJhblF3ei9rbit4V3JFSW9VdVk4SjR1YVhkVGlWNk1nUTYyaFY4SE83YzRZZyBuQmtieUpH'
    b'MURUQXRWb2VYWGRuaGVhWldrTWh2OTJZcW9uM3E4K3NDQytvQ08zcVY0OGQ2SjBSNFhicmFM'
    b'WlpwOEZnNGxNOVpraDJHIHg4Rnl0VUd0TmVaT0VzV0c4L3I2MVdxZGFYb0sveDl6bzNNemdq'
    b'a01va1puMm4rbWZ1dWVLOFhWWFdxdDQvLzh6TVRpcVdIbEJoTjIgVi8xLzU4OWZ4MkhSbmZL'
    b'Y0xtbWRIQjl3Wi9BUHhrQnVIdEVWVlJmOW1lM0RQVlpEVElXdmJEbDNiZDhUK3o4UVNHVGEv'
    b'TEoyTnhZSiBBREFqTldqL0I3T21wd2h3Q0x6cldNMmgvSWI3TGtyeDFhNzRaVHZzV3BQTEpI'
    b'M3hSdVlqYVVHdUhSNWRkL1J3UWFOY3BSK3RlWEJuIGFlU3ZuWkpxU0hTaVhxSWFWTFRYT3Qy'
    b'ZitHNzJnYWQrOEdYTEhkT296dlQyRjRXZWJ0U3VQaFVBQUlkZ0VpTjlJb1Z1a1NMZTIwOGwg'
    b'N3o1K0kwTEl4U0hZWnhmR0RTajFIaHd5QUtDcXZ1OW9RV09aaXc2N0RUL1ZyMTJ5YU0xdDYv'
    b'b0dvK1hYL3B3ZVhPWWxLQWVBWVZkYSBROFN4RkdyRDZuZVBBd0M0VE5MY3ljSDJSaWFOTUh1'
    b'U0NJZkFmVkxOYy84NU5hd3ltUzNXbm40MWkwYXcyMVhYbS9wdnVoSFlVV1RWIGdKWjA4dG90'
    b'Uko4Z2FMczVSOXVDM1B0ZFdXVkhlYXZYSjJjU2JUYkkxVXkwczRwS3hzOU1GK1pmYnR1ODgv'
    b'STNoNnQySDdzeEljSXIgZm95WHhXS05GTG1GODduWG0vcGYvT2pzVzl1SzdzS3EvT2FVS2Rt'
    b'djNKa3RFaTdnRkYzcGREaURsWjIzNnhLeWNOUUNwTDhVTlgxNyBlT2laNWVuM1RvNU02TUdl'
    b'ZmZyS2xuTnhpNzh0ck9nQUFBUjZNMGJSR2RRYUVLVWVmMnV3Vk8yd2piQVduUkVaSDlnUjY5'
    b'K1pHVjVQIEl3ejZyVnRPVGJqUk00UWpRaUVpSW44MkhvRXo0djJYNTR5TkNlVmR2dDd6ZFY1'
    b'VmI3L21kRWxyWjU5U3JUWEdoZkhZOUx0RnZ3YmcgV2M2Rlp3QkFVNmY4YUdGalo1K3FyR2FR'
    b'aTJ3R3NiWlZlb3N0QVpOSGpWanhZengvelMrYmtSWTBBc1d1U0FTRXg2YXMvK0w4KzkrViA2'
    b'QXptbk9mMmxkWDBDa1kxcmRsZ2dwMjZCNEpzR2FHTkhJcWFSZFlHdWZjYlROajk1ZUZlVEtY'
    b'UmpEMVh5MDhLYXZYbnlCemExNG9wIGF4MWlFeVdDUUlGZTlNTHRTOWF0bkNEMFkwbGsyZ2lS'
    b'VzBxTXI3OG5QZGlmYmJaWWxXcmpzbW5oYTVlTlg1UWRSaVFNTWEvcFRWaWEgVzRMenNLQzhY'
    b'YWsyVEU4UkhNcHZTSS96cysrOWEyaVh1VEhKZVdmcTdlYXk0NWJEZVBzaStvamFXQ3c2WWYz'
    b'cXBHZm14emozeGQvbSBseTJiSGo1bmt1aURIU1gvL3JyWWFCb3V4NVh2dy9oa2Q5azdYMTZ3'
    b'SHlvMWh1eW45M3k4Tm1NVWllVzZ5a1luR2pnVVRVMFBiMjNXICtUMmxZMzFaY3JVQmQ2QTh6'
    b'S0h2cTI5WmUrNFl1T1gvNE90Qm01Yk1kMk9TclZaYlk3dk15NDE2dEtoeDM2azZIcHRNSW1D'
    b'Tkppc08gd2ZUMGEwd1dpdzJ5K1hzdzBtSjlsajh5NXZMMW5xL3lxdHA3bEU0WHNsUE9qb3dQ'
    b'ZGw0Mk5jYXhuUHIwL0dnQXdJMFdLWmRKT2wvUiBBUUJZTkRYcytJVm1mcTdEUUNRUktWb2pR'
    b'aUVZUjQ1WXNhRzhUMStkSXZKakRja3ExNURwcWptUlFqL1dNNXRPRGlpR3hlaHA3MUcrIDhN'
    b'RnAxNVordWU2WlRTZEhrVmhXRiswdTF4SmErNWt5TFhIZGdjblRJMnN6UWhvL1BKbk01MHFi'
    b'SkVNc1lock1XQXhrZ3lBUUcrcVIgRk9YTnBCRXl4dmwvLy9PMTVpNzVHQUYzMmIrT1dLeTJs'
    b'Yk1qVzNzVXErZEV2ZlpKL3RwSEo1UlVkK2tNNW04T1hzWENHQ2FOTUhkeSA4SXpVb05kV2tH'
    b'cGIrZ2VVK3A5TzFtbDBScE9WVE1RUDRYdjFTalZVRXM3UGc3YitpNkxGVTBNalJlNTVaK3NY'
    b'Wm9lNCtJYVlrZFpZIFpUVzlDY3QyMkFNcVhDWnA4MHVUY2pPQ1hUczh1ZkhFL2pOMUVwbDJ1'
    b'TVVhTXJ3K3VqRjNGbG1MeFZqTk53TUtsNXA5NThaVzEvVnkgRDEwSjVYT2xPWkUzdW1UMElU'
    b'OUlKK3BWZW56OFdLOEwyNWQrc3J1c3FMTHowTG1HeXJvK2k5VzJMQ2Q4VVhiWTl6OWZDeGR3'
    b'aEw0cyBoVnEvY25hRTJXd1ZlRFBiZXBSMlAwWWkwMzcrVThYblAxWEVodkNXNW96NTc1cG9L'
    b'aG4veWE0eUtqSWdsYXZ1M0UzT1paSk9YV294IG1peHZQNWxFSWlDOVVnMkhRYVNSQjYxRHVi'
    b'eUh4akdNS0xGY0lvR1dMckhLS2MyTkZxbTlsaHFDeFl3QXF4NU1jS2dhYjVhaXRYOXcgNjNa'
    b'VnA4Y1k3OTdxVGw2VGhEMmtycktEUWRLMVNubmxOYjFKeTM5bzdKQUYrVElKZU94WW9UdXdX'
    b'YS9jNkpPcDlBQ0F5bnB4eGppLyAzbjZOTzV1TXg4RXdURHhVNEFqb0pFWjQ0aEJzVTRlTVFN'
    b'RHVPbmJ0bys5THBRb3RCZ1BaSUd5ZnVDdVV6N3N6V0pXVkdPZzhMQ3p2IGNMcjJONzN1a2Nq'
    b'S3YxdmFqTUNIQ1FCWTkzbGh6TUx0K1dYdEFBQyt6LzNmRVI4Vi9OY29JWW1ITFJPRG0xeGI2'
    b'bnM1VGlQOUxnajEgRURmSXhoaE5sb3RWblZhcmJXRjI2THpKSWJNbkNWTmovU2JIQjNUMnFR'
    b'QUFhbzB4VXVRZTZNMklFcm1QRVhBalJXNVY5WTdVMDdSWSAvd1ZaSWVuai9HWlBDazZQOVcv'
    b'clVhaTFKcXZWZHE1NXNxTC82bTkrT3hHUGhXNmQ5eXo2MXRFa0ZoYkcrSHJRTnUrOC9PNy9Y'
    b'ZFFaIHpOT2UzVnQwcFpOL3Z4MStIcHU4OS8xWk1BYjZTM0FyTGJqbERqZDVhTWxUUlk2ZVVi'
    b'N2RDSTRRZWpPQnpHS3hZQ0RBWTVPRXZxeVkgRVBlMlhzVWcvd0k1TTlPRkZCSVNHc2dKQ2VB'
    b'TTZoZXJoVUhCVDBzV2VMQkpldVBnVWx1UHhzZXFMbkgxQ29lVTVEWldHVTBXeEZBeSBtc1R5'
    b'OTZUdk9ITHRueCtlY1VSeDlLYnB6KzI5NzFiTzQ3TWkrTjZNdjByWnlBUitHd2xudXZXMjNi'
    b'Nk1qTUhZUEJsSzZzMVExbFBwIGw3b055U3lxNDZ4TVpXanRWdGEzeTB4bVMwKy9wdGtsQ21D'
    b'M3U3ZnVxYmc5V0NYWEcweldwZzZaeFdxVHFRYkhYK1R2dzBNS2l5dXEgN0ljcWpiRkxyQm95'
    b'UXVTSzQwVlZTYjVuUjJDc2ZqVzdRU0xUcnJ5NWl1NjBuWi9aZEI5aTdqZ0VuanM1MkkxRll0'
    b'R0lLMmFPQlFCcyBlQ29sSm9RM29OQzM5U2lHWTdIb2ZzR1BKWjhaZFgxWGljTnZKMkROT3VN'
    b'dEVTWXN4c3BqcU5KRnpjMFNsajF3bWhiY1hHTmNTS1Z3IGdnT1EyaFlwQU1CbXMwMUw1dk00'
    b'NUc2eCt1RForcWhnZHg2YlFzREJKeTYyZUx0VG8wTjRqUjJ5eG5hWjFXcDdka0hzMXdjckdU'
    b'UkMgZXF5dlhHWGdza2dmN0NnRkFPQVJPRkxrbmphT0wyMElOYmNlQjlFUmRnS2R1dFM2TUNz'
    b'VWhxRzc3TnlzYjJxZEVhMGJUV0lOcVp6dSB5NHFLMFdTUnluV2Z2ejdGNlJ4RUNOMGloRzdk'
    b'RXZXTTUvYzl5QnJyWkUyUTNveEFrTTArQTlvZ2dNWGNzbmt3YTB4OVFWMUFtR2ZmIHpwSklB'
    b'TURzNkd0ODdrQ3RWTFJrZHRxbkIzYzRqUjRHRmUvQm9lQVJiRzZHQ0llRDNWbmtYcWthajJB'
    b'dVgrOFcrckhQWFc2TENmRjQgZWw3VW5JeGdDaGtiRStMaHc2UDU4RUJMbDl3ZVh6Q1lMQUZl'
    b'OUtTNDZNTWRRVmg5c2MwR0lBaU1DZUx1T1hFRGdzRFowcllwQ1FHRCBVUklYM1ZCWjF6ZGhY'
    b'R3hoWTJxS2Y4Rm9HdS9EaCtNWG0xTlc3T3pwVjd2KzVyakYzNWIvK3JyWXFLTlBTWGwxWCti'
    b'NWV2L2tJSWZ4IGF6Qmg4WWpaMWE0SzlSVEgrSFY5a1I5dkR4UkYrM1UzaUhsQlFkRjdEdWMx'
    b'ZGNpZFlhUXR1OHIwUmpPWmlKQUlPTDQzRTR1RkF6eVogR3AyWlFTVXExUVllbTlMZXEweU85'
    b'dXZvVTQwUDk3SmFBQUNnb1YyMjQrZzF3czBRL0tHQ3hzb2JEUUF2RkRFdjE3ZjIyazJYa0VC'
    b'MiBhN2Vpb1YxV2NyTzJqNTF6VGpSMXloUEcrZzdnbjlZWThBOG5zUUFBVmZYaUhva3JzY1Rk'
    b'TG9jUEdyUUdaTVBoaWRlNmVCSVZtVWtlIG5FcnNlVEoyZWxFSmhpNFpyVk5HYjVNNlhCd1JU'
    b'MUlybnlEMDV5SFd3WlZnR2dYLzFMeG9BZzZMeDhFNEhFWWkxd3I5bUdxZFVhMHogQ3YyWUVy'
    b'a1dnb0F2ajlvM29HYlNDRXdhQVVFd0FJQWdYK2JDckZBaXpwRUpROFBKT2p1YldXNlJUTEtt'
    b'dnI3YzNwaVRFcVRTR2dPOCA2UGFRa01GbzZaZHIzVzltdGhsTkZoSUJBUURNeU03ZDIvQXZa'
    b'MER1WVNNV25ZS1BFTG0zOXlyLy9YV3hRbTFJamZGNVlGa2xVWkZmIFA1QzU5VnlDTTFKNm04'
    b'MCtPYlJSeEpPTUMreTQyc2xyRkRzY1FETGVPTmE3MTB5ZUJrR0FSaGtNWXhMd3NOQ1BaVEJh'
    b'bWpybG9nQk8gYmtad2FDQm5SbHBRbUlEYjFxTlFxSTE0UEJ6b3padzNKU1F4d2lzeHdvdkRK'
    b'TnByQVF2OVdNNVF1eTliUnFON1RJaU55bStmWjFaWCBPQjNBbUJBZWpNRVVYKzFTYVl5blMx'
    b'cVZHaU9kaW5lNmpaRkNkd0FBQmdNdFhQRGF6cnFORWpYOUlTUlcvRmpQclh2S3czTy9ldU96'
    b'IGd1Q1pYeFpWZG83aWJzRzdvS0dQcy9IbmRCWkZsOGh2QXdCa2hEYnFqRWk0VjUvVEsvUmhL'
    b'WWlJQ1krMS9GQWNWZDNKQy9mcTgyUEwgQVFDdlRjMHY2WnMzTFd0cGE2ZVlST003L1VRaUhn'
    b'RUFYRytTSEMxc3hHRXhkcTdjYU80dnF1aTRmTDJYZ01EWEc2VW5MamJMbEhvcyBqTEcvdnNx'
    b'clVtb01BQURDVFdJRmVCQ2l3NE1sQTBwQjVCcVRxcXl4clJzQWNPcFNxOGxzelV3TWlBdnp3'
    b'T1BneGc0WkhvRTFONU9CIHRYcFRRWGxiWTRjTUFMRHphQ25YTTJuYjFVOS9LQnV1Wnh3Tlkx'
    b'R1F1Nk8xUy9GTFViTjlHVnV0TStXZHJWZHJqYlkvdWpkcCtESkkgMlJSdFZuaTlGMFBacldC'
    b'a2o2azdmVU53cWNrM01hajlSbzhiQUVERTY3L1M1cGtiZTYxVFJxOXM5NFFnVzVxbytXS2pY'
    b'NHFvaFVSQSBmaXhMOXFESnhUVXYwcjFtdFRSWE4vZmhBUUFaNC8wNURDS0N4VEJwQklQSjR1'
    b'ZEJ2OW9ndm5LalQyc3crL0pvYkRxUlJTY29OY1l1IGlZckhvWkFJU0Uxei94Z0JGd3RqWkVw'
    b'OWZubkgxUVl4QU9EUlRIWi9mM05EeFFjdG1nUXNQZVZDYVZsMHVDakFpM0g4UW5Pd1B6dkEg'
    b'aTNIcVVvdFNiVWlKOXFsdWxBVDVzZ0FBRFcyeU9SbWlpaHVkeDR0cWFIQ2R3TEltemZlbmhJ'
    b'QWJENXZHdXZNQkFnL3lJd1U4R2NwQSByblREa1ludFVvYkZoa0ZnUjFvSEJyS2xpbG8rUHhk'
    b'L29kRVBBQkFmMkZGUUZ6Z3BwTWxraHJlZWpyaFNKL254eUlsTTBUbHN6eG9LIGhXb1BPNGZ4'
    b'T1FBQUdNYTRzOGtTbWFhblgxM2RJS0dRY1FnVzQyb25kSXJWWjB0YnJWYWJTbVB3Y25QRXdj'
    b'WUdPVDdiM2ErYlFIK1IgUVZEZ1lmM2lhVEd2UGJubzZQbm1MckhhWXJFQ0FQQTRlSHFLUU9q'
    b'SFVtZ016bEprZGlzK0l6NG9KelhFcW1zUXVuVnlxY080SitWQiBMd3J5SUVCbHdMK3hmOHFu'
    b'WnhKdml6b204TnM5R0tyeVZwcFk2U2dMd0tWcUFqZ0Q1eHNDT2dZYzVvc3Y5VG9CYTU3Z1c4'
    b'aWNXcHQzIDhZVzRjRjZFMEcxdzlHRzRwVXZlMmFmaU1rbnR2VXFkd2N5a0VnQUFSck5GTE5Y'
    b'UXlmaFRKYTBCWGd3bWpXRHZIOFozQXdDRWVYUi8gbkxNRkFBQkQ1YVZtaTkxc1dwQVpVbGpS'
    b'b2RJYVc3cmtBVjRNQU1DVWhJQTN0aHgwNTdBQnVHV3QwTWVETTNmK3hwMC9zaFlKWHh1KyBI'
    b'VHZvRTFaL0c5dk9qWGRsbGRNWlhEaSs2c1VwNTZWcWtzdU0zSmRYRWRZanB5NVBLdi9mc3J6'
    b'dm4vaHAwMXhIblp4UUQzR2tiOCtBIFFpOVREcjV3Q0F4QkdKM1JwTkdiRkNxRFdtdlU2RTBh'
    b'dlVtdE5TclVCcVBKZ2tOZ3FYeXdmN2RZRFFCWU5MN1NmazEzcXRSTDkveVogSWtkUUtpWGFK'
    b'MUxrYnMvQmtzZzBBSUJFN3pQakNLdEtxdXB2KzBVSUZyTm8vajhQTmF4RU5kYW9vYmFIdSs3'
    b'Z1pOZVc2UkcxSEtxVyBROUhPaUt6eFk4dWZTTDIyN2tDS3hRcG1SVjJmSUdoUEViYUdlSWlI'
    b'WEp4ZU03bG80Nmt3SG9mc0dzOHJxR2h2YkpjYmpPWStxWVpDIHd0RXBlQWlDZEFaVHYwelgx'
    b'Q0hQcjJoZnN5alcrUkVxR1NIampTdVN5NXhYaVBhczZGSE9QcklyRllJcFprQ0dnS1d4SSt4'
    b'R3VNZG4gdTRxU1l3U0lwaTArdkhadjNlN3hFZXY3WmFyODBycTBjWTRrUkJ3Q2N3S1h5elE3'
    b'bUdRdFNxeFJRSmVjeHFGb2UrVVVlNUVaZDdycSB5MGNQZkhjaCtzMmNNM2J2ejQxdU9MUjU3'
    b'Z3YvemRzNDUrVGRxMkV0R2wrMTRYQVRMK05UWjR2SlpORzdGQ2VYS25UUndUeG5sUGhNIGFT'
    b'c0E0UGo1WmdnekdFWi9abEx4YmJhUkIyMGdoNWJuUEh3a0NIeDB0TWRpU3p0NThjYVc3Sk1B'
    b'Z0ZES3p1cmFSVUQydzdVZWN0cTQgZHh5L1M2d0k5QmQxbEhPWjVEWjBLaHdGQ0xnRG55dzhZ'
    b'bWNWQUdCQlhMVUhYZVhOVk00ZjUxajlGZkprS2RFK2E2YzEvR2FOTlFTMiBmTGJrb0VwamRM'
    b'NWNXUlV1NEc1OEptM2U1SkExaStOb1pKeXpYYTBiN0UvSFNWK2JtditiTXErSzJ6d3RrVG96'
    b'RVVmRkd3QUFZYnlHIDZzdGJXV1J0Q0t0UW9YWkVkNVVxOVd2dmJ4ZHdocXZtSUVxczM0QWZS'
    b'eWE5V2Y4RGdTMUxFaXJzMFN5M216V1MyY1EraVV6anc3bW4gcTJXRjF6L3VNcEhkTk9FeFNk'
    b'SGViNjJlOE1LU1dBb1orL3JqQ1dzV2p3c051UDJLTUdUZHZtSWZuZmpieTdVVW5BRVlPakMy'
    b'd1p5YyBHZnh0QTlLdTlNRENrNmQrc0xlRThMMXl4aFRkbHF5QkVtdEVFZVFtSlNJbU41cDYz'
    b'MU83WXYyN0FBQTgrbUNDQ2hHcjAra05Gc3U5IFdpcWZMVG1Vd0w4bGQ4cHNzWVlHY1BybHVn'
    b'Tm42a1QrN0NNRmpkN3VWQmk2UGRQcnZkd1RVOEx1TmZVRHNpcUFkVENOZ0VJd1BEYnUgQ0Fa'
    b'aml5QnRPbndpejJTMjFqUzBpTmkxcVBFK21rZ0xicTUvNzBNaVltSlRobUNQemt3Z0VnakFl'
    b'cTk1SHdTcytaYzEyek0vV2xIYSBNcmlLMWR3cFg3dHNmSFdqUkdzd0pVWjY5ZlpyNmpwdTJR'
    b'eTRidnJabDdJS2Y0ZlFWajNBRHBIdUsrUTI4L1FMeit4UDVaSGJvNzJIIGtWaW94cm9uZURN'
    b'VlE3SUtBTkN1anZUaDBiUWc4TjZ2eGlEcDgxLzV2MVdwcGM2VzRxdGRoL0xyWlVwOWRxTGdh'
    b'RUhqOXo5WEcwMVcgSnhHL2Vtei9PN04rUnlhY3hvQ0hDQUZFR2w5ckhHSkRJbzFneUFvNkdl'
    b'bFpPNndqaG1xc1B3NlRCVDdaT0kzZ3VSTEJZcEludlh5dyAyQnRyYXJBWmU4WjduWEdqL2tZ'
    b'dVBCRXgvVzlaM3NUZ3BqVzdwL2NxcVJxZDZWSjFGNW1JcTZ6dFUyZ016aHliWkdIcnRxVjVv'
    b'WjczIFZIcTVxaWU4WFIwRnNONFFKV2JxNUJ5VDJacDNjS09Bc0RQV3UycmtCK2N2VU9mOVhq'
    b'QXFEeHQvN2ZqYlVXR2hUSUxZYUNXSlFqSUUgL3Q0NmczbmZxZHFlenJJNHpxNzB3SHZTTVZv'
    b'anN2VnN3a2Nua25xVlZOZjJCSDc3K2hsbk1zUHI3KzBpdUY5YVZ0UXFjcExpd3BPaiBmR0FN'
    b'VkhDcFdDZXZzdG1nWmdtYmEvMXgzdGo5RHlleGlIaXN6bUIreUlnbDFaRFlONk9McHhzbnF1'
    b'ai93a3YvN1VlckdkQzdYK2xOIGlQYzhQYzYvL2g0dlpiWmlqbGNMZnl5TnVOYmxuaDFldHlT'
    b'aE11eG1Bc1c5WU92NVhBOFdKb0JXQmtHMks1S3BkTjdrQlBJS0Q5b0EgQU1CcWhSUTZnbXNP'
    b'MlVORnJFM1BwYjM2U2Y1RFJxemJrTjhZa3lZb0gzWGxiYlppaWxzamtnT3ZqSzRZSTJHOE02'
    b'aUVGNWJFOFVlMSBWc3hJT0k4UEFLc0FBRmlNZGRSWk5WekV1cTJtd1BRVVBnNkJaMDI4cFZR'
    b'R0FZZUZJSURpWWNXd0VPdUZKWEUvL1hkbXhuaC9PM1htIFRCSUJBR1pQY3RUN2lnbmhiWGs1'
    b'NDgzVkUydzJkUHdmV2d4THVPR0RIYVZsT3g4N3RXMUJjNmQ4eDlGcjl0MUk0OE05MTY5T21q'
    b'Y2wgT0RTUTA5R3JETS85R2gzOWh4akRaYnhIQmJ1WGZQK29hMWFrSzZZKzg5T3hDODBQbWZH'
    b'T1lpU005eXUxZmU5L04zU05nSzhQVnQxZiBWcUg0R3hHTFNzWlJTRU1YN3NVaE1JZEJSSWNl'
    b'SmRidlJrNnE0TnErSjU1YkdEdmsyYVhUd3VzUHJYNStVZXhmcGNnTWl0RW5sZytQIGR2S0xC'
    b'WWMzNTk1OWt5Q1RSdGo4VXNhRmI1ZUsvRm5vUFVDOXd0OUdSNjl5eXBNLzBpbDRIb2ZNWlpJ'
    b'V1pJYmFhNjA2c2V0WXpiWjkgVnlRRFdyRk1NMHoxUzFFOHRPRUdoZHFnVUJ2cVdnZWNaVTlr'
    b'U3IxOUQ1TkdaN1J2STBHQlRvVi9ISHh2SmdDZ3BMcGJNR1BiMGNKRyBad3NLbEZoL0NnSWY1'
    b'dFVHOGRSbmZ4cFE2T2VzelR0eHNZVS9xZzhCUVBHUUVNdGl0V1krdWNkdVN4bE5sdGt2SG1q'
    b'clVlSnhNRHJ1IEtMSCtPR0FNTlBlbGc3MHVENjNVNmswelg5aVBSOUMwVmRSNC8xUHF5blpu'
    b'dVZXWkV2VUVVWTJGQWdWS0xCUW9zVkNneEVLQkFpVVcgQ3BSWUtGQmlvVUNCRWdzRlNpd1VL'
    b'TEZRb0VDSmhlSkJ3UDhEZmJva0lzRlRzY1lBQUFBbGRFVllkR1JoZEdVNlkzSmxZWFJsQURJ'
    b'dyBNakl0TURZdE1UVlVNVGc2TkRRNk1Ea3JNREE2TURDcFNSWUVBQUFBSlhSRldIUmtZWFJs'
    b'T20xdlpHbG1lUUF5TURJeUxUQTJMVEUxIFZERTRPalEwT2pBNUt6QXdPakF3MkJTdXVBQUFB'
    b'QUJKUlU1RXJrSmdnZz09ICIgaWQ9ImltYWdlMTQ4MDAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'AU_ACT')

AU_ACT = b64_AU_ACT
index.append("AU_ACT")
index.append("Australia Capital Territory")
catalog["AU_ACT"] = AU_ACT
catalog["Australia Capital Territory"] = AU_ACT
country["Australia Capital Territory"] = ('AU_ACT', '', 1)
lookup["AU_ACT"] = ('AU_ACT', '', 'Australia Capital Territory', 1)
lookup["Australia Capital Territory"] = ('AU_ACT', '', 'Australia Capital Territory', 1)
details["AU_ACT"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":""}
regional["AU_ACT"] = ('AU_ACT', 'Australia Capital Territory', 1)
regional["Australia Capital Territory"] = ('AU_ACT', 'Australia Capital Territory', 1)
#----------------------------------------------------------------------
b64_AU_NSW = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcyIiB3aWR0aD0iMjAwIiBoZWlnaHQ9'
    b'IjEwMCIgdmlld0JveD0iMCAwIDIwMCAxMDAiIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHht'
    b'bG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzIGlkPSJkZWZz'
    b'NiIgLz4KICA8ZyBpZD0iZzgiPgogICAgPGltYWdlIHdpZHRoPSIyMDAiIGhlaWdodD0iMTAw'
    b'IiBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9w'
    b'dGltaXplUXVhbGl0eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9S'
    b'dzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFBQUJHZEJUVUVBQUxH'
    b'UEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2'
    b'bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBTgp1a2xFUVZSNDJ1MmRl'
    b'MXdUUng3QWY3TzdTVWdDQ1FGOElRK2hTa1ZVcWljVzhOcXoxaXRhUzdWYXRSWEY5ancrVnJI'
    b'dFNYdDkxd2VlCkg2OWVxejBGN2RYenpvcGFMZWVqdGZTd1ZjL1B4eXBVck5ZSHFOQUtRbmhV'
    b'REsrOFNMSzdjMzhFQXlMRUVEYVE0SHova2VEc3pzN00KbDVuWmVRVlZKRDNqbDdwY0Z2Y0lk'
    b'RUpSU2RVSFcvKzcrMUEreC9FZ0tMT25qZnRpeXhMcnp5VWpndTJFSEZaVVlmMWh6dEt0MlRs'
    b'bgpoWDBNaWtMVEpvMWVuVFpqVEZRSWI5QTM3ZDliOTJrR3A3blZOb3gwYkl4ZjZuTDVjenVB'
    b'NEdDdUdzOFZWQzZhcDU0LzA1QjNzc01RCkk0WUZmclpoMGNVanE1Tm54ZE0wMWFjU1Q2SEV5'
    b'ZEZudjE3eDFmWlhvc1A4RzdLMmx5WDh0bmJkcXJaV1NjZkdETjYrSjJqWEFUdC8KZTRTN1lh'
    b'ei9XUFd5L2wxMm1JTld2ZDVjTXRWRnRWZlBLOVcybG1ySTJ0NVpMVVY4Y2xJczJsZkZOZFRm'
    b'b1ZkTXJQK3kxNlF4c1gxUwpyenVVMHV2cVB0M2NzR09iTFFkYWxPbzhCd2lPNXZPUW8zbjkz'
    b'bDVGK3dmWWZtVXN5RmN2bkgzUHh2RkM3dXE1aWVNcENubVFVbk1UCngxODhrdDdhOEUxNVJQ'
    b'UHgrclpXdFRSOG4yVVRxN3FiMjFmVWpiNExGZzA1OG4xN3ZlN1Y5NHFLQ055YnNmamlrWFQz'
    b'MTh1bTFONk0KeFpGQlN1ZjZVb1hGVlVTWEx1VDU2SVFWVHkvYWRLRlUweDI5TG4yYjdwNWRl'
    b'MXYzdkR0S0ZaVlVMVXpiSGoxbEpkSEZjUkNFL0tGTApyOXdDRGt5NGRMaWhWMUpFYUM5V3J4'
    b'U0dpOFFpU3JtZFdEMWNNSUtMUlpSeWE3RjZySkFFRklzbzVURmk5VUNCQ1NJV1Vjb2p4WEpw'
    b'CjRYVlRMS0tVeDR2bG9vSjBXaXlpVko4U1MzQzlUR1oyYjhiaUxvazFOL1VUWTdPWktOVUh4'
    b'UkpRTDNWMWZkQWdWWmZFS3EyNEZSWWMKUUpUeUFMRm1MOW5pL01VSWpSMFpPdWVwbUxEZ0FH'
    b'd3lHWDQ0cFR1YXkydTFiY09Jd3gvd1RwZ21pWWkwZnlzSHhjS3N4WEQ2cEJPeApxS3Zydi96'
    b'Mi9NbUNFcDUzWGluQmw0TDFaYkV3eHU3d0hBNksxY3VaRmJxSUdPTm9tMGF5Z0VERUluaE9V'
    b'MWdjR1VSeXdVRWk5RStRClRDQTFGb0dJUlNCaUVRaEVMRUt2d1pBczhDQkNCL3ZIKzNFUnhY'
    b'bGh5REFZR1gyUlJZNVlBTkJqcGdHTDFGaGFobVhYaHNXZHJxUEsKcStxSVdJUjdFQlljc0dC'
    b'bWZOS00ySWp3QVpyTURYWFgydzhYSzVGRmlTeWhZSmdBR3I4bm4vVlBUYnQydldiM3dmeXNB'
    b'M2xsNmx0RQpMRUo3UmtjR3ZaYVNrRFFqdHFzYlZSNE1INWorMm94Vnk2Zm5ITCs0WnRQaGdn'
    b'dWxSQ3dDQU1DQUFNWDZkMll2bUJtSGtMMnRkVWdFCkFJQXRuZlNnS1pRNE9UcHhjblIyenRt'
    b'WFYreis5VllUNmJ6ZjF6dy8vZUdyLzF1YlBDdmVqbFcwRHdJQTczR005empHOXJFelprOGIK'
    b'ZCtYNDJybUo0M3V1eG5LVCtWMlBtSVFHMTA5Q2kwVk14cHFrbE9jZnZXZElXUlR0KzdpSWtp'
    b'SUE4SjBrYWpobTBlYXpkc0tybExLOQpHWXNueGo3NDZxclB6UmFXTklYM0VYS1paUDhuU3hO'
    b'K045S1J3S1l5WGpLRVJnd0FBR2JCVkdaeTVLcVg1aytNQ0Ivd1RFcG1rODVJCm1zTDdBaCs1'
    b'MTdFOXJ6dG9sVFNTSHZ5R0ZOMnVGaEFEZzkrUVNpTnBSNjZkRkI5NVpGZWF0MXppMmhwcnp0'
    b'S3RUbC9jZHFGZloySE0KcGIvb2NyODJGVis5UTJlNVhQYklSTy9IbmtCaXNTREpzQmZMbzQ4'
    b'anFWU1FoWDR1YlFHenR5NTVlRXk0ZytHTlY3anlGWWF3alhKYgpqVlcrd3NEcEhGMWFGenNt'
    b'L010L3Z2emt3bzlOWmxlMWlZeHpxeUxiTGszdU5QSG5DdW95TjdZNzlJSDJWU21UWGxBbHAx'
    b'QStQdXJxCitxQkJYUlBMdWpTNWc0SUplOEJ2eWF0M3g5aDBZSjgxeHNEa2xOU0ZreDZMSCs2'
    b'ZVM1TXoxaVE1V0ZlMXRwdGo2TVlURm5FZ0FnQnoKRlphUG9adE9kc0dTU2ZHUkg2OThmc203'
    b'V1M1S1ViYzJVeml0bENDYktib1p1L3ZvTmVlcG1IMlpMemtZV0pPNW9TNXpZMHN2aGdmWgpL'
    b'Qm9BREpjNDYwY0E4RXRkN3ArYTV1RGQ1cis2YmZlaC9GN3VZN1U5V0xHemN1M3dkQnJhVitX'
    b'WHVueklrVlArcVdsWGE3UUwwN2FQClRsaTVjLzlwSjFvbGpQSGhveGZHUFpYKzlLSk41d3ZM'
    b'Tys1L2RIUjZETmRRWDVlNXNTeGhnaVp6dy9DQlB1NXorT1dBQU1VLzFpVTcKY3lVUEFHQW81'
    b'QXlGbk8xalY4bjh5L3hCL1pXOUpwYmdTbld6cXVENXZxUFhoKy9OOFZYSXVwRVhUaXBsUmVr'
    b'alhmZm1zNzBnbHJzcAoxY2YwR2pzeU5HbEdMeDhkbUR3ckxqb3l1T2ZFY21lbCtveGU3eXli'
    b'Wm4vR3BnZEFDTDJ6YkZwUGlPVXBTbm02WG1IQkFjOGtqSFdICnQ0ZG5ueHdYT3RqZmhXSjVv'
    b'bEtlcTFmeXJIZzNPYnVWb3REOG1YRXVFY3ZUbGZKRXZlWk5kNk9EbVFYdjZsRjlTU2tQMGlz'
    b'azBDOGkKZklEN2lCVTVkRkJJb0orUVhiZkwxeXFqSWdLZEhtd3NMSzVhcytsd2RrNEJ6M2Q1'
    b'cTM2UGZaY09SYUhaMDJMZWZ5V3hteWtkK2Z2MwpCYXV1UnFrMlRRMTA0a0pqUVo3eGpMMGhU'
    b'ZW40V0dtTU0rMWE2amVWK3k0M0NKVkFwck84ZGtpcHQvYzRwMVRQMTE3N0RwL0p6aW13Cm81'
    b'ZTE5bXFYYW12dDFiaDdoekxwaGNqa0ZBRWZhVmp4NmJ0WEdOK1RKbjlNRDZmNHh4Qi9sVmRX'
    b'dC9UUHpBaTRhSVFwSkR2SEE0RHgKVEw1OTh6cDlKRXNJd0hEQnhISkNxYUtTcWc5V2Z1Rnho'
    b'd0haOUxJekpXVmZMNEFZd1Y0SmthR0QyQ05wNHhXdXMwdDBDZ2hmTGxNTgpwZ0dncVpiN2Vh'
    b'MFJEVU5OREZhRVVpb3ByYysxT0I1N2h4R0ZVWG9CYzV1NUg1UzZ1KytWYy95aUUzb0orQmpC'
    b'Vkt0WXRBK1NSZEdtCk1uNWdpbGY1Q29OOEROMTBpcldOcHhmMVl4K1k2d1hIT01sVlRNbWc0'
    b'bGNMeDRPY29xamhDR3R3NE04QStiek9pemNwc0RFVVdVUlkKY2hQUkppd3pvUTVmMVJRVEdQ'
    b'MTVibUNLVitYZmpKSlF5bERJY2RxV0JpY0VHWVVYNjM1UVNoQzloRUlCclNzUk9DMzJmVnhr'
    b'WGJVWAp0bEhlZU1JQ2JkWXB5SGdVTkVSOGM1Q3AyY0FwVlhTdG10UHErWDRoZExNRks4WXlu'
    b'RDhQR0NrZm92a0F4Ti9pK1VhTVdUQlJtSlVnCnRKdWwyM1ZTZUpDRTBQMlR2UkFESWVreVV4'
    b'blhkdEdwQWdtNWhJWXhGdVJyTWo0eUZ1UzNVOHIzaFJUZnBCY3B1WGNmVThwSnZRcnkKTlJr'
    b'ZndRbkJvcGJkTGtVa0F1OXhEQ1ZGMXBWVmlBRnhJSktOb2cyRm5MWFNHcUtocTc4ejBXSmcv'
    b'Q2tBRURGSXBhQmxYdFN3NTd5dQo3bXltL1pFa0dNeUlWeUhLZXpqRE52Sk5QM0w4Vlg1QWt0'
    b'Y05xVVZoUUcycksxa1VMUTVzallpU0lwODRSbmVXdGU3RmtBc3FscE5IClJSSzZTYUg4T3hG'
    b'Z20xaCswOFRpd1MzREdZWWl0ajdYWWhNTEFBeERJSFNabE9VdzVZWEVJc1N5V01RZ3JZSEhH'
    b'QVlGTUFEUTNJeTkKdkpEWmhEVVY3SUJ3RVkveHhjMEc3d3VZeDBDak84UlNUUkhKUnJRMFUr'
    b'Wkt2aTdIYkJQTEROUkkvV1NCQjBnSlBZd0J0NVF1dG9BMgpqK1dOR0xNQUFKZ0ZjeFUyWE9M'
    b'YXJsa1FxN0g2aEZscnhsVzFyUG9tcXpYd1RYcGU1a1VOQ21CcUN0bWZQdFRmcW1BQm9PYWNw'
    b'WFp6CmMrbDN6UXlOK2s4UWllWXkvVDZRR2tjaFd6dG91TVNacTFvajRvMVltOGZhdG83cHNa'
    b'QWJJR2hRamlIRjNQTThKMUlyYnpjOXRBL2kKZExqdW9ObjdOOHlOdHd5VURFeHFIdHAwajR4'
    b'aENFb3dXOEF4elVnYVN2djUwNXdPTjU2eGxCMDBXUTZ6b0lQNkJxN2hlNHRxdklnZgpRZXUv'
    b'dHNCUVNoeEFjU1lzWXBBZU1GT0ViZFVJbzBRM2Q1aDg0a1RxdFVhMkRuT05HSnRiL3ZNbWxt'
    b'U3hJUzRjYmlEMEFCVzhMSmcyCjJqcnYxazUwemJabVRvZmJyVERXU1hEd2kxSnZmN3J1bWdV'
    b'a2FFQ0lTRnZMYVU2eXpCSFdHOEFzaDhBM3ZMejhLYzFORGt1ZzRaaFoKVVFNTnE1c3hBQmRQ'
    b'TVZNb1JYL2FCSnl0MHJMZXZHWmJzN21hTjFmZjBXa3V4MUpYRFRjUWVveFNMSXNIVGZzUnhJ'
    b'NEdzZVFtVkxtdApHWnNRNmc4OEJ6VTZrL2hYa0RUZnJvTU11RHJYREZxTWkvaEdIaFNBYlAy'
    b'YjJndXNVUXdjaSsrZXFla3dvbEplVHNUeWVFb2k0djJjCm50SzUwZm9LejJERTVQRXQ3MkhX'
    b'MTlqYlV6cXRQa1U3OWtqZlZJS0FVenFrakh1Rjd6WEk4UzBQYmRGa2JyakhYR0ZNbkhOM1Bw'
    b'WDEKdW9BSkpHK0Z2VU41VmQyMTZ6WHU4enhGSlZYcTZub2lWbDlnejZFZjNPZGhCTjhFUnNU'
    b'cU5YYnVQKzBtQzBNNGp0OTlrSWpWVnloVAozenFRKzZNN1BFbDJ6dGtibFJvaVZ0OWg3ZWFj'
    b'WHY4dUk0enh1aTA1Z3QrV2lOV2IvRlJVbm5VZ3IzZWY0ZC9acHk1ZVVST3graHAvClhwdGQz'
    b'MmpvVmdGMm93enJHdzF2L2ZVL3JrZ1hFYXVYdWFscFd2ejJaMDRYblN5S2xrWFJUcGZrc3Zk'
    b'MzFXcTBSS3krU1hiTzJVOTIKbmVqcVZZb0pUTDhraVdxS1NEVkYxQzlKb3BqUTViSHV6SjNI'
    b'OTN6cHFpRVBJcFpiOE1yS1Bia25MbmZwRXYxNVRqbFJKQnZCeUVZdwp5b2tpL1htdVM1Y2ZP'
    b'M1VsTFgyZjYxSkV4SElMTEN3M2UrbVcvUFBYSFF3dmphUkQwbVZ0ajRvTVNaYzVlRlFrQU9T'
    b'ZCsyVkd5bWFYCkhuRkx4SElYZEhyVDVIa2ZPbGh2R2E5d2xldU4rTFlZbUlYSzlVWTdPM3ph'
    b'MVZVSjh6Zm85Q2FYSm9lSTVVYm9EYWJwZjl6c1lIOUwKRWthWnlqaHpKVyt1NUUxbG5DVE1v'
    b'YUxNM0hsOGF2SkdyYjdaMVdraHF4dmNDN09GWGZKdTFvbjhhMXZYTGxBcDdSM0lacmpNYWZO'
    b'WQpuemdHQUxSNXJQMHZFQUNBdWdiOVMrL3NkTzdJV1ZKajlSSDJIVDR6OU5HMy92NnZvM1lt'
    b'RTYzN0FYVm5XZDFaMXZheFF6REdPL2VmCmpwejBYbzlaUmNSeVgrb2E5SDlhL2ZsRFUxZlpQ'
    b'MmNGV3pyOUloMjR2Yjh0Sm5ITndyVHROelZOUGZuOHBDbDBheTVkVlM5TTI3N2kKbzBNTFpz'
    b'Yk5teEViT1hTUWd4Y1dGbGQ5L3RVUFdmdFA5OVlYRjVKOWhaNUVjS0JmdkI4ZlVad2ZSdW1E'
    b'VUxNS21hMGJYdzJZcWNmaQpDdXhWeXN0TEltSlBhWkN3cS9hSVdBUjNnZlN4Q0VRc0FoR0xR'
    b'TVFpRUloWUJDSVdnWWhGSUJDeENFUXNBaEdMUUNCaUVZaFlCQ0lXCmdVREVJaEN4Q0VRc0Fv'
    b'R0lSU0JpRVloWUJBSVJpMERFSWhDeENBUWlGb0dJUmJoLytEKzRaaXhpTGhzNXlRQUFBQ1Yw'
    b'UlZoMFpHRjAKWlRwamNtVmhkR1VBTWpBeU1pMHdPUzB4TVZReE9Ub3lNRG96TXlzd01Eb3dN'
    b'Q2pRSjF3QUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNQpBREl3TWpJdE1Ea3RNVEZVTVRrNk1q'
    b'QTZNek1yTURBNk1EQlpqWi9nQUFBQUFFbEZUa1N1UW1DQwoiIGlkPSJpbWFnZTEwIiAvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'AU_NSW')

AU_NSW = b64_AU_NSW
index.append("AU_NSW")
index.append("Australia New South Wales")
catalog["AU_NSW"] = AU_NSW
catalog["Australia New South Wales"] = AU_NSW
country["Australia New South Wales"] = ('AU_NSW', '', 1)
lookup["AU_NSW"] = ('AU_NSW', '', 'Australia New South Wales', 1)
lookup["Australia New South Wales"] = ('AU_NSW', '', 'Australia New South Wales', 1)
details["AU_NSW"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":""}
regional["AU_NSW"] = ('AU_NSW', 'Australia New South Wales', 1)
regional["Australia New South Wales"] = ('AU_NSW', 'Australia New South Wales', 1)
#----------------------------------------------------------------------
b64_AU_NT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTIxMiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9Ob3J0aGVybl9UZXJyaXRvcnkuc3ZnLnBuZyIK'
    b'ICAgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMv'
    b'aW5rc2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9y'
    b'Z2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cu'
    b'dzMub3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2'
    b'ZyIKICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMK'
    b'ICAgICBpZD0iZGVmczE1MjE2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0i'
    b'bmFtZWR2aWV3MTUyMTQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNv'
    b'bG9yPSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlc2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5r'
    b'c2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3Vw'
    b'bW9kZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTUy'
    b'MTgiPgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMjAwIgogICAgICAgaGVpZ2h0PSIxMDAi'
    b'CiAgICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdl'
    b'LXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmlt'
    b'YWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQU1nQUFBQmtDQUlBQUFC'
    b'TTVPaGNBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9B'
    b'QUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3Zh'
    b'ZVRBQUFQCjRFbEVRVlI0MnUyZGVWeFRWOXJIbjN1ekJ3aGJRcEFkWkllaWFNR0tDRk5RUjRv'
    b'RjdmQjJYTjVxWlJCSHJhOStXcGRxMVZHcjQxUmYKNXFPb1kxM0dXaFhMVkdTMFVxbmlWaGEz'
    b'S1NDQ29DSWlpeGdnR0xLUWtPM2U5NDg0eUdnZzRUWFVRTTd2TDdqbnlia25oeS9uUE9lNQo1'
    b'emtYZzJHaE9BLzYxb25XZ0dRMndsRVhJQ0d3a0JCWVNBZ3NKQ1FFRmhJQ0N3bUJoWVNFd0VK'
    b'Q1lDRWhzSkNRRUZoSUNDd2tCQllTCkVnSUxDWUdGaE1CQ1FrSmdJVmt3V0RpT0p5VWxvWTVH'
    b'WUpsWXMyZlBQbjc4T0ovUFIzMXRVYUlNUnFYdTd1NVNxUlFBbUV4bWJtNnUKazVNVGs4bk16'
    b'ODhIQUFhRHdlVnl1N3E2VEh0SGIxdEt2Q2NkL1RtSCtZajExVmRmU2FYU1c3ZHU1ZWZuZTNw'
    b'NkFzRENoUXR6YzNQdgozNy9mMWRVVkZSV0YrbjNZQ3h1TVNxT2pvNHVLaXZRV05UVTErZmo0'
    b'YURRYTA5NFJaZWxZeEloVlhGeGNYbDZ1dCtqQWdRTW1wd3JKClVzRHk5ZlcxczdQVFd4UVNF'
    b'a0tuSTJkbytJdHE4aG9qSWlMeTh2S2NuSnowbHM2Y09aUFA1OCtZTVVNc0ZxUGUxNG5KOTNh'
    b'SVRMWjcKNnpjTXZqZk5ocXRzYjVBMzN4T1YvU1FxeTljcXBHaFZDQURBWXJFeU1qSkNRME5w'
    b'TkZvL05sMWRYVGR1M0VDclFwekI5dm5EWDBjdQp5TFFOaldYd1BLbHNEa2FoMGpoY3RsdWdR'
    b'OFEwNTBtcGFuRzd2S0VTVFlXZ1VDaFNVbEljSFIwVEV4TWJHeHRmS2oxMTZ0VFlzV05kClhG'
    b'eDI3dHlKQmlvQThGMjhueGN6R3pEOVN5Z0ttek55UVNZM0tnV0I5UUt2YytmTzFkYld2blM5'
    b'b0tDZ3JLeU1KRW1FRkFCd2dpYzYKakgzUDBLb2Q4NWkxQ2FQU0VWZ3ZKSkZJQU9EWXNXTnZ2'
    b'LzEyV1ZsWnp4VWtuZXhIVHpiR2pHN3ZiT1VSZ3B6M0YzcjA2RkZ5Y3ZJUApQL3dBQU9QR2pW'
    b'dTNicDFJSkVJODlZaG15elBXMG82UHdIcWhsU3RYOXN4NkdvMW00OGFOR0laWkZEb1loY29k'
    b'L3p2N3NlOVJXRGJkCmdycjJvbXhaWFdsUHFWcjZ6TWg2MUJMaGl6cHhDamY2UTd0Ums2bFdk'
    b'dDF0OWNLaWJHbnR2eXdMckZkOUtZdnlydGdlb1NQVGQxdDUKaGVsK3RRMk41Y2ZQZjNwdWIw'
    b'UDJSaUJKQUZDTDI0MEY2OStXTkE0M1lFVzJ0VS80OHpvaGx2L3V2TGFyeHhwT2JEQzN3QVRh'
    b'anpWWQpqbm5JaG5NOVZQVjQ0aU1TUC9GSi9TdGdPQURJbSs0YVU1VkdMbFk5ZXdJQU5GdW5v'
    b'TFduZTZqcXFkUHAzYm1oRzgvVDdaMFJXTU9kCnFxQUpRYXUrcHpDdDlKWTZ2VHZYNDhOMUFD'
    b'Q3BMaUpVM1FackUxZGVJYlVhbk00TVhudWE3UmFrMTRibEdoQzA5Z3pPWUNPd2hyTmYKNVRY'
    b'M0wvMEhDRnltTGVVRVR5UlUzWkxxUW9NVmRwWmZBQURQMlp0WnJnSDltTEZHK0xxK3Z4eUJa'
    b'VURwNmVrTEZpd1lpbUR4SnM1awp1d2Nib2cvM1hiZ1hwekVFQlg4MzZMWjMzRHJEQ1o3SWow'
    b'ODFlT3NSaVovUU9Gd0VWcCtLakl6TXpNemN1M2Z2aEFrVGhpQllzNHd4Cm96dTZPc1Y5M0hu'
    b'bmtxUzZxQit6NWxOL0lWVGQ3di8xQlJpeG9NWnBETWZ4SHlDd1hwa2dYRnhpWTJQVDB0TE9u'
    b'RG5EWURCb05GcE8KVGs1YVdscHNiS3lMaTh1UW9Jckc0ZHI0anpNV3dlamZBMG5XL20yaHF1'
    b'T0pYZ05oeVVuQnBXK1lmRzhidndnajZ6UWN5amUzY0VOeQpjdktaTTJjR3J4M1cxdFkxTlRV'
    b'Y0RxZjNSV2RuNTRNSER3S0FUQ1p6Y1hIUmJYYzJhN0JzbmNEb1dKMlYxMXNVbGszT0w0M1lw'
    b'cWtCCm41Mnc4bnlyZDJCR1VIQ283dWdYRit1VkgvMW13a0RJNXBsSlZ4ZzFZbzBlUFRvbkoy'
    b'ZnMyTEdEMXc2WlRQYmRkOS8xVlpxVmxXWCsKVkFHQVV0Z0V4c2ZxTUp6RzRSWTFxdzRWUGFy'
    b'Y01Pbnh0NnNWVHg4U3FtN3gzY0s3VzZaVkhGejlQeGM3VmNUQXd1NUtZYU81ajFndQpMaTV0'
    b'YlcyNjNaNFpHUmxVS25YNzl1M3g4ZkVBUUtWU25aeWNXbHBhVE51VWd3Y1BMbHk0c0sraUlU'
    b'RVZhaFhTem9xTGRzWTlCSHorCm40MWhSNm9VaGMycWxJZC9lK3VmQnh5WldKT1VLR3hXNVQ1'
    b'UUFnQ1RPckJuRmNJYi96UjNzT2JQbjc5aHc0Wjc5KzQxTlRYRnhjVUIKUUZ4Y1hGNWVucnU3'
    b'ZTJCZzRPYk5tN2R1M1lxQ0M2L3E4ZkV2UW56Q2pWbWRrVnFOVXRqOFZLYlZrbkJYcUxrcmxM'
    b'MXEweUxWZGdzZQpHWG5yem9xTEhkZE9tZnRVZU9EQUFaSWt3OExDRWhNVGV5NG1KaWFHaFlV'
    b'QndLRkRoMHplbEg3aUMwTW85TkF0cUt2ZThyN3NVYmxCClMrbURtMDhseXJwT3JVcEx2am91'
    b'MFhBQWdPSW5hdW45RzZUV1VKWUFTYlplUFB4ZzE4Y2tvVFYzc05yYjIzTnpjL1VXNWVUa3RM'
    b'YTIKbXR4NW56V3J6NFg2bkRsemJHeHNoZ3BiaXBZSGR6ZE5iY3plcE9ucTdIUFNsRXNhVHF3'
    b'L1VLSG95eU5URXdBQVZVTE5sYXJHNWxQYgorcm1kdkttNitzL0o5VWRXRWlxRitYUkNuMU9o'
    b'ZzRPRGw1ZVgzaUp2YjI4SEI0ZG56NTZac0IweW1Td29LTWpQejgvUHorL0xMNzkwCmRuWUdB'
    b'SUZBc0g3OSt0cmEydHJhMmlIaHZQZWU1bHJ5TWdVWERuTEhmOENMbldNOWNpeEdlZDdWYW5H'
    b'YnNQajdwK2YzSDd2MjZQeGoKNVhQN2w5ejZYbGMyWDVQWk12NDNxdlpmemxNVzJJMmVndE1Z'
    b'dXVzYXVWaGNjYW4xOGhGSlRZa1o5Z0RXbCtlZW41K3ZtL1gwcXFhbQpKaUVob2FHaFlURGFG'
    b'QjRlWGxKU2d1TjRURXpNclZ1M2pQbUltZWNWNGd3MmE0UXZZSmhhM0s1NjF2S3dVM3VnUWxI'
    b'VXJETHk0eXdxCk5pdUkrZnRBcGkyTHp1Ujc0UXcyb1ZRb25qNEVrakRicjZ4bnhNSXdiUFhx'
    b'MWJvTTVuN1dqSjkrK3VueTVjc0hZeWRNZVhuNXNtWEwKQU1CSXFzeW9OOW0yRHBIdnM5MURt'
    b'SHd2bWkxZnE1Qm9GRkpsZTZPc3JsUlVtdC8wck91N0dzWDFGbldMYkdCQUtEVGs0VXJGTjFX'
    b'SwpFRWRxdktkMGhoK1Q0K3pwUFBrUFZsNWhOQTZQd3JMQktGU2xzS203clVGNjc1cTQ2cW81'
    b'ZUZwOXJtYXBWR3BVVk5UMjdkdkhqZnVQClVQTE5temRYclZwMTdkcTExOHc3VFVwS0lrbnk3'
    b'Tm16SnZrYTVqQmlPVVFtalV6ZlRXSHFiNFpHSm1ySnkzenk0OTU5WmRKajFkMEEKUU1HQklN'
    b'RGcveVdPQVk2QmhnQW1GZHM4d1NvdXhOWHJvMjBPa1VrWXJqL0RxdXZ4blFlN1BsYTJON3pa'
    b'M3VqVGVkZG9OSVdGaGErTwpHVGR2M2l3c0xIeE5xbGdzMXM2ZE8vZnMyV05sWlRVOG9ndzJB'
    b'ZVA5bGh6c2l5b0FvRnJiZTh6OFUvRG5PWitNYzN6UGh3RUFXaU9vCkFnQ0NCQTBCR01DV2FP'
    b'dXBFeVBDdGhVN3ZqT2pMNm9Bd01vckxIQmw5aHZmUW1NZzhxNUxmN2h3NGNMbzBhTjFvOHRy'
    b'SmtURXhNVHMKMkxIait2WHIzdDdlSGg0ZUpTVWxPM2JzaUltSkdlcGd1YWVzNlhIUCs1RnRT'
    b'SXovc2lNcklxeXQ2UU9MZkU3eW9zZVA4UTljK2IweApFVEtXaXo5djRreXpCcXV0clczNTh1'
    b'VlRwMDZ0cUtoSVNrcWFOMitlUUNCNG5mdDFkWFV0V3JSbzFLaFJ1bDlIalJxMVpNa1NsVW8x'
    b'CnBLbkM2U3hPb0xGSDZOaU5tdVFlbS9KYnI0RmxkRTMzWlhqTzJXTDhyaGk3c0hnekRUZm90'
    b'SHYzN3Q3dStkR2pSMTh6SWFLMHREUTkKUFQwcks2dm5TbHBhbW1tem9uOTkwZTJkWVNEZFlo'
    b'UHdqcmZ0Y1FDbDhSOFphVWUxQ1hobklFMGFZZFlqMW1Ba1JEeDgrTEQzcjYvbQp0UTQ1VWRp'
    b'Y0FkbHJKRUthRVUvL2U2Tkt4ZjhqVjhma1RmcTFSNnpCRUpmTHJhK3YzN2R2SHdBc1dyU0l4'
    b'K01OZGJBMHNzNEIyWXR1CkY5U0x0VHBjTkgxSEhzam4wUjhnU2FnWGE0TXJMckpHK0JyZEpK'
    b'SEZnVlZjWE96cjYwc1FCQUJrWkdSWVd3LzVBOVBVNGpaU296SXkKRVY3ZVZDMTVXUFp6czhx'
    b'YWhzblVob2Qva2dRMkZidlNxSW9zUERIaXQrbTZEQitEVW9tZW12VlVPQmlTU0NRNnFnQ0FJ'
    b'SWhoa0hkUApxQlNpMndWR21aSmtROWI2ZjlUSWNZQlFIalhhbGVadlQrbkxPMk5Tc1hBbjZy'
    b'c2VkQzlieXJVV2RWMTFaZHZQV1VZMnFlUG1hWXNiCnNZYWwyaTUvNi9CMm9rR3pwcE5iQmJl'
    b'dnV0bmdKNVB0NkxZOHFvMGpxVlkyMWRmdEtaZGZlS3dDQUFvR1doSllWR3p4YUZaeUVNZlcK'
    b'MVpkUWQ2czdXMlV5V2FsQTdYcjBjN1o3c1BWSUF6c3UxUktoNkpjZkVWakRRWjEzTG5YZUx1'
    b'aG5peCtwMVRUbC9Mbmw3QzZPQS9lLwpQMXJxRVBrK2cvZjhvWmxmUTZWNzVuenZTOVg3S3hS'
    b'MENvWmhzRzh5SitxOUQ3M203NkN5YlFHQUpMU3l1bExQbjdQYWk3SnJ0bjNnCnMyQ1g0N2pw'
    b'L1RTbU1Yc2pvVmErMlE2aERJKy9xemtjdkNhckszVWMvd0ZGWDhoYlZQYlRnMTN6UktYbnVG'
    b'RXBRWi9uY29LanFWWjIKTDBJRGRuemJzRGpYbXV3SEhVcWhnbGdWYVJVZkV4M3dXUmFGem5x'
    b'K1BNUndocU9yL1pnRWg0aHBuZVhuMjY0Y2xUZlhXSG1Ob2xyYgo2MEg4ZGtGajlxWTN2MUpH'
    b'WUpsc2JkalYyVmwrbnUwV3hPQjUvSHRwOWt4NFBmZnhzVFV0ZVprYWFjZUloTVUrcVJrNFRV'
    b'ODdhVFlPCkdFN2hQaW1wYk5jc2orUUVmNTVMczNIVVk4YmhjU2VrZE42NUpLa3VicjE4Uk5Y'
    b'ZWlOT1pESzZiN2drUHFWRzFGdno5MGFIbEpQSG0Kanc4ZUpzZS9tTlcyR1FiUGs4bjMxc3JG'
    b'WFEyVlBacy91ZU4vNTd0NGZ6OXhWSzFjVXJvMEpLZEtsRFk3eFgvWmtYNVhmSUs3bXhPVQo3'
    b'Yy96SnFqVzlpelhRQXpINVExVkdybTVuT3lLZkN6VFM5bmU4TkxtQW11ZjhKRi8zTnQvZEo3'
    b'QzV0aUd4RXhUL0dSd0VVQzNkdzc0CjdFVGx1amhTbzlLRnJLVDNyNXRiSjZDekczNkZXUUgz'
    b'K25nSFJxRVpOR1I3aE5KeFlIdUdHclowQ3hveDlZL20vS1VSV0lNdXA1aFoKTDU4OTFOZWd4'
    b'YlFDQUlweE8xNWNwNitnMlRvaHNDeFh2Tmc1UmxycVRqVXk1bXdqSFlXTzQ1SVJXSllybGx1'
    b'Z2taYmRUeDhDZ0VKUQpaMnpOTHY0V0RkWlFPZEpqa0VRb1pFWmF5cHRyQUVEUmZNL29FVTVo'
    b'dVdEeCtmeWhraUEvU09xc3VtcU1tVWJhb1dpcEJRRHBmV04zCnAzWGV1V3haWVBWK24ycHFh'
    b'bXBDUW9LZm41L2VVa3ZRazl6dDJtN0RnNWJ3ZWk2cFZRT0F1T3FxU21SNG02NjQ4b3JZT0dT'
    b'SEQxamIKdG0wN2UvYnNwRW1UY0J4UFRVM0ZNQ3d0TFkzQllNeWRPL2YyN2R1RGVtcU5HVXJa'
    b'MFh6dnF4UURvVXVTYkM4ODhmeEhRaXNzenU2LwpUdW1EbXc4eTU1dnp0eDZVeUh0NGVManVW'
    b'UlROemMxdWJtNEFJSmZMRlFxRm82TmpYVjJkdjc5L3o3WVpVOG44WDRUSjlnajFXN3kvCkww'
    b'ZSs3Zkszanc1LyttTEZ4K2FFYlN0aU9McnBOVzR2L2tmOU55c0lwZHljdisrZ1BDc1VDQVJU'
    b'cGt4eGQzZnZPVWlOUnFPeDJXd0EKMkxKbHkvWHJwZzhUbS8vYnY5VGl0dmFyV1lSR1NiZHo3'
    b'djBja05ScVdnc09QVDYrdG5kYU02bFdpbjc1MGNZdmd1N2cwdHRTVWxQYwpjSHh0eTlsZHVr'
    b'blRuRFVvajNUNGZINURROE9yNzM0bUNJSWdDQmFMcFZBb3dQSkVhSlJQVG1jOE9aM0I1SHV6'
    b'WEFNWVBFK05UQ1M1ClY2TDNxRWlsc0tucVQxTnMvQ0xZSHFHa1Z0UGQ5bGplV1BYR054eS9t'
    b'YWtRdzdENCtQajA5UFRwMDZmMzg3NUNrVWgwOHVUSlhidDIKVlZkWFc4NVVhR2xDQVZLa29l'
    b'Tzg4L244blR0M3pwdzU4OVdwY01XS0ZWOS8vYlhKcDBJMFlsbkVpTlhhMnVyaDRhSG5aamdP'
    b'QUpicApZQ0d3VEtBeFk4Ym9QUGZtNW1iZEZibGMzdEhSQVFCTGxpelI0WVdFd0Jxd2xpNWRt'
    b'cGVYTjNueVpFOVBUMTNlODU0OWUxeGRYZWZOCm15ZVR5UklTRWxDL0l4L3IvK2xqOVJ4U3Vt'
    b'Yk5tcTFidHdZRUJQU2swdmN1UlQ3V2NOV2d4TEY2YzNQNDhPSG82T2plQnpTWW5Db2sKU3d3'
    b'M3RMYTJEdEgzZUNHWk5WZ0FZUEozV0NBaHNKQVFXRWhJQ0N3a0JCWVNBZ3NKQ1lHRmhNQkNR'
    b'bUFoSVNHd2tCQllTQWdzSkNRRQpGaElDQ3dtQmhZU0V3RUpDWUNGWml2NFBLQzhQdGJ4d2l6'
    b'Z0FBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpJdE1EWXRNVFZVCk1UZzZORFE2TVRJ'
    b'ck1EQTZNREJuNUVKZ0FBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl5TFRBMkxURTFW'
    b'REU0T2pRME9qRXkKS3pBd09qQXdGcm42M0FBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAg'
    b'aWQ9ImltYWdlMTUyMjAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'AU_NT')

AU_NT = b64_AU_NT
index.append("AU_NT")
index.append("Australia Northern Territory")
catalog["AU_NT"] = AU_NT
catalog["Australia Northern Territory"] = AU_NT
country["Australia Northern Territory"] = ('AU_NT', '', 1)
lookup["AU_NT"] = ('AU_NT', '', 'Australia Northern Territory', 1)
lookup["Australia Northern Territory"] = ('AU_NT', '', 'Australia Northern Territory', 1)
details["AU_NT"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+09:30","altname":""}
regional["AU_NT"] = ('AU_NT', 'Australia Northern Territory', 1)
regional["Australia Northern Territory"] = ('AU_NT', 'Australia Northern Territory', 1)
#----------------------------------------------------------------------
b64_AU_QLD = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjg0MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1F1ZWVuc2xhbmQuc3ZnLnBuZyIKICAgeG1sbnM6aW5r'
    b'c2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAg'
    b'IHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9z'
    b'b2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkv'
    b'eGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6'
    b'c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVm'
    b'czEyODQ2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTI4'
    b'NDQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2'
    b'IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIy'
    b'IgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNo'
    b'ZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIi'
    b'CiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTI4NDgiPgogICAgPGlt'
    b'YWdlCiAgICAgICB3aWR0aD0iMjAwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVz'
    b'ZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpv'
    b'cHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNl'
    b'NjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQU1nQUFBQmtDQUlBQUFCTTVPaGNBQUFBQkdk'
    b'QlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFB'
    b'QU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFQCmtVbEVR'
    b'VlI0MnUyZGVWUVVWN3JBdjZwZXEvZW1tNlZSRmxFV0FUV0NVVkdTUm9nbVVhTjVPcTdQb0Mv'
    b'RzhibEc1OHk4azNOaW9zWWsKczd5Y045RnhTWUxKVVRNVE5jdzRMekhxUEVVRGlxSVJjVWRr'
    b'VVNCaTAwMDN2ZE5kdlZTOVB6Q0VyYkVidXFFaDkvY1BEWDJydXVyZQpIOSs5ZGV1NzFaaG02'
    b'akxSdHJXY0Z6TEFBK1ZWcWo5OWV2cHYzMXgxdXlud0t3dG1waDNkL1VicjZ3WXN0WWVTdytn'
    b'N3JTOFdyZCtmCmY3TE12NGVCNDlpc2FhbmJOczBlbnhKRlcxcXNueDh6L3o2UFV1dmFsMkZQ'
    b'SFMvYXRwYjQ5WmVBOExKV0hSZXZhNmV2YXNwOGpTd28KNmJaRWNyeml3RWZMYjU1OE8zZmVK'
    b'QVlESDFJbmoyT3Y1SXk1K3MxYjMrU3RlU1pHWnRuNTE4WlJMeHMzL2FHOVZleXA0K1ZuOGtL'
    b'TAp2K3poZncvUlRkMjIvdmlsNllXVUNud055eVJ0djdUcXBjMWFRUmFWRGxXOU9pZ1ZIV0wr'
    b'TUs4eGRrWW5wVGpLQ2ZMQ0EwaXBQdFZ6ClJPMXA4Y2R2NGVHeXRqK1JSYVhhckJWUGpWNDNU'
    b'cjY5YUhZNmptT0RTS2xGczlOdm50cnljNVNLbjJsNmV5ZWxNM1NLVXZMQ0F4emwKQkNSSG4y'
    b'cTdYR1VVdkxrc292cFVKNzJlMmptbXhDc083MXA1ODlTVzROZXJUYW5EdTFZbUs4Uzk2L2p1'
    b'VnFtUUxqN1UrYmlYMzUrNwphdCtOT2wxZjlMcDFha3R3ZG81dEhWOWZsQ3F2VXEzNDdjRm5a'
    b'bjZBZFBFZURCdXh4cWRMYmo5T1RBUjB1bUZBemdqUldhd0JhWXdBCmlZV1VDanF4K3JsaC9D'
    b'NFdVaXFveGVxM1J2S2pXRWlwUVNOV1B6U1lYOFJDU2cxS3NRTGFlSDBVQ3lrMTZNVUtVRVAy'
    b'V2l5azFKQVMKeSs5NmtRN1g0VjByZlJKcjhZYlBiWFlIVW1vSWl1Vkh2UjZwOU1NVlVwL0Vl'
    b'dmlqYmtTVURDazFDTVJhdUM2dkQxWmlhYWxSQzJhbQpqNGlTMFhhU1BQZUQ3WjhGdE5IU3Zn'
    b'd3pNWlpZK0NKclRFTFB1L0pTTEhDNjdHZEtldkVwajFUNmJ3cHVGVit0cGlpNjErZnI5MVN3'
    b'Cm9Td1dUZFBCY0J6ZWlqV2c0SEZya1RIZTFoV3FBZ1FTQ3pGNHVzSkhrSUpxd1V1aVJqeVBL'
    b'Z0ZGTEFRU0M0SEVRaUNRV0Fna0ZnS0oKaFVBOEZTYXFna0ZLaUlRdkVSRlNFUThBOUtZV2c4'
    b'bldiTEFpc1JDK2R5NDRsamxoWlBhVUpPV2srSlFFaFZ3cTZGU2dxZGxTWHFVcQp1bEoxOW1M'
    b'RnhXczFmYmtyMm5mUUJLa1BETlFFcVNKTXZDNVhtVHR2OHZBSWlaZWIvS2pTSHpwMlpjK2h3'
    b'c1ltMDhDSWhXNUMreEF6Cit2MG1kSWlFdjIzVHJEY1dUZVZ5V0FEd1ZZM2xHUmtuV2NMcVla'
    b'TnlnL09Hamx3NlVnQUFkdEw1MmVIaTdUdFA2STB0YVBDT2VNS3kKVnlmZUs5aTZQamVyMVNv'
    b'QVlPRFkraEx0ZjE3U25tNnd1VG9HQkpxR0VvMTk0MlhkK2hJdDg2ZUY2VndPYStPS2FmY0t0'
    b'aTU1cGIrZgpHSUFpVmpCR0xCN0IzdlBlNHVYekozZjZ1OGJ1WGxLb2FXMHhHUWVmSGNXYkY4'
    b'dG5ZTmlwUnkxL3I3V3FiVzRBd0FDK3lnb0xKeGlkCnR2MGkvOUtHclVkdGRtYy9EZDRYcmQv'
    b'ZmV5dmJKZnA1S3VPcWVHakxQKzI4WGRsaFF5R1ArMUltZDA0MnhtSDU1VFI2K3BSWlNvekgK'
    b'OVV1aVgvOGdGZk8rM2I5bWF2cklybStGY1JtcEV2WnR2UU1BZENSMXNOcnk5VU1yQU5qY1A1'
    b'OVVxcFRkMVNvQWVIM0JsSlQ0eUZkVwo3dFhxTGYwUnNmcWVtdXlwaktPNHpMUjlYNmVIUHVB'
    b'eUNYLzlVc0htWEZ3czZIVnFjcTgvTWZoVGswTWsvTzhQYng2VEdPbXB3TGYxCkxSL2ZOZmF3'
    b'aDgwcDRsZWllWjdldlgzLzhiUWxmKzZIaVlrK0xhYm9Zd1AzY1RIRjBOT0xSN0RQZkxreEl5'
    b'MnVoekpHQjdYZ25OcmwKSWV3eU1NalBEcGV3ZXhvNlh5cDdNSDNaemtEM2liaFBTclU5c3N4'
    b'VHV6cUt5N1RUVnpVOWw5dStYWEdaUkxoMWJYak52MFRiMWxabwp6Q3QrZTNEY3pBOE9IYnZT'
    b'aTE2SnB1bmpaMjgvTy9jUGMxZnR1MzczeDI3THNEUFQ1R2Z5UWk4Y2FyK3FndElaek52M3Fr'
    b'ZStaTnEyCk55bE1HSnlQajl2ejN1S2VyUUlBTVJ0UGszTTh2VHRCenVuWktnQ1lraGEzYTl1'
    b'aW9MZ3E5THRTZlF3VkZEVUU5VnIyNnNTdW8vVnUKeVZFUW50N0tqaVM4MmNQS2hWTUNmWjNv'
    b'd3hKN3YzYzlmbDlpUDNnN3h4QUovMTdCMXRBUWdUZUZXMXowL0hOcTB0MDUzck54N0ZoTwpP'
    b'SS9wMVVQd05Ecno2QmUyQjI1K0N4OHNVV3BvUjY5dG0yWjVhUlVBOEpqWTVGQU9BTkJ1VjRL'
    b'bEtNRlNSTHRkQURBbG5PT2xWUUFRCkpoTyt1M0ZXdjNhRmcwV3BJYU5YUktobzVjS3BQbTJT'
    b'RTBrQVFLcmw5Q0x1bVVYY002bVcwd0NRclNCODJzbnFwWm1LTUhGL2lEVVkKbFJvQ2VxMWZu'
    b'a1Z3Zlp2UG14VEtFYkJ3S2NNc0lvUWlRaWhsbUhsTWJHSW94NmVkY0Rtc05jdWVENnhZZzEy'
    b'cHdhc1hqbU92L2RzawpYN2RpNFZobU9MZVlPZk5hVFgxcGRYMHhjNll5Z21ENy9vamgzSG1U'
    b'QXZSZ1lxYmZCcjg3L2hGVU0wT3RlcDM0L2s0UFo5ZXFWNmV6CmE5WEx1dnNyL3ZxbFNadHpE'
    b'M3kwL0w5V3p3amMwRDV6d3Nnb2hmU3JHZ3NUeDdJVTNEQXV3MU5KcTlWcXNWaElrdVR4ZUV3'
    b'bU0wZEIKVk55NU1YdllQUUM0Ykw2WkhUbkhZREM0WEM2NzNjNW1zd1VDQVkvbmNacFVZM2NY'
    b'cXV3dWlsNDZNaVJqZk56RmF6WCtGK3ZtcVMwcAo4WXBlSzNXM1N2WCtPMGZ6VDVZRjU2MlNO'
    b'cjBXekV6YnNtRm10MmZxcFY2L1d6MWp6SXM3L0g2RU9WT1RBQ0JkemxselNmdEpoU2xCCnpK'
    b'b2VTV1FyQ0NtblE1alU2YlJORHdxeDV1L2NwTnJHQ1FmWlM3UXJMSTBnSGxqakFHQUNqNERx'
    b'U3hxbW10Yit5MDJxbWR3SWZjZ3MKK1lnc21VemVmaWRtSjFXaUljODAyTXFhU1pxRzNSbHlB'
    b'TWpKVEFxSVdKNnNHdXhLZGRMcjZIZlg4aytXOVVXdjBadHpBM0ZzejArTQpCNEJFTVN0Wndp'
    b'bzNPQ3VOemtxamMxK0ZLVm5DbmpHTXlGWVFQQ2FtMSt0VmxRVXlLQlpNL0VBb0hXWm9xbmFv'
    b'QzBJczUwbG5QWThmClJnUDlqTzJUYURxYTVveGxwMjJSaEk0eTZ4OVpLbjZ2cW5JekdDOUtK'
    b'QkxTVFY5dUlrODN0Rnh0SXR1bTdKTWw3TmIwRytYRStJQjAKaFVPajQvTkpyMTUzamlBYTYv'
    b'ZWpTa2w0WXZuOFdINzVEY09UVDZUaGp0NXhSKy9ZWFc1S2w3TmZFcGhEZFVlbDJRZTRQREVB'
    b'U0VKSApRZWdvQUtpVzNDS3I5bUlBakRFZmhpYjlmR3hDNlhEV3VBL05oYTlYTm1XY3JZZmlS'
    b'cnV0eTZUWHIyTDVUd3lMandpNFdFTlZLWCtOCnZVRGs1NE9SaW5sdEdjYktDR0kvWVZiWjNC'
    b'MWFoS0pMTkNSTFZadEJpZjVaVFdkRjJNZUw4SWF0SHp1L080OHI1TVNNSkVjeURSU3cKRGg2'
    b'NWYzWUhEU0RjOUZya2tqbDNESTRpRlpibzVoZFgxRjVnZGhPUXdnakdjeEhjMXRmaGNwRllT'
    b'QmpOdG9DSTlVdFF5aTk2K1pmMgplZXM0Qm5OaStKOVdkSk5KYktaNExNcDVwdDdVdlBkUXc5'
    b'WExHV1czdUFCUVh1dTRmaG5mTXdHQXhqOHJFalF6QWNDNmN1dk80MldWClVTTXFsRGxiM0M0'
    b'TG8vdVpyWGt4ZkVhN2EwR1psTzkvc2NpaVV2UFczWjIrN2d1WFNRUy9XUzdZc0JRVDhvZVlV'
    b'cjNUcTdXV29ON1AKQnlEZ2Q1aDVtaldjT0ZSbDd0cHRhVGh5YTEzOTV1YVh4K1FCaThKcTM3'
    b'VEp6ckdGdHhrMWNXUkljd2tBTk1kUkU1cVpSb1ZiUGM2Mgo0TWpmblRoOUsrUy9yVEtwSmxv'
    b'T1hScU55OEJlSHQ1Qk9KR0E2Lyt1a1BpUEx3QjQwSFdad1A3cnNQOTZRTnMxLzJSWmZsdE9a'
    b'cy9yCkZBS1p1dG1xMS9HenQ1OVdrRGRRL3dBTkZKY2RFUk9CTmRYTWQwWmQ0WVJPWnRTTDdM'
    b'Rk5oQ3ZGN2RJSkFNQ1piTFRlcCtxbTJXT20Kc013bDdvYnBaSXlNMlJnZTNVQjFZMHovWEdx'
    b'aG5QZUJ4R0lsMi8vNjNZOHRYY1BWazM5emFwMmFsY0hKeGg2dEptMHVXaHpETUN4dwpEa3Ro'
    b'aVJMSGloTEhEazlsYVNjN1F5WXhIR3k2YmlISnpnRTFPM00vdGE3YlhaRnUrdVNqRGgyZnlX'
    b'SkhZZzBwMm1jSnUybjQzM3FQCnVRWjJJb2JCRVpocUtVMmRTOS9zTW1vb3h3Tm95cWRaMVQ4'
    b'd3EzOW95cWZkajhGdUZkaWNRbDJqeTFSTE1UZ0NGei9XMDk3K1VXdHQKbnlxbzAvcy9vUlF0'
    b'V0IxSTlNWVdyZDdTT29RdmFyUnBPbDRTQWdBYng5TGxiR1VFb1l6Z0dtcm5HTjNudEExMnNa'
    b'UnA0ZEoySlNXbQpNRzRNampGQU5KOXkyTjM4RUF1ZmhVV2xNU09UZVlJSnIzNGRxeWpWa29X'
    b'TjlxN1REVnE3KzBLamJacUNBQUMxMXVUM2tUc1NhK0M1Clc2bFNUb29IZ0dPMTF2WlhpTzBu'
    b'U0gvcU4wRnRkQXFpaHRrb3RZYkNFcE9pYjFYYXR4K0o1YmdNYTNKVWlhT2xGWThiSXRrZ1NC'
    b'aW0KMHFtSDJTQWN4ekxDdUJsaFhES2xtd25Tcng5YVc4VUswQmQ4SXJFR21LSXJWY3BKOGVV'
    b'R1I3bkJDUUNlYnVrQUFQV1kwbjNtRHYxQQo5RkN0dnFISEVpTmRGaGYzd2kwYW96Z3JzamdB'
    b'cnB0NmpNV200OEpFZFg5c0NCL2hhRnZpem1GZ3lnaXVNb0xiL3BiT2ZhT3ozT0JNCmxyRE9Y'
    b'NmtLeEhuMWNwVU93bDg4OSt5b29xTy84ZVltTkUzVGhVZGVGM0hzRk1hbEtNcUo4eDViSEM1'
    b'ZzRnd203cllyK0V3dVJtS0EKWWJUZFRIS1ZpNy9BTUk5cEMrMXVRZ3N5Zi9YUnBiSUhTS3lo'
    b'Qm81akR5KzhIL1hUTXJpZVJ2cGFMWi9QTHl3c1RFOVBiMnhzMUdnMApxYW1wTlRVMVBCNVBv'
    b'VkNVbHBhT0hqMWFLQlJldlhwMXhvd1pScU5STHBjL2RaOTFEYzBqbGU4RTRtNHZBNU0raTFw'
    b'M0FLRnBrRWtGCnowOGM5ZFNTSEE2bnFxcUtKRW1kVHVkeXVZUkNvZGxzWmpLWk5FMmJ6V2Fo'
    b'VUdnd0dEUWFEWVBCSUVreU9qcTZoNGpWeGw4T2Z2OTkKU1NYcUNvY200WExSZy9NN2ZFb2lQ'
    b'VnVuejd2WlNJQkx4TVFBd09TaVc0QzVlbHhFZG96VSs1M1lTZWRJNWJzcWpURWdrUmkxNjRD'
    b'agoxcHJ5amhUN3RFbHhNMmhZa2pxVy9EWW11NDNKNmxqeUpwYmtRck52bjd2dmJ4Y0NaQlVT'
    b'SzFqWXZ2T0VSbWYyc25DTGk3N2NSSGI5CmU0bUdiSEhSM3R1OFk5ZUpBSTRkVWFNR0EzcGp5'
    b'K2IzOHIwTlYybzcyZDJkSHdkRlgxUjdlM1BtemUzNUJwTU5pVFgwT1h5ODlJdjgKUzk2VVBL'
    b'ZnlLTVJabFZldWZIYTQrT3NUMXdKN3RZdGFOSGpZc1BYb1U5UFBqUTZxVEV0NmV2ZWFsalE0'
    b'bnBMZFZGeGFzM2xIZnFEUApCWWtWUk5qc3pybXJQcmw5LzNFUFpRb2I3VDJNbzl3MG5HL3Nx'
    b'VGU4VmRFd2Q5Vytmbmo4R2hJcnVHZzJXTE1XLzA5eHFjZTRkZTV4Cmg4Nk9ZR0FFbzhOODFk'
    b'bkhIbnZEeTljZnZ2RHZPL3ZuZWFSb2dqVG9zSlBPSThkTEZXSGlyaG10R3J0NzMwKzV5eklP'
    b'dm5BRS81M3gKMGtWeEFpa0hyN2U2V2xOaG11enVGNGZ6Qkt6T0lTUHZ5TVVsR3o4UFJPb1ZF'
    b'bXZRNEhKUjN4YmNxbnlnZm03aUtEN3Y1L1RsNC9VdAoxN1NPQkRGclZhTG9kMk1sYVRJT2g0'
    b'R3hjQ3had3A0ZncwOFVzelIyU21OM3k3bU1WQ203YmF2R0p0TWJiLzMxajUvOG42c2ZrOHZS'
    b'CnpIdFFJeFh6M3QwNDY5ZExNbHZuNVgxOUhIZUx6ZkhwNGVJZHUwNEVkR1lCaVRWWUNaZUwx'
    b'dVVxYytkTmlvNE04WEtUdW9ibVE4Y3UKN3psVTVQMjhLeExyRndxT1l4bmo0M0l5azVRVDQx'
    b'TVNGR0V5WWVjUm1NNThwL0x4K1IrcUN5N2NLN24rY0dBZnRJN0VHcXhJUkVUcgo5elFCZ01G'
    b'azArbXRnY2d3N2pVb2czU3dZakRaK24vazVFTjhSUzJFUUdJaGtGZ0lKQllDZ2NSQ0lMRVFT'
    b'Q3dFQW9tRlFHSWhrRmdJCkJCSUxnY1JDSUxFUUNDUVdBb21GUUdJaEVFZ3NCQklMZ2NSQ0lK'
    b'QllDQ1FXQW9tRlFDQ3hFRWdzQkJJTGdVQmlJWUtPL3djQWdpQjEKbGhRSFVnQUFBQ1YwUlZo'
    b'MFpHRjBaVHBqY21WaGRHVUFNakF5TWkweE1pMHdObFF4TVRvd09EbzFPQ3N3TURvd01FalB3'
    b'eVVBQUFBbApkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNakl0TVRJdE1EWlVNVEU2TURnNk5U'
    b'Z3JNREE2TURBNWtudVpBQUFBQUVsRlRrU3VRbUNDCgoiCiAgICAgICBpZD0iaW1hZ2UxMjg1'
    b'MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'AU_QLD')

AU_QLD = b64_AU_QLD
index.append("AU_QLD")
index.append("Australia Queensland")
catalog["AU_QLD"] = AU_QLD
catalog["Australia Queensland"] = AU_QLD
country["Australia Queensland"] = ('AU_QLD', '', 1)
lookup["AU_QLD"] = ('AU_QLD', '', 'Australia Queensland', 1)
lookup["Australia Queensland"] = ('AU_QLD', '', 'Australia Queensland', 1)
details["AU_QLD"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":""}
regional["AU_QLD"] = ('AU_QLD', 'Australia Queensland', 1)
regional["Australia Queensland"] = ('AU_QLD', 'Australia Queensland', 1)
#----------------------------------------------------------------------
b64_AU_SA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNDA1NyIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NvdXRoX0F1c3RyYWxpYS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMTQwNjEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXcxNDA1OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNDA2MyI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIyMDAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBTWdBQUFCa0NBSUFBQUJNNU9oY0FB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVAK'
    b'bzBsRVFWUjQydTJkZVZ3VFo5N0Fmek5KeUIyT0FBbTNGUERnRUVIUlZhaFliVldnbHRyZDFs'
    b'S3R0Ylh1YmoxcTNXby83V3EzdU5xdQo2MmZmZmF0dnJkdWlYVXZYZXJWMnFVVzNGYVcyV2l3'
    b'Z29JaWdnQXBFSU9GSXlIMU1adDQvd2lKeWhBQkpTT2p6L1lkaFpqTEhNOTg4CngrOTU1Z2tt'
    b'UzE0aHlGN0xmSFEyRE1LTjJwYmRIMzEzT0svRWJDYkJyanlkbm5qc2c1Y3R5L2V3V0N0N0Js'
    b'SFhMUXZMMWg4NGNick0KdnBlQjQxakdJN0hacnoyZUVCTkNxYldhZ3lkVmY4a2hwUjI5OS9G'
    b'SVRoQmtyMlgvOWpOQTJKaXF4a3ZsN1krdGFVdDUzbEJRTk9BZQowVkVCaC83Mnd0WFRXMWMr'
    b'Tll0R3c4ZlZ6ZVBZa2dWeEpYbHY1dVc4TWkxTXFON3pyOWJJdEs3WGR2VzJ5aU01d2Zkc2p0'
    b'L0Z6Nng4Cjl4QURwSzNsenk5Tkw2U1U0MU5ZNk5YemowV3Y5bm1yREJkS3g2dGVEeWdWNnFO'
    b'Nkw2ZDF3c0krU2pGVFovaCtmd2dwTmFwMEZ0LzkKenZQOU4zR1JzR2VWNFVKcCs3eFZRK1pl'
    b'RmFlM0xudDhPbzVqYnFUVXNzZW5YejJ6N1g0dUZaV3UzTHFIN0ZEMHlhVjh2ei9FVEoyQgo1'
    b'QmhWYXQ5bzZlSnRYQ0d1TzlOSHJ5RUx4NWlvZ0NON1YxODlzODMxOWVwUjZzamUxZEVCbmlN'
    b'citLcHFXNUF1dzBqeitMU2RtV3YyClZ6UjBqRWF2YTJlMnVXYmgyRlB3alVhcEc3VXRxelov'
    b'T2kzOVhhU0w3V0JZK0N2RGFuTGJNVERoMEhERG1Od1JvcTlZWS9Jd0hDUVcKVXNybHhITHln'
    b'N0c3V0VncGx4YkxhUS9Kam1JaHBkeEdMQ2M4TUx1SWhaUnlTN0VjK3ZCR0tSWlN5dTNGY3RD'
    b'REhMRllTS2x4SlpiZAo5VElZaVNON1Z3OUxyR2MzSE5UcGpVaXBjU2lXSGZXU3RNaURBN3lI'
    b'SmRhZHBvN3dFQ0ZTeWczRWVtWmR6aWlzeEJKalE1NU9ueDRlCklxVDBCc1A1WXQxWEJWU1h1'
    b'dmMrOUVrVDJNOHNZc1JOdEg0b0c4VUNFNkUvV3pTQ3MwaGE1SGtGMXk2VzFKRWtOZUw3dGZ0'
    b'UXNQRXMKRmtWUnJuQWR0b28xcHVBUHJVWEcySnBXS0FrUVNDeUUreFNGRW9oQnFXQWpJZUZ6'
    b'VVNLZ0hBdUJ4RUlnc1JBSUpCWUNpWVZBWWlFUQpRMEpIU2VDbStIQU1YaXlETjhzQUFISTlV'
    b'NkZuZG1xWlNDekU4QXNYakVvSmE1bi8wTDNVQ2MweG9rNWZqcjdQRG0wYTlnMlo5NFc3Cmdl'
    b'ZnFneTgxaWtscUxOL0pRd0hTWVRCV0FkSUF2bmJkcnlwWFRyc1ZMRkRiK0pHbUxsNXV4YVI5'
    b'bDJOYjFaeXhFUXQxUWc4anozQjYKSjdRUHg1QTl2L2psNmRVc3Vua0VIOWNUdEk5TG9yY1hK'
    b'c2wxVENRV0VxdWJGZkczL2lmdEp6K3V6dkl2UlFGSndRaGVDcFpwMkp2eQprNDlVUnFGVzRT'
    b'OGREb1A0NTFQbmMzOXpyc2NxQU5oNzNxdXNrV1hqRWE1Sm1BWFYzWVdnUDFkMytKbUNBMHNM'
    b'MlF6Q2VaWDNaZXNQCmpEeTc2elhRYjdCOWlKbzd1aFBmbVNwdlBmQkJQb2UxT0lYMXhIeU15'
    b'YkRMYlZnN1MwWXF4bUhaWmFDZmMvQm1HNzVlY1RvNXRMVm4KemM1OG43ZlNPZ3R2Y2lhSmpU'
    b'WWU1RndOKzJvVE16bENWMVRQbmo5RkN3QXZKZGJFK011WGZKYmVybVU1NFM3c01EUjVzSDJN'
    b'Rjh1VQoyL2YzbWZRQkYzcHgxei9IMjdRUzkrU05lR2p5aU0vbytrT1RmVGlHd3BmeTRrUWRB'
    b'R0FnTUswQjkrYWFZN1BEOWl4ck8zaEpFT0JKCkxFM1FwRVRxckIva1pEbnYvODU3Q2JubTZX'
    b'RUdrb1N0R1oxbU05Qm9BQUNWVXVFam4yUTZJVENCajBDcG52bWxCclBLZUxHcy9iRTEKYlEr'
    b'djdQMk1jYUVYLzUyMW92ci9DTExYMXNoVXF6Wi91dVV2SjRkNzlyZDIvenR6emY3eXFxWUJ0'
    b'M3FrSlBxZXpmSDdNYmYzc0hleQpRNkhhL3FFMFlyRXkrOFBKL254WG50K0x3eUJPTGMrM1dB'
    b'VUFSZ0o3WWwrQVJFNFBFQkJucWpoNkU1Wlh3U3UrTTNSK1l6UmhUWjEwCmxSNC9Yc29MOENM'
    b'S0dwbUw5Z1JaTnNXSk9yNWVjZG9KWlNJK0prckZwNytiZS9MbkVaUktGRVdkT2xlWmxMbHJY'
    b'T3ExYjhrUHMwT2wKQUNCVjBxUktHcDlGVGhhYk5oNzFTNDdTWDZwbGQycG9BS0F4RGgyZE1s'
    b'TUFBUFZ0RExVQkQvYzFyY2tWUmZxYjlDYnNxM0llUmNHYwprTmE5R1JkZFFpeTdLelhLa29n'
    b'a3g2RmVLK0p2dlpCd3N6dE1ZTUlmL1h2d3pueWY1Yk9VVnlYTWM5WHNOalZOSXFjRGdJQkYy'
    b'dkQxCjYxNFFDWWlQZi9Ba0tWZ1VvMDNiRzFSNGs0MWhBQUNycDFkbnhkV09aUjNMTG5VcHA3'
    b'MWk3NzUxTHgrT29mclZJMzVjSFVuQmtnOEMKTStNMWZEYjU5citGRTRRbVBZRzFkdDN2SU5u'
    b'emJGdEduTWI2MGI0bzQ3MzVwVy9Qdi9NbmE0dHVzd2t6ZlBmYVBiVVJOeEpZZkxCQgpwbUZQ'
    b'MlpQbHVQZ1c3aTY1MVBqT3ZiTG5GMXNpQ3pnR3FSTjF1Ny8xM2xmbzZjc3ozKzFnOUZoRm85'
    b'T21UNXNTR3poMHc1REhmS0M0ClBGL0RJVWxZUGt1MTRhai9pZ05pRTRGWlloQi9lcVRVcVVX'
    b'aHV5ZzFidlFTODdTckUyc0FnQ0N4dEwxQlo2czRBTkRhUlc5WDB4N1EKaGN1Yk96TXExTWMw'
    b'dEZnOC91SzB0QWZ1blU0ZCtra2drZE8zTEpSZnZzTzZLbUVDd08rU3FnTDRXbWVJNVk1S2pR'
    b'Tzkxcyt1dERUVAo2RGkxY2I3aVRzY0FzVDBhalJZVEcxdFRVNDNaMExQTTU4Q0U4SEFXNjM3'
    b'N1VhWEhBVUNoeGJmbENmUEt1V0UrSmdCZzBjMnZ6THp1CldMSGNYU24zMVF2SHFPZmpiMW1l'
    b'L2FMM2cxNDk2amZnYmtLaE1HNXFITVBjWmNzeGVkQldkYTE4OXB3NUEyN1ZFZGp6QjhWWEdw'
    b'Z0EKc0RMaEpvNDVKR0tNanllbDNGR3ZsTENXRUUrMXBiU2FGbUlZTEFMRDVYSUJvS2xWWmNz'
    b'eDY5cTVGVmV2eDAyZE91RFcxaTU2bUpDSQpDeklDUUtpbmVuYUkxQ0ZpV2VZOUg3RlMxVEpW'
    b'MXFzSHA2YnRkQjJsQnRRcjY5V0RnODJuYmFOZUZhZTNPdUlLRjBSSUxBc2JqdnA5CldjWWJi'
    b'RGVUeWFSV3FldWxGRUVPWFJhZXZSMmkwK25xNitvOFBEd0czS0h3SnZ2dHZPNE9qQVdSRW9l'
    b'SUZSTVZNQnFsNHROMkh2dm0KaW90M3dKRWtkZXliSy9GcE8wZWoxeFIvdmlPdWJXNVk5L1c4'
    b'dVZqT1l3NzZ6ZlQxODhOcHVGS3RMNnozQndBamdXV2ZFdWI4NkZuZApNb0E2VmZjWUZFVzF0'
    b'YlVaamNaQmdreVEvdCtZUldwWXM1TmFoVFlXZk5QUzMzVjlwUWJVYThTRm95T3VLa2JVYVZu'
    b'SXY4YlZHQWN0CmJTdkt5ei83TkhkcS9OU1NqaGdBVUJsd2pnZFowc0I4OFhEVXFzOG5OL2NL'
    b'ZEJrSXpJUGpKUlFLaTMvK2VkRDh6NHdWM09Eb2pCZ0EKUlB0M09sd3NkNnhMT2JQdVpmZUw4'
    b'V1liTENPTUNSSzdWTSt5UGpRdU9TVjUzZm9OUE9FRUk0RUp1ZWIwV0kzT2dMZkxOY1cxNUIv'
    b'UAp6dXFSOHVKZDBUczdkczFKU2JaeUtETUpYNVR4dnEzaUFvQ0lwL05rR1IwbDFpOUJLYnZv'
    b'WlY5NnhxM1RjV3I3a2s3cnpRTlBMNjg1CktjbnBXWnYzbDhZRFFHeVFNVG5LQkFDcDgrYjlk'
    b'ZjhYUjY5UEFRQ3pHVzdEdzRremt0TFRNN3g5dkswY2JlZVRIVThtZEE5MEZ2WWIKUGo5NjZJ'
    b'WUxwYXAzUHVqemMxKzQwSXYzaHhkNEc1N0QrTndidFMyN2QzdzVMbWZCcytpVlgzamRTcWVR'
    b'UlM5TEtrR2puUytBeCt5TwpkbElVL1A2d3YvVUUvcjZ3c0tteEtTSWl5aS8rdWZmT05FMFdH'
    b'eTQwQkFZRkNmNncrWFdSV0Z4NGsrTkw0MTFWVHQyNDZ4OXF0YnFvCnFFaXJzUmI4UFBTVDRL'
    b'a0V0U1VxSm1EYVA4Y2E0WGdzaEYxSUNHeS84c29KeS9KVkNYUDk1MzR0WGRiZW0vSVhpYmE4'
    b'OFlaVUp2M2IKWDNjRHdORVRKNllsVEtQVDZTcVZLbkZxUEVWUklhR2gyM2Y4K2Z5NTgrY0xD'
    b'cHFiQjYyVkw1aWkvVEJMUnZ0dllEL3h3NmNyV256dApuR09ocHp1R3FBMzNnK3lCWG9Uc3dU'
    b'NmMvc2lrMGkydnY0N2pPQUJnR0JZVEcwT24wd0ZBbzlaWTNsMW9hbXg4NllWVlE1NjM2RGFM'
    b'Cm9EQWFkTmZwbEFZUFo3UUtFVTZqOXloaFA1NzU0aHVTelF2bE5wVGdKQUFFQlFXeDJXekxH'
    b'aTZQaTJHMnZrWDQ3RXpWcVhVdEhyVDcKTFlVT0J3eFdSbUtOSlhJZHM0OWJYbXlTUnJNcGd2'
    b'UFlva1U5eTN3K1B5ZzQySlpQQ1ZnazE0TUtFNXA2UEpTcTJWMTZsR09OTzZxawpQbjJ5ayty'
    b'dERWNmNvZHRKZmJvQzB6UFNoL3pJWkxHeGRGdmpXMmtQQks2cTJud2NIc2RDT0o4TGR3UDdy'
    b'TkdaOEdlVFZMOUx0ZGJmClBHOHk0U3Q4UUlpSHdrTmlnNnlOcUhseGp2TGRwUjM5ZndyM2h6'
    b'dUJTS3h4eUxuNnZrVVkxNFBjdkZDK1phSDhrMVhTeGJHYUFZTmIKcTJaM0hOaTNxL2Vha2gr'
    b'LzNaSFozcS9ORHdDd1phSDhveFd5UDZaM3hnY2IraCtxb0M3WUVmZUZXb1ZqektWR2NWTVh6'
    b'ekxBb1E5egpvM1JKRS9RWXRPKy80RmtyOWFodTlXQXhxR1k1VGV4cFRwcWdmLzlTclprZ2FI'
    b'UTZBT2oxK3ZiV3h1aFpoZ2cvVTV1S1ppQXdHbzNLCmlOVUdleFBMWnltdEZLd05DdjVsaVFp'
    b'Sk5RNGhLU3kzWXRMVzFDc0RibVV6S0FEWTlLaUNwRUJ2eEFIQVRBR2ZSY3BVdEJ1M083ODUK'
    b'ZFNwejZWSUFPSDcwV09uMXBudHo2Vit2YjhZeGFGSFEvQVZtRm1Qb1JrQnV4VVFIVFVxRGlz'
    b'S3g1NFBMY1RyVEVOOXdIQU1PaytRdwpTVDZMbENwcEt6OFJ6NG5RbVRxckxGdXJLMHVlLzVW'
    b'eTR6Ry9GZ1dkUWFOQ2hZUXRWdWtKMmorS1l4MTBVMGlzc1VlcVp1ZVVUckZ4CjV6b1o0NTgv'
    b'Q2Y3K2ROdDdUN2IvSno4ZkFCUUtoYVMyZlBOajdUa3JaZG1uZk9wa3RzNWFzTDg0dGtYbHFF'
    b'bU9VSmVPUytETk5sUnYKUE9MUEhmamQrYy9MK05lYVBXNDJNMlVxWnJ1Q25CRnBZTkFaVFYy'
    b'K0RmZmtXOS9lVmxKY2NyM3ltaGRMNjhXUUtuVll6VDBtbHdXVApBblhSSWFZbm9qVlRBd3lE'
    b'MlR4bFQ1WkM3NmpYdjJpWWR4SjZybU9PbnFEZjYrTCtPdVoyLzAwYUk3NDFYMmdTNHpYMWJK'
    b'a3BGRGQyCjhZSThCSDV6Zkh4REprNmMrTldYSjhWaVVYQm9xRjlnaEVTdUpUaGRiUjFzRmZq'
    b'UytlcDJqQjVJTjhjRUROekIvUEpYODY4MCt6bnUKamxDTzVVSWNXRnI0VW1KTi8vVXlKVTJx'
    b'b3RmTEdCaEdYV25rMWhFenZmMkN1Vnd1aDh2bGNiaytRaCtsVXFuVDZadWI3MTBwT3I5bQpk'
    b'bk9JTnlIWDRvdGp0UHhCWHB2K3VDVDY5MStuT3ZSZVVLdlFoZGp3emNPVGZCVzlKekN5NEM4'
    b'dyt3dk1jVUVHaW9MM3ovbTBhZXZDCnc4MkJ3VUVSa1pFaWtZakpaQ3FWeXBhV1puOS9mNFhL'
    b'SkZYU1hweWp0SEtXaXcwQm04NGtPL3Bla0ZndWhNNUV6enljM2pPTjBVQ3gKQ1JBSlRFMmQr'
    b'cnNOZDBQRHdzckx5am83TzVObUpoWC9YTnpVMkVpU1pxUEpiREpiQ3g5Y2F4Vm1IazRic2hH'
    b'S2lzTHhXWkhQVzM0bQpKV3pnbHo1YXUraWJqdnVXM0IxNFBNTExEM2U5c1VpT0Q2TFc1U2JS'
    b'RS85eTBzUnJxUEx1aWhYNW81V1JBWHh0UWtCNy82MDhGdm1iCjZlcUpZaU9UVGlsMXVNYUll'
    b'OUFwTm9OYVBrdjFWbHJucnhQVmc0MXZ6aW1OempxKzBCRkRyMUNPNVdaa3hkWCtiOGFsd1dJ'
    b'UUZncHYKc21NQ2pUZ0d2cnhCcDFWdVZYTmV5MDg1ZmozQ21SZVB4SEwxWXZGUGo1VCtkc2FO'
    b'a2MzQnB6WFJQeXFKMlZFNDNYSHhLaVNXR3lQaQo2ZGJOcWx5WmNEUFUwOVlmRUdoUThITXJK'
    b'dTY3SENmVHNNZmttcEZZYmdPT1ViTkRwQXNpSmFsaHpUR2l6djVGcEV6RHZpN3orZUZ1CllF'
    b'RnRjSkZFUExZVCtDT3gzQlV2bHNIeU8wMEFvTkF6TzdRc1I0d3dIakVvanVXdUtQUk01OWVj'
    b'aHBHL29pZUVRR0loa0ZnSUpCWUMKZ2NSQ0lMRVFTQ3dFQW9tRlFHSWhrRmdJQkJJTGdjUkNJ'
    b'TEVRQ0NRV0FvbUZRR0loRUVnc0JCSUxnY1JDSUpCWUNDUVdBb21GUUNDeApFRWdzQkJJTGdV'
    b'QmlJVnlPL3dkYmtjcXV2NzVVZ0FBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3'
    b'Tnkwd01sUXhOam8wCk9UbzFPQ3N3TURvd01QSlRRM29BQUFBbGRFVllkR1JoZEdVNmJXOWth'
    b'V1o1QURJd01qTXRNRGN0TURKVU1UWTZORGs2TlRnck1EQTYKTURDRER2dkdBQUFBQUVsRlRr'
    b'U3VRbUNDCiIKICAgICAgIGlkPSJpbWFnZTE0MDY1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'AU_SA')

AU_SA = b64_AU_SA
index.append("AU_SA")
index.append("Australia South Australia")
catalog["AU_SA"] = AU_SA
catalog["Australia South Australia"] = AU_SA
country["Australia South Australia"] = ('AU_SA', '', 1)
lookup["AU_SA"] = ('AU_SA', '', 'Australia South Australia', 1)
lookup["Australia South Australia"] = ('AU_SA', '', 'Australia South Australia', 1)
details["AU_SA"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+09:30","altname":""}
regional["AU_SA"] = ('AU_SA', 'Australia South Australia', 1)
regional["Australia South Australia"] = ('AU_SA', 'Australia South Australia', 1)
#----------------------------------------------------------------------
b64_AU_TAS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNDU5NyIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1Rhc21hbmlhLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'NDYwMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzE0NTk5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE0NjAzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBTgo3RWxFUVZS'
    b'NDJ1MmRhVmhUeHhxQXYzT3lRVUpDSUlDQ2dJSkN0WWdLN3BVS2JxMGlyYjIyaWd1aVQ5VStq'
    b'MXRiMnQ3VzN0b3JhbTIxCmk0cTFMbFdyUlMxYVcvdFlGYTZLQ3hWRld4YVZSUVFSRnhTVWhB'
    b'UkNTRUtTYys2UHRCWWpSQ0E1SWFIZiswZE1Kak5uWnQ3TXpKbVoKTXlFZWpvZ1RKUzdralIw'
    b'T0xWQlVXdm41dGhQN0R2OWhNRkJnVmFaRWh4L1lOTS80OXoyaXI1bVEzZWdDNHgreGkzY2NU'
    b'TTIxN21XUQpKREZ4Vk4vRXQyUENRdnpvK2diVnprUEt6N1pURDJSTnczQkhoSWtTRnpxL3NR'
    b'ZVFWcFpxNC9rODZiajUxUkd6dE9sWnpZWjROc2g3Cjk1ZXpyNlIrRkQ5NUtJdEZkcXJNazhS'
    b'TFkwTC9PTHowOFBZRkE3cEw2cFAyVnZXYVVQdjJtcVpXY1VlRWVaemM3cG01eDh4M0QybW0K'
    b'YkkzLy9OUDBRcVdZTDJHSitORi9qSHBKbytab003STdxMTZQS2VYdnJ2eDBlMVdQRjB5VTRr'
    b'VU84amk3RzVXeXFKeTczanJodW1FcAoyVVh5NkNWdFJyWTBhczVUVzYvTHFSL0Z4Z3drU2NL'
    b'QmxJcU5HWGdsYmRuZnJWUlFkTjFIU1pSTVlkSktlWnpkellzY2hISllWTnBGCmxiVXViOFYx'
    b'dlpGbW90ZFRPOGVRSU8rVWpYT3ZwQzJ6ZjcwZUtaV3ljZTZ6M3E3dDYvZ0tTeXRSbHphVWVm'
    b'OEpuMHlhditYeWJaa2wKZWwxTlcyYWZuZU9qanM4U3BZcEtLK2U4OS8yQTZOV29TK3NoaUlB'
    b'RmJicmx0dUxFQktQVERSMlNJOFJVckE2cERJYkVRcVhzVGl3YgpWNHpWeFVLbDdGb3NtMVdT'
    b'RmNWQ3BSeEdMQnRVbUZYRVFxVWNVaXhHSzg5Q3NWQXBoeGVMb1lwc3QxaW9WS2NTeStwNmFS'
    b'djFLUnZuCnRrbXNhVXQycWpXTnFGUW5GTXVLZWxWVXluMjkzZG9rVnZsZFdZQ2ZCSlZ5QUxH'
    b'bUx0cHVnWlZFZUYrL0tkRURBL3drdEVhclBmMjcKK3BkMHVyYSthUmoyTXoyY3A3N0lDUTAy'
    b'SDFVcnhRS2RYbk15cXgycFZGVEtENmRmemZ6akJrWFI3YzZ2MWJlQ2RXYXhhSnEyaCt0bwpy'
    b'VmdkQ2htNEVJMXBiVmxoRVNBb0Z1STRYV0VGaEdBcHRCSy9nSkZZQ05oaUlTZ1dnbUloQ0lx'
    b'Rm9GZ0lpb1VnVDRXTlJlQ2d1SXNGCllwR3ptNGdQQVBLNkJrV2R1a2FoUXJHUXRuY3VKQkV4'
    b'cU9mbzUzcEhEZzBLQ2ZiMmNITXhDVkJkVTE5VVdwbHhxZlRVK2VMek9XV1cKcklwYURrNlF0'
    b'b0dPbWlEMTluSmRGQjhaUDNtWWIxZHhLejl5dDFLZWZPalNOOGxucTZyck9rWXNYSVJ1UTV0'
    b'aDgwVm9kN0VnOGUySgo4MkpIT1BFNDdmaTRScXY3TmlWelJkSXhlVzBEaW9WaS9VbmNLME8r'
    b'V3ZhYXA3dUxoZkU4bENrVFZoNU1PWktOZDRYL2RQak8zRjFmCnhDZXZtMk81VlFEZ0pSSHVT'
    b'M3A5eDlvNFp5ZU96YkxBamwyOG8vM05YWk9OZmkyRjBSZVhxdytlME9XWFBQWkJJZDlwZklU'
    b'VHk2TUoKbm5XeWFpNlZpWkVFMzhrcUcvMXNnNXNyLzljZEMwWU03R25kYUYrZjhseElrTTlM'
    b'Y3pkTDVmVzI2QW90MzVyY1Vwakd6Tnk2RlZ0TQpEbjBnSldMQjRoa3VDZkdrcTB1N3R5YTNP'
    b'MFg3MzVyc0xoYWNTVWtJZmNhSG9manpyOThmTlgyOURTWW1MSHFZd3NJS3R2QmhpczZuCkY5'
    b'K1plM0xQbThQREF4bE41VUx1elhGeFNXcU56bDdFc3FKU1ZuejhxelBwdGV1TCtObXZEck5C'
    b'UWp0L3ZEQi82ZDZPRjR1aGlyVGkKQTZ1ZFFLKzRWNFlrcjV0anMrUm12dlVkby9lSmJYakUz'
    b'dXFWWi9WSDdCMVhMM2V4NEZyNjhxZmVBOWJLYWhSU0dUVHF1b2MrYS9rYwpSSit4SzVpYjMy'
    b'clZvU0FNVlJoRGg0STRvbDRiRTZjdWpvOHlINmE2c2lyMS9aWFNBOGU4ZVlLQVBaK3phUmo4'
    b'cnhpVE1GZFBaUlIrCnZhdFJVU2QrTGp3a2ZrcmhnY05sMy8wbzhQS1lmbkkvMzhXRnpYNXNC'
    b'UzlwMTVtRVZRZHRKNWJOS29uUlk0d2NTSyt1bnFLeWpGVm0KSnBtdVovMmVIYnZFbzBMbVRY'
    b'Tm9vR1Zna0lLK2tjMXFpT2czY2NkWDNYb0dHSU9sZmJhaCszKzI1ZnVMRGI1ZXJKSTcvbElW'
    b'RFVRVgo2SlJnQUM0bk5HMW4rT2pJcHRGcXRMcWVrZit0ZkZqTFJLWklrNHA1ZEtKd1MzWFRt'
    b'SmtySFRlLyt2bjRwblZEU3NUQzVRdTdsUDFQCmxMaXcrS0Z5em52Zjk0OWVuWHpva28yLyto'
    b'UkZIem1WUDNqU21rbnp0K1FWM20wMkREY2kzT1BrZHM5enlVMGZtS1prQ3VXS3pROTYKanE5'
    b'TDNOemJTMmpqazZFWHo0NHlZOVd1dUFXTno4Mk91cXVpYWVBQjRRRnNNYkM2QVlmVTY0UFA1'
    b'cWZOZmZkUlNQbkd2ZmxCWHJHMwpzMmFjUHh4Ym5SZXF5QzZiUEtMUVIxamxKUkl1bVJrMnlu'
    b'U2gwNG5IV1JBM2t0a1dxME8rNnpZN0t0S2VXeStTSk1yUGZlTDMxM3plCms2UzQ5d3VRYTl5'
    b'QkxmaXJGYUFCcWtCZkRYb1BZTjJHUnE5OW40K2NNUVVBOXZrTUlycDV6ZmdqdGZXcDM3bGZF'
    b'emp5WXlZbWpVbEgKYjZVY3ZmV0tHTlRUakZVbk5teFZoZlRJZDZZTlFOK0J4aXJRNllFdUJJ'
    b'MGVhQW1RVjBETkExSjUvYVl4c0hqaDlIN1o1WHZDWGt6OQplRTNXM29ONUowNWZ6ODV0YURB'
    b'M1BQZjNjUjhleHNpMEdWRlFjajhreUx2ZDMrbkMwc3BQdms0OW1KcmJEdXR0OWxzNkpFbE1p'
    b'UTVmCnRpVGF3cHlHdnJqSzZoV3dJaUhtNHlYUkxiMjd4M2V3WHFOMXE5ZjZhY0VkMk5uUU1C'
    b'UUV1ZERBQTFJRFZFL2dWWUt1eGxmeWNsRzYKUUNnRWdQTS8vRlMrL2p2bnFocVdzb0duMFFs'
    b'MEZJZWlhN21rWXV6Z3liL3M1SEs1VHlhUm1IUnNaZEl4NjR2VjB1NEdScFd5c1ZqVwowb3Nk'
    b'OXI3VksrQk1Ta0xrMENBekFXaWEvbGt5SUZ5dTF3SUZRRWhCVHdIZEJUZ1hRZFVQbkFwQTZ3'
    b'M3NvS3UvOW1oaEFzSmdNQnpmCnNMWFBlNXN2dlR4NDJ1SGR6VnhBVnNtWW1SdVlIYnkzcWVN'
    b'YkVMMzZ3TkVjKzEvVGJkbzVIamlhWXp6WHZuMmRJeE5YRlJMcy9iUlIKTU9HeDdvTUxJakFB'
    b'd1FlaUhnd1BRRjhCT21jZ2MwSGpDNXhxWjdaU29UQUd2bldqTE8zTFRmdkd6OWp2TzJTL09I'
    b'UnYzekYzaTRvSApUcDJrQm9vcXVkMXMvTThHZFdVaVgrdzJEMlpYL2V6UTUwc1p4MTdIemhT'
    b'WUdkb2I5VElwRFVxbUFKR1ZMOGJObGYva0R1Tm1ackJPClhkRFcxUmNER1F3OExoQjZBRi9n'
    b'M0FRdER3ZytFRTVPdkN1ck5sNHVUbkNybEQralovZHIybGpVUHBEMmYrME9TWHNENmZ2dTY4'
    b'MUcKM3NWRDVDcDBybFdxR1JIcm42Q1VWZlN5THEyeENnQWFibFZvZ2ZJQjNsWFExSU1oRW9U'
    b'bG9CVUFHUWhjUCtENnlRMXcwamhVYUdZSQo1VUd6QkFicVhsSkM1THhaTGNVdmNSTllYeXh0'
    b'UnJaeStTYVRuL3NpSldLWGQyYTdMSmxCQ0FXZFRLbjI2V1VzSmJoajVRdHdFZkNlCmZMSHk1'
    b'cTNqNDJaeWFDQmZHTzRxY2ZlTUdOeFlVZVVIM0ZMUWlvQ3NCZUFEb1FLcUczRDhtelBwU1p5'
    b'QjFHaTFaZ0tJWEp5WW1zZEMKT29Td0VMK2NJeDgyZlVXajBhejM2UjhzMS9HQkRBQ3VFRWdh'
    b'UUFFR05WQktvR1NnVndPbEIrZ09ISC9nOGx1OUFmaFVXTGY0M09NdAp2UnNlOCtubG9nckdC'
    b'KytJemFoWG1UWWtTcVZTTHhZQzBBSWdDdm4wRFZLbkIxb0tlaWNndEVCUkFJSEFxd0Y5YjNB'
    b'eVdxV0dacm9SCkdreGZKWHY1bTdtTXVucU5MZTRLRVp2eDVDNWhUMC9QVjNZbjNSZ1hkclNQ'
    b'eDZqYjV5SWFpMnB6OWo1MGRWSUE1US9jbnNCckFHcDgKazV1SUFtakdpUWVnYTFxdlNxQml0'
    b'bjF1NWpKa2N1dHZLTVVIVmpzU2VXMkRWRjV2TW9RUEhUbWlUK3JRUnpzUitvZUg5VmZrNzNN'
    b'Swo1bXZwY3RCZUFOV2I0R2w4U3dzMEFhQUR1b0FQOG00UzRYMlp1NnBSQlJRQjBCWCtYbnk4'
    b'NGlmcTdkYmk1UDREYVozVlIrN1lZblU4CmhTWE4vTDZteWY0V0FLQldMY3g1NnhWbkxtOFd1'
    b'TE9NdDRwQUhlbmozajFyUDZmc2FJeXFjRmJKYjBGSHR4RnNkajl3N2c1Y0pSaU0KSDlRRDdi'
    b'YmMzRk5yRFAzQUo0clZ3V1JjS20xTnNGbi9mbnYrK3M5b0Z0a0YyQ3dndEVDbkQvWi9zL0Mz'
    b'QWNPR2RBdjhjOXRNU0ZRRQpjV0F0QUlpQVZTZ2dUay9vRHdCc0lNbzJtOXVGL0Z2ckxnREZj'
    b'akJPblM5dVpjaXN3OGZDMUNRQTFJQWg4NE1wczAvL1JCREU0N01uCjFNMTNQZ1dBR3l3OW5S'
    b'QVhkMnp2TFVKSEF3VE9pelVUYlhwbU1SUDV3akZXQjNNK3AreHVwZHpNQm9kSFhOLzBmWGNB'
    b'R2lEbmpRbHoKMWlRMmZVdW4wNVZleWMvNmNNMzQyL1dsUE5ydHlCYi9IbjdYY3ZKWUFFVk8x'
    b'S2pYNDFxSzgvYTltb3VYeTFHc1RnaEYwY21ITG4yMApxTVdGeUtzWm1Ua3g4N2g2T2xSTHlB'
    b'aEM5Y1BxdUZkZk1nbno3ZWhYd3pPTCt3S2hBcGJocTNkVGwzNFNrM3RmRDdRbnNPOU1IYzNs'
    b'CjhWcUtQUG5RUllaV2U3RXI3SGcyZlgvV3pGTit4OWR1N0ZWUDlkRFFMQnF1ak9vN2ZOcGtO'
    b'c2QwdTJsaldIQ2FKeXZYVHlUYnYzck0Kb3JsU0hpdVByYTBnOVpuK3dqR3JQMndwWm8xV3Qz'
    b'WGZPWVl5eFNMY0JtUFZkaXlxQnEyWFJEaDBRRUN6NzNMOXZYT1UwanYra2pIWgp2dzU1by9u'
    b'MXZtSGp4N0g3OXByd3hmTEFzSDRBTVBEbDhZWDM3cjZVZVdqSUJ3djVJbUZMNlg2ZG5QRnpX'
    b'aDVEbWNJbEhidkF6WlYvCkxYMjVsNlI1Q1dpYU5obW5XODREYVYyZnNTc1VkV3FHY29SZG9W'
    b'MGdyMjFJV0htdzVXOC9ZZlVVMzFweGtEbXJzQ3UwSXdwSzd2djUKdUpsNTlNT0tmSnVTdVhi'
    b'ckNVYVRRTEhzaUpPWjE2S0dCZnY3dURPYVNtWjJXVnpDTHIyZTJVMVEyQlhhRVdxTmJ0TDhy'
    b'Zm5YN3pPWAp4TlhpZTVQbWIySDZxQmtVeSs2b1VhaWlwcTNMekM1akl2S0xlZVZqWnliWjVq'
    b'eFM3QXJ0RG8xV3QvOUl0cmVYcTNYSFc5djNuNS8rCjVrNG10bDZoV0E2RFhrLzltbjYxNU9h'
    b'RDU0ZjBFdkI1RnNaV1ZWMDNiK25ldFZ1UDYyMjR1UnpGc3V2N3hKMC9YbkRpY2ZyMzhlV3cK'
    b'V2UySW9VSGR1R2xQUnV6aTdUa0ZkMng4OFRoQjZnQjA4UkF0aW8rTW56eTA5VGVNdCsvVkpC'
    b'KzYrRTF5eGtPWnNrT3VHY1Z5R0VpUwpHQjRXT0NhaWQrU1FvSkJnN3llbjZSL0tsQVVsOTMv'
    b'Ny9VYjZ1V3RaZWVVZGU0SS9pdVdvaUVYT3h0OXBBZ0JGblZvbVZ6R3h3N2pkCjRMWVpSMFZS'
    b'cDJaMFRjYlM5aFZyQ0VHeEVCUUxRYkVRQk1WQ1VDd0V4VUlRRkF0QnNSQVVDMEZRTEFURlFs'
    b'QXNCRUd4RUJRTFFiRVEKQk1WQ1VDd0V4VUlRRkF0QnNSQVVDMEZRTEFURlFsQXNCRUd4RUx2'
    b'ai84YWY0Z245cTN0L0FBQUFKWFJGV0hSa1lYUmxPbU55WldGMApaUUF5TURJekxUQTFMVEF4'
    b'VkRFek9qRXlPakkxS3pBd09qQXdVS1Y5QmdBQUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1q'
    b'QXlNeTB3Ck5TMHdNVlF4TXpveE1qb3lOU3N3TURvd01DSDR4Ym9BQUFBQVNVVk9SSzVDWUlJ'
    b'PQoiCiAgICAgICBpZD0iaW1hZ2UxNDYwNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'AU_TAS')

AU_TAS = b64_AU_TAS
index.append("AU_TAS")
index.append("Australia Tasmania")
catalog["AU_TAS"] = AU_TAS
catalog["Australia Tasmania"] = AU_TAS
country["Australia Tasmania"] = ('AU_TAS', '', 1)
lookup["AU_TAS"] = ('AU_TAS', '', 'Australia Tasmania', 1)
lookup["Australia Tasmania"] = ('AU_TAS', '', 'Australia Tasmania', 1)
details["AU_TAS"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":""}
regional["AU_TAS"] = ('AU_TAS', 'Australia Tasmania', 1)
regional["Australia Tasmania"] = ('AU_TAS', 'Australia Tasmania', 1)
#----------------------------------------------------------------------
b64_AU_VIC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjI0NyIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1ZpY3RvcmlhXyhBdXN0cmFsaWEpLnN2Zy5wbmciCiAg'
    b'IHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lu'
    b'a3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdl'
    b'Lm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'CiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAg'
    b'ICAgaWQ9ImRlZnMxNjI1MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5h'
    b'bWVkdmlldzE2MjQ5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3Nj'
    b'YXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1v'
    b'ZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE2MjUz'
    b'Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgog'
    b'ICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1y'
    b'ZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFn'
    b'ZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01'
    b'T2hjQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFB'
    b'Q0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVU'
    b'QUFBTQpMMGxFUVZSNDJ1MmRlVlFVUng2QXE3dm5oSm5obWdFSkF3U1V5Q0VCaE1pNlhtaEVG'
    b'REZzMU1RajhkZzErZ2pCeENRbXkxdmREYjZZCjZMbzVUSFRWVmRsb05FdGNFN05xeElnb1hq'
    b'eWZpaWpvQUlJSElKZWNJd1BUYzNYWC9qRjVCSWtRaFlIdXdkLzNEejN6bXU0NnZxbWoKcTdx'
    b'S3FCL3pxaUl0V1R4NU5PcUdvckxhRGYvSyt1YmdKWVpoa1UxNUtYN2t2czJ2V1krcmlSRTlu'
    b'T21GcjFzUDVxVHMzSitaYjl0ZwprQ1F4ZmVLSXRCVUpFU0hldUUzZm5uNUF0MjRIZTYrcDh6'
    b'bWlNUkdLdEdUcHNqMEllTVJVTmVWZWFZeGQyakIyZ1RINy9FUFBDQTd3CjNQWEpvb0xNVlF0'
    b'blJsTVVPYWdpVHhJem5nKzlkREQxNEk3WHczM2QycjdZV3pkczJ2MFY2enRiSlJvVG9UeStR'
    b'M1Z1VHcrL1BlQWgKYVd2OTg2VHBCVXIxZndxN09YZDhzT3JWR0xQWWVEcHZzT3IxZ0ZJK3Jy'
    b'cVBkOVE5UGFXTFV1SUpVY3BUdTBDcFBxWHprUElzcDQycApwSWRieDFmRzAzbU5NWXQvcy9T'
    b'Nm1ybHFUa0lrU1JKMnBOU2NoTWlDbzZ0L0thVUM0bHRYZmNFMmFidVVVc3BUdThRVG9rQ09Q'
    b'cVYyClVlMTkyVnV2RHJsNXRJdGV2MWs1aGdSNFpueTVwT0RvYXY3cjFhRlV4cGRMZ2oyZGVs'
    b'ZnhhY3BxUVpmSFNQT3dhV3NUbDI2OVd0SFUKRjcwS2o2N21aK1hZVWZIMVJhbWlzdHJGSzNl'
    b'SHgzOEV1anc2Qk9IMyttTjF1VzM0WUtKZkh6ZHdFaU9ncTFpY1pFWS9pUVZLOFU2cwpBYzRZ'
    b'bTRzRlN2RmFyQUhMSkJ1S0JVclpqVmdEa0dFMkVRdVVza3V4K2pYeitpZ1dLR1gzWXZWVFJ2'
    b'WmFMRkRLaWtSZ1NKcFlnUkRhCmx1TnJzRWpzVlN5YjYyVTBXVEsrWFBKWVlzMWRuazRiVEtD'
    b'VWxTWGpiNzgreXg5anZPM0FuZlF6L3ZZdGxnMzFxcXB0VVh1NlBKWlkKZCs0MitYbTdnVkpX'
    b'SmdWV3BjeXdJSVEySHhhY0xGSHpTNnlYMzlqUkJ5dUprU084WDRxUDlQTjJ3d2FqOGVSRitv'
    b'ZHNmTCt0OHptQwo0VTlMWDQ0VGhqN1Q4NlVlVVN4a3RoaU9uKy9GWGFwcVd3NW1GNTY3ZEpO'
    b'bGNhL2phL09wWUgxRVFKbDNMc3JEQ0MzZEhXVmhoUHdTCkMyUE1oM0E4cWxpY1F2b25jM1p2'
    b'ekV5UEdlN2pabkFVbVEzSXBhb0JYeWlzREhFdDJmVEhNb1JReWxjQlJjMkIwYy82cUZXRUJM'
    b'VzAKbTBTVlRlSWpwMjRnZ3VKTWV1aS84QitwbUZ3K0wzU1U2cXlJdlZQWElnaFN0OTE5S21S'
    b'S2VDaHRjSzJ6T0dJV3hVOE9teVVST09OTAozakpOY1pYTTA4dGlHT29mN0RkMmM0YUdOckln'
    b'RnZCd1JvVjZqVk9mMy9SRGU1WW1BaUZFRWt5VWIxTjBRSTdhUlNmMUc0WVFzalJrCkZyZklM'
    b'NVRKOGlwR3NaaENDTVdGVktlOGVQNWlhTkRwdkx2Y2lOVnpIY1FUK0JKSXYvR2MzRFltM0xH'
    b'NS9sYVdKc3o2a2NYVTVkc3UKRjh2ZGZWeTAwZUVFUXVpZngzMnJteFVNd2gxMTN6R04xL3d4'
    b'QlRIaFVkMU0yWVFTQzBESVNZYUx5cVRXWTZXbGZVM0RqVGlEcmxRZwpQRVU2a3NRd0V1R2ts'
    b'cHNUSzJrSGpIZkszVGU1QlZyUExLNXhjQi9HWGNjQ3NvMy9OR29aZncvV3phSmZvaTJmUk44'
    b'UFpFMFVJa0l0CkZxV2h3ZGl1eEFoTk5tazlXUkZDNkYzZFBWOHpYU3FTN1hQeTluTm5LclFX'
    b'empvNmtHMzg1MEJPcmJlOGF2ZWlzMG50RFNFVzg0Mi8KMGJwZ0JpRlU1MmQycElvY3FhSTZQ'
    b'ek5DNkw0N28xbEF6NkYxcWJxYXZRdFBlOHZ2SHNqaGJOWXJsRmgyUUVsRnU3T3pvMWpiVnJx'
    b'SQpWbDRYRGgwaExEYlRBVHBwZXloVFYrbEVJTlFlMnF5N3hwVEYwaU1TeE5VbnpkcFlzeWRG'
    b'bVp4bEpSWHRYSVdaZWdlNVE4NDlJcCs3CitISjE2MmE5SWpES3oxRlZhUmhoWVFtRXhBUWpa'
    b'U1hQa0VyL01KbXJVa2pWR1p0WjRUZ0tXN0RPenl3SkpMV3FjWnVPdXBiVWNEYUEKQ0ZXaGZY'
    b'RDh1cXNEcWFOTDJIb05nMWpFYWpHNlNiWm1ZS284bjZqSWI4M0FWQjFKNktVU1o1ZDdsMWw5'
    b'Q1NzbGRNZXZ1M0lZWUtnSwo3WU0ybXRtVnJYczdSdWpZU2tva0JPRko2aEl0S29vVWVTS0NJ'
    b'RlFMU0wzZTR1U3V4NWhXanhjNGVRbisvaFBkUmpNY0JoaEtMTHVoClhhZW5NZXVrVnVzc1JL'
    b'V0I5QXdZZXB0UnZ2RnQrTHZmZU5kaEI2K1FvWlZtc3AxRnJzUFZOTU9ZOUczY2hoYkVzaHRj'
    b'TkxoMkx5dVEKeUN0MHFGQ0xLTktvcFNWbnJxS3NBc1Y5V2lTZ2pOZTBSTG1PRUVqazkvYXlx'
    b'bUtHMjlEQ0lQVGovQW81SElSR2lDS1o5YlB5bldVaQpVaUJtc1pBa0NZRkFTQkltQWhFTUZw'
    b'ck5Kb3dRaGN3TVk5UzJtVksvRzhtd0ZJZWhoVGFXM1RBL0lmeVZ0OWVVbHBaR1IwY1hGaGJx'
    b'CjlmcVFrQkNOUnFOUUtMeTl2WE56YzRPRGczMThmRTZjT0RGM3dvUUMrdXU5aDY5QmlRVWwx'
    b'bS9qS0tYZW5COGVIcVNTU1VYdTdxcUgKbmxOZjM5QkdtNjRVMVcvS0tHam50UEV1bUpPeXMv'
    b'ZFdkcHJvMTkwNWxwSTc5UDRzODdYU0IvNVI3aUNaT2xieXdpUkNiSnZwYVQzZApaZm9Fd2tG'
    b'aWs0bCtIRGZlYVdaZCttV0VFTUxzTXo0S3J5RUtOeGVabzRSQ0NMVWJtS2FXdHVxNjF0TEtW'
    b'a1R3b3Qxc2c2bkozWjFqCk9wZmZ1bVpybDBVZlNEZG54NVQ1c3JjWGtrNnlYazlON3ZVZDRa'
    b'MGMvb3BsRTZWczhqSUY2RFZJeExLaFVqWjgvUXYwc21PeCtpa2oKYmZqQ0t1aGxaMkwxYSti'
    b'Wi9CVjcwTXNPeEJxQURPdW5SVUZBTDU2S05XQ1oxSy9MR0lGZVBCSnJnRE5tQUJaZUcvUjZp'
    b'WVFDaEpESgpiT0dwV0p4a3hvQXRGVG1JOVpvOUxRSmo5UDFQVjNnbkZqVTBtYXNNR0lBdFR3'
    b'YXJYaklIOGNwbHNWbG5pajVZTVIwaHRHYmprU25qCmd6L1pmcnhOYitTTFdOZExhMElDUEh1'
    b'ZDZKcXkycldiTXZkbjV2ZGlxR1RBOXRJaFNlS2wrSkdybDhmM01hYWhjUi95cDBqNCtQM0UK'
    b'MUtTNGpvL3J0aDViOVkrRC9Ba2UyVjFhbTg3bE44WXViUmkzc0hOYWsyN084ZytTUFc3OXBF'
    b'aExMcTdYelhzelBXemEybjAvWHViNQpBQnpMNG4wL1hnNmJ0bmJlbStuZExkY3VHanRTZVh5'
    b'SDZ1elhuUmVyWVp1MHVqVmI3ZzJkMnBxMkpjaGR6cXRJRlpVK0VKRmluaTFECi81QUJ5NTkz'
    b'cHZpVlVvcVAzaHB5NTVnaUxibWtYbWRkOTV6L1NqMVVyOFNsVzY5bzd2YWdWNWVkS1RyMDRr'
    b'MjdtRWhOaWt2ZnNLRHoKbCtrYkZxUW14UkVFd1VleHJLVlVsNzEwT2tvcCtWK1dGdGUxTGw2'
    b'NU95eitvNjhQWExEVDNqakw0c01ucmoyWHVMNEh2WDdlUytkWApwUmRQb29BeFhyL3RtQ3g0'
    b'eGFIc1Fvd3h4dmhRZHFFc2VNWDZiY2Q0TWdrS2RVejBlNlFHN0lmZkQ1cW5PMWE5anVSYzc2'
    b'RnBieTI5Ckhwb3lmTUJzWWNRaVFkS3EveGlNbGpreklzMFdobGZCRXhoUDUraysyTnhsdXkv'
    b'U3pWbjJ6aUxaOHZtRTNIR1FLZFU3dmF5cGhDcjUKRmY3M1BqNXd2YlFHSWRSZDBjdjljeXdB'
    b'NlBmR093Q0FXQUNJQllCWXdLQkVMQktBV0lDTmNYZVRmL2JYMlFQM3VBRlNmTkR6L08rSApP'
    b'OG1sTDA0Tm41c1FsWnQzUzBDUng4NFUzMnRzN2RlYlVvVExjNUQwZ3h1cFJIUjAxL0tSSTN4'
    b'SWtwZzVOVUlzRXU3NE5oZXF3aWVPCjBPRlAyZmFDUldXMTVWV05IUjkzN3NzZGdKRWZFSXN2'
    b'V0xkcUp3aGk3OFkvRFZFcE9yN3BPd3RuUmdmNGVWaW5DeGhObHM5V3ozYVMKUy9zOU9sQVY4'
    b'b1M0OFVIYjE3MFNGcVJPakgzVyt5bVh1Uzg4Tjh4SGVmYlN6YjVmdWFLNmVmV25oMitXMS84'
    b'dXd0OXpWT3FXUGFjWgpoclgwOHdBZERPbndpTXl2VXFaT0NMWWUzMnRzSFQ0cHJiWE5ZS3VM'
    b'Q3dYVXk5TWp2emw0RVI0M1BGbU1pUndhNEtmcTNPS2VOVFhDCmh0YzNXNWdCc3dyRTRnc3FW'
    b'OW1zYVJHM0szOXBZdCtxYUJnZDZkL0RWSDJlQTFVaGozQldTSnV2Zm5xMXFDb3N5T3VGMTdZ'
    b'ZXllbk4KcW1CaWtXQmFUTWovc2dvNDdvdEE0NTAvZUhtNE9Dc2NaaXpaY3VkdWsxQkFYYnRS'
    b'ODdqOXlvZ1FkY3JDaVN1WFRkYVUxdXBwRTRjdgo3VUNKeFNNa1lxSFJaTEUrWkpLSWhRYWor'
    b'WEd2OE9la0tldmUvd05DcUxLbStmbjVYOXlxYk9BcUx0REc0aEVHbzduajBXVXZyRUlJCmJm'
    b'ejNTWVpoR1liZDg4TkZEcTFDTUZZNHlIQjFkcHlkdlAzQzFmTFJJem5lMUI2cVFnQ3FRZ0RF'
    b'QWtBc0FBQ3hBQkFMQUxFQUFNUUMKUUN5Z3Z4bWlVbGlubTRKWWdBMlFTb1FlU2dWQ2FPNk1x'
    b'RGtKa1FnaEQ2VkNLaEh5SjRRd3BHT1gwQVp6NWxjcGxUWE5FU0ZxaGtWKwozc3F3SVBYRWVa'
    b'K0RXRUJmMmJRNzU3c3R5NnpIWVlGZXM1TzM4eXA0TUIvTC92QWE0cHkySXVHOXBiRnltYVRq'
    b'eTdGUnc3dzhYVFNsCk5UcmJUWk1Ic1o0c2RHMkc2dG9XaE5DWVNIL3JvcU1ZbzR4RGwvNzc0'
    b'MlZOS1YrV3VJV3EwQzdSbE5YcWFSTkJFQ3pHQkVJRVFWVFgKYWMvbDNZSmVJZERYWHFHUGwr'
    b'dm9tUnUrUDNwbGYyYis2SmtiZk5WdXZPb1Z3bndzK3lZeDlsbU0wYUhzUXI0RkRNU3liM2k3'
    b'U1JPMApzZXdiSGlvRmJTd0F4QUpBTEFBQXNRQVFDd0N4QUFERUFrQXNBTVFDUUN3QUFMRUFF'
    b'QXQ0a3ZrL0dLSkJPQkZkZTRJQUFBQWxkRVZZCmRHUmhkR1U2WTNKbFlYUmxBREl3TWpNdE1E'
    b'RXRNekJVTURFNk5URTZOREFyTURBNk1EQjIxUUJ0QUFBQUpYUkZXSFJrWVhSbE9tMXYKWkds'
    b'bWVRQXlNREl6TFRBeExUTXdWREF4T2pVeE9qUXdLekF3T2pBd0I0aTQwUUFBQUFCSlJVNUVy'
    b'a0pnZ2c9PQoiCiAgICAgICBpZD0iaW1hZ2UxNjI1NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'AU_VIC')

AU_VIC = b64_AU_VIC
index.append("AU_VIC")
index.append("Australia Victoria")
catalog["AU_VIC"] = AU_VIC
catalog["Australia Victoria"] = AU_VIC
country["Australia Victoria"] = ('AU_VIC', '', 1)
lookup["AU_VIC"] = ('AU_VIC', '', 'Australia Victoria', 1)
lookup["Australia Victoria"] = ('AU_VIC', '', 'Australia Victoria', 1)
details["AU_VIC"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":""}
regional["AU_VIC"] = ('AU_VIC', 'Australia Victoria', 1)
regional["Australia Victoria"] = ('AU_VIC', 'Australia Victoria', 1)
#----------------------------------------------------------------------
b64_AU_WA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjU2MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1dlc3Rlcm5fQXVzdHJhbGlhLnN2Zy5wbmciCiAgIHht'
    b'bG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3Nj'
    b'YXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5l'
    b'dC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAg'
    b'IHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAg'
    b'aWQ9ImRlZnMxNjU2NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzE2NTY0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0i'
    b'IzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNo'
    b'YWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9'
    b'ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE2NTY4Ij4K'
    b'ICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgogICAg'
    b'ICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5k'
    b'ZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9w'
    b'bmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FNQUFBRDBXSTg1'
    b'QUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2'
    b'QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ3hGQk1WRVhxTzF6NHU4Yi8vLy9WMnVa'
    b'ZgpjNkFFSkdzQklXbFdhNXZrQUNzREkycE9aSmJPMU9MKzgvWHprS1BtRno3bUV6dnJQMS80'
    b'd012Kzh2VHloWnJVMnVaWWJaeFhiSnpqCjV1N2U0dXlKbUxuKzkvajN0Y0x1Wkg3dFZYTHhm'
    b'Skw2MHRuLyt2dVVvc0FWTG1FbU9sbzBSRlFVTDJFRUkyaENUazZFZkRQRHFCbnQKeEFmLzBR'
    b'RHN3d2pDcHhtQ2V6TkFUVThESTJnY05GNklmakhsdnd2anZneUdmaklhTWwrV2lTdjR6QVAz'
    b'eXdPU2hpMFRMbUpnWTBMcQp3d2xjWUVRTUtXU2praWFmamlnTEtHWDcxOTd5Z3BqdVluejJx'
    b'cmorK1ByKzlmZkZxUmpKckJiNXc4M3JSR1R4ZjVYOThQUFZ0QkhUCnN4S2lrU2FkamloaFpF'
    b'RmJYMFRyeEFqOHp3Q2FmZ0JIT2dCSlBBQ1RlQUJmVGdCU1JBQUJBUUFBQUFCM1lnRFpzZ0RM'
    b'cGdEMHlBRGEKc3dEd3hRQ1FoQzdudlFBTkN3QW9JUUFDQWdBWEV3QUxDUURrdXdCRk9RQ3Vq'
    b'd0E2TUFDcWl3QkJOUURodUFEZnR3RHl4Z0E1THdDeQprZ0RldGdEenh3RDd6Z0FLQ0FBV0Vn'
    b'QlJRZ0QzeWdDRGV6TnJXQURJcEFBVEVBQldSZ0JkVEFDNW1BRGh2QXo0eXdBMUt3Qm1WQURS'
    b'CnF3QURBZ0FPQ3dBOVNsQ0ZmVEwrMEFCZVRRQVJEZ0JPUUFDMGxBQi9lVFZzV1FDbmlRRENu'
    b'd0FnR2dENXpBQytwQnVKY0FCZ1R3QUYKQkFDK25BRG93UW0ybFFDaGhBQVFLMk1wUFZuc3dR'
    b'QVZFUUFqT1ZzMVJWUnRXUUFlR1FENnpRQ2dnd0F1SmdBeFFsVzFsQUFiRmdBcApJZ0JFT0FB'
    b'NExnRDl6d0RIb3dCUVFnQUdCUUI1WXdBVUVBQ29pZ0QyeWdDOXBCdkdvZ0FJQndCdVdnQi9l'
    b'RFZCVFU4WUZBQXpLZ0E3ClNWR0ZiUUFySXdBUURRQklPd0NBYVFBaEd3Qy9uUURndkEySGZ6'
    b'SFVyZ0RGb1FEYnN3Qitad0RXcndBWk1sLzJ5d1NVaHl5T2d5OFIKTEdKZVlVTllYVVdnanll'
    b'WmlpckhxaGNKSjJiVXRCTFJzUk1TTFdMRXFSaWJqQ2xkWUVPVGhpeVBneTRZTVdBL1RFK0Jl'
    b'alRCcGhyQQpwUnFBZVRRbE9sb2tPVnYvcnlrUkFBQUFBV0pMUjBRQ1pndDhaQUFBQUFkMFNV'
    b'MUZCK2NKQ0JRUE9jeURWRzhBQUFTelNVUkJWSGphCjdkcjNleFJGR0Fmd3NNS0VJRWhMNkxh'
    b'UVFNSkVpQkNDNFFoSUVLbUNvcUJHR1JBaUVCRHBvUWxvS0pFcW9LQVVFU3RHQlJGN0Z4Q3cK'
    b'S3lDQ2dCUWJ4WC9DdlUzdWJ1WnVkdWJkdmJnMyt6amZYNUk4czdmN2ZpNnpaV1kyS2FtV0Vj'
    b'b1Z0ZXNnK3lTYlc5UU54L3dqV2JCeApTcjByamZvTnJySTJUYXFGUEVoUzhFQWdpZ01JeXpB'
    b'TWp5QkFDaGdTemZBSTB0QTZZS1BHVWdvUUVtUTBhY3J1MVJNSSs5MVpTVTFMCmNRdEpTVXMx'
    b'WXZmb0NZUjNZQzRGQU9FempGUlBJTEU5MnFhRFNTSGdQZjAzRUhBQkVraGlHUllFV0lRUWtt'
    b'aEdOUVJVaUFDU2VFWVkKQWlqR0ZxSUNnNEpJQzdLQnFNRmdJSktpdUJCVkdGRVFZV0VjaURx'
    b'TUdJaUFraFlOYWFZUWd3T3hwVFNQaHJSUWlHRkNramxwMXJLRgowYXAxbTZ1RHVlWmFJeElH'
    b'Y2wzc0ZzMnZUK1B0enhPSTRTUU1CQjROK1Y5QzZub1FEZEVRRGRFUURmRURKTDF0UmtiYlRI'
    b'OUQyclhQCnl1NkFyZVRjMExGVHJrOGhOM2J1Z3Bua2RjMzM0U05LZXJlYmNFd0t1Z2Y4QnVt'
    b'Umc3a3A3T2tyU0srYnNXMTZGOFV6c0FxbHp5M1cKNktudnJmM3NJT0V0K3JzZldBVUdZRUVH'
    b'cHJzZTZvWXlhTEJWZHNQYmh2Q0d1cHl0M0ExMTA0ZGlZVzRQT0lmWU1Hd21IMnFHMG1zZwps'
    b'bVJBa1VOSWluMXhOdE5CTlVHNUEwc3p6UEVFblcxaHRoTjBjVlB1eElEYzVXektWRkNVWU1v'
    b'MFBrcm04RWk1SSs2KzU5N2lFVHhJClRxYURTV3hoUWNKSjdIZ28zYWh5Nzd0L0pDR2pncitO'
    b'eGcrTUdWdENOVDBJWGxhUUZDTlpWbkJOeVMrSUZEdHUvSVRTaVdTUytTOTUKYVBMRFU2Wk9t'
    b'ejZEdXNmbnd4WjZwSVZJRjNwY1VqcFQzL3JNMGxsbHN3bVpnK2RPSS9NSW1mOElYaEJwWEFo'
    b'WmVnTVVBVmg2YzBQSgp6YU1nb3hkaC9DaDVET05SeEVyNTRpV1J4cVc1MHNWUVVBR2d4VkRu'
    b'bFBiTUtUMFRMNnNnaitQbEs2b2daR1VaZGVhdmtpeFBjdzRlCngvSTBiMitpQWxhekY2YzFU'
    b'NUMxNDhhc0k2R1VyNCswUFFsNmFKUXdITHd3RUx0SFVRSFpMT1FwUWpac2ZEcnNJRk9lV1Ja'
    b'dTJ3U0EKTkc1VWRkQ21UV3JpRlk1UVFuc1ZGZENCY1d3bVpFdlpWa0psd3JQaHhtMVNDS2hI'
    b'TzNxcGh2MnZpQjRYR2NkenBXVCs4cFcwWSt0Mgpxdmw1TVFSNFlqcDh6WW1tQ0k3L0F1MTQ4'
    b'U1h6YnJpRmRwQjVVNjJiWTFWZUZrRUFuY294SkxxRENUWjhoWWJzTUN0Zi95b0RxYWlzCmZP'
    b'MzE0dXIyTjV5TlJ6d05EVmtRN0ZRN2R6R1FOM2Z2SW0vdDhRR0U3bHB2Qnl0LzUxMFNuZmN3'
    b'cEdzbEdFS2Y3RXNJTisrUEJaM3MKQ1liUWw5L3BmTWdIc010dm9pSDBEYkdDNTlqOVlhajVJ'
    b'NlVoV1JUazQwOWlHQ00vclF3M2Y2WTA1SFA2K3J2eml5akgzbzFVNno2bApJY3hqUEM3Wi82'
    b'VTVSQ1FIRGg0NmFQNzQ2bXU2N1p0Y3BTSG8yNmpCZWNsMzMvK3dCdU05RzM0cy9vbHA2SWpV'
    b'aGh3K2drR0JESFVUCm02TXd5TTlJZFVpZ0VPTFlka3g1Q1BvRkFqbU8xSWVnRTNMSHI4Z1Br'
    b'S0tUTWtmMktWOUFVT1pwc2VPM004Z2ZFSFRtck1oeDB0MUMKVDJKNmwrQThPWGNLK1FlQzBQ'
    b'bmhOdGZkNDZDUHF3TkJnZDhMWWhsSC9qaUcvQVpCS0w5ckhzdFltdlVuOUxOS1FjeG40Yi8r'
    b'dmxEZAp4UW92WGxybDVCVU9wRjRDbHpNeS9nazQvSkNLRUZmUkVBM1JFQTNSRUEzUkVBM1JF'
    b'QTNSRUEzUkVBM1JFQTNSRUEzUkVBMkpQLzhDCnRHWjE3UE02U1c0QUFBQWxkRVZZZEdSaGRH'
    b'VTZZM0psWVhSbEFESXdNak10TURrdE1EaFVNakE2TVRVNk5UY3JNREE2TUREVE9pbmoKQUFB'
    b'QUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEE1TFRBNFZESXdPakUxT2pVM0t6QXdP'
    b'akF3b21lUlh3QUFBQUJKUlU1RQpya0pnZ2c9PQoiCiAgICAgICBpZD0iaW1hZ2UxNjU3MCIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'AU_WA')

AU_WA = b64_AU_WA
index.append("AU_WA")
index.append("Australia Western Australia")
catalog["AU_WA"] = AU_WA
catalog["Australia Western Australia"] = AU_WA
country["Australia Western Australia"] = ('AU_WA', '', 1)
lookup["AU_WA"] = ('AU_WA', '', 'Australia Western Australia', 1)
lookup["Australia Western Australia"] = ('AU_WA', '', 'Australia Western Australia', 1)
details["AU_WA"] = {"continent":"Oceania","capital":"","currency":"","web":"","lang":"","tz":"+08:00","altname":""}
regional["AU_WA"] = ('AU_WA', 'Australia Western Australia', 1)
regional["Australia Western Australia"] = ('AU_WA', 'Australia Western Australia', 1)
#----------------------------------------------------------------------
b64_AW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWF3IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImF3LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDI4OHYyMTZI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGNsaXAtcGF0aD0idXJsKCNh'
    b'dy1hKSIgdHJhbnNmb3JtPSJzY2FsZSgyLjIyMjIpIj4KICAgIDxwYXRoIGZpbGw9IiMzOWMi'
    b'IGQ9Ik0wIDB2MjE2aDMyNFYwSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmYwIiBkPSJNMCAx'
    b'NDR2MTJoMzI0di0xMkgwem0wIDI0djEyaDMyNHYtMTJIMHoiLz4KICA8L2c+CiAgPHBhdGgg'
    b'ZmlsbD0iIzljYyIgZD0ibTE0Mi43IDI4IDIuOSAzLTMtM3ptLTMgNiAzIDMtMy0zbTUuOSAw'
    b'IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIgZD0ibTEzOS43IDM3IDMgMi45LTMt'
    b'M201LjkgMCAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM2Y2MiIGQ9Im0xMzYuNyA0Mi44'
    b'IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2M2NiIgZD0ibTE0Mi43IDQyLjggMi45IDMt'
    b'My0zeiIvPgogIDxwYXRoIGZpbGw9IiM2Y2MiIGQ9Im0xNDguNiA0Mi44IDIuOSAzLTMtM3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjY2NmIiBkPSJtMTM2LjcgNDUuOCAzIDMtMy0zem0xMS45IDAg'
    b'Mi45IDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9Im0xMzkuNyA0OC43IDMgMy0z'
    b'LTNtNS45IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjNmNjIiBkPSJtMTMzLjggNTEu'
    b'NyAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjMDAiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tl'
    b'LXdpZHRoPSIzLjciIGQ9Im0xNDIuMiAzNC0yMC43IDc4LjVMNDIuOCAxMzRsNzguNCAyMC41'
    b'IDIxIDc4LjQgMjAuOS03OC40IDc4LjQtMjEtNzguNC0yMC45LTIxLTc4LjR6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzZjYyIgZD0ibTE1MS41IDUxLjcgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjOWNmIiBkPSJtMTMzLjggNTQuNiAzIDMtMy0zbTE3LjcgMCAzIDMtMy0zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmY2MiIGQ9Im0xMzYuNyA1Ny42IDMgMy0zLTNtMTEuOSAwIDIuOSAzLTMt'
    b'M3oiLz4KICA8cGF0aCBmaWxsPSIjNjljIiBkPSJtMTMwLjggNjAuNSAzIDMtMy0zeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNjMzMiIGQ9Im0xMzcuNyA2Mi41IDEgMi0xLTJtMTEuOCAwIDEgMi0x'
    b'LTJ6Ii8+CiAgPHBhdGggZmlsbD0iIzY5YyIgZD0ibTE1NC41IDYwLjUgMyAzLTMtM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjOWNmIiBkPSJtMTMwLjggNjMuNSAzIDMtMy0zbTIzLjcgMCAzIDMt'
    b'My0zeiIvPgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9Im0xMzMuOCA2Ni40IDMgMy0zLTNtMTcu'
    b'NyAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzY5YyIgZD0ibTEyNy45IDY5LjQgMyAz'
    b'LTMtM3ptMjkuNSAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljYyIgZD0ibTEyNy45'
    b'IDcyLjMgMyAzLTMtM20yOS41IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2ZmIiBk'
    b'PSJtMTI3LjkgNzUuMyAzIDMtMy0zbTI5LjUgMCAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiM2OWMiIGQ9Im0xMjUgNzguMyAyLjkgMi45LTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjZmNj'
    b'IiBkPSJtMTMwLjggNzguMyAzIDIuOS0zLTNtMjMuNyAwIDMgMy0zLTN6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzY5YyIgZD0ibTE2MC40IDc4LjMgMyAyLjktMy0zeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiM5Y2MiIGQ9Im0xMjUgODEuMiAyLjkgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2MzMyIg'
    b'ZD0ibTEzMS44IDgzLjIgMSAyLTEtMm0yMy42IDAgMSAyLTEtMnoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjOWNjIiBkPSJtMTYwLjQgODEuMiAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjZmYi'
    b'IGQ9Im0xMjUgODQuMiAyLjkgMy0zLTNtMzUuNSAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2ZjYyIgZD0ibTEyNy45IDg3LjEgMyAzLTMtM20yOS41IDAgMyAzLTMtM3oiLz4KICA8'
    b'cGF0aCBmaWxsPSIjOWNjIiBkPSJtMTIyIDkwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'I2MzMyIgZD0ibTEyOC45IDkyIDEgMi0xLTJtMjkuNSAwIDEgMi0xLTJ6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzljYyIgZD0ibTE2My4zIDkwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2Nj'
    b'ZiIgZD0ibTEyMiA5MyAzIDMtMy0zbTQxLjMgMCAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNmY2MiIGQ9Im0xMjUgOTYgMi45IDMtMy0zbTM1LjUgMCAzIDMtMy0zeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM5Y2MiIGQ9Im0xMTkgOTkgMyAyLjktMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNj'
    b'MzMiIGQ9Im0xMjYgMTAwLjkuOSAyLTEtMm0zNS40IDAgMSAyLTEtMnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjOWNjIiBkPSJtMTY2LjMgOTkgMyAyLjktMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNj'
    b'Y2YiIGQ9Im0xMTkgMTAxLjkgMyAzLTMtM200Ny4zIDAgMyAzLTMtM3oiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZmNjIiBkPSJtMTIyIDEwNC44IDMgMy0zLTNtNDEuMyAwIDMgMy0zLTN6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzljYyIgZD0ibTExNiAxMDcuOCAzIDMtMy0zeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNjMzMiIGQ9Im0xMjIgMTA3LjggMyAzLTMtM200MS4zIDAgMyAzLTMtM3oiLz4KICA8'
    b'cGF0aCBmaWxsPSIjOWNjIiBkPSJtMTY5LjIgMTA3LjggMyAzLTMtM20tNjIgMyAzIDIuOS0z'
    b'LTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIgZD0ibTExMC4yIDExMC43IDMgMy0zLTNtNjUg'
    b'MCAyLjkgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljYyIgZD0ibTE3OCAxMTAuNyAzIDMt'
    b'My0zbS03OS42IDMgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2NmIiBkPSJtMTAxLjMg'
    b'MTEzLjcgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjZmNjIiBkPSJtMTEzLjEgMTEzLjcg'
    b'MyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjYzMzIiBkPSJtMTE2IDExMy43IDMgMy0zLTNt'
    b'NTMuMiAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTE3Mi4yIDExMy43'
    b'IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIgZD0ibTE4NCAxMTMuNyAzIDMtMy0z'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiM5Y2MiIGQ9Im0xODcgMTEzLjcgMi45IDMtMy0zeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiM2OWMiIGQ9Im04Ni42IDExNi42IDMgMy0zLTN6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzljYyIgZD0ibTg5LjUgMTE2LjYgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIj'
    b'Y2ZmIiBkPSJtOTIuNSAxMTYuNiAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9'
    b'Im0xMDQuMyAxMTYuNiAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjMzMiIGQ9Im0xMDku'
    b'MiAxMTcuNiAyIDEtMi0xbTY3LjkgMCAyIDEtMi0xeiIvPgogIDxwYXRoIGZpbGw9IiNmY2Mi'
    b'IGQ9Im0xODEgMTE2LjYgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2ZmIiBkPSJtMTky'
    b'LjggMTE2LjYgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNjIiBkPSJtMTk1LjggMTE2'
    b'LjYgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjNjljIiBkPSJtMTk4LjcgMTE2LjYgMyAz'
    b'LTMtM20tMTIxIDMgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNjIiBkPSJtODAuNyAx'
    b'MTkuNiAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjZmYiIGQ9Im04My42IDExOS42IDMg'
    b'My0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTk1LjQgMTE5LjYgMyAzLTMtM3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjYzMzIiBkPSJtMTAwLjMgMTIwLjYgMiAxLTItMW04NS42IDAg'
    b'MiAxLTItMXoiLz4KICA8cGF0aCBmaWxsPSIjZmNjIiBkPSJtMTg5LjkgMTE5LjYgMyAzLTMt'
    b'M3oiLz4KICA8cGF0aCBmaWxsPSIjY2ZmIiBkPSJtMjAxLjcgMTE5LjYgMyAzLTMtM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjOWNjIiBkPSJtMjA0LjYgMTE5LjYgMyAzLTMtM3oiLz4KICA8cGF0'
    b'aCBmaWxsPSIjNjljIiBkPSJtMjA3LjYgMTE5LjYgMyAzLTMtM20tMTM4LjggMyAzIDIuOS0z'
    b'LTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljZiIgZD0ibTcxLjggMTIyLjUgMyAzLTMtM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmNjIiBkPSJtODYuNiAxMjIuNSAzIDMtMy0zeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNjMzMiIGQ9Im05MS41IDEyMy41IDIgMS0yLTFtMTAzLjMgMCAyIDEtMi0xeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9Im0xOTguNyAxMjIuNSAzIDMtMy0zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM5Y2YiIGQ9Im0yMTMuNSAxMjIuNSAzIDMtMy0zeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiM2OWMiIGQ9Im0yMTYuNCAxMjIuNSAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM2'
    b'Y2MiIGQ9Im02MCAxMjUuNSAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM5Y2YiIGQ9Im02'
    b'MyAxMjUuNSAyLjkgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTc0LjggMTI1'
    b'LjUgMi45IDMtMy0zem0xMzUuOCAwIDIuOSAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNm'
    b'IiBkPSJtMjIyLjMgMTI1LjUgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjNmNjIiBkPSJt'
    b'MjI1LjMgMTI1LjUgMyAzLTMtM20tMTc0LjIgMyAzIDIuOS0zLTN6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2NjZiIgZD0ibTU0IDEyOC40IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIg'
    b'ZD0ibTY1LjkgMTI4LjQgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjYzMzIiBkPSJtNzAu'
    b'OCAxMjkuNCAyIDEtMi0xbTE0NC43IDAgMiAxLTItMXoiLz4KICA8cGF0aCBmaWxsPSIjZmNj'
    b'IiBkPSJtMjE5LjQgMTI4LjQgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2NmIiBkPSJt'
    b'MjMxLjIgMTI4LjQgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjNmNjIiBkPSJtMjM0LjIg'
    b'MTI4LjQgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNjIiBkPSJtNDIuMyAxMzEuNCAz'
    b'IDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjY2YiIGQ9Im00NS4yIDEzMS40IDMgMy0zLTN6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTU3IDEzMS40IDMgMy0zLTN6bTE3MS4zIDAg'
    b'MyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2NmIiBkPSJtMjQwIDEzMS40IDMgMy0zLTN6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iIzljYyIgZD0ibTI0MyAxMzEuNCAzIDMtMy0zbS0yMDYuNiAz'
    b'IDMgMi45LTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjYzY2IiBkPSJtNTEuMSAxMzQuMyAzIDMt'
    b'My0zem0xODMgMCAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM5Y2MiIGQ9Im0yNDkgMTM0'
    b'LjMgMi45IDMtMy0zbS0yMDYuNiAzIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIg'
    b'ZD0ibTQ1LjIgMTM3LjMgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjZmNjIiBkPSJtNTcg'
    b'MTM3LjMgMyAzLTMtM20xNzEuMyAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIg'
    b'ZD0ibTI0MCAxMzcuMyAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM5Y2MiIGQ9Im0yNDMg'
    b'MTM3LjMgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjNmNjIiBkPSJtNTEuMSAxNDAuMyAz'
    b'IDIuOS0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIgZD0ibTU0IDE0MC4zIDMgMi45LTMt'
    b'M3oiLz4KICA8cGF0aCBmaWxsPSIjZmNjIiBkPSJtNjUuOSAxNDAuMyAzIDIuOS0zLTN6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2MzMyIgZD0ibTcwLjggMTQxLjIgMiAxLTItMW0xNDQuNyAwIDIg'
    b'MS0yLTF6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTIxOS40IDE0MC4zIDMgMi45LTMt'
    b'M3oiLz4KICA8cGF0aCBmaWxsPSIjY2NmIiBkPSJtMjMxLjIgMTQwLjMgMyAyLjktMy0zeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiM2Y2MiIGQ9Im0yMzQuMiAxNDAuMyAzIDIuOS0zLTNtLTE3NC4y'
    b'IDMgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNmIiBkPSJtNjMgMTQzLjIgMi45IDMt'
    b'My0zeiIvPgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9Im03NC44IDE0My4yIDIuOSAzLTMtM3pt'
    b'MTM1LjggMCAyLjkgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljZiIgZD0ibTIyMi4zIDE0'
    b'My4yIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzZjYyIgZD0ibTIyNS4zIDE0My4yIDMg'
    b'My0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzY5YyIgZD0ibTY4LjggMTQ2LjIgMyAyLjktMy0z'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiM5Y2YiIGQ9Im03MS44IDE0Ni4yIDMgMi45LTMtM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmNjIiBkPSJtODYuNiAxNDYuMiAzIDIuOS0zLTN6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2MzMyIgZD0ibTkxLjUgMTQ3LjEgMiAxLTItMW0xMDMuMyAwIDIgMS0yLTF6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTE5OC43IDE0Ni4yIDMgMi45LTMtM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjOWNmIiBkPSJtMjEzLjUgMTQ2LjIgMyAyLjktMy0zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM2OWMiIGQ9Im0yMTYuNCAxNDYuMiAzIDIuOS0zLTNtLTEzOC43IDMgMyAz'
    b'LTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNjIiBkPSJtODAuNyAxNDkuMSAzIDMtMy0zeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNjZmYiIGQ9Im04My42IDE0OS4xIDMgMy0zLTN6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZjYyIgZD0ibTk1LjQgMTQ5LjEgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjYzMzIiBkPSJtMTAwLjMgMTUwIDIgMS0yLTFtODUuNiAwIDIgMS0yLTF6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZjYyIgZD0ibTE4OS45IDE0OS4xIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2NmZiIgZD0ibTIwMS43IDE0OS4xIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzlj'
    b'YyIgZD0ibTIwNC42IDE0OS4xIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzY5YyIgZD0i'
    b'bTIwNy42IDE0OS4xIDMgMy0zLTNtLTEyMSAzIDIuOSAyLjktMy0zeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiM5Y2MiIGQ9Im04OS41IDE1MiAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjZmYi'
    b'IGQ9Im05Mi41IDE1MiAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9Im0xMDQu'
    b'MyAxNTIgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjYzMzIiBkPSJtMTA5LjIgMTUzIDIg'
    b'MS0yLTFtNjcuOSAwIDIgMS0yLTF6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTE4MSAx'
    b'NTIgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2ZmIiBkPSJtMTkyLjggMTUyIDMgMy0z'
    b'LTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljYyIgZD0ibTE5NS44IDE1MiAzIDMtMy0zeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiM2OWMiIGQ9Im0xOTguNyAxNTIgMyAzLTMtM3oiLz4KICA8cGF0aCBm'
    b'aWxsPSIjOWNjIiBkPSJtOTguNCAxNTUgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2Nm'
    b'IiBkPSJtMTAxLjMgMTU1IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTEx'
    b'My4xIDE1NSAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjMzMiIGQ9Im0xMTYgMTU1IDMg'
    b'My0zLTNtNTMuMiAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTE3Mi4y'
    b'IDE1NSAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNjY2YiIGQ9Im0xODQgMTU1IDMgMy0z'
    b'LTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljYyIgZD0ibTE4NyAxNTUgMi45IDMtMy0zbS03OS43'
    b'IDMgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2NmIiBkPSJtMTEwLjIgMTU4IDMgMy0z'
    b'LTNtNjUgMCAyLjkgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljYyIgZD0ibTE3OCAxNTgg'
    b'MyAzLTMtM20tNjIgMyAzIDIuOS0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2MzMyIgZD0ibTEy'
    b'MiAxNjEgMyAyLjktMy0zbTQxLjMgMCAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM5Y2Mi'
    b'IGQ9Im0xNjkuMiAxNjEgMyAyLjktMy0zeiIvPgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9Im0x'
    b'MjIgMTYzLjkgMyAzLTMtM200MS4zIDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjY2Nm'
    b'IiBkPSJtMTE5IDE2Ni44IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2MzMyIgZD0ibTEy'
    b'NiAxNjguOC45IDItMS0ybTM1LjQgMCAxIDItMS0yeiIvPgogIDxwYXRoIGZpbGw9IiNjY2Yi'
    b'IGQ9Im0xNjYuMyAxNjYuOCAzIDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM5Y2MiIGQ9Im0x'
    b'MTkgMTY5LjggMyAzLTMtM200Ny4zIDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjZmNj'
    b'IiBkPSJtMTI1IDE3Mi43IDIuOSAzLTMtM20zNS41IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBm'
    b'aWxsPSIjY2NmIiBkPSJtMTIyIDE3NS43IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2Mz'
    b'MyIgZD0ibTEyOC45IDE3Ny42IDEgMi0xLTJtMjkuNSAwIDEgMi0xLTJ6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2NjZiIgZD0ibTE2My4zIDE3NS43IDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzljYyIgZD0ibTEyMiAxNzguNiAzIDMtMy0zbTQxLjMgMCAzIDMtMy0zeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNmY2MiIGQ9Im0xMjcuOSAxODEuNiAzIDMtMy0zbTI5LjUgMCAzIDMtMy0zeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNjZmYiIGQ9Im0xMjUgMTg0LjUgMi45IDMtMy0zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNjMzMiIGQ9Im0xMzEuOCAxODYuNSAxIDItMS0ybTIzLjYgMCAxIDItMS0y'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNjZmYiIGQ9Im0xNjAuNCAxODQuNSAzIDMtMy0zeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiM5Y2MiIGQ9Im0xMjUgMTg3LjUgMi45IDMtMy0zbTM1LjUgMCAzIDMt'
    b'My0zeiIvPgogIDxwYXRoIGZpbGw9IiM2OWMiIGQ9Im0xMjUgMTkwLjQgMi45IDMtMy0zeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmY2MiIGQ9Im0xMzAuOCAxOTAuNCAzIDMtMy0zbTIzLjcgMCAz'
    b'IDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM2OWMiIGQ9Im0xNjAuNCAxOTAuNCAzIDMtMy0z'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNjZmYiIGQ9Im0xMjcuOSAxOTMuNCAzIDMtMy0zem0yOS41'
    b'IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNjIiBkPSJtMTI3LjkgMTk2LjMgMyAz'
    b'LTMtM20yOS41IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjNjljIiBkPSJtMTI3Ljkg'
    b'MTk5LjMgMyAzLTMtM20yOS41IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjZmNjIiBk'
    b'PSJtMTMzLjggMjAyLjIgMyAzLTMtM20xNy43IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjOWNmIiBkPSJtMTMwLjggMjA1LjIgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjYzMz'
    b'IiBkPSJtMTM3LjcgMjA3LjIgMSAyLTEtMm0xMS44IDAgMSAyLTEtMnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjOWNmIiBkPSJtMTU0LjUgMjA1LjIgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIj'
    b'NjljIiBkPSJtMTMwLjggMjA4LjIgMyAyLjktMy0zbTIzLjcgMCAzIDMtMy0zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmY2MiIGQ9Im0xMzYuNyAyMTEuMSAzIDMtMy0zbTExLjkgMCAyLjkgMy0z'
    b'LTN6Ii8+CiAgPHBhdGggZmlsbD0iIzljZiIgZD0ibTEzMy44IDIxNCAzIDMtMy0zem0xNy43'
    b'IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjNmNjIiBkPSJtMTMzLjggMjE3IDMgMy0z'
    b'LTNtMTcuNyAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjYyIgZD0ibTEzOS43IDIy'
    b'MCAzIDMtMy0zbTUuOSAwIDMgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIgZD0ibTEz'
    b'Ni43IDIyMi45IDMgMy0zLTNtMTEuOSAwIDIuOSAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIj'
    b'NmNjIiBkPSJtMTM2LjcgMjI1LjkgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjYzY2IiBk'
    b'PSJtMTQyLjcgMjI1LjkgMi45IDMtMy0zeiIvPgogIDxwYXRoIGZpbGw9IiM2Y2MiIGQ9Im0x'
    b'NDguNiAyMjUuOSAyLjkgMy0zLTN6Ii8+CiAgPHBhdGggZmlsbD0iI2NjZiIgZD0ibTEzOS43'
    b'IDIzMS44IDMgMy0zLTNtNS45IDAgMyAzLTMtM3oiLz4KICA8cGF0aCBmaWxsPSIjOWNjIiBk'
    b'PSJtMTM5LjcgMjM0LjcgMyAzLTMtM201LjkgMCAzIDMtMy0zbS0zIDYgMyAyLjktMy0zeiIv'
    b'Pgo8L3N2Zz4K', 'AW')

AW = b64_AW
index.append("AW")
index.append("ABW")
index.append("Aruba")
catalog["AW"] = AW
catalog["ABW"] = AW
catalog["Aruba"] = AW
country["Aruba"] = ('AW', 'ABW', 0)
lookup["AW"] = ('AW', 'ABW', 'Aruba', 0)
lookup["Oranjestad Aruba"] = ('AW', 'ABW', 'Aruba', 0)
lookup["ABW"] = ('AW', 'ABW', 'Aruba', 0)
lookup["Aruba"] = ('AW', 'ABW', 'Aruba', 0)
details["AW"] = {"continent":"Americas","capital":"Oranjestad","currency":"Aruban Florin","web":".aw","lang":"nl-AW | pap | es | en","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_AX = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWF4IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImF4LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMTA2LjMgMGgxMTMz'
    b'LjN2ODUwSDEwNi4zeiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgY2xpcC1w'
    b'YXRoPSJ1cmwoI2F4LWEpIiB0cmFuc2Zvcm09Im1hdHJpeCguNTY0NzIgMCAwIC41NjQ4MiAt'
    b'NjAgLS4xKSI+CiAgICA8cGF0aCBmaWxsPSIjMDA1M2E1IiBkPSJNMCAwaDEzMDB2ODUwSDB6'
    b'Ii8+CiAgICA8ZyBmaWxsPSIjZmZjZTAwIj4KICAgICAgPHBhdGggZD0iTTQwMCAwaDI1MHY4'
    b'NTBINDAweiIvPgogICAgICA8cGF0aCBkPSJNMCAzMDBoMTMwMHYyNTBIMHoiLz4KICAgIDwv'
    b'Zz4KICAgIDxnIGZpbGw9IiNkMjEwMzQiPgogICAgICA8cGF0aCBkPSJNNDc1IDBoMTAwdjg1'
    b'MEg0NzV6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0wIDM3NWgxMzAwdjEwMEgweiIvPgogICAgPC9n'
    b'PgogIDwvZz4KPC9zdmc+Cg==', 'AX')

AX = b64_AX
index.append("AX")
index.append("ALA")
index.append("Åland Islands")
catalog["AX"] = AX
catalog["ALA"] = AX
catalog["Åland Islands"] = AX
country["Åland Islands"] = ('AX', 'ALA', 0)
lookup["AX"] = ('AX', 'ALA', 'Åland Islands', 0)
lookup["Mariehamn Åland Islands"] = ('AX', 'ALA', 'Åland Islands', 0)
lookup["ALA"] = ('AX', 'ALA', 'Åland Islands', 0)
lookup["Åland Islands"] = ('AX', 'ALA', 'Åland Islands', 0)
details["AX"] = {"continent":"Europe","capital":"Mariehamn","currency":"Euro","web":".ax","lang":"sv-AX","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_AZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWF6IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzNmOWMzNSIgZD0i'
    b'TS4xIDBoNjQwdjQ4MEguMXoiLz4KICA8cGF0aCBmaWxsPSIjZWQyOTM5IiBkPSJNLjEgMGg2'
    b'NDB2MzIwSC4xeiIvPgogIDxwYXRoIGZpbGw9IiMwMGI5ZTQiIGQ9Ik0uMSAwaDY0MHYxNjBI'
    b'LjF6Ii8+CiAgPGNpcmNsZSBjeD0iMzA0IiBjeT0iMjQwIiByPSI3MiIgZmlsbD0iI2ZmZiIv'
    b'PgogIDxjaXJjbGUgY3g9IjMyMCIgY3k9IjI0MCIgcj0iNjAiIGZpbGw9IiNlZDI5MzkiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMzg0IDIwMCA3LjcgMjEuNSAyMC42LTkuOC05Ljgg'
    b'MjAuN0w0MjQgMjQwbC0yMS41IDcuNyA5LjggMjAuNi0yMC42LTkuOEwzODQgMjgwbC03Ljct'
    b'MjEuNS0yMC42IDkuOCA5LjgtMjAuNkwzNDQgMjQwbDIxLjUtNy43LTkuOC0yMC42IDIwLjYg'
    b'OS44TDM4NCAyMDB6Ii8+Cjwvc3ZnPgo=', 'AZ')

AZ = b64_AZ
index.append("AZ")
index.append("AZE")
index.append("Azerbaijan")
catalog["AZ"] = AZ
catalog["AZE"] = AZ
catalog["Azerbaijan"] = AZ
country["Azerbaijan"] = ('AZ', 'AZE', 0)
lookup["AZ"] = ('AZ', 'AZE', 'Azerbaijan', 0)
lookup["Baku Azerbaijan"] = ('AZ', 'AZE', 'Azerbaijan', 0)
lookup["AZE"] = ('AZ', 'AZE', 'Azerbaijan', 0)
lookup["Azerbaijan"] = ('AZ', 'AZE', 'Azerbaijan', 0)
details["AZ"] = {"continent":"Asia","capital":"Baku","currency":"Azerbaijan Manat","web":".az","lang":"az | ru | hy","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_BA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImJhLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1LjMgMGg2ODIu'
    b'NnY1MTJILTg1LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNiYS1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoODApIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjMDA5IiBkPSJNLTg1LjMg'
    b'MGg2ODIuNnY1MTJILTg1LjNWMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNGQzAiIGQ9Im01Ni41'
    b'IDAgNTExIDUxMi4zVi4zTDU2LjUgMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNGRkYiIGQ9Ik00'
    b'MzkuOSA0ODEuNSA0MTIgNDYxLjJsLTI4LjYgMjAuMiAxMC44LTMzLjItMjguMi0yMC41aDM1'
    b'bDEwLjgtMzMuMiAxMC43IDMzLjNoMzVsLTI4IDIwLjcgMTAuNCAzM3ptODEuMyAxMC40LTM1'
    b'LS4xLTEwLjctMzMuMy0xMC44IDMzLjJoLTM1bDI4LjIgMjAuNS0xMC44IDMzLjIgMjguNi0y'
    b'MC4yIDI4IDIwLjMtMTAuNS0zMyAyOC0yMC42ek0zNjUuNiAzODQuN2wyOC0yMC43LTM1LS4x'
    b'LTEwLjctMzMuMi0xMC44IDMzLjItMzUtLjEgMjguMiAyMC41LTEwLjggMzMuMyAyOC42LTIw'
    b'LjMgMjggMjAuNC0xMC41LTMzem0tNjQuMy02NC41IDI4LTIwLjYtMzUtLjEtMTAuNy0zMy4z'
    b'LTEwLjkgMzMuMmgtMzQuOWwyOC4yIDIwLjUtMTAuOCAzMy4yIDI4LjYtMjAuMiAyNy45IDIw'
    b'LjMtMTAuNC0zM3ptLTYzLjctNjMuNiAyOC0yMC43aC0zNUwyMjAgMjAyLjVsLTEwLjggMzMu'
    b'MmgtMzVsMjguMiAyMC40LTEwLjggMzMuMyAyOC42LTIwLjMgMjggMjAuNC0xMC41LTMzem0t'
    b'NjQuNC02NC4zIDI4LTIwLjYtMzUtLjEtMTAuNy0zMy4zLTEwLjkgMzMuMmgtMzQuOUwxMzgg'
    b'MTkybC0xMC44IDMzLjIgMjguNi0yMC4yIDI3LjkgMjAuMy0xMC40LTMzem0tNjMuNi02My45'
    b'IDI3LjktMjAuN2gtMzVMOTEuOSA3NC4zIDgxIDEwNy42SDQ2TDc0LjQgMTI4bC0xMC45IDMz'
    b'LjJMOTIuMSAxNDFsMjcuOCAyMC40LTEwLjMtMzN6bS02NC02NCAyNy45LTIwLjdoLTM1TDI3'
    b'LjkgMTAuMyAxNyA0My42aC0zNUwxMC40IDY0bC0xMSAzMy4zTDI4LjEgNzdsMjcuOCAyMC40'
    b'LTEwLjMtMzN6bS02NC02NEw5LjQtMjAuM2gtMzVsLTEwLjctMzMuM0wtNDctMjAuNGgtMzVM'
    b'LTUzLjcgMGwtMTAuOCAzMy4yTC0zNS45IDEzbDI3LjggMjAuNC0xMC4zLTMzeiIvPgogIDwv'
    b'Zz4KPC9zdmc+Cg==', 'BA')

BA = b64_BA
index.append("BA")
index.append("BIH")
index.append("Bosnia and Herzegovina")
catalog["BA"] = BA
catalog["BIH"] = BA
catalog["Bosnia and Herzegovina"] = BA
country["Bosnia and Herzegovina"] = ('BA', 'BIH', 0)
lookup["BA"] = ('BA', 'BIH', 'Bosnia and Herzegovina', 0)
lookup["Sarajevo Bosnia and Herzegovina"] = ('BA', 'BIH', 'Bosnia and Herzegovina', 0)
lookup["BIH"] = ('BA', 'BIH', 'Bosnia and Herzegovina', 0)
lookup["Bosnia and Herzegovina"] = ('BA', 'BIH', 'Bosnia and Herzegovina', 0)
details["BA"] = {"continent":"Europe","capital":"Sarajevo","currency":"Convertible Mark","web":".ba","lang":"bs | hr-BA | sr-BA","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_BB = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1iYiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMDI2N2YiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmM3MjYiIGQ9Ik0yMTMuMyAwaDIxMy40djQ4MEgy'
    b'MTMuM3oiLz4KICA8cGF0aCBpZD0iYmItYSIgZD0iTTMxOS44IDEzNS41Yy03IDE5LTE0IDM4'
    b'LjYtMjkuMiA1My43IDQuNy0xLjYgMTMtMyAxOC4yLTIuOHY3OS41bC0yMi40IDMuM2MtLjgg'
    b'MC0xLTEuMy0xLTMtMi4yLTI0LjctOC00NS41LTE0LjgtNjctLjUtMi45LTktMTQtMi40LTEy'
    b'IC44IDAgOS41IDMuNiA4LjIgMS45YTg1IDg1IDAgMCAwLTQ2LjQtMjRjLTEuNS0uMy0yLjQu'
    b'NS0xIDIuMiAyMi40IDM0LjYgNDEuMyA3NS41IDQxLjEgMTI0IDguOCAwIDMwLTUuMiAzOC43'
    b'LTUuMnY1Ni4xSDMyMGwyLjUtMTU2Ljd6Ii8+CiAgPHVzZSB4bGluazpocmVmPSIjYmItYSIg'
    b'd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEg'
    b'NjM5LjUgMCkiLz4KPC9zdmc+Cg==', 'BB')

BB = b64_BB
index.append("BB")
index.append("BRB")
index.append("Barbados")
catalog["BB"] = BB
catalog["BRB"] = BB
catalog["Barbados"] = BB
country["Barbados"] = ('BB', 'BRB', 0)
lookup["BB"] = ('BB', 'BRB', 'Barbados', 0)
lookup["Bridgetown Barbados"] = ('BB', 'BRB', 'Barbados', 0)
lookup["BRB"] = ('BB', 'BRB', 'Barbados', 0)
lookup["Barbados"] = ('BB', 'BRB', 'Barbados', 0)
details["BB"] = {"continent":"Americas","capital":"Bridgetown","currency":"Barbados Dollar","web":".bb","lang":"en-BB","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_BD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJkIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwNmE0ZSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPGNpcmNsZSBjeD0iMjgwIiBjeT0iMjQwIiByPSIxNjAi'
    b'IGZpbGw9IiNmNDJhNDEiLz4KPC9zdmc+Cg==', 'BD')

BD = b64_BD
index.append("BD")
index.append("BGD")
index.append("Bangladesh")
catalog["BD"] = BD
catalog["BGD"] = BD
catalog["Bangladesh"] = BD
country["Bangladesh"] = ('BD', 'BGD', 0)
lookup["BD"] = ('BD', 'BGD', 'Bangladesh', 0)
lookup["Dhaka Bangladesh"] = ('BD', 'BGD', 'Bangladesh', 0)
lookup["BGD"] = ('BD', 'BGD', 'Bangladesh', 0)
lookup["Bangladesh"] = ('BD', 'BGD', 'Bangladesh', 0)
details["BD"] = {"continent":"Asia","capital":"Dhaka","currency":"Taka","web":".bd","lang":"bn-BD | en","tz":"+06:00","altname":""}
#----------------------------------------------------------------------
b64_BE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBkPSJNMCAwaDIxMy4zdjQ4MEgweiIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZmZDkwYyIgZD0iTTIxMy4zIDBoMjEzLjR2NDgwSDIxMy4zeiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2YzMTgzMCIgZD0iTTQyNi43IDBINjQwdjQ4MEg0MjYuN3oi'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'BE')

BE = b64_BE
index.append("BE")
index.append("BEL")
index.append("Belgium")
catalog["BE"] = BE
catalog["BEL"] = BE
catalog["Belgium"] = BE
country["Belgium"] = ('BE', 'BEL', 0)
lookup["BE"] = ('BE', 'BEL', 'Belgium', 0)
lookup["Brussels Belgium"] = ('BE', 'BEL', 'Belgium', 0)
lookup["BEL"] = ('BE', 'BEL', 'Belgium', 0)
lookup["Belgium"] = ('BE', 'BEL', 'Belgium', 0)
details["BE"] = {"continent":"Europe","capital":"Brussels","currency":"Euro","web":".be","lang":"nl-BE | fr-BE | de-BE","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_BF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJmIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNkZTAwMDAiIGQ9Ik02NDAgNDc5LjZILjRWMEg2NDB6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjMzVhMTAwIiBkPSJNNjM5LjYgNDgwSDBWMjQwLjJoNjM5LjZ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmMzAwIiBkPSJtMjU0LjYgMjc2LjItMTA2LTcyLjRoMTMx'
    b'TDMyMCA4Ni42IDM2MC40IDIwNGwxMzEtLjEtMTA2IDcyLjQgNDAuNSAxMTcuMy0xMDYtNzIu'
    b'NkwyMTQgMzkzLjQiLz4KICA8L2c+Cjwvc3ZnPgo=', 'BF')

BF = b64_BF
index.append("BF")
index.append("BFA")
index.append("Burkina Faso")
catalog["BF"] = BF
catalog["BFA"] = BF
catalog["Burkina Faso"] = BF
country["Burkina Faso"] = ('BF', 'BFA', 0)
lookup["BF"] = ('BF', 'BFA', 'Burkina Faso', 0)
lookup["Ouagadougou Burkina Faso"] = ('BF', 'BFA', 'Burkina Faso', 0)
lookup["BFA"] = ('BF', 'BFA', 'Burkina Faso', 0)
lookup["Burkina Faso"] = ('BF', 'BFA', 'Burkina Faso', 0)
details["BF"] = {"continent":"Africa","capital":"Ouagadougou","currency":"CFA Franc BCEAO","web":".bf","lang":"fr-BF | mos","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_BG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZDYyNjEyIiBkPSJNMCAzMjBo'
    b'NjQwdjE2MEgweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MTYwSDB6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDA5NjZlIiBkPSJNMCAxNjBoNjQwdjE2MEgweiIvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'BG')

BG = b64_BG
index.append("BG")
index.append("BGR")
index.append("Bulgaria")
catalog["BG"] = BG
catalog["BGR"] = BG
catalog["Bulgaria"] = BG
country["Bulgaria"] = ('BG', 'BGR', 0)
lookup["BG"] = ('BG', 'BGR', 'Bulgaria', 0)
lookup["Sofia Bulgaria"] = ('BG', 'BGR', 'Bulgaria', 0)
lookup["BGR"] = ('BG', 'BGR', 'Bulgaria', 0)
lookup["Bulgaria"] = ('BG', 'BGR', 'Bulgaria', 0)
details["BG"] = {"continent":"Europe","capital":"Sofia","currency":"Bulgarian Lev","web":".bg","lang":"bg | tr-BG | rom","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_BH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJoIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDAiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNjQwIDBIOTZsMTEw'
    b'LjcgNDhMOTYgOTZsMTEwLjcgNDhMOTYgMTkybDExMC43IDQ4TDk2IDI4OGwxMTAuNyA0OEw5'
    b'NiAzODRsMTEwLjcgNDhMOTYgNDgwaDU0NCIvPgo8L3N2Zz4K', 'BH')

BH = b64_BH
index.append("BH")
index.append("BHR")
index.append("Bahrain")
catalog["BH"] = BH
catalog["BHR"] = BH
catalog["Bahrain"] = BH
country["Bahrain"] = ('BH', 'BHR', 0)
lookup["BH"] = ('BH', 'BHR', 'Bahrain', 0)
lookup["Manama Bahrain"] = ('BH', 'BHR', 'Bahrain', 0)
lookup["BHR"] = ('BH', 'BHR', 'Bahrain', 0)
lookup["Bahrain"] = ('BH', 'BHR', 'Bahrain', 0)
details["BH"] = {"continent":"Asia","capital":"Manama","currency":"Bahraini Dinar","web":".bh","lang":"ar-BH | en | fa | ur","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_BI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJpIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImJpLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTkwLjUgMEg1OTJ2'
    b'NTEySC05MC41eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBjbGlwLXBhdGg9InVybCgjYmktYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRl'
    b'KDg0LjkpIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjMThiNjM3IiBkPSJtLTE3'
    b'OCAwIDQyOC44IDI1NkwtMTc4IDUxMnptODU3LjYgMEwyNTAuOCAyNTZsNDI4LjggMjU2eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2NmMDkyMSIgZD0ibS0xNzggMCA0MjguOCAyNTZMNjc5LjYg'
    b'MHptMCA1MTIgNDI4LjgtMjU2IDQyOC44IDI1NnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik02NzkuNiAwaC03OS45TC0xNzggNDY0LjNWNTEyaDc5LjlMNjc5LjYgNDcuN3oiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zOTguOSAyNTZhMTQ4IDE0OCAwIDEgMS0yOTYu'
    b'MSAwIDE0OCAxNDggMCAwIDEgMjk2IDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJN'
    b'LTE3OCAwdjQ3LjdMNTk5LjcgNTEyaDc5Ljl2LTQ3LjdMLTk4LjEgMHoiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNjZjA5MjEiIHN0cm9rZT0iIzE4YjYzNyIgc3Ryb2tlLXdpZHRoPSIzLjkiIGQ9'
    b'Im0yODAgMjAwLjItMTkuMy4zLTEwIDE2LjQtOS45LTE2LjQtMTkuMi0uNCA5LjMtMTYuOS05'
    b'LjItMTYuOCAxOS4yLS40IDEwLTE2LjQgOS45IDE2LjUgMTkuMi40LTkuMyAxNi44em0tNjQu'
    b'NiAxMTEuNi0xOS4yLjMtMTAgMTYuNC05LjktMTYuNC0xOS4yLS40IDkuMy0xNi45LTkuMi0x'
    b'Ni44IDE5LjItLjQgMTAtMTYuNCA5LjkgMTYuNSAxOS4yLjQtOS4zIDE2Ljh6bTEzMC42IDAt'
    b'MTkuMi4zLTEwIDE2LjQtMTAtMTYuNC0xOS4xLS40IDkuMy0xNi45LTkuMy0xNi44IDE5LjIt'
    b'LjQgMTAtMTYuNCAxMCAxNi41IDE5LjIuNC05LjQgMTYuOHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'BI')

BI = b64_BI
index.append("BI")
index.append("BDI")
index.append("Burundi")
catalog["BI"] = BI
catalog["BDI"] = BI
catalog["Burundi"] = BI
country["Burundi"] = ('BI', 'BDI', 0)
lookup["BI"] = ('BI', 'BDI', 'Burundi', 0)
lookup["Bujumbura Burundi"] = ('BI', 'BDI', 'Burundi', 0)
lookup["BDI"] = ('BI', 'BDI', 'Burundi', 0)
lookup["Burundi"] = ('BI', 'BDI', 'Burundi', 0)
details["BI"] = {"continent":"Africa","capital":"Bujumbura","currency":"Burundi Franc","web":".bi","lang":"fr-BI | rn","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_BJ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJqIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImJqLWEiPgogICAgICA8cGF0aCBmaWxsPSJncmF5IiBkPSJNNjcuNi0xNTRoNjY2djY2Nmgt'
    b'NjY2eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgY2xpcC1wYXRoPSJ1cmwo'
    b'I2JqLWEpIiB0cmFuc2Zvcm09Im1hdHJpeCguOTYxIDAgMCAuNzIwNyAtNjUgMTExKSI+CiAg'
    b'ICA8ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBh'
    b'dGggZmlsbD0iIzMxOTQwMCIgZD0iTTAtMTU0aDMzM3Y2NjZIMHoiLz4KICAgICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZDYwMCIgZD0iTTMzMy0xNTRoNjY2djMzM0gzMzN6Ii8+CiAgICAgIDxwYXRo'
    b'IGZpbGw9IiNkZTIxMTAiIGQ9Ik0zMzMgMTc5aDY2NnYzMzNIMzMzeiIvPgogICAgPC9nPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'BJ')

BJ = b64_BJ
index.append("BJ")
index.append("BEN")
index.append("Benin")
catalog["BJ"] = BJ
catalog["BEN"] = BJ
catalog["Benin"] = BJ
country["Benin"] = ('BJ', 'BEN', 0)
lookup["BJ"] = ('BJ', 'BEN', 'Benin', 0)
lookup["Porto-Novo Benin"] = ('BJ', 'BEN', 'Benin', 0)
lookup["BEN"] = ('BJ', 'BEN', 'Benin', 0)
lookup["Benin"] = ('BJ', 'BEN', 'Benin', 0)
details["BJ"] = {"continent":"Africa","capital":"Porto-Novo","currency":"CFA Franc BCEAO","web":".bj","lang":"fr-BJ","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_BL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJsIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'BL')

BL = b64_BL
index.append("BL")
index.append("BLM")
index.append("Saint Barthélemy")
catalog["BL"] = BL
catalog["BLM"] = BL
catalog["Saint Barthélemy"] = BL
country["Saint Barthélemy"] = ('BL', 'BLM', 0)
lookup["BL"] = ('BL', 'BLM', 'Saint Barthélemy', 0)
lookup["Gustavia Saint Barthélemy"] = ('BL', 'BLM', 'Saint Barthélemy', 0)
lookup["BLM"] = ('BL', 'BLM', 'Saint Barthélemy', 0)
lookup["Saint Barthélemy"] = ('BL', 'BLM', 'Saint Barthélemy', 0)
details["BL"] = {"continent":"Americas","capital":"Gustavia","currency":"Euro","web":".gp","lang":"fr","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_BM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2NmMTQyYiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTU1OS43IDEzMC42'
    b'djE2MS42YzAgNDMuMS04Ni4yIDU3LjItODYuMiA1Ny4ycy04Ni40LTE0LTg2LjQtNTcuNFYx'
    b'MzAuNmgxNzIuNXoiLz4KICA8cGF0aCBmaWxsPSIjMmY4ZjIyIiBkPSJNNTU5LjcgMjkyLjJj'
    b'MCA0My4xLTg2LjIgNTcuMi04Ni4yIDU3LjJzLTg2LjQtMTQtODYuNC01Ny40YzAgMCAwLTMu'
    b'NSAxLjgtNS40IDAgMC0xIDcuMSA0LjUgMTIuNiAwIDAtNC4zLTcuOCAwLTE1LjMgMCAwLTEu'
    b'NyA5LjggNC40IDE1LjMgMCAwLTMuMy03LjkuNC0xNi43IDAgMC0xLjggMTQuMyA0LjcgMTcu'
    b'MyAwIDAgMS44LTguNC0uOC0xMy42IDAgMCA0LjUgMS44IDQuMyAxMy44IDAgMCAxLjQtMS44'
    b'IDEuOC0xMC41IDAgMCAuMiAxMCAzLjUgMTIuMyAwIDAgMS4yLTEtLjMtNS41LTEuNi00LjQu'
    b'Ni02IDEtNiAwIDAtLjggNSAzLjQgOC44IDAgMC0xLjgtNy45LjctOSAwIDAtLjYgNi43IDQu'
    b'OCA4LjEgMCAwIC4zLTEuOS0uOC00IDAgMC0xLTIuNS0uMy00LjUgMCAwIDEuNyA2IDQgNyAw'
    b'IDAtMS40LTMuNiAwLTcgMCAwIC4yIDUgNC43IDcuMSAwIDAtMy00LTEuOS04LjJsMjguNyAx'
    b'LjQgMTUgLjcgNDQuNy0zIDcuNi02LjdzMy4xIDQuMS0xLjggMTAuOGMwIDAgNC44LS44IDYu'
    b'My04LjMgMCAwIDIgNC4xLS43IDguOCAwIDAgNS4zLTUuNCA2LTExLjMgMCAwIDIuMSA1Ljgt'
    b'Mi45IDEyIDAgMCA0LjQtMS42IDYuMy04LjEgMCAwIDEuNiA0LTIuNyA5LjUgMCAwIDguMS00'
    b'LjEgNy45LTEzIDAgMCAzLjMgNC44LS41IDExLjYgMCAwIDQtMy43IDQuNS05LjMgMCAwIDIu'
    b'MyAyLjUtLjIgOS40IDAgMCA1LTQuOCA1LjgtOS45IDAgMCAxIDQuOC0zLjIgMTAuOCAwIDAg'
    b'Mi45LS44IDUuNy02LjYgMCAwIC43IDIuNC0xLjggNi42IDAgMCAyLjgtLjUgNC42LTUuOSAw'
    b'IDAgLjMgMy4yLS41IDYgMCAwIDIuMS0xLjMgMi42LTcuM2E5IDkgMCAwIDAgMS4yIDQuNHYu'
    b'OHoiLz4KICA8cGF0aCBmaWxsPSIjZDQwMDAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5l'
    b'am9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNTE1LjQgMTk4LjdzLTMgLjYt'
    b'Ny0uNmMtMy44LTEuMi01LjMtLjctNi41IDAgMCAwIDEuNS0zLjEtMi4zLTUuNiAwIDAgMS4y'
    b'IDMuMi0uNSA0LjYgMCAwLS43LjctMS42LS4zIDAgMC0xLjMtMS41LTIuOC0yLjQgMCAwIDMu'
    b'My0xLjIgMi43LTQuNS0uNi0zLjMtMi40LTMuNi0zLjMtNC4xYTYgNiAwIDAgMCAwIDIuNHMt'
    b'My41LTIgMS4yLTQuN2M0LjgtMi43IDQtNC40IDMuMS01LjhhMTMuMSAxMy4xIDAgMCAwLTMu'
    b'NS0zLjZzMSAxLjYuNyAyLjljLS4xIDEuMi0yLjQgMi0yLS4xLjUtMi40IDAtMiAwLTQuMyAw'
    b'IDAgNC4yIDEuNCA2LTIuOCAwIDAgMS42LTQuMy0zLjgtNi40IDAgMCAxLjMgMS44LjcgMyAw'
    b'IDAtMS4yIDIuMi0yLjUuNi0xLjMtMS43LTIuMi0yLjItMi4xLTQuMiAwIDAgNC45LjcgMy42'
    b'LTQuNyAwIDAtLjkgMy42LTcuMi0xLjIgMCAwIDQuMi00LjIgMi41LTcuNiAwIDAtLjUtMS41'
    b'LTQuOS0uNyAwIDAgMy44LTIuNCAyLjMtNC41IDAgMC0uOS0xLjMtNC42LjQgMCAwIDEuNS0y'
    b'LjMtMi4xLTUgMCAwLTIuNCAxLjItMy42IDIuNCAwIDAtMi40LTMtNC00LjMgMCAwLTIuOCAx'
    b'LjEtMy41IDQuMyAwIDAtMS4zLTEuNS00LjMtMi40IDAgMC0xLjQgMi44LjUgNSAwIDAtMS40'
    b'IDAtNC0xLjEgMCAwLTIuOC0xLjItMi4zIDEuMS4zIDIuNC42IDMgMS4yIDQuMiAwIDAtNi41'
    b'LTEuNS02LjIgMmE4LjggOC44IDAgMCAwIDMgNi4ycy0zLjUgNC44LTYuNiAxLjJjMCAwLTEu'
    b'MiAxLjIgMS4yIDQuMiAwIDAgMi40IDIuNS4zIDQuMiAwIDAtMi41IDItMy43LTIgMCAwLTQu'
    b'MSA0LjEuOCA3LjIgMCAwIDMgMS44IDYuMy0xIDAgMC0xIDgtNCA2LjQgMCAwLTEuOS0xLjIg'
    b'MS40LTIuOSAwIDAtNC44LS42LTUuNSA0IDAgMC0uNiAzLjUgMy41IDUgMCAwIDMuMSAxLjIg'
    b'MCAzLjYgMCAwLTIuNSAxLjctLjkgNC40IDAgMCAxLjggMi44LTIuOSAzLjIgMCAwLTIuNCAw'
    b'LTMuMy0uNCAwIDAtMSAyLS40IDQgMCAwLTIuMy0xLjctNy41LjItNS4yIDItNC45LjYtNS4y'
    b'IDEuMmwtMS42IDIuNHMyLjggMy42IDIuOSAzLjNsLS42IDQgMS40LjYgMTAuOC00LjggMTEt'
    b'NS43IDguOS40IDUuNiAxLjMgNy4yLjYgNS40LTIuOGg3LjZsOC40IDQuMiA5LjUgNS43IDUg'
    b'MSAzLjktLjN2LTcuOHoiLz4KICA8cGF0aCBmaWxsPSIjZDQwMDAwIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNDI4LjIg'
    b'MjA3LjdzNC4yIDIuMiA2LS4zYzAgMCAyLjItNC40LTIuOC02IDAgMCAyLjgtMy4yLS4yLTYu'
    b'MiAwIDAtMS42LTEuNi00LjItLjUgMCAwLTEuMi0yLjMtMy43LTIuMiAwIDAtMi40IDAtMyAy'
    b'LjUgMCAwLTMuMi0xLjItNC45LjYgMCAwLTMgMy4yIDEuMSA1LjhsMi45LjMgMi44LTEuNCAz'
    b'LjMuOXMtLjkgMy4yIDIuNyA2LjV6Ii8+CiAgPHBhdGggZmlsbD0iIzY0YjRkMSIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTUyMS42IDIwMC4xYTYuNyA2LjcgMCAw'
    b'IDEgNi45IDMuOGMyLjYgNi4yLTMgOS42LTMgOS42LjQgMS4zLjUgMy4yLjUgMy4yIDcuOCAx'
    b'IDYuNCA5LjggNi40IDkuOGwtMi42LTIuMmMtNC41LTEuOC05LjMgMi4yLTEyLjYgOC42LTMu'
    b'NCA2LjYtMS44IDkuNS0xLjIgMTcuMy42IDcuNyAxMyAxMi40IDEzIDEyLjRsLTkuNyAyNWMt'
    b'My44IDEwLTEyIDUuOS0xNC4zIDMuNy0yLjMtMi0yLjktLjgtNCAwLTEuMSAxIDUuMyA2LTYu'
    b'NSAxMC44LTExLjcgNC43LTEzLjcgOC4zLTE1LjcgOS41LTIgMS4yLTEwIC41LTEwLjgtLjYt'
    b'MS0xLS40LTEtMy41LTIuOS0zLTEuNy04LjItMy41LTEzLjgtNi4yLTUuNi0yLjctNS40LTYu'
    b'Mi01LjMtNi45IDAtLjcgMS45LTYuNS00LjctMS45LTYuNSA0LjctMTIuMS0yLjItMTIuMS0y'
    b'LjItMS4yLTEuNy02LjgtMTYuNC02LjgtMTYuNGE5Mi40IDkyLjQgMCAwIDAtNC4zLTEycy0u'
    b'NC44IDQuNS0yYzQuOC0yLjcgNy03LjMgOC43LTExLjkgMS43LTQuNiAwLTEyLjUtLjYtMTQt'
    b'LjYtMS42LTQuMi04LjktOC43LTEwLjQtNC40LTEuNi03LjUgMi40LTcuNSAyLjRzLTEuMy05'
    b'IDYuNi0xMGMwIDAgMC0xLjguNC0zLjEgMCAwLTUuNi0zLjQtMy05LjYgMCAwIDEuOC00LjMg'
    b'Ni44LTMuOGwtMS4xIDIuNHMtMS4yIDEyLjYgMTcuMiA0LjJjMTguNS04LjYgMTgtMTAuMiAy'
    b'OC43LTQuOGw3LjYtLjFzMTEtNS4zIDE0LjctM2MzLjUgMi4zIDE2LjMgOS40IDE2LjMgOS40'
    b'czEyLjQgNC43IDE0LjktNHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDI0'
    b'N2QiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00NjUu'
    b'OCAyNTVzLS42LTMuOS0xLjItNi40YzAgMC0xLjUtMy45IDEtNi44bDIuOC0zLjNzMS44LTIu'
    b'NCA0LTIuN2MwIDAgMi4zIDAgMi40LS41LjMtLjUgMi44LTQuNSA4LjYgMCAwIDAgMS44LTMg'
    b'NC44LTMuNiAwIDAgMy0uOCA0LjUgMS40IDAgMCAzLjUtMi42IDYuNCAxLjcgMCAwIDQuMS0y'
    b'LjQgNy4yIDIuMyAwIDAgNC0yIDYuNCAyLjEgMi41IDQuMyAyIDYgMiA2bDIgNi44IDYuNSA4'
    b'LTE1LjIgNS44aC03bC0xMy43IDMuNi0yNC4zIDEuOS02LjctOCA5LjYtOC4zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNkNDAwMDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3Vu'
    b'ZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00NDUuMyAyOTUuNXMtMy42LjEtNS41IDEuMmMt'
    b'MS44LjgtMy4zIDEuOC01LjQgMy4yIDAgMC0xIDEuMy01LjIuNSAwIDAtNy4yLTEuNy03LjIg'
    b'NCAwIDAtOC44LjYtNS4yIDguMyAwIDAgMi4zIDYgNy4zIDEuOCAwIDAtMy4yIDQuNSAzIDYu'
    b'MyAwIDAgNC40IDEuMiA1LjgtMy41IDAgMCAuNy0xLjgtMS00IDAgMCAyLjEtLjQgMy42LTIu'
    b'NyAwIDAtNC42IDUuOC41IDggMCAwIDYuMyAxLjUgNi42LTUgMCAwLS42LTMuMiAyLTQuMyAw'
    b'IDAgNS0xLjIgNy02LjYgMCAwLTctMy45LTYuMy03LjJ6TTQzMC42IDIzOHMtNS42LTIuNS04'
    b'LjQgMGMwIDAtMy41LTIuMi03LjUgMCAwIDAtMy43IDIuNC02LjMgNS4yIDAgMC0xLjggMS41'
    b'LTEuMiA2LjQgMCAwIDEgMy41LjUgNS4xIDAgMC0xLjItLjItMy43IDIuOCAwIDAtMy4xIDMu'
    b'NS02IC4zIDAgMCAxIDQuNiA2LjEgMy44IDAgMC0yLjUgMi0uMyA3IDAgMCAxLjYgMy42LTEg'
    b'OC4yIDAgMCA0LjUtMS44IDQuNC03LjIgMCAwLS41LTMuNiAxLTYgMCAwLTEuNSAyLjIgMS42'
    b'IDcuMSAwIDAgMi40IDMuNi41IDcuMiAwIDAgNC40LTEuNiA0LTctLjQtNS40LTMtMy4yLTEu'
    b'NC04LjIgMCAwIC41IDIuNiAxLjggNGE3LjIgNy4yIDAgMCAxIDIuNCA3czIuNi0zLjQgMi02'
    b'LjhhMTMuMSAxMy4xIDAgMCAwLTEuMy00LjRsOC40LTQuOCA0LjMtNy41eiIvPgogIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBzdHJv'
    b'a2Utd2lkdGg9IjEuMiIgZD0iTTQxNy44IDI1OS41cy0zLjUtLjItNC0zbS02LjEtMS44czEu'
    b'MiAwIDIuNCAxLjJjMCAwIC43IDEuMiAxLjkgMSIvPgogIDxwYXRoIGQ9Ik00MjMgMjQ5LjJz'
    b'LTEuOCAwLTMtLjhjMCAwLS45LS43LTEuNS40IDAgMC0xIDEuNi44IDIuMyAwIDAgMi4yIDEu'
    b'Mi0xLjIgMy40IDAgMCA0LTEuNiAyLjQtMy42IDAgMC0xLjgtMS4yLTEuMi0xLjcgMCAwIC4y'
    b'LS40IDEgMCAuNi42IDIgLjQgMi43IDB6Ii8+CiAgPHBhdGggZmlsbD0iIzc4NDQyMSIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0ibTQ3Ny42IDI1OSAyLjEtLjYtMTQt'
    b'NDhoLS40eiIvPgogIDxwYXRoIGQ9Ik00MzEuMiAzMTIuM3MtMy4yLTEuOS02IC4zYzAgMCAu'
    b'NC0xLjIgMi40LTEuNyAwIDAgMS4yLTMuMiA0LjMtMi45IDAgMC0xLjMgMS42LTMgMi44IDAg'
    b'MCAxLjguMiAyLjQgMS41eiIvPgogIDxwYXRoIGZpbGw9IiM2NGI0ZDEiIHN0cm9rZT0iIzAw'
    b'MjQ3ZCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00'
    b'MTkuNyAzMTkuOHMtNS4yLTMuMi0yLjMtOC43YzAgMCAuOC0xLjUgMi4zLTEuMiAwIDAgMy4z'
    b'IDEgLjggNS41IDAgMC0xLjQgMi45LS44IDQuNXptMTAuNSA1LjNzLTcuNC0zLjQtNS4xLTku'
    b'MmMwIDAgLjctMiAyLjQtMS44IDAgMCAyLjguMiAyLjMgNCAwIDAtLjkgMy42LjQgN3oiLz4K'
    b'ICA8cGF0aCBkPSJNNDI4LjcgMzAzLjZzLTIuMyAxLjctMy4xIDIuOGMwIDAtMS0xLjItMi4y'
    b'LTEuOCAwIDAgMS41LS4zIDIuMi4zIDAgMCAxLjItMSAzLTEuM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjNjRiNGQxIiBzdHJva2U9IiMwMDI0N2QiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0'
    b'cm9rZS13aWR0aD0iMS4yIiBkPSJNNDM1LjIgMzIzLjZzNi0xLjQgNC44LTcuNWMwIDAtLjYt'
    b'Mi42LTMtMi4yIDAgMC0zIC44LTEgNC42IDAgMCAxLjEgMi42LS44IDUuMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZjVjZTAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYi'
    b'IHN0cm9rZS13aWR0aD0iMS4yIiBkPSJtNDYxLjYgMTk2LjcgNS43IDEuOXM1LjQgMi4zIDEy'
    b'LjMgMGw1LjItMi0zLjUgNS40djIuOWwyLjEgMy4ycy0xLjMuNi01LjQtMmMwIDAtNC40LTMu'
    b'NC05LjYgMCAwIDAtMyAyLTUuNCAybDMuNS0zLjgtMS4zLTMuNS0zLjYtNC4zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Ik00MzcuNSAzMTYuNXMuMi0uNCAwLS41bC0uNS4ycy0uNiAx'
    b'IDAgMi40YzAgMCAuNS45LjMgMS44di40cy4zLS4xLjMtLjRjMCAwIC40LS44LS4yLTEuOCAw'
    b'IDAtLjYtMS40LjEtMi4xeiIvPgogIDxwYXRoIGZpbGw9IiNkNDAwMDAiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik01MTgg'
    b'MjA3LjdzLTQuMiAyLjItNi0uM2MwIDAtMi4xLTQuNCAyLjktNiAwIDAtMi44LTMuMi4xLTYu'
    b'MiAwIDAgMS42LTEuNiA0LjItLjUgMCAwIDEuMi0yLjMgMy43LTIuMiAwIDAgMi40IDAgMyAy'
    b'LjUgMCAwIDMuMy0xLjIgNSAuNiAwIDAgMi44IDMuMi0xLjIgNS44bC0yLjkuMy0yLjktMS40'
    b'LTMgLjlzLjggMy4yLTMgNi41eiIvPgogIDxwYXRoIGZpbGw9IiNmNWNlMDAiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00'
    b'ODQuOCAyMDQuNHMwIC44LS44IDFjMCAwLTEgLjMtMS41LS45di0uM2MwLS41LS4zLTIgMS40'
    b'LTMuMyAwIDAgMi42LTIuMSA3LjYuNWExOTIgMTkyIDAgMCAwIDE0LjggNy41czMuMSAxLjYg'
    b'Ny45IDEuOGMwIDAgNi41LjUgOS4zLTQuMSAwIDAgMi4xLTMuNSAwLTUuOCAwIDAtLjktMS0y'
    b'LjMtLjhhMyAzIDAgMCAwLTEuOCAxLjJzLTEgMS40LjEgMi41YzAgMCAxLjYgMSAyLjItMSAw'
    b'IC4yLjUgMS43LS40IDIuOSAwIDAtNCA2LTE0LjktLjFsLTE0LjMtOC4xcy03LjEtMy43LTEx'
    b'LjYgMi4xYzAgMC0zLjQgNC44IDEuMSA3LjkgMCAwIDMuNCAyIDUuNC0xLjIgMCAwIDEuOC0z'
    b'LjEtMS00LjQgMCAwLTIuNC0xLjItMy4zIDEuMi0xIDIuNCAxLjggMyAyIDEuMyAwIDAgMC0u'
    b'NC4zIDB6Ii8+CiAgPHBhdGggZmlsbD0iI2U0Y2I1ZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTQyOCAyMjkuMnYtOWMw'
    b'LS44IDAtMS4yIDEuMi0yLjIgMS0uOCAyLjEtMi4zIDMuNyAxLjcgMCAwIDMuMi0zLjUgNC4y'
    b'LTQgMCAwIDItMS41IDMuMy43IDAgMCAxLjYtMi42IDMtMy4yIDAgMCAzLjItMiAzLjMgNC4y'
    b'bDIuNS0yLjRzMi0xLjUgNC4yLjdjMCAwIDMuNSAzLjYgNCA0LjYgMCAwIC44IDEgMSAyLjcg'
    b'MCAwIDAgMiAxIDMgMCAwIDEuMSAxIDIuMiAxLjIgMCAwIDIuNS4xIDMuNiAyLjYgMCAwIC4z'
    b'LS41IDEuNiAxMS4ydjIxLjVsLTE0LjQgMTcuMS0yMy4xLTYuNi05LjItMy45LTIuMi02LjYg'
    b'OS01LjkgNC44LTEzLTEuNS05LjMtMi4yLTUuMnoiLz4KICA8cGF0aCBmaWxsPSIjNzg0NDIx'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJtNDkxLjYgMjQwLjQgMS4y'
    b'LTEuNSAyLjUtMnM0IDEwLjQgNC4yIDEyLjd2My4yczYgMS42IDcuMiAxMC43bC01IDkuMi03'
    b'LjgtNC40LTIuMy0xLjV2LTI2LjN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQxOC4z'
    b'IDMxMi40cy4yLS4zIDAtLjZsLS41LjRzLTEuNSAxLjctLjIgNC40YzAgMCAwIC40LjMuMiAw'
    b'IDAgLjMgMCAwLS4zIDAgMC0xLjEtMi40LjQtNHoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgc3Ryb2tlLXdpZHRoPSIxLjIi'
    b'IGQ9Ik00NDEuNyAzMTAuNnMuMS0uOC0uNC0xLjZjMCAwLS4zLS42LS4yLTEuNW01LjYtOTAu'
    b'MXMwIDIuMy43IDRjLjYgMS42IDIuOSA0LjUgMyA1LjkiLz4KICA8cGF0aCBmaWxsPSIjZDQw'
    b'MDAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0'
    b'aD0iMS4yIiBkPSJNNTAxIDI5NS41czMuNi4xIDUuNSAxLjJjMiAuOCAzLjQgMS44IDUuNSAz'
    b'LjIgMCAwIDEgMS4zIDUuMi41IDAgMCA3LjItMS43IDcuMiA0IDAgMCA4LjcuNiA1LjIgOC4z'
    b'IDAgMC0yLjQgNi03LjQgMS44IDAgMCAzLjIgNC41LTMgNi4zIDAgMC00LjQgMS4yLTUuNy0z'
    b'LjUgMCAwLS44LTEuOCAxLTQgMCAwLTIuMS0uNC0zLjUtMi43IDAgMCA0LjUgNS44LS41IDgg'
    b'MCAwLTYuMyAxLjUtNi43LTUgMCAwIC41LTMuMi0yLTQuMyAwIDAtNS0xLjItNy4yLTYuNiAw'
    b'IDAgNy4yLTMuOSA2LjUtNy4yeiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0ibTQ0My44'
    b'IDIyNy40IDYgNDcuOG0tNC41LTQ3LjkgNi42IDQ0LjZtLTUuNS00NC44IDcuOCA0NC4yIi8+'
    b'CiAgPHBhdGggZmlsbD0iIzc4NDQyMSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEu'
    b'MiIgZD0ibTQ1OC42IDI2Ny41IDIuMi0uNy0xNC00OGgtLjV6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMTAiIHN0cm9rZS13aWR0'
    b'aD0iMS4yIiBkPSJtNDUwLjcgMjI1LjMgMTQuMSAzNS41bS0xNS0zNSAxMy42IDM3Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQyNy42IDMyMS42cy0xLjctMS41LTEuNC00LjNjMCAw'
    b'IDAtLjYtLjMtLjcgMCAwLS4zLS4xLS4zLjYgMCAwLS41IDIuOSAxLjUgNC41IDAgMCAuMS4z'
    b'LjQuMiAwIDAgLjIgMCAwLS4zeiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0ibTQ1MS41'
    b'IDIyNC44IDE0LjMgMzIuNG0tMTguMy0zMC40IDkgNDMuNyIvPgogIDxwYXRoIGZpbGw9IiNm'
    b'NWNlMDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjIiIGQ9Ik01MjAgMjU5Yy02LjMtMy42LTcuNy0xMS40LTcuNy0xMS40YTI0LjYg'
    b'MjQuNiAwIDAgMSAxLjYtMTQuM2M0LTguNiAxMS4xLTEwLjMgMTEuMS0xMC4zcy02LjkgNC44'
    b'LTguOCAxMS4yYzAgMC0xLjQgNS41LS42IDEwLjcuOCA1LjUuNSA0LjEgMS44IDguM2wyLjYg'
    b'NnoiLz4KICA8cGF0aCBmaWxsPSIjNzg0NDIxIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iMS4yIiBkPSJtNDkyLjcgMjM4LjctMjYuNiA4LjUtMS40IDEyYy02LjMgOS4xLTE5LjIg'
    b'MTAuNy0xOS4yIDEwLjdsMTAgMTAuNyAxOSA0IDEwLjItNy44IDkuMi04LjRjLTEtNC41LS41'
    b'LTExLjItLjUtMTEuMiAwLTEuMi41LTMuOC41LTMuOHMtMS41LTEwLjctMS4yLTE0LjV6Ii8+'
    b'CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0i'
    b'MTAiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNDY1IDI1Ni4yczE3LjYtNS41IDI4LTEwbS0z'
    b'Ni40IDIwczIyLTQgMzcuMy0xMi44bDUuNi0zLjgiLz4KICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgc3Ryb2tlLXdpZHRoPSIxLjIi'
    b'IGQ9Im00OTkuNSAyNTIuOC02IDQuNHMtMjQuNSAxMS4yLTQzLjIgMTEuNm00My4xLTMuNlM0'
    b'NzQuNiAyNzUgNDY0IDI3NSIvPgogIDxwYXRoIGZpbGw9IiNkNDAwMDAiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik01MTUu'
    b'OCAyMzhzNS42LTIuNSA4LjQgMGMwIDAgMy42LTIuMiA3LjYgMCAwIDAgMy42IDIuNCA2LjIg'
    b'NS4yIDAgMCAxLjggMS41IDEuMiA2LjQgMCAwLTEgMy41LS4zIDUuMSAwIDAgMS4xLS4yIDMu'
    b'NSAyLjggMCAwIDMuMyAzLjUgNiAuMyAwIDAtLjggNC42LTYgMy44IDAgMCAyLjQgMiAuMyA3'
    b'IDAgMC0xLjYgMy42IDEgOC4yIDAgMC00LjYtMS44LTQuNC03LjIgMCAwIC40LTMuNi0xLTYg'
    b'MCAwIDEuNCAyLjItMS43IDcuMSAwIDAtMi40IDMuNi0uNCA3LjIgMCAwLTQuNS0xLjYtNC03'
    b'IC4zLTUuNCAzLTMuMiAxLjMtOC4yIDAgMC0uNCAyLjYtMS43IDRhNy4yIDcuMiAwIDAgMC0y'
    b'LjQgN3MtMi42LTMuNC0yLTYuOGMuNi0zLjUgMS4yLTQuNCAxLjItNC40bC04LjMtNC44LTQu'
    b'Mi03LjV6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAyNDdkIiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMTAiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNDIwLjYgMjY4LjRzLjgt'
    b'My43IDQuMy0yLjRjMCAwIDEuMi02IDcuNy02LjIgNi41LS4yIDYuOCA2LjQgNi44IDYuOCAw'
    b'IDAgMi0yLjggNS4xLTIuNSAwIDAgNS41LS4zIDMuNiA4LjVsMSAxLjJzNC4xLTkuOSAxMi43'
    b'LTcuNGMwIDAgOC40IDIuNiAzIDEwLjcgMCAwIDQuMiA1LjUgNy42IDUgMy42LS41IDYuNy0x'
    b'LjYgMTAuMi03LjggMy42LTYuMiAxMS43LTcuMiAxMy43LTYuOCAyIC4zIDMuNyAxLjggNCAz'
    b'LjIgMCAwIDQuMy0xNC4zIDE5LjgtMTIuMmw2LjIgMy4zIDIuNCAxLTMuNiAxMC04LjQgMTku'
    b'Mi02LjYgMi02LjgtMy45LTIuNCAxLjJ2NS45bC05IDYuNC02LjIgMi41LTYuOCA0LjgtMS43'
    b'IDQuMnMtMy43LTEuNy04IDBsLTEuNC0zLjYtNC0zLjctMTUuNi03LjQtMi43LTktMi45LTEu'
    b'My0zLjIgMy42LTQuNS42LTctNC44LTcuNC0yMXoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iMS4y'
    b'IiBkPSJNNDg4LjIgMTk4cy02LS4yLTUuNyA2Ii8+CiAgPHBhdGggZmlsbD0iI2Y1Y2UwMCIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9IjEu'
    b'MiIgZD0iTTUyNyAyNjMuM2MtMTAuMi0zLjItMTMtMTQuMy0xMy0xNC4zYTI1LjUgMjUuNSAw'
    b'IDAgMSAxLjItMTUuNWM0LjgtMTEgMTIuNy0xMSAxMi43LTExYTQgNCAwIDAgMSA0LjUgMy4y'
    b'Yy40IDIuNC0xLjMgMy4zLTEuMyAzLjMtMi43IDEuNS00LjUtLjUtNC41LS41LTEuMi0xLjYt'
    b'LjMtMi45LS4zLTIuOS43LTEgMi0uNCAyLS40IDEuMy4yIDEgMS42IDEgMS42cy40LTEuNi0x'
    b'LjItMS44YzAgMC0zLjItLjctNi44IDMuOCAwIDAtNC43IDYuMS00LjcgMTQuMSAwIDAtLjYg'
    b'MTQuOCAxNC43IDE4LjYgMCAwLTEuNiAyLjQtNC42IDExLjEgMCAwLTMuMyAxMS4yLTYuNCAx'
    b'Ny4zIDAgMC00LjMgOC42LTEzLjkgNS4xIDAgMC01LjYtMi41LTUuNi02LjUgMCAwLS4zLTMu'
    b'OCAzLTQgMCAwIDMuMy0uMyAzLjMgMi41IDAgMCAwIDMtMy41IDIuNCAwIDAtMS4yLS4zLTEu'
    b'MS0xLjUgMCAwIC4yLTEuMiAxLjgtLjYgMS41LjYgMCAwIDAtLjEgMCAwLS42LS4zLTEuMiAw'
    b'IDAgMC0uNiAwLS42IDEgMCAwIDAgLjYuNyAxLjFsMS43LjJzMSAyIDMgMi43YTggOCAwIDAg'
    b'MCA3LjEtMS4yIDEwLjcgMTAuNyAwIDAgMCAzLTQuMyAxMTMuMyAxMTMuMyAwIDAgMCA1LjIt'
    b'MTMuNXMxLjgtNS43IDMuNC04Ljd6Ii8+CiAgPHBhdGggZmlsbD0iI2Y1Y2UwMCIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0i'
    b'TTQ5OCAyOTEuNHMyLS4yIDIgMS41YzAgMC0uMSAyLjQtMy4yIDEuOSAwIDAtMy0uNi0yLTQg'
    b'MCAwIC44LTIuMyAzLjYtMiAwIDAgMi44IDAgNCAzLjggMCAwIDEgMy4zLS43IDYtMS44IDMt'
    b'Ni4yIDUtOC40IDYgMCAwLTguNyAzLjMtMTEuMyA1LjMgMCAwLTQgMi45LTIuMiA1LjYgMCAw'
    b'IC43IDEuMSAxLjcgMS4xIDAgMCAxLjIgMCAxLjMtMS4yIDAgMCAwIC43LS43IDEgMCAwLS44'
    b'LjQtMS43LS4zIDAgMC0xLTEtLjItMi40IDAgMCAxLTEuNiAzLjYtLjYgMCAwIDIgMS4xIDEu'
    b'MiAzLjMgMCAwLS45IDIuMS0zLjQgMiAwIDAtMS45IDAtMy4yLTEuMi0yLTIuMS0yLTYtLjIt'
    b'OCAwIDAgMS41LTIuMSA0LjctMy42bDktMy41YzIuNi0xLjEgNC45LTIuMyA2LjQtNC4xIDAg'
    b'MCAxLjMtMS40IDEuOC00IDAgMCAuNC0yLS44LTIuNGwtMS4yLS4zeiIvPgogIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjIiIGQ9Ik00OTguMiAyOTEuNHMyLjEtLjQgMy41IDIuMmMwIDAgLjcgMS41'
    b'LjggMi41bS43LTlzLTIuMS4zLTEgMy40YzEuMSAyLjkgMyAzLjcgMy41IDQuMiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmNWNlMDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIu'
    b'NiIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00NjEuNiAyMDQuNHMwIC44IDEgMWMwIDAgLjgu'
    b'MiAxLjMtLjl2LS4zYzAtLjUuMy0yLTEuMi0zLjMgMCAwLTIuOC0yLjEtNy44LjUgMCAwLTQg'
    b'Mi02LjcgMy42IDAgMC03LjEgMy44LTggNCAwIDAtMy4yIDEuNi04IDEuOCAwIDAtNi41LjUt'
    b'OS4yLTQuMSAwIDAtMi4yLTMuNSAwLTUuOCAwIDAgLjgtMSAyLjItLjguNi4xIDEuMi40IDEu'
    b'OCAxLjIgMCAwIDEgMS40LS4xIDIuNSAwIDAtMS42IDEtMi4yLTEgMCAuMi0uMyAxLjYuNSAz'
    b'IDAgMCA0IDUuOSAxNC44LS4zbDE0LjMtOHM3LjItMy43IDExLjYgMmMwIDAgMy40IDQuOC0x'
    b'IDggMCAwLTMuMyAyLTUuNS0xLjIgMCAwLTEuNi0zIDEtNC40IDAgMCAyLjQtMS4yIDMuNSAx'
    b'LjIgMSAyLjQtMiAzLTIuMiAxLjMgMCAwIDAtLjQtLjEgMHptLTM1LjIgNTQuN2M2LjMtMy41'
    b'IDcuOC0xMS41IDcuOC0xMS41IDEuNC04LTEuNy0xNC4zLTEuNy0xNC4zLTQtOC42LTExLTEw'
    b'LjMtMTEtMTAuM3M2LjggNC44IDguNyAxMS4yYzAgMCAxLjYgNS41LjYgMTAuNy0uOCA1LjUt'
    b'LjUgNC4xLTEuOCA4LjN6Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTQ1OC40IDE5'
    b'OHM2LS4yIDUuNiA2Ii8+CiAgPHBhdGggZmlsbD0iI2Y1Y2UwMCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTQxOS4zIDI2'
    b'My4zYzEwLjMtMy4yIDEzLTE0LjMgMTMtMTQuM2EyNS41IDI1LjUgMCAwIDAtMS4xLTE1LjVj'
    b'LTQuOC0xMS0xMi43LTExLTEyLjctMTFhNCA0IDAgMCAwLTQuNSAzLjJjLS4zIDIuNCAxLjMg'
    b'My4zIDEuMyAzLjMgMi44IDEuNSA0LjYtLjUgNC42LS41IDEuMS0xLjYuMi0yLjkuMi0yLjkt'
    b'LjctMS0yLS40LTItLjQtMS4yLjItMSAxLjYtMSAxLjZzLS4zLTEuNiAxLjItMS44YzAgMCAz'
    b'LjItLjcgNi44IDMuOCAwIDAgNC44IDYuMSA0LjggMTQuMSAwIDAgLjYgMTQuOC0xNC44IDE4'
    b'LjYgMCAwIDEuNyAyLjQgNC42IDExLjEgMCAwIDMuNCAxMS4yIDYuNiAxNy4zIDAgMCA0LjIg'
    b'OC42IDEzLjcgNS4xIDAgMCA1LjYtMi41IDUuNi02LjUgMCAwIC40LTMuOC0zLTQgMCAwLTMu'
    b'My0uMy0zLjMgMi41IDAgMCAwIDMgMy42IDIuNCAwIDAgMS4yLS4zIDEtMS41IDAgMC0uMi0x'
    b'LjItMS43LS42LTEuNi42IDAgMCAwLS4xIDAgMCAuNS0uMyAxLjEgMCAwIDAgLjYgMCAuNiAx'
    b'IDAgMCAwIC42LS43IDEuMWwtMS41LjJzLTEgMi0zLjIgMi43YTcuNSA3LjUgMCAwIDEtNy0x'
    b'LjIgMTAuNyAxMC43IDAgMCAxLTMtNC4zIDExMy41IDExMy41IDAgMCAxLTUuMy0xMy41cy0x'
    b'LjgtNS43LTMuMi04LjdsLS42LTEuMnoiLz4KICA8cGF0aCBmaWxsPSIjZjVjZTAwIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iMS4yIiBk'
    b'PSJNNDQ4LjUgMjkxLjRzLTItLjItMiAxLjVjMCAwIDAgMi40IDMuMiAxLjkgMCAwIDMtLjYg'
    b'MS45LTQgMCAwLS43LTIuMy0zLjYtMiAwIDAtMi43IDAtNCAzLjggMCAwLS45IDMuMy44IDYg'
    b'MS44IDMgNi4yIDUgOC4zIDYgMCAwIDguNyAzLjMgMTEuNCA1LjMgMCAwIDMuOSAyLjkgMi4x'
    b'IDUuNiAwIDAtLjYgMS4xLTEuNyAxLjEgMCAwLTEuMiAwLTEuMy0xLjIgMCAwIDAgLjcuNyAx'
    b'IDAgMCAuOS40IDEuNy0uMyAwIDAgMS0xIC4yLTIuNCAwIDAtMS0xLjYtMy40LS42IDAgMC0y'
    b'LjIgMS4xLTEuMiAzLjMgMCAwIC43IDIuMSAzLjIgMiAwIDAgMiAwIDMuMi0xLjIgMi0yLjEg'
    b'Mi02IC40LTggMCAwLTEuNy0yLjEtNC44LTMuNi0xLjktLjYtNS41LTIuMS05LTMuNS0yLjct'
    b'MS4xLTUtMi4zLTYuNS00LjEgMCAwLTEuMy0xLjQtMS44LTQgMCAwLS4zLTIgLjktMi40bDEu'
    b'Mi0uM3oiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRl'
    b'cmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNDQ4LjIgMjkxLjRzLTIuMS0u'
    b'NC0zLjQgMi4yYzAgMC0uNyAxLjUtLjkgMi41bS0uNy05czIuMi4zIDEuMSAzLjRjLTEuMiAy'
    b'LjktMyAzLjctMy42IDQuMm0yNy40LTkxLjFzNS4yLTMuMyAxMC40LjNtLTM5LjcgMzEuM3Mu'
    b'Ny0zLTIuNi04YzAgMC0yLjItNC43LTMuMi03LjVtNy40LTMuMyAyLjMgNi42IDMgNi44Ii8+'
    b'CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0i'
    b'MTAiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNDQxLjIgMjM4LjNzMiAyLjEgMS44IDUuNm0t'
    b'OC4xLTcuOXMyLjEgMSAxLjkgNi44YzAgMC0uMSA0IDMgNi4ybS01LjMgMS40czYuNy0uNyA3'
    b'LjIgMy41YzAgMCAwIDQgMi40IDQuMyAwIDAgMy4zLjMgNCAzLjZtLTExLjQtNi44czEuMiAx'
    b'LjcgMi40IDIuNm02LjItN3MxLjYgMi43IDIgNC4xbTUuMy0zNXMxLjYgMi4xIDMuMSAzbTMu'
    b'MSA5LjZzMy40IDEuNiAzIDEwYzAgMC0uNiA1IC45IDcuNyIvPgogIDxwYXRoIGZpbGw9IiM3'
    b'ODQ0MjEiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Im00NDMuMSAyMjYu'
    b'Ni40LjhzNiAuMyA5LjEtMy44bC0uMy0uOHMtNS4zLS4zLTkgMy44eiIvPgogIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBzdHJva2Ut'
    b'd2lkdGg9IjEuMiIgZD0iTTQ2NC43IDI1OC41czIwLjYtNiAyOC42LTkuNiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM3ODQ0MjEiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Im00'
    b'NjIuNSAyMjAuNS0uMi0uNiAxMC4xLTQgLjMuOHoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgc3Ryb2tlLXdpZHRoPSIxLjIi'
    b'IGQ9Im00NjMuNCAyMjAuMSA2LjggMzMuM20tNS42LTMzLjYgNy43IDMzbS02LjQtMzMuNiA4'
    b'LjQgMzIuOW0tNS0zNC4xIDExLjUgMjQuNm0tMTAtMjUgMTIuMyAyNC4yTTQ3MS44IDIxN2wx'
    b'My40IDI0LjNtLTE1LjUgMTIuNCA1LjItMS42bS05LjEtMS42czE1LjItNC41IDI3LTkuMk00'
    b'NjUuNCAyNTJzMTkuNS01IDI3LjItOC44bS0yMS4yIDI0LjYgMSAzLjMgMi44LTEtMS0zLjFt'
    b'NS0xLjMgMSAzIDIuOC0uOS0xLTNtLTE2LTE3LjYtLjItNC4yIDI1LjUtNy43IDEuMyAzLjZt'
    b'LTE2IC44IDEuMyAzLjhtNy42LTYuNCAxLjYgMy42bS41LTQuMyAxLjYgMy4zbS40LTQgMS42'
    b'IDMuNm0wLTQgMi44LTEuNiAxLjIgMy4xbS0yLjYtMi4zIDEuNCAzLjMiLz4KICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDI0N2QiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjIiIGQ9Ik00MjkuNSAyODMuMXMtNS01LjEgMC0xMGMwIDAtNS41LTIu'
    b'Ni00LjYtN20xMy42IDIxcy01LjMuNy0zLjctOS40YzAgMC0yLjIgNC0yLjkgNmE0LjcgNC43'
    b'IDAgMCAwIDIgNS40Yy45LjYgNS41IDEuOCA3LTEuMm0tOC4zLTE2LjJzLTIuMSAxLjktLjYg'
    b'NS40bTIuOC01cy4yIDMuNSAyIDUuNG0tLjUtNi43czAgNCAyLjkgNi42bS0xLjUtOHMwIDQu'
    b'NSAzLjQgNy40bTEzLjUtLjdzMS42LTMuOSA1LjItMy42YzAgMC0xLjcuOC0xLjcgMi41IDAg'
    b'MC0uMiAzIDIuOSAzLjIgMCAwIDIuNS40IDMuOC0xIi8+CiAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlPSIjMDAyNDdkIiBzdHJva2UtbWl0ZXJsaW1pdD0iMTAiIHN0cm9rZS13aWR0aD0i'
    b'MS4yIiBkPSJNNDYzLjEgMjkzLjFzLTguOS00LjItOC0xMC4xYzAgMCAuNC0zLjYgNC01LjRt'
    b'LTIgMy44cy0uOCAyLjUgMSA0LjNtMS4xLTZzLTEuMiAyLjguNyA0LjhtMS41LTYuM3MtMS40'
    b'IDIuNC4yIDQuNW0tOC40IDExczQuOCA0LjMgOC42IDQuM20tMTAuMS0yLjlzNC41IDMuNiA3'
    b'LjQgNC4ybS05LTMuMnM1LjUgNC45IDkgNS4ybTEzLjcgNC42cy01LjUgMy0xLjIgNi4ybS0y'
    b'LjQtOS40IDktNC42bS02LjcgNi4yczktNS41IDExLjctNi43bS03IDcuMnM3LjctNS4yIDEx'
    b'LjktNy41bS02LjggNy4xczUuMy00IDEwLjUtNy4xbTEuNy01LjFzLTIuNi0zLjktMTEuMiAw'
    b'YzAgMCAzLjMtMi45IDkuNS01LjJtOC41LTE2LjNzLjggMy4xIDAgNSIvPgogIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iIzAwMjQ3ZCIgc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBzdHJv'
    b'a2Utd2lkdGg9IjEuMiIgZD0iTTQ4Ni41IDI4NS43czEuOC0yLjYgNi4zLTRjMCAwIDEuMiAz'
    b'IDQuOCAyLjUgMCAwIDUuMi0xLjEgMy42LTcgMCAwLTEuMS00LjItNy4yLTQuN20xOC4xLTcu'
    b'M3M2LjEgMS4yIDYgNi4xYzAgMCAuNiA3LjYtNy40IDltNi42LTEyczEuNi0zLjcgNS41LTUu'
    b'Mm0tNC42LTIuMnMxLjcgMi44IDIuOCAzLjFtLTMuNi0xczEuNSAyLjEgMiAyLjVtLTIuNi0u'
    b'NWE4IDggMCAwIDAgMS41IDEuNk00ODUgMjM1LjhzMS4yLTIgNC4zLTEuMm0xMi4xIDE1Ljhz'
    b'Mi03LjggOC41LTVtLTIuNi0uNnMuNi0zLjYtMS01LjVtLTMuNiA1LjJzLjkgMS41LjEgMi43'
    b'Ii8+CiAgPHBhdGggZmlsbD0iIzY0YjRkMSIgc3Ryb2tlPSIjMDAyNDdkIiBzdHJva2UtbWl0'
    b'ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTUxNi4yIDMyNXM3LjQtMy4z'
    b'IDUuMS05LjFjMCAwLS43LTItMi40LTEuOCAwIDAtMi44LjEtMi4zIDQgMCAwIDEgMy44LS41'
    b'IDd6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTUxOC44IDMyMS42czEuNy0xLjUgMS41'
    b'LTQuM2MwIDAtLjItLjYgMC0uNyAwIDAgLjQtLjEuNC42IDAgMCAuNSAyLjktMS40IDQuNSAw'
    b'IDAtLjEuMy0uNC4yIDAgMC0uMiAwIDAtLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzY0YjRkMSIg'
    b'c3Ryb2tlPSIjMDAyNDdkIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9'
    b'IjEuMiIgZD0iTTUyNi43IDMxOS44czUuMi0zLjIgMi40LTguN2MwIDAtLjktMS41LTIuNC0x'
    b'LjIgMCAwLTMuMiAxLS43IDUuNSAwIDAgMS4yIDIuOS43IDQuNXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNNTI4IDMxMi40cy0uMi0uMyAwLS42bC40LjRzMS41IDEuNy4zIDQuNGMw'
    b'IDAtLjEuNC0uNS4ydi0uM3MxLjItMi40LS4yLTR6Ii8+CiAgPHBhdGggZmlsbD0iIzY0YjRk'
    b'MSIgc3Ryb2tlPSIjMDAyNDdkIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lk'
    b'dGg9IjEuMiIgZD0iTTUxMSAzMjMuNnMtNS44LTEuNC00LjctNy41YzAgMCAuNi0yLjYgMy4x'
    b'LTIuMiAwIDAgMyAuOCAxIDQuNiAwIDAtMS4xIDIuNi43IDUuMXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNNTA4LjggMzE2LjV2LS41cy40IDAgLjUuMmMwIDAgLjYgMSAuMSAyLjQg'
    b'MCAwLS41LjktLjIgMS44IDAgMCAwIC4zLS4zLjRsLS4yLS40cy0uMy0uOC4yLTEuOGMwIDAg'
    b'LjYtMS40IDAtMi4xeiIvPgogIDxwYXRoIGQ9Ik01MTUuMiAzMTIuM3MzLjQtMS45IDYgLjNj'
    b'MCAwLS4yLTEuMi0yLjQtMS43IDAgMC0xLTMuMi00LjItMi45IDAgMCAxLjIgMS42IDMgMi44'
    b'IDAgMC0xLjguMi0yLjQgMS41em0yLjQtOC43czIuNCAxLjcgMy4yIDIuOGMwIDAgLjktMS4y'
    b'IDItMS44IDAgMC0xLjItLjMtMiAuMyAwIDAtMS4xLTEtMy0xLjN6Ii8+CiAgPHBhdGggZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMTAiIHN0cm9rZS13'
    b'aWR0aD0iMS4yIiBkPSJNNTA0LjggMzEwLjZzLS4zLS44LjMtMS42YzAgMCAuNC0uNi4yLTEu'
    b'NW0yMy40LTQ4czMuNS0uMiA0LTNtNi0xLjhzLTEuMiAwLTIuMiAxLjJjMCAwLS45IDEuMi0y'
    b'IDEiLz4KICA8cGF0aCBkPSJNNTIzLjYgMjQ5LjJzMS44IDAgMi43LS44YzAgMCAxLjEtLjcg'
    b'MS43LjQgMCAwIDEgMS42LS44IDIuMyAwIDAtMi4yIDEuMiAxLjMgMy40IDAgMC00LjItMS42'
    b'LTIuNC0zLjYgMCAwIDEuOC0xLjIgMS0xLjcgMCAwLS4yLS40LS45IDAtLjcuNi0yLjEuNC0y'
    b'LjYgMHoiLz4KICA8cGF0aCBmaWxsPSIjNjRiNGQxIiBzdHJva2U9IiMwMDI0N2QiIHN0cm9r'
    b'ZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNTI2IDIwNS42cy44'
    b'LTEuMi41LTQuNGMtLjQtMy4yIDIuNi0zLjcgMy42LTIuOCAwIDAgMS4yIDEgMCAzLjFhOC4z'
    b'IDguMyAwIDAgMS00LjEgNC4xeiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik01MjcgMjAz'
    b'czEuMi0xLjEuNi0zLjZsLjItLjJoLjNzLjYgMi44LS42IDQuMmMwIDAtLjIuMy0uNSAweiIv'
    b'PgogIDxwYXRoIGZpbGw9IiM2NGI0ZDEiIHN0cm9rZT0iIzAwMjQ3ZCIgc3Ryb2tlLW1pdGVy'
    b'bGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik01MjUuMSAyMDQuNHMwLTEuNC0y'
    b'LjMtMy42Yy0yLjQtMi40LS41LTQuNCAxLTQuNCAwIDAgMS4zIDAgMiAyLjNhOC4zIDguMyAw'
    b'IDAgMS0uNyA1Ljd6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTUyNC44IDIwMS40czAt'
    b'MS42LTIuMi0zLjN2LS40aC40czIuMyAxLjggMi4zIDMuOGMwIDAgMCAuMy0uMy4zIDAgMC0u'
    b'MiAwLS4yLS40eiIvPgogIDxwYXRoIGZpbGw9IiM2NGI0ZDEiIHN0cm9rZT0iIzAwMjQ3ZCIg'
    b'c3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik01MjIgMjAz'
    b'LjNzLS43LTEtMy41LTIuMWMtMi45LTEtMi4yLTMuNS0xLTQgMCAwIDEuMy0uNSAyLjYgMS4x'
    b'YTcuNiA3LjYgMCAwIDEgMS44IDV6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTUyMC42'
    b'IDIwMS4zcy0uNi0xLjQtMy4yLTIuMWMwIDAtLjIgMC0uMi0uMyAwIDAgMC0uMi4zLS4xIDAg'
    b'MCAyLjkuNiAzLjcgMi40bC0uMS4zcy0uMyAwLS40LS4yeiIvPgogIDxwYXRoIGZpbGw9IiM2'
    b'NGI0ZDEiIHN0cm9rZT0iIzAwMjQ3ZCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjIiIGQ9Ik01MjMuNyAyMDQuNHMtMS4zLjUtNC40LTFjLTMuMS0xLjUtNC40'
    b'IDEuMS0zLjggMi4zIDAgMCAuNSAxLjYgMi44IDEuMmE4LjMgOC4zIDAgMCAwIDUuNC0yLjR6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTUxNi42IDIwNS40czEuNCAxIDMuOSAwaC4z'
    b'czAgLjItLjIuM2MwIDAtMi42IDEuMi00LjQuMSAwIDAtLjIgMCAwLS4zaC40eiIvPgogIDxw'
    b'YXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik01MTkuMyAxOTQuN3MxLjQuOCAxLjIgMi41Ii8+CiAg'
    b'PHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMTAi'
    b'IHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNTI2IDE5NXMuNiAxLjkgMCAzIi8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzY0YjRkMSIgc3Ryb2tlPSIjMDAyNDdkIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42'
    b'IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTQyMC4yIDIwNS42cy0uOC0xLjItLjUtNC40Yy40'
    b'LTMuNC0yLjUtMy43LTMuNS0yLjggMCAwLTEuMiAxLS4yIDMuMWE4LjMgOC4zIDAgMCAwIDQu'
    b'MiA0LjF6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQxOS4xIDIwM3MtMS0xLjEtLjYt'
    b'My42di0uMmgtLjRzLS41IDIuOC43IDQuMmMwIDAgLjIuMy4zIDB6Ii8+CiAgPHBhdGggZmls'
    b'bD0iIzY0YjRkMSIgc3Ryb2tlPSIjMDAyNDdkIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBz'
    b'dHJva2Utd2lkdGg9IjEuMiIgZD0iTTQyMS4yIDIwNC40czAtMS40IDIuNC0zLjZjMi4zLTIu'
    b'NC40LTQuNC0xLTQuNCAwIDAtMS42IDAtMiAyLjNhOC4zIDguMyAwIDAgMCAuNiA1Ljd6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQyMS41IDIwMS40czAtMS42IDItMy4zYzAgMCAu'
    b'My0uMyAwLS40aC0uMnMtMi40IDEuOC0yLjQgMy44YzAgMCAwIC4zLjQuMyAwIDAgLjIgMCAu'
    b'Mi0uNHoiLz4KICA8cGF0aCBmaWxsPSIjNjRiNGQxIiBzdHJva2U9IiMwMDI0N2QiIHN0cm9r'
    b'ZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNDI0LjMgMjAzLjNz'
    b'LjYtMSAzLjUtMi4xYzIuOC0xIDItMy41LjktNCAwIDAtMS4yLS41LTIuNiAxLjFhNy42IDcu'
    b'NiAwIDAgMC0xLjggNXoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDI1LjYgMjAxLjNz'
    b'LjYtMS40IDMuMi0yLjFjMCAwIC4yIDAgLjItLjMgMCAwIDAtLjItLjItLjEgMCAwLTIuOS42'
    b'LTMuNyAyLjR2LjNzLjQgMCAuNS0uMnoiLz4KICA8cGF0aCBmaWxsPSIjNjRiNGQxIiBzdHJv'
    b'a2U9IiMwMDI0N2QiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iMS4y'
    b'IiBkPSJNNDIyLjUgMjA0LjRzMS40LjUgNC40LTFjMy0xLjUgNC40IDEuMSA0IDIuMyAwIDAt'
    b'LjcgMS42LTMgMS4yYTguMyA4LjMgMCAwIDEtNS40LTIuNHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJNNDI5LjYgMjA1LjRzLTEuMyAxLTMuOSAwaC0uMnYuM3MyLjggMS4yIDQuNS4x'
    b'YzAgMCAuMiAwIDAtLjNoLS40eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00Mjcg'
    b'MTk0LjdzLTEuNS44LTEuMiAyLjUiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00MjAu'
    b'MiAxOTVzLS42IDEuOSAwIDMiLz4KICA8cGF0aCBkPSJNNDg2LjcgMTc3LjZzMSAyLjcuNiA1'
    b'LjJjLS4zIDIuNC4yIDIuOSAxIDMuNC43LjMgMi40LS40IDIuNS0yLjIgMCAwIDIgMy44LTEu'
    b'OCA2LjMgMCAwLTIuNyAxLjctNS0uNC0uOC0uOS0xLjItMy0uNy01IDAgMCAuNi0yLjctLjUt'
    b'NS41IDAgMCAxLjYgMS42IDEuMiA0LjkgMCAwLS44IDYgMy42IDUuNiAwIDAgMyAwIDMtMy42'
    b'IDAgMC0xLjEgMS4yLTIuNC44YTIuNCAyLjQgMCAwIDEtMS44LTIuOGMuMS0xLjYuNi00LjMu'
    b'My02Ljd6TTQ4MiAxODdzLS40IDQuOC00LjYgNS45YzAgMCAuNi0uOS0uMy0zLjMgMCAwLTEt'
    b'MS4yLTEtMy4zIDAgMC0xLjIgMSAuMyAzLjggMSAxLjcgMCAzLjYtLjEgMy43LS40LjEgNi45'
    b'LTEgNS42LTYuN3ptLTUuNi00LjVzLTEuMS0xLjItMS4yLTMuOGMwLTIuNy0uNS0zLjQtLjkt'
    b'My42IDAgMCAuNSAyLjMuNCAzLjZhNyA3IDAgMCAwIC40IDNzLTIuNC4zLTMuOS0zYy0xLjMt'
    b'My4zLTIuNy0zLTMuNC0zIDAgMCAuOC4xIDIuNCAzIDEuNiAzIDIuMSAzLjcgNi4yIDMuN3pt'
    b'LTEwLjgtN3MxLjIgMy4yIDEuNCA0LjhjMCAwLTMuMS0xLTQtMy41IDAgMC0zLjIgMS0yIDQu'
    b'NyAwIDAtMi45LTEtNC4yLTMuMiAwIDAgMS42IDEuMiAzLjEgMS43IDAgMC0uMi0zLjEgMy42'
    b'LTQuMiAwIDAgLjYgMi43IDIuNiAzLjN6bTUtNS40czEuMiAxLjUgMy40IDEuNWEzLjYgMy42'
    b'IDAgMCAwIDMuMi0xLjVzLS4xIDIuNi0zLjIgMi43YzAgMC0zLjMgMC0zLjMtMi43em0tMTMu'
    b'NCAxOC41IDIgMS45czEuMiAxLjIgMi0uM2MwIDAgMS4zLTIuNCAyLjktMi4yIDAgMC0xLjIu'
    b'Ny0yLjQgMyAwIDAtLjIuNy0xLjIuOC0uNSAwLTEgLjItMS44LS43IDAgMC0uNy0uOS0xLjUt'
    b'Mi40em0xNi43LTI5LjRjLTMuMiAwLS41IDIuNC0uNSAyLjQgMCA0LTMuMSA1LjQtNS4zIDQu'
    b'Mi0yLjItMS4yLS40LTQtLjQtNHMtMi40IDEuNS0xIDMuOWMxLjYgMi40IDUuNyAxLjIgNy4y'
    b'LS45IDEuNSAyLjIgNS43IDMuMyA3LjEuOSAxLjctMi40LS44LTQtLjgtNHMxLjggMi45LS41'
    b'IDRjLTIuMSAxLjMtNS40IDAtNS4yLTQgMCAwIDIuNy0yLjUtLjUtMi41em0yLTQuNHMxLjIg'
    b'MiAxIDVjMCAwIC45LTMtMS00Ljl6bS0xMCA0LjdzLS4zLTIuMi0yLjQtMi40YzAgMCAxLjkg'
    b'MS4zIDIuNCAyLjR6bTE2IDBzLjMtMi4yIDIuNS0yLjRjMCAwLTEuOCAxLjMtMi40IDIuNHpt'
    b'LTE5LjIgMy4yczEuNi41IDIuNi0uN3ptLTUuNC0xMy4xczEuOS0uMSAzLjggMi43YzAgMC0x'
    b'LjkgMS0yLjQgMS42IDAgMCAwLTEgMS0xLjcgMCAwLS40LTEuNC0yLjQtMi41em0zMiAwcy0y'
    b'LS4xLTMuOSAyLjdjMCAwIDIgMSAyLjQgMS42IDAgMCAwLTEtMS0xLjcgMCAwIC40LTEuNCAy'
    b'LjUtMi41em0tMTQuNyAyLjJzMS43LjUgMy44LS43YzAgMCAyLjYtMS40IDQuMyAwIDAgMC0x'
    b'LjQtLjctNC4zLjcgMCAwLTIuNyAxLjYtMy44IDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZD0iTTQ3Ni40IDE1My42czEuNC0yLjUgNi0yYzAgMC0xLjMgMy42LTYgMnoiLz4KICA8ZWxs'
    b'aXBzZSBjeD0iNDc5LjQiIGN5PSIxNTIuOCIgZmlsbD0iIzc4NDQyMSIgcng9Ii44IiByeT0i'
    b'MS4xIi8+CiAgPGVsbGlwc2UgY3g9IjQ3OS40IiBjeT0iMTUyLjgiIHJ4PSIuNSIgcnk9Ii43'
    b'Ii8+CiAgPHBhdGggZD0iTTQ2Ni44IDE0OC4xczIuOC4zIDQuNiAxLjJjMCAwIDEuOCAxLjIg'
    b'My44LS4zIDAgMCAyLjItMS40IDMuNy0zLjEgMCAwLTMuNSAyLjMtNC44IDIuNyAwIDAtMS4y'
    b'LTEtMS41LTIuMyAwIDAgMC0xIDItMi43IDAgMC0yLjUuOC0zIDIuOWE3LjIgNy4yIDAgMCAw'
    b'IDEuNCAyLjNzLS40LjMtMS42LS42YzAgMC0yLjgtLjgtNC42IDB6bTcuMiAxN2MtMi40IDIu'
    b'MSAwIDEuOSAwIDEuOXMyLjQuMiAwLTJ6bS0xLjQtMTMuMnMtMS44LjUtNC0uN2MwIDAtMi42'
    b'LTEuNC00LjMgMCAwIDAgMS41LS43IDQuMy43IDAgMCAyLjkgMS42IDQgMHoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNNDcwLjggMTUzLjZzLTEuNS0yLjUtNi0yYzAgMCAxLjIgMy42'
    b'IDYgMnoiLz4KICA8ZWxsaXBzZSBjeD0iNDY3LjciIGN5PSIxNTIuOCIgZmlsbD0iIzc4NDQy'
    b'MSIgcng9Ii44IiByeT0iMS4xIi8+CiAgPGVsbGlwc2UgY3g9IjQ2Ny43IiBjeT0iMTUyLjgi'
    b'IHJ4PSIuNSIgcnk9Ii43Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9IjEuMiIgZD0iTTU2MCAxMzAuNnYxNjEuNmMwIDQzLjEtODYuMiA1Ny4y'
    b'LTg2LjIgNTcuMnMtODYuNC0xNC04Ni40LTU3LjJWMTMwLjZoMTcyLjd6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzAwNiIgZD0iTTAgMGgzMjB2MjQwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZD0ibTM3LjUgMCAxMjIgOTAuNUwyODEgMGgzOXYzMWwtMTIwIDg5LjUgMTIwIDg5VjI0MGgt'
    b'NDBsLTEyMC04OS41TDQwLjUgMjQwSDB2LTMwbDExOS41LTg5TDAgMzJWMHoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjYzgxMDJlIiBkPSJNMjEyIDE0MC41IDMyMCAyMjB2MjBsLTEzNS41LTk5LjV6'
    b'bS05MiAxMCAzIDE3LjUtOTYgNzJIMHpNMzIwIDB2MS41bC0xMjQuNSA5NCAxLTIyTDI5NSAw'
    b'ek0wIDBsMTE5LjUgODhoLTMwTDAgMjF6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTEy'
    b'MC41IDB2MjQwaDgwVjB6TTAgODB2ODBoMzIwVjgweiIvPgogIDxwYXRoIGZpbGw9IiNjODEw'
    b'MmUiIGQ9Ik0wIDk2LjV2NDhoMzIwdi00OHpNMTM2LjUgMHYyNDBoNDhWMHoiLz4KPC9zdmc+'
    b'Cg==', 'BM')

BM = b64_BM
index.append("BM")
index.append("BMU")
index.append("Bermuda")
catalog["BM"] = BM
catalog["BMU"] = BM
catalog["Bermuda"] = BM
country["Bermuda"] = ('BM', 'BMU', 0)
lookup["BM"] = ('BM', 'BMU', 'Bermuda', 0)
lookup["Hamilton Bermuda"] = ('BM', 'BMU', 'Bermuda', 0)
lookup["BMU"] = ('BM', 'BMU', 'Bermuda', 0)
lookup["Bermuda"] = ('BM', 'BMU', 'Bermuda', 0)
details["BM"] = {"continent":"Americas","capital":"Hamilton","currency":"Bermudian Dollar","web":".bm","lang":"en-BM | pt","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_BN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ibiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmN2UwMTciIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDMzLjN2MjEzLjRsNjQwIDEwMFYy'
    b'MzMuM3oiLz4KICA8cGF0aCBkPSJNMCAxNDYuN3YxMDBsNjQwIDIwMHYtMTAweiIvPgogIDxn'
    b'IGZpbGw9IiNjZjExMjYiIHRyYW5zZm9ybT0idHJhbnNsYXRlKC0xNjApIHNjYWxlKC42NjY2'
    b'NykiPgogICAgPHBhdGggZD0iTTY5NS43IDU2OS43YTExNy4yIDExNy4yIDAgMCAxLTQ5LjQt'
    b'MTcuMmMtMi40LTEuNi00LjYtMy01LTMtLjQgMC0uNiAxLjktLjYgNC4xIDAgNi40LTIuNiA5'
    b'LjYtOSAxMS4zLTYuMiAxLjYtMTUuNi0xLjYtMjMuMi04YTY4LjMgNjguMyAwIDAgMC0yNC43'
    b'LTEzLjUgMzkuOSAzOS45IDAgMCAwLTI4IDMuNiA4LjcgOC43IDAgMCAxLTIuOCAxLjNjLTEu'
    b'MSAwLTEtNi45LjItOSAxLjUtMyA1LjEtNS44IDkuNC03LjMgMi4yLS44IDQtMS44IDQtMi4z'
    b'IDAtLjQtLjgtMi0xLjctMy42LTIuOS01LjEtMS43LTEwIDMuNC0xMy45IDUuMi00IDE0LTQu'
    b'NiAyMS43LTEuN2EzMiAzMiAwIDAgMCA0IDEuNGMxIDAgLjQtMS41LTIuNC01LjYtMy4yLTQu'
    b'Ny0zLjktNy0zLjUtMTIuN2ExNC43IDE0LjcgMCAwIDEgMTMuNS0xMy41YzUuOC0uNCA5LjQg'
    b'MS42IDE4IDkuN2ExNDQgMTQ0IDAgMCAwIDg2IDQxLjZjOC4zIDEgMjQuOC41IDM0LjUtMWEx'
    b'NTYgMTU2IDAgMCAwIDgxLjgtNDAuOGM2LjQtNiA5LjQtNy42IDE0LjctNy42IDQuNSAwIDcu'
    b'NyAxLjQgMTEgNSAzIDMuMyA0IDYuNCAzLjYgMTEuNS0uMiAzLjItLjcgNC43LTIuNiA3Ljkt'
    b'Mi44IDQuNS0yLjMgNSAzLjIgMi44IDcuNi0zIDE2LjktMS42IDIxLjkgMy4yIDQuNCA0LjIg'
    b'NC44IDguNCAxLjQgMTQtMS4zIDIuMS0yLjMgNC0yLjMgNC40IDAgLjYgMSAuOCA1LjUgMS42'
    b'IDYgMSA5LjUgNS40IDkuNSAxMi4yIDAgMi0uMyAzLjctLjYgMy43cy0yLjYtLjktNS0xLjlj'
    b'LTctMi45LTExLTMuNi0xOS4yLTMuNS02LjIgMC04LjMuMy0xMi42IDEuN2E1Ny41IDU3LjUg'
    b'MCAwIDAtMTkuNSAxMS41Yy02LjQgNS43LTEwLjQgNy41LTE2LjYgNy40LTUuOCAwLTkuNy0x'
    b'LjctMTEuOC01LTEuMS0xLjgtMS4zLTIuOC0xLTYuOC4yLTIuNi4xLTQuNyAwLTQuNy0uMyAw'
    b'LTIuNSAxLjQtNSAzLjFBODAuNSA4MC41IDAgMCAxIDc3OCA1NjBhMTgxLjYgMTgxLjYgMCAw'
    b'IDEtODIuMyA5Ljd6Ii8+CiAgICA8cGF0aCBkPSJNNzA2LjMgNTI1LjJhMTM2LjQgMTM2LjQg'
    b'MCAwIDEtOTcuOS01NS43Yy0yNC40LTMzLjItMzItNzcuMS0yNC42LTExNy4yIDQtMTguMyAx'
    b'Mi0zNi42IDI1LjUtNDkuNmExMTQuNiAxMTQuNiAwIDAgMC04LjcgNzQuM2M5IDQ5LjggNTEg'
    b'OTEuOSAxMDEuMyA5OS4yIDIwIDUuNyA0MC41LS40IDU5LjUtNi41IDQyLTE0LjggNzQtNTQu'
    b'NiA3Ny44LTk5LjEgMy4zLTI0LS4zLTQ5LjEtMTEuMi03MSA2LjIgMy4zIDE0IDE2LjIgMTgu'
    b'NiAyNC44IDE2IDMxIDE2LjcgNjguMSA3LjMgMTAxLjItMTIuOCA0Mi4xLTQ1IDc5LTg3LjUg'
    b'OTIuNGExNjUuNyAxNjUuNyAwIDAgMS02MCA3LjJ6Ii8+CiAgICA8ZyBpZD0iYm4tYSI+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik01MTIgNDY5LjljLTIuNS0uNC01LjMgMi4xLTQuMyA0LjcgMS44IDIu'
    b'NiA1IDQgNy44IDUuMmE1NC4yIDU0LjIgMCAwIDAgMjMuMiAzLjYgNDkuNiA0OS42IDAgMCAw'
    b'IDE3LTNjMy0xIDYuOC0yIDgtNS40IDEuMy0yLjEtMS00LjMtMy4xLTMuOS0zIC43LTYgMi05'
    b'IDIuOWE1Ny43IDU3LjcgMCAwIDEtMjAuMyAyIDU0IDU0IDAgMCAxLTE0LjQtNC4yYy0xLjYt'
    b'LjctMy4xLTEuNy00LjktMS45eiIvPgogICAgICA8cGF0aCBkPSJNNTE0LjggNDU5LjVjLTIu'
    b'NS0uNC00LjcgMi42LTMuNyA1IDIgMi44IDUuMyA0LjMgOC40IDUuNmE0Mi40IDQyLjQgMCAw'
    b'IDAgMTcgMi45aDEuNWEzNy42IDM3LjYgMCAwIDAgMTQuNC0yLjhjMi43LTEuMSA2LjEtMi4y'
    b'IDcuMy01LjIuOS0xLjcuMi00LjEtMi00LjMtMS44IDAtMy41IDEuMi01LjMgMS43YTQ0LjMg'
    b'NDQuMyAwIDAgMS0yMC42IDMuMmMtNC40LS41LTguNS0yLjEtMTIuNS00LTEuNS0uNy0yLjgt'
    b'MS44LTQuNS0yeiIvPgogICAgICA8cGF0aCBkPSJNNTE4LjMgNDQ5LjZjLTIuMi0uMy0zLjcg'
    b'Mi4yLTMuMyA0LjEuMyAxLjggMS44IDMgMy4xIDRhMzAgMzAgMCAwIDAgMTguNiA1LjNoMS42'
    b'YTI4IDI4IDAgMCAwIDEyLTIuOGMyLjUtMSA1LjQtMi4zIDYuMy01LjIuNC0xLjMuNi0zLjIt'
    b'LjktNC0xLjYtLjgtMy4xLjUtNC41IDFhMzQgMzQgMCAwIDEtMTUuNSAzLjkgMjcgMjcgMCAw'
    b'IDEtMTMuMS00Yy0xLjUtLjctMi43LTItNC4zLTIuM3oiLz4KICAgICAgPHBhdGggZD0iTTQ4'
    b'MS41IDMwMi43Yy0zLjIgMy4zLS43IDkuMy0xIDEzLjUgMS44IDEzLjIgMy45IDI2LjUgOC44'
    b'IDM5IDYgMTIgMTguOCAxOC41IDI2LjUgMjkuMiAyLjggNS4xIDEuOCAxMS4zIDIuNCAxNyAu'
    b'NCAxNS4zLjMgMzAuNyAwIDQ2IDcgMy42IDE0LjUgNyAyMi41IDUuNyA0LjctMS4xIDEzLjUt'
    b'MS44IDE0LjUtNi41bC0xLTc5LjVjLTIuNy04LjEtMTEtMTIuMy0xNy4xLTE3LjVhMTU1LjUg'
    b'MTU1LjUgMCAwIDEtMTQuMi0xNi4xYy0yLjYtNC41LTEyLjktNi05LjIgMS42IDIuMiA2Ljcg'
    b'Ny43IDExLjYgOS4xIDE4LjYuMyAzLjkgNSAxMSAxIDEzLjJhMjQuNSAyNC41IDAgMCAwLTEw'
    b'LjctMTBjLTQuNC0zLjMtMTEuNy00LjctMTMuMy0xMC41YTQyLjkgNDIuOSAwIDAgMC0xMS0y'
    b'MmMxLjUtNy40IDAtMTYuNy02LjQtMjEuNWwtLjktLjJ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00'
    b'OTEuNCAzMDQuMmMtMyAuNS0yLjggNC4yLTEuNSA2LjJhMjcuMiAyNy4yIDAgMCAxIDEuMSAx'
    b'My40IDQ0LjEgNDQuMSAwIDAgMSAxMC42IDIxLjdjMCAzIDMuMiA0IDUuMyA1LjUgNC45IDMu'
    b'MSAxMC4zIDUuNCAxNC43IDkuMy45IDEgMS42IDIgMSAwLS43LTIuNi0xLTUuNC0zLTcuMy0y'
    b'LjgtMy02LjItNS42LTEwLjItNi40LS4zLTQuMi0yLjMtOC00LjEtMTEuNi0yLTMuNS00LjEt'
    b'Ny4yLTcuNS05LjQgMC02LjEgMC0xMi41LTIuNi0xOC4yLS44LTEuNC0yLTMuMS0zLjgtMy4y'
    b'eiIvPgogICAgICA8cGF0aCBkPSJNNDk5LjcgMzA2LjZjLTIgLjYtMS42IDMuMi0xIDQuN2E1'
    b'NCA1NCAwIDAgMSAxIDEzLjJjMy45IDMgNi4yIDcuNCA4LjQgMTEuNiAxLjQgMi44IDIuNiA1'
    b'LjggMy4xIDguOSAzLjEgMSA1LjggMyA4LjIgNS0xLTIuOC0zLTUtNC41LTcuN3MtMy01LjYt'
    b'My43LTguN2MtMy0zLjEtNC42LTcuNi00LTEyIC4yLTQuNy0xLjMtOS42LTQuNS0xMy4yLS44'
    b'LS44LTEuOC0xLjctMy0xLjh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MDkuMiAzMDhjLTEuMi4y'
    b'LTEuOCAxLjItMi40IDIuMS0uMy45LjggMS44IDEgMi44YTIxLjggMjEuOCAwIDAgMSAxLjQg'
    b'MTAuNGMtLjEgMi41LjggNSAyIDdhMy45IDMuOSAwIDAgMSAzLjUtMi44Yy41IDAgMS40LjIg'
    b'MS0uNy0uNC00LjgtMS4xLTkuNi0yLjgtMTRhOS42IDkuNiAwIDAgMC0yLjgtNC41Yy0uMi0u'
    b'Mi0uNi0uNC0xLS4zeiIvPgogICAgPC9nPgogICAgPHVzZSB4bGluazpocmVmPSIjYm4tYSIg'
    b'd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEg'
    b'MTQ0MCAwKSIvPgogICAgPHBhdGggZD0iTTcxNS43IDQ3NmEzNS42IDM1LjYgMCAwIDEtMjku'
    b'OS0yNGMuMy0yLjIgMyAxLjIgNC4zIDEuNWExOSAxOSAwIDAgMCA4IDIuNmMzLjUgMS41IDUu'
    b'NyA1IDkuMSA2LjkgMS42IDEuMiA3LjIgMy42IDYuMS0uMy0xLjMtMi0yLjItNC42LTEtNyAx'
    b'LjgtNC4xIDQuNy03LjcgNy43LTExLjIgMi4xLS43IDMuNiAzLjYgNS4xIDUgMi4xIDMuMyA0'
    b'LjcgNy4zIDMuNCAxMS4zLTEuMiAxLjUtMiA2IDEuMyA0LjYgNC0xLjggNy4zLTQuOCAxMC42'
    b'LTcuNiAzLTIgNi43LTIuMSA5LjctNCAxLjUtLjMgNC40LTMuMSA1LTEuNmE0NC45IDQ0Ljkg'
    b'MCAwIDEtNy40IDEyLjMgMzIuMSAzMi4xIDAgMCAxLTE4LjggMTAuOWMtNC40LjgtOC44IDEt'
    b'MTMuMi42eiIvPgogICAgPHBhdGggZD0iTTczMS41IDQ2MC4yYy4zLTIuNy0uMy01LjQtMS43'
    b'LTgtMi4xLTQuMi01LTgtOC0xMS45LTIuOC0xLjYtNC4zIDMuNy02LjEgNS4yLTIuOSA0LjMt'
    b'Ni41IDguNy02LjcgMTQtMS42IDIuNS00LjYtMi01LjktMy41YTE5IDE5IDAgMCAxLTQtMTIg'
    b'NTAuOCA1MC44IDAgMCAxIDMuNi0yMC42YzItNS42IDUuMS0xMSA0LjgtMTcgLjItNC43LS43'
    b'LTkuNy00LjQtMTIuOC0zLjYtMi44IDIuMy0zLjQgNC4xLTIgMy4yLjMgNC45IDUuNSA3Ljgg'
    b'NC4yIDEuMS0yLjcgMS40LTYgMy44LTguMSAyLjMtMy4yIDQuNyAxLjMgNS41IDMuNSAxLjcg'
    b'MS44IDAgNi41IDIuNiA2LjYgMy4yLTIuMyA1LjUtNiA5LjYtNi45IDEuNy0xIDQuNSAwIDIu'
    b'MyAxLjgtMyAyLjktNS42IDYuNC02LjIgMTAuNy0uOSA1LjMuNCAxMC43IDIuNyAxNS40IDQu'
    b'NSA5LjQgOCAyMCA1LjcgMzAuNS0xIDQuNi00LjIgOC42LTggMTEuMy0uNS4zLTEuMy4zLTEu'
    b'NS0uNHoiLz4KICAgIDxwYXRoIGQ9Ik03MjYuNyAzODkuNmEyMS4yIDIxLjIgMCAwIDAtNS42'
    b'LTdjLTIuNCAwLTMuOSAzLTUuNSA0LjYtMS4xIDIuMS0yLjUgNS42LTUuMyAyLjktNC41LTIu'
    b'Ni01LjItOC4zLTUuMi0xMy0uMy03LjYgMi44LTE0LjcgNS41LTIxLjYgMS43LTQuMyAxLjMt'
    b'OS4yLjItMTMuNi0xLjMtNS01LjQtOC42LTguNS0xMi42LjItMS41IDQuMi0uNyA1LjctLjQg'
    b'My40LjkgNS40IDMuOCA3LjkgNiAxLjgtLjYgMS00LjIgMS45LTUuOSAwLTIuNCAzLjItNS41'
    b'IDQuNS0yLjEgMiAyLjIgMCA2LjUgMi41IDcuOCAyLjQtLjkgMy42LTMuNSA1LjgtNC43YTgg'
    b'OCAwIDAgMSA3LjgtLjVjLjkgMi4yLTIuNiA0LTMuNiA2YTIwLjQgMjAuNCAwIDAgMC0zLjgg'
    b'MThjMS40IDUgMy44IDkuNSA0LjcgMTQuNWE0MC4xIDQwLjEgMCAwIDEtLjUgMTcuMmMtLjkg'
    b'My40LTMuOCA1LjYtNi44IDctLjgtLjctMS4yLTEuNy0xLjctMi42eiIvPgogICAgPHBhdGgg'
    b'ZD0iTTcxMS42IDMyNi45Yy0zLjQtMi41LTQuNS00LjgtNC41LTkuNSAwLTIuMy41LTMuNiAy'
    b'LTUuOCAyLjQtMy4yIDItNC4yLTEuMy0zLjMtNS4zIDEuNS03LjguMi04LTQuMyAwLTIuMi40'
    b'LTMuMSAzLjMtNi43IDIuNC0yLjggMy4zLTQuMyAyLjgtNC44LS41LS40LTMuMyAyLTkgNy44'
    b'YTEyNCAxMjQgMCAwIDEtMTEuNCAxMC42Yy05LjggNi42LTE5LjIgNy42LTIzLjUgMi41LTIu'
    b'Mi0yLjYtMi4xLTQgLjQtNS42YTI3LjQgMjcuNCAwIDAgMCA0LjQtMy43IDg2IDg2IDAgMCAx'
    b'IDE2LjEtMTEuNmMzLjYtMS44IDQuNC0zIDIuMS0zLTMgMC0xMi41IDYuMi0xOS44IDEyLjgt'
    b'Mi4xIDItNS4yIDQuMi02LjggNWEyNS40IDI1LjQgMCAwIDEtMTMuOSAxYy0yLjItLjctNi4z'
    b'LTQuNS02LjMtNS45IDAtLjMgMS0xLjEgMi0xLjhhMzAgMzAgMCAwIDAgNC42LTMuMmM1Ljgt'
    b'NSAxNi44LTEwLjMgMjUuNS0xMi4yIDIuOC0uNSAxLjctMi0xLjQtMS44YTU2IDU2IDAgMCAw'
    b'LTI1IDExLjdjLTguMyA2LjktMjAuOCA2LjItMjQuOC0xLjMtLjctMS4zLTEuMi0yLjUtMS0y'
    b'LjdhOTIuOCA5Mi44IDAgMCAwIDIwLjQtNy44IDUxLjUgNTEuNSAwIDAgMSAxOC4xLTYuNWMy'
    b'LjgtLjUgMy0xLjkuMy0yLjItMy42LS40LTkgMS40LTE4LjUgNi0xMi4zIDYuMS0xNS44IDcu'
    b'Mi0yMi4yIDYuOC02LS40LTkuMy0xLjktMTQtNi40LTMuMi0zLTcuNi0xMC41LTYuOC0xMS40'
    b'YTYzLjUgNjMuNSAwIDAgMCAxNS44IDEuM2M4LjMgMCAxMC42LS4yIDE1LTEuNWE4NC4zIDg0'
    b'LjMgMCAwIDAgMjQtMTIuMSA1Ny41IDU3LjUgMCAwIDEgMzYuOC0xMy42YzEyLjQgMCAyMC4y'
    b'IDIuOCAyNy4yIDkuOSAyLjQgMi40IDQuNCAzLjkgNC43IDMuNi4zLS4zLjYtNC41LjctOS4z'
    b'IDAgMCAzLjctLjQgNC41LjcgMCA3LjcgMCA4LjQgMS4yIDguNC43IDAgMS41LS44IDItMiAx'
    b'LTIuNSA1LTYgOS4yLTguMiA5LTQuNSAyNC43LTQuNyAzNy4zLS4zYTYyLjQgNjIuNCAwIDAg'
    b'MSAxNi43IDkuNSA5MC4yIDkwLjIgMCAwIDAgMjQgMTJjNi44IDIgMTkgMi41IDI1LjEgMWE2'
    b'MS45IDYxLjkgMCAwIDEgNS40LTFjMi4zIDAtMS42IDcuNi02LjIgMTIuMS04LjQgOC4yLTE5'
    b'LjMgOC4xLTM0LjYtLjEtOS42LTUuMi0yMS04LTIxLTUuMiAwIC42LjYgMSAxLjUgMSAzLjMg'
    b'MCA5LjcgMi4yIDE4LjcgNi41YTUzLjcgNTMuNyAwIDAgMCAxOC4zIDYuNWMyLjMgMCAyLjQg'
    b'MS41LjIgNC43LTIuMyAzLjQtNi4yIDUtMTEuNyA1LTUuMyAwLTguMy0xLjEtMTMtNS04LTYu'
    b'Ni0yNy42LTE0LTI2LjktMTAgLjIuNyAxLjEgMS4yIDMuMiAxLjVhNTYgNTYgMCAwIDEgMjMu'
    b'MSAxMWw1LjkgNC4zYzEuMS42IDEuMS44LjIgMi41LTEuNCAyLjgtNS4yIDQuOS05LjIgNS4z'
    b'LTUuMi42LTkuOC0xLTE0LjUtNS0xMC04LjMtMTkuMy0xNC4zLTIyLjMtMTQuMy0yLjUgMC0x'
    b'LjQgMS40IDMgMy43YTc5LjcgNzkuNyAwIDAgMSAxNS44IDExYzIgMS45IDQuMyAzLjcgNSA0'
    b'LjEgMS45IDEgMS44IDIuNC0uMiA1cy01LjQgMy44LTkuNyAzLjNjLTguNi0uOS0xNS40LTUt'
    b'MjYtMTZhNzAuNyA3MC43IDAgMCAwLTguMi03LjhjLTEuNCAwLS41IDEuOSAyLjIgNSAzLjQg'
    b'My43IDQgNS44IDIuNyA5LTEuMSAyLjYtMyAzLjMtNi44IDIuMi00LTEtNC42IDAtMiAzLjEg'
    b'My44IDQuOSAzLjMgMTAuNy0xLjUgMTQuOGExMiAxMiAwIDAgMS0zLjQgMi4zYy0uNCAwLTEu'
    b'NC0xLTIuMy0yLjQtMy00LjYtNS43LTQuNi04LjcgMGE1My42IDUzLjYgMCAwIDEtMiAzIDEx'
    b'My4xIDExMy4xIDAgMCAxLTMtMi4yeiIvPgogICAgPHBhdGggZD0ibTcyNi43IDIzMy01LjIg'
    b'NC00LjYtMy40djI3LjhoOS44eiIvPgogICAgPHBhdGggZD0iTTY5NC45IDIwNC4zYTg4LjMg'
    b'ODguMyAwIDAgMS05IDMyLjNsMTEuMS0xMC4zIDcuNyA5LjIgOC40LTkuNCA4LjUgOCA4LjIt'
    b'OC4zIDguNSAxMCA3LjQtOC4yIDEyLjYgOWMtNC42LTEwLTEwLjctMTguNi0xMC0zMi44LTEy'
    b'LjEgOS00MSAxMC42LTUzLjQuNHoiLz4KICAgIDxwYXRoIGQ9Ik03MTcgMTk3LjZjLTQuNSAw'
    b'LTkuMi4xLTEzLjQgMWEyMC4xIDIwLjEgMCAwIDAtNy44IDNjLjMgOC42IDQxIDEyLjEgNTEu'
    b'OS4yYTIwIDIwIDAgMCAwLTguMi0zLjNjLTQtLjgtOC42LS44LTEyLjktMXY3LjFINzE3di03'
    b'eiIvPgogICAgPHBhdGggZD0iTTcyNC45IDE1NGgtNi4zdjQ5LjRoNi40eiIvPgogICAgPHBh'
    b'dGggZD0ibTcyNC45IDE1NS4yLTIuNCAyMy43IDI0LjMgMTEuOS0xMi4zLTE2LjUgMTYuOC01'
    b'LjV6bS0yLjctNi4xYy0zLjcgMC02LjQgMS40LTYuNCAzczIuNyAzIDYuNCAzIDYuNC0xLjQg'
    b'Ni40LTMtMi43LTMtNi40LTN6Ii8+CiAgPC9nPgogIDxnIGZpbGw9IiNmN2UwMTciPgogICAg'
    b'PHBhdGggZD0iTTMxNCAzNzUuOWMyLjctLjkgNC4yLTIuNSA1LjMtNS42LjUtMS42LjktMy4y'
    b'LjgtMy42LS4yLTEtMS40LTEtMi42LjEtLjkuNy0xIDEuMS0uOCAyLjYuNyAzLjctLjcgNC43'
    b'LTcuNyA1LjQtLjcgMC0yLjggMC00LjUtLjMtMy40LS40LTQuNiAwLTMuNCAxYTcgNyAwIDAg'
    b'MCAyLjEuOWMxLjkuNSA4LjguMiAxMC44LS41em0xNC43LS42Yy40LS40IDEuNy0xIDMtMS41'
    b'IDEuNy0uNSAyLjYtMSAzLjMtMi4yIDIuMS0zIDEuNy01LjctMS4zLTkuMy0xLjctMi0yLjQt'
    b'MS45LTMuNy4zLTEuMiAxLjgtMS4xIDIgLjUgMi40LjkuMiAxLjcuOCAyLjEgMS42IDEuOCAz'
    b'LjEgMS4zIDUtMS40IDUtMi40IDAtMyAuNC0zLjcgMmwtLjYgMS45YzAgLjYgMSAuNSAxLjgt'
    b'LjJ6bS00LjgtMy41Yy40LTEuMy42LTMuNS41LThhMzMgMzMgMCAwIDAtLjMtNi40Yy0uNC0u'
    b'NC0yLjMuOC0yLjYgMS43YTMgMyAwIDAgMCAuNSAyLjFjLjYgMS4yLjcgMi40LjUgNy0uMyA2'
    b'IC4xIDcgMS40IDMuNnoiLz4KICAgIDxwYXRoIGQ9Im0zMTIuNiAzNjkgLjctNWMuMS0xLjcu'
    b'NS0zLjguNy00LjcuNy0yLjMgMC0yLjktMS44LTEuNmwtMS4zIDEgLjIgMy4zYy4zIDMtLjIg'
    b'OC41LS45IDEwLjctLjIuNi4xLjQuOS0uNS42LS43IDEuMy0yLjIgMS41LTMuM3ptLTEwIDEu'
    b'NmMyLjQtMiAyLjEtNS42IDIuNy04LjQgMC0xLjkgMS4yLTQuMS40LTUuOC0yLjMuNC0zLjcg'
    b'Mi42LTIuNSA0LjcgMCAyLjUgMCA1LjItMS4zIDcuNC0xIDEuNS00LjQgMS4xLTQuMi0xIC44'
    b'LTMtMi45LTEuNS00LjMtLjctMS4xLjgtMy41LjktMi42LTEtLjYtMi43LTMuOS0xLTUuNy0x'
    b'LTEuNyAwLS4xLTMuNS0yLjYtMy00LjUtLjMtOS41LjEtMTMuNS0yLjYtMi4zLTEuMS0yLTMu'
    b'OS0uNy01LjcgMS40LTIuNCAxLjgtNS41IDQtNy40IDIuMy0yLjEtMi0xLjItMy0uNS0yLjIg'
    b'MS4yLS4yIDQuMy0yIDYtMSAxLjgtMi40IDQuMi00LjggMy45LTMuNS0uNy01LjUtNC04LTYt'
    b'Mi4yLS41LTEgMy40LjIgNC4yYTIxLjkgMjEuOSAwIDAgMCA3LjQgMy42YzIuNi0uNSAyLjcg'
    b'MyA1IDMuNSA0IDIgOC42IDIuNSAxMy4xIDIuOCAxLjguMS44IDMuMyAzLjEgMi42IDEuMy40'
    b'IDQuMy0uNSA0LjQgMS0yIDIuNCAxLjkgMi4zIDMuMyAyIDEuOS0uNCA0LjItMSA0LjcgMS40'
    b'IDEuNSAxLjcgNC4zIDEuNCA2LjIuNWwuNy0uNXoiLz4KICAgIDxwYXRoIGQ9Ik0yNjIuOCAz'
    b'NTAuNGEyMy45IDIzLjkgMCAwIDAgMi40LTQuMiAxNiAxNiAwIDAgMSAyLTMuNmMxLjItMS4y'
    b'LjUtMi0xLjQtMS42LTEgLjItMS40LjYtMS41IDEuNWEyMyAyMyAwIDAgMS0yLjUgN2MtMS43'
    b'IDIuNS0xLjcgMi42LTEgMi42LjMgMCAxLjItLjggMi0xLjd6bS0yNS0xNS43Yy0xLjkgMC0y'
    b'IDEuMi0uMiAxLjggMSAuMyAxLjcgMSAyLjMgMi4zIDEuNyAzLjUgMi44IDQuMiA3LjUgNC42'
    b'bDMgLjIuMiAxLjljMCAxIC4zIDEuOC41IDEuOGwyLjYtMWMyLjItMS4yIDQuMy0zLjggNC4z'
    b'LTUuNSAwLTEtMS44LTIuMi0zLjQtMi4yLS43IDAtMiAuNi0zLjEgMS40LTMuNCAyLjQtNyAy'
    b'LTktMS4yLTEuNS0yLjYtMy4yLTQtNC43LTR6bTE2LjMgNi41Yy45IDAgMSAuNy42IDJhLjku'
    b'OSAwIDAgMS0xLjcgMGMtLjQtMSAuMS0yIDEtMnptMTI2LjUtNGMtMS4zIDAtMS42LjItMi40'
    b'IDEuNC0xLjMgMS45LTEuNCA2LS4yIDcuNC43LjkuOC45IDIuMy4yIDIuMi0uOSAyLjYtLjgg'
    b'Mi41LjMgMCAzLTQuMiA4LjctOC42IDExLjdhOS43IDkuNyAwIDAgMC0yLjQgMmMtLjMuOCAx'
    b'LjMuNyAzLjMtLjRhMjEgMjEgMCAwIDAgNy45LThjMS4xLTIuMyAxLjMtMyAxLjUtNyAwLTMu'
    b'OCAwLTUtLjYtNi4yLS44LTEuNC0xLTEuNS0yLjgtMS41aC0uNXptLjEgMi41YzEgMCAxIC4y'
    b'IDEuMiAxLjYgMCAxLS4xIDEuNy0uNyAyLjMtLjguNy0xIC43LTEuNi0uNC0xLTEuNi0uNC0z'
    b'LjUgMS4xLTMuNXptLTIwLjIgMjguNWMzLjktMiA2LjItNC4xIDcuNi03LjJhMjAgMjAgMCAw'
    b'IDAgMS4zLTMuMWMwLS42LTEuOS0xLjUtMy0xLjVzLTEuNC0uOC0xLTNjLjUtMi4xIDAtNC44'
    b'LTEtNC44LS4zIDAtMSAuNS0xLjMgMS4xLS42IDEtLjcgMS40LS4yIDIuNy43IDIgLjEgMy42'
    b'LTEuNyA0LjktLjkuNi0xLjMgMS4zLTEuMyAybC4xIDEgMi4xLTEgMi0xLjIgMS4xIDFjLjcu'
    b'NCAxLjIgMS4yIDEuMiAxLjcgMCAyLjQtNi44IDYuNC0xMS40IDYuOC0yLjUuMi0zIDAtMy44'
    b'LS44LS43LS43LS45LTEuMy0uNy0ybC41LTIuNmMuNC0yLjEtLjQtMS44LTIgLjYtMS4yIDIt'
    b'MS42IDQuMS0uOSA1LjIuNiAxIDQuNCAxLjggNy4yIDEuNiAxLjcgMCAzLjQtLjUgNS4yLTEu'
    b'NHptMjYtMTQuNWMyLjQtMi41IDMuNS01LjUgMy41LTEwdi0zLjVsMi0xYzIuNy0xLjIgNS4y'
    b'LTMuNyA1LjItNS4xIDAtMS40LS43LTEuNC0xLjguMi0uOSAxLjEtMiAxLjgtNiAzLjctMSAu'
    b'NC0xLjEuNy0xLjQgNS0uMiA1LTEgNi44LTMuNyAxMC4yLTEuNyAyLTEuOCAyLjQtLjYgMi40'
    b'LjUgMCAxLjgtLjkgMi44LTJ6bS0yNi43LTIuOGMuMi0uNy0xLjItMS4yLTEuNy0uNi0uMy4y'
    b'LS40LjYtLjIuOS40LjYgMS42LjQgMS45LS4zem0zNi44LTkuNWMuMy0uOC0xLjEtMS4zLTEu'
    b'Ny0uNy0uMi4zLS4zLjctLjEgMSAuNC42IDEuNi40IDEuOC0uM3ptLTQ0LjMtMjUuOWMtMSAu'
    b'NS0xLjUgMS41LTIuMSAyLjMtLjUuMy0uMS42LjEgMSAxLjcgMS43IDIuNCA0LjIgMy4yIDYu'
    b'NS44IDIuNyAxLjggNS42IDEgOC40LS4zIDEtMS4yIDIuMS0yLjQgMS44LTItLjEtNC0uNy02'
    b'LS43LTEuOS4xLTMuMyAxLjgtNS4xIDEuNi0xLjIgMC0xLjItMi40LTIuMi0xLjctLjYgMS4z'
    b'LS4zIDIuNy0uNCA0IC4yLjMuOC4xIDEuMS4yaDMuN2MuMiAxLjIuMiAyLjcgMSAzLjcgMS4z'
    b'LjQgMi44IDAgNC0uNSAxLjItLjYgMS40LTIuMSAxLjgtMy4zLjQtMS4zIDItMSAzLTEuNWE1'
    b'LjcgNS43IDAgMCAwIDQtNS43Yy0uMi0zLjktMS42LTcuNC0yLjgtMTEtLjUtMS42LS45LTMu'
    b'My0xLjUtNC45bC0uNC0uMnptLTYgMjEuOGMxLjMgMCAxLjkgMS42IDEuNiAyLjctLjUgMS41'
    b'LTIuNC42LTIuNy0uNS0uNy0xLS4zLTIuMyAxLTIuMnoiLz4KICAgIDxwYXRoIGQ9Ik0yOTYg'
    b'MzI0LjhjLS42IDAtMS4zLjItMiAuNy0zLjUgMi41LTQuNSA1LjQtMiA2LjYgMS43LjggMS4z'
    b'IDEuOC0xLjUgMy4yLTQgMi03LjUgMS43LTE0LjItMS0xLjYtLjctMi0uNC0xLjcgMSAuNCAx'
    b'LjUgMS44IDIuMyA1LjEgMyAzLjYgMSA4IC43IDEwLjgtLjVhMTQgMTQgMCAwIDAgNC4zLTMu'
    b'NGwyLjItMi4zIDIuNS4zYzMuMS40IDMuMi40IDMuMiAxLjkgMCAxLjIgMCAxLjIgMi45IDEu'
    b'NWw0LjcuMmMxLjMgMCAyIC4zIDIuNC45LjYuNy45LjggNS42LjQgNC40LS40IDUuMi0uNCA3'
    b'LjIuMyAxLjQuNCAzIC42IDQuMS41IDMuNC0uNCA4LTMuMSA4LjctNS4xIDAtLjMgMS4zLS43'
    b'IDIuNy0xIDMuNC0uNyAzLjUtMS40LjQtMS44YTIyLjkgMjIuOSAwIDAgMS00LjYtMS4xIDEy'
    b'LjIgMTIuMiAwIDAgMC0zLjUtLjljLTEuNyAwLTMuMyAxLTMuMyAyLjIgMCAuNy4yLjggMi4z'
    b'LjYgMS44LS4yIDIuNC0uMSAzLjQuNy43LjUgMS4xIDEuMSAxIDEuMy0uNS44LTQuNSAyLjYt'
    b'Ni4yIDIuOWE0LjcgNC43IDAgMCAxLTMtLjVjLTEuNi0uOC0zLjgtLjktNC4zLS4yLS4yLjMt'
    b'LjYuMS0xLjMtLjVsLTEtMS0yLjQgMWMtMi40IDEtMy4zIDEtMy4zLS4yIDAtLjUtLjctLjYt'
    b'NC4yLS4zLTMuOS4yLTQuMy4xLTUtLjctLjctLjctLjctMS0uMi0xLjcuNC0uOC40LTEgMC0x'
    b'LjUtLjQtLjQtMS0uNC0yLjUgMC0zLjkgMS01IC41LTUtMi41IDAtMS45LTEtMy0yLjMtM3pt'
    b'LTEgMi44Yy4yIDAgLjQuMS43LjQuMy4zLjUgMSAuMyAxLjMtLjMuOS0yIC45LTIuMyAwLS4y'
    b'LS41IDAtMSAuNS0xLjNsLjgtLjR6Ii8+CiAgICA8cGF0aCBkPSJNMjg4IDMzMC40YzIuNC0x'
    b'LjUgMi40LTEuNCAyLjctNS41LjItMyAuMi0zLjItLjYtMy4yLTEuMiAwLTEuOCAxLjMtMS44'
    b'IDMuNyAwIDEuNi0uMiAyLjMtMSAzLTIgMi02LjggMS4xLTcuNS0xLjMtLjItLjguMS0xLjYg'
    b'MS4xLTMgMi4xLTMgMS43LTMuOC0xLTEuNS0xLjcgMS42LTIgMS42LTEuNy4zLjMtMS4zLS4z'
    b'LTEuOC0xLjgtMS40LS43LjItMS4yLjYtMS4zIDEuNi0uMi44LS42IDEuMy0xLjMgMS41LTEu'
    b'Mi4zLTMuMi0uOC0zLjItMS44IDAtLjcgMy00LjQgNi45LTguNCAxLjQtMS41IDIuNi0zIDIu'
    b'Ni0zLjEgMC0uMi0uOC0uNC0xLjctLjQtMS40IDAtMS44LjItMS44LjggMCAuNC0xLjkgMy00'
    b'LjMgNS43LTUgNS42LTUuNCA2LjctMyA4LjJhNiA2IDAgMCAwIDYuNi0uMmwxLjYtMS4xdjJj'
    b'MCAyLjUuNSAzLjUgMi41IDQuNWE4IDggMCAwIDAgOC0uNHptMTA0LjQtMzQuNmMtMS44IDEu'
    b'MS0uNCAzLjQgMCA1LS44IDItMy41IDIuNi01LjUgMy0yLjguNS00LjggMi44LTUuOCA1LjMt'
    b'LjYgMS42LTIgNC0zLjUgMS42LTEuMy0xLjMtMy43LTIuNC01LjItLjgtMS4yIDEuMS0xLjUg'
    b'Mi43LTIgNC4yLS43LTEuMS0xLTIuOC0yLjQtMy4yLTIuNC4zLTEuNSAzLjMtLjQgNC41IDEg'
    b'MS41IDIgMy4zIDEgNS0xIDItNCAzLjQtNS43IDEuNy0xLjYtLjktLjUtNC0yLjItNC4yLS44'
    b'LjYtLjggMy45LTIuMSAyLjEtMS0xLjUtLjQtMy42LTEuNi00LjktMS4zLjItMi40IDIuNS0y'
    b'IDMuNyAxLjggMi40IDIuNiA1LjQgMy4zIDguMy40IDEuMi0uMSAzLjUgMSA0IC43LTEuOSAw'
    b'LTQgLjYtNS45IDEuOC0uMiAzLjcuNiA1LjUuMiAyLjctLjMgNC43LTIuNiA1LjYtNC45LjMt'
    b'MS44IDAtMy42LS4xLTUuNCAyIC40IDQuMi40IDYuMiAxIDEgMS41LS4zIDMuNy0uNiA1LjMt'
    b'MSAzLjQtMy43IDUuOC02LjIgOC0xLjEuNy0xLjIgMi40LjMgMS41YTE1IDE1IDAgMCAwIDcu'
    b'NS04YzEuMS0yLjYuMi01LjUgMS04LjEgMS0yIDMuNS0xLjYgNS40LTEuNiAxLjkgMCAzLjUt'
    b'Mi4zIDIuOS00LjItLjYtMi4yIDEuNy0zLjIgMy4yLTQgMi4xLTEgMy43LTMuMSAzLjUtNS41'
    b'IDAtMS4zIDAtMy42LTEuNy0zLjd6bS03LjMgMTIuNWMyLjIuNi0uNCA0LjgtMS42IDIuMS0u'
    b'NC0xIC41LTIuMSAxLjYtMi4xem0tMTAuMyAzYzIuOS0uMSAxLjggNC0uNiAyLjItMS4zLS43'
    b'LS45LTIuMi42LTIuMnpNMjcwIDMyNy42YzAtLjQtLjItLjctLjYtLjctLjcgMC0xLjIuNy0u'
    b'OSAxLjMuNC43IDEuMy4zIDEuNS0uNnptMzQtMy42YzAtLjctLjMtLjktLjgtLjgtMS4xLjIt'
    b'MS4zIDEuNy0uMSAxLjcuNiAwIC45LS4zLjktMXptLTQyLTIwLjRjLTEuMy0uMy0yLjIuOS0y'
    b'LjcgMi0xIDEuNy0yLjIgMy40LTQgNC4zLTEuMy40LTIuNy0uMS0zLjktLjgtMS4zLS43LTEt'
    b'Mi4zLTEuNi0zLjQtMS0uOC0yLjcuMy0yLjYgMS41LS4xIDEuNiAxLjMgMi41IDIuNiAzLjEg'
    b'MSAuNyAyLjYgMSAzIDIuMyAwIDEuMS40IDIuNCAxLjcgMiAxLjUgMCAyIDEuOCAxLjMgMi45'
    b'YTYuMyA2LjMgMCAwIDAtLjcgNGMuNy43IDEuNC0xIDItMS40bDEtMS40YzIuNy4xIDUuMy41'
    b'IDggLjQgMiAwIDMuNS0xLjIgNC43LTIuNiAxLjgtMS44IDMuMi0zLjkgNS4xLTUuNCAxLjQt'
    b'LjQuNy0zLS44LTIuMi0xLjMuNS0xLjcgMi0yLjYgMi45YTMxIDMxIDAgMCAxLTUgNS4yYy0x'
    b'LjUuNi0zLjEuMy00LjYgMC0uNi0uNSAxLjItMSAxLjUtMS42LjgtLjggMS44LTEuNiAyLjMt'
    b'Mi43LS41LTEtMS45LTEtMi45LTEtMi40LjItNC4zIDIuMy02LjggMi41LTEuOSAwLS45LTIg'
    b'MC0yLjcgMS42LTIgMy40LTMuOCA1LjEtNS43LjUtLjYgMi4zLTEuMiAxLjItMi0uNC0uMi0u'
    b'OS0uMi0xLjMtLjJ6bTEuMiAxMGMxLjMuNy0uOCAxLjgtMS42IDEuNy0xLjEuMy0xLjItLjgt'
    b'LjItMSAuNi0uNCAxLjItLjcgMS44LS43em0tMy44IDIuNmMuNyAwIDIuMi43LjggMS4xLTEg'
    b'LjgtMi0uOC0uOC0xLjF6Ii8+CiAgICA8cGF0aCBkPSJNMjg5LjQgMzE3LjhjMC0xLTEuNi0u'
    b'OC0xLjguMi0uMi42IDAgLjcuOC42LjYgMCAxLS40IDEtLjh6bTc0LjctNi42Yy4yLS45LTEt'
    b'MS41LTEuNy0uOC0uNy42IDAgMS45LjggMS43LjQgMCAuOC0uNSAxLS45ek0yNDggMzAyLjFj'
    b'MS4xLTEgMS4yLTEuMS43LTMuMy0uOC0zLjEtLjctMy41LjUtMy44IDEuNS0uMyA1LjMgMS43'
    b'IDYgMy4zLjggMS4zLjcgMS40LS40IDIuNC0xLjIgMS4xLTEuMiAyLjQgMCAyLjQgMSAwIDMu'
    b'Ny0yLjYgMy43LTMuNSAwLTEuMy0zLTQuNC01LjQtNS41YTEwLjcgMTAuNyAwIDAgMC00LjYt'
    b'MWMtMy4xIDAtMy41LjctMi43IDQuMiAxIDQuMi0uMyA0LjgtMy43IDEuNmExMC40IDEwLjQg'
    b'MCAwIDEtMy41LTguNmMwLTQgMS42LTYuMSA1LjEtNi42IDIuNC0uMyAyLjMtLjkgMC0xLjIt'
    b'My42LS42LTYuNiAxLjgtNy43IDYtMS4zIDQuNyAxLjYgMTAuNCA2LjcgMTMuMyAyLjcgMS41'
    b'IDMuNyAxLjYgNS4zLjN6bTEzOS4yLTUuMmMuMy0uMi41LS45LjUtMS40cy41LTEuNiAxLjEt'
    b'Mi40Yy42LS44IDEtMS42IDEtMS44IDAtLjgtMS4zLS44LTIuMyAwLTEuMS45LTIgMS0yIDBs'
    b'MS4yLS45YzEuNi0uNyAxLjctMS41LjQtMi4xLTEuNy0uOC0zLjUuNi0zLjYgMy0uMSAxLjYg'
    b'MCAxLjggMS4yIDIuNSAxLjEuNyAxLjMgMSAxLjEgMi0uMyAxLjYuNCAyLjIgMS40IDEuMXpt'
    b'MTMtMS40YzEtMSAxLjgtMS45IDEuOC0yLjIgMC0uMy45LTEuMiAxLjktMiAyLjgtMiAzLjUt'
    b'NCAyLjItNy4zLS41LTEuMy0yLTMtNS41LTZhMjYgMjYgMCAwIDAtNS40LTQuNGMtLjkgMC0u'
    b'NyAzLjQuMiAzLjcgMS43LjYgMi44IDEuMyA1LjQgMy43IDMuMiAyLjggNC42IDUuNSAzLjgg'
    b'Ny0uNyAxLjQtMS43IDEtNC41LTJhMTMuOCAxMy44IDAgMCAwLTMuMi0yLjljLS4zIDAtLjUu'
    b'Ni0uNSAxLjQgMCAxIC41IDIgMiAzLjUgMi4zIDIuNiAyLjUgNC4xLjcgNS41YTUgNSAwIDAg'
    b'MS0xLjQgMSAzMy4yIDMzLjIgMCAwIDAtOS0xMGMtLjMgMC0uNS40LS41IDEuNCAwIDEuMy4y'
    b'IDEuNyAxLjIgMi4yYTM4IDM4IDAgMCAxIDcgN2wxLjggMmE5IDkgMCAwIDAgMi0xLjd6bTYt'
    b'MTYuOGMtLjUtMS4yLTguNC05LjQtOS4zLTkuNC0uNCAwLS41LjUtLjQgMS44IDAgMS42LjMg'
    b'MS44IDEuNCAyLjFhMjAgMjAgMCAwIDEgNC42IDMuNyAxNyAxNyAwIDAgMCAzLjcgM3YtMS4y'
    b'em0tNDcuOCA5Mi42YTEuMiAxIDAgMSAxLTIuMyAwIDEuMiAxIDAgMSAxIDIuMyAwem00LjIt'
    b'MS40YTEuMiAxIDAgMSAxLTIuNCAwIDEuMiAxIDAgMSAxIDIuNCAweiIvPgogIDwvZz4KPC9z'
    b'dmc+Cg==', 'BN')

BN = b64_BN
index.append("BN")
index.append("BRN")
index.append("Brunei Darussalam")
catalog["BN"] = BN
catalog["BRN"] = BN
catalog["Brunei Darussalam"] = BN
country["Brunei Darussalam"] = ('BN', 'BRN', 0)
lookup["BN"] = ('BN', 'BRN', 'Brunei Darussalam', 0)
lookup["Bandar Seri Begawan Brunei Darussalam"] = ('BN', 'BRN', 'Brunei Darussalam', 0)
lookup["BRN"] = ('BN', 'BRN', 'Brunei Darussalam', 0)
lookup["Brunei Darussalam"] = ('BN', 'BRN', 'Brunei Darussalam', 0)
details["BN"] = {"continent":"Asia","capital":"Bandar Seri Begawan","currency":"Brunei Dollar","web":".bn","lang":"ms-BN | en-BN","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_BO = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMTAwIiBoZWlnaHQ9Ijc1MCI+DQo8'
    b'cmVjdCBmaWxsPSIjMDA3OTM0IiB3aWR0aD0iMTEwMCIgaGVpZ2h0PSI3NTAiLz4NCjxyZWN0'
    b'IGZpbGw9IiNGOUUzMDAiIHdpZHRoPSIxMTAwIiBoZWlnaHQ9IjUwMCIvPg0KCjxyZWN0IGZp'
    b'bGw9IiNENTJCMUUiIHdpZHRoPSIxMTAwIiBoZWlnaHQ9IjI1MCIvPgoNCjwvc3ZnPg==', 'BO')

BO = b64_BO
index.append("BO")
index.append("BOL")
index.append("Bolivia")
catalog["BO"] = BO
catalog["BOL"] = BO
catalog["Bolivia"] = BO
country["Bolivia"] = ('BO', 'BOL', 0)
lookup["BO"] = ('BO', 'BOL', 'Bolivia', 0)
lookup["Sucre Bolivia"] = ('BO', 'BOL', 'Bolivia', 0)
lookup["BOL"] = ('BO', 'BOL', 'Bolivia', 0)
lookup["Bolivia"] = ('BO', 'BOL', 'Bolivia', 0)
details["BO"] = {"continent":"Americas","capital":"Sucre","currency":"Boliviano","web":".bo","lang":"es-BO | qu | ay","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_BQ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJxIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzIxNDY4YiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MzIw'
    b'SDB6Ii8+CiAgPHBhdGggZmlsbD0iI2FlMWMyOCIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+Cjwv'
    b'c3ZnPgo=', 'BQ')

BQ = b64_BQ
index.append("BQ")
index.append("BES")
index.append("Bonaire Sint Eustatius Saba")
catalog["BQ"] = BQ
catalog["BES"] = BQ
catalog["Bonaire Sint Eustatius Saba"] = BQ
country["Bonaire Sint Eustatius Saba"] = ('BQ', 'BES', 0)
lookup["BQ"] = ('BQ', 'BES', 'Bonaire Sint Eustatius Saba', 0)
lookup["BES"] = ('BQ', 'BES', 'Bonaire Sint Eustatius Saba', 0)
lookup["Bonaire Sint Eustatius Saba"] = ('BQ', 'BES', 'Bonaire Sint Eustatius Saba', 0)
details["BQ"] = {"continent":"Americas","capital":"","currency":"US Dollar","web":".bq","lang":"nl | pap | en","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_BR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgc3Ryb2tlLXdpZHRoPSIxcHQiPgog'
    b'ICAgPHBhdGggZmlsbD0iIzIyOWU0NSIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMCAwaDY0'
    b'MHY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmOGU1MDkiIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgZD0ibTMyMS40IDQzNiAzMDEuNS0xOTUuN0wzMTkuNiA0NCAxNy4xIDI0MC43IDMyMS40'
    b'IDQzNnoiLz4KICAgIDxwYXRoIGZpbGw9IiMyYjQ5YTMiIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'ZD0iTTQ1Mi44IDI0MGMwIDcwLjMtNTcuMSAxMjcuMy0xMjcuNiAxMjcuM0ExMjcuNCAxMjcu'
    b'NCAwIDEgMSA0NTIuOCAyNDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmZmVmIiBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGQ9Im0yODMuMyAzMTYuMy00LTIuMy00IDIgLjktNC41LTMuMi0zLjQg'
    b'NC41LS41IDIuMi00IDEuOSA0LjIgNC40LjgtMy4zIDNtODYgMjYuMy0zLjktMi4zLTQgMiAu'
    b'OC00LjUtMy4xLTMuMyA0LjUtLjUgMi4xLTQuMSAyIDQuMiA0LjQuOC0zLjQgMy4xbS0zNi4y'
    b'LTMwLTMuNC0yLTMuNSAxLjguOC0zLjktMi44LTIuOSA0LS40IDEuOC0zLjYgMS42IDMuNyAz'
    b'LjkuNy0zIDIuN204Ny04LjUtMy40LTItMy41IDEuOC44LTMuOS0yLjctMi44IDMuOS0uNCAx'
    b'LjgtMy41IDEuNiAzLjYgMy44LjctMi45IDIuNm0tODcuMy0yMi00LTIuMi00IDIgLjgtNC42'
    b'LTMuMS0zLjMgNC41LS41IDIuMS00LjEgMiA0LjIgNC40LjgtMy40IDMuMm0tMTA0LjYtMzUt'
    b'NC0yLjItNCAyIDEtNC42LTMuMy0zLjMgNC42LS41IDItNC4xIDIgNC4yIDQuNC44LTMuMyAz'
    b'LjFtMTMuMyA1Ny4yLTQtMi4zLTQgMiAuOS00LjUtMy4yLTMuMyA0LjUtLjYgMi4xLTQgMiA0'
    b'LjIgNC40LjgtMy4zIDMuMW0xMzItNjcuMy0zLjYtMi0zLjYgMS44LjgtNC0yLjgtMyA0LS41'
    b'IDEuOS0zLjYgMS43IDMuOCA0IC43LTMgMi43bS02LjcgMzguMy0yLjctMS42LTIuOSAxLjQu'
    b'Ni0zLjItMi4yLTIuMyAzLjItLjQgMS41LTIuOCAxLjMgMyAzIC41LTIuMiAyLjJtLTE0Mi4y'
    b'IDUwLjQtMi43LTEuNS0yLjcgMS4zLjYtMy0yLjEtMi4yIDMtLjQgMS40LTIuNyAxLjMgMi44'
    b'IDMgLjYtMi4zIDJNNDE5IDI5OS44bC0yLjItMS4xLTIuMiAxIC41LTIuMy0xLjctMS42IDIu'
    b'NC0uMyAxLjItMiAxIDIgMi41LjUtMS45IDEuNSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZmZl'
    b'ZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtMjE5LjMgMjg3LjYtMi43LTEuNS0yLjcgMS4z'
    b'LjYtMy0yLjEtMi4yIDMtLjQgMS40LTIuNyAxLjMgMi44IDMgLjYtMi4zIDIiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmZmZWYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTIxOS4zIDI4Ny42'
    b'LTIuNy0xLjUtMi43IDEuMy42LTMtMi4xLTIuMiAzLS40IDEuNC0yLjcgMS4zIDIuOCAzIC42'
    b'LTIuMyAybTQyLjMgMy0yLjYtMS40LTIuNyAxLjMuNi0zLTIuMS0yLjIgMy0uNCAxLjQtMi43'
    b'IDEuMyAyLjggMyAuNS0yLjMgMi4xbS00LjggMTctMi42LTEuNS0yLjcgMS40LjYtMy0yLjEt'
    b'Mi4zIDMtLjQgMS40LTIuNyAxLjMgMi44IDMgLjYtMi4zIDJtODcuNC0yMi4yLTIuNi0xLjYt'
    b'Mi44IDEuNC42LTMtMi0yLjMgMy0uMyAxLjQtMi43IDEuMiAyLjggMyAuNS0yLjIgMi4xbS0y'
    b'NS4xIDMtMi43LTEuNS0yLjcgMS40LjYtMy0yLTIuMyAzLS4zIDEuNC0yLjggMS4yIDIuOSAz'
    b'IC41LTIuMiAyLjFtLTY4LjgtNS44LTEuNy0xLTEuNy44LjQtMS45LTEuMy0xLjQgMS45LS4y'
    b'LjgtMS43LjggMS44IDEuOS4zLTEuNCAxLjNtMTY3LjggNDUuNC0yLjYtMS41LTIuNyAxLjQu'
    b'Ni0zLTIuMS0yLjMgMy0uNCAxLjQtMi43IDEuMyAyLjggMyAuNi0yLjMgMm0tMjAuOCA2LTIu'
    b'Mi0xLjQtMi4zIDEuMi41LTIuNi0xLjctMS44IDIuNS0uMyAxLjItMi4zIDEgMi40IDIuNS40'
    b'LTEuOSAxLjhtMTAuNCAyLjMtMi0xLjItMi4xIDEgLjQtMi4zLTEuNi0xLjcgMi4zLS4zIDEu'
    b'MS0yIDEgMiAyLjMuNS0xLjcgMS42bTI5LjEtMjIuOC0yLTEtMiAxIC41LTIuMy0xLjYtMS43'
    b'IDIuMy0uMyAxLTIgMSAyLjEgMi4xLjQtMS42IDEuNm0tMzguOCA0MS44LTIuNS0xLjQtMi43'
    b'IDEuMi42LTIuOC0yLTIgMy0uMyAxLjMtMi41IDEuMiAyLjYgMyAuNS0yLjMgMS45bS42IDE0'
    b'LjItMi40LTEuNC0yLjQgMS4zLjYtMi44LTEuOS0yIDIuNy0uNCAxLjItMi41IDEuMSAyLjYg'
    b'Mi43LjUtMiAybS0xOS0yMy4xLTEuOS0xLjItMiAxIC40LTIuMi0xLjUtMS43IDIuMi0uMiAx'
    b'LTIgMSAyIDIuMi40LTEuNiAxLjZtLTE3LjggMi4zLTItMS4yLTIgMSAuNS0yLjItMS42LTEu'
    b'NyAyLjMtLjIgMS0yIDEgMiAyLjEuNC0xLjYgMS42bS0zMC40LTI0LjYtMi0xLjEtMiAxIC41'
    b'LTIuMy0xLjYtMS42IDIuMi0uMyAxLTIgMSAyIDIuMi41LTEuNiAxLjVtMy43IDU3LTEuNi0u'
    b'OS0xLjguOS40LTItMS4zLTEuNCAxLjktLjIuOS0xLjcuOCAxLjggMS45LjMtMS40IDEuM20t'
    b'NDYuMi04Ni42LTQtMi4zLTQgMiAuOS00LjUtMy4yLTMuMyA0LjUtLjYgMi4yLTQgMS45IDQu'
    b'MiA0LjQuOC0zLjMgMy4xIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIGQ9Ik00NDQuNCAyODUuOGExMjQuNiAxMjQuNiAwIDAgMCA1LjgtMTkuOGMtNjcu'
    b'OC01OS41LTE0My4zLTkwLTIzOC43LTgzLjdhMTI0LjUgMTI0LjUgMCAwIDAtOC41IDIwLjlj'
    b'MTEzLTEwLjggMTk2IDM5LjIgMjQxLjQgODIuNnoiLz4KICAgIDxwYXRoIGZpbGw9IiMzMDll'
    b'M2EiIGQ9Im00MTQgMjUyLjQgMi4zIDEuM2EzLjQgMy40IDAgMCAwLS4zIDIuMiAzIDMgMCAw'
    b'IDAgMS40IDEuN2MuNy41IDEuNC44IDIgLjcuNiAwIDEtLjMgMS4zLS43YTEuMyAxLjMgMCAw'
    b'IDAgLjItLjkgMi4zIDIuMyAwIDAgMC0uNS0xYy0uMi0uMy0uNy0xLTEuNS0xLjhhNy43IDcu'
    b'NyAwIDAgMS0xLjgtMyAzLjcgMy43IDAgMCAxIDItNC40IDMuOCAzLjggMCAwIDEgMi4zLS4y'
    b'IDcgNyAwIDAgMSAyLjYgMS4yYzEuNCAxIDIuMyAyIDIuNiAzLjJhNC4xIDQuMSAwIDAgMS0u'
    b'NiAzLjNsLTIuNC0xLjVjLjMtLjYuNC0xLjIuMi0xLjctLjEtLjUtLjUtMS0xLjItMS40YTMu'
    b'MiAzLjIgMCAwIDAtMS44LS43IDEgMSAwIDAgMC0uOS41Yy0uMi4zLS4yLjYtLjEgMXMuNiAx'
    b'LjIgMS42IDIuMmMxIDEgMS42IDEuOSAyIDIuNWEzLjkgMy45IDAgMCAxLS4zIDQuMiA0LjEg'
    b'NC4xIDAgMCAxLTEuOSAxLjUgNCA0IDAgMCAxLTIuNC4zYy0uOS0uMi0xLjgtLjYtMi44LTEu'
    b'My0xLjUtMS0yLjQtMi4xLTIuNy0zLjNhNS40IDUuNCAwIDAgMSAuNi00em0tMTEuNi03LjYg'
    b'Mi41IDEuM2EzLjQgMy40IDAgMCAwLS4yIDIuMiAzIDMgMCAwIDAgMS40IDEuNmMuOC41IDEu'
    b'NC43IDIgLjYuNiAwIDEtLjMgMS4zLS44YTEuMyAxLjMgMCAwIDAgLjItLjhjMC0uMy0uMi0u'
    b'Ny0uNS0xYTM0LjYgMzQuNiAwIDAgMC0xLjYtMS44Yy0xLjEtMS4xLTEuOC0yLTItMi44YTMu'
    b'NyAzLjcgMCAwIDEgLjQtMy4xIDMuNiAzLjYgMCAwIDEgMS42LTEuNCAzLjggMy44IDAgMCAx'
    b'IDIuMi0uMyA3IDcgMCAwIDEgMi42IDFjMS41IDEgMi40IDIgMi43IDMuMWE0LjEgNC4xIDAg'
    b'MCAxLS40IDMuNGwtMi41LTEuNGMuMy0uNy40LTEuMi4yLTEuN3MtLjYtMS0xLjMtMS40YTMu'
    b'MiAzLjIgMCAwIDAtMS45LS42IDEgMSAwIDAgMC0uOC41Yy0uMi4zLS4yLjYtLjEgMXMuNyAx'
    b'LjIgMS43IDIuMmMxIDEgMS43IDEuOCAyIDIuNGEzLjkgMy45IDAgMCAxIDAgNC4yIDQuMiA0'
    b'LjIgMCAwIDEtMS44IDEuNiA0IDQgMCAwIDEtMi40LjMgOCA4IDAgMCAxLTIuOS0xLjEgNiA2'
    b'IDAgMCAxLTIuOC0zLjIgNS40IDUuNCAwIDAgMSAuNC00em0tMTQuMi0zLjggNy4zLTEyIDgu'
    b'OCA1LjUtMS4yIDItNi40LTQtMS42IDIuNyA2IDMuNy0xLjMgMi02LTMuNy0yIDMuMyA2Ljcg'
    b'NC0xLjIgMi05LTUuNXptLTIwLjctMTcgMS4xLTIgNS40IDIuNy0yLjUgNWMtLjguMi0xLjgu'
    b'My0zIC4yYTkuNCA5LjQgMCAwIDEtMy4zLTEgNy43IDcuNyAwIDAgMS0zLTIuNiA2IDYgMCAw'
    b'IDEtMS0zLjUgOC42IDguNiAwIDAgMSAxLTMuNyA4IDggMCAwIDEgMi42LTMgNi4yIDYuMiAw'
    b'IDAgMSAzLjYtMS4xYzEgMCAyIC4zIDMuMiAxIDEuNi43IDIuNiAxLjcgMy4xIDIuOGE1IDUg'
    b'MCAwIDEgLjMgMy41bC0yLjctLjhhMyAzIDAgMCAwLS4yLTJjLS4zLS42LS44LTEtMS42LTEu'
    b'NGEzLjggMy44IDAgMCAwLTMuMS0uM2MtMSAuMy0xLjkgMS4yLTIuNiAyLjYtLjcgMS40LTEg'
    b'Mi43LS43IDMuOGEzLjcgMy43IDAgMCAwIDIgMi40Yy41LjMgMS4xLjUgMS43LjVhNiA2IDAg'
    b'MCAwIDEuOCAwbC44LTEuNi0yLjktMS41em0tOTAuMi0yMi4zIDItMTQgNC4yLjcgMS4xIDku'
    b'OCAzLjktOSA0LjIuNi0yIDEzLjgtMi43LS40IDEuNy0xMC45LTQuNCAxMC41LTIuNy0uNC0x'
    b'LjEtMTEuMy0xLjYgMTEtMi42LS40em0tMTQuMS0xLjcgMS4zLTE0IDEwLjMgMS0uMiAyLjQt'
    b'Ny41LS43LS4zIDMgNyAuNy0uMyAyLjQtNy0uNy0uMyAzLjggNy44LjctLjIgMi40LTEwLjYt'
    b'MXoiLz4KICAgIDxnIHN0cm9rZS1vcGFjaXR5PSIuNSI+CiAgICAgIDxwYXRoIGZpbGw9IiMz'
    b'MDllM2EiIGQ9Ik0yMTYuNSAxOTEuM2MwLTEuNS4zLTIuNi43LTMuNmE2LjcgNi43IDAgMCAx'
    b'IDEuNC0xLjkgNS40IDUuNCAwIDAgMSAxLjgtMS4yYzEtLjMgMi0uNSAzLS41IDIuMSAwIDMu'
    b'Ny44IDUgMmE3LjQgNy40IDAgMCAxIDEuNiA1LjVjMCAyLjItLjcgNC0yIDUuM2E2LjUgNi41'
    b'IDAgMCAxLTUgMS43IDYuNiA2LjYgMCAwIDEtNC44LTIgNy4zIDcuMyAwIDAgMS0xLjctNS4z'
    b'eiIvPgogICAgICA8cGF0aCBmaWxsPSIjZjdmZmZmIiBkPSJNMjE5LjQgMTkxLjNjMCAxLjUu'
    b'MyAyLjcgMSAzLjYuNy44IDEuNiAxLjMgMi44IDEuM2EzLjUgMy41IDAgMCAwIDIuOC0xLjFj'
    b'LjctLjggMS0yIDEuMS0zLjcgMC0xLjYtLjItMi44LTEtMy42YTMuNSAzLjUgMCAwIDAtMi43'
    b'LTEuMyAzLjYgMy42IDAgMCAwLTIuOCAxLjJjLS44LjgtMS4xIDItMS4yIDMuNnoiLz4KICAg'
    b'IDwvZz4KICAgIDxnIHN0cm9rZS1vcGFjaXR5PSIuNSI+CiAgICAgIDxwYXRoIGZpbGw9IiMz'
    b'MDllM2EiIGQ9Im0yMzMgMTk4LjUuMi0xNGg2YzEuNSAwIDIuNS4yIDMuMi41LjcuMiAxLjIu'
    b'NyAxLjYgMS4zcy42IDEuNC42IDIuM2EzLjggMy44IDAgMCAxLTEgMi42IDQuNSA0LjUgMCAw'
    b'IDEtMi43IDEuMmwxLjUgMS4yYy40LjQuOSAxLjIgMS41IDIuM2wxLjcgMi44aC0zLjRsLTIt'
    b'My4yLTEuNC0yYTIuMSAyLjEgMCAwIDAtLjktLjYgNSA1IDAgMCAwLTEuNC0uMmgtLjZ2NS44'
    b'SDIzM3oiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTIzNiAxOTAuNWgyYzEuNCAw'
    b'IDIuMyAwIDIuNi0uMi4zIDAgLjYtLjMuOC0uNXMuMy0uNy4zLTFjMC0uNi0uMS0xLS40LTEu'
    b'Mi0uMi0uMy0uNi0uNS0xLS42aC0ybC0yLjMtLjF2My41eiIvPgogICAgPC9nPgogICAgPGcg'
    b'c3Ryb2tlLW9wYWNpdHk9Ii41Ij4KICAgICAgPHBhdGggZmlsbD0iIzMwOWUzYSIgZD0ibTI0'
    b'OSAxODUuMiA1LjIuM2MxLjEgMCAyIC4xIDIuNi4zYTQuNyA0LjcgMCAwIDEgMiAxLjQgNiA2'
    b'IDAgMCAxIDEuMiAyLjRjLjMuOS40IDIgLjMgMy4zYTkuMyA5LjMgMCAwIDEtLjUgM2MtLjQg'
    b'MS0xIDEuOC0xLjcgMi40YTUgNSAwIDAgMS0yIDFjLS42LjItMS41LjItMi41LjJsLTUuMy0u'
    b'My43LTE0eiIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMjUxLjcgMTg3LjctLjUg'
    b'OS4zaDMuOGMuNSAwIC45LS4yIDEuMi0uNS4zLS4zLjYtLjcuOC0xLjMuMi0uNi40LTEuNS40'
    b'LTIuNmwtLjEtMi41YTMuMiAzLjIgMCAwIDAtLjgtMS40IDIuNyAyLjcgMCAwIDAtMS4yLS43'
    b'IDEzIDEzIDAgMCAwLTIuMy0uM2gtMS4zeiIvPgogICAgPC9nPgogICAgPGcgc3Ryb2tlLW9w'
    b'YWNpdHk9Ii41Ij4KICAgICAgPHBhdGggZmlsbD0iIzMwOWUzYSIgZD0ibTMxNy42IDIxMC4y'
    b'IDMuMy0xMy42IDQuNCAxIDMuMiAxYy43LjQgMS4zIDEgMS42IDEuOS40LjguNCAxLjcuMiAy'
    b'LjgtLjIuOC0uNSAxLjUtMSAyYTMuOSAzLjkgMCAwIDEtMyAxLjRjLS43IDAtMS43LS4yLTMt'
    b'LjVsLTEuNy0uNS0xLjIgNS4yLTIuOC0uN3oiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZD0ibTMyMyAxOTkuNi0uOCAzLjggMS41LjRjMSAuMiAxLjguNCAyLjIuM2ExLjkgMS45IDAg'
    b'MCAwIDEuNi0xLjVjMC0uNSAwLS45LS4yLTEuM2EyIDIgMCAwIDAtMS0uOWwtMS45LS41LTEu'
    b'My0uM3oiLz4KICAgIDwvZz4KICAgIDxnIHN0cm9rZS1vcGFjaXR5PSIuNSI+CiAgICAgIDxw'
    b'YXRoIGZpbGw9IiMzMDllM2EiIGQ9Im0zMzAuNiAyMTQuMSA0LjctMTMuMiA1LjUgMmMxLjUu'
    b'NSAyLjQgMSAzIDEuNC41LjUuOSAxIDEgMS44cy4yIDEuNSAwIDIuM2MtLjQgMS0xIDEuNy0x'
    b'LjggMi4yLS44LjQtMS44LjUtMyAuMy40LjUuOCAxIDEgMS42bC44IDIuNy42IDMuMS0zLjEt'
    b'MS4xLTEtMy42YTE5LjUgMTkuNSAwIDAgMC0uNy0yLjQgMi4xIDIuMSAwIDAgMC0uNi0uOGMt'
    b'LjItLjMtLjYtLjUtMS4zLS43bC0uNS0uMi0yIDUuNi0yLjYtMXoiLz4KICAgICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZiIgZD0ibTMzNiAyMDcuNCAxLjkuN2MxLjMuNSAyLjEuNyAyLjUuNy4zIDAg'
    b'LjYgMCAuOS0uMy4zLS4yLjUtLjUuNi0uOS4yLS40LjItLjggMC0xLjJhMS43IDEuNyAwIDAg'
    b'MC0uOC0uOWwtMi0uNy0yLS43LTEuMiAzLjN6Ii8+CiAgICA8L2c+CiAgICA8ZyBzdHJva2Ut'
    b'b3BhY2l0eT0iLjUiPgogICAgICA8cGF0aCBmaWxsPSIjMzA5ZTNhIiBkPSJNMzQ3IDIxMy42'
    b'YTkgOSAwIDAgMSAxLjctMy4yIDYuNiA2LjYgMCAwIDEgMS44LTEuNSA2IDYgMCAwIDEgMi0u'
    b'N2MxIDAgMiAwIDMuMS40YTYuNSA2LjUgMCAwIDEgNC4yIDMuM2MuOCAxLjYuOCAzLjUuMiA1'
    b'LjdhNy40IDcuNCAwIDAgMS0zLjQgNC41Yy0xLjUuOS0zLjMgMS01LjIuNGE2LjYgNi42IDAg'
    b'MCAxLTQuMi0zLjMgNy4zIDcuMyAwIDAgMS0uMi01LjZ6Ii8+CiAgICAgIDxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Ik0zNDkuOCAyMTQuNGMtLjQgMS41LS41IDIuOCAwIDMuOHMxLjIgMS42IDIu'
    b'MyAyYzEgLjMgMiAuMiAzLS40IDEtLjUgMS42LTEuNiAyLjEtMy4yLjUtMS41LjUtMi43IDAt'
    b'My43YTMuNSAzLjUgMCAwIDAtMi4yLTIgMy42IDMuNiAwIDAgMC0zIC4zYy0xIC42LTEuNyAx'
    b'LjYtMi4yIDMuMnoiLz4KICAgIDwvZz4KICAgIDxnIHN0cm9rZS1vcGFjaXR5PSIuNSI+CiAg'
    b'ICAgIDxwYXRoIGZpbGw9IiMzMDllM2EiIGQ9Im0zNzQuMyAyMzMuMSA2LjQtMTIuNCA1LjMg'
    b'Mi43YTEwIDEwIDAgMCAxIDIuNyAxLjljLjUuNS44IDEuMS44IDEuOXMwIDEuNS0uNCAyLjJh'
    b'My44IDMuOCAwIDAgMS0yIDJjLTEgLjItMiAuMi0zLjEtLjIuNC42LjYgMS4yLjggMS43LjIu'
    b'Ni4zIDEuNS40IDIuOGwuMiAzLjItMy0xLjUtLjQtMy43YTIwIDIwIDAgMCAwLS4zLTIuNSAy'
    b'IDIgMCAwIDAtLjUtMWwtMS4yLS43LS41LS4zLTIuNyA1LjItMi41LTEuM3oiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0ibTM4MC41IDIyNy4yIDEuOSAxYzEuMi42IDIgMSAyLjMg'
    b'MSAuMyAwIC43IDAgMS0uMi4zLS4xLjUtLjQuNy0uOC4yLS40LjMtLjguMi0xLjJhMiAyIDAg'
    b'MCAwLS43LTEgMjMuNyAyMy43IDAgMCAwLTEuOC0xbC0yLTEtMS42IDMuMnoiLz4KICAgIDwv'
    b'Zz4KICAgIDxnIHN0cm9rZS1vcGFjaXR5PSIuNSI+CiAgICAgIDxwYXRoIGZpbGw9IiMzMDll'
    b'M2EiIGQ9Ik00MjYuMSAyNTguN2E4LjkgOC45IDAgMCAxIDIuNS0yLjYgNi42IDYuNiAwIDAg'
    b'MSAyLjItLjkgNS41IDUuNSAwIDAgMSAyLjIgMGMxIC4yIDEuOS42IDIuOCAxLjJhNi42IDYu'
    b'NiAwIDAgMSAzIDQuNGMuMyAxLjctLjIgMy42LTEuNCA1LjVhNy4zIDcuMyAwIDAgMS00LjUg'
    b'My4zIDYuNSA2LjUgMCAwIDEtNS4yLTEuMSA2LjYgNi42IDAgMCAxLTMtNC40Yy0uMy0xLjgu'
    b'Mi0zLjYgMS40LTUuNHoiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQyOC42IDI2'
    b'MC4zYy0xIDEuMy0xLjMgMi41LTEuMSAzLjZhMy42IDMuNiAwIDAgMCAxLjYgMi41YzEgLjcg'
    b'MiAuOSAzIC42IDEtLjMgMi0xIDIuOS0yLjQuOS0xLjQgMS4zLTIuNiAxLjEtMy42LS4xLTEt'
    b'LjctMS45LTEuNi0yLjZzLTItLjgtMy0uNWMtMSAuMi0yIDEtMyAyLjR6Ii8+CiAgICA8L2c+'
    b'CiAgICA8cGF0aCBmaWxsPSIjMzA5ZTNhIiBkPSJtMzAxLjggMjA0LjUgMi4zLTkuOCA3LjIg'
    b'MS43LS4zIDEuNi01LjMtMS4yLS41IDIuMiA0LjkgMS4xLS40IDEuNy00LjktMS4yLS42IDIu'
    b'NyA1LjUgMS4zLS40IDEuNi03LjUtMS43eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'BR')

BR = b64_BR
index.append("BR")
index.append("BRA")
index.append("Brazil")
catalog["BR"] = BR
catalog["BRA"] = BR
catalog["Brazil"] = BR
country["Brazil"] = ('BR', 'BRA', 0)
lookup["BR"] = ('BR', 'BRA', 'Brazil', 0)
lookup["Brasilia Brazil"] = ('BR', 'BRA', 'Brazil', 0)
lookup["BRA"] = ('BR', 'BRA', 'Brazil', 0)
lookup["Brazil"] = ('BR', 'BRA', 'Brazil', 0)
details["BR"] = {"continent":"Americas","capital":"Brasilia","currency":"Brazilian Real","web":".br","lang":"pt-BR | es | en | fr","tz":"-05:00 | -02:00","altname":""}
#----------------------------------------------------------------------
b64_BS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImJzLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTEyIDBoNjQwdjQ4'
    b'MEgtMTJ6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNicy1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTIp'
    b'Ij4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik05NjguNSA0ODBoLTk3OVYxLjhoOTc5eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZTkwMCIgZD0iTTk2OC41IDM0NC41aC05NzlWMTQzLjNo'
    b'OTc5eiIvPgogICAgPHBhdGggZmlsbD0iIzA4Y2VkNiIgZD0iTTk2OC41IDQ4MGgtOTc5VjMy'
    b'MC42aDk3OXptMC0zMTguN2gtOTc5VjJoOTc5eiIvPgogICAgPHBhdGggZD0iTS0xMSAwYzIu'
    b'MyAwIDM5MS44IDIzNi44IDM5MS44IDIzNi44TC0xMiA0NzkuMi0xMC45IDB6Ii8+CiAgPC9n'
    b'Pgo8L3N2Zz4K', 'BS')

BS = b64_BS
index.append("BS")
index.append("BHS")
index.append("Bahamas")
catalog["BS"] = BS
catalog["BHS"] = BS
catalog["Bahamas"] = BS
country["Bahamas"] = ('BS', 'BHS', 0)
lookup["BS"] = ('BS', 'BHS', 'Bahamas', 0)
lookup["Nassau Bahamas"] = ('BS', 'BHS', 'Bahamas', 0)
lookup["BHS"] = ('BS', 'BHS', 'Bahamas', 0)
lookup["Bahamas"] = ('BS', 'BHS', 'Bahamas', 0)
details["BS"] = {"continent":"Americas","capital":"Nassau","currency":"Bahamian Dollar","web":".bs","lang":"en-BS","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_BT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJ0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZDUyMCIgZD0i'
    b'TS4xIDBoNjQwLjF2NDgwSC4xeiIvPgogIDxwYXRoIGZpbGw9IiNmZjRlMTIiIGQ9Ik0uMSA0'
    b'ODBoNjQwLjFWMHoiLz4KICA8ZyBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjUiPgog'
    b'ICAgPGcgZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIuNCI+CiAgICAgIDxwYXRoIGQ9Ik0z'
    b'NDUuNCAxNTBjLTQtMS4zLTYuNi43LTYuNCA1LjkgMCA1LjEgMi44IDggNi44IDYuMWwtLjQt'
    b'MTJ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNDguOSAxNDAuNGMtMy4zLTIuNi02LjQtMS41LTgg'
    b'My40LTEuNSA1IC4xIDguNiA0LjUgOGwzLjUtMTEuNHoiLz4KICAgICAgPHBhdGggZD0iTTM1'
    b'NC40IDEzMWMtMi44LTMtNi0yLjQtOC40IDIuMi0yLjMgNC42LTEuMyA4LjUgMy4yIDguN2w1'
    b'LjItMTAuOHptLTMuNiA0NS41Yy00LjkgMS44LTUuNCA4LjUtMi4zIDEyLjYgMyA0LjEgOC43'
    b'IDQuOSAxMS44IDBsLTkuNS0xMi42eiIvPgogICAgICA8cGF0aCBkPSJNMzQ1LjEgMTYyLjNj'
    b'LTQuNi0xLjUtOC44IDQuNy05LjUgMTAuMy0uOSA3LTExIDkuNC01LjQgMjAuMSAxLjItNi44'
    b'IDUuNy0xMC42IDkuMy0xMC44IDMuNi0uMyA5LTEgMTEuMy01LjRsLTUuNy0xNC4yem0xNC43'
    b'IDI3LjZjLTUuNCAxLjMtNi4yIDguNS0yLjMgMTMuNiAzLjMgNC40IDEzLjcgMy40IDEzLjQt'
    b'MWwtMTEtMTIuNnptMTUuMyA0My40Yy4zLTQuNy03LjItNi41LTEwLjgtNS42LTMuNiAxLTEw'
    b'LjUtLjEtMTItNC0xLjQgMy4xLjUgNi41IDUuNyA4LjIgNCAxLjIgMy45IDQgMi43IDUuNCAz'
    b'IC41IDExLjcuNSAxNC40LTR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNzAuOSAyMDMuN2MtNS4z'
    b'LTIuNC04LjQgMS4yLTEwLjQgNC42LTMgNS0xMi4xLTEuNC0xNS4yIDUuMyA0LjItMS44IDgu'
    b'NCAyIDEwLjQgMy4zIDUuNyAzLjcgMTYuNiAyLjYgMTguMi02LjJsLTMtN3oiLz4KICAgICAg'
    b'PHBhdGggZD0iTTM3NCAyMDkuOGMtNS4zIDQtNy40IDguOC03LjIgMTIgLjEgMy4yIDQuNiAx'
    b'MC4zIDkuNSAxMC43IDIuOC01LjggNC4zLTE4LTIuMy0yMi43em0tMjIgMjQuOWMwLTIgMi44'
    b'LTIuNyA0LjgtMiAxLjkuNiA0LjkgMi41IDMuOCA0LjZsLTguNi0yLjZ6TTMyMyAyMjRjLS41'
    b'LTIuMyAzLjItNi4zIDguMi00LjEgNSAyLjIgNS43IDYuNCAzLjYgOC4xbC0xMS44LTR6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik0zMzUuMiAyMjguNGMtLjQtMS4zIDMuMy0zLjkgOS40LTIuNCA2'
    b'LjIgMS42IDcuNyA1LjYgNy41IDguN2wtMTYuOS02LjN6bS0xMi45LTQuM2MzLjMtMi40IDIt'
    b'Ny0uOS04LjUtNS4yLTIuNi0zLjMtOS4yLTYuNy0xMC41LTMuMy0xLjMtNi41LTMuNi02Ljct'
    b'Ni0xLjYgMy4zLS42IDYuMiAxLjcgOC4zIDIuMyAyLTEuOCAxMC40IDEuMiAxMi42bDExLjQg'
    b'NC4xem0tNjktMS44Yy0yLjctNC4yLTkuMS0zLjUtMTEuOC0uNS0yLjcgMy0yLjMgNy4zLjIg'
    b'OS4zbDExLjYtOC44em0xNS41LTYuM2MtMS01LjctNy45LTYuMy0xMS42LTQuOS0zLjggMS40'
    b'LTYuMyA3LjEtMy45IDExLjJsMTUuNS02LjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNzkgMjE1'
    b'LjJjMi41LTQuNy0yLjMtMTEuOC03LjctMTIuOC00LjUtMS05LjgtLjktMTEuNi01LjMtMSAz'
    b'LjggMS44IDYuMyA1LjIgOC41IDMuMyAyLjItLjYgNy44IDQuOCAxMWw5LjQtMS40eiIvPgog'
    b'ICAgICA8cGF0aCBkPSJNMjc4LjYgMjE1LjRjLTEuMi0zLjQgMS4xLTggNS43LTcuNiA0Ljcu'
    b'MyA3LjMgMy42IDUuMyA3LjlsLTExLS4zeiIvPgogICAgICA8cGF0aCBkPSJNMjg4LjkgMjE1'
    b'LjdjLS43LTMuNiAyLjItNy44IDYuOC02LjggNC41IDEgNi42IDQuNyA0IDguNWwtMTAuOC0x'
    b'Ljh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yOTkgMjE3LjNjLS40LTMuNiAyLjctNy42IDcuMi02'
    b'LjQgNC41IDEuMiA2LjQgNSAzLjYgOC43bC0xMC43LTIuM3ptLTc3LjYgNTljLTguNyAwLTEw'
    b'LjggMi0xMiAxMS0xLjYgMTEgMTMuNSAxMi4zIDEyLTExeiIvPgogICAgICA8cGF0aCBkPSJN'
    b'MjI1LjIgMjY0LjdjLTEzLjItNS0yMC40IDE2LTMzLjYgMTIuMiA0LjcgNy41IDE2LjEgMCAy'
    b'MC40LjggNy4yIDEuMyAyMi44LTEuNCAxMy4yLTEzem0tOC42IDI4LjdjLTYuNi0zLTEzLjYg'
    b'Ny0xMi40IDExLjUgMS43IDUuNSAxNi43IDEgMTIuNC0xMS41ek0xODYgMzM2LjdjMy42IDEg'
    b'OCAzIDcuMiAxMC0uOCA3LTE0IDIxLjEtMjUuOCAyMi0xMS44LjctMTYgMTUtMjYuMyAxMSA5'
    b'LjYtMS44IDkuNi0xMi42IDE3LTE2LTUuNC0yLTguMiAxMC4zLTE1LjIgMTAuM3MtMTAuMyAx'
    b'MS4xLTE4LjggMTAuM2MtOC41LS43LTkuMyAxMy41LTI2LjQgMTMuNy0xMyAuMS0yOSAxNS4z'
    b'LTM0LjkgOC43IDEyLjctMS44IDE3LjgtOC44IDI1LjMtMTYuNSAxMi0xMi4zIDI1LjctNi44'
    b'IDMwLjQtMTcuN2EzMS42IDMxLjYgMCAwIDEtMTguMyA1LjRjLTgtLjItMTYuNiAxMi42LTI1'
    b'LjUgNyA1LjEtLjcgOC41LTIuOSAxMy45LTguNiA1LjUtNS44IDEzLjctMiAyMC4xLTggMTAt'
    b'OS4yIDE4LjctMS41IDI4LjMtMTMtMi43LTEuNC04LjUtLjUtMTMuOSAyLjQtNS40IDIuOC0x'
    b'Mi4zLTItMTguNSAxLjQuNy03LjYgMTUuMi0zLjMgMjQuMi04LjUgMTAuMi02IDE4LjYtNC4y'
    b'IDI2LjYtMy41LTExLjIgMC0xNS41LTEwLjctMzEtNy42LTYuNyAxLjQtMTIuMS05LjMtMTgu'
    b'OC0zLjkuMi00IDcuMi03LjIgMTQuNC0zLjMgNy4yIDMuOSAxMC4xLTMuNCAyNC41IDUuNyA2'
    b'IDMuNyAxNi4xLTIuNCAyMi41IDEuNi0uOC0yLjQtNC41LTQtOC44LTMuNiAyLjctNS42IDIw'
    b'LjItNC45IDI3LjguN3oiLz4KICAgICAgPHBhdGggZD0iTTE5Ny40IDMyOC4zYy01LjYtNC40'
    b'LTEzLjUuOS0xOS0xLjIgMCAzLjYgMS45IDkgNy44IDExLjEgMS44LTEuMyAxMC04LjQgMTEu'
    b'Mi05Ljl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMDYuMyAzMTUuOGMtOC45LTQuNS0xMC40IDYu'
    b'Ny0xNy40IDQuNC4zIDMuMiAyLjkgNy4yIDguNSA4LjFsOS0xMi41eiIvPgogICAgICA8cGF0'
    b'aCBkPSJNMjExLjYgMzA1LjZjLTEzLjEtNS4xLTE0LjggNy41LTIyLjUgNSAxLjggNC40IDEy'
    b'LjggNi44IDE4LjUgNS4ybDQtMTAuMnptMTgtNTUuMmMtMy41LTUtMTAuOC0xLTEyIDQuOS0x'
    b'LjEgNS44IDEuNyAxMy45IDYuNiAxMmw1LjQtMTd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMzgu'
    b'NSAyMzVjLTYtMS41LTEzLS44LTEyLjIgNS0yLjQgMS4xLTMgOC43IDMuMyAxMC40bDguOS0x'
    b'NS41eiIvPgogICAgICA8cGF0aCBkPSJNMjQyLjUgMjMxYy02LTctMTIuNS02LjktMTYuMi00'
    b'LTYuOSA1LjUtMTMuNSAyLjQtMTMuNyA3LjggNC4xLTMuMiA3LjguNiAxMS0uNSAzLjQtMS4y'
    b'IDUuOSA1LjMgMTUuMiAyLjZsMy43LTZ6bS0xNC4zIDEwMy45Yy45IDEuNyA2LjQgMi40IDku'
    b'MS0uNCAzLjYtMy44LS4zLTE0LjItNi0xNS01LjctLjctNi4yIDExLjgtMy4xIDE1LjR6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik0yMjEuOCAzMzUuMWM4IDMgMTEuNS0zLjcgNy4yLThhODAgODAg'
    b'MCAwIDEtNy4yIDh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xOTEuNCAzNDYuMmMtMS42IDQuNy05'
    b'LjYgNS40LTE4LjYgMTkuOC05IDE0LjUtMTcuNiA4LjQtMTkuOCAxOC4zIDEwLjgtOC43IDE5'
    b'LjMtMyAyNS44LTExLjYgOS43LTEzLjEgMTcuOC0xMS4yIDIxLjYtMjAgNS40LTEyLjcgMjkt'
    b'MTIuNCAzMC40LTMyLjMtOC0xLjUtMzMuMyAxOS45LTM5LjQgMjUuOHptMjAzLjItMTk0Ljdj'
    b'MTAuMyAzLjQgMTAuNSAxNi43IDIyLjQgMjEuMSAxMS44IDQuNCAxMyAxNSAyMi43IDEyLjQt'
    b'OS0yLjUtOC40LTEyLjktMTcuOC0xNS41LTExLTMtMTUuMi0xOS44LTI0LTIyLjRtNDQgNzQu'
    b'M2MxLjggNC4yIDEuNSAxMS41LTUgMTMuNCAzLjUgMi4yIDguNy4yIDExLjUtNC42LTQuMiA5'
    b'LjQtMS40IDE3LjkgNS4zIDE5LjYtMy4yLTYuNiA0LTkuNyAxLjctMTQgNC4yIDEuOSA4IDcu'
    b'NyA3LjggMTEuMyA1LjYtNi4yLTQtMTQuNS0yLjMtMjAuM2wtMTktNS40ek0zNzUgMjg3LjZj'
    b'LTYuMy01LjUtOSAxLjUtMTItMS0zLTIuMi02LjgtMi41LTguMy0uMyA1LjQuMiAyLjggNC40'
    b'IDEzLjMgNS40LTEwLjUuNy04LjYgMTIuNS0xNS42IDExLjkgNy40IDcgMTEuMy02LjMgMTcu'
    b'NC00LjEtMS44LjUgMi44IDQuNy0uNCAxMC40IDUuMi0uMSA3LjMtNy4zIDgtMTFsLTIuNC0x'
    b'MS4zem0tMTM5IDYwLjJjLTIuMi0yLTktMi45LTExLjUtMS4zLTIuNiAxLjUtMS43IDIgMS40'
    b'IDIuMiAzLjEuMiA3IDUuMi40IDUuNS0zLjEuMS0yIDcuNi04LjUgOC4xIDIuNiAzLjIgMTAu'
    b'MiAxLjEgMTIuOS0yLjQtLjUgMi45IDMuMyA1LjUgMS44IDkgNC43LjUgMi05LjcgOS41LTku'
    b'Mi0zIC40LTEuOCA3LjQgMy42IDUuNi0zLjIgMS41LTEuNSA1LjMgMiA0LjQtMi4yLjctMyAz'
    b'LjcuMiA1LjQgMy4xLTQuMy0uNC0xOS41LTExLjctMjcuM3ptMjgwLjYtMTQyLjFhMTcuOSAx'
    b'Ny45IDAgMSAwIDAtMzUuNyAxNy45IDE3LjkgMCAwIDAgMCAzNS43eiIvPgogICAgICA8cGF0'
    b'aCBkPSJNNDIzLjQgMjI3LjJjNS41LTUuMSAxMy43LTcuNyAxOS40LTMuOCA1LjYgMy44IDI0'
    b'LjQgOC40IDMzLjcgMiA5LjMtNi40IDEzLjctOS44IDE3LjgtOSAzIDQuNiA2LjggNi44IDEx'
    b'LjQgNy4yIDEuNCAxLjYgNi41IDIuOCA5LjMgMi41IDQuMSAxIDkuMS0uMyAxMy4xLTQuNyA2'
    b'LjIgMSAxMi0zLjcgMTQuMi0xMC43IDYuNi0uNyA3LTggMi44LTEzLTMuOC0uNy0uOS0xMy44'
    b'LTE0LjktMTEuMiA2IDMuNiAxLjQgMTAuOCA2LjMgMTQuMi0zLjMgMC03LjcgMS40LTguNyA2'
    b'LjQgMS4zLTMuNC0uMi01LjgtMS02LjUgMC0zLTYuNS0xMC4zLTEyLjctNy42IDQuNCAxIDIg'
    b'OCA1LjIgMTAuOGE4LjEgOC4xIDAgMCAwLTYuMiAzLjNjLTEuNy0zLTcuNi02LTExLjItNi4z'
    b'IDAtMS0uMi0zLS43LTQuMS0xLjYtMy4xLTMtNi44LTIuMy0xMS41YTQ4IDQ4IDAgMCAwLTcu'
    b'MiAxMS40Yy00LjktMy40LTE3IDEuNS0yMi43IDIuOC01LjYgMS4zLTI0LjctMS44LTI5LTYu'
    b'NGE0OS4yIDQ5LjIgMCAwIDAtMjEtOS44Yy0xMS0zLjItMTEtMTUuMi0yMy4xLTIzLjUtLjMg'
    b'MTUgMjIuNCA2Mi40IDI3LjUgNjcuNXpNMjk3LjIgMzQxLjFhMTcuMyAxNy4zIDAgMSAwIDAt'
    b'MzQuNiAxNy4zIDE3LjMgMCAwIDAgMCAzNC42eiIvPgogICAgICA8cGF0aCBkPSJNMjU2IDMy'
    b'Ny44YzMuNSA0LjUgOS40IDQuMiAxMS45IDMuOSAyIDUuNCA4LjYgNS4yIDExLjQgOC4yIDIu'
    b'OSAzIDEyLjUgMi43IDE1LjMgMS0yLjUtLjItNS45LTEuOC05LTQuNS00LTMuMi0yLjItOS44'
    b'LTUuMi0xMmExMSAxMSAwIDAgMCAyLjItOC42YzIuNC0xLjQgNC4yLTMuNyA0LjQtNC45YTE1'
    b'IDE1IDAgMCAwIDkuNi00LjFjMi4yIDIgNy43LS42IDEwLjcgMi44LjYtOC41LTcuNS0xMy0x'
    b'My0xMC4xLTIuMS0xLjItNy45LS40LTkgMS4xLTEuNy0uOC02LjggMS44LTkgMy41IDIuNS0x'
    b'LjQgMi45LTUuNyAxLjktNy4yIDIuMi0xIDQuNi0zLjkgNC45LTYgMyAuNSA3LjctMS42IDku'
    b'Ny0xLjEtMy4zLTQuNC04LjgtNi0xNC41LTUuNS01LjkuMy04LjQgNC40LTkuMiA4LjgtMy40'
    b'IDIuMS00LjYgOS0zLjMgMTEuNS0yIDAtMy45IDEuOS00LjYgM2EyNi43IDI2LjcgMCAwIDAt'
    b'OS40LTJtMS4zLTdjLTEuMi0zLjQuMy02LjQgMS4xLTkgMi02LjguOC04LjYtNS4zLTcuN2E0'
    b'NyA0NyAwIDAgMCA0LjIgMTYuN3oiLz4KICAgICAgPHBhdGggZD0iTTI0OC42IDI4Mi4zYzEu'
    b'NiAxLjYgNyAyLjMgNy42LTIuNi43LTUuNi0xLjYtNy44LTYuNS01LjYtLjQgMS4zLS44IDYu'
    b'NS0xIDguMnoiLz4KICAgICAgPHBhdGggZD0iTTI0OS44IDI3My45YzIgLjggNi41IDIuNSA5'
    b'LTIuMyAyLTQtLjctNy01LTYuOC0xIDEuMi0zIDUuMy00IDkuMXoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTTI1My42IDI2NC40Yy41IDEuNiA1LjggNi43IDkuNiAzIDMuOS0zLjcgMy45LTkuMy0x'
    b'LjktMTEuMy0xLjUuMi02LjIgNS42LTcuNyA4LjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNjEu'
    b'MyAyNTZjMS4xIDMuMyA0LjggOC44IDExLjUgNi4zIDYuNy0yLjYgMy44LTExIC43LTEyLjdh'
    b'MzMgMzMgMCAwIDAtMTIuMiA2LjV6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNzMuNSAyNDkuNmMt'
    b'LjUgMi45IDAgMTAuNiA5LjIgMTAuNSA5LjEtLjIgNi42LTEwLjkgNC4yLTEyLjQtMy43IDAt'
    b'MTAgLjEtMTMuNCAyeiIvPgogICAgICA8cGF0aCBkPSJNMjg3LjMgMjQ4Yy0xIDIuMy0zLjMg'
    b'MTYuNyAxNC42IDEyLjcgMi4zLS41IDguMy0xMy44LTE0LjYtMTIuNnoiLz4KICAgICAgPHBh'
    b'dGggZD0iTTI5Ny4xIDI0OS40Yy0xLjggMS44IDIuOCAxNi4zIDE1IDEzLjkgMTItMi41IDEu'
    b'OS0xNi4zLTE1LTE0eiIvPgogICAgICA8cGF0aCBkPSJNMzA3LjQgMjUxLjZjLTIgNCAxIDE1'
    b'LjggMTUuOSAxNS44IDEzLjUgMC0uNy0xNS42LTE1LjktMTUuOHoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTTMxOS4xIDI1NWMtMSAyLjMtMi4xIDE0LjggMTUuNSAxNS45IDEyLjcuOCA5LjYtMTcu'
    b'My0xNS41LTE1Ljl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zMzggMjYwLjNjLTIuMSAzLjktNC40'
    b'IDEzLjUgMTQuOSAxNC4zIDEyLjMuNSA0LjctMTQtMTQuOC0xNC4zeiIvPgogICAgICA8cGF0'
    b'aCBkPSJNMzU0LjEgMjYzLjNjLTIuOCAzLjgtLjcgMTEuNCA2LjUgMTIuOCA5IDEuOCAxMC4z'
    b'LTYuNyA0LjEtMTAuOC02LjItNC0xMC42LTItMTAuNi0yeiIvPgogICAgICA8cGF0aCBkPSJN'
    b'MzYzIDI2NWMtMi4xIDMuNy0uOSAxMi40IDEyLjggMTIuNCAyLjggMCAxMy42LTExLTEyLjkt'
    b'MTIuM3pNMjU3LjEgNDMzYTIwIDIwIDAgMSAwIDAtNDAgMjAgMjAgMCAwIDAgMCA0MHoiLz4K'
    b'ICAgICAgPHBhdGggZD0iTTQwNC4xIDE0MS43YTM1LjIgMzUuMiAwIDAgMC01LjQgOGMtNi43'
    b'IDIwIDExLjIgMzUgMjEuNiA1Ni43YTYzIDYzIDAgMCAxLTUuNiA2MC43Yy00LjQgNS44LTMu'
    b'MSA3LjUtOC44IDEzLjQtMi4yIDIuMy00LjYgNS4yLTMuOCAxMy40IDMuNi0xLjMgOC43IDIg'
    b'OS43IDUgMi42LTEuNCA2LjItLjkgNy41LjcgNC40LTIgOC0xIDExLjkgMyAzLjMtLjQgNyAw'
    b'IDEwLjMgMy43IDEuOC0zLjYgNS40LTUgOC00LjEtLjMtNC43IDQuMy04IDguNC02LjJhNy42'
    b'IDcuNiAwIDAgMSA5LjgtOWM0LjctMy42IDE0LTMuOSAxOC42IDEuNS04LjMtMi4zLTggNi41'
    b'LTE1IDUuNyAxLjggNS4xLTIuOCA4LjEtNy40IDkuOCAzLTEuNCA2LjItMy4xIDcuMi0xLjMg'
    b'Mi42LTIuMyA3LjctMS40IDktLjMgMy40LTEgNi43LS4yIDguMiAzLjkgNC43IDIuOCA3Ljgg'
    b'MTAgNC40IDE1LjQtMS01LjYtNC45LTUuNC02LjQtNy43LTMuNiAxLjMtNy4yIDEuMy04LjMt'
    b'MS0yIDItOSAzLjktMTIgLjgtMS4yIDQuNi01LjIgOC41LTkuOSA4LjUgMS4zIDMuNi0yLjMg'
    b'OS43LTUuMSAxMi44IDQuNCAyLjMgMyA3LjUgMiAxMC42IDYuOCAxIDEgNyAxMi43IDEwLjgt'
    b'NS43IDEuOC0xNi44IDAtMTguMy03LTUuNy0uMi05LjUtNS45LTkuMy0xMS44LTQuNC00LjEt'
    b'NS0xMCAxLTE0LjItNS4xIDEuNi04LTYuNy0xNS40LTMuMy0zLjcgMS43LTEzLjUtMS4yLTEz'
    b'LjQtNC42LTEuNSAyLjUtMTEgMS41LTEyLjItMi45LTMuMSAxLjctMTAuMy0xLjEtMTAuMi01'
    b'LjQtNCAxLjgtOS40LTEuNC05LjEtNS41LTMuOC0uNS00LjItMy45LTQtNi43LTMuMy0xLjYt'
    b'Mi40LTQuOC0xLTguNi0yLjQtMi42LTEuNC02LjIuNC05LjYtMi41LTIuNi0yLTUuNi0xLjMt'
    b'OS4zLTEyLjMtMS0yNy44LTQtNjMuMy0xNC45LTUzLjYtMTYuNS02OCAyMi4yLTU2LjIgNDYu'
    b'NCAxMy43IDI4LTEuNSAzNCAzLjEgNTQuOCA1IDEgNy41IDUuMiA3LjIgOS42IDMgLjEgNSAy'
    b'LjggNCA4YTkgOSAwIDAgMSA3LjYgMi4zYzEuOC0zLjQgNy44LTQuMiAxMC44LS4zIDYuNy0u'
    b'NSAxMC4xIDUgOS44IDExLjZhMTggMTggMCAwIDEtMS41IDE5LjNjLjQtMi43IDAtNi41LS4x'
    b'LTguOS0uMy00LjItNi4yLTUuMS01LjYtOC42LTMgLjMtNi0xLjQtNy0zLjdhNi44IDYuOCAw'
    b'IDAgMS02LjYgMS4zYzMuNCAxLjUgNi4yIDcuNyA1LjEgMTEuOCAxLjggMy4xIDEuNCA4Ljgt'
    b'LjcgMTEuMi0xIDUtNSA2LjgtMTAgNC42IDIuOS0xLjggMy45LTUgMy44LTcuN2ExMCAxMCAw'
    b'IDAgMS0yLjktNi4zYy01IC44LTEyLTMuNS0xMy4yLTUuMmEyMCAyMCAwIDAgMC0yMCAyMC4x'
    b'Yy0uNi00LjEtNS44LTguMi01LjEtMTEuNy0zLjEtOS41IDEuMy0xOC40IDEzLjktMjAuMi0x'
    b'LjYtMy42IDMuOC03LjMgMS44LTExLjRhOTcgOTcgMCAwIDAtMTQuNy0yMC4xYzQuNC03LjUg'
    b'My0xNy41LjUtMjMuNy0zLjctOC45LTcuMi02LjctMjAuMyA3LjctMjEuNCAyMy41LTUwIDE3'
    b'LTc1LjIgMzIuNS02LjcgNC0xMy40IDUuNi02LjItMS42czI2LjItMTQuNCAzOC42LTIwLjZj'
    b'MjMuMi0xMS42IDQyLjgtMzAuOSA1MC41LTY4LjUgMTguMS04OC40IDg1LTU5LjIgMTI3LjIt'
    b'NDIuOCAzOS43IDE1LjUgMzIuNS0xOS41IDEyLjQtNDAuNy0yNC4yLTI1LjMtMTkuMy00NS4z'
    b'LTgtNjEuMyAyMC4zLTIuOCA1OS40IDQuMyA1MS41IDExLjF6Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik00NzUuOSAzNTguOGEyMiAyMiAwIDEgMCAwLTQ0LjEgMjIgMjIgMCAwIDAgMCA0NHoiLz4K'
    b'ICAgIDwvZz4KICAgIDxnIGZpbGw9Im5vbmUiIHN0cm9rZS13aWR0aD0iLjQiPgogICAgICA8'
    b'cGF0aCBkPSJNMzkxLjggMTQyLjdjLTUgMjEuNy0uOCAzMS41IDYuNCA0MSAxNC45IDE5Ljcg'
    b'MjYuOCA2NC42IDkuOCA5NCIvPgogICAgICA8ZyBzdHJva2UtbGluZWNhcD0icm91bmQiPgog'
    b'ICAgICAgIDxwYXRoIGQ9Ik00MTcuNSAyNTIuM2MyLS43IDYtMy4yIDYuOC03LjRtLTUuMi0y'
    b'Yy42LTMuNyA2LjQtNS4zIDYuNS05LjNtLTYuNC01LjJjLS40LTMuOSA1LjgtNy40IDQuOS0x'
    b'MS4ybS04LjMtMi43Yy0uNS0yLjIgNS4yLTYuMyAzLjYtOS44bS03LjgtMy44Yy0xLjItMi40'
    b'IDIuNy01LjIgMS03LjhtLTcuMi0zYy0uNC0xLjYgMi01LjMuNy03LjVtLTYuOS01LjJjLjUt'
    b'LjcgMi42LTIuMiAxLjgtNC4xbS02LTUuM2MuOC0uNCAzLjMtMS4yIDMtMyIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZS1saW5lam9pbj0icm91bmQiIGQ9Ik0yNjYgNDEwLjljLTUtMS44LTEx'
    b'LjUuNy0xMi44IDUuMW0zLjkgNGMuNi00LjQgNy4zLTYuMyA5LjMtNC4zLTQuMi0yLjMtNi4z'
    b'IDYtMi41IDYuMm0zNC42LTEwMy44Yy0zIDEuNi00IDcuMiAwIDExLjVtNC42LTEwLjJjLTIu'
    b'MSAxLjgtMiA3LjIgMS4yIDguNS0yLjctMiAwLTUuMyAyLTUuNCAxLjktLjEgMy4yIDIuMi44'
    b'IDQuNW0xNzcgNS4yYy03LjItMi0xMyA2LjQtNi40IDEzLjktLjItNy4yIDUtMTIgMTEuMy0x'
    b'MC43bS0zIDVhMi43IDIuNyAwIDAgMC0yLjcgMi43YzAgMS40IDEuMiAyLjggMy4yIDIuOCAx'
    b'LjMgMCAyLjQtMS41IDIuNC0yLjdtMjIuNi0xNjFjMS4yIDQuNCA3LjIgNi4zIDEyIDUuMm0w'
    b'LTIuOGMtMy43LjEtNi44LTMuNC02LjYtNi4zIDAgMi4yIDUgMy4yIDYuNiAxLjgiLz4KICAg'
    b'ICAgICA8cGF0aCBkPSJNMjY3LjkgMzMxLjdjLTEtMi42IDMtNS4yIDMuMi03LjYuMS0yLjUg'
    b'NC42LTQuNCA5LjMuMm0tMi4yLTI3LjQtMi41IDEuMm0xMS40IDEyLjhjLTEuMSAwLTMuNCAw'
    b'LTQuNi0uOW0wIDUuOGMtLjguNS0yLjggMS4yLTQgMS41bS00MC4xIDc2LjNjLS4yIDIuMyAy'
    b'LjIgNS43IDMuNCA2LjdtNi42LTEyLjJhMTAgMTAgMCAwIDAtMS4zIDcuNm0yMC41IDBjLTIu'
    b'My0xLjUtLjgtNS40LTEtOC0uMy0yLjYgMi43LTYuNyA4LjUtMy4yTTI0NiAzODFjMi4zLS40'
    b'IDQuNy0uMyA2LjMuNG0yMy03LjdhOC4zIDguMyAwIDAgMC0xLjQgNG0xMi4zLTQuM2MtMS44'
    b'IDAtMy40IDEuMy00LjIgMi42bS0yMC44LTY4LjVjMiAuNyA3LjQgNCA3LjYgNy40bTE0LjMt'
    b'MjQuMmMtNi4zLS4xLTguOC02LjUtNC02LjVtMTUuMyAxNS4yYy0yLjQgMS0xLjMgNS4yIDIu'
    b'MiA3LjNtLTE3LjMgMzMuMWMtMS4yLTEuNi40LTYgNC40LTQuN201IDUxLjdjLjMtNCA1LjIt'
    b'Ni4yIDcuMi0xLjhtLTI1LjUgMTNjLS4zLTQuMyAyLTUuNyAzLjgtNiAyLS4yIDQuNyAxLjQg'
    b'NiA0LjJtLTQ4LjEgNWMuMi0yLjYgMi40LTUuMyA0LjctNC45bTIzMS0xMDkuNGMtMS43IDEu'
    b'Mi0yLjggNi43IDMuNSA3LjJNNDU4IDI5NmMwIC42LjggMS41IDEuMyAybTI5IDguM2MtMS42'
    b'LTEuMy02IDQtMiA3LjdtLTM5IDM1LjZjLS45LTMuNyAyLjUtNC43IDUuOC0zLjltLTE0LTIy'
    b'LjJjMi0xLjIgNC0yLjcgNi40LTMuM20tNy40IDE3LjVjMC0zIDEuNi01LjcgMy02LjRtOC40'
    b'LTI5LjFhMTYgMTYgMCAwIDAgMi40IDkuMm0yOC4yLTljLTEuOS42LTMuNSAxLjMtNC4yIDIu'
    b'OW0yLjEgNy43YzEtLjggMi0xLjcgMi40LTIuM200Ni4zLTExMC4yYzAgMy42LTQuNSA1LjYt'
    b'Ny41IDMuM20xNy4zLTMuMWMyIDEuNSA4LjkgMCA3LjMtNE01MjggMjIxLjRhMTEgMTEgMCAw'
    b'IDEtNC45LTNtMTkuMS03LjdjLTIuMy41LTMuOSAwLTUtLjVtLTMxLjYgMTMuNGExNyAxNyAw'
    b'IDAgMCA2LjUtMS42TTUwMiAyMDAuOGMtMS43LS4yLTMgLjEtMy45LjhtMjkuOCA1LjVhMTEg'
    b'MTEgMCAwIDEtMyA1LjIiLz4KICAgICAgICA8cGF0aCBzdHJva2UtbGluZWpvaW49InJvdW5k'
    b'IiBkPSJNNDk3LjUgMjEyLjhjMy4yLTEuNCA3LjIgOS41IDE1IDUuN20uNi0xMS40YTExLjMg'
    b'MTEuMyAwIDAgMC0xLjggNS42Ii8+CiAgICAgIDwvZz4KICAgICAgPHBhdGggZD0iTTM1OSAx'
    b'OTAuNGMxLS4yIDIuOS0uNSAzLjMtMS44TTIyNi41IDMxMC4zYzMuOSAyLjIgNi42IDUuOSA1'
    b'IDExLjRtMTcyLjEtMTQzLjJjMS4yLjggNS41LjggOCAwbTMgMi42YzAgMS44LjUgOC42LTMg'
    b'MTBtMS4zLS44YzMuMiAxIDkuNi42IDExLjctNS4zbS00LjUgNWMxLjcgMi42IDIuMiA3LjYt'
    b'Mi44IDEwLjNtNC02YzMuOCAxLjIgMTIuNCAxLjQgMTEuNS02bS0zIDZjMi43IDMuNSAxNCA3'
    b'LjggMTIuMi4zbS0yMi41IDEwYzQuMyAxLjEgMTAuNS0xLjkgOC05LjZtMTIuMyAzLjljLjYg'
    b'MyAxNSA2IDEzLjEtLjdtLTIuNyAzLjljMi43IDYuMiAxNyA1LjcgMTIuNS0yLjZtLTIuMyA2'
    b'LjVjMi44IDMuNCAxNS41IDEuNCAxMC40LTdtLS4xIDYuOGM3LjkgNiAxNy0yLjUgNy04Ljdt'
    b'NC42IDYuOGM3IDUuNSAxNS41LTQuNSA5LjQtNy4zbS02NC40IDVjMi4yLjYgNi44LjQgNy45'
    b'LTMuNm0tMS44IDIuN2MtLjIgNS44IDkuNiA4IDEyLjEgMS4zbS0zLjMgMy43YzEuOCAzLjkg'
    b'MTAuNSA1LjQgMTEuOS0uMW0tMS40IDIuNmMxLjQgMy44IDguOSAzLjQgMTEtLjZtLTIuOCAy'
    b'LjZjMi4zIDUgMTEuOSA1IDE0LTIuM20tMS42IDMuMmMzLjcgMi4zIDExLjcgMS40IDExLTUu'
    b'OG0tMS41IDUuMmM1LjYgNC41IDEzLjQuMSA5LjUtNy41bS0uMyAxMy40YzMtLjUgNC41LTYu'
    b'NCAxLjQtOG0tNzAgOWM2LTMuMyA3LjMtOSAzLTE0LjVtMi4yIDguOWMzLjkgMi4zIDExLjIt'
    b'LjIgMTIuNS01LjhtLTcuMiA2LjRjMi4yIDIuOCAyLjYgNi4zLS4zIDkuNW0yLTUuOWM2Ljkt'
    b'NC4yIDE1LjQgMy42IDkgOC40bS0xLTguOGMxLjUtLjQgNC4yLTMuMiA0LjQtNi40bS0xLjQg'
    b'OS40YzIuOS0zIDIyLjIgMyAxMCA5LjNtLTEtMTcuNGMzLjggMS40IDUuNyA2LjcgMCA4LjVt'
    b'NSA0LjRjNC00LjMgMTctMS42IDEyLjMgMy44bS0zLjEtNS41YzIuMy03LjkgMTYuMS0zIDEx'
    b'LjYuMm0tMTQuNC04Yy40IDEuNS41IDUuMy0yIDcuNG0xMy42LTlhNi4xIDYuMSAwIDAgMS0u'
    b'OCA1LjNtOS41LTUuMmMuOCAxLjQgMiA0LjEtLjggNi4zbS0xMDkuNC02NS41Yy4xIDcuMyAy'
    b'LjcgMTIuMiAxMi42IDcuNm0tOS41IDEuMWMtNSA2LjYuNiAxMy43IDEwLjMgNi42TTM2NSAx'
    b'NjVjNi43IDcuMiAxOC43IDIgMTEtOW04IDE1LjJjLTEuMiA3LjEgNC42IDguNSA5LjMgNS4z'
    b'bS0zNC4yLTEwLjNjMS4yIDcuMSA4LjUgMTIuNyAxNS42IDguNG0tNi45IDEuNGMwIDEwLjIg'
    b'MTQgMTEuMyAxNy4zLjhtLTUgNi40YzQuNSA5LjMgMTQuMyA1LjUgMTcuNS0uMW0tMjcuNC0x'
    b'NC43YzEuOCA0LjUgNS40IDkuNSAxMy43IDUuOG0tMzkuNS04YzEuMiAzLjcgNy45IDguMiAx'
    b'NS42IDNtLTEwLjggMS44Yy00LjIgNiA0IDExLjcgMTQgMi43bS05LjEgNC43YzEuNiA4LjUg'
    b'NSAxNS40IDE3IDQuNG0tNiA0LjRjNC40IDUuNCAxMS4xIDguNyAxNy40LS40Ii8+CiAgICAg'
    b'IDxwYXRoIGQ9Ik0zODcuMyAxODguOGMtLjQgNi41LjggOS43IDUuOSA5LjQgNC0uMiA3Ljct'
    b'My4zIDkuOS02LjdtLTEwLjggNi43Yy0uMiA3LjQgNS42IDEzLjIgMTYuNSA1LjdtLTEyIDNj'
    b'LTIgNS41IDQuMSAxNC41IDE2LjIgOS45bS00MS45LTI0LjZjLS43IDcgNS44IDExLjggMTYu'
    b'NCAyLjdtLTExLjIgNS4xYy40IDUuOCA3IDEyLjggMTYuNiAyLjdtLTEyIDQuN2MtLjcgOS45'
    b'IDguNCAxMi43IDE2LjEgNS4xTTM2Ny4yIDIwMGMyIC4yIDMuNy0xLjYgNC43LTNtLS40IDEw'
    b'LjJjMS44LjQgNS0xLjIgNi0zLjNtLTEuNCAxNWMyIDIuMyA5IC43IDkuOS0yLjNtLTIuMiAy'
    b'LjJjMy44IDkgMTQuMSA4LjcgMTguNC0xLjVtLTIgMy42YzIgNS4zIDYuOSA4LjYgMTQuOSA2'
    b'LjhtLTExLTEuNGMtNC41IDcuMyAxLjQgMTYgMTEuNSA3LjVtLTkgMy41Yy0uNSA0LjYgMy43'
    b'IDkuOSA5LjUgMTAuNW0tMjguNi0yNGMtMS41IDEwLjQgNiAxNS40IDE1LjMgOS44bS0yNi4y'
    b'LTQuOGMyLjQgMS45IDYuOCAyLjEgMTEgLjZtNSA2Yy0yLjQgOC44IDYuNiAxNS4xIDE0LjMg'
    b'NS4zTTM4MCAyMzAuMmMuMiA0LjUgNC41IDkuNCAxMi4xIDhtMjEuMyA5Yy01LjIgMy40LTYu'
    b'MiA5LjYgMSAxMy42bS0xMy42LTE1LjRjLjIgNS4yIDIuNyA4LjIgOC41IDguN20tMTYuMS0x'
    b'MS40Yy03LjggNy0uMiAxNS4zIDkgOC4zbS0zLjYgMi4yYy0yLjYgOC4xIDcgMTMgMTIuMiA0'
    b'LjhtLTI4LjItMjJjLTIuOCA4IC44IDEzLjIgNy40IDEyLjdtLTE3LjYtMTQuM2MuNCA0Ljgg'
    b'NC41IDYuNSA5LjIgNS40bS02LjItLjRjLTMuNSA2LjcgMS44IDEwLjMgOC44IDcuOG0yMSAx'
    b'NWMtMSA0LjItLjQgNy4yIDUuOSA4LjdtLTUuNC0yLjdjLTcuNiAzLjQtOC4zIDEwLjgtMi40'
    b'IDE1LjVtLTMuOC0yMy43YTcuNiA3LjYgMCAwIDAgMS4yIDEyLjNtLTM1LTM1LjhjLTQuMyA0'
    b'LjMtLjIgMTYuMiA5LjUgOS43bTE1LjcgNS4zYy02IDUtMy4zIDEzLjggNi41IDExLjRtLTE2'
    b'LjMtMTVjLTMuMSA4LjctLjIgMTEuOCA2LjggMTEuOSIvPgogICAgICA8cGF0aCBkPSJNMzU5'
    b'LjMgMjM2LjFhOC4yIDguMiAwIDAgMC0xLjUgMTIuMmMyLjMgMi42IDYuNyAxLjQgOC0xLjlt'
    b'LTE3LjYtMTMuOGMtNS45IDcuNiAwIDE2LjYgOC40IDE0bTIzLjMgOC42Yy02IDIuMS0xMC43'
    b'IDcuNi03IDEyLjUgMi4zIDIuOCAxMS44IDMuMiAxNC41LTcuOE0zNjkgMjQ4LjFjLTMuNSA1'
    b'LTIuNCA5LjggNCAxMi4ybS00LjQtMi44Yy0zLjggMi02LjIgNC41LTUuMyA5bS0zLjEtMTYu'
    b'OWMtMS40IDYgLjMgOS44IDQgMTEuNm0tNC4xLTQuNGMtNS44LS40LTguOCAyLTYuOCA3Ljht'
    b'LjUtNi40Yy01LjctMi02LjYtNy00LjEtMTJtLS44IDcuNmMtNi4yLjItOSAzLjMtOSA3LjUi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTM0MC41IDIyOS43Yy00LjUgMS45LTYgOC00LjMgMTEuMyAx'
    b'LjcgMy4zIDcgMy42IDEwLjIgMS40TTMyOCAyMjQuOWMtNC4xIDQuNi42IDEzLjcgOCAxMS41'
    b'bS0xOC42LTE1LjFjLTMuOCA1LjQuNCAxNC40IDEwLjMgMTEuOG0uNSAyNS4xYy0xLTYuNCA1'
    b'LjctMTAuNiAxNC0yLjNtLTQtMTNhMTAuMSAxMC4xIDAgMCAwLTMuMyA4LjVtLTI4LTMzLjJj'
    b'LTQuMyA3LjIuOSAxMy44IDEwIDExLjJtMTMuOCA2LjdjLTYgNi00IDEyLjEuNSAxNS42bS00'
    b'LjQtOC41Yy05LjEuMS05LjYgMTAuNy0yLjIgMTRtLTQuNy0yNC42Yy0zLjggMi42LTUgOS43'
    b'IDEuNSAxMi41bS0xLjggMy40Yy0zLjktMS44LTguNS40LTguMSA0LjltMi4zLTQuOGMtMy41'
    b'LTguMi0xMy42LTYuOC0xMi43IDEuN20xNS41LTExLjljLTIuMS40LTYuNSAxLjctOC4yIDVt'
    b'LjYtMTQuM2E3IDcgMCAwIDAgMi41IDExLjRNMjk2LjcgMjE2Yy0uOCA1LjYgMS40IDguMyA4'
    b'LjQgNy44bS02LS43Yy0yLjYgNi43IDEgOS43IDggOS4zbS02LjQtMWMtNC4xIDQuOS0xLjMg'
    b'MTAuMSAyLjcgMTIuM20tNC42LTYuMWMtNy40LTEtOC41IDcuNi02IDExLjUiLz4KICAgICAg'
    b'PHBhdGggZD0iTTI5Mi45IDIxNS41Yy00LjUgMi03LjEgNy42LTQuNyAxMSAyLjUgMy41IDcu'
    b'NCAyLjQgMTAgLjZtLTguNCAxYy0zLjggNS43LS40IDEwIDMuNiAxMS42Ii8+CiAgICAgIDxw'
    b'YXRoIGQ9Ik0yNzUuMyAyMTQuOGMtMyAzLjEtMS4xIDkuNCA2IDkuNiA1LjkgMCA4LjgtNS40'
    b'IDctOS4zbS04IDkuM2MtMi4zIDUuMS0uOCAxMC43IDggOS44bTMuNiA4Yy01LjMtMi40LTEy'
    b'LjYgMC05LjUgNi41bS0uNy0xNS42Yy0yLjIgMy4xLTEuNSA3LjUgMSAxMC4ybS0xLjQtMmMt'
    b'My42LjctNy4xIDIuNi01IDguM20tLjUtNC42Yy00LjYtMS40LTEwLjUgMi03IDYuN20tLjct'
    b'NC41Yy00LS43LTguNyAzLjYtNC45IDcuOG0tMS41LTMuNWMtMy42IDEtNy45IDUtNC4xIDgu'
    b'M20yMi4zLTI4LjVjLTUuMiAyLjMtNS43IDguMS0zLjMgMTIuNG0tMi4yLTIzYy03LjcgMy03'
    b'LjYgMTMuMiAxIDE2LjRtLTMuNy0yLjNjLTQuNiAyLjctNS41IDcuOS0yLjQgMTEuMm0tNS43'
    b'LTI5LjJjLTMgMS0yLjggMTAuNSA1LjQgMTAuM20tMTMuOS03LjFjLTYuMiA0LjEgMS4zIDE0'
    b'LjUgMTEuMyA3bS01LjUgMi43Yy0uOSA0LjIuMyA4LjggNy4xIDkuNG0tNi43LTMuOGMtNC45'
    b'IDEuOC01LjggMTEuOSAzIDEyLjdtLTE4LjYtMjEuOGMtNi4zIDUuOCA1LjIgMTAuOCA5LjQg'
    b'Mi40bS0xOC4xIDcuMmMtMy4xIDMuOCA3LjcgMTMuNiAxMi41LTIuOG0xLjEtLjNjLjMgNCAy'
    b'LjYgNi4yIDcuMyA2LjVtMCAzLjdjLTcuNyAxLjItMTAuMSAxMC43LTEuNiAxMi44bS0xMi41'
    b'LTE0Yy0uMyAzLjUgMy41IDYuNSA3LjcgNS45bTMuOSA3LjhjLTcgMS42LTcuOSAxMC42LTEu'
    b'NyAxMG0tMy4yIDguNGMtNS44LTEuNy02LTguNi0uOC0xMS4yIi8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik0yNDUuNyAyNjcuOGMtNC45IDMtMyAxMC0uNCAxMXM0LjctLjIgNS0yLjRtLS41IDEwYy42'
    b'IDMuMy0xMS45IDItNS41LTguNG0wIDguOWMtNC4yIDYuNiAyLjYgMTIgNi45IDYuM20tNi40'
    b'IDEuNmMtMS43IDUuMyA0LjcgOS4xIDguOCA1TTIzMSAyNDUuNGMtMi4zIDQuNyA5LjMgNi41'
    b'IDEwLTMuM20tMTMuMiAxMC4zYy0yLjMgOS4zIDE1LjIgNy40IDEwLjctNC42bS40IDYuMmE4'
    b'LjIgOC4yIDAgMCAwIDExLjYtNi4zbS01LjMgNi42YTEwIDEwIDAgMCAwIDQuNyA2LjNtLTEz'
    b'LjEtMy45Yy0uOCA1IDQuMyA5LjIgMTAgOC44bS05LjEtMy45Yy0yLjggMy45LTMuNyAxMS4z'
    b'IDUuMiAxMS44TTIyNCAyNjNjLTEuNCA0IDcgOC4xIDExLjggMS41bS0xNC40IDguN2MtLjcg'
    b'MyA2LjggNyAxMS01LjhtLTMuMyA2LjVjMS44IDMuMiA3LjkgNS44IDExLjYtLjVtLTYgMy45'
    b'Yy0xLjYgNC41IDIuNyA4LjcgNy44IDcuNW0tMTcuNS04LjVjLTEgNi40IDYuNSAxMC4xIDEx'
    b'IDYuOG0tMTUuOS00Yy0yLjIgOC4yIDguNCAxMS4zIDEyLjQgNS4xbS0yLjcgMi41Yy40IDQu'
    b'NiA3LjYgOC42IDEzLjIgNC44bS0yNi4xLTFjLS41IDIuMSA4LjEgNC4yIDkuNC0zbS00LjQg'
    b'NC45YzIgNS4yIDkgNi41IDEzIDBtLTIuMyAyLjZjMSA1IDcuMiA3LjcgMTIuOCA0LjNtMi4z'
    b'IDJjLTEuNCA2LjUgNS40IDExLjggOS42IDguMm0tMjAuNi05LjRjLTIgNy4yIDcgMTEuMyAx'
    b'MiA3LjNtLTIyLjgtMTFjLS41IDYuOCA0LjggMTAuOCAxMC44IDcuOG0tMjIuMy03Yy0xLjgg'
    b'NC4zIDcuOCA3LjkgMTIuMyA0LjJtLTE4LjIgNy43YzIuNSAyLjggMTEgMCAxMS43LTYuM20t'
    b'Mi4zIDQuNmMzLjEgMy42IDEwLjUgNS42IDEzLjQtMi4ybS0yLjYgNGMwIDUuNiA5LjggOS42'
    b'IDEzLS42bTExLjcgMmMtMSAyLjcgMS4yIDcgNS43IDcuNW0tMTMuOS05LjJjLS42IDMgMy45'
    b'IDcuNCA4LjcgNS43bS45IDEuM2MtMS4zIDMuMy0uMiA4LjEgNC4zIDhtLTMuOS0xLjhjLTMu'
    b'NCAyLjgtMiA3LjkgMi45IDhtLTQuNi0zLjJjLTQuOCAzLjItMy4xIDEwLjMgMy4yIDkuOU0y'
    b'MzkgMzEzYzAgNyA4LjcgOCAxMC4zIDEuNm0tMy4zIDRjLTEuMyA0LjIgMiA4LjIgNy4zIDdt'
    b'LTYuMyA0Mi44YzEuMiAxLjcgNi0xLjIgNC43LTQtMS4zLTIuOC02LjQtMS4zLTUuOCAxLjdt'
    b'NC42LTIuOWMuNi01LjYtNi02LjUtNy43LTEuNm0yLjQtMi45YzEuNy0yLjgtNC02LjctNi4z'
    b'LTIuNW0yLTEuN2MxLjYtNC4xLTQuOC02LTUuMy0yLjJtLTEuNS01LjRjLjgtMiA4LS44IDUg'
    b'My41bTUuNSA1LjFjMi44LTIuNi0yLTcuOC01LTZtMjQgMTMuOWMtMi4yLjItNC41IDEuNy0y'
    b'LjkgNi41IDEuMiAzLjMgNi4xIDMuNCA2LjkgMS41Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNjAu'
    b'NSAzNjUuOWMtMi4yLTEuNS03IDEtNC44IDUuNiAxLjYgMy41IDUuOCAyIDYuNC4ybS0xNCAu'
    b'OGMxLjIgMiA2LjYgMSA3LjYtMW0tMy44LTUuNGMxLjItLjggMy4zLjIgMy43IDEuMm0tNC0z'
    b'M2MtMy44IDIuNS0xLjUgMTAgNC4zIDhtLTUuNi0xLjljLTMgMi4zLS4yIDkuNiA1LjMgNi44'
    b'bS00LjMgMGMtMi4xIDIuMS0uMSA3LjggNS4yIDYuN20tNi0zLjhjLTEuMi0uNS00LjItLjIt'
    b'NS41IDEuOG0yLjEtMjhjLTIuOCAyLjgtMS40IDguMyAzLjggOC44bS00LjgtM2MtNCAyLTQg'
    b'MTAgNCAxMC4zbS00LjMtMS4zYy0yLjMgMS44LTEuMiA4LjggNC42IDcuOW0tMi44LS4zYy0u'
    b'OC45LTEgMy0uMiAzLjltLTIuMy02LjVjLTIgMC00LjggMS41LTUuNSAzLjdtLTMuNy03LjVj'
    b'LjctMiA3LjEtMiA3LjYgNC4xbS42LTcuMmMtLjkuMi0yLjYgMS0zIDIuOG0uMi0yMS43Yy0y'
    b'LjcgMi42LTQgMTAuNSA0LjMgMTJtLTkuOSA0LjRjMC0yLjEgNS44LTQgNy44LS44TTIzMiAz'
    b'MjIuOGMuOCAxLjYgNC44IDMuOCA3LjIgMm0tMjgtMTQuNmE2LjMgNi4zIDAgMCAwIDcuMiA2'
    b'LjVjNC4zLS41IDUuMi00LjIgMy45LTYuN20tMy4yIDYuOWMtMi45IDMuNC42IDguMyAzLjgg'
    b'Ni45bS0uNi05LjRjMS43LS42IDcuMi0xLjQgOC45IDEuMm0tMjYuOC0uMmMtMS4zIDIgNi43'
    b'IDMuOSA5LjQuMm0tMi43IDEuOWMtLjMgMi42IDEgNyA3LjYgNS4xIi8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0yMTkuOCAzMjYuNmMxLTIuMi0zLjgtNS44LTcuNi0xLjgtMy43IDQgLjYgOC41IDIu'
    b'OSA3TTIwMi43IDMxOGMtMiAzLjQgNS41IDkuNSA5LjggMy44Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik0xOTcuNyAzMjMuOGMtMi43IDIuOC43IDcuOSA0LjcgNi4zIDQuMS0xLjUgMy43LTUuOCAy'
    b'LjctNi45Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xOTIuNSAzMjljLTIuMiAyIDAgNi42IDMgNi42'
    b'czQuOS0yLjMgNC4zLTUuNG01LTEuNmMtLjQgMyA0IDUgNi45IDIuMm0wLTUuNGMuNS0uNi4y'
    b'LTEuNy0uNS0yLjNtLTIzLjQgOS44Yy0yLjUgMiAzIDcuNiA2LjMgMi41bTEzLjEtMy41Yy0x'
    b'LjYgMS41IDEgNS41IDMuNiA0LjNtLTEyLjQtMS41Yy40IDIuNyA1LjggNC44IDkuMi42bS02'
    b'LjMgMi4xYy0uOCAxLjguOSA0LjUgMyA0LjJtNDguMyAxMS44Yy0yIDMuOSA0LjQgOC41IDkg'
    b'My43bS00LjQgMi4xYy0xIDIuMS4yIDUuMSAyIDYuMm0tOC0xLjdjLjQtMiAzLjItMy44IDUu'
    b'Ny0yLjltLTktMi4yYy4zLTEuOCAyLjYtMy41IDQuNC0zbTE0Ny4yLTc3LjRjLTkuMi4xLTUu'
    b'MyAxNC44IDIuNiAxMS45bS01LjYtMWMtMS44IDIuOSAxLjcgNy42IDUuNiA0LjhtLTEgLjZj'
    b'LTIuOCA0LjUgNi45IDExLjQgMTAuOCA0LjNtLTMuMSAyLjdjMCA0LjMgMTIuNSA3IDEwLjct'
    b'MS41bS0xLjIgNC42YzMgNSAxNCA1LjUgMTIuOS0ybS0yLjUgNS4yYzIuMyAzLjQgMTMuMiA1'
    b'LjQgMTIuOC0xLjVtLTU2LjctNDAuOGMxLjUgNCA2LjggNS40IDEyLjYgM20tMTYtLjJjMy43'
    b'IDIuMy0xLjYgMTIuOS03LjEgOC42bTcuMi0yYzQgMS45IDguOS41IDEwLjMtNS4ybS0yLjUg'
    b'NC40Yy40IDMgNC43IDUuMyAxMC4yIDQuMW0tMjAuMS0xYzUuMiA0LjQtMi4zIDEzLjQtNS43'
    b'IDkuM203LjYtNmMyLjUgMS44IDguOC44IDkuNC00bS0yLjggNGMuNSAzLjEgMyA0LjMgNi40'
    b'IDQuNG0tMTQuNC0uMWMyLjYgMy42IDkgNC42IDExLjktLjFtLTIuOSAyLjdjLS4yIDMuNCAz'
    b'LjYgNi4zIDcuNiA1LjVNMzc1IDI5NWMzLjMgMS43IDctNC43IDQuMS05bS0uMiAxNS43YzQg'
    b'LjIgNC41LTUuOC43LTkuMm04LjQgMTQuN2MzLjQtLjggMi4zLTguMS01LjgtOC43bTE2IDE0'
    b'LjFjMy4yLS45LjYtOS04LjMtOC41bTIwLjUgMTEuNGMyLjItMy40LTUtOS0xMS02bTE3IDEw'
    b'LjZjNCAxLjIgNi44LTkuNC01LjktNy43bTEzLjMgNy43YzMuNS0xIDYtNy4yLTQuMi01LjJt'
    b'MTIgNS43YzMgMS42IDQuNC03LjUtNS01bS00Ny0yM2MzLjkgMi4xIDEwLS40IDkuNC01LjNt'
    b'LTEuNSA0LjJjMS4zIDIuMy44IDYuOC0xLjcgOG0yLTIuNmMyLjYgMSA2LjEuMSA4LjItNG0t'
    b'My42IDRjLjcgMS44IDEgNS40LS43IDcuMm0xLjMtNC4xYzIuOSAxLjYgNi4yLS41IDcuNi0z'
    b'LjVtLTEuOCAyLjZjMiAxLjMgMy45IDcuMy40IDkuOG0yLTIuOGMyLjQgMCA2IDAgOC4zLTNt'
    b'LTEuNyAxLjdjMi4yLjYgNC44IDQuMiAzLjkgNy40bS4xLTEuMWMyLjUtLjMgNi43LTIgNy45'
    b'LTVtLTEuMiAyYTYuNiA2LjYgMCAwIDEgMy4yIDYuNW0wLTIuMWMyLjUtLjEgNC43LTEuNCA1'
    b'LjMtNC4xbS0uNiAxLjhjMS44LjYgNCAyLjcgNC4xIDUuMW0tLjMtMS41YzEuOC0uMyAzLjEt'
    b'MS40IDQuMy0zLjJtNC45LS4zYzIuMyAyLjMtLjggMTAtNS42IDguNm0tNDMuOS0xNjQuN2Mt'
    b'NC43IDIuOS0xOC4zIDItMTEuNi05LjJtMTMgMS42Yy05LjUgMy44LTIxLTMuNS05LTExLjNt'
    b'LTMuMi0yLjZjLTcuOCAwLTEzLjEgMTIuNi0yLjYgMTdNMzQ4LjYgMTM4Yy0yIDQgNS4zIDgu'
    b'NCAxMC4zIDQuNCAzLjktMy4xIDMuNi0xMS41IDEuMy0xNC43bS0xNS42IDE5LjhjLTIuNiA4'
    b'LjUgMTYuNCA5IDEzLjQtNC41bS0xNC40IDE3LjJjLjYgNi40IDE4LjEgNC4zIDEyLjUtOC43'
    b'bTItMy42YzEuNCAyIDUuMyA1LjMgMTEuOSA0LjZtLTktMTMuNWMuNiAyLjMgNC41IDQgOS41'
    b'IDIuM00xODUuNCAzMzQuOGMtNC41IDMuMSAyLjQgOC4xIDQuOSAyLjZtLTguNC0uMmMtNC40'
    b'IDMuMiAyLjQgOC4yIDQuOSAyLjdtLTguNi0uM2MtNC40IDMuMiAyLjQgOC4xIDUgMi43bS04'
    b'LjgtLjVjLTQuMyAyLjMuNyA3LjggNSAzbS05LjItLjljLTQuMyAyLjMuNyA3LjggNSAzbTE2'
    b'LjYtOS42Yy0uMSAzLjMgNi4xIDQuNiA4LjQtLjNtLTQuNSAzLjNjLTIgMi41IDEuNiA1LjUg'
    b'My41IDQuNG0tMTEuOC00LjhjLS4yIDIuOCA1LjIgNC40IDcuOCAxLjNtLTQuOSAxLjZjLTEu'
    b'NyAyLjIgMS43IDUuMyA0IDQuNG0tMTAuNS00LjhjLjIgMi4yIDMuMyA0LjcgNi42IDMuM20t'
    b'NC42LS4zYy0xLjMgMS4xLS43IDMuOCAxLjEgNC43bS03LjgtNWMtLjUgMiAyLjkgNS42IDYu'
    b'NCAzLjNtLTUuNy0xYy0yIDEuNy0xLjggNC4xLjggNC41bS01LjgtNC43Yy0uMiAxLjQgMS41'
    b'IDMuNiAzLjcgMy4zbS0xNC43LTMuNGMtMiAxLjEgMy4yIDYuNyA2LjUgMS41bS0xMS42Ljhj'
    b'LTIuNiAxLjIgMy44IDcuNCA2LjcgMS4xbTEwLTEuM2MtMiAuNC0zLjMgMy4zLTEuNiA0LjVt'
    b'LTUtMy41Yy0uMiAxLjIgMi4zIDMgNC4zIDIuNG0tNS45LTEuOWMtMiAxLjItLjkgNC42IDEu'
    b'NCA0LjFtLTguMy0xLjhjLTEuOCAxLjMtLjUgNCAyIDMuNG0xLjMtMy42YzAgLjcgMS43IDEu'
    b'OCAzIDEuM20tMTIuNS0yLjVjLTIuMyAxLTIuMSA2LjYgNS41IDMuNm0tMTAuNi0xLjNjLTMu'
    b'MiAxLjUtMi4xIDUuOCA0LjggMS43bS41LjNjLS44LjctMS43IDMuNSAxLjUgMi40bS03LjIt'
    b'MWMtMS4zIDEuMS0uNSAzLjUgMi4zIDIuNm0tOS0yLjJjLTIuMyAxLjMgMi44IDMuMSA2LjIt'
    b'LjVtLTQuNiAyLjFjLTEgMS0xIDQuMSAxLjYgM20tOC4yLTEuN2MtMS41IDEuMSAxIDIuNyA2'
    b'IC41bS00IDEuMWMtMS45IDEuNS0xLjcgMy40IDEgMi44bS02LjQtMmMtMiAxLjkuOSAzLjEg'
    b'NC40IDEuNm0tNC40LjVjLTMuNCAxLjUtMS45IDQuNC4yIDMuM20xMTMuOCA2LjVjLS44IDEu'
    b'NyAxLjggMy4xIDQuMyAyLjcgMi4zLS4zIDQuNi0yLjMgMi44LTVtLjEgMy40YzIuNCAxLjgg'
    b'Ni41LS4zIDYuNS0zIi8+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSIjZmZmIiBzdHJva2Utd2lk'
    b'dGg9Ii40Ij4KICAgICAgPHBhdGggZD0iTTM5Ni44IDEwM2MtMTAuMy01LTMxLjctMTQuNi0z'
    b'Ny44LTYuOSA1LjYtMi4zIDIxLjguMSAzNS4yIDEyLjVsMi42LTUuNXoiLz4KICAgICAgPHBh'
    b'dGggZD0iTTQwMyAxMDIuNWMtMTEuOS0xMy45LTE5LTEwLjgtMjcuNS0xNS41LTgtNC41LTIw'
    b'LjgtNS40LTIzLjMgMS43IDExLjctNS43IDIyLjUgMyAyOS4yIDQuMiA5IDEuNCAxNC4yIDgu'
    b'NSAxNi45IDExLjdsNC43LTJ6bTQ0LjktMS44Yy02LjItMTQuMS0xOS40LTEwLjQtMjUuMi0x'
    b'Ni40LTguNS04LjgtMzAtMTctMzktMTAuOSAxOS42LTEgMjggMTMuNSAzOC40IDE4LjYgNy41'
    b'IDMuNiAxNS41IDExLjMgMjUuOCA4Ljd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00MjQuNyA5OS4y'
    b'Yy0xMC41LTEzLjEtMjYuOC0yNC43LTM0LjItMjAuNCA5LjguNiAxMi45IDcuNCAxOS44IDEx'
    b'LjggNyA0LjMgMy45IDEwLjcgMTQuNCA4LjZ6bS01MC4yIDIzLjJjLTExLTQuMS0zMi43LTYu'
    b'Mi00Mi44IDYuNCAxNi44IDIuOSA0MiAxLjMgNDIuOC02LjR6Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik0zNzIuNCAxMjcuM2MtMTEtNS4yLTE5LjcgMi0zMC4xIDEtMTkuOC0yLTM0LS44LTM1Ljgg'
    b'OC44IDExLjMtMTAuMiAzMC40LTEuOCAzOC4xLTMuOSA3LjctMiAzNi4zLS4zIDQ1LjMgMy42'
    b'LTQuNi01LjctMTEuOC03LjItMTcuNS05LjV6bTM0LjgtMjkuNWMtMi42LTguNS0yLjQtMTcu'
    b'NSAxMC4zLTE2LjktMy4yLTQtMTUtNi0xNyA4LjktMTQtMTAuMy0yOS40LTEyLjEtMzIuMi0z'
    b'LjIgNy4yLTYuMiAxOC40LTEuNyAzMS44IDEzLjVhMjMuOCAyMy44IDAgMCAxIDcuMS0yLjN6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zODcuOSAxMDkuNWMtOC01LjItMTguOC0xMy41LjEtMTYu'
    b'OS04LTQuMy0yMC0yLjQtMTguNyAxMi41LTIxLjYtOC43LTM3LjEtNS44LTQwLjQgMi45LTMu'
    b'NiA5LjUgOS44IDE0LjggMTIuMSA4LjctMi40IDEtMTAuOC0xLjgtNi40LTcuMnMyNi44LTEu'
    b'MyA0OC4xIDkuOGM2IDMgMjYuMyAyLjYgNS4yLTkuOHoiLz4KICAgICAgPHBhdGggZD0iTTM4'
    b'Mi4yIDEyMy43Yy02LjEtMTIuNi0yNi4xLTEuMi0zMC4xLTEzLjQtNS42IDE3LjkgMjguNCA4'
    b'IDMwLjEgMTMuNHptMTI3LjEgMTMuNmM0LjIgMi4xIDcuOC0xLjIgMS40LTMuNyA0LjIgMiA3'
    b'LjktMS4xIDEuNS0zLjcgNC4yIDIgNy44LTEuMSAxLjQtMy43LTEuNyAxLjctNC4xIDgtNC4z'
    b'IDExLjF6bTIuMi0yNC4yYzkuMy05LjgtLjctMTMuMSAxMC42LTIzLjIgOS4zLTguMiAxLjgt'
    b'MTMuNyAxMC41LTIwIDIuOS0yLjEgOS02LjIgOS42LTEwLjQgMy43IDkuMy0xMS42IDEwLjYt'
    b'MTAuNiAyNS41LjcgOS41LTUuOCA4LjctOC4yIDI0LjgtLjUgMy4zLTIuOSAxMC44LTExLjkg'
    b'My4zeiIvPgogICAgICA8cGF0aCBkPSJNNTE1LjYgMTE3LjVjNS4yLTExIDExLjEtMTAuOSAx'
    b'NC0xNS4yIDUuNC04LjMgMTYuOCAxLjQgMjYuNS02LTEuNyAxMC41LTE0LjcgNi44LTIwLjQg'
    b'MTMuNS01LjYgNi43LTEwLjMgOS43LTIwIDcuN3oiLz4KICAgICAgPHBhdGggZD0iTTUxNyAx'
    b'MjEuMWM5LTcuMiAxNS42LTIuNCAyMS44LTYuMiAxNS43LTkuNSAyMiAyIDM2LTIuNi0zLjYg'
    b'OS0yNC40IDEuMy0zMy40IDhzLTQwLjcgMTMuMi0yNC41Ljh6bS0yNi4zIDUxLjRjLS4yLTQu'
    b'MS00LTkuNC05LjQtMTAtNS40LS43LTcuOC02LjQtMTEuOS02LjYtNC4xLS4zLTYuOC04LjUt'
    b'MTIuNS04LjQtNS42LjEtOCA3LjUgNS4zIDE0LjIgMTMuMyA2LjcgMjggMTQuNCAyOC41IDEw'
    b'Ljh6bS0xNi44IDMuNWMtNS42LjItNi40IDguNS0xMS44IDguNyA3LjQgNCAxMi45LTEuOCAx'
    b'Ni43LTdMNDc0IDE3NnoiLz4KICAgICAgPHBhdGggZD0iTTQ3OC42IDE3N2MtNSA0LjEtNi40'
    b'IDEyLjcuNyAxNS4yLTQuMi01LjkgNy41LTguNSAzLjktMTRsLTQuNi0xLjJ6Ii8+CiAgICAg'
    b'IDxwYXRoIGQ9Ik00ODMuNCAxNzcuM2MtMy44IDcuNCA2LjEgOC4zIDMuNSAxNCA1LjctMS4z'
    b'IDYuNi0xMiAxLjQtMTQuOGwtNC45Ljd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00NDUuNiAxNjEu'
    b'M2M5LjMtLjUgMTcuNyA0LjUgMjMuNCAxMi42IDMuNiA1LjEgMTUuNyA3LjIgMTkuOSAzIDQt'
    b'NCAxLjgtMTIuOC04LjUtMTAtMi42LTQuMy0xMC0yLjgtMTMuNy02LjQtMy42LTMuNi0xNy41'
    b'LTEzLjktMjEuMS44eiIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9'
    b'Ik00ODAuNCAxNjdjLTIuNS41LTMuMyA0LjctMS43IDYuOW03LTQuNGMuNyAxLjMuMiAzLjEt'
    b'LjIgNG0tMjUuMi0xMS44YzQuNy4yIDUuNiAzLjcgMTAuOCA1Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik00NTcuMSAxNTBhMTYxIDE2MSAwIDAgMSAzNy42IDEyLjNjOC4xIDQuNiAyMC43IDYgMzEu'
    b'NiAyLjggMTEtMyAzMi4yLTUuOSAzMS4xIDcuOCA1LjgtNi45LTEuNS0xNC4yLTE2LjItMTUu'
    b'NS4zLTYuNy02LjktMTIuNy0xMi04LjcgNC43LS43IDguOCA4LjItLjYgMTEuOGE4LjQgOC40'
    b'IDAgMCAwLTExLjctOS44YzQuNCAxLjMgOSA4LjgtMSAxMS42LTYuMyAxLjgtMTUuNC0uNS0y'
    b'Mi4yLTQuNi02LjgtNC4xLTQ1LTE5LTM2LjYtNy44eiIvPgogICAgICA8cGF0aCBkPSJNNDk4'
    b'LjYgMTQzLjNjLTUuMSAyLjMtMS44IDcuNy05LjcgMTAuOC04IDMtMTMuNiAxMC4xLTExLjgg'
    b'MTYuMiA1LjQtMTEuOSAxNS0xMS4zIDE4LjMtMTYgMy40LTQuNiA4LjMtMTEuNCAzLjItMTF6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MDAgMTQ0Yy0uMiA5LjQtNy42IDYtNC43IDE5LjIuOSA0'
    b'LjEgMi42IDEwLjgtLjMgMTcuNSA4LjMtNiAzLTE4LjcgNi43LTIzLjUgMS44LTIuNCA0LjIt'
    b'NiA1LTktMS45IDUuMy0xLjcgMTUuNCAzLjUgMTgtNC4yLTEwIDExLjUtMTguMy43LTMwLTEu'
    b'NiAzLTYuNSA4LTEwLjggNy44em0tMjYuMi05LjRjMS4zIDIgMi42IDYuOCAxLjQgOS42IDIu'
    b'Ni0xLjYgNi4zLTUuNiA3LjUtOC4zIDUuMy44IDcuMyA3LjMgMi4zIDEwLjIgMyAwIDguNCAw'
    b'IDExLjMtMy41LTMuNi00LTE0LjgtMTAuMi0yMi41LTh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0z'
    b'OTMuNyAxMTYuMWExMCAxMCAwIDAgMC00LjgtMmMtNy44LTEuNi0zLjctOC42IDIuOS04LjUg'
    b'MTQuMi0xNS41IDIyLjEtMy42IDM5LjQtOC40IDYtMS44IDEwLjItMS4zIDEzLjQuMiA3Ljgt'
    b'NS4yIDE2LjgtMy44IDIzLjQgMi4zYTUuMyA1LjMgMCAwIDEgMy0yLjRjNi4xLTEuNyAxMSAz'
    b'LjQgMTIuNyAxMC4xIDQuNy0uOCAxMC4xIDEuNSAxMy43IDQuNyA0LjktMi41IDguMi0yLjYg'
    b'OS41IDAgNC40LTIgMTAtMy40IDEyLjkgMy42cy02LjcgNC45LTguMyAxOS42Yy0xIDktMTEg'
    b'MTIuNi0xOSA3LjItMTIuOC04LjctMjUuMy0xMC0zMS41IDMtNi4xIDEzLjItMTEgMjAuOC0y'
    b'NiAxNi41YTE2IDE2IDAgMCAwLTE2LjcgNi41Yy00LjQgNi0xMSAuNC0xOSAxIDEwLTEuNSA2'
    b'LjEtNCAxNC45LTQuNiA4LS41IDUuOS04IDExLTktMjAgNS4xLTE5LjMtMi40LTM1LjggMi44'
    b'IDcuMi05LjMgMTguNi00LjEgMjQuMi05LjUtMTQuOS0uMy0yMS42LTEwLTI4LjMtNi0xMC41'
    b'IDYuNS02IDI0LjgtMzMuNSAyMy4yLTEzLjQtLjctMjEuOSAxLTI5LjggOSAxMy45LTI4Ljgg'
    b'MzIuOC0xMyA0Mi0yMi4xYTY4IDY4IDAgMCAwIDEyLjMtMTQuNyA2LjEgNi4xIDAgMCAxIDQt'
    b'My4yYy0yMi45LTcuMi05LTE4LjUgMTMuNC0xOS4zeiIvPgogICAgICA8cGF0aCBzdHJva2Ut'
    b'bGluZWNhcD0icm91bmQiIGQ9Ik01MDYuOSAxMTJjLjMuOC41IDEuOC41IDMgMCA1LjYtOC41'
    b'IDUuOC05IDE0LjItLjMgNC40LS44IDYuOC0zLjcgNi4zLTMtLjUtNS42LTUuMS0yLjgtMTAu'
    b'NSIvPgogICAgICA8cGF0aCBkPSJNMzk4IDEwNy43YTEwLjkgMTAuOSAwIDAgMC02LjItMi4x'
    b'bTUyLjgtOC4zYzYuOCAzIDEwLjEgMTAgMjAgMTAuNCA5LjYuMyAxNS41IDE0LjIgMzEuNSA1'
    b'LjFhMzggMzggMCAwIDEgMS4yLS42TTQ2OCA5OS43YTEyLjcgMTIuNyAwIDAgMC0xLjQgOC4y'
    b'bS0yOS44IDIxYy0xMiAwLTE1LjIgNi4xLTE1LjIgMTIgMCA2IDUuNyAxMy43IDE1LjcgMTMu'
    b'N3MxNS41LTYuMiAxNS41LTEyLjktNi4yLTEyLjktMTYtMTIuOXoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTTQzOSAxNTQuM2MtLjItMy4zLTYuMy0yLjgtNi01LjQuMi0yLjYgMy4zLTMuNiAzLjMt'
    b'Ny4yczUuNC0zLjkgNy4yLTFjMS44IDIuOCA3LjIgOC4zIDguNCA1LjVtLTguNC01LjVhOS45'
    b'IDkuOSAwIDAgMC0uNCAxMy4xbTQuMy04LjhjLTEgMi0xLjIgNS0uMSA2LjgiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0ibm9uZSIgZD0iTTQ5NS41IDEzNS42YzkuNS44IDExLTkuNyA0LTEwLjNt'
    b'LTE1LjctMTcuOGMtMy4yLTQuMi0xMC44LTUuNi0xMSAzLjIiLz4KICAgICAgPHBhdGggZD0i'
    b'TTQ3MiAxMjAuOGMtMy4yLTgtMTEuNS05LjEtMTUuOC01LjEtMy43IDMuMy0zLjggMTIgNCAx'
    b'My44IDIuOC0zLjMgOC03LjUgMTEuOC04Ljd6bS0zLjUtNWMtNC43LTQuMS0xMS41IDMuNy01'
    b'LjMgMTAuOG0tODMgOC43YzMuMi0uNyA3LjcuOCAxNC43IDQgNC4zIDIuMSAxNy41IDYuNSAy'
    b'NS43IDIuMS04LjUgMy4xLTE1LTkuNy0yMS40LTguMi02LjQgMS42LTE4LjIgNC0yMy4xLS44'
    b'IDEyIC44IDE4LjUtOC44IDMyLjQtLjVhMjQgMjQgMCAwIDAgMTMuMSAzLjZjLTExLjMtMTMu'
    b'Ni0yNi4yLTQuOS0yNy44LTE2IDYuOCA3LjQgMjMuNS0xLjYgMzIgMTIuMW0tMjkuNS0xMGMt'
    b'MS42LTItMS00LTIuNi01LjUiLz4KICAgIDwvZz4KICAgIDxwYXRoIHN0cm9rZT0ibm9uZSIg'
    b'ZD0iTTQ4My44IDEwNy41Yy0yLjgtMy05LS43LTcuMiA1LjRhOS42IDkuNiAwIDAgMSA3LjIt'
    b'NS41ek00NjYuMyAxMjRhMjEuMSAyMS4xIDAgMCAxIDUuNy0zLjIgMTIuNCAxMi40IDAgMCAw'
    b'LTMuOC01LjJjLTEuNS0xLTUuNyA0LjctMS45IDguM3oiLz4KICAgIDxwYXRoIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0iTTQ1OC43'
    b'IDExMy41Yy00LjYtMy4xLTguOS0yLjgtMTAuMy0uMy0zLjMgMC02LjEgMi40LTYuMiA3LjJt'
    b'Ny4xIDIuMWMtNS41LTMuOC0xMy4xLTIuNC0xMi42IDYuMW0tMy40IDQuOWMyLjctMi4yIDYu'
    b'Ni0zLjggOS42IDBtMzEuOC04LjRjLTEgMS40LTEuOCAzLjYtLjEgNy0yLTIuOC03LjItMi44'
    b'LTEyLjggNC40bTI1LjEtMTEuOGMtNi43LjgtNi41IDUuMi0xLjEgN20tNDYuNS0yMy40Yy01'
    b'LjctMS4xLTkuOCAyLjItMiA1bTEyLjgtOC44Yy04LTItMTEuMi4xLTcuNiAybS0xNS41IDMw'
    b'Yy0uMiAyLjkgMS4zIDYuNiA2IDIuNG0tNC40IDYuMWMwIC44LS4xIDEuNy0uNyAyLjRtLTE3'
    b'LjktNDBjLTQuOS0xLjUtNS44LTYgMC01LjZtLTEuNiAxNmMtNS40LTEuOS01LjQtNy4xLTEt'
    b'Ni42bTExIDMuOGMtNi4zLTEuNS02LjUtNS45LTEuOC01LjJtMi42LTguMmMtMy40LS4yLTgu'
    b'NSAzLjUuMSA1LjdtOS4zIDEuOGMtNy45LTEuMS03LjcgMi0zLjEgNC4xbTktMTEuNmMtNi0x'
    b'LjEtOC4xIDIuNS00IDRtLTE1IDE4LjNjLTEuNS0xLjItMi43LTcgNC4zLTUuM20xMC4zIDMu'
    b'NWMtNC43LTEuMy05LjIgMy40LTQuOSA2bTExLjItMTEuNWMtNS0xLTkuMi41LTYuNSAyLjMi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00ODMuNiAx'
    b'MDcuNWE5LjYgOS42IDAgMCAwLTcgNS40Ii8+CiAgPC9nPgo8L3N2Zz4K', 'BT')

BT = b64_BT
index.append("BT")
index.append("BTN")
index.append("Bhutan")
catalog["BT"] = BT
catalog["BTN"] = BT
catalog["Bhutan"] = BT
country["Bhutan"] = ('BT', 'BTN', 0)
lookup["BT"] = ('BT', 'BTN', 'Bhutan', 0)
lookup["Thimphu Bhutan"] = ('BT', 'BTN', 'Bhutan', 0)
lookup["BTN"] = ('BT', 'BTN', 'Bhutan', 0)
lookup["Bhutan"] = ('BT', 'BTN', 'Bhutan', 0)
details["BT"] = {"continent":"Asia","capital":"Thimphu","currency":"Indian Rupee | Ngultrum","web":".bt","lang":"dz","tz":"+06:00","altname":""}
#----------------------------------------------------------------------
b64_BV = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJ2IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImJ2LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGNsaXAtcGF0aD0idXJsKCNidi1hKSI+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNLTI4IDBoNjk5Ljd2NTEySC0yOHoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNkNzI4MjgiIGQ9Ik0tNTMtNzcuOGgyMTguN3YyNzYuMkgtNTN6TTI4OS40LS42aDM4'
    b'MXYxOTloLTM4MXpNLTI3LjYgMzIwaDE5MC40djE5MC4zSC0yNy42em0zMTkuNiAyLjFoMzc4'
    b'LjN2MTg4LjJIMjkyeiIvPgogICAgPHBhdGggZmlsbD0iIzAwMzg5NyIgZD0iTTE5Ni43LTI1'
    b'LjRIMjYxdjUzNS43aC02NC41eiIvPgogICAgPHBhdGggZmlsbD0iIzAwMzg5NyIgZD0iTS0y'
    b'Ny42IDIyNC44aDY5OHY2My41aC02OTh6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'BV')

BV = b64_BV
index.append("BV")
index.append("BVT")
index.append("Bouvet Island")
catalog["BV"] = BV
catalog["BVT"] = BV
catalog["Bouvet Island"] = BV
country["Bouvet Island"] = ('BV', 'BVT', 0)
lookup["BV"] = ('BV', 'BVT', 'Bouvet Island', 0)
lookup["BVT"] = ('BV', 'BVT', 'Bouvet Island', 0)
lookup["Bouvet Island"] = ('BV', 'BVT', 'Bouvet Island', 0)
details["BV"] = {"continent":"Americas","capital":"","currency":"Norwegian Krone","web":".bv","lang":"","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_BW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJ3IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMGNiZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0iTTAgMTYwaDY0MHYxNjBIMHoiLz4KICAgIDxwYXRoIGQ9Ik0w'
    b'IDE4Nmg2NDB2MTA4SDB6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'BW')

BW = b64_BW
index.append("BW")
index.append("BWA")
index.append("Botswana")
catalog["BW"] = BW
catalog["BWA"] = BW
catalog["Botswana"] = BW
country["Botswana"] = ('BW', 'BWA', 0)
lookup["BW"] = ('BW', 'BWA', 'Botswana', 0)
lookup["Gaborone Botswana"] = ('BW', 'BWA', 'Botswana', 0)
lookup["BWA"] = ('BW', 'BWA', 'Botswana', 0)
lookup["Botswana"] = ('BW', 'BWA', 'Botswana', 0)
details["BW"] = {"continent":"Africa","capital":"Gaborone","currency":"Pula","web":".bw","lang":"en-BW | tn-BW","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_BY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWJ5IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImJ5LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi42djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBjbGlwLXBhdGg9InVybCgjYnktYSkiIHRyYW5zZm9ybT0ic2NhbGUoLjkzNzYgLjkz'
    b'NzUpIj4KICAgIDxwYXRoIGZpbGw9IiNiMjAwMDAiIGQ9Ik0wIDBoMTAyNHYzNDAuMUgweiIv'
    b'PgogICAgPHBhdGggZmlsbD0iIzQyOWYwMCIgZD0iTTAgMzQwLjFoMTAyNFY1MTJIMHoiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoMTEzLjR2NTEySDB6Ii8+CiAgICA8ZyBm'
    b'aWxsPSIjYjIwMDAwIiBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Ik01LjQg'
    b'OC43aDUuNHY4LjdINS40em0xNi4yIDBoMTYuMnY4LjdIMjEuNnpNMjcgMGg1LjR2OC43SDI3'
    b'em0yNyAwaDUuNHY4LjdINTR6bTIxLjYgOC43aDE2LjJ2OC43SDc1LjZ6TTgxIDBoNS40djgu'
    b'N0g4MXpNMTYuMiAxNy40SDI3VjI2SDE2LjJ6bTE2LjIgMGgxMC44VjI2SDMyLjR6bTM3Ljgg'
    b'MEg4MVYyNkg3MC4yem0xNi4yIDBoMTAuOFYyNkg4Ni40ek0xMC44IDI2aDEwLjh2OC43SDEw'
    b'Ljh6bTI3IDBoMTAuOHY4LjdIMzcuOHptMjcgMGgxMC44djguN0g2NC44em0yNyAwaDEwLjh2'
    b'OC43SDkxLjh6bTEwLjgtMTcuM2g1LjR2OC43aC01LjR6bS05Ny4yIDI2aDEwLjh2OC43SDUu'
    b'NHptMzcuOCAwSDU0djguN0g0My4yem01NCAwSDEwOHY4LjdIOTcuMnptLTg2LjQgMjZoMTAu'
    b'OHY4LjdIMTAuOHptNS40IDguN0gyN3Y4LjdIMTYuMnptMjEuNi04LjZoMTAuOHY4LjZIMzcu'
    b'OHptLTUuNCA4LjZoMTAuOHY4LjdIMzIuNHptLTEwLjggOC43aDE2LjJ2OC43SDIxLjZ6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik0yNyA4Ni44aDUuNHY4LjdIMjd6bTM3LjgtMjZoMTAuOHY4LjZI'
    b'NjQuOHptNS40IDguNkg4MXY4LjdINzAuMnptMjEuNi04LjZoMTAuOHY4LjZIOTEuOHptLTUu'
    b'NCA4LjZoMTAuOHY4LjdIODYuNHptLTEwLjggOC43aDE2LjJ2OC43SDc1LjZ6bTUuNCA4Ljdo'
    b'NS40djguN0g4MXpNNTQgNzhoNS40djguN0g1NHpNMCA3OGg1LjR2OC43SDB6bTEwOCAwaDUu'
    b'NHY4LjdIMTA4em0tODEgNDMuNGg1LjR2OC43SDI3em0tNS40IDguOGgxNi4ydjguNkgyMS42'
    b'em0tNS40IDguNmgyN3Y4LjdoLTI3ek04MSAxMjEuNWg1LjR2OC43SDgxem0tNS40IDguN2gx'
    b'Ni4ydjguNkg3NS42em0tNS40IDguNmgyN3Y4LjdoLTI3em01LjQgNDMuNGgyN3Y4LjdoLTI3'
    b'em0tMTAuOC0zNC43aDM3Ljh2OC43SDY0Ljh6bS01NCAwaDM3Ljh2OC43SDEwLjh6bTUuNCA0'
    b'My40aDE2LjJ2OC43SDE2LjJ6bS01LjQtOC43aDI3djguN2gtMjd6TTg2LjQgMTY1aDI3djgu'
    b'N2gtMjd6TTgxIDE5MWgxNi4ydjguN0g4MXoiLz4KICAgICAgPHBhdGggZD0iTTIxLjYgMTk5'
    b'LjZIMjd2OC43aC01LjR6bTY0LjggMGg1LjR2OC43aC01LjR6TTAgMTY0LjloMjd2OC43SDB6'
    b'bTQ4LjYgMTcuM2gxNi4ydjguN0g0OC42ek01NCAxOTFoNS40djguN0g1NHptLTE2LjItMjZo'
    b'MzcuOHY4LjdIMzcuOHpNNTkuNCAzNC43aDEwLjh2OC43SDU5LjR6bS0xMC44IDguN2gxNi4y'
    b'djguN0g0OC42em0tNS40IDguN0g1NHY4LjZINDMuMnptMTYuMiAwaDEwLjh2OC42SDU5LjR6'
    b'TTAgNDMuNGgxMC44djguN0gwem01LjQgOC43aDEwLjh2OC42SDUuNHptOTcuMi04LjdoMTAu'
    b'OFY1MmgtMTAuOHpNOTcuMiA1MkgxMDh2OC42SDk3LjJ6TTAgMTMwaDUuNHY4LjdIMHptMTA4'
    b'IDBoNS40djguN0gxMDh6bS01OS40IDY5LjVoMTYuMnY4LjdINDguNnptLTUuNCA4LjdINTR2'
    b'OC42SDQzLjJ6bTE2LjIgMGgxMC44djguNkg1OS40em0tMjEuNiA4LjZoMTAuOHY4LjdIMzcu'
    b'OHptMjcgMGgxMC44djguN0g2NC44em0tMzIuNCA4LjdoMTAuOHY4LjdIMzIuNHptMzcuOCAw'
    b'SDgxdjguN0g3MC4yek0yNyAyMzQuM2gxMC44djguN0gyN3ptNDguNiAwaDEwLjh2OC43SDc1'
    b'LjZ6TTE2LjIgMjQzaDE2LjJ2OC43SDE2LjJ6bTY0LjggMGgxNi4ydjguN0g4MXptMTAuOC04'
    b'LjdoMTAuOHY4LjdIOTEuOHptNS40LTguN0gxMDh2OC43SDk3LjJ6bTUuNC04LjdoMTAuOHY4'
    b'LjdoLTEwLjh6bS05MS44IDE3LjRoMTAuOHY4LjdIMTAuOHptLTUuNC04LjdoMTAuOHY4LjdI'
    b'NS40ek0wIDIxN2gxMC44djguN0gwem0yMS42IDM0LjhIMjd2OC42aC01LjR6bTY0LjggMGg1'
    b'LjR2OC42aC01LjR6bS0zMi40LTI2aDUuNHY4LjZINTR6bS0xNi4yIDI2aDUuNHY4LjZoLTUu'
    b'NHptMzIuNCAwaDUuNHY4LjZoLTUuNHptLTE2LjIgMGg1LjR2OC42SDU0em0tNTQgMGg1LjR2'
    b'OC42SDB6bTEwOCAwaDUuNHY4LjZIMTA4ek01NCAxMzAuMmg1LjR2OC42SDU0ek0yNyA0My40'
    b'aDUuNHY4LjdIMjd6bTU0IDBoNS40djguN0g4MXptLTMyLjQgNjAuN2gxNi4ydjguN0g0OC42'
    b'em0tMTAuOCA4LjdINTR2OC43SDM3Ljh6bTUuNCA4LjdoNS40djguN2gtNS40em0tMTAuOC0x'
    b'Ny40aDEwLjh2OC43SDMyLjR6bTUuNC04LjZINTR2OC42SDM3Ljh6bTUuNC04LjdoNS40djgu'
    b'N2gtNS40em0xNi4yIDguN2gxNi4ydjguNkg1OS40em01LjQtOC43aDUuNHY4LjdoLTUuNHpt'
    b'NS40IDE3LjNIODF2OC43SDcwLjJ6bS0xMC44IDguN2gxNi4ydjguN0g1OS40em01LjQgOC43'
    b'aDUuNHY4LjdoLTUuNHptMjEuNi0xNy40aDEwLjh2OC43SDg2LjR6bTUuNC04LjZIMTA4djgu'
    b'Nkg5MS44em0xMC44IDguNmgxMC44djguN2gtMTAuOHptLTEwLjggOC43SDEwOHY4LjdIOTEu'
    b'OHptNS40IDguN2g1LjR2OC43aC01LjR6bTAtMzQuN2g1LjR2OC43aC01LjR6TTAgMTA0aDEw'
    b'Ljh2OC43SDB6bTUuNC04LjZoMTYuMnY4LjZINS40em0xMC44IDguNkgyN3Y4LjdIMTYuMnpt'
    b'LTEwLjggOC43aDE2LjJ2OC43SDUuNHoiLz4KICAgICAgPHBhdGggZD0iTTEwLjggMTIxLjVo'
    b'NS40djguN2gtNS40em0wLTM0LjdoNS40djguN2gtNS40em0tNS40IDY5LjRIMjd2OC43SDUu'
    b'NHptMjcgMEg1NHY4LjdIMzIuNHptMjcgMEg4MXY4LjdINTkuNHptMjcgMEgxMDh2OC43SDg2'
    b'LjR6bS00My4yIDE3LjRoMjd2OC42aC0yN3ptLTM3LjggMGgyN3Y4LjZoLTI3em03NS42IDBo'
    b'Mjd2OC42SDgxem0yNyAzNC43aDUuNHY4LjZIMTA4em0tMTA4IDBoNS40djguNkgwem01LjQg'
    b'Mjk1aDUuNHYtOC42SDUuNHptMTYuMiAwaDE2LjJ2LTguNkgyMS42ek0yNyA1MTJoNS40di04'
    b'LjdIMjd6bTI3IDBoNS40di04LjdINTR6bTIxLjYtOC43aDE2LjJ2LTguN0g3NS42ek04MSA1'
    b'MTJoNS40di04LjdIODF6bS02NC44LTE3LjRIMjdWNDg2SDE2LjJ6bTE2LjIgMGgxMC44VjQ4'
    b'NkgzMi40em0zNy44IDBIODFWNDg2SDcwLjJ6bTE2LjIgMGgxMC44VjQ4Nkg4Ni40ek0zNy44'
    b'IDQ4NmgxMC44di04LjdIMzcuOHptMjcgMGgxMC44di04LjdINjQuOHptMjcgMGgxMC44di04'
    b'LjdIOTEuOHptMTAuOCAxNy4zaDUuNHYtOC43aC01LjR6bS05Ny4yLTI2aDEwLjh2LTguN0g1'
    b'LjR6bTM3LjggMEg1NHYtOC43SDQzLjJ6bTU0IDBIMTA4di04LjdIOTcuMnptLTg2LjQtMjZo'
    b'MTAuOHYtOC43SDEwLjh6bTUuNC04LjdIMjd2LTguN0gxNi4yem0yMS42IDguN2gxMC44di04'
    b'LjdIMzcuOHptLTUuNC04LjdoMTAuOHYtOC43SDMyLjR6bS0xMC44LTguN2gxNi4ydi04LjdI'
    b'MjEuNnptNS40LTguN2g1LjR2LTguNkgyN3ptMzcuOCAyNmgxMC44di04LjZINjQuOHptNS40'
    b'LTguNkg4MXYtOC43SDcwLjJ6bTIxLjYgOC43aDEwLjh2LTguN0g5MS44em0tNS40LTguN2gx'
    b'MC44di04LjdIODYuNHptLTEwLjgtOC43aDE2LjJ2LTguN0g3NS42em01LjQtOC43aDUuNHYt'
    b'OC42SDgxek01NCA0MzRoNS40di04LjdINTR6bS01NCAwaDUuNHYtOC43SDB6bTEwOCAwaDUu'
    b'NHYtOC43SDEwOHptLTgxLTQzLjRoNS40di04LjdIMjd6bS01LjQtOC44aDE2LjJ2LTguNkgy'
    b'MS42em0tNS40LTguNmgyN3YtOC43aC0yN3pNODEgMzkwLjVoNS40di04LjdIODF6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik03NS42IDM4MS44aDE2LjJ2LTguNkg3NS42em0tNS40LTguNmgyN3Yt'
    b'OC43aC0yN3ptNS40LTQzLjRoMjdWMzIxaC0yN3ptLTEwLjggMzQuN2gzNy44di04LjdINjQu'
    b'OHptLTU0IDBoMzcuOHYtOC43SDEwLjh6bTUuNC00My40aDE2LjJ2LTguN0gxNi4yem0tNS40'
    b'IDguN2gyN1YzMjFoLTI3ek04Ni40IDM0N2gyN3YtOC43aC0yN3pNODEgMzIxaDE2LjJ2LTgu'
    b'N0g4MXpNMCAzNDdoMjd2LTguN0gwem00OC42LTE3LjNoMTYuMlYzMjFINDguNnpNNTQgMzIx'
    b'aDUuNHYtOC43SDU0em0tMTYuMiAyNmgzNy44di04LjdIMzcuOHptMjEuNiAxMzAuMmgxMC44'
    b'di04LjdINTkuNHptLTEwLjgtOC43aDE2LjJWNDYwSDQ4LjZ6bS01LjQtOC43SDU0di04LjdI'
    b'NDMuMnptMTYuMiAwaDEwLjh2LTguN0g1OS40ek0wIDQ2OC42aDEwLjhWNDYwSDB6bTUuNC04'
    b'LjdoMTAuOHYtOC42SDUuNHptOTcuMiA4LjdoMTAuOFY0NjBoLTEwLjh6bS01LjQtOC43SDEw'
    b'OHYtOC42SDk3LjJ6TTAgMzgyaDUuNHYtOC43SDB6bTEwOCAwaDUuNHYtOC43SDEwOHptLTY0'
    b'LjgtNzguMkg1NHYtOC42SDQzLjJ6bTE2LjIgMGgxMC44di04LjZINTkuNHptLTIxLjYtOC42'
    b'aDEwLjh2LTguN0gzNy44em0yNyAwaDEwLjh2LTguN0g2NC44em0tMzIuNC04LjdoMTAuOHYt'
    b'OC43SDMyLjR6bTM3LjggMEg4MXYtOC43SDcwLjJ6TTI3IDI3Ny43aDEwLjhWMjY5SDI3em00'
    b'OC42IDBoMTAuOFYyNjlINzUuNnpNMTYuMiAyNjloMTYuMnYtOC43SDE2LjJ6bTY0LjggMGgx'
    b'Ni4ydi04LjdIODF6bTEwLjggOC43aDEwLjhWMjY5SDkxLjh6bTUuNCA4LjdIMTA4di04LjdI'
    b'OTcuMnptNS40IDguN2gxMC44di04LjdoLTEwLjh6bS05MS44LTE3LjRoMTAuOFYyNjlIMTAu'
    b'OHptLTUuNCA4LjdoMTAuOHYtOC43SDUuNHpNMCAyOTVoMTAuOHYtOC43SDB6bTIxLjYtMzQu'
    b'OEgyN3YtOC42aC01LjR6bTMyLjQgMjZoNS40di04LjZINTR6bTAgOTUuNWg1LjR2LTguNkg1'
    b'NHptLTI3IDg2LjhoNS40VjQ2MEgyN3ptNTQgMGg1LjRWNDYwSDgxek00OC42IDQwOGgxNi4y'
    b'di04LjdINDguNnptLTEwLjgtOC43SDU0di04LjdIMzcuOHptNS40LTguN2g1LjR2LTguN2gt'
    b'NS40ek0zMi40IDQwOGgxMC44di04LjdIMzIuNHptNS40IDguNUg1NFY0MDhIMzcuOHptNS40'
    b'IDguN2g1LjR2LTguNmgtNS40em0xNi4yLTguN2gxNi4yVjQwOEg1OS40em01LjQgOC43aDUu'
    b'NHYtOC42aC01LjR6bTUuNC0xNy4zSDgxdi04LjdINzAuMnptLTEwLjgtOC43aDE2LjJ2LTgu'
    b'N0g1OS40em01LjQtOC43aDUuNHYtOC43aC01LjR6TTg2LjQgNDA4aDEwLjh2LTguN0g4Ni40'
    b'em01LjQgOC41SDEwOFY0MDhIOTEuOHptMTAuOC04LjZoMTAuOHYtOC43aC0xMC44em0tMTAu'
    b'OC04LjdIMTA4di04LjdIOTEuOHptNS40LTguN2g1LjR2LTguN2gtNS40em0wIDM0LjdoNS40'
    b'di04LjZoLTUuNHpNMCA0MDhoMTAuOHYtOC43SDB6bTUuNCA4LjVoMTYuMlY0MDhINS40eiIv'
    b'PgogICAgICA8cGF0aCBkPSJNMTYuMiA0MDcuOUgyN3YtOC43SDE2LjJ6bS0xMC44LTguN2gx'
    b'Ni4ydi04LjdINS40em01LjQtOC43aDUuNHYtOC43aC01LjR6bTAgMzQuN2g1LjR2LTguNmgt'
    b'NS40em0tNS40LTY5LjRIMjd2LTguN0g1LjR6bTI3IDBINTR2LTguN0gzMi40em0yNyAwSDgx'
    b'di04LjdINTkuNHptMjcgMEgxMDh2LTguN0g4Ni40em0tNDMuMi0xNy40aDI3di04LjZoLTI3'
    b'em0tMzcuOCAwaDI3di04LjZoLTI3em03NS42IDBoMjd2LTguNkg4MXptMjctMzQuNmg1LjRW'
    b'Mjk1SDEwOHptLTEwOCAwaDUuNFYyOTVIMHptNDguNi00My41SDU0djguN2gtNS40em0xMC44'
    b'IDBoNS40djguN2gtNS40em0wLTE3LjNoNS40djguN2gtNS40em0tMTAuOCAwSDU0djguN2gt'
    b'NS40ek0xMC44IDQ3Ny4zaDEwLjh2OC43SDEwLjh6bTc1LjYtMTY0LjloNS40di04LjdoLTUu'
    b'NHptLTY0LjggMEgyN3YtOC43aC01LjR6bTI3LTguN2gxNi4ydjguN0g0OC42eiIvPgogICAg'
    b'PC9nPgogIDwvZz4KPC9zdmc+Cg==', 'BY')

BY = b64_BY
index.append("BY")
index.append("BLR")
index.append("Belarus")
catalog["BY"] = BY
catalog["BLR"] = BY
catalog["Belarus"] = BY
country["Belarus"] = ('BY', 'BLR', 0)
lookup["BY"] = ('BY', 'BLR', 'Belarus', 0)
lookup["Minsk Belarus"] = ('BY', 'BLR', 'Belarus', 0)
lookup["BLR"] = ('BY', 'BLR', 'Belarus', 0)
lookup["Belarus"] = ('BY', 'BLR', 'Belarus', 0)
details["BY"] = {"continent":"Europe","capital":"Minsk","currency":"Belarusian Ruble","web":".by","lang":"be | ru","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_BZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ieiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHJhZGlhbEdyYWRpZW50IGlkPSJiei1h'
    b'Ij4KICAgICAgPHN0b3Agb2Zmc2V0PSIwIiBzdG9wLWNvbG9yPSIjZmZlZjVkIi8+CiAgICAg'
    b'IDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iI2VhNTcwMCIvPgogICAgPC9yYWRpYWxH'
    b'cmFkaWVudD4KICAgIDxyYWRpYWxHcmFkaWVudCBpZD0iYnotYiI+CiAgICAgIDxzdG9wIG9m'
    b'ZnNldD0iMCIgc3RvcC1jb2xvcj0iIzk1MmQxYSIvPgogICAgICA8c3RvcCBvZmZzZXQ9IjEi'
    b'IHN0b3AtY29sb3I9IiM1NzBhMDAiLz4KICAgIDwvcmFkaWFsR3JhZGllbnQ+CiAgICA8cmFk'
    b'aWFsR3JhZGllbnQgeGxpbms6aHJlZj0iI2J6LWEiIGlkPSJiei1jIiBjeD0iMjQ3LjEiIGN5'
    b'PSIyMzguMyIgcj0iMzYiIGZ4PSIyNDcuMSIgZnk9IjIzOC4zIiBncmFkaWVudFRyYW5zZm9y'
    b'bT0ic2NhbGUoMS4yMjYyNCAuODE1NSkiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNl'
    b'Ii8+CiAgICA8cmFkaWFsR3JhZGllbnQgeGxpbms6aHJlZj0iI2J6LWEiIGlkPSJiei1kIiBj'
    b'eD0iMzIyIiBjeT0iMTUyLjkiIHI9IjEwLjYiIGZ4PSIzMjIiIGZ5PSIxNTIuOSIgZ3JhZGll'
    b'bnRUcmFuc2Zvcm09InNjYWxlKC45MzYxNSAxLjA2ODIxKSIgZ3JhZGllbnRVbml0cz0idXNl'
    b'clNwYWNlT25Vc2UiLz4KICAgIDxyYWRpYWxHcmFkaWVudCB4bGluazpocmVmPSIjYnotYiIg'
    b'aWQ9ImJ6LWUiIGN4PSIzNjQuMiIgY3k9IjIzNy44IiByPSIzNiIgZng9IjM2NC4yIiBmeT0i'
    b'MjM3LjgiIGdyYWRpZW50VHJhbnNmb3JtPSJzY2FsZSgxLjIyNDIgLjgxNjg2KSIgZ3JhZGll'
    b'bnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxyYWRpYWxHcmFkaWVudCB4bGluazpo'
    b'cmVmPSIjYnotYiIgaWQ9ImJ6LWYiIGN4PSI0NjguMSIgY3k9IjE1Ni4xIiByPSIxMC43IiBm'
    b'eD0iNDY4LjEiIGZ5PSIxNTYuMSIgZ3JhZGllbnRUcmFuc2Zvcm09InNjYWxlKC45NTU5NiAx'
    b'LjA0NjA3KSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICA8L2RlZnM+CiAg'
    b'PHBhdGggZmlsbD0iI2NlMTEyNiIgZD0iTTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmls'
    b'bD0iIzAwM2Y4NyIgZD0iTTAgMzQuM2g2NDB2NDExLjRIMHoiLz4KICA8Y2lyY2xlIGN4PSIz'
    b'MjAiIGN5PSIyNDAiIHI9IjE4OC42IiBmaWxsPSIjZmZmIi8+CiAgPGNpcmNsZSBjeD0iMzIw'
    b'IiBjeT0iMjM5IiByPSIxNTYuMyIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNTUyMzAwIiBzdHJv'
    b'a2Utd2lkdGg9IjMuOSIvPgogIDxwYXRoIGZpbGw9IiMwMDdmMDAiIGQ9Ik0zMDIgNzMuMmMx'
    b'NC0xNS4yIDI2LjkgMi4zIDI2LjUgMTAuNkMzMjguMiA5MiAzMTQgMTEwIDMwMSA5NS41YzEz'
    b'LjQgMy40IDE3LjQtMTEuNSAyNC4xLTExLjctNi43LjItOS41LTE0LjYtMjMuMi0xMC42em0t'
    b'MTQ3LjIgMTE5Yy03LjQtMTkuNCAxNC0yMyAyMS4zLTE5IDcuMyAzLjkgMTcuMyAyNC42LTEu'
    b'NiAyOS42IDktMTAuNC0yLjctMjAuNS4yLTI2LjYtMi45IDYtMTcuNSAyLTE5LjkgMTZ6TTQ3'
    b'MS45IDE3M2MxOS40IDcuNiA3LjYgMjUuOC0uMiAyOC40LTcuOSAyLjctMzAtNC0yMS0yMS4y'
    b'IDEuNiAxMy42IDE3IDEyIDE5LjcgMTguMS0yLjYtNi4yIDEwLjMtMTQgMS41LTI1LjN6TTIx'
    b'OC44IDM3Ny40Yy0yMC43LTItMTQuMy0yMi43LTcuNS0yNy40IDYuOC00LjcgMzAtNC4zIDI2'
    b'IDE0LjctNS4zLTEyLjYtMTkuNy02LjgtMjQtMTIgNC4zIDUuMi02IDE2LjMgNS41IDI0Ljd6'
    b'bTIwOS4zLTE1Yy4zIDIwLjctMjEuMSAxNi44LTI2LjYgMTAuNi01LjQtNi4yLTcuNy0yOSAx'
    b'MS44LTI3LjMtMTIgNi42LTQuNiAyMC4yLTkuNCAyNSA0LjgtNC44IDE3LjEgNCAyNC4yLTgu'
    b'MnpNMTcwIDE1M2MtMS45LTIwLjYgMTkuOC0xOC4zIDI1LjctMTIuNiA2IDUuOCAxMCAyOC40'
    b'LTkuNiAyOC4yIDExLjUtNy42IDMtMjAuNSA3LjQtMjUuNi00LjQgNS0xNy4zLTIuOC0yMy41'
    b'IDEwem0yMi4yIDE5M2MtMjAuNS0zLjUtMTIuNy0yMy43LTUuNi0yNy45IDctNC4yIDMwLjEt'
    b'Mi4zIDI1IDE2LjQtNC41LTEzLTE5LjMtOC0yMy4xLTEzLjYgMy44IDUuNS03LjIgMTYgMy43'
    b'IDI1ek0zNTQuMyA3NGMxOC42LTkuMiAyNC4zIDExLjcgMjEgMTkuMy0zLjIgNy41LTIzIDE5'
    b'LjQtMjkuOCAxLjMgMTEuMiA3LjkgMjAuMy00LjcgMjYuNy0yLjQtNi40LTIuMy0zLjctMTct'
    b'MTcuOS0xOC4yek0zOTQgMzg4LjNjLTkuMyAxOC41LTI2LjUgNS4zLTI4LjUtMi43czYuNS0y'
    b'OS4zIDIzLTE5Yy0xMy44LjUtMTMuNCAxNi0xOS44IDE4IDYuNC0yIDEzLjMgMTEuNCAyNS4z'
    b'IDMuN3ptOTAuNS0xNzguN2MxNS42IDEzLjctMS43IDI2LjgtMTAgMjYuNy04LjItLjEtMjYu'
    b'OC0xMy44LTEyLjUtMjctMyAxMy40IDEyIDE3IDEyLjQgMjMuNi0uMy02LjcgMTQuNS05Ljgg'
    b'MTAtMjMuM3ptLTI2My0xMDguOGM0LjctMjAgMjQuNS0xMS4yIDI4LjQtMy45IDMuOCA3LjMu'
    b'NSAzMC0xOCAyMy44IDEzLjMtMy43IDkuMy0xOC42IDE1LTIyLTUuNyAzLjQtMTUuNS04LTI1'
    b'LjQgMi4xem0tNjEuNiAxNzIuNWMtMTguMi0xMC00LjItMjYuNSA0LTI4LjEgOC0xLjcgMjku'
    b'MiA3LjcgMTggMjMuNy4yLTEzLjctMTUuNC0xNC0xNy4yLTIwLjUgMS44IDYuNS0xMiAxMi43'
    b'LTQuOCAyNXptMjYzLjYtMTU5LjZjMjAuNi0zIDE5LjQgMTguNyAxNCAyNC44LTUuNSA2LjIt'
    b'MjggMTEuNC0yOC45LTggOC4yIDExIDIwLjggMS45IDI2LjIgNi01LjQtNC4xIDEuOS0xNy4z'
    b'LTExLjMtMjIuOHpNMzA2LjMgNDA4LjFjLTE5IDguNC0yMy44LTEyLjctMjAuMy0yMCAzLjYt'
    b'Ny41IDIzLjktMTguNiAzMC0uMS0xMS04LjQtMjAuNSAzLjgtMjYuOCAxLjMgNi4zIDIuNSAz'
    b'IDE3LjIgMTcuMSAxOC44ek00NzYuOCAyOTNjOC42IDE4LjgtMTIuNiAyMy43LTIwLjEgMjAu'
    b'Mi03LjUtMy41LTE4LjgtMjMuNi0uMi0yOS43LTguNCAxMC45IDQgMjAuMyAxLjQgMjYuNiAy'
    b'LjUtNi4zIDE3LjMtMyAxOS0xNy4xem0tMzI1LjEtNjAuNmMtMTItMTcgOC0yNS43IDE2LTIz'
    b'LjYgOCAyIDIyLjggMTkuOCA1LjcgMjkuMiA2LjItMTIuMy03LjYtMTkuMy02LjMtMjUuOS0x'
    b'LjMgNi42LTE2LjUgNi4xLTE1LjQgMjAuMnpNMjY0IDM5NS42Yy0xOS42IDcuMS0yMy0xNC4y'
    b'LTE4LjktMjEuNCA0LTcuMiAyNS0xNi45IDI5LjkgMi0xMC4zLTkuMS0yMC43IDIuNC0yNi44'
    b'LS41IDYgMi45IDEuOCAxNy4zIDE1LjggMTkuOXptLTUuNy0zMTRjMTEuNi0xNy4yIDI3LTIg'
    b'MjggNi4zLjkgOC4xLTEwLjMgMjguMi0yNS40IDE1LjggMTMuOCAxLjMgMTUuNC0xNCAyMi0x'
    b'NS4yLTYuNiAxLjItMTEuNy0xMy0yNC42LTd6bTIwMC4yIDI1Mi4xYzEuMyAyMC42LTIwLjMg'
    b'MTcuNy0yNiAxMS43LTUuOC01LjktOS4xLTI4LjYgMTAuNC0yNy44LTExLjcgNy4yLTMuNiAy'
    b'MC40LTguMiAyNS40IDQuNi01IDE3LjMgMy4zIDIzLjgtOS4zem0tNS4zLTE5NC40YzIwLjQg'
    b'NCAxMiAyNCA0LjcgMjgtNy4yIDQtMzAuMiAxLjMtMjQuNC0xNy4yIDQgMTMuMSAxOSA4Ljcg'
    b'MjIuNiAxNC40LTMuNi01LjcgNy43LTE1LjctMy0yNS4yem0tMjU4LjQtMTQuNmMuMi0yMC42'
    b'IDIxLjUtMTYuMiAyNi44LTkuOSA1LjMgNi4zIDcgMjkuMy0xMi40IDI3IDEyLjItNi4zIDUt'
    b'MjAgMTAtMjQuNy01IDQuNy0xNy00LjUtMjQuNCA3LjZ6TTE2OSAzMTFjLTE4LjYtOS40LTUu'
    b'MS0yNi40IDIuOS0yOC4zIDgtMiAyOS41IDYuNyAxOSAyMy0uNC0xMy43LTE2LTEzLjQtMTgt'
    b'MTkuOCAyIDYuNC0xMS42IDEzLjEtNCAyNXpNMzkyIDkxYzE5LjUtNy4zIDIzIDE0IDE5IDIx'
    b'LjItNCA3LjItMjQuOSAxNy4xLTI5LjktMS43IDEwLjQgOSAyMC43LTIuNiAyNi45LjMtNi4y'
    b'LTIuOS0yLTE3LjMtMTYtMTkuOHptLTQxLjMgMzE0LjhjLTE1LjIgMTQuMi0yNi43LTQuMS0y'
    b'NS44LTEyLjMuOS04LjIgMTYuMy0yNS4zIDI4LjItOS45LTEzLTQuMy0xOCAxMC40LTI0Ljkg'
    b'MTAgNi44LjQgOC41IDE1LjMgMjIuNSAxMi4yem0xMzIuNy0xNThjMTQuMiAxNS4xLTQuNCAy'
    b'Ni41LTEyLjYgMjUuNS04LjItLjktMjUuNC0xNi4zLTkuOC0yOC00LjQgMTMgMTAuMyAxOCAx'
    b'MCAyNC43LjMtNi43IDE1LjQtOC40IDEyLjQtMjIuMnoiLz4KICA8cGF0aCBmaWxsPSIjMDA1'
    b'ODAwIiBkPSJNMzAxIDk1LjVjMTMuNCAzLjQgMTYuNy0xMS4zIDIzLjUtMTEuNS00IDQuNy0x'
    b'NC4yIDE2LjctMjMuNSAxMS41em0xLTIyLjNjMTQtMTUuMiAyNi45IDIuMyAyNi41IDEwLjYt'
    b'MTEuNS0yMC0xNS0xNy0yNi42LTEwLjZ6TTE3NC40IDIwMi44YzktMTAuNC0yLjgtMTkuOSAw'
    b'LTI2IDIuNiA1LjYgOC45IDIwLjEgMCAyNnptLTE5LjctMTAuN2MtNy40LTE5LjMgMTQtMjIu'
    b'OSAyMS4zLTE5LTIzLjEgMS40LTIyIDYtMjEuMyAxOXptMjk1LjktMTEuOGMxLjYgMTMuNSAx'
    b'Ni43IDExLjMgMTkuMyAxNy41LTUuOS0yLTIxLTcuMS0xOS4zLTE3LjZ6bTIxLjItNy4zYzE5'
    b'LjQgNy42IDcuNiAyNS44LS4zIDI4LjQgMTQuNy0xNy44IDEwLjUtMjAgLjMtMjguNHpNMjM3'
    b'LjMgMzY0LjdjLTUuMy0xMi42LTE5LjItNi40LTIzLjQtMTEuNyA2LjIuMyAyMiAxLjIgMjMu'
    b'NCAxMS43em0tMTguNSAxMi43Yy0yMC43LTItMTQuMy0yMi43LTcuNS0yNy40LTkuMiAyMS4x'
    b'LTQuNiAyMi4xIDcuNSAyNy40em0xOTQuNS0zMS43Yy0xMiA2LjYtNC4yIDE5LjYtOSAyNC4z'
    b'LS40LTYtMS4zLTIxLjggOS0yNC4zem0xNC44IDE2LjdjLjMgMjAuNy0yMS4xIDE2LjgtMjYu'
    b'NiAxMC42IDIyLjMgNi42IDIyLjcgMiAyNi42LTEwLjZ6TTE4NiAxNjguNGMxMS41LTcuNSAy'
    b'LjctMTkuOCA3LTI1IDEgNi4xIDMgMjEuOC03IDI1ek0xNjkuOSAxNTNjLTEuOS0yMC42IDE5'
    b'LjgtMTguMyAyNS43LTEyLjYtMjIuNy00LjktMjIuOC0uMi0yNS43IDEyLjZ6bTQxLjUgMTgx'
    b'LjVjLTQuNC0xMy0xOC43LTcuNi0yMi41LTEzLjIgNi4xLjcgMjEuOSAyLjcgMjIuNSAxMy4y'
    b'ek0xOTIuMSAzNDZjLTIwLjUtMy41LTEyLjctMjMuNy01LjYtMjcuOS0xMC42IDIwLjUtNiAy'
    b'MS44IDUuNiAyNy45ek0zNDUuNCA5NC42YzExLjMgNy45IDE5LjctNC43IDI2LjEtMi41LTUu'
    b'NCAzLTE5LjMgMTAuNi0yNiAyLjV6bTguOS0yMC42YzE4LjYtOS4yIDI0LjMgMTEuNyAyMSAx'
    b'OS4zLTMuNS0yMi44LTgtMjEuMS0yMS0xOS4zem0zNC4yIDI5Mi42Yy0xMy44LjUtMTIuOCAx'
    b'NS42LTE5LjMgMTcuNiAyLjUtNS42IDktMjAgMTkuMy0xNy41em01LjUgMjEuN2MtOS4zIDE4'
    b'LjUtMjYuNSA1LjMtMjguNS0yLjcgMTYuNyAxNiAxOS4yIDEyIDI4LjUgMi43em02OC0xNzlj'
    b'LTMuMSAxMy40IDExLjkgMTYuMyAxMi4yIDIzLTQuOS0zLjgtMTcuMi0xMy43LTEyLjItMjN6'
    b'bTIyLjUuM2MxNS42IDEzLjctMS43IDI2LjgtMTAgMjYuNyAxOS45LTEyIDE2LjctMTUuNCAx'
    b'MC0yNi43em0tMjUyLjYtODljMTMuMy0zLjYgOC44LTE4IDE0LjYtMjEuNS0xIDYtNCAyMS41'
    b'LTE0LjYgMjEuNnptLTEwLjQtMTkuOGM0LjctMjAgMjQuNS0xMS4yIDI4LjQtMy45LTIwLTEx'
    b'LjctMjEuNi03LjItMjguNCA0em0tMzkuNSAxNjhjLjEtMTMuNi0xNS4yLTEzLjMtMTctMTku'
    b'OCA1LjYgMi43IDE5LjkgOS43IDE3IDE5Ljl6bS0yMiA0LjVjLTE4LjMtMTAtNC4zLTI2LjUg'
    b'My45LTI4LjEtMTYuOCAxNS45LTEzIDE4LjYtNCAyOC4xem0yNDguNi0xNDIuOGM4LjIgMTEg'
    b'MjAuMiAxLjYgMjUuNiA1LjctNi4xIDEuMi0yMS43IDQuMS0yNS42LTUuN3ptMTQuOS0xNi44'
    b'YzIwLjYtMyAxOS40IDE4LjcgMTQgMjQuOCAzLjctMjIuNy0xLTIyLjUtMTQtMjQuOHpNMzE2'
    b'IDM4OGMtMTEtOC40LTE5LjkgMy45LTI2LjEgMS40IDUuNS0yLjggMTkuNy05LjggMjYtMS40'
    b'em0tOS43IDIwLjFjLTE5IDguNC0yMy44LTEyLjctMjAuMy0yMCAyLjcgMjIuOCA3LjIgMjEu'
    b'NCAyMC4zIDIwem0xNTAuMi0xMjQuN2MtOC40IDEwLjkgNCAxOS43IDEuNSAyNS45LTIuOC01'
    b'LjQtMTAtMTkuNS0xLjUtMjZ6bTIwLjMgOS41YzguNiAxOC44LTEyLjYgMjMuNy0yMC4xIDIw'
    b'LjIgMjMtMi44IDIxLjYtNy4yIDIwLjEtMjAuMnptLTMwMy4zLTU1YzYuMi0xMi4zLTcuNy0x'
    b'OC42LTYuNC0yNS4yIDMuOCA0LjggMTMuNSAxNy4zIDYuNCAyNS4yem0tMjEuOC01LjdjLTEy'
    b'LTE2LjkgOC0yNS41IDE2LTIzLjUtMjIuMSA3LTE5LjggMTEtMTYgMjMuNnptMTIzLjMgMTQ0'
    b'Yy0xMC4zLTkuMS0yMCAyLjUtMjYuMi0uNCA1LjctMi40IDIwLjQtOC41IDI2LjIuM3ptLTEx'
    b'IDE5LjRjLTE5LjYgNy4xLTIzLTE0LjItMTguOS0yMS40IDEuMSAyMyA1LjcgMjEuOSAxOC45'
    b'IDIxLjR6bS0zLTI5MS45YzEzLjcgMS4zIDE0LjctMTMuOCAyMS4zLTE1LTMuMSA1LjMtMTEu'
    b'NCAxOC44LTIxLjQgMTV6bS0yLjctMjIuMmMxMS42LTE3LjEgMjctMS44IDI4IDYuMy0xNC41'
    b'LTE4LTE3LjYtMTQuMy0yOC02LjN6TTQ0MyAzMTcuNmMtMTEuNyA3LjItMy4zIDE5LjgtNy45'
    b'IDI0LjgtLjctNi4xLTIuMy0yMS44IDgtMjQuOHptMTUuNiAxNi4xYzEuMyAyMC42LTIwLjMg'
    b'MTcuNy0yNiAxMS43IDIyLjQgNS43IDIyLjcgMSAyNi0xMS43em0tMjUtMTgzLjZjNCAxMy4x'
    b'IDE4LjUgOC4zIDIyLjEgMTQtNi0xLTIxLjgtMy41LTIyLTE0em0xOS43LTEwLjhjMjAuNCA0'
    b'IDEyIDI0IDQuNyAyOCAxMS4zLTIwLjEgNi44LTIxLjYtNC43LTI4em0tMjQ0IDIuNmMxMi4y'
    b'LTYuNCA0LjctMTkuNiA5LjYtMjQuMi4zIDYuMS44IDIxLjktOS42IDI0LjJ6bS0xNC40LTE3'
    b'LjJjLjItMjAuNiAyMS41LTE2LjIgMjYuOC05LjktMjItNy4xLTIyLjYtMi40LTI2LjggMTB6'
    b'bS00IDE4MWMtLjMtMTMuNy0xNS42LTEyLjgtMTcuNi0xOS4yIDUuNyAyLjQgMjAuMiA5IDE3'
    b'LjYgMTkuMnpNMTY5IDMxMWMtMTguNS05LjQtNS0yNi40IDMtMjguMy0xNi4yIDE2LjQtMTIu'
    b'MyAxOS0zIDI4LjN6bTIxMi4yLTIwMC40YzEwLjQgOSAyMC0yLjggMjYuMiAwLTUuNyAyLjYt'
    b'MjAuMyA4LjctMjYuMiAwek0zOTIgOTFjMTkuNS03LjMgMjMgMTQgMTkgMjEuMy0xLjItMjMt'
    b'NS44LTIxLjktMTktMjEuM3ptLTM4LjkgMjkyLjZjLTEzLTQuMy0xNy40IDEwLjItMjQuMiAx'
    b'MCA0LjMtNC41IDE1LjQtMTUuOCAyNC4yLTEwem0tMi40IDIyLjJjLTE1LjIgMTQuMi0yNi43'
    b'LTQuMS0yNS44LTEyLjMgMTAgMjAuNyAxMy44IDE3LjkgMjUuOCAxMi4zek00NjEgMjQ1LjNj'
    b'LTQuNCAxMyAxMC4yIDE3LjMgOS45IDI0LTQuNS00LjItMTUuOC0xNS4zLTkuOS0yNHptMjIu'
    b'NCAyLjVjMTQuMiAxNS4xLTQuNCAyNi41LTEyLjYgMjUuNSAyMS05LjkgMTguMS0xMy42IDEy'
    b'LjYtMjUuNXoiLz4KICA8ZyBmaWxsPSIjNzMwMDAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iLjUiPgogICAgPHBhdGggZD0iTTM0OSAxMjAuM3MuNi0xLjMgMS43LS42YzEgLjgg'
    b'MS4zIDQuMiAxLjMgNC4ybC0xLjYuOHMuOS0xLjMtMS4zLTQuNHptLTguOCAzMC43cy44LTEt'
    b'LjMtMy40bDEuNS0uNXMuNiAxLjgtLjIgMy45aC0xbTI3LTUuNC0zLjcgMi4zIDEuOS44IDQu'
    b'NS0yLjYtMi43LS41bS00OS43IDE0LjZjLTEgLjgtMSAyLjEtMS43IDMtLjQuNy0yIDEuOC0y'
    b'IDMtLjIgMS4xLS4zIDEuOS4yIDMuNS42IDEuNSAzIDguNSAyIDEzLjctMSA1LjMtLjYgNy41'
    b'LS4zIDguMy40LjggMS42IDMgMi4zIDMgMS42LS4yLjktLjcgMS41LTEuNyAxLjQtMi41IDAt'
    b'MjIuMi0uNy0yNy42LS41LTQuMi0yLjUtOC0yLjctOC40bC0uOC0yLjZjLTEuNS0zLjUtMy4z'
    b'LTYuNS0zLjMtMTMuOSAwIDAtNC43IDEuMS04LjgtOC4yLTIuMi00LjctNS4zLTQuMi05LTUu'
    b'N2wxLjYtMS4xczMuMiAxLjYgNC43IDEuNmMxLjYgMCAxLTMuMiAxLTMuMmwxLjctMS41djYu'
    b'OGMwIDMuMSA0LjMgNy40IDYuOCA4LjcgMS42LjggMy42LTIuNCAzLjEtNS42LS41LTMgMC03'
    b'LjMgMC03LjNsMi4yIDEuM3MtLjggMS4zLS42IDIuMWMuMy44IDEuMy0uNyAyLjEtMS41IDAg'
    b'MCAuMi4yIDEgLjJsLTIuMyA0Yy0uOCAxLjItLjggNi4yLS44IDggMCAyIC43IDYuMi43IDcu'
    b'NiAwIDEgMS44IDUgMy4zIDcuNGwxLjYgMy41YzEuMiAxLjkgMS4zIDMuMiAyIDQuNy40Ljgg'
    b'MSAzIDEuNiA3bC43IDdjLjIgMi40IDIuMi42IDQuNS0xIDIuNC0xLjggMi40LTYgMi40LTZz'
    b'MS44LTEuNiAxLjUtLjdjLS4yIDEgMSAyIDEgMi0xLjQgMy4zLS42IDIuOS45IDIuOCAxLjUt'
    b'LjIgNi41LTQgNi41LTQgLjctLjIgMy44LS4yIDMuMyAwLS42LjMtMS40IDEuNy0xLjQgMS43'
    b'bDMuMy0uNGMtMS4xLjktNS41IDMuNC02LjUgNGE5MC42IDkwLjYgMCAwIDEtOC42IDQuMWMt'
    b'Mi4zIDEtNi43IDMuMi02LjkgNS40IDAgMi4zLjMgOC4zIDAgMTAuM2wtMSAxMC42aC0xMC40'
    b'czItNy42IDAtOS43Yy0yLjEtMi4xLTctOC40LTEwLTEwLjUtMy4yLTIgMi0uNSAyLS41di0y'
    b'LjFsNC44IDUuN3M4LjMtNy4zIDAtMTcuM2MtMi42LTMuMS01LjMtNy45LTcuMy04LjQtMi4y'
    b'LS42LTMuMy0xLTYuOSAwLTMuNyAxLjEtMTIuNiAxLjEtMTYuMy00LjhsMy4xLS41IDIuNy0x'
    b'cy0xLjEgMy43IDYuMyAzLjcgOC40IDAgNy44LTYuOGwyLjItMS4xIDEuNiAxLjVzLTEuMSAz'
    b'LjgtLjUgNS4zYy41IDEuNiAzIDIuNyA1LjEgNC4yIDEgLjcgMS42LjggMi4yLjguOS0uMSAx'
    b'LS4xIDIuMi0xLjMgMS44LTIgMS40LTEuOCAzLjItMy40bDEtMS42IDEuMSAyLjl6Ii8+CiAg'
    b'ICA8cGF0aCBkPSJNMzE5IDE1NWMuNS0uNCAxLjItMS45IDItMy4xIDEuMS0yIDIuNS0zLjIg'
    b'NC01LjYgMS41LTIuMiAyLTUuNiAxLjUtNy45bDEuNC44djMuN2wyLjctMiAuOC40cy01Ljkg'
    b'Ni0xMS4zIDE1LjlsLTEtMi4yem0tNTEuMy0yMC4zYy44IDEuNCAxLjYgNCAzLjkgNmwxLjYt'
    b'LjRzLTMuNi00LjItMy42LTZsLTEuOS40bTkuMi0yLjRzLjUgNS0uOCA2LjlsMS42LS44czEt'
    b'My40LjctNS4zbC0xLjUtLjd6bTUxLjQtMTUuN3MtLjMgNyAxLjEgMTEuM2wxLjktLjVzLS4z'
    b'LTEuMyAxLjItMS45YzEuNi0uNSA1LjMtMiA3LjItMy42bC0uNi0xLjZzLTIuOCAyLjMtNC4y'
    b'IDIuOWMtMS4zLjUtMiAxLTMuMS43LTEuMS0uMy0yLjQtMi0xLjYtNmwtMS45LTEuM20yMC43'
    b'IDMyLjhzLS40IDUtLjIgNy4ybDEuNy40cy0uNC02IC43LTYuNWwtMi4yLTFtNy41IDMuN3Mt'
    b'MS45IDMuMi00IDMuNWwzLjQtLjdzMS0uNSAyLjQtMmwtMS44LS44Ii8+CiAgPC9nPgogIDxn'
    b'IGZpbGw9IiMyODk0MDAiIHN0cm9rZT0iIzAzMCIgc3Ryb2tlLXdpZHRoPSIuNSI+CiAgICA8'
    b'cGF0aCBkPSJtMzI2LjYgMTM4LjQgMS4zLjggMS4zLjIgMy4yIDIuNmMxLjIgMSAxLjItLjIg'
    b'MS4yLS4ybC44IDMuMWgxbC0uMiAzLjIgMS44LTEuNiAyLjIgMS45czEuNS0xLjQgMi4zLTEu'
    b'NGMuOCAwIDEuMS0uOCAxLjEtLjhoLjFjLTUuMi0yLjQtNy40LTUtNS45LTcuNiAyLjYtNC40'
    b'IDYuOC0xLjYgOC4xLTFsMTkgMTAuMnMxLjMtLjguNC0xLjZjLTEtLjgtMS40LTIuNy0xLTMu'
    b'NS4yLS44IDIuNCAyLjQgMy40IDIuN2wzLjUuN3YtMXMzIDIuMiAzIDMuM2MwIDAgMi4zLTEu'
    b'MiAxLjUtMS45LS43LS43IDMuNSAxLjcgMy43IDNsMS0xYy0uMiAwIC4yLTMuMiAxLjMtNC42'
    b'YTQuOCA0LjggMCAwIDEgMi0xLjlzMS0xLjcgMi0xLjdjMCAwLTEtLjYtMS40LTEuNC0uNS0u'
    b'OC0xLjYtMS4yLTEuNi0xLjJzMS40LTEgMS44LTEuNWMuNC0uNi44LS43LjgtLjdzLTIuMi0x'
    b'LjktMy44LTIuMmMwIDAtLjEtMi41LTItMi43aC44cy0xLjQtMi44LTIuOC0yLjhjMCAwIC45'
    b'LTEgMS42LTEuMSAwIDAtMS42LTIuMi0zLjktMS40bDEuNS0uNnMtMS0xLjEtNC40LS42YzAg'
    b'MCAuMy0xLjMtMS4yLTIuNCAwIDAtMS4yIDAtMS4yIDEgMCAwLTEuMi0xLTIuNy0xLTEuNCAw'
    b'IC41IDEuNi41IDEuNnMtMi0xLjMtMy4xLTFjMCAwIC41LTIuMi0uOC0zLjMgMCAwLTEuNC43'
    b'LTEuOCAxLjdsLS40LTFzLTIgMi40LTIuNCAxLjdjLS4zLS40LS42LTItLjYtMmwtMS4xIDEu'
    b'Ny4yLTIuNHMtMS40LjgtMi41IDMuM2MwIDAtMS4zIDEuMy0xLjMgMi40IDAgMC0xLjEtMS4y'
    b'LTIgMC0xIDEuNCAwIDEuMSAwIDEuMXMtLjUuNS0xLjUuN2wuMi44cy0xLjItLjctMi4yLS40'
    b'bC41IDEuMnMtMi42LjItMi43LTJjMCAwLTIuMS0xLTIuNC4ybC0xLjYgMXMtLjUtMS0xLjMt'
    b'MS4yYy0xLS4zLS4yIDEuMy0uMiAxLjNzLS4zLTEuMi0xLjUtMS44Yy0xLjItLjUtLjIgMS0u'
    b'MiAxcy0xLjUtMS4yLS44LTIuMmMwIDAtMS40IDEuNC0uNyAyLjdsLTEgLjdzLS41LS41LS40'
    b'LTFjMC0uMy0xLjcgMS4zLTEuNyAxLjNzLTEtMi42IDAtMi42Yy4xIDAtMS44IDAtMi4xIDIu'
    b'MiAwIDAtMS4zIDAtMi41LjRzMSAxLjMgMSAxLjMtMi0uNC0zIC4ybC43LjlzLS43LS43LTIu'
    b'NC0uMWMtMS43LjUuNC44LjQuOHMtMS43LS40LTIuNiAwYy0uOS40LjMgMSAuMyAxcy0zLjIt'
    b'MS0zLjctLjZjLS41LjMgMSAxLjggMSAxLjhzLTIgLjUtMi4zIDJsMS44LjdzLS44LjQtMS4y'
    b'IDEuMWMtLjQuOCAxLjIuNCAxLjIuNHMtMi4yIDEuNi0yLjIgMi44YzAgMCAxLjYuNSAyLjct'
    b'LjcgMS4yLTEuMi40LS44LjQtLjhsLjEuOHMyLjMtMSAyLjMtMS42YzAtLjUtLjQuOC0uNC44'
    b'bDIuMi0xLjIgMS41IDF6Ii8+CiAgICA8cGF0aCBkPSJtMzI0LjcgMTA4LS41LTIuMiA1IC42'
    b'LjktMnMyLjQgMSAzLjEgMS44YzAgMCA0LjYtMS4yIDYtLjdsLS42IDIuMXM0LjIuMyA1LjYu'
    b'OGMxLjIuNS0uNiAxLjYtLjYgMS42czQuOC42IDYuOCAxLjhjMi4yIDEuMyAyLjIgMi40IDEu'
    b'MSAyLjdsMi42IDQuMnMtNC4yLjUtNSAxLjVjLS43IDEuMS0xLjUtMS0xLjUtMWwtLjggMi45'
    b'cy0yLjYtMS40LTMuNy0yLjRjMCAwLTEuMyAxLjYtLjUgMi40bC00LjgtMy4xcy0yLS4zLTIg'
    b'MS41bC0zLTMuNC0yLjYuOHMtLjgtMS0xLjctMS40Yy0xLjEtLjItLjMgMS40LS4zIDEuNGwt'
    b'MS42LTEuOS0xLjYtMS44cy0xLjMgMS44LTIuNCAxLjhjLTEgMC0xLTEuMi0uOC0yLjEuMy0u'
    b'OC0zLjEtMS0zLjQgMCAwIDAtMS00IDIuNi01bDMuNy0xem0tMTkgMTMuMy0xLjYgMS42LTEt'
    b'LjUtMS45IDIuMS0uNC0xLjEtMSAxLjctMS43LS42LS44IDEuMy0xLjUtLjNzLTEuMiAxLjIt'
    b'MiAxLjVjLS44LjIgMC0xLjggMC0xLjhzLTEuMiAyLTIgMmMtLjkgMC0uNi0xLS42LTFzLS41'
    b'IDEuNC0xLjQgMS42Yy0uOSAwLS41LTEtLjUtMWwtMS42IDEuMnYtMWwtLjctLjNzLjQtMS44'
    b'IDEuMS0yLjJjLjctLjQtLjctMS41LS43LTEuNWwuNy0uOHMtMi0uNS0yLS4xYzAgMCAxLTIu'
    b'NiAyLjQtMy4xbC4xLTNzMS40LTEuMSAyLjYtMS4yYzEuNC0uMi0uNC0yLjMtLjQtMi4zbDMu'
    b'Mi0xLjguNC0yLjMgNC43LjQgMS0yIDMuOCAxIDMuMy0xLjcgMi4zIDIuNyAzLjUuM3YzLjFz'
    b'NC4xIDEuMyA0LjYgMS43YzAgMC0uOCAyLjUtLjggMyAwIDAgMy0uOCAzLjgtLjZsLjQgMy40'
    b'czUgMS42IDUuMyAyLjVjMCAwLTEgLjctMS43IDEuNiAwIDAgLjYgMyAuNiA0bC0uNC41cy0x'
    b'LjQtMS4zLTIuNi0xLjVsLTEgMi4xLTEuNy0xLjFoLTEuMXMtLjktMS0xLjYtMXYtMWwtMS40'
    b'LjlzLTIuMi0xLjEtMi4yLTEuOGwuMS0xLjUtMi4yIDEuNXMtLjUtMS4xLS40LTEuNmMwLS41'
    b'LS45IDEuMS0uOSAxLjFzLTEuMi0yLTEtMi40bC0uNCAxLjdzLTIuMy0uOC0yLjYtMi40eiIv'
    b'PgogICAgPHBhdGggZD0iTTI3NC41IDEzMC45czQuMSAyIDQuMSAzYzAgMCAxLjEtMi4xLjUt'
    b'M2wxLjYgMS4xcy41LTEuOS0uMS0yLjVjLS41LS41IDMuNS0yLjEgNC40LjUgMCAwIDIuNC0y'
    b'LjUtMi4zLTQuNyAwIDAtLjQtMS42IDIuNS0xLjIgMCAwLS4yLTEtLjktMS4zaDIuN3MtMS42'
    b'LTEuNC00LTEuOGMtMi40LS40LTEtLjctMS0xLjItLjItLjUgMC0yLjIgMC0yLjJzLTEuNC0u'
    b'NS0yLjUgMGwuNC0uNHMtMi41LS43LTMuNS0uMWMwIDAtMS41LS42LTEuMy0yLjEgMCAwLTEu'
    b'NS0uMS0yLjEgMS40IDAgMC0xLjQgMS42LTMuMyAxLjYtLjMgMC0xLjctLjgtMS43LS44bC0x'
    b'LjIgMi43SDI2NWwuNSAxcy0yLjgtLjgtMy43IDBjMCAwIDEuMSAxLjcuOCAyLjggMCAwLTIu'
    b'Mi40LTIuNy44LS42LjQuOC43LjguN3MtMi42LjgtMy4yIDEuNmwxIC43LTEuMiAxLjYgMSAu'
    b'Mi0yLjUuOGMtLjkuMyAxLjUuNSAxLjUuNWwtMS4xIDEgMS44LjNzLTEuNCA0LTEuNSA1Ljhj'
    b'MCAwIDIuMi0yLjcgMi44LTNsLTEuOCAzczMuNC0xIDMuNy0xLjZsLjUtMSAuMSAxLjZzMS4z'
    b'LTEuNyAxLjUtMi40Yy4xLS43IDIgLjcgMiAuN3YtMWwyLjQuN2MuNyAwIC44LS4zLjgtLjNs'
    b'MS42LS4yLS4zIDEuNHMxLjItLjggMS41LTEuNmMuMi0uOC44IDAgLjggMGwuOC0zLjFoMS42'
    b'em0tMTMuNCAxMy44IDEuNiAzLjNjLTEuMyAwLTMuMSAxLjUtMy4xIDEuNS4zIDUuNC0xIDUu'
    b'MS0xIDUuMS4zIDEtLjMgMi44LS4zIDIuOGw3LjctNC42LjEtLjUgOS4yLTQuMy4zLjUgMi42'
    b'LTEuNSAxLjkgNC45LTEuOSAxYy4xIDEuNyAyLjEgNC42IDIuMSA0LjZsMi40LS42IDIuNy0x'
    b'djFjMC0uMyAyLjktMS4zIDIuOS0xLjNsMS4zIDEuM2MxLS4xIDIuNy0yLjUgMi43LTIuNWwy'
    b'IC44cy43LTEuMi43LTIgMi42LS44IDIuNi0uOGwxLjcgMS4yIDIuMy0xLjhzLjcgMS4zIDEu'
    b'NiAxLjVjMSAuMSAzLjQgMiAzLjQgMS42IDAtLjQgMS0yLjUgMS0yLjVsNC4xIDEuNmMtLjUt'
    b'MS44LTItNC0yLTRzMi0xLjYgMS43LTJjLS40LS40LTEuNiAwLTEuNiAwbDEuMi0yLjRoLTEu'
    b'NmwuNS0uNi0yLjUtMSAxLjMtMi44Yy0uNi0uNy03LjMtMi03LjMtMmwxLjYtMS41cy0uOC0x'
    b'LjItMS42LTEuMi00LjkuMS01LS4zbC0xLjgtMS44LTIuNiAxLjktMS4zLS40LTIuMi44czAg'
    b'MS4zLS4zLjRjLS4zLS44LTIuMy0yLjgtMi4zLTIuOC0uNC43LTMgMy44LTMgMy44cy0uNSAx'
    b'LjctMS4zLjVjLTEtMS4yLTMtMi40LTMuNC0xLjUtLjIgMS4xLTIuMSAyLTIuNSAxLjgtLjQt'
    b'LjMtMi41LS4xLTIuNy41LS4xLjctMi41IDIuNC0yLjUgMi40LTEuNC0uNy0zLjgtLjMtMy44'
    b'LS4zcy0uNyAxLjEtLjggMmwtNC43IDEuMnptNDQuMiAzOS42di0ybDIuMyAxLjUgMS40LTEu'
    b'NSAxLjggMS43IDEtMS43djIuOGwyLjctMi4zIDEuNS42di0yLjJzMS45LTMuMSAxLjEtMy43'
    b'bDEuNi0uNXMtMi43LTIuNi0zLjQtMy4xYy0uOC0uNi0xLjktLjYtMS45LS42cy0yLTItMy40'
    b'LTIuN2MtMS4zLS41LTIgLjYtMiAuNnMtLjgtMS41LTIuMi0xLjhjLTEuMy0uMy0xLjMgMS0x'
    b'LjMgMXMtMS0xLTIuMi0xLjRjLTEuMy0uNi0uNCAxLjItLjQgMS4ybC00LjUtMS40LjYgMS40'
    b'LTQuMi0xLjEuNSAxLjUtMy0uNS0uMiAxLjMtNC4yLjguOCAxLjQtMi42LTEuMXYxLjlsLTMg'
    b'MSAxLjEgMS00LjcgMi40Yy0uNy41IDEuNiAxLjYgMS42IDEuNmwtNC4yLS42IDEuNiAxLjQt'
    b'My43IDMuNCAyLjYgMS45LTEuNiAyLjMgNCAuOCAxLjUgMi42IDMuMi0uNnYzbDQuNy0zLjdz'
    b'My40IDMgMy43IDIuMWMuMi0uOC4yLTMuNC4yLTMuNGgxLjdWMTg3bDEuMiAxIDIuMi0zLjEg'
    b'Mi44IDMuOSAyLjItNSAzLjEuNXptMTkuMS0xMS44LS40LTQuNS0xLjQgMS40LjYtNC4yLTIu'
    b'Mi0uNC44LTQuMS0xLjYtLjguNC0yIDEuNi0xLjEgMi44LTIuOCA2LjYuMS43LTIuMSA0Ljcu'
    b'OGMuOC44IDMuMy0xLjggMy4zLTEuOGgxbDEgMnMzLjQtLjQgNSAuNmwtMS45IDIuNiAzLjUu'
    b'MyAyLjMuNSAyLjQtLjggMy4yLS4yLjcgMS4zaDNsLTEgMS4xIDMuOCAxLjgtLjguOHMyLjIu'
    b'OCAzLjcuOGguOHMuOCAxLjgtLjMgMi42YzAgMCAxLjEgMi42IDMuNCAzLjEgMi40LjUgMi40'
    b'LjUgMi43IDEgLjMuNiAwIDMuMi0yLjcgMy4ydjIuN3MtMiAxLjgtMi4zIDIuNmwtMS42LTFz'
    b'LTEuMyAxLjUtMS4zIDIuNWMwIDAtMy41LTQuNS00LjctNC43LTEuNC0uMi0xIDIuNi0xIDIu'
    b'NmwtMy44LTMuMS0uNSAyLjEtMy4xLTIuNi0xLjkgMS4zLTMuMy0zLjUtMy4yLjQgMS4yLTEu'
    b'NmgtMy45bC0uNy0zLjQtLjYgMi44LTIuNC0xLjYtMyAzLjNzLS40LS40LS45LTJjLS41LTEu'
    b'NS0xLjggMi0xLjggMmwtMS4xLTIuNS0xLjMgMi40cy0xLTEuOC0yLjEtMi40Yy0xLS41LTIg'
    b'My0yLjQgNC41em0uNiAxMC4zLjItMS42IDUuNi0yLjIgNC43LTEuNyAyLjMtMS4xIDEuMSAx'
    b'LjkgMS40LTIuNyAyLjEgMi44IDEuMi0xLjUgMS44IDEuNGgxLjZsLjMgMnMzLjkuMyA0LjIt'
    b'LjVjLjMtLjguOCAyLjcuOCAyLjdsMy43LjUuOCA0LjJzMS44IDMuOSAxLjIgNS40Yy0uNSAx'
    b'LjctMi0yLTItMnMtLjMgMi45LS42IDMuN2MtLjIuOC01LS44LTUtLjhsLTIgMy45cy0yLjIt'
    b'My4xLTMuMi0zLjEtMSAzLjEtMSAzLjFsLTQuNS01LjNjLTEuMy0xLjUtMS42IDEuNi0xLjYg'
    b'MS42cy0yLTMuNC0yLTQuNGMwLTEtMS45LTIuMi0xLjktMi4ycy0zLjIgMy43LTUuNiA0Ljdj'
    b'MCAwIC4zLTIuMy0uNS0zLS43LS45LTMgMS41LTMgMS41cy0xLjctMy42IDAtNy40eiIvPgog'
    b'IDwvZz4KICA8ZyBmaWxsPSJub25lIiBzdHJva2U9IiMwMDRiMDAiIHN0cm9rZS13aWR0aD0i'
    b'LjUiPgogICAgPHBhdGggZD0ibTM1MC44IDEyNC41LjUgMnMxLjgtLjQgMy0uM2wtLjcgMi4y'
    b'czIuMy0uNCAzLjQuM2wtLjUgMS4yIDIuNyAxLjItMi41IDJzNCAxLjUgNC45IDIuN2MwIDAt'
    b'Mi43IDEuOC0zIDEuNy0uNS0uMi0uMi44LjUgMS43bC0yLjItLjFzLjkgMiAuOCAyLjhjLS4y'
    b'LjgtMy44LjYtMy44LjZtMTQuMS01LjNzLjctMy45LS40LTQuOWMwIDAgMi41IDIuMiA0LjIg'
    b'Mi4zIDEuOCAwIDAtMy4yIDAtMy4yczIuMyAxLjIgMy41IDEuNWMxLjIuMi0uOS0yLjQtLjkt'
    b'Mi40cy43LTEuMyAyLjctLjFtLTQ1LjQtMTUuNXMwLTEtLjMtMS40Yy0yLjQtMy4yIDIuNCAy'
    b'LjQgMy40IDIuNm00LjUgMHMxLjYgMS4yIDIuMyAxLjJjLjggMC0uNS0zLjEtLjktMy41LS4z'
    b'LS40IDIuOSAxLjMgNCAxLjQgMS4yLjMgMS40LTIgMS40LTJzMy42LjcgNC40IDEuMm0tMjUt'
    b'LjctLjUtM20tMjQuMiAxMi43Yy0uMi0uMyAxLTIgLjUtMi45IDAgMCAuNy42IDEuNC43LjYu'
    b'MS40LTIuMi40LTIuMmwuNy4zczItMSAxLjctMS44Yy0uNC0uOCAxLjQgMS4yIDEuNCAxLjJz'
    b'MS4xLTEuMiAxLjEtMS43IDEuNCAxLjIgMS40IDEuMiAxLjUtLjMgMS41LTEuMmMwLS45IDEu'
    b'OC4zIDEuOC4zcy44LTEgLjctMS44bS0xOS43IDkuOHMuOS0yLS4xLTMuNG0tMjMuNiA5Ljhj'
    b'MC0xIC41LTMuNiAwLTQtLjQtLjQgMSAuNCAyLjIuN205LjMtLjRjLTEuMi0xLjEtMS45LTEu'
    b'Ny0zLjctMS43bS0xNi4yIDguM2MuMy0uNy44LTIuNC41LTMuM20yNSA1MS43IDEuMy0yLjYg'
    b'MS42IDMuNyAxLTIuMy40LjcgMi40LTIuNSAyLjUgMy44bTQwLjctMTYuNSAxLjctMy4zIDIu'
    b'MyAxLjIgMS0zLjMgMi40IDEuNSAxLjMtMyAyLjcuNy4yLTIuMnMxLjggMSAyLjMgMS45Yy42'
    b'LjcgMC0yLjcgMC0yLjdsMi4yIDFzMS41LTEuNi0uNi0yLjQiLz4KICAgIDxwYXRoIGQ9Im0z'
    b'NDMuNiAxNjMuMSAyLjMgMy40IDItMi4yIDEuNyAzLjggMi4zLTEuNCAzLjIgMS45IDEuNS0x'
    b'LjIgMy41IDIuNSAxLjQtMyAzLjIgMSAyLTMuNW0tODQuNC05LjJzMS40LTIuMyAxLTMuNGMt'
    b'LjctMSAyLjggMS44IDIuOCAxLjhzLjctMi4zLjMtMy40Yy0uNi0xIDMuOSAzLjIgMy45IDMu'
    b'MnMuNy0zLjcgMC00LjRjLS44LS44IDQuMyAxIDQuMyAxczItLjYgMS4yLTEuNmMtLjgtMS4x'
    b'IDMuNCAxLjUgMy40IDEuNXMxLTIuNiAwLTMuNiAzLjIgMS4zIDMuMiAxLjNsLTEuNi0yLjgg'
    b'My40LjItLjMtMy4ybTMwLjMgNDUuMSAyLjItMSAyIDIgMi4yLTMuNSAyLjYgMi41LjQtMi41'
    b'IDIuOCAxLjIuNi0xLjYgMy4xIDEuNy4zLTIuNCAxLjYuNS4zLTEuNSIvPgogIDwvZz4KICA8'
    b'cGF0aCBmaWxsPSIjOWRkN2ZmIiBkPSJNMjgzLjEgMjk4LjFhNjkuOCA2OS44IDAgMCAxLTYt'
    b'MTNsNDIuNC0zNy4yIDQyLjMgMzcuMWE2NC43IDY0LjcgMCAwIDEtNi4yIDEzLjNsLS4zLjUt'
    b'My4yLTEuMnMtMS40IDEuMy0yLjUgMS40Yy0xLjQuMi0yLjctMS4zLTIuNy0xLjNzLTEuOCAx'
    b'LjYtMy43IDEuM2MtMS45LS4yLTIuNi0xLjQtMi42LTEuNHMtMiAxLjYtMy40IDEuM2MtMS4y'
    b'LS4zLTIuMS0xLjItMi4xLTEuMnMtMS4yIDEuNS0yLjggMS4yYy0xLjYtLjMtMy0xLjItMy0x'
    b'LjJzLTIuNSAxLTQgMS4zYy0xLjYuMy0zLTEuNC0zLTEuNHMtMiAxLjQtMi44IDEuNGMtLjgg'
    b'MC0zLjctMS40LTMuNy0xLjRzLTMgMS00LjEgMWMtMSAwLTQtMS4zLTQtMS4zcy0yLjkuOC00'
    b'LjEuOGMtMS40IDAtMy40LS44LTMuNC0uOHMtMi4zIDEuMS0zLjYuOGMtMS40LS4zLTIuNC0u'
    b'OC0yLjQtLjhzLTIuNiAxLjEtNC4yLjhjLTEuNi0uMy0zLjQtMS40LTMuNC0xLjRzLS4zLjgt'
    b'My40IDEuNCIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIuNyIgZD0iTTMxOS41IDIwNS4xVjI0OGwtNDIuMyAzNy40YTg0LjIgODQuMiAwIDAg'
    b'MS00LjQtMjcuMVYyMDVoNDYuNyIvPgogIDxwYXRoIGZpbGw9IiNmZmQ4M2MiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIuNyIgZD0iTTMxOS41IDIwNS4xVjI0OGw0Mi4yIDM3LjRh'
    b'ODQuMiA4NC4yIDAgMCAwIDQuMy0yNy4xVjIwNWgtNDYuNSIvPgogIDxnIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIuNSI+CiAgICA8cGF0aCBmaWxsPSIjNzMwMDAwIiBkPSJNMjky'
    b'LjIgMjg5LjJjMy4yIDEuNyAyIDEuMiA4LjcgMy41YTYxLjggNjEuOCAwIDAgMCAyMC43IDIu'
    b'OGM4IDAgMTIuNC0uNyAxNS0xLjQgMi41LS43IDMuMS0xLjggMy4xLTEuOGwtNi41IDYuN3Mt'
    b'MjYuMyAxLjQtMzEtMS43Yy0yLTEtNi00LjItMTAtOHoiLz4KICAgIDxwYXRoIGZpbGw9Im5v'
    b'bmUiIGQ9Ik0zMzAuOCAyNzYuOHM4LjQgNC44IDAgMTRtLTM3LjgtMSAxMi0xMS42LTEuMyAx'
    b'NS40bTYuMyAxLjR2LTI1LjhtMjAuOCAyNS44di0yNy40bS0xMC41IDI3LjlWMjY2Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmYwMDE4IiBkPSJtMzEwIDI3MC42LTUuNCAxLjcgNS40LjZ2LTIu'
    b'M20xMC4zLTQtNS44IDIuMSA1LjguMnYtMi40bTEwLjUgMS42LTUuOCAyLjIgNS44LjNWMjY4'
    b'em0zLjQgMTIuNGMtLjMtMS4xIDMuNC0xIDMuNC0xczEgMy45IDAgNi4zbC0zLjEtLjZzLjMt'
    b'Mi42LS4zLTQuN3oiLz4KICAgIDxnIGZpbGw9IiNmZmYiPgogICAgICA8cGF0aCBkPSJtMjk0'
    b'LjggMjg4LjEgMTAuMy0xMC0uNSA2cy01LjMgMy41LTUuMyA1LjlsLTQuNS0xLjltNS41IDIu'
    b'MXMxLTMuMSA0LTQuN2wtLjMgNi4zLTMuNy0xLjZ6bTE0LjctMTcuM3M0LjItLjYgNy40IDBj'
    b'MCAwLS41IDQuMiAwIDUgMCAwLTUuOC0xLjQtOC4xLjggMCAwLS44LTQgLjctNS44em0tOC45'
    b'IDFzNC4yLS41IDcuNCAwYzAgMC0uOCA0LjgtLjMgNS41IDAgMC00LjctMi42LTctLjQgMCAw'
    b'LTEuNi0zLjMgMC01eiIvPgogICAgICA8cGF0aCBkPSJNMzA1LjkgMjc5LjRzNC4yLS40IDcu'
    b'MyAwYzAgMC0uNSA0LjMgMCA1IDAgMC01LjUtMS4yLTcuOC44IDAgMC0xLjEtMy45LjUtNS44'
    b'em04LjQtLjdzNi0uOCA5LjEtLjNjMCAwLTEuMiAzLjQuMyA1LjcgMCAwLTYuNS0xLjctOSAu'
    b'MyAwIDAtMi0zLjktLjQtNS43em0tOSA2LjUgOC4yLjZzLS44IDYtLjMgNi43YzAgMC02LjYt'
    b'MS41LTcuOC42IDAgMC0yLjItNS40IDAtNy45em05LjIgMHM3LS41IDEwLjMgMGMwIDAtMS45'
    b'IDQuNS4yIDguNCAwIDAtOS4yLTIuNi0xMC41LS41IDAgMC0yLjEtNS40IDAtNy45em0xMC44'
    b'LTEyLjNzNC4yLS42IDcuMyAwYzAgMC0uNSA0LjIgMCA1IDAgMC01LjgtMS40LTggLjggMCAw'
    b'LS45LTQgLjctNS44em0wIDUuOHM0LjItLjUgNy4zIDBjMCAwLS41IDQuMiAwIDUgMCAwLTUu'
    b'OC0xLjMtOCAuNyAwIDAtLjktMy45LjctNS43em0uNSA2czQuMi0uNiA3LjQgMGMwIDAtMSA2'
    b'LjYtLjYgNy40IDAgMC00LjgtMi4zLTctLjMgMCAwLTEuNC01LjIuMi03eiIvPgogICAgICA8'
    b'cGF0aCBkPSJNMzM0LjUgMjg1LjJzMS4zIDUgMyA1LjZsLTIuMiAyLjhzLTIuOS0yLTMuMi00'
    b'LjRjMCAwIDEuOS0yLjEgMi40LTR6Ii8+CiAgICA8L2c+CiAgPC9nPgogIDxnIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIuNiI+CiAgICA8cGF0aCBmaWxsPSIjMDA2YWM4IiBzdHJv'
    b'a2U9Im5vbmUiIGQ9Ik0zNTUuNCAyOTguN2E2Ni4yIDY2LjIgMCAwIDEtMzYgMjguMyA2Ny4z'
    b'IDY3LjMgMCAwIDEtMzYuMy0yOC44aC4xYzMtLjcgMy40LTEuNSAzLjQtMS41czEuOCAxLjEg'
    b'My40IDEuNGMxLjYuMyA0LjItLjggNC4yLS44czEgLjUgMi40LjhjMS4zLjMgMy42LS44IDMu'
    b'Ni0uOHMyIC44IDMuMy44YzEuMyAwIDQuMS0uOCA0LjEtLjhzMyAxLjMgNCAxLjNjMS4xIDAg'
    b'NC4yLTEgNC4yLTFzMi45IDEuNCAzLjcgMS40Yy43IDAgMi44LTEuNCAyLjgtMS40czEuNCAx'
    b'LjcgMyAxLjRjMS41LS4yIDQtMS4zIDQtMS4zczEuNC45IDMgMS4yYzEuNi4zIDIuOC0xLjIg'
    b'Mi44LTEuMnMuOS45IDIuMSAxLjJjMS40LjMgMy4zLTEuMyAzLjMtMS4zcy44IDEuMiAyLjcg'
    b'MS40YzEuOC4zIDMuNy0xLjMgMy43LTEuM3MxLjMgMS41IDIuNyAxLjNjMS4xLS4xIDIuNS0x'
    b'LjQgMi41LTEuNGwzLjMgMSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRo'
    b'PSIuNSIgZD0iTTM1My43IDMwMS4yYy0xLjQuMS0xLjYtLjgtMS42LS44cy0yIDEuNi0zLjgg'
    b'MS4zYy0yLS4zLTIuOS0xLjUtMi45LTEuNXMtMiAxLjYtMy40IDEuM2E1IDUgMCAwIDEtMi4z'
    b'LTEuMXMtMS4zIDEuNC0zIDEuMWMtMS42LS4yLTMtMS4xLTMtMS4xcy0yLjcgMS00LjQgMS4z'
    b'Yy0xLjYuMy0zLTEuNS0zLTEuNXMtMy44IDEuMi00LjYgMS4yYy0uOSAwLTMuNi0xLjItMy42'
    b'LTEuMnMtMS45IDEuMS0zIDEuMS00LjItMS4zLTQuMi0xLjMtMyAuOC00LjMuOGMtMS40IDAt'
    b'My41LS44LTMuNS0uOHMtMi41IDEtMy45LjhsLTIuNC0uOHMtMi43IDEtNC40LjhjLTEuNi0u'
    b'NC0zLjYtMS40LTMuNi0xLjRzLS4zLjctMy41IDEuNGgtLjEiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiM1YWM4MDAiIGQ9Ik0yOTMuMSAzMDUuMnMtLjMuNy0yLjggMS4ybC0uNy4yLjYtLjItLjcu'
    b'M2E0NCA0NCAwIDAgMCAxMS43IDExYzQuNSAzIDkuNiA2LjYgMTguNCA5LjJhNzEgNzEgMCAw'
    b'IDAgMTcuOC05YzYtNC41IDkuMi03LjIgMTIuNi0xMS43LTIuNyAxLjUtMi4zIDEuNS0zLjcg'
    b'MS4zLTEuMy0uMy0yLjMtMS4zLTIuMy0xLjNzLTEuMyAxLjUtMyAxLjNjLTEuNi0uMy0zLTEu'
    b'My0zLTEuM3MtMi4yIDEuNS00LjQgMS40Yy0xLjYtLjEtMy0xLjYtMy0xLjZzLTMuOCAxLjMt'
    b'NC42IDEuM2MtLjkgMC0zLjYtMS4zLTMuNi0xLjNzLTEuOSAxLjItMyAxLjItNC4yLTEuNC00'
    b'LjItMS40LTMgLjgtNC4zLjgtMy40LS44LTMuNC0uOC0yLjUgMS00IC44Yy0xLjMtLjMtMi40'
    b'LS44LTIuNC0uOHMtMi43IDEtNC40LjhjLTEuNi0uMy0zLjYtMS40LTMuNi0xLjR6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmZkODAwIiBkPSJNMzE5LjYgMzI2LjlhODkgODkgMCAwIDAgMTcu'
    b'MS04LjZjLTEgMC00LTEtMi45LTEuMiAwIDAtMS4yIDEtMi4zIDEtMS4xIDAtNC4yLTEuMy00'
    b'LjItMS4zcy0zIC43LTQuMy43Yy0xLjQgMC0zLjQtLjctMy40LS43cy0yLjYgMS00IC43bC0y'
    b'LjQtLjdzLTIuOCAxLTQuNC43Yy0xLjYtLjMtMy42LTEuMy0zLjYtMS4zcy0yLjQgMS4zLTQg'
    b'MS40YTU1IDU1IDAgMCAwIDE4LjQgOS4zeiIvPgogIDwvZz4KICA8ZyBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iLjUiPgogICAgPHBhdGggZmlsbD0iI2IzNGIwMCIgZD0iTTMxMy4y'
    b'IDI0OWMxLjktMS42IDMtMyAyLjMtNC4yLS43LTEtMS44LjYtMyAuMiAwIDAtMi0xLjEtMi41'
    b'LTItMS0xLjItMi41LTIuMy0zLjMtMy40LS45LTEtNC4yLTUuMy05LjEtMTAuMy0xLjUtLjkt'
    b'MS4xLTQuNC0yLjItNS41IDAtLjgtMTAtMTAuNi0xMy40LTE0LTEuNS0xLjEtMi4yLTEuOC00'
    b'LjcuNS0yIDEuNy0yLjcgMy42LS4xIDUuOGwxMi44IDExLjdjMS45IDEuOCA0LjUgMi4xIDUu'
    b'NiAzbDEzIDEzLjRjMS43IDEuNCAyLjUgMi40IDEuNSAzLjYtMSAyIC4xIDIuMy4zIDIuMy4y'
    b'LjEgMS4xLjEgMS43LS40bDEtLjd6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJtMjgw'
    b'LjcgMjE0IDEzLjQgMTMuMiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRo'
    b'PSIuNiIgZD0ibTI5OC44IDIyMCAxLjEtMi41Yy4yLS40IDMuOC02LjIgNS42LTYuM2wxMS4z'
    b'IDguMmMwIC41LTUgNy44LTUuMyA3LjIgMCAwLTEzLjItNS41LTEyLjctNi42eiIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2NjYjhjOCIgc3Ryb2tlPSJub25lIiBkPSJNMzA2IDIyMmMtMS42LTEu'
    b'Mi00LjEtMi40LTYuMi0zLjhsLS45IDJjLjcuOCAxMCA1LjEgMTEuNiA2IDAgMC0xLjgtMi00'
    b'LjYtNC4yeiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0i'
    b'TTI5OS44IDIxOGE3MyA3MyAwIDAgMCA1IDMuMWMyLjcgMiA0LjQgNCA2LjQgNS4yIi8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjNzgyMTIxIiBkPSJtMjc3LjEgMjUzIDI1LjUtMzEuN2MuNS0uNCAy'
    b'LjktLjQgMy4yIDJsLTI0LjIgMzNzLTIuNy0uMy00LjUtMy40eiIvPgogICAgPHBhdGggZmls'
    b'bD0iIzczMDAwMCIgZD0iTTM2Mi43IDI1My4zYy0xIC43LTIuNC44LTIuNC44LTEuNy0xLjkt'
    b'My00LTUuNC02LjVsLTI1LjUtMzEuMyAyLjctMi42IDIzIDI2LjljLjYuNyA0LjYgNC45IDgu'
    b'NCA5LjggMCAwIC4zIDItLjggMi45eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTMz'
    b'OC4xIDIyMC4zLTQtNXMtMy4yLjUtMy44IDIuMWMwIDAtMi4yIDMuNy04LjIgNC4xIDAgMCAx'
    b'LjcgNyA4LjYgMTAuNyAwIDAgMi41LTcuMiA1LTguNCAwIDAgMi41LTEuOSAyLjQtMy42eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iIzczMDAwMCIgZD0iTTMyNy45IDI0MmMtLjYtLjMtMS4yIDAt'
    b'MiAuNC0uOS41LTEuOC4zLTEuNy0uNyAwLS44IDAtLjcgMS0xLjRhNi4zIDYuMyAwIDAgMSA1'
    b'LS41bC0yLjMgMi4xbTI3LjgtMjcuN2MtLjItLjctLjQtMS40LjMtMi4yLjctLjguNy0yLjIt'
    b'MS0xLjUtMS43LjctMi4yIDIuNS0uOSA1LjRsMS42LTEuN3oiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Im0zMjcuMyAyNDIuNSAyOC45LTI4LjcgNy4xIDcuNnMtMS41LS42LTItLjJj'
    b'LS41LjQuNSAxLjkuNSAxLjlzLTEuMy0uNS0xLjktLjFjLS43LjQgMCAyIDAgMnMtMS4yLS44'
    b'LTEuOC0uNWMtLjUuNCAwIDIuMyAwIDIuM3MtMS41LS41LTItLjFjLS4zLjQgMCAyIDAgMnMt'
    b'MS41LS43LTIuMyAwIC40IDEuOS40IDEuOS0yLS44LTIuNy40Yy0uOCAxLjIuMSAyLjIuMSAy'
    b'LjJzLTEuNi0uNy0yLS40Yy0uNC40IDAgMi4zIDAgMi4zcy0xLjMtLjgtMi4yLjJjLS45IDEg'
    b'LjEgMiAuMSAycy0xLjMtLjgtMi0uNGMtLjYuNC4yIDIuMi4yIDIuMnMtMS4yLS45LTIuMSAw'
    b'Yy0uOSAxIDAgMiAwIDJzLTEtMS0yLjIgMGMtMSAxIDAgMi4xIDAgMi4xcy0xLjUtLjgtMi4x'
    b'IDBjLS43LjguMiAxLjkuMiAxLjlzLTEuMi0uNy0yLS4zYy0uNy40IDAgMi4xIDAgMi4xcy0x'
    b'LjEtMS4zLTEuNi0uNmMtLjYuNyAwIDIuNCAwIDIuNHMtMS0xLjMtMS42LS42Yy0uNy42LjQg'
    b'MiAuNCAycy0yLS44LTEuNS0uOHoiLz4KICAgIDxwYXRoIGZpbGw9IiM3ZTRiN2UiIHN0cm9r'
    b'ZT0ibm9uZSIgZD0ibTM1NC41IDIxNi4yLTIuMiAyLjIuNSA3LjdzLjUtMi4yIDEuMS0uN2Mw'
    b'IDAgLjItMS44LjctMS41LS40LS4yIDAtNy44IDAtNy44bS00LjMgNC4zLTEuNiAxLjUuNiA3'
    b'LjdzLjQtMi45IDEuMS0uNnYtOC42bS0xNy42IDE3LjItMS41IDEuNy40IDQuN3MuNS0zIDEu'
    b'MS0uN2wtLjItMi42LjItMyIvPgogICAgPGcgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjN2U0Yjdl'
    b'IiBzdHJva2Utd2lkdGg9Ii45Ij4KICAgICAgPHBhdGggZD0iTTMzMC45IDIxOC4zYzEgMSA0'
    b'IDUgNCA1bS0yLjYtMi45Yy0uMi42LS42IDIuMy0xLjUgMy4ybTItMi44Yy0uMi40LS4yIDEu'
    b'Ny0xLjUgM20yLTIuNGMtLjMuNy0uNCAxLjItLjggMS43bTEtMWMwIC40LS4zLjUtLjQuOG0t'
    b'My4yLTIuN2EyOSAyOSAwIDAgMS00LjggMi44bTQtMS44YTE0IDE0IDAgMCAxLTMuMSAyLjJt'
    b'Mi44LTFjLS41LjQtMS41IDEuNC0yLjMgMS43bTEuOC0uNWMtLjQuNS0xIC44LTEuNSAxLjEi'
    b'Lz4KICAgICAgPHBhdGggc3Ryb2tlLWxpbmVjYXA9InNxdWFyZSIgZD0iTTMxMS4zIDIyNC43'
    b'Yy4zLS42LjktMS44IDEuNi0yLjggMS0xLjQgMS4zLTEuNiAxLjgtMiIvPgogICAgPC9nPgog'
    b'IDwvZz4KICA8cGF0aCBmaWxsPSIjMjg5NDAwIiBzdHJva2U9IiMwNjAiIHN0cm9rZS13aWR0'
    b'aD0iLjUiIGQ9Ik0yMTcgMzAzLjRjMS41LjcgMC00LjguNS02LjguNi0yLjIgNC44IDUuMiA2'
    b'LjggNi4yIDIuMiAxIDE1LjMtNS4yIDE1LjMtNS4ybDMuMS01LjggMS43IDQuOHMzLjYtNC4y'
    b'IDQuNi01LjhjMS4xLTEuNiAwIDMuMS0xIDQuNy0xLjEgMS41IDMuMSAyLjEgMi42IDUuMy0u'
    b'NSAzIDQuMi0yLjIgNC4yLTIuMmwxMi4xIDFzMi03LjMgNS4zLTExLjVsMSA0LjggNS01LjFh'
    b'NjUuOSA2NS45IDAgMCAwIDQxLjMgMzkuMiA2Ni42IDY2LjYgMCAwIDAgNDAuMi0zNi42bDYu'
    b'NyA3czUuMy0xLjYgNi4zLTIuMmE3MC4zIDcwLjMgMCAwIDEgMTUuNSA1LjZjMSAuNy4zLTMu'
    b'NS4zLTMuNXM1LjggMS4xIDUuMyA0LjJjMCAwIDEuMi0yLjkgMi4zLTMuNCAxLjEtLjUgMy42'
    b'IDIuNyA0LjIgMy43LjUgMSAxMyAyLjYgMTQuNyAzLjYgMCAwIDEuMyAxLjYgMS4zIDIuNyAw'
    b'IDAgMi43LS4zIDQuNy0uMyAwIDAtMS41LjgtMS41IDIuNCAwIDEuNi0uOCAyLjktMi40IDMu'
    b'Ni0xLjUuOCAwIDEuNCAyIDEuNiAyLjIuMyAwIDMtNC4xIDQuNSAwIDAtMSAyLjMuOCAzLjEg'
    b'MCAwLTMuNy4zLTQuMi0uOCAwIDAtMS4zIDIuNS0xLjMgMy44IDAgMC00LTEuMy01LTEuOSAw'
    b'IDAtMS42IDEuNi0uNSAyLjMgMCAwLTcuMS0uNy04LjUtMy40IDAgMC0yLjUuOC0yIDEuNyAw'
    b'IDAtNS0zLjQtNi42LTMuNGwtMSAxLjdzLTMuNS0yLTQuNS0yLS4yIDEuNS0uMiAxLjVsLTQu'
    b'OC0yLjktMS45IDMtNS0yLjdjLTEtLjgtMS4yIDEuNi0yIDEuOSAwIDAtMS42LTIuMi0zLjct'
    b'MS45IDAgMC0uOCAyLjYtLjUgMy40bC03LjEtMS41Yy0xLjEtLjMtLjUgMS4yIDAgMi4zIDAg'
    b'MC00LjUtMS4zLTUuNS0ybC0uMyAycy0zLjctLjMtNC41LTFsLTIuMyAzLjFoLTMuNWwtLjcg'
    b'Mi45cy02LjYtMS45LTcuMi0uOGMtLjUgMSAuMyAyLjYuMyAyLjZsLTUuNy0uNy0uNSAyLjNz'
    b'LTYuNy0yLTguMi0xYzAgMC0yIDItMy40IDIuNi0xLjMuNSAwLS44IDAtLjhsLTItMi45cy0y'
    b'LjQgMS4zLTMuOC44Yy0xLjMtLjYtNS41IDItNi44IDEuMyAwIDAgMC0xLjktMS4xLTIuNC0x'
    b'LS40LTIuOC0uNC0zLjYuOGwtMi4yLTNjLTEuMi0yLjItMy4xLjEtMy4xLjFsLS4zLTIuNS0z'
    b'LjYtLjNjLTIuMi0uMy0yLjYtMi4yLTIuNi0yLjJzLTUuNi42LTYuNC4zbDEuNC0xLjNzLTcu'
    b'NiAxLjYtOS4yIDFjLTEuNy0uNSAxLjgtMi42IDEuOC0yLjZsLTguNC0yYy0xLjMtLjQtOSAx'
    b'LjItMTAgMS4ycy0xLjYtMS44LTEuNi0xLjgtMS44IDEuNi0zLjQgMi4xYzAgMC0xLjMtMy4x'
    b'LS41LTMuNCAwIDAtNSAxLjMtNS4zIDIuNiAwIDAtMS4yLTItMS0zIDAgMC0yLjQgMy44LTMu'
    b'NSA0LjYtMSAuOC0uMi0xLjktLjItMS45cy0yLjkgMy43LTQgNHYtMi42cy04LjQgNC41LTEw'
    b'LjcgMy45YzAgMCAwLTEuOS44LTIuNGwtNS4zLS4yYy0xLjMtLjItMi44LS44LTQuMi0xLjEt'
    b'MS4zLS4yIDEuOS0xLjYgNC0xIDAgMC01LjgtMi4xLTcuNi0xIDAgMC0uOC0yLjIgMi4zLTMg'
    b'MCAwLTQtMy45LTYuMy0zLjYgMCAwIDIuNi0xLjYgNC44LS44IDAgMC0yLjUtNi42LTQtNy40'
    b'IDAgMCA1LjUtMSA3LjEtLjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzczMDAwMCIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNMjA4LjkgMTg4LjggMjgwIDE1MmMuMy0yLS43'
    b'LTMuNC0xLjktNS0yMC4zIDEwLTM4LjggMjIuMi02MS40IDI5LjUtMS4zLjUtMTIuNSA1LjIt'
    b'MTguMyAxMi4xYTcuNyA3LjcgMCAwIDAtMiA0LjVzLjIgMy4xLjkgNGMwIDAgLjEuOCAxLjIg'
    b'MS41IDAgMCAuNy4zIDEuMS4yLjUgMCAxLjQgMCAyLjYtMmE1Mi40IDUyLjQgMCAwIDEgNi43'
    b'LTh6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'Ii41IiBkPSJtMjY2LjEgMTUyLjQgOS4yLTQuNHMzLjEgMi4zIDIuOCA1YzAgMCAuNyA2IDgu'
    b'MiAxMC4yIDAgMC02LjMgOC0xNy40IDguNiAwIDAgMS4yLTEwLjQtMS4xLTEzLjUgMCAwLS40'
    b'LjQtLjItLjEuMy0xLS4yLTQuNS0xLjctNS4zbC4yLS41eiIvPgogIDxwYXRoIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZT0iIzdlNGI3ZSIgc3Ryb2tlLXdpZHRoPSIuOCIgZD0iTTI3Ni45IDE1My42'
    b'Yy0yIC44LTguMyA0LjEtOC4zIDQuMW01LjItMi4xYzAgMS0uNiAzLjMgMCA1bS0uOC00Ljdj'
    b'MCAuNS0uOCAyLjIgMCA0LjZtLTEtNC4xYy0uMiAxLS40IDEuNSAwIDIuNm0tLjgtMmMtLjIu'
    b'NSAwIC44IDAgMS4ybTUuOC0xLjVjLjMuNyAyLjkgNC44IDQuNSA2LjVtLTQuMS00LjdjLjMu'
    b'OCAxLjcgMy42IDIuOCA0LjdtLTMtM2MuNCAxIDEuMSAyLjcgMiAzLjdtLTItMS44YTggOCAw'
    b'IDAgMCAxLjEgMi41Ii8+CiAgPGcgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii41Ij4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNiMzRiMDAiIGQ9Im0zNDIuMyAxNDguMyAyNi4xIDEyLjhjNS4y'
    b'IDIuNSA3LjEuMiAxMCAxLjVsNTEuNiAyNi4yYzQuNSAyIDcgMi41IDYuMyA0LjgtLjEgMy43'
    b'IDEuNyAzLjcgMi4yIDMuOC40IDAgMi4xLS4yIDIuOC0xLjJsLjYtLjZjLjYtLjYuNS0uNy43'
    b'LTEgMi4xLTMgMy4zLTUuOCAxLTcuNS0yLjUtMS4zLTIuOCAxLjUtNS42IDEuMiAwIDAtNC44'
    b'LTEuOC02LjYtMy4xLTMuMi0xLjgtNy44LTMuOS04LjgtNS0zLjMtLjYtMjgtMTQuNi00Mi4x'
    b'LTIxLjYtMS41LTEuMi0yLjMtNS45LTUuMy03LjQtLjgtMS4zLTE5LjgtMTAtMjkuOC0xNS0z'
    b'LjYtMS4zLTUuNy0yLjItOC4zIDIuMy0yLjMgNC40LTEuOCA2LjggNS4yIDkuOHoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIGQ9Im0zNDQuNSAxNDIuOCAyOS4yIDE0LjYiLz4KICA8L2c+'
    b'CiAgPGcgZmlsbD0iI2ZmYTU0YiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii41IiB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSgtNDApIHNjYWxlKC45NikiPgogICAgPHBhdGggZmlsbD0i'
    b'dXJsKCNiei1jKSIgZD0iTTMwOS43IDE2NS4xYy0uMi42LS43LjItLjcuNC0uNCAyLjItLjMg'
    b'My4zLS44IDQuNWE3LjEgNy4xIDAgMCAxLTMuMSAyLjZjLTIgLjctNC41IDMuMS04LjUuOWwt'
    b'LjYtLjVzMS4xIDQuMS0zIDYuMmwtMTUuNyA4LjJzLTEuNSAyLjgtLjUgNi41YzAgLjYuMyAx'
    b'LjEtLjMgMS41LTEgLjctMi43IDIuOC0zLjcgNiAwIDAtMy0xLjMtMy0zLjIgMC0yIDEuMi0z'
    b'IDEuNS00LjQuMy0xLjMgMS00LjcuNy01LjctLjQtMS4xLTIuMy0xLjUtMy0yLS42LS4zLTEu'
    b'NC41LTEuMyAxLjQuMSAxIC44LjggMS42IDEgMCAwLS45IDItLjggMy40bC05LjIgNC44IDEu'
    b'NiAyLjNjLjQuNyAxLjMgMTAuMiA0IDE0LjdzMy43IDMuMiA0LjMgMy44bDIgMmMuOC41IDQg'
    b'LjggNC41LTFhOSA5IDAgMCAxIDMuMi00LjFjMi0xLjYgNi01LjQgNi03LjIgMCAwIDIuMyA2'
    b'LjggMiAxMi40IDAgMCA4LjUgMS43IDE2LjEgMS45IDcuNiAwIDExLjUtMS41IDExLjUtMS41'
    b'czEtNi40LjYtNy43YzAgMCAxLjIgNC4yIDIuMiA1LjYgMSAxLjggMi4xIDUuMyA0LjMgNS41'
    b'IDIuMi4xIDQtMi4xIDQuMi0zdi02LjhoOC43czMuOCAxLjUgNSAxLjNjMS4zLS4xIDItMS4z'
    b'LjgtMS43bC0uNC0uM2MxLjIgMCAyLjYuNyAyLjYuN2g0LjNsLS4xLS41Yy0uMy0xLjItMi42'
    b'LTIuMi00LjItMy0xLjYtLjUtMy41LTEuMi00LjctMS4zYTIwIDIwIDAgMCAwLTYuMi40Yy0u'
    b'OCAwLTMuOS40LTUuOCAxLjMtLjUuMy0xIC40LS44LTEgLjMtMS4zLjItNy44LTEuMy0xMC41'
    b'LTEuMi0yLTEtMy42LS45LTUuMmE4NyA4NyAwIDAgMCAwLTguOGMtLjMtMS43LTIuNS00LTYu'
    b'Ni00LjQtMy44LS41LTctMy43LTcuMy02LjItLjMtMi42LjQtNy4yLjgtOS4zIi8+CiAgICA8'
    b'ZyBmaWxsPSJub25lIj4KICAgICAgPHBhdGggZmlsbD0idXJsKCNiei1kKSIgZD0iTTI5Mi40'
    b'IDE1My42Yy0uNyAzLjMtLjcgNi4xLS42IDkuMy4xIDIuMSAxLjEgNC42IDIgNi43YTEwIDEw'
    b'IDAgMCAwIDIuOCAzLjljMy42IDIuMyA3LS4yIDguOS0xYTYuNCA2LjQgMCAwIDAgMi43LTIu'
    b'NWMuNS0xLjIuMy0yLjEuOC00LjVsLjctLjRjMS0xLjUuNy0yIDEuMi0zIC42LTEtLjUtMi4y'
    b'LTEuOC0yIC42LTEuOSAxLTQgLjQtNS45LS4yLS42LjUtMi4yLS42LTEuOC00LjYgMS44LTEw'
    b'IDEuNC0xNC44IDEuNC0uNCAwLS44LS44LTEuNC0uN2wtLjMuNSIvPgogICAgICA8cGF0aCBm'
    b'aWxsPSIjMDAwIiBkPSJNMjkyIDE1NS4zYy0uNS0uNC0uNi0xLjMgMC0zLjIuNy0yIDAtMiAx'
    b'LjEtMy4ycy45LTEuNiAxLjYtMS45Yy43LS4yIDIuOC0uMiAzLjUtLjVhMTEgMTEgMCAwIDEg'
    b'OS0uM2MxLjUuOCAyLjUgMi44IDMuNCAzLjYgMSAuNyAxLjcgMy42IDEuNSA3LjktLjMgNC4z'
    b'LTEuMiAzLjUtMS4yIDMuNXMtMS4yLTItMi4yLS4zYzAgMCAwLTEuNy4yLTMgLjEtMS4xLS42'
    b'LTMuNC4xLTQuOSAwIDAtNS44IDEuOC04LjcgMS43LTMtLjItNy40LS45LTcuNi0xLjZsLS43'
    b'IDIuMiIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiNmZmYiIGQ9Ik0yOTUg'
    b'MTUxLjhjLS4zLS42LTEuOC0yLjktLjYtMy42IDEtLjYuNCAyLjggMiAzLjUgMCAwLS42IDEu'
    b'NS0xLjQuMXoiLz4KICAgICAgPHBhdGggZD0ibTI5OC4zIDE2MC4xLS45IDMuMm0xMC42IDEu'
    b'NmMuMi42LjQuMyAxIC40bS4zLTRjLjUtLjUgMS4yLS4yLjggMS4zbS0xNy43LTQuOSAyLjgg'
    b'MWMxLjUuNi42IDIuOS4yIDQuMy0uMi43LTEgMi0uNiAyLjUuNS44IDEuMS4zIDIgLjQgMC0u'
    b'My42LS41LjgtLjUuNyAwIDEuMS41IDEuNy4zLjYtLjMuNS0xLjIuMy0xLjdtLS4xLTQuNWMw'
    b'LS40IDEtLjggMS41LS45IDIuMS0uNCAzLjYtLjcgNS40LjVtLTUuNyAxMS4xYy0xLjguNC0z'
    b'LjYuNy01LjItLjJtMC0uOGMuOC0uNCAxLjEtLjggMi4xLS4zYTUgNSAwIDAgMSAxLjEtLjRj'
    b'LjggMCAxLjQuMyAyLjIuOG0tNS41LjNjMS0uMyAzLjMtLjMgNS40LjEiLz4KICAgICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTI5Mi4zIDE2MC4xYy43IDAg'
    b'MS42LS45IDMuMi4zIDEuMS44LTEuOCAxLjUtMS4zIDEuNC0xLjQuMi0xLjgtLjUtMS45LTEu'
    b'MiAwLS4xLS4yLS41IDAtLjV6bTguNC44Yy43LTEuNCAxLjgtMSAyLjgtLjggMSAuMy43LjEg'
    b'MS43LjctMS4yLjEtLjkuMi0xLjcuNi0uOS41LTEuNy43LTIuMy4zLS4yLS4yLS43LS41LS43'
    b'LTEgMCAuMiAwIC4zLjIuM3oiLz4KICAgICAgPHBhdGggZmlsbD0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIuMyIgZD0iTTI5My44IDE2MS40Yy40IDAgLjctLjQuNy0uOCAwLS42LS4zLTEtLjct'
    b'MS0uNSAwLS45LjQtLjkgMSAwIC40LjQuOC45Ljh6bTguNi4yYy40IDAgLjctLjQuNy0xYS44'
    b'LjggMCAwIDAtLjgtLjhjLS40IDAtLjcuMy0uNy44IDAgLjYuNCAxIC44IDF6Ii8+CiAgICA8'
    b'L2c+CiAgICA8ZyBpZD0iYnotZyI+CiAgICAgIDxnIGZpbGw9Im5vbmUiPgogICAgICAgIDxw'
    b'YXRoIGQ9Ik0zNDUuOSAyMTMuN2EzLjkgMy45IDAgMCAwLTEuOS0xLjRsLTItMWMtLjctLjQt'
    b'MS43LS41LTIuNC0uOW0uNSAyLjYtLjktLjVjLS4zIDAtLjcgMC0xLS4yIDAgMCAwLS4yLS4y'
    b'LS4yYTMuNSAzLjUgMCAwIDEtMi40LTEuM20tNjIuOC05LjNjMSAuNyAzLjIgMi4yIDMuNCA1'
    b'LjFhMTAuNSAxMC41IDAgMCAwIDEgM00yNjQgMjAyYy41IDEuNy42IDcuNCA2IDEzLjRtLTUt'
    b'MjEuNGMtLjQgMS4xLTEgMi4yLjIgM20xNC40IDEwLjdjMS4xLTIuNiA0LjYtMi40IDQuNi00'
    b'LjgiLz4KICAgICAgICA8cGF0aCBkPSJNMjg0LjggMjA3LjNjLS4zLTIuOS0xLTQuNS0uNC04'
    b'LjcuMi0xLjIuNC01LjkgMC04LjEgMCAwIDEuNiA3LjgtMy43IDkuM20zNC40IDEyLjVjMC00'
    b'IDEtNi4yIDEtNi4yIDEuMi01LjYtMS4yLTcuNy0uMy05LjEuOS0xLjIgMi0zLjguNS04Ljkg'
    b'MCAwIDIuOCAxMC41LTQuNSAxMC41LTcuNSAwLTcuMi0yLjctNy4yLTIuNyIvPgogICAgICAg'
    b'IDxwYXRoIGQ9Ik0yODQuNCAxOTAuNWMwIDIgMCA4LjQgOSA4LjQgMi44IDAgNS44LTIgNy40'
    b'LTMuM20yLjItMi43Yy0uMy0yLS4zLTQuNC0uMy03bS0xMy42LTMuNGMyLjQtLjMgNC40LS42'
    b'IDktLjZtLjItNi4zYy41IDIuMi0uMyA1LjggNCA2LjNtNC4zLTcuMWMtLjYgMS42LS42IDMu'
    b'My0uOCA0LjRtLjIgMi43YzEuNyAwIDUtMS4xIDktLjNtMS40IDIyLjhjLjkgMS42IDEgMy44'
    b'IDMuNiA2LjJtLTMxLjctMTEuNGMuMiAxLjMtMS44IDUuNy0uMyA5LjNhMTIuMyAxMi4zIDAg'
    b'MCAxLTEuMiAxMW02LjctMTljLS45IDEuNy0yLjMgMy4zLTIuNiA0LjdtNi42LTEuNmMwIDEt'
    b'Mi43IDguNy00LjcgMTAuOSAwIDAgMy42IDEuNCAzIDYuNm03LjQtMjFjMCAxLjItLjIgMS42'
    b'IDEgMi40bTIuNCAwYzEuMyAxLjYgNS41IDYuNSA0LjYgOS4ybS03LjQtNi41Yy4zIDEgLjMg'
    b'Ni4zLS42IDltLTIuMS0uMmMtMS4xIDAtMi44LjgtMyAyLjdtOC43LTNjMS4xLS4zIDMuMyAx'
    b'LjYgMy4zIDdtMTUuNy0xMC4yYy0yLjEuNi0zIDEuNy0yLjQgMS4xLTEuMSAxLTIuMiAxLjYt'
    b'Mi4yIDEuNiIvPgogICAgICA8L2c+CiAgICAgIDxwYXRoIGZpbGw9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iLjMiIGQ9Ik0yODkuOCAxOThjLjYgMCAxLjEtLjQgMS4xLTEgMC0uMy0uNS0uNy0x'
    b'LjEtLjctLjUgMC0xIC40LTEgLjggMCAuNS41LjkgMSAuOXptMjMgLjNjLjYgMCAxLjEtLjQg'
    b'MS4xLTEgMC0uNC0uNS0uNy0xLS43LS42IDAtMS4xLjMtMS4xLjhzLjUuOSAxIC45eiIvPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjgwLjUgMjM5LjhjMS4zLTggNS0xNC41IDUu'
    b'MS0xNS4yIDAgMCAzLjkuOSAxMC42IDEuNSA2LjYuNyA4LjQuNCAxMS41LjJsNi44LS44czEu'
    b'MiAyLjQgMS4zIDQuOGMuMyA1LjIgMi4zIDI3LjcgMi41IDMzLjcgMCAwIC44IDMuNi44IDEy'
    b'LjMgMCA5LjYgMi42IDI5IDIuNiAzOS40bC0yLjYuNXMtMTQuNSAxLjEtMTQuNS0uOGMwLTIu'
    b'MS0uOC0yNyAxLjQtNDIuMSAwIDAtLjUtMy0xLjQtNS41LS44LTIuNS00LjMtMTAtNC4zLTEx'
    b'LjcgMCAwLTUuNyAxNi02IDE4LjgtLjMgMi42LTEuMiAzOC40LTEuNyA0MS4zIDAgMC04LjIg'
    b'Ni4zLTkuMyA3LTEuMS40LTktMy40LTkuMy00LjRhMjExIDIxMSAwIDAgMSA0LjYtMzMuMmMx'
    b'LjQtNy4xLjYtOC40LjYtMTAuNHMuMS0yNy41IDEuMy0zNS40eiIvPgogICAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBkPSJNMjk0LjMgMjc1Yy0uNiAyLjItMS43IDQuMy0zLjYgNS43bS0yLjct'
    b'NTMuNmMtLjMgMS4zLTIuMyA3LjMtNy4yIDEwLjltMTQuMy05LjhjLTEuMSAzLjYtNS41IDIy'
    b'LjctNi4zIDQ1LjRtLS4zIDcuMS0xLjcgMjAuOG0tLjggM2E3MS4zIDcxLjMgMCAwIDAtMi43'
    b'IDE4LjdtMzIuMi0zNmMtLjIgMi0xIDE1LjcgMy42IDI4bS0xOC41LTg2Yy0uMyAyLjMtLjgg'
    b'MTYuNy0uOCAxNy44IDAgMS4yIDEuNiAyLjggMi40IDMgMCAwLTEuNi42LTIgNm0tNC0xMi44'
    b'Yy0uMyAxLjctMiA4LjUtMyAxMS4zbTEzLTI1LjVzNSAxIDUuMyAwYzAgMCAxLjYgMjkuNSAz'
    b'LjggNDZtLTExLjItNDIuMi0uNiAxNi41bTIuNSAyLjFzMS45IDIuOCAxLjQgNG0tMTcuOC0y'
    b'OCAzIC44bTUuMiAxLjZjLS4zLjktLjYgNC42LS42IDQuNm04LjggMzguOWMuNi44IDEuNCAy'
    b'IC44IDQuNCIvPgogICAgICA8cGF0aCBmaWxsPSIjOWI1ZjAwIiBkPSJNMjg1IDIyNC40czAt'
    b'My4yIDEuMS00LjhjMCAwIDMuNS43IDguNCAxLjIgNSAuNSA5IC45IDEyLjYuNSAzLjctLjQg'
    b'Ny40LTEuMyA3LjQtMS4zczEgNC44LjUgNS41YzAgMC00IC44LTguMyAxYTg2IDg2IDAgMCAx'
    b'LTE0LjUtLjggNTcgNTcgMCAwIDEtNy4zLTEuM3oiLz4KICAgICAgPHBhdGggZmlsbD0iI2Zm'
    b'ZiIgZD0ibTI4OCAyMjQuOC43LTQuOGgxbC0uMiA1LjEtMS40LS4ybTIyLTQuMS4xIDUuNSAx'
    b'LjMtLjItLjEtNS42LTEuMy4zbS0xNS42IDAtLjQgNS4zaC43bC43LTUuM2gtMSIvPgogICAg'
    b'ICA8cGF0aCBkPSJNMjc2LjggMzIwLjhjLS4zIDEuMy0uOCAzLjItMSA1LjUgMCAuNS0uNiAz'
    b'LjMgMSAzLjQgMSAwIDEuNC0yLjkgMS40LTIuOXMtMSAzLjMuMyAzLjdjMS44LjQgMi0zLjYg'
    b'Mi0zLjYtLjIgMS4xLTEuNCA0IC4zIDQuMyAxLjkuMyAyLjQtMy45IDIuNC0zLjlzLTEuNiA0'
    b'LjIuMyA0LjNjMS43IDAgMS43LTQgMS43LTRzLS45IDUgMS41IDQuNWMxLjQtLjIgMS43LTIg'
    b'Mi0zIC40LTEuNSAxLjMtMy40LjItNi42LS44LTIuMy0uNS0zLS41LTNzLTIuOSAyLjItNS4x'
    b'IDMuNmMtMSAuNi02LjUtMi4zLTYuNS0yLjN6bTI5LjctNC40Yy0uNS0uMy0uNCAxLjktLjYg'
    b'Mi45LS4xIDEgLjIgMy4yIDMuNiAzIDMuNC0uMyA2LjctMSA4LjktLjUgMi4xLjYgNS4zLjcg'
    b'NyAuNyAxLjcgMCAyLjgtLjIgMy43LS41LjctLjMgMi4yLjQgMyAuNHMxLjctMSAxLjYtMS44'
    b'YzAtMS4zLTEuMy0xLjMtMy0xLjRhMjIgMjIgMCAwIDEtNS0xYy0xLjEtLjMtMy4xLTEuNS01'
    b'LjctMmwtNS45LjJjLTEgMC03IC4zLTcuNiAweiIvPgogICAgPC9nPgogICAgPGcgZmlsbD0i'
    b'bm9uZSI+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmIzNjYiIGQ9Ik0yNTUuNyAxODkuOGMtLjUu'
    b'My0xLjEtMiAuNC0yLjkgMCAwIC40LTIgMi0yLjEgMCAwIDEuNC0xLjkgMy4zLTEuNyAwIDAg'
    b'Mi4yLTEuNSAzLTEuMy45LjEgMyAyLjEgMyAyLjkuMi43IDAgMS45LS41IDIuNC0uNi42LTEt'
    b'LjEtMS4xLTEgMCAwIC40IDEuNi0uOCAyLjItMS4yLjctMS4xLjItMS4yLS42IDAgMC0uNCAx'
    b'LjYtMS4yIDEuOS0uOC4zLTEuMy0uNS0yLS41IDAgMCAxLjEuOS40IDEuNS0uNy41LTEuNS4z'
    b'LTItLjEtLjUtLjUtMS4yLTEuOS0zLjMtLjZ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNjUuNyAx'
    b'ODZjLS41LTEuNS0yLjItMy00LTIuOG0yLjIgNC40Yy0uMy0uNC0uNC0uOC0uOC0xLjItLjkt'
    b'MS41LTIuOC0xLjQtNC40LTEuOG0yLjQgNC41Yy0uNi0uNC0uOC0xLjItMS40LTEuNS0xLS40'
    b'LTItLjktMy4zLS43Ii8+CiAgICA8L2c+CiAgPC9nPgogIDxnIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIuNSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTQwKSBzY2FsZSguOTYpIj4K'
    b'ICAgIDxwYXRoIGZpbGw9InVybCgjYnotZSkiIGQ9Ik00MzkuMSAxNjUuMWMuNy0uMy41LjYu'
    b'NiAxIC40IDEuMy40IDIuNy45IDMuOS42IDEuMS44IDEuNSAxLjggMiAxLjYgMSA2LjQgMy42'
    b'IDkuOCAxLjVhMy4xIDMuMSAwIDAgMCAuNy0uNXMtMS4zIDQuMSAzIDYuMmwxNS42IDguMnMx'
    b'LjUgMi43LjYgNi41Yy0uMi42LS40IDEuMS4yIDEuNSAxIC43IDIuNiAyLjggMy44IDYgMCAw'
    b'IDMtMS4zIDMtMy4yIDAtMi0xLjMtMy0xLjYtNC40LS4yLTEuMy0xLTQuNy0uNi01LjcuNC0x'
    b'LjEgMi4xLTEuNSAyLjgtMiAuNy0uMyAxLjYuNSAxLjMgMS40IDAgMS0uOC44LTEuNiAxIDAg'
    b'MCAxIDIgLjggMy40bDkuNCA0LjgtMS42IDIuM2MtLjUuNy0xLjUgMTAuMi00LjIgMTQuNi0y'
    b'LjggNC41LTMuNyAzLjMtNC4yIDRsLTIuMSAxLjhjLS42LjUtMy44LjktNC41LS45YTkgOSAw'
    b'IDAgMC0zLjEtNC4xYy0yLTEuNi02LTUuNC02LTcuMiAwIDAtMi4zIDYuOC0yIDEyLjQgMCAw'
    b'LTguNCAxLjctMTYuMiAxLjktNy42IDAtMTEuNS0xLjUtMTEuNS0xLjVzLTEtNi40LS42LTcu'
    b'N2MwIDAtMS4yIDQuMi0yIDUuNi0xLjEgMS44LTIuMiA1LjMtNC40IDUuNS0yLjIuMS00LTIu'
    b'MS00LjItM3YtNi44aC04LjdzLTMuOCAxLjUtNSAxLjNjLTEuMy0uMS0xLjktMS4zLS45LTEu'
    b'N2wuNC0uM2E3IDcgMCAwIDAtMi41LjdINDAybC4xLS41Yy4zLTEuMiAyLjYtMi4yIDQuMy0z'
    b'IDEuNi0uNSAzLjMtMS4yIDQuNi0xLjMgMS45LS4yIDMuMi0uMSA2LjIuNC44IDAgNCAuNCA1'
    b'LjggMS4zLjUuMyAxIC40LjgtMS0uMy0xLjMtMS4yLTUuNS4zLTguMyAxLTEuOS45LTMuNS44'
    b'LTUuMi0uMi0xLjctMS4xLTUuNi0xLjEtNy4zIDAtNS43IDQuNC04IDguMi05LjIgNC4zLTEu'
    b'NCA3LjEtMi44IDctNS4zLS4yLTIuNy41LTcgLjEtOSIvPgogICAgPGcgZmlsbD0ibm9uZSI+'
    b'CiAgICAgIDxwYXRoIGZpbGw9InVybCgjYnotZikiIGQ9Ik00NTYuMyAxNTMuNmEyMCAyMCAw'
    b'IDAgMSAxLjIgNS4zYzAgMS4yLS41IDEuNC0uMSAyLjguNyAyLjQtLjggNS0yLjUgOC0uOCAx'
    b'LjItMS40IDMtMi43IDMuOC0zLjQgMi4xLTcuNS0uNC05LjYtMS4zYTMuNyAzLjcgMCAwIDEt'
    b'Mi0yLjJjLS40LTEuMi0uNS0yLjMtLjgtNCAwLS4zIDAtMS4yLS42LS45LTEuMy0xLjQtMS0y'
    b'LTEuNi0zLS41LTEgMS0yLjIgMi0yYTEwIDEwIDAgMCAxLS4yLTUuOWMuMi0uNi0uNi0yLjIu'
    b'NS0xLjggNC41IDEuOCAxMCAxLjQgMTQuOCAxLjQuNCAwIC43LS44IDEuMy0uN2wuMy41Ii8+'
    b'CiAgICAgIDxwYXRoIGZpbGw9IiMwMDAiIGQ9Ik00NTYuOCAxNTUuM2MuNC0uNC4xLTIuMy0u'
    b'NC00LjMtLjEtMS0xLTEuNS0yLTIuNnMtMS42LTEtMi4zLTEuNGMtLjYtLjItMi0uMi0yLjgt'
    b'LjUtLjYtLjMtMi4yLS4xLTMuNy4xLTIgLjMtMy4yLjItNC43IDFzLTIuOCAxLjgtMy4zIDMu'
    b'M2MtLjQgMS0xIDIuNS0uOCA2LjguMiA0LjMgMSAzLjUgMSAzLjVzMS4xLTEuNyAxLjktLjZs'
    b'LS4zLTMuNmMtLjEtMS4yIDAtMi44LjUtNC42IDAgMCA0LjYgMS43IDkgMS43IDMgMCA3LS4z'
    b'IDcuMS0xbC43IDIuMnoiLz4KICAgICAgPHBhdGggZD0iTTQ1MC40IDE2MC4xYy43IDEuOC4x'
    b'IDEuMy40IDIuNG0tMTAuMiAyYzAgLjgtLjYuNi0xIC42Ii8+CiAgICAgIDxwYXRoIGQ9Ik00'
    b'NTYuOSAxNTguOGMtMS0uNy0yLjctLjItMy41LjEtMS41LjctLjcgMi4zLS4yIDMuNy4yLjcg'
    b'MSAxLjcuNSAyLjQtLjQuOC0uNy40LTEuNi41IDAtLjMtLjggMC0xLjEgMC0uNiAwLTEgLjQt'
    b'MS41LjItLjYtLjMtLjUtMS4yLS4zLTEuN20uMS00LjVjMC0uNC0xLjMtLjgtMi43LS45LTIu'
    b'MyAwLTIuNS4xLTQuMiAxLjNtMTEuNSA5Yy0uNC0uNi0xLTEtMi4xLS40IDAtLjItMS42LS40'
    b'LTEuNi0uNC0uOCAwLTEuMy4zLTIuMS43bTUuNi42Yy0xLS42LTMuMy0uMi01LjYtLjJtLjIu'
    b'OGMxLjcuNSAzLjUuOCA1LjIgMCIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2Ut'
    b'd2lkdGg9Ii4zIiBkPSJNNDU2LjQgMTYwLjFjLS43IDAtMS0uOS0zLjEuMy0xLjEuNyAxLjgg'
    b'MS41IDEuNCAxLjQgMS4yLjIgMS42LS41IDEuNy0xLjIgMC0uMS4yLS41IDAtLjV6bS04LjMu'
    b'OGMwLS44LTEuOC0xLTIuOS0uOC0xIC4zLS41LjEtMS41LjcgMSAuMS43LjIgMS42LjYuOS41'
    b'IDEgLjkgMi4zLjMuMy0uMS43LS41LjgtMSAwIC4yLS4yLjMtLjMuM3oiLz4KICAgICAgPHBh'
    b'dGggZmlsbD0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTQ1NS4xIDE2MS40YS44Ljgg'
    b'MCAwIDEtLjgtLjhjMC0uNi4zLTEgLjgtMSAuNCAwIC43LjQuNyAxIDAgLjQtLjMuOC0uNy44'
    b'em0tOC43LjJjLS40IDAtLjctLjQtLjctMSAwLS41LjQtLjguOC0uOHMuNy4zLjcuOGMwIC42'
    b'LS4zIDEtLjggMXoiLz4KICAgIDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2J6LWciIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9IiM3MzAwMDAiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC0xIDAgMCAxIDc0OC44IDApIi8+CiAgICA8ZyBmaWxsPSJub25lIj4KICAgICAgPHBh'
    b'dGggZmlsbD0iIzczMDAwMCIgZD0iTTQ5MS42IDE5My41Yy41LjIgMi0yIC41LTMgMCAwLS41'
    b'LTItMi0yIDAgMC0xLjQtMi0zLjQtMS43IDAgMC0yLTEuNS0yLjktMS40LTEgLjItMyAyLjIt'
    b'MyAzLS4yLjUgMCAxLjguNSAyLjQuNi41IDEtLjEgMS0xIDAgMC0uMyAxLjUuOSAyLjIgMS4y'
    b'LjcgMS4xIDAgMS4yLS43IDAgMCAuMyAxLjYgMS4xIDIgLjkuMiAxLjQtLjUgMi0uNSAwIDAt'
    b'MSAuOC0uMyAxLjMuNy42IDEuNS4zIDIgMCAuNi0uNS4zLTEuOCAyLjQtLjZ6Ii8+CiAgICAg'
    b'IDxwYXRoIGQ9Ik00ODIuNSAxODkuOGMuNS0xLjggMi4yLTMuMiA0LTIuOW0tMiA0LjRjLjEt'
    b'LjQuMi0uOC41LTEuMiAxLTEuNiAzLTEuNiA0LjYtMS45bS0yLjUgNC41Yy42LS40LjgtMS4x'
    b'IDEuNC0xLjRhNS4zIDUuMyAwIDAgMSAzLjItLjciLz4KICAgICAgPHBhdGggZmlsbD0iIzcz'
    b'MDAwMCIgc3Ryb2tlPSJub25lIiBkPSJNNDgyLjMgMTg2LjhjLS45LjctMS44IDEuOC0xLjkg'
    b'Mi4yIDAgLjcgMCAxLjkuNSAyLjUuNi41IDEgMCAxLjEtLjggMCAuNSAwIDEuNS44IDIgMS4z'
    b'LjcgMS4yLjEgMS4zLS43IDAgMCAuMyAxLjYgMSAyIC45LjIgMS40LS41IDItLjUgMCAwLTEg'
    b'LjgtLjMgMS4zLjcuNiAxLjUuMyAyIDAgLjYtLjUuMy0xLjggMi41LS42LjIuMi44LS40IDEt'
    b'MS4xbC03LjctNS41LTIuMy0uOHoiLz4KICAgICAgPHBhdGggZD0iTTQ4MC43IDE4OC4yYy0x'
    b'LjUgMi42LjUgNC4xIDEuMSAyLjYtLjEgMi40IDEuNyAyLjMgMi4zIDEuNS43IDIuNSAxLjkg'
    b'MS40IDMgMS4yLTEuMyAyLjMgMS40IDEuNiAyIDEgMS0xLjMgMS40LS4yIDItLjNsMS4zLTEu'
    b'M20tOC01LjdjLTEuNyAxLTIuNSAyLjItMi42IDMuN201LTIuMmMtMS44IDEtMi42IDIuMi0y'
    b'LjYgMy43bTUuNC0xLjdjLTEuNy45LTEuOCAxLjctMi41IDIuOCIvPgogICAgPC9nPgogIDwv'
    b'Zz4KICA8cGF0aCBmaWxsPSIjNWFjODAwIiBkPSJtMjM4LjUgMzEwLjctLjItNC41IDEuOSAx'
    b'LjYuNC0zLjRjLjgtLjIgMi4xIDEuMyAyLjEgMS4zbC0uMi0zLjQgMi44IDMuMXMtLjItMi42'
    b'LjgtNC4yYzAgMCAyLjIgMS45IDIuMiA0IDAgMS45IDEuOC0yLjYgMS44LTIuNmEzMTE2LjIg'
    b'MzExNi4yIDAgMCAwIDEuNiA1bDEuMy0xLjkgMSA0IDIuNC0zLjUgMS44IDQgNC4yLS4zLjUg'
    b'Mi40IDEuOS0yIDIuNCAxLjVzMi0uNiAzLjEtLjYgMi40IDEuNCAyLjQgMS40LjgtMS40IDEu'
    b'NS0xLjkgMS45LjggMi4yIDEuNmwxLjYtMi45czIgMiAyLjMgMi45YzAgMCAuMy0yLjQuOC0z'
    b'LjIuNS0uNyAxLjIuMyAxLjggMS4zbDEuMy00LjJzMS40LjMgMi4zIDEuOWMxLjEgMS41IDEu'
    b'MS0yLjQgMS4xLTIuNHMyLjQgMy4yIDMgNS4zYzAgMC0xNi4yIDUuNi0yNy42IDRhMzA2IDMw'
    b'NiAwIDAgMS0yNC41LTQuM20xMTAuOS0uNXMuNy0yLjEgMS44LTMuMmMwIDAgMiAyLjQgMiAz'
    b'LjJsMS43LTEgMS42IDEuNSAxLjgtMS4zIDEuOCAxLjYgMy4yLTEuNCAxLjMgMS40IDUtLjYg'
    b'MS44LjggMS44LTIuMyAxLjYgMS44IDIuNy0yLjZzMS4zIDEgMS41IDEuOGMwIDAgMi4yLTEg'
    b'Mi43LTEuOCAwIDAgMi0uOCAyLjMuNSAwIDAgMS4zLTEgMS4yLTItLjEtMS4yIDEuNS0uNCAy'
    b'IDEgMCAwIC41LTIuMiAyLTIuNCAwIDAgMS4yIDEuMy45IDMuNyAwIDAgMi4zLTEuOSAzLjQt'
    b'Mi4xIDAgMCAuNSAyLjYtLjMgNSAwIDAgMi40LTQgMy0yLjcuMS44LjcgMy41LjEgNS4zbDIu'
    b'Mi0xLjMuOCAyLjYgMi4zLS41cy0xMy45IDIuMS0yNyAuOWMtMTMtMS4zLTI1LjMtNS45LTI1'
    b'LjMtNS45bS05LjYgOS43Yy42LS40LTQuNCAxMC4zLTE2LjUgMTAuOS0xNi45LjgtMzEuMy03'
    b'LjctMzEuMy03LjdzMS44LTIuOSAyLjktMy43YzAgMCAyLjMgMS45IDMgNC4yIDAgMCAuNC0x'
    b'LjUgMS4yLTIuOSAwIDAgMi45IDEuNCAzLjQgMy4yIDAgMCAxLTEuOCAxLjgtMi4zLjgtLjYg'
    b'MS42IDIgMS42IDMuNiAwIDAgMS45LTIgMy0yIDAgMCAyIDEgMi42IDQuMyAwIDAgMi0xLjgg'
    b'Mi42LTEuNSAwIDAgMi4zIDEuNSAxLjggMy43LS4zIDEuMiAyLjMtMS40IDUuNS0yLjJsMi45'
    b'IDIuMiAzLjQtNC43czIuMS44IDIuMSAyYzAgMCAxLTMuNyAxLjgtNCAuOC0uNSAxLjggMS4x'
    b'IDEuOCAyLjIgMCAwIC4zLTIuOCAxLjktMy40IDAgMCAxLjYgMSAxLjYgMi4xIDAgMCAxLjYt'
    b'My4yIDIuOS00eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzA2MCIgc3Ryb2tl'
    b'LXdpZHRoPSIuNSIgZD0ibTIzOC41IDMxMC43LS4yLTQuNSAxLjkgMS42LjQtMy40Yy44LS4y'
    b'IDIuMSAxLjMgMi4xIDEuM2wtLjItMy40IDIuOCAzLjFzLS4yLTIuNi44LTQuMmMwIDAgMi4y'
    b'IDEuOSAyLjIgNCAwIDEuOSAxLjgtMi42IDEuOC0yLjZsMS42IDUgMS4zLTEuOSAxIDQgMi40'
    b'LTMuNSAxLjggNCA0LjItLjMuNSAyLjQgMS45LTIgMi40IDEuNXMyLS42IDMuMS0uNiAyLjQg'
    b'MS40IDIuNCAxLjQuOC0xLjQgMS41LTEuOWMuOC0uNSAxLjkuOCAyLjIgMS42bDEuNi0yLjlz'
    b'MiAyLjEgMi4zIDIuOWMwIDAgLjMtMi40LjgtMy4yLjUtLjcgMS4yLjMgMS44IDEuM2wxLjMt'
    b'NC4yczEuNC4zIDIuMyAxLjljMS4xIDEuNSAxLjEtMi40IDEuMS0yLjRzMi40IDMuMiAzIDUu'
    b'M201OC43LS44cy44LTIuMSAxLjktMy4yYzAgMCAyIDIuNCAyIDMuMmwxLjctMSAxLjYgMS41'
    b'IDEuOC0xLjMgMS44IDEuNiAzLjItMS40IDEuMyAxLjQgNS0uNiAxLjguOCAxLjgtMi4yIDEu'
    b'NiAxLjcgMi43LTIuNnMxLjIgMSAxLjUgMS44YzAgMCAyLjItMSAyLjctMS44IDAgMCAyLS44'
    b'IDIuMy41IDAgMCAxLjMtMSAxLjItMi0uMS0xLjIgMS41LS40IDIgMSAwIDAgLjUtMi4yIDIt'
    b'Mi40IDAgMCAxLjIgMS4zLjkgMy43IDAgMCAyLjMtMS45IDMuNC0yIDAgMCAuNSAyLjUtLjMg'
    b'NC45IDAgMCAyLjQtNCAzLTIuNy4xLjguNyAzLjUuMSA1LjNsMi4yLTEuMy44IDIuNiAyLjMt'
    b'LjVtLTEwOS44IDhzMS44LTMgMi45LTMuN2MwIDAgMi4zIDEuOCAzLjEgNC4yIDAgMCAuMy0x'
    b'LjYgMS0zIDAgMCAzIDEuNCAzLjUgMy4yIDAgMCAxLTEuOCAxLjktMi4zLjctLjYgMS41IDIg'
    b'MS41IDMuNiAwIDAgMS45LTIgMy0yIDAgMCAyIDEgMi42IDQuNCAwIDAgMi0xLjkgMi42LTEu'
    b'NiAwIDAgMi40IDEuNiAxLjggMy43LS4zIDEuMiAyLjMtMS40IDUuNS0yLjFsMi45IDIuMSAz'
    b'LjQtNC43czIuMS44IDIuMSAyYzAgMCAxLTMuNiAxLjgtNCAuOC0uNSAxLjkgMS4xIDEuOSAy'
    b'LjIgMCAwIC4zLTIuOCAxLjgtMy40IDAgMCAxLjYgMSAxLjYgMi4xIDAgMCAxLjYtMy4yIDMt'
    b'NCIvPgogIDxnIGZpbGw9IiNmZmYiPgogICAgPHBhdGggZD0iTTMxOS41IDM2MS45YzIyIC4y'
    b'IDM1LTcuOCA0Mi0xMi42IDE2LjgtMTEuMiAyMC4zLTExLjYgMjMtMTEuNCAzLjEuMyA3Ljcg'
    b'MS4zIDggNCAuMiA0LjMtNi42IDYuMS0xMC41IDYuMS00IDAtMTQuNS0yLjYtMTQuNS0yLjZs'
    b'LTIuNyAxLjljMS44LjggMjMuMiA4IDI3LjMgMS4yIDQuMi02LjggOC40LTE3LjkgOC40LTE3'
    b'LjlzLTQuNy04LjQtMTUuMS04LjRjLTEwLjYgMC0yMC44IDYuNy0yNy42IDExLjctNi45IDUt'
    b'MTUuNSAxMS44LTM4LjMgMTEuOC0yMi45IDAtMzEuNi02LjgtMzguNC0xMS44LTYuOS01LTE3'
    b'LjEtMTEuNy0yNy42LTExLjdhMTggMTggMCAwIDAtMTUuMiA4LjRzNC4yIDExIDguNCAxOGM0'
    b'LjEgNi43IDI1LjUtLjUgMjcuMy0xLjRsLTIuNi0xLjhTMjYxIDM0OCAyNTcgMzQ4cy0xMC45'
    b'LTEuOC0xMC42LTZjLjItMi44IDQuOC0zLjggOC00LjEgMi43LS4yIDYuMi4yIDIyLjkgMTEu'
    b'NGE3MiA3MiAwIDAgMCA0Mi4yIDEyLjYiLz4KICAgIDxwYXRoIGQ9Ik0yODQuMSAzMzZzMC0x'
    b'LjktLjMtNC42Yy0uNC0zLjUtMi40LTQuNC00LTMuOS0xLjIuNC0zLjMgMy0zLjMgM3YuMWEz'
    b'MSAzMSAwIDAgMC0zLTEuOCAxOCAxOCAwIDAgMSA2LjMtMy42YzEgMCAxNC41IDUuNCAxOC44'
    b'IDkuMSAxIDEgMS44IDcgMS4yIDlhNDYuNSA0Ni41IDAgMCAxLTE1LjctNy4ybS02LjUgMTMu'
    b'NnMtMi45IDMtMyA4LjNjMCA2LjMgNC41IDYuNiA3LjUgNi41IDMuNyAwIDYuNi0yLjEgNi41'
    b'LTguOSAwIDAtNi0yLjUtMTEtNm03Ny4xLTEzLjYuNC00LjZjLjQtMy41IDIuNC00LjQgNC0z'
    b'LjkgMSAuNCAzLjIgMyAzLjIgM3YuMWwzLTEuOGMtLjctMS01LjItMy42LTYuMi0zLjZzLTE0'
    b'LjUgNS40LTE4LjggOS4xYy0xIDEtMS44IDctMS4zIDlhNDUuNSA0NS41IDAgMCAwIDE1Ljct'
    b'Ny4ydi0uMW02LjUgMTMuN3MyLjkgMyAzIDguM2MuMiA2LjMtNC41IDYuNi03LjUgNi41LTMu'
    b'NiAwLTYuNS0yLjEtNi41LTguOSAwIDAgNi0yLjUgMTEtNiIvPgogIDwvZz4KICA8cGF0aCBm'
    b'aWxsPSIjNjlmIiBkPSJNMjcxLjMgMzQ1LjRTMjYwLjkgMzQ4IDI1NyAzNDhjLTQgMC0xMC45'
    b'LTEuOC0xMC42LTYgLjItMi44IDQuOC0zLjggOC00LjEgMi4zLS4yIDUuMyAwIDE3IDcuNW05'
    b'Ni4xIDBTMzc4IDM0OCAzODIgMzQ4YzMuOSAwIDEwLjctMS44IDEwLjQtNi0uMi0yLjgtNC44'
    b'LTMuOC03LjktNC4xLTIuMy0uMi01LjQgMC0xNyA3LjVtLTgzLjQtOS4zYTkzLjcgOTMuNyAw'
    b'IDAgMS0zLjEtMi4zYy0xLjUtMS4xLTMtMi00LjUtMy4yIDAgMCAyLjEtMi43IDMuMi0zIDEu'
    b'Ny0uNiAzLjcuMyA0LjEgMy44LjMgMi43LjMgNC43LjMgNC43bS03LjEgMjcuNmMxLjggMSAz'
    b'LjkgMSA1LjEuOCAzLjcgMCA2LjYtMi4xIDYuNS04LjkgMCAwIDQuNSAyLjMgMTEuOCA0IDAg'
    b'MCAxLjIgMS41IDEuNCA0LjQuMyAyLjUtMS40IDUuMS0zLjMgNSAwIDAtMTAuMy0yLTE2LjUt'
    b'My0zLjctLjctNS0yLjMtNS0yLjNtNzcuNy0yNy42IDMuMi0yLjMgNC40LTMuMnMtMi4xLTIu'
    b'Ny0zLjItM2MtMS42LS42LTMuNi4zLTQgMy44bC0uNCA0LjdtNy4xIDI3LjZjLTEuOCAxLTMu'
    b'OSAxLTUuMS44LTMuNiAwLTYuNS0yLjEtNi41LTguOSAwIDAtNC41IDIuMy0xMS43IDQgMCAw'
    b'LTEuMyAxLjUtMS41IDQuNC0uMiAyLjUgMS41IDUuMSAzLjQgNSAwIDAgMTAuMy0yIDE2LjUt'
    b'MyAzLjYtLjcgNS0yLjMgNS0yLjMiLz4KICA8ZyBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iLjciPgogICAgPHBhdGggZD0iTTMxOS41IDM2MS45YzIyIC4yIDM1'
    b'LTcuOCA0Mi0xMi42IDE2LjgtMTEuMiAyMC4zLTExLjYgMjMtMTEuNCAzLjEuMyA3LjcgMS4z'
    b'IDggNCAuMiA0LjMtNi42IDYuMS0xMC41IDYuMS00IDAtMTQuNS0yLjYtMTQuNS0yLjZsLTIu'
    b'NyAxLjljMS44LjggMjMuMiA4IDI3LjMgMS4yIDQuMi02LjggOC40LTE3LjkgOC40LTE3Ljlz'
    b'LTQuNy04LjQtMTUuMS04LjRjLTEwLjYgMC0yMC44IDYuNy0yNy43IDExLjctNi44IDUtMTUu'
    b'NCAxMS44LTM4LjIgMTEuOHMtMzEuNi02LjgtMzguNC0xMS44Yy02LjktNS0xNy4xLTExLjct'
    b'MjcuNi0xMS43cy0xNS4yIDguNC0xNS4yIDguNCA0LjIgMTEgOC40IDE4YzQuMSA2LjcgMjUu'
    b'NS0uNSAyNy40LTEuNGwtMi43LTEuOFMyNjEgMzQ4IDI1NyAzNDhzLTEwLjktMS44LTEwLjYt'
    b'NmMuMi0yLjggNC44LTMuOCA4LTQuMSAyLjctLjIgNi4yLjIgMjIuOSAxMS40YTcyIDcyIDAg'
    b'MCAwIDQyLjIgMTIuNnoiLz4KICAgIDxwYXRoIGQ9Ik0yNzEuMyAzNDUuNFMyNjAuOSAzNDgg'
    b'MjU3IDM0OGMtNCAwLTEwLjktMS44LTEwLjYtNiAuMi0yLjggNC44LTMuOCA4LTQuMSAyLjMt'
    b'LjIgNS4zIDAgMTcgNy41em05Ni4yIDBTMzc4IDM0OCAzODIgMzQ4YzMuOSAwIDEwLjctMS44'
    b'IDEwLjQtNi0uMi0yLjgtNC44LTMuOC03LjktNC4xLTIuMy0uMi01LjQgMC0xNyA3LjV6bS04'
    b'My40LTkuM2E5Mi42IDkyLjYgMCAwIDEtMy4xLTIuM2MtMS41LTEuMS0zLTItNC41LTMuMiAw'
    b'IDAgMi4xLTIuNyAzLjItMyAxLjctLjYgMy43LjMgNC4xIDMuOC4zIDIuOC4zIDQuNy4zIDQu'
    b'N3oiLz4KICAgIDxwYXRoIGQ9Ik0yODQuMSAzMzZzMC0xLjktLjMtNC42Yy0uNC0zLjUtMi40'
    b'LTQuNC00LTMuOS0xLjIuNC0zLjMgMy0zLjMgM3YuMWEzMS45IDMxLjkgMCAwIDAtMy0xLjgg'
    b'MTggMTggMCAwIDEgNi4zLTMuNmMxIDAgMTQuNSA1LjQgMTguOCA5LjEgMSAxIDEuOCA3IDEu'
    b'MiA5YTQ2LjYgNDYuNiAwIDAgMS0xNS43LTcuMm0tNi41IDEzLjZzLTIuOSAzLTMgOC4zYzAg'
    b'Ni4zIDQuNSA2LjYgNy41IDYuNSAzLjcgMCA2LjYtMi4xIDYuNS04LjkgMCAwLTYtMi41LTEx'
    b'LTZ6Ii8+CiAgICA8cGF0aCBkPSJNMjgwLjEgMzUxLjFzLTIuMyAyLjUtMi43IDYuNWMtLjIg'
    b'My4xIDEuOCA0LjkgNC41IDQuNyAzLjctLjIgNS4xLTUuMyAzLjQtOC4xbC01LjItMyIvPgog'
    b'ICAgPHBhdGggZD0iTTI3NyAzNjMuN2MxLjggMSAzLjkgMSA1LjIuOCAzLjYgMCA2LjUtMi4x'
    b'IDYuNC04LjkgMCAwIDQuNSAyLjMgMTEuOCA0IDAgMCAxLjIgMS41IDEuNCA0LjUuMyAyLjQt'
    b'MS40IDUtMy4zIDQuOEwyODIgMzY2Yy0zLjctLjctNS0yLjMtNS0yLjN6bTc3LjctMjcuNiAz'
    b'LjMtMi4zYzEuMy0xLjEgMi44LTIgNC40LTMuMiAwIDAtMi4yLTIuNy0zLjMtMy0xLjYtLjYt'
    b'My42LjMtNCAzLjhsLS40IDQuN3oiLz4KICAgIDxwYXRoIGQ9Im0zNTQuNyAzMzYgLjQtNC42'
    b'Yy40LTMuNSAyLjQtNC40IDQtMy45IDEgLjQgMy4yIDMgMy4yIDN2LjFhMzEuOSAzMS45IDAg'
    b'MCAxIDMtMS44Yy0uNy0uOS01LjItMy42LTYuMi0zLjZzLTE0LjUgNS40LTE4LjggOS4xYy0x'
    b'IDEtMS44IDctMS4zIDlhNDUuNyA0NS43IDAgMCAwIDE1LjctNy4ybTYuNSAxMy42czIuOSAz'
    b'IDMgOC4zYy4yIDYuMy00LjUgNi42LTcuNSA2LjUtMy42IDAtNi41LTIuMS02LjUtOC45IDAg'
    b'MCA2LTIuNSAxMS02eiIvPgogICAgPHBhdGggZD0iTTM1OC43IDM1MS4xczIuNCAyLjUgMi44'
    b'IDYuNWMuMyAzLjEtMS45IDQuOS00LjUgNC43LTMuNy0uMi01LjEtNS4zLTMuNC04LjFsNS4x'
    b'LTMiLz4KICAgIDxwYXRoIGQ9Ik0zNjEuOSAzNjMuN2MtMiAxLTQgMS01LjIuOC0zLjYgMC02'
    b'LjUtMi4xLTYuNS04LjkgMCAwLTQuNSAyLjMtMTEuNyA0IDAgMC0xLjMgMS41LTEuNSA0LjUt'
    b'LjIgMi40IDEuNSA1IDMuNCA0LjhsMTYuNS0yLjljMy42LS43IDUtMi4zIDUtMi4zeiIvPgog'
    b'IDwvZz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0i'
    b'LjciIGQ9Ik0yOTkuNiAzNjEuNHMzLjMgMi40LS43IDUuM20tOS02LjggMTAgNC4zbS04LjMt'
    b'Mi4xIDcuMiAzLjFtLTQuNi01IDUuNCAyLjVtMzkuNy0xLjNzLTMuMyAyLjQuNiA1LjNtOS02'
    b'LjgtMTAgNC4zbTguNC0yLjEtNy4yIDMuMW00LjYtNS01LjQgMi41Ii8+CiAgPHBhdGggc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNMjYxIDMzMS40Yy4yLjIuMi40LjMu'
    b'N2EyLjUgMi41IDAgMCAxIDAgLjggMi40IDIuNCAwIDAgMS0xLjIgMS42IDMgMyAwIDAgMS0y'
    b'LjIuNCAzLjcgMy43IDAgMCAxLTEtLjQgNC4zIDQuMyAwIDAgMS0xLS42bC0uMy40LS40LS4x'
    b'LjQtMi45LjUuMWMwIC40IDAgLjcuMiAxbC4zIDEgLjcuNmMuMi4yLjUuMy45LjRoLjdhMS4y'
    b'IDEuMiAwIDAgMCAuOS0uNiAxLjggMS44IDAgMCAwIC4yLS42IDEuNyAxLjcgMCAwIDAtLjEt'
    b'MSAxLjggMS44IDAgMCAwLS43LS43IDQ4LjMgNDguMyAwIDAgMC0uOC0uNWwtLjgtLjZjLS41'
    b'LS4zLS44LS42LTEtMS0uMi0uNC0uMi0uOC0uMS0xLjQgMC0uMy4yLS42LjQtLjhhMi41IDIu'
    b'NSAwIDAgMSAxLjUtMSAyLjkgMi45IDAgMCAxIDEgMGwxIC40LjguNi4zLS40LjUuMS0uNSAy'
    b'LjgtLjUtLjFhMTEuMiAxMS4yIDAgMCAwIDAtMSAzLjYgMy42IDAgMCAwLS40LS44IDIgMiAw'
    b'IDAgMC0uNS0uNyAyIDIgMCAwIDAtLjgtLjQgMS40IDEuNCAwIDAgMC0xIC4yYy0uNC4yLS42'
    b'LjUtLjYuOHYxbC43LjcuOC41YTE0LjEgMTQuMSAwIDAgMSAxLjMgMWMuMiAwIC40LjMuNS41'
    b'bTEyIDEuNi0uNS0uMWExLjQgMS40IDAgMCAwLS41LS4xYy0uMiAwLS40LjEtLjUuM2E1Ljcg'
    b'NS43IDAgMCAwLS42IDFsLTEuOCAzLjFhMi40IDIuNCAwIDAgMS0xLjkgMS4zaC0xLjFhNC4y'
    b'IDQuMiAwIDAgMS0xLS41IDQuMyA0LjMgMCAwIDEtMS0uOCAzIDMgMCAwIDEtLjctMSAyLjIg'
    b'Mi4yIDAgMCAxLS4xLTEgMiAyIDAgMCAxIC4yLS44bDIuNC00LjNhLjkuOSAwIDAgMCAuMS0u'
    b'NHYtLjNhMS41IDEuNSAwIDAgMC0uMy0uM2wtLjQtLjMuMi0uMyAzLjEgMS43LS4yLjMtLjMt'
    b'LjFhMiAyIDAgMCAwLS40LS4xaC0uNGEuOS45IDAgMCAwLS4yLjNsLTIuMiA0YTMuMyAzLjMg'
    b'MCAwIDAtLjMuNyAxLjggMS44IDAgMCAwIDAgLjhjMCAuMiAwIC41LjIuN2wuOS44IDEgLjNh'
    b'MS45IDEuOSAwIDAgMCAxLjUtLjVsLjUtLjYgMS42LTMgLjUtMXYtLjZjMC0uMi0uMi0uMy0u'
    b'NC0uNWEzLjYgMy42IDAgMCAwLS40LS4zbC4yLS40IDMgMS43YTE5LjIgMTkuMiAwIDAgMS0u'
    b'Mi4zbTQuMyA3LjVhMS45IDEuOSAwIDAgMSAwIDEuOCAyIDIgMCAwIDEtLjguOCAyLjIgMi4y'
    b'IDAgMCAxLTEgLjNsLTEtLjFhNCA0IDAgMCAxLS45LS40bC0zLjUtMiAuMi0uNGE1IDUgMCAw'
    b'IDAgLjguMy41LjUgMCAwIDAgLjMgMCAuNy43IDAgMCAwIC4zLS4zbDMtNS4zYTEgMSAwIDAg'
    b'MCAuMS0uMy42LjYgMCAwIDAtLjEtLjQgMS43IDEuNyAwIDAgMC0uMy0uM2wtLjMtLjIuMi0u'
    b'NCAzLjQgMiAuNy41LjYuN2ExLjYgMS42IDAgMCAxIDAgMS42IDEuOCAxLjggMCAwIDEtLjYu'
    b'NmwtLjcuM2EyLjUgMi41IDAgMCAxLS43IDAgMy4zIDMuMyAwIDAgMS0uOC0uMnYuMWE1IDUg'
    b'MCAwIDEgLjYuNmwuNS43em0tLjYtMS44Yy4yIDAgLjQtLjIuNS0uM2EyLjcgMi43IDAgMCAw'
    b'IC41LS42Yy4yLS40LjMtLjguMi0xLjItLjEtLjMtLjQtLjYtLjktLjlsLS40LS4yLS40LS4z'
    b'LTEuNiAyLjguNi40LjguM2guN3ptLS42IDIuN2MuMi0uNC4zLS44LjEtMS4zIDAtLjQtLjQt'
    b'LjgtMS0xLjFhMjkgMjkgMCAwIDAtLjUtLjRsLS40LS4xLTEuNSAyLjVhLjYuNiAwIDAgMCAw'
    b'IC43Yy4xLjIuNC40LjcuNS41LjMgMSAuNCAxLjQuMy41LS4yLjgtLjUgMS4yLTF6bTE4Ljkg'
    b'NC4zYTMuNSAzLjUgMCAwIDAtLjUgMCAxLjQgMS40IDAgMCAwLS42LS4xYy0uMSAwLS4zLjEt'
    b'LjQuNGE1LjkgNS45IDAgMCAwLS41IDFsLTEuNSAzLjNjLS4xLjQtLjQuNy0uNyAxYTIuNiAy'
    b'LjYgMCAwIDEtMSAuNCAzLjIgMy4yIDAgMCAxLTEuMSAwIDQuMyA0LjMgMCAwIDEtMi4yLTEg'
    b'My4xIDMuMSAwIDAgMS0uNy0uOCAyLjIgMi4yIDAgMCAxLS4zLTEgMiAyIDAgMCAxIC4yLS45'
    b'bDItNC41YS45LjkgMCAwIDAgMC0uNC43LjcgMCAwIDAtLjEtLjMgMS42IDEuNiAwIDAgMC0u'
    b'My0uM2wtLjQtLjIuMi0uNCAzLjMgMS40LS4yLjRhMy41IDMuNSAwIDAgMC0uNC0uMSAyLjMg'
    b'Mi4zIDAgMCAwLS40IDBoLS4zYTEgMSAwIDAgMC0uMi4zbC0xLjkgNC4zLS4yLjdhMS43IDEu'
    b'NyAwIDAgMCAuNCAxLjRjLjIuMy41LjUgMSAuN2wxIC4yYTEuOSAxLjkgMCAwIDAgMS41LS43'
    b'IDIuNSAyLjUgMCAwIDAgLjQtLjZsMS4zLTMuMS4zLTF2LS43bC0uNC0uNGEzLjcgMy43IDAg'
    b'MCAwLS41LS4zbC4yLS40IDMuMSAxLjQtLjEuM205LjIgMTAuOC0zLjYtMXYtLjRhOSA5IDAg'
    b'MCAwIC42IDBsLjQuMWEuOC44IDAgMCAwIC40LS4yLjcuNyAwIDAgMCAuMi0uM2wxLjctNS44'
    b'YTEuNCAxLjQgMCAwIDAtLjEgMGwtNC44IDZoLS4zbC0uNi03LjktMS41IDQuOC0uMiAxLjEu'
    b'MS42LjUuNGEzLjIgMy4yIDAgMCAwIC41LjNsLS4yLjQtMy4yLTF2LS40aC42YTEgMSAwIDAg'
    b'MCAuNSAwYy4yIDAgLjMtLjIuNS0uNGwuMy0xIDEuMi00LjJhMS43IDEuNyAwIDAgMCAuMS0u'
    b'NiAxIDEgMCAwIDAtLjEtLjQgMS4yIDEuMiAwIDAgMC0uNC0uNCAyIDIgMCAwIDAtLjUtLjJs'
    b'LjEtLjQgMi44LjguNiA2LjcgMy41LTQuNS4zLS41YTIuOCAyLjggMCAwIDAgLjItLjRsMi43'
    b'LjgtLjEuNGEzLjkgMy45IDAgMCAwLS41IDAgMi40IDIuNCAwIDAgMC0uNC0uMS40LjQgMCAw'
    b'IDAtLjMuMSAxIDEgMCAwIDAtLjEuNGwtMS43IDUuOGEuOC44IDAgMCAwIDAgLjNsLjEuM2Ez'
    b'LjQgMy40IDAgMCAwIC44LjRsLS4xLjRtOC43LTIuNmExLjkgMS45IDAgMCAxIC43IDEuN2wt'
    b'LjQgMWMtLjIuMy0uNS40LS44LjYtLjMuMi0uNi4yLTEgLjNoLTFsLTQtLjV2LS40aC41YTEu'
    b'NyAxLjcgMCAwIDAgLjQgMCAuNS41IDAgMCAwIC4zLS4yLjcuNyAwIDAgMCAuMS0uNGwuOC02'
    b'YTEgMSAwIDAgMCAwLS4zLjYuNiAwIDAgMC0uMy0uMyAxLjcgMS43IDAgMCAwLS40LS4yaC0u'
    b'M3YtLjVsMy45LjVjLjMgMCAuNiAwIC45LjJsLjcuNGExLjYgMS42IDAgMCAxIC42IDEuNWwt'
    b'LjIuOGExLjcgMS43IDAgMCAxLS42LjUgMi42IDIuNiAwIDAgMS0uNi4zIDMuNCAzLjQgMCAw'
    b'IDEtLjguMmwuOC4zLjcuNXptLTEuMy0xLjUuNC0uNS4yLS43YTEuNSAxLjUgMCAwIDAtLjMt'
    b'MS4xYy0uMi0uMy0uNi0uNS0xLjEtLjVhMjcuMyAyNy4zIDAgMCAwLTEtLjFsLS40IDMuMmgu'
    b'OGMuMy4xLjYgMCAuOCAwYTEuMyAxLjMgMCAwIDAgLjYtLjN6bS41IDIuOGMwLS41IDAtMS0u'
    b'My0xLjMtLjMtLjMtLjgtLjUtMS40LS42bC0uNy0uMWgtLjRsLS4zIDIuOWEuNi42IDAgMCAw'
    b'IC4yLjZsLjguM2MuNiAwIDEgMCAxLjUtLjQuMy0uMy41LS43LjYtMS40em0xMS40IDIuNmgt'
    b'Mi4yYTQ0IDQ0IDAgMCAwLTEuNC0ybC0xLjMtMS44aC0xdjIuN2wuMS40LjMuMmguNGwuNS4x'
    b'di40aC0zLjZ2LS40aC40bC40LS4xYS41LjUgMCAwIDAgLjItLjIuNy43IDAgMCAwIC4xLS40'
    b'di02LjRsLS4zLS4zYTIuMiAyLjIgMCAwIDAtLjQgMGwtLjQtLjF2LS40aDQuOWEyLjggMi44'
    b'IDAgMCAxIC45LjRsLjYuNmEyLjMgMi4zIDAgMCAxIDAgMS44IDIgMiAwIDAgMS0uNC43IDIu'
    b'NSAyLjUgMCAwIDEtLjcuNCA1LjMgNS4zIDAgMCAxLS44LjNsMSAxLjRjLjMuNC43LjggMSAx'
    b'LjRhMi41IDIuNSAwIDAgMCAxIC44IDMgMyAwIDAgMCAuOC4xdi40em0tMy4xLTYuMmMwLS41'
    b'LS4yLTEtLjQtMS4yLS4zLS4zLS44LS41LTEuMy0uNWgtMXYzLjZoLjhjLjUgMCAxLS4xIDEu'
    b'My0uNS40LS4zLjYtLjguNi0xLjR6bTEzIDUuNi0zLjYuM3YtLjRsLjctLjJjLjIgMCAuMy0u'
    b'Mi4zLS4ydi0uMmEuNS41IDAgMCAwIDAtLjFsLS45LTEuOC0zIC4yYTkuNiA5LjYgMCAwIDAt'
    b'LjIuN2wtLjEuNmEzLjQgMy40IDAgMCAwLS4xLjR2LjNjMCAuMi4xLjMuNC4zbC45LjF2LjRs'
    b'LTMuMi4zdi0uNGEyIDIgMCAwIDAgLjQtLjEgMS4zIDEuMyAwIDAgMCAuNy0uNmwuMi0uNSAx'
    b'LjEtMy42IDEuMS0zLjZoLjVsMy40IDcgLjIuM2ExLjIgMS4yIDAgMCAwIC43LjRoLjR2LjR6'
    b'bS0zLjctMy4xLTEuNi0zLjItMSAzLjQgMi42LS4yem0xNS43LTYuN2EyNy45IDI3LjkgMCAw'
    b'IDAtLjQuMiAzLjEgMy4xIDAgMCAwLS44LS45Yy0uNC0uMi0uNy0uNC0xLS4zYTYuMyA2LjMg'
    b'MCAwIDAtLjMgMGwtLjYuMi0xLjQuNC45IDMuMiAxLS4yLjYtLjMuMy0uNC4xLS40di0uNmwu'
    b'NC0uMi45IDMuMi0uNC4xYTIuOSAyLjkgMCAwIDAtLjMtLjVsLS40LS40YS45LjkgMCAwIDAt'
    b'LjUtLjIgMi4zIDIuMyAwIDAgMC0uNi4xbC0xIC4zLjggMi44czAgLjIuMi4zYS42LjYgMCAw'
    b'IDAgLjMuMmguNGwuNC0uMS4xLjQtMy41IDEtLjEtLjRhOS41IDkuNSAwIDAgMCAuNC0uMmwu'
    b'NC0uMmEuNS41IDAgMCAwIC4yLS4zLjguOCAwIDAgMCAwLS4zbC0xLjYtNS45YTEuMSAxLjEg'
    b'MCAwIDAtLjItLjNsLS4zLS4yYTIuNCAyLjQgMCAwIDAtLjQgMCAyLjQgMi40IDAgMCAwLS41'
    b'IDBsLS4xLS4zIDYuNC0xLjguNiAybTkuNC0uNyAxIDIuNC02IDIuOC0uMi0uMy40LS4zYTEu'
    b'NCAxLjQgMCAwIDAgLjMtLjIuNS41IDAgMCAwIC4xLS4zLjguOCAwIDAgMCAwLS40bC0yLjct'
    b'NS40YTEgMSAwIDAgMC0uMi0uMy41LjUgMCAwIDAtLjQgMGgtLjRhMiAyIDAgMCAwLS40IDBs'
    b'LS4yLS4zIDMuMy0xLjYuMi40YTIuOCAyLjggMCAwIDAtLjQuMiAyLjIgMi4yIDAgMCAwLS4z'
    b'LjMuNC40IDAgMCAwLS4yLjMuOC44IDAgMCAwIC4xLjRsMi41IDVjMCAuMy4yLjUuMy42bC4z'
    b'LjJoLjRsLjctLjMuNC0uMi40LS4zLjMtLjJhLjYuNiAwIDAgMCAuMi0uMyA2LjMgNi4zIDAg'
    b'MCAwIC4yLTJsLjMtLjJtNC41LTguM2E0LjIgNC4yIDAgMCAxIDEuNS44bDEuMiAxLjRhNSA1'
    b'IDAgMCAxIC42IDEuNyA0LjEgNC4xIDAgMCAxIDAgMS42IDQgNCAwIDAgMS0uNyAxLjUgNCA0'
    b'IDAgMCAxLTEuMiAxIDQgNCAwIDAgMS0zLjIuNCA0IDQgMCAwIDEtMS40LS43IDUgNSAwIDAg'
    b'MS0xLjItMS40IDUgNSAwIDAgMS0uNi0xLjcgNC4zIDQuMyAwIDAgMSAwLTEuNyA0IDQgMCAw'
    b'IDEgMi0yLjQgNCA0IDAgMCAxIDEuNS0uNiAzLjkgMy45IDAgMCAxIDEuNS4xem0yLjMgNS42'
    b'YTQgNCAwIDAgMC0uMi0xLjMgNyA3IDAgMCAwLS43LTEuNCA3LjIgNy4yIDAgMCAwLTEtMS4z'
    b'IDQgNCAwIDAgMC0xLS44IDIuNCAyLjQgMCAwIDAtMS0uMmMtLjUgMC0uOC4xLTEuMi4zLS40'
    b'LjMtLjcuNi0uOSAxYTIuNiAyLjYgMCAwIDAtLjMgMWMwIC41LjEuOS4zIDEuM2E3LjIgNy4y'
    b'IDAgMCAwIDEuNSAyLjZjLjMuNC43LjYgMSAuOGEyLjQgMi40IDAgMCAwIDEuMi4zYy4zIDAg'
    b'LjcgMCAxLjEtLjNhMi4zIDIuMyAwIDAgMCAxLjItMnptMTAuNS01LjctMS45IDEuMy0yLjMt'
    b'LjktMi0uNi0uOC41IDEuNiAyLjEuMi4zaC40YTEuOCAxLjggMCAwIDAgLjMtLjFsLjQtLjMu'
    b'My40LTMgMi0uMi0uM2E4LjYgOC42IDAgMCAwIC42LS41LjUuNSAwIDAgMCAwLS40LjcuNyAw'
    b'IDAgMCAwLS4zbC0zLjYtNWExIDEgMCAwIDAtLjItLjIuMy4zIDAgMCAwLS40IDAgMyAzIDAg'
    b'MCAwLS43LjNsLS4zLS40IDMuMi0yLjJhNC42IDQuNiAwIDAgMSAuOS0uNSAyLjcgMi43IDAg'
    b'MCAxIC45LS4ybC44LjFhMi4yIDIuMiAwIDAgMSAxLjEgMS40di44YTIuNSAyLjUgMCAwIDEt'
    b'LjIuNyA0LjkgNC45IDAgMCAxLS41LjhsMS42LjUgMS42LjVhMi41IDIuNSAwIDAgMCAxLjIu'
    b'MWguNGEyLjYgMi42IDAgMCAwIC40LS4zbC4yLjR6bS02LjItMy4zYy0uMy0uNC0uNi0uNi0x'
    b'LS43LS40LS4xLS45IDAtMS4zLjNsLS44LjYgMiAzIC43LS41Yy40LS4zLjctLjcuOC0xLjIg'
    b'MC0uNSAwLTEtLjQtMS41em0xMy4yLTIgLjcgMi40LTYuNiAyLjQtLjItLjRhNC4zIDQuMyAw'
    b'IDAgMCAuOC0uNC42LjYgMCAwIDAgLjItLjMuNy43IDAgMCAwIDAtLjRsLTIuMi01LjZhMSAx'
    b'IDAgMCAwLS4xLS4zbC0uNC0uMWgtLjRhMi4yIDIuMiAwIDAgMC0uNSAwbC0uMS0uMyA2LjEt'
    b'Mi4zLjcgMS45LS40LjFhMi43IDIuNyAwIDAgMC0uOC0uN2wtLjktLjNhNC4zIDQuMyAwIDAg'
    b'MC0uNC4ybC0uNi4yLTEuMi40IDEuMSAzLjEgMS0uM2MuMiAwIC40LS4yLjUtLjNhLjkuOSAw'
    b'IDAgMCAuMy0uNHYtMS4xbC40LS4xIDEuMSAzLS40LjJhMy4yIDMuMiAwIDAgMC0uMy0uNSAx'
    b'LjUgMS41IDAgMCAwLS40LS4zLjkuOSAwIDAgMC0uNS0uMmMtLjIgMC0uNCAwLS42LjJsLS45'
    b'LjMuOSAyLjQuMi41YS41LjUgMCAwIDAgLjMuM2guNWwuNy0uMy41LS4yYTMuOSAzLjkgMCAw'
    b'IDAgMS0uNGwuMi0uMy4yLTF2LTFsLjUtLjFtNy4xLTUuOGMuNC4zLjguNyAxIDEuMy4zLjUu'
    b'NSAxIC42IDEuN2E0LjkgNC45IDAgMCAxIDAgMS44IDQuMSA0LjEgMCAwIDEtLjggMS41IDMu'
    b'OSAzLjkgMCAwIDEtMi43IDEuNiAzLjkgMy45IDAgMCAxLTMtLjkgNC4xIDQuMSAwIDAgMS0x'
    b'LTEuMiA0LjkgNC45IDAgMCAxLS42LTEuNyA1IDUgMCAwIDEgMC0xLjlsLjgtMS41YTQgNCAw'
    b'IDAgMSAyLjctMS41IDQgNCAwIDAgMSAxLjYgMGwxLjQuOHptLS4xIDZjLjItLjQuMy0uOC4z'
    b'LTEuM3YtMS41YTcgNyAwIDAgMC0uNC0xLjUgMy45IDMuOSAwIDAgMC0uNy0xLjIgMi40IDIu'
    b'NCAwIDAgMC0uOS0uNyAyLjMgMi4zIDAgMCAwLTEuMS0uMWMtLjUgMC0xIC4yLTEuMi41LS4z'
    b'LjItLjYuNi0uNyAxYTQgNCAwIDAgMC0uMyAxLjIgNyA3IDAgMCAwIC40IDNsLjcgMS4xYy4y'
    b'LjQuNS42LjkuNy4zLjIuNy4yIDEuMi4yYTIuMyAyLjMgMCAwIDAgMS0uNSAyLjQgMi40IDAg'
    b'MCAwIC44LTF6Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMzY2'
    b'IDIwNS4xdjUzYzAgMTAuNi0xLjQgNTIuNi00Ni41IDY5LTQ1LjMtMTYuNC00Ni43LTU4LjQt'
    b'NDYuNy02OXYtNTNIMzY2Ii8+Cjwvc3ZnPgo=', 'BZ')

BZ = b64_BZ
index.append("BZ")
index.append("BLZ")
index.append("Belize")
catalog["BZ"] = BZ
catalog["BLZ"] = BZ
catalog["Belize"] = BZ
country["Belize"] = ('BZ', 'BLZ', 0)
lookup["BZ"] = ('BZ', 'BLZ', 'Belize', 0)
lookup["Belmopan Belize"] = ('BZ', 'BLZ', 'Belize', 0)
lookup["BLZ"] = ('BZ', 'BLZ', 'Belize', 0)
lookup["Belize"] = ('BZ', 'BLZ', 'Belize', 0)
details["BZ"] = {"continent":"Americas","capital":"Belmopan","currency":"Belize Dollar","web":".bz","lang":"en-BZ | es","tz":"-06:00","altname":""}
#----------------------------------------------------------------------
b64_CA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTE1'
    b'MC4xIDBoMzM5Ljd2NDgwSDE1MHoiLz4KICA8cGF0aCBmaWxsPSIjZDUyYjFlIiBkPSJNLTE5'
    b'LjcgMGgxNjkuOHY0ODBILTE5Ljd6bTUwOS41IDBoMTY5Ljh2NDgwSDQ4OS45ek0yMDEgMjMy'
    b'bC0xMy4zIDQuNCA2MS40IDU0YzQuNyAxMy43LTEuNiAxNy44LTUuNiAyNWw2Ni42LTguNC0x'
    b'LjYgNjcgMTMuOS0uMy0zLjEtNjYuNiA2Ni43IDhjLTQuMS04LjctNy44LTEzLjMtNC0yNy4y'
    b'bDYxLjMtNTEtMTAuNy00Yy04LjgtNi44IDMuOC0zMi42IDUuNi00OC45IDAgMC0zNS43IDEy'
    b'LjMtMzggNS44bC05LjItMTcuNS0zMi42IDM1LjhjLTMuNS45LTUtLjUtNS45LTMuNWwxNS03'
    b'NC44LTIzLjggMTMuNGMtMiAuOS00IC4xLTUuMi0yLjJsLTIzLTQ2LTIzLjYgNDcuOGMtMS44'
    b'IDEuNy0zLjYgMS45LTUgLjdMMjY0IDEzMC44bDEzLjcgNzQuMWMtMS4xIDMtMy43IDMuOC02'
    b'LjcgMi4ybC0zMS4yLTM1LjNjLTQgNi41LTYuOCAxNy4xLTEyLjIgMTkuNS01LjQgMi4zLTIz'
    b'LjUtNC41LTM1LjYtNyA0LjIgMTQuOCAxNyAzOS42IDkgNDcuN3oiLz4KPC9zdmc+Cg==', 'CA')

CA = b64_CA
index.append("CA")
index.append("CAN")
index.append("Canada")
catalog["CA"] = CA
catalog["CAN"] = CA
catalog["Canada"] = CA
country["Canada"] = ('CA', 'CAN', 0)
lookup["CA"] = ('CA', 'CAN', 'Canada', 0)
lookup["Ottawa Canada"] = ('CA', 'CAN', 'Canada', 0)
lookup["CAN"] = ('CA', 'CAN', 'Canada', 0)
lookup["Canada"] = ('CA', 'CAN', 'Canada', 0)
details["CA"] = {"continent":"Americas","capital":"Ottawa","currency":"Canadian Dollar","web":".ca","lang":"en-CA | fr-CA | iu","tz":"-08:00 | -03:30","altname":""}
#----------------------------------------------------------------------
b64_CA_AB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc0MDIyIgogICB3aWR0aD0i'
    b'MjAwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDIwMCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQWxiZXJ0YS5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzNDAy'
    b'NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzQwMjQiCiAg'
    b'ICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAg'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAg'
    b'IGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJi'
    b'b2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAg'
    b'aW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNDAyOCI+CiAgICA8aW1hZ2UKICAg'
    b'ICAgIHdpZHRoPSIyMDAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZlQXNw'
    b'ZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXpl'
    b'UXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJP'
    b'UncwS0dnb0FBQUFOU1VoRVVnQUFBTWdBQUFCa0NBSUFBQUJNNU9oY0FBQUFCR2RCVFVFQUFM'
    b'R1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFB'
    b'Nm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVQKQWtsRVFWUjQydTJj'
    b'ZVhpVTFibkEzM08rYmRaTU1rdjJqUVFTU0VoWVlzTlNsRVVVNkJVRkxnV2gwR29yV2krNFhi'
    b'Mml0dFgycWRoYgpyVzNCcmU1YUtCUkNSVVFRWkRFc0lTRUtrV3lRYmJLUlpaTFo5NWx2T2Zl'
    b'UFVLcm85VnJnUGs4ek9iLy81bnZPOTg3a3pXL2U5LzNPCmZETklYN29KS0pSckRhWXBvRkN4'
    b'S0ZRc0NoV0xRcUZpVWFoWUZDb1doVUxGb2xDeEtGUXNDb1dLUmFGaVVhaFlGQW9WaTBMRm9s'
    b'Q3gKS0JRcUZ1VmZGemEyL3p6U3ZZVlJ2RmYzemlPWWtNc09LZ2dwZ0s0bXJJempVTVlxS3Rh'
    b'd0pkTC9udy84cEtpbzZNclZMRDlPdG0yLwo3Q0Jhdmd6TnZ1R0tZOWJXMWo2MzhTMFUwNG1Q'
    b'ZGJFQXBrK2ZQbmZ1M0NzWHl4TlF5dDYvdkl4Tm1vd1dMNzdpbURxZERqYStSV2NzCkNvV0tS'
    b'YUZpVWVpTU5WemhpVXcydmF6czNIM2xJZG83djJidyttc1pPVlY5NVhOYmJ3OEdRc1VheGpD'
    b'RWtLcHF3dkxYTml5cHE0ZTYKK2lzL1hZb2l3TEZ0Rm0yRkZDb1doWXBGb2NON0xDTWpoRXF2'
    b'UXltcFZ4NmlzNXZVTjF4MkRCVVdRSGJtRllkRWZUM2taQTBWYXhnVApSUXg2Y0IyK21wMzNk'
    b'N2FRSjU2ODNJeVZ5OUdkcTY5Y3JJTUhsWk4zeFhhem9LMlFRc1dpVUxFb2RIaVBhUlQ1NU1t'
    b'VFBwL3Z5bWVzCm1qTkVpbHcrSk5XY1FmRzZLNDdaMXRZVzgyS2gyUDZwU0tWcEE2dEp4Snor'
    b'S2tvNllZbHkyVUVKNGF1NTBROGhIUEYyNFRHUDBJbzEKZkZ1OUlDZk1WSFI1VjNWcGVhMWZG'
    b'UEUzZzdlTHpsZ2pHeUpMM2hhYUJpcld0L1VsYWp1dVJOM2Z2SVp4ZkZ5aTMvZjRTa3RtWkpz'
    b'Uwo2cVc2MEZiNGpiNDRxNHFTK3RadmZPRGd3VU1WMVVkYUJ6UmdtWU13LytVMUp3c3QvVS8v'
    b'NldkRHR6VlBtalRwdlQySGpsWWZIaUJGClNFajhWczhTYU9NbFcxUTdFYkVhS2xhc1h5TjZt'
    b'M0kxTlEvLzRwNGYvdkNIQUhEYmJiY0JRRVZGeFVNUFAxcnZtY1RHNVFPQTdLNGQKclR2LytL'
    b'L1gzbjc3N1FCQUNIbjg4Y2V6c3JKV0xiOTF4Vko1YTlsSEgxZWU4R2xtWFBLSDkxYWthZnVD'
    b'aW5GQUtTQkNDZ0NBcnltRApQNzFrOGR3SkUyWnMyYnJURmNBWEJpTjJNWU5vY3FsWXNkZjUz'
    b'SXpqOElKcFNWdTNIbU1ZNXRMeHlzcktmZnYyTFYxeVcyck5oVU1uCjk2WWJmUGV1WGY3QS9h'
    b'OWZITnVqMFlNSEQyN1lzR0gzN3QxV3F6VW5KMmRzYmxLeVNmV1g5N2E3RFVzNVQwVytaWERG'
    b'Znl4VkZMbXIKcThzYml1NHIvOGpBT1pjdFcvRFVVeWNSUWdDZ0tJcmRiaDg3ZHV6aDhxcWRl'
    b'dy8yUnZPUkpuTWtKSndSMGhiRWROYzdpYlNqa0s5KwpjbmJvZDAvZEhRNkg1c3laTS9RdkI0'
    b'Qm5uMzJXNDdpQ2dnS1R5WVFrNzlvZkw5ejQrOTlNbXpxMXBxYW1zN016TlRXMXVycTZ2YjE5'
    b'Cno1NDllWGw1VnF2VllEQ2twYVhkYzg4OVUwckdudmp3K2JsVE14LzlyNGQ3ZW5xS2lvclMw'
    b'OVA5SHZ1ZEt4YTh1T241V2JObUVVS0cKbnFXd3NQREFnUU9wcWFtS0hFazJjb2txdTd1dkxo'
    b'QUdDSFVpMDNRcTFyQVZ5MUdSbklDZWZmSk9TeHc0SElNYWphYXlzbkxNbURFTQp3MnpldkRr'
    b'Y0RtZG1abFpXVnByTjVqVnIxdXpmdi8vdzRjTkhqaHpwN2UxVnE5VWZmdmpoa2lWTEtpb3FT'
    b'a3BLQ0NIcDZlazh6My8yCjJXZmp4bzNMejg5ZnRYSjViVzJ0VHFkTFRrNnVxcXBLU2txNisr'
    b'NjdDd29LdG0zYlZsWldkdXJVcVdQSGpoVVdGbW8wbW1uVHBoMDcKZGd4akxBaUNWc1BmZUgy'
    b'eHg5N1IyOU9OVE4rTjRjekgrZ1pweSsvdXZmZW5GZ056ODgwMzUrVGsvT0VQZnlndExXMXBh'
    b'Vm0zYnQzRwpqUnVEd1NESGNmbjUrVDZmaitmNXJLeXNvMGVQWG5mZGRaZjZZRTFOalN6TFU2'
    b'ZE94ZmdmbDg4blRwelFhRFJxdFRvek0vUDQ4ZU5UCnBreFp2SGp4cFFXeUxKZVZsWFYzZDVl'
    b'VWxKdzVjd1lBTEJhTHcrRklUMDgzbTgxRGEzWitlUExQNzd4T04waUhOeHdEQlFVRkRRME4K'
    b'bjN6eUNjZHhnaUJrWjJjLy9mVFRxMWV2dGxxdGRYVjFlcjFlcjlmTHNseGJXMXRTVW5McFJK'
    b'N25wMHlaOHRXQU0yYk11T1RRNk5HagpHeHNiMjlyYWxpMWJ0bjc5K3NMQ1FwN25DU0VHZ3dF'
    b'QUprK2VQTFF5SXlQalMwbG5VTXluUGVZcjFuTTVrNUpOY1liOFVXT21GcGRtClp2NWpjRzV0'
    b'YlZXcFZPbnA2VjljSDQxRzJ6dmFHMXJPZGZaMStTT0JjRFRDYXZpb0pFWjhJYlZHdy9NY0ky'
    b'T2U1VEpTMGtkbjV1WmsKWkp0TXBrdlI3SFo3VDA5UGJtN3V4SWtUdi9sVmZYQ2c4bzNYWDR2'
    b'dGloWDdZcUhyRVVwVktUNlJkNE01b2svVUdLY1ZsODZkTVlmagp1S0UxSG8vbmFOWHhPbXZE'
    b'Z05maEVMMWVUUWdsOEVqM1RiV2NoR1FsSUhGKzBNdXFPRjRYeDJtMWpEckZsRHgrekxqYzdG'
    b'eWowZmpWClUyd0R0b3FhVTUydUhwdDN3Tjd2R3FqMVVMRmlRYXd2YWVFU1RVNVZoaXFKQjk0'
    b'UmRkbEVwODhzWStQVmZrV01SR1RpRVRVQlRpc0oKY1lMT29OTEhxL1JKQ1JaN3hOM2g3KzJL'
    b'MmtRekFvd0FRQmlBMENkaE9tUEYzSnNwZ1hNbXlFN1NLL2NGSlhzUXNaaE4wbDJEc0FLRApF'
    b'cGt3UUZnUmJiMjlTbDhFRUdJaktteFJRVHg4OGRNelNZcjlKSTlFc2Y0dUFqQ3BHaVpWUXlR'
    b'aXRmdWtWaC9Tc0d5MkRxbVpLeTJQClJPb0pLczRvSUdEVE5PeUVoUDl0b1NRclZLd1JJQmlM'
    b'dURGeEFFQUNrdGppSlNFWmFWazJTNHYxM0xlUlNiWkg1TDRReUFRNHhLWnIKMlF3dFRTa1Y2'
    b'OHVHYVZtK09HRm9OcGU2QXBMZkJ3d0FJR3pnRUllQng0QUFaREkwdVVOVUFRYUJUTEJKNEFv'
    b'TWlLTTNJRkd4L2svRAoxQXlYSDNmeGdVeVVvRVRDTWduTFE0TVVOdkpNbWdieDFLU1JMWmJl'
    b'bHNJSGhXc1dMbklOWWtTOVVTLzBVckdHZC9XNXFmaUdXMjc2CnpqdDd0MWIxZjg1aWxrY3NB'
    b'c1JpZHM3b2FjdS90L1NMZHpvTVliZmJOMno5dlNQaXdReGlFWnNycEZVSEcxbkNBQUVKeTZB'
    b'QUIwd0MKRzdkMi9wM0ZCVi82YWROM3lqYVhOMVdHbEVpVWxSVVZFQUFzQW9jWUhuSEpqTkVE'
    b'd1hoZS80dlZqeGdNaHJlMzd0L1ZzcDJLTmV5SgppdEhVaEtRbENmUDg0U0RHbUdVWWdlRjFn'
    b'cmFqcTdPeDlkem96RndBeU1rZXhYRWN4dGp1ZHBSa0ZobDFDU3pMQWtCV1NzWk0zL1VJClFN'
    b'QThBQ2lLNGczNEpDSW5tUk1Cd09sMGVqeWUxTlJVUVJBVzMzenJ2Qmx6QWNEcjlYbzhucUhU'
    b'STVHSUx4S3dKSmlENFNBTGpGWTcKVWtiN0VTRldTbkxLaW9YTExqMnNiNmgvWXZNenNoWndJ'
    b'NGZVakZJakFvdUlXOFFpYUZuMXF1dVhybHEwNG12ajlQVDBFRUxTMmZRVwphK3V4enlwT3Ra'
    b'MXB4cjFJeTVqNmhmbmpaeTJZT1M4bEpRVUFVbEpTQ0NHdmxiM2RZbXMzNjQzQlNOQVhEUXlF'
    b'blg0aHdwN0FmSlNaCm5Yb0xGU3QyRUVXeHNycHFYTjdZOFlYanQvNzhOVW1TUXFHUVdxMity'
    b'QnVxMWVxaGh2akduczFacGpTTldwT1prajVwL0VTYnpmYmsKVzgvNDVSQkJvT2d4UjFoRVFB'
    b'YzhGMklqdlB6QnVjTU4xdk8vdXYvbjJ6N2M0Zko2N2xqMEE0SGxqV29EaXhpOVdxY1FNaWt1'
    b'V1ZKawpnb2dhQzJnRWZOVmdwSWkxci96QTI1L3VFRE00cFU3VWVsa0QxaTR2dlhWUzhjVDQr'
    b'UGhMYXdZSEJ6dTZPdnNkdGxQV21uUGhEam1OCnE0bzBRd1NnUGx4d2ZOVEtXVXZlL01WTFg0'
    b'M3NjcmxxRytwNGdhKzNubnZvajA5WTR3ZUJ4NGYrVkNuSVhNQWdDVTU4VS9wMGk5NlUKR3Ar'
    b'a0FHRXduam50aHIvc1BFTEZHdlo0UE43enplMDl2UU1UNHdyQURkNklMOENFb2twMFc5VUhE'
    b'VzNOYzc5NzA2VjY5cWVkcnhJdApGamhCeTZtS05IbmcrbnNJTFFEQTZZWUdsdm1hQ1duN3Zy'
    b'OWF3eGVBSUFCQ01GZ0dOUmd3QUdBWkdSd0lBTTYwMW1NR2N5eUxDQkFBClNjUmVyeS9tMHg3'
    b'N04vcmxaS1lZMU9LLzFLdnloYm5Xemo3NklmVHdadVVOM1BxRlN2bFpuMEhMVEJxdEFRQlpJ'
    b'Uzk5TUhEL29xU2gKQlR1T091ZE9qalBxV1FEb2M0cmxaNzByWmwrOHkrcjFmWU0vV1dEQkNB'
    b'RGdSTDFmNE5CMzhyVUFvQkI0NFgzYkE0c3ZSdmpiY2RmTQpZcjNad0FMQWdGdjgrTFIzMVkw'
    b'WEkyeDYzN2IyMWtRR0l3Q290UVlEWVdWYWdlNzVmZHd2MzZXdGNMalhaQ0FWRGY3S3ZvZ2tL'
    b'cUdvCndqS29ZeUFhbDY4OWRUNGdjRWlTU2I4S3YxdnVLczFSQThDbkhTRVN6MVkzQlFRV1JT'
    b'UWlqTmI4N1lRcks1RVhKWEtzTzZUSVJKUUoKeTZBTGptajhPRjNWT2IrYXh4R0pYR0RSTzBl'
    b'ZDAzSTFBSEM2STZnWXVVK2JBanlIUklrWXhtcDNISFBucHZDaVJJNTJoaFFBaFFBUQpJZWJU'
    b'SHV1WEo1aS80SVMxcjNUbGpkZGw1bW4vNjYwTEg1LzJiai9qdldORjZxcm4yeHM2UW91ZmJy'
    b'dGx2dVZDVkhuem9PUFYvZllCCkF2TnZNdi83aHJiNmp0QWRtN3ArdER6bHoxV3VRelhlQjEv'
    b'dkdwV3Z6UzNRUGZCYTk2RWE3N3VWbmp0V3BOeTVxYk8rTTdUMEdldjgKbTB4MkJLL3V0Nzk1'
    b'ME5FZEpiZk10eXpaME5iUUVWcjV1NDRmM1o1YVZ1UDUrTFQzMGJjdnBPZHF4aGJwMTc3UzNU'
    b'NEFnR1BjclZpZgpzYnIvTW5VMG1UL2JXVlB2WjFnMFBrL0x1RVhqR00zT1BRUHI3c3B3MUho'
    b'UnRucmJlN2JKeFRvdVFnQkJtRVZuNjN6ZnZ5Mkp1UkEyClQ0NTc2YzBMdHk5SzZtdndrd1N1'
    b'OXJ4ZklXUlNnUjZjWWxLQmJ2djd0dnZXcEErZThTcnBxcDBmREJRWDZnU0pBQUZSd0tjLzk2'
    b'NWMKbWd5ZEllUEV1SmZlN0Y2Nk1NbmU1RmZpK1hOdHdYQkVMaW5TN3k4M1ZiVmduTEVpaGpN'
    b'ZjQxLy9BaVZxNnpwcjFFZS9VeEtYYU9MUApuUTlvWk9KRDhOQlBNM2Z0SFVqaThhZlcwTzJM'
    b'a3djZFltOUh5T3VUalVuOC9Cdk5KMDY1MHpWTVZXdndpUWV6ajU5eVMyNnAxUmFaClVLeFBT'
    b'MVkxblBQckFCeFI1WkcxV2JzL2NsaFlWRzBOTHIwbDBlNFVlenZDZnA5c1NPUnZuV2M1Y2Nx'
    b'ZHBtYXFXZ09QUFREcStDbVAKNUJLdC9kSENRbDEycHZwc25mOUl0WS9FbHlKVkNtMkZ3eFpE'
    b'c1NqSlBYMHN4eUlDSkJTU2VSVzJkb1FFQVRjMkJRQ2dzVG1nRXBEVApKYXBVV0JDd1B5QUxQ'
    b'RzV1Q3dKQVUydUE1M0JyZTVEbmtjOHZjUnhDbVBqOEVzK2o5cTR3eitQNmN6NEFhR29OQ2ly'
    b'czg4dUNnRlVxCjdQWEtnb0FibXdNQTBOZ1U0SG5VMlIwU0JCd015U3dMQUtTdUtTekpDc1NO'
    b'cDYxd21PT3RJejFsQzJacTA5SndrcEZuUE9MWTZRbnYKYnU5N2RGMVc4eEdIdmxDM1kvZEF5'
    b'WVE0YjM4WUFGUW12djY4ZjlFQ1M3Z3BrSCtqNmJjdmRONjlPdTNzSnc0bGdldTJpUXdEYVJZ'
    b'TwpPY1h4TTQxdmJPbjkyVVBaalFmdDZuenRybjMyOFdNMVlZY0lBTHBFMWVjTm51OHZUUEkz'
    b'K3NmTU5qMzdZdWVQbHFlY3IzQkpCczdtCkZIdHQwWS9MQTBycVN0QVgwdUY5bUJOWEJPYlpI'
    b'eDBOTkxmeVI4b2RmcSswZS8vZ095OFVQUHhrQ3dBODg4ZU9SKy9MY3JuRjFwWkEKVTNNZ0hG'
    b'YnV2eXZqdVJjN0FlQ1JwMXEydkZLNFpXZGZNQ2dmT09Jb0tkWk9MTlR0UCt3SUJ1VnQ3L1Z2'
    b'ZWFYd29aODNBOEN6TDNRKwplSGQ2S0t3ME5RZGFXd0llci9qd3ZWbS8yZGdCQUE4LzJmTHVp'
    b'd1c3OWc3NGZkS2hjb2ZUclJ3b0Q4cW1tMlBlcXBGUnNmNWV0NVMrClBScTFjT05rZnRRWTBX'
    b'VGt3aEVsU3lZdE1nbUdsSEJZTWFzUUllQ01LcGhCY1RvMmowVmRMR2pVck1NcEdpS0tFeU8z'
    b'WDVKbFlvN24KRW1UaUZwQXBnUXRGU0tha05Jc2tFSlFqVWNVc1lJVEFFU0VjaC9RNlpneURP'
    b'akJTcTdEZEtUYlVvdFBuM2Q0Z0E4bExZcjRKam96aAovUkpDRWpKT0VTVzU2WHh6WXh1cllz'
    b'amNXWEZoV3pRdVE0MHhzcGc0MTJCVWtraEtoa3FyWVpNVGVTNGdaeGZwbzFHU202MGU2QWdw'
    b'CkF0WWJHRU1jQ3dyQklhVmdra0VoWk94b1RiQS9vazFWc1F4T2lHZTlEbEdTU0ZxbVdxZGxV'
    b'bE5VakUvS0dxLy92Q0c0NzZEMzgrWkkKV0hjOVN2OEJ4UFRBUHNKYTRSZjJ0SkI1RnM1Yjcx'
    b'ZE4yMzBrOUpOSFhPWE51ZzIvYjEvOGI1YWV2c2pBUUxTM04rcHlTd3ZubVgrNwpxUk1BZnJi'
    b'QmV0ZXExQzFsZllwTURwYzd4NHpTNUdhckQzM2lWR1N5ZmJkdHplcTA5YjlxQllELzN0aXhj'
    b'SjdKN1paNmU2TTJtMmdiCmpONjJ3UEwwOCsySEdsUjMzR2Y5OHc1WHJ6Z0Y1VDJHRStjQzVr'
    b'ZE9za2RNSy96S05nUnhWaEw3MFhpRHBpQmJtbG9xY0JGbGFCK3IKcHRhL2ZGRWljeUZzbWhU'
    b'Mzhwc1hsaTlLNm0vMGt3U3V0c2t2SzJUeXBYMnNYYloxYTlMdE5WNDVUVlgyd1dCeG9WWXRY'
    b'OXpIT256Ywo0dy9ndGs0Wm02ZUNlVFpnMVFoTThFZ1Y2OHQ2R2VOVjB3cjRCRTB3TFU5VE9G'
    b'Wlhmc0pWYXVMcVE4cVBWNmJzZUgrQTJNS2RJV1Y4Cm9RNFFxcS8zWmFteGJCWldMRW5hdktO'
    b'L3JJQ3E3ZUtjR3hMcUd2MDl6Y0VPRzdiMlIvb0hKVEJPSDdGS2pieFcrUFhOY1NiT2U4ekYK'
    b'VHRsYjRYbnZKTi9aS2F0VkYzZWhHczc3MVNyYzNCYmdlZXoyeUN5SEVBS1BWK0k0Yk8wTXFs'
    b'WDQ4M3JmMEU2WVJzVzBXS043cXNpSgpzOEUrYVFxTWVRSVNGNHhrcTBaOHhmcHE5Um9zMStr'
    b'MDMvOGVPelVSNTgwMlB2YnJ0dlgzWmRXVk8rUUVycTA3akRESlNWTXpMbkhjCjljYm5YKzU2'
    b'N3Blanp4MjB0d04rK1YyZjF4ZEJwdW5JUEJNWU5jMGxGZXNyeUVIaXJDVDJFenE5WWNMbzRQ'
    b'YTM4dTk2OE55YTc4YnYKUGV2TExkSVJndHJyZmZPTDlHK2NkTDN4eDRKNXk4NE91Sk1kZGh2'
    b'RVg0Y3NzNEhWMGZ4UnNiNk5Yc2VUTE9yeEdYalhFOGwxN2NGZApyU0dGa0VXNW1vbTVtbmxQ'
    b'ZFR2RFRITmJFT0t2UTVaWndPcHB6a2JxUHRZL04zdHhTSnVEaktXQmtHSnRhM24xTUZlVWE2'
    b'eXU2M083CnhHUnoycExmQnM2MXVSeGtBc3BZaVF4Rk1YOERESzFZL3o5SWZtSS9TbHluVXBN'
    b'VENDSDlOZzhrbENMelROcjRxRmpYUkM4ZkdTd0gKaEpCNUptMTgzd2I2b3lEZk1rOTZsTEtR'
    b'cHVHZm1DWm9DaWhVTEFvVmkwTEZvbENvV0JRcUZvV0tSYUZRc1NoVUxBb1ZpMEtoWWxHbwpX'
    b'QlFxRm9WQ3hhSlFzU2hVTEFxRmlrWDUxK1YvQUIzRGtYdFhSdkdXQUFBQUpYUkZXSFJrWVhS'
    b'bE9tTnlaV0YwWlFBeU1ESXlMVEEwCkxUSXlWREUyT2pVeU9qUTJLekF3T2pBd04rcHVJQUFB'
    b'QUNWMFJWaDBaR0YwWlRwdGIyUnBabmtBTWpBeU1pMHdOQzB5TWxReE5qbzEKTWpvME5pc3dN'
    b'RG93TUVhMzFwd0FBQUFBU1VWT1JLNUNZSUk9CiIKICAgICAgIGlkPSJpbWFnZTQwMzAiIC8+'
    b'CiAgPC9nPgo8L3N2Zz4K', 'CA_AB')

CA_AB = b64_CA_AB
index.append("CA_AB")
index.append("Canada Alberta")
catalog["CA_AB"] = CA_AB
catalog["Canada Alberta"] = CA_AB
country["Canada Alberta"] = ('CA_AB', '', 1)
lookup["CA_AB"] = ('CA_AB', '', 'Canada Alberta', 1)
lookup["Canada Alberta"] = ('CA_AB', '', 'Canada Alberta', 1)
details["CA_AB"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["CA_AB"] = ('CA_AB', 'Canada Alberta', 1)
regional["Canada Alberta"] = ('CA_AB', 'Canada Alberta', 1)
#----------------------------------------------------------------------
b64_CA_BC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc1MzI3IgogICB3aWR0aD0i'
    b'MTY3IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE2NyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQnJpdGlzaF9Db2x1bWJpYS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzNTMzMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzUzMjkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNTMzMyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNjciCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBS2NBQUFCa0NBSUFBQUJzQ0xlaEFBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQTUKWkVs'
    b'RVFWUjQydTFkWjF5VFo5Yy8yVHRBMkh2SUVrU1dBdUlXM0h2YmFtc2RPS3AxNzFuM2F0VzZh'
    b'dXZXcWhXcmRWUkZSVkZrN3kyQwpzbmNnQ2RuN2ZqOGtaQmtjU0orbnIzM096dytZZTEvbnVz'
    b'NzRuM0doaW5wSFVvSURxZUdodEFGOWNkWlcwRW5FRnlsU2lsdGpzMW14CjJhek1VaTc4Vitu'
    b'TnVkNXV0aVFBZUJrZUlXOWh2WDBDaW9EdmxwY0tBTXhXcWRYVStQL3UyN3Jaa2lJREdhcC9a'
    b'bFFjQUNoRlltRjIKTGo4cGxaK1VJaW9xQmdUcHdHMnhacWFVMEo3VThGQnFlQ2hXem14dWpY'
    b'bmNHdk1ZQVBDT0RxcGZxZUZoR0RydFUxNmRTc0tvM2hzQQpHdGpTRndYczJHelcvYlRtbW1Z'
    b'Si9JL2VJaXRUZkg4L3M4aEF4dEFlNXM1V1JBQkFGRXB4OFN0bVVnby9LVldRa1kxSXBSMjRM'
    b'WnBJCklBY0ZxQmhLNnVvRmFMUjZCdWllSksydVlWMnJZVjI3Z2NLZ2lkNWUxUEF3YW5nb3BV'
    b'Y2dDby8vbEUreU1jTlA3bXM5dWE4MUFKVFYKaTFRQzRGRldTNnRBL20vbU5KbUFDZmN4VWEy'
    b'TklIYzZDcVZoUWFwcVdTdTR2QTdjVm85M3dZRW9naEhlWVkxZWlTaVVvc0tYb3NLWAp6RlBu'
    b'MENRaU9kRC83Zm5TWWZFMXo5WiszZ2g3aFJMSmVjTlR6WUQ0Zkk1VXJ2dzNjQnFEUmdWMG9h'
    b'azQzYmViS1FHSEJnQjVjd3YzCjRXTitVaXJ2UmFLc3JxRmpkOWJLNlY0aEdCT1Q5MGo3OTk1'
    b'T0tSTHprMUw1U2FrQVI3Qm1wcVNBN3BUZ0FHcDRHTW0zNnlkK2Y3QUgKUGRpRHZuYUtpMENz'
    b'U0g2cE5nS3lYbk03cExiKzBhUlIxWU1EelUycFdBQlFpa1RDOUhUMko2cHFjd2FsWnpBMVBK'
    b'VFdOeHhuWi9zUgpGMzdVWStSc0RpOHVuaGNYRDNBRWEybWhOZ1A3OThIWldIL0tvRkNJV2lP'
    b'Z2lTTjlucytPeldZOXpHaXBiQkwvLytXMHRSbStYemV6CnlFREc4SjdtanBadnFlcjBMRVFt'
    b'NjRpcUpwSElnZDNWb3RmSEcxU0s0V08xQUQ4alM1Q2N4azlPRStia0lmSU9LVm9VaXVqZWhk'
    b'b3IKaE5JcmhCcmFBMDJoZE5iQWFZeUEyR3dXbXkvcjhIMytZelk4aFlqcDFWVmZWU09JdU9R'
    b'MVB6bFZ4V21sVU5pUkFjWml5ZjUrS2dGTwo4dmREWVRDZk9MQW9EbDltUXNFYXVnY3ZYNEd5'
    b'STRyMlEweUpEcEJDaWFTWGNHT3pXYkZack9TWHJSOXJCUHl0WE1kajBXRnRuTzdwClNjZGlV'
    b'Q3BWTGNqSTRpZWw4cDRueUJvYVAxVlY5KzZGb1ZFN2F5MjFDdVFvelBCWWpYM1J4OWVVaUVl'
    b'ckpMa3dPMWVZbGN0UFNoRVYKdnV6WTNUVnVBemtvZ0J6US9kTm5xSXFFRWtWU2tkb0l5SDdO'
    b'VTM2QVJ2dzd1SzVSMVVPQ3pOWExSaWdVNXVSL3FsZHRZVTdwRWRRcApldlB0UVVzbzVDUVdj'
    b'cDduczFFdzlMSDJrUmlVdjV0NkJ2VDNNOE5oVVFBZ1p6WUxNclA1U2FtOCtFUlpmUWN0VERT'
    b'RlF2YnZwdFpHCm4yWUc2bEl6VnhhWHk0ck5aajNPWXBVM2lQNXVydHVZNGZ0Mk00c01aSXdJ'
    b'c1hDd0lBQUFvbENJaTB2NEtsV2RsdGt4RllrbWs4a0IKZnArb3F0OG1rVlNaV2NwTkxPVEVa'
    b'ck5lRkhBa01xMkExT082QWN3UzVtM0VtMVRaOC95a1ZBVzNnNGliZGpyMzY0Mnp0ZWwwSStC'
    b'cApMcXVGSytzc3J1dU9RN0FIWFFOc3FBYUJsNUNrNUFzNnBBb3hSRzlQdFNvTUNVWmhzWjB5'
    b'Q0hJRmtsdW05b2NUQ2psaXFYRlYyQzdYCmpTSkhRNElaTHRZa2pUbXFudU9aMlloRTJyRzMx'
    b'RUVEUXpGMGVxZDh1UkpCWGxZSlZYTThKcU9aSjFKOExOZmZJL1BpNG1WTnpFLzgKWGxyZjhN'
    b'NHllelhJUjBJaEp6NmZ3eFcrWDk1OEVOZDF5Y09lUE1qZkxDS1FNZENmWVVISEFZQlNMQkZt'
    b'NVFneXM0VlpPUjJXY24rVApHU2lXS2hPTE9EMDk2WFF5OWtPNExwWXE0L1BaZmJxWmtna1lB'
    b'RkFLQk1MY0FyV3E3cWg5bzUzWllTRVlVNVBPbXRrNWIvaHh1YXk0ClhIWjhQcHNuVW56Y2FI'
    b'OHMxLzhERmcyYVNDRDZkRldCQVowby9UNkU2NXBKckpKaG90eDhSS0hvd0lPMG9ZN2VZWGdI'
    b'Ky8rQUZ2czQKcmsvZW1mZnBiNFBEb2tLOVRTSUNHTDdPV3FrbGEyemlKNmNKMGpLVkFrR0g3'
    b'NHd4b1ZOQ2VsRERlbUl0ekR1WDZ5S2xrdFNHTG11NApyaFNKYXJmdTZyRENRbUhRcEc2KzFG'
    b'NGhSRy9QempMS1ZIcm5XUjc3V1M2YjJTcnJsQnVpa004UC96UnEwSXBFSkJKSnczVUVZTGZp'
    b'CnpYcU1HeHBRR3E2THhXSUNnWURxUEc3OVl3bjliMkI1Y2xMQ3NSOFc2ZjZTZ1dWdjJDNUlJ'
    b'K2hKKy9NblY4Yy9mL0p2R0JBczYrb2YKbjk5WGxkVFdlTm83YVA2YmxYUTYyUGQ1L0g1N2M3'
    b'RTZ1aS90eHVydXJVendaVUdXdWNvT1R2NXhwd2Y1Yk1uZFVyOTZqdWJDb3VvcQpIMGVuejI5'
    b'OFVIbWVBWi9mVi8wQ1ZiMVFwdDBST2dBSWxNcmlpTkp2NW9uMjdTZEdabm5oVWFnOFRHdmcx'
    b'a29mRCtYclNsVGlacWNnCm1aa0NRUjc2bDZ4ZEw3cDJpV2gvMThNRWd3R0FmQ0luUmRFYUpY'
    b'UCtuNFQvLzBGZHFVUlJaRTB0U2d3QWlTald4Qy9GQURCL29maWUKZVJVQU5IazArM2dvQWNE'
    b'ZEdXRjdzQkNBdXlZMWN4YUtBR0RzRkhFU3RnVUE2dEZpMGFEYTdpYUUvK24xL3pjazQyRm1m'
    b'U010Q3E1bwpWa3FSTGx3YUZRRUFVeHBFem13OUthc2VOVVByVTR6N1JuQlNXaDMyQmNmQ0ZB'
    b'Q0FTQURvd21NaDhweUFpamxmeVVRY3pHYzVQdGpQCjhxdk1KTVRLV3RUeUZlSTFheXJHREpQ'
    b'Vk5FSnhCZkJGb0ZBb0dmMVlSZFZJVHJuNlRBSk9TZXZONGlxUVc4K0FTZ0l2RndnZkxycksK'
    b'ZlhOa3BiaWhHVWhDQXVBL3cvSDVQUFY2ZzF5VzBMdll5MXZCWkVOUkdjZ1YwSzBMT0ZxRFdB'
    b'b2lDU2dSS0s4QlBBNGtNbkN6QnpRYQpTQVFnNHFHNkVmSmZBeFlEWFYzQmlnRlZsUmkveDU3'
    b'TytNOVF5R01XbXR0OGZsK0ZSYUh1aWx0ZU55cWRiR0JTQklUNVFYMHpvRkZRClZnc3JaZ0NE'
    b'RG13ZURPd0pDRUNZSHd3TGg3dnhRQ0VCZ3NDNGdSRG1CelZORUpjT3RUV1lJV0liN09mb3Zu'
    b'K2VlcDJJUXZlMElwemEKRE1VVllFSUZXd3NnNEtDcUFaeHRJU1lKVXZLZ3BoSHV4c09iYXNo'
    b'NUJROFN3ZEVhcWhvQWh3VjdLekNoUWtrVm5ONENJVFlFSXVyegpISi9QVThJRHdFM3JpaklU'
    b'VG1nM3NEQUZKaHRLcThEY0ZNeG9RQ1VEalF3QWdFSUJnZ0NDQUY4RWZDR3dlZERDQVE4bnNH'
    b'SUFrdzNwCmhlREVNWm5VNlBwNWNwMTU1dUpuK1dGLzVUNTR4WDRnVS9LdExlUUJYaERrRGVi'
    b'dkMzZTF0RUpXTWVTOGdzWVdMQUZEOHpBWk5zcC8KK09mSjljOGJoNit0clMxNW1kN0NyRUFV'
    b'UWo2M1JYcm5PcnRWU0NlaE1EaEVJRU1vT0pSY2h1S0pFRk1TampEcFN5cmRISTJsTUN5Ywp2'
    b'WHhDN096c1B1TmgrYmRFWDFUMElaSFdmd05oNXg5NTJTazNjclFrcXBKRU1lak9OSG9WUEw0'
    b'Z0xhUERPY1VBZ0VLanJWY3M3cXhFCm5mZThMWmNyU00wUVpHUXJSYUtPTGtNVTBkT2QyaXVV'
    b'NE9haStZM0Rsei9MWTc4b1lQUEZpczVaNjUrU1ZXRTB0KzdUU1M4RnNhUFYKQWtZcmdQNHph'
    b'NzFUM2wrYlhkaFcxNkpiSTJhUS9maTNjNTJBUTdmVjVKa0hlOUE2Y1dWL2VncWl0aHluTFE5'
    b'VGxVanY2MHlsa1REdwpZUmxVR2FYY1VDOFRWYTdjcDVOU0pCSm01MzFpY3RIYk0xZ2dWcndv'
    b'NER6SllUM0padVdXOFpVZmVkc1A1Ym9tV1dwb3NMa3FCNjBUCk9TM0l6QllrcDNVc0JSSExN'
    b'S09FOUNBSEIxQ0NBelU1MXdaRk14K2JMYWxiYlJyb1RrTjNraENUdDdBRTZabjhwRlIrUXJL'
    b'MHRxNUQKOEFxYTFOVkw5YkdhZkV1ZVNKSDZrYTBDM3NWMVd3YWhqNjlwWkNCalZLaUZuWG1u'
    b'QVpOeUZsdVFsc0ZQU3VVbnBraHJhanZ5N2JxMQpYbTFsdHFvMEk2TUZjcCtTR1cxQnh3MzBW'
    b'L2NRVU4ya2N3VWJQeVZOd1dudGlKVFd6YTN1R1lUQzRVQ25WVUJNUmt0VisxV0NobHpYCmZH'
    b'UnZYMVBkSkxoUEZuU2ZXazVsOUNOMTYyRGVVUXpiV1ZVUW1tVXdNdFRDdnJPV2dWSXBldmxL'
    b'a0prdHpNemh2VWpxV0k2aDBaSkgKamNCN2tzTmk4V1NHWENmaDBiMTlUVHRkb09ubHpIZW8y'
    b'NEp1dWpRNUtBQk5KSFRNcVBuUFZEeDFzaG5ZMFJ4elRYa3p0VTh2dkwwZAo2Q2ZNUDg5ajgw'
    b'UUsxSlBzbHQ2KzZ2TDVUcFpkSGUyMllMUTA0bFdOTURhN0pUYWJGWmZML3RnbUYzOXJkU01P'
    b'aXdyek5va0lZRVFFCk1qclRET3lNSEhQVlNLcXFEWEZXbGlwek5hbUkwemtvamJhRXM2TzFj'
    b'RWFyNGQraHF2ODVYTmVsdjhzTTFBeHZwelN6Nk4ycjQxeFgKY0xtQ2xIUitjaG8vS1ZWU1Vk'
    b'a3hsNVRhSzRUYUs0UVNGcUtTUlIrdXF2K1pYTmNsU3hQOGdPNW1uVzRHU3Q2VXE2dmgweklV'
    b'UEg1SAp6RUFjN3VNVTBxY3JIcVAxbXdvbGtsbks3UlQ4NFo5RHpGYnA5UmVOMTE4MGRxNFpT'
    b'T2ppU3VqaWFqNWpXb2RMRFJHWjdBTzRybFNLClhuNVNJYU9xa0owY0ZFQUpEdFN0WU9xc1Zo'
    b'VC9mS3BuU1RRem9MUE1RQlFHVGZMdFN2THRhaGsxNjJPcnRMRHZOOHFTMHhTdHJSMTQKSjZQ'
    b'VmlrMGM2ZlA4eHMrZzdVeUhxYXhlOUd0OTdhLzNhM1VyWnpYOXFEcEdhQ0pCcGJQaHd5b3k5'
    b'ZlQ2cDROSFJ2c1UvaDJxK3ArdgoxLzlaWnFCK294UlVhUmxMWEZRc3lNd1ZabVdMWDcrQmoy'
    b'Y0p6dGFHRWhSQTdOYVZFaFNBTldlb2JUMGw4ckpLa0ZqSVNTeHFUUy9oCi9uZmJ5VDNiRit4'
    b'b1JRU0ExNU5tR0FYQ1VIaWM1LzJiQU1EaXlYb3VTZnZ2Q2dNR0RSZm1aZExiMTdTM3I0bXFl'
    b'Vldua0t5K1FaQ1YKSTh6TUVXYmxvS0lmVnlIS1Q0amVvTkFvb2hIelJDWkgvam1OQThrRXRL'
    b'cG1FWkhLb0cxZWk0UjhFcG1xL1E0OERnQVFCSVFTQmZ4agpTUFBtblVpSVV2bnZ5cXJRcFpp'
    b'WW1HSERodjA3di8zL2F3NW9kWFcxMGQ5TFNrb1dMMTdVMlBqK1psOHZYcnhmZnpjMk5pNWE5'
    b'RzFKClNjbEh2Y1AvdVA1M1VYSnlzdEhmUFQwOVFWcDVlS05YYXVwN3NpVGVGTDBueEp5U2tu'
    b'SjRveGRJS3owOVBkczc0WDljLzQ5U1ZsYVcKdEoxd3p2enY5dmgzYVUySUhwQ2RuZDJ1YVNP'
    b'VFlTUzU4dlpScHV6czdKU2JBN3U3dFM1WXN0ZTRaeXVWWm1abS9qOGRQZXpkRkNhTgpqS1dS'
    b'TUpZbWVFZEw0dDlkNlNHVks4c2J4RHlobkNPUTgwUnlJZzVESTJPb1JJeWRPY0hLOUNOS3lz'
    b'aGswcE1uVDRZUE41SzU3T2ZuCmQrcG94T0Y1VDFZY0hPUjZ0TnpVMUZSemlDZFNWRFdKK1NM'
    b'NTY3SUtQM2ZaOWNmRnJxNk9WQ0xHMFpLb0M1aHd1ZHpMUndidlh5UmUKOW12a0YzNStSbC9n'
    b'eVpOWU91M2pET3dtanJTZUplR0pGRHloUWl4VDBFaFlVd3FXUnNhNjJoRHgyTDkzK1NrUnBJ'
    b'WXBZYlpLZVNJRgpUeWpIanZrK1YzT01Tc0owYzZiMjhqRVpIV3JadDV1cHFqbm1weE5QcElq'
    b'SmFMNlgxcHhWeWl1dUVjamt4dTFIU3hOOGQxZnFBSCt6Ck1XR1czVjNmMDBEVHpzNCs0Y2s1'
    b'bzF3SGdGa0xEOXg0SExSckFXZkhqdStXYlRweko1bjVNTE1scDR4WDNpQlNHNitjbHcrL2hx'
    b'SGIKbjRHSnQrb1NGMnRTZDFmcTBCN21ZOElzais3K2RudFV5eDlQNE90NWU5cDdnYlRucDV3'
    b'OFI3NzMyL01yK0hlU21jL3kySG5sL0NhTwpjZUdFdzZLOEhTaEJIclJSSVpaRGU1aXJrcjA2'
    b'd1ZsWElQSDU3THVwemNrdld3c3IrWHlkUGxWNjJKeHEyNDZVNHRaRE42c3NUZkF6CkI5dEdE'
    b'YmYzdENkMzBFTkFJTDZBZmVwQjdZMkVwdmJhM2VrU3MxWDZKTFArYWZUZXpTYmVYa0dSVVNP'
    b'Y1p3NjJVelUzZTV2czdlM1QKSHNiSTVYS3NzUTVWZ1lHQlozN3lteHlaNzBtOWJEODJRa2wy'
    b'TUR4RHdncnlCcEJvRVp1S1JsRkZvK2hPQ25QeHZrZG5JcTZRaVpENgp1dHVVdFQyTVBsMmhV'
    b'UEFhbnRqMG45ZmV0N1J3WlplZTFQOTZyK0psWml5cXRSanBNaE13N2NMdk1qbVNYOEhQcitC'
    b'ZmVGeFB4S01uCjliR09HbTdYdDV0WmgrWHVxeHJocVFlMUZ4N1hOYmZUcHdvRDdsOGJQYUFD'
    b'MUk3ZnJZN0xaYVBSS0VkTElvbndvWE93ckY1MEtxWnUKN3FHaUgyOVU1WmZ6NVlvUGRnN1JX'
    b'QlFhdlRGd3E2MHdldjhOeGFGWWZFR2xnRVRBT0ZrU0RRU1BTQ1JxTGY5SlNoamc2dXBxTU5X'
    b'eQpYbk1QLzFsMTVoNXpXbkJxdnlBNC9ydE1STzlsOEJ3VGNkcjJ5Wm1INzNsTHlENEdoeXlZ'
    b'cHkrdWZzM2t3S3hMVXh1UkxtWlVySjI1CllZdWk1OCtmbzFwTytZYXZ0YmJXYS9VcWtTbGpz'
    b'MWxiTHBiTis2bm8wWjFMazh5V0QzR09lOEdmQ1c5UHUvWVhhRjQ1Ly96aittdngKaldLcDBw'
    b'WkJVRzM5OGlIVXdwVkZ4emN1UFZteTVreHBVbEdyVU5MdVN2dlFiRWtzQnRYYnh6VEVpKzdu'
    b'U3ZXMEoxdVk0R2trREoyTQpsU3NRcmxET0V5bWFPTkxDU241dUdUK3hrSk5mOGI0SW9MZ1pp'
    b'QmJ0SGNRMzNudTg2RENWREZOL0RIM04yQXdZQXBXRUdlVFBDT2hDCjYrNUtkYk1sbVpDeElP'
    b'ZkYvbUpkS1owMmY5VTVua2hSMXlMSksrZmxWL0NmNXJDcm1XTFZhajRhTW0zeFZHVE9ic3Ba'
    b'M3A4R2ZjQzgKaFlkZkhyN1hkZm5vWXRJU0F3RTFsejd1MUhyaDhXalU0dFRmZ2NBQUFGc0dJ'
    b'U0tBNGVkSzlYZWoycHNUYUdUczJZT3ozQ20vOTUzZApwRVJUdVVKNVdZTW92NXlmVThaN2tz'
    b'M2lpUlNnRUh1d3QwZXZURy9sdzVEalM2VTJvem8yRGlycTdrcnQ3V3ZxNzBiemNhSlltYXFI'
    b'CkhZTkI4WVJ5bmtqUjNDcDlWU1BNcitDbnZlSW1GbklVeWc5YVlOZ1BuNFBQODluUDg5bWRo'
    b'QThwZ0pVSGpPN0dMVDdya1JPT2xDVnQKdTVQMlkrckFOU3R5VFgvaWkrQk9Ddk5PaWw0UzdV'
    b'WW5uQks1NC96VkMrT2QzUWlNekRJekFOYTRQb0t6ZjFRQlZhKzlqQzJsQ1FCcwp5WTNGQnFN'
    b'a3FCdzdRZ2dBYWE4WktwWURRRDFMOHR2VGV0MlpzZEgxVHBVQTV6b24xNWpoSkF2Z3Jvejdz'
    b'YVNSQlJHN3gwanQyMmM1Ckt3OUk3KzhLblZmT3p5dm5RNmZTZjhsekkxbEQzV05RdHVzNHRk'
    b'Z3VtckszRzRVRUQzZVh1TFhzTUhwT0ZjdGtmRDhoY0FyYlJYSTQKRmdBUTNCV0FXMnB3eUpi'
    b'V0FnQzJ0R2JEYTdnbHdWMVYxMXEyKy9LdFJlUDdDcXRhakJmVGRHblovbkJYQ1I0SDQzZjVz'
    b'ZXdXdDI5Vgp5Nkh1OFlkdy9mUHkxK2xkb09KNnUwZFI2RnpTeHQzbmNkWU1PRFV2Q2NWTU1z'
    b'SjFqbVZQSDNCUVBHcnZIaEk1RmdEc0xJR29xRGZrCk9wMERBTFowdzBnTVdWbG5hNkh5TU5z'
    b'MVlwd1ZENE84b1pKdFJES2ptQWxuRnFSWU1XRHRNZnhMMnNaM3RaZXN1QTQwdDM4ZlNtUGQK'
    b'ejRaN0ZVVHRaNEVSTGZZa1JoVytnVUU5NFN1WFE2QTBkSHVxV20xUktCanZrd0R0QkFwTkNS'
    b'elZIK2JFSmtPdW0vSUJ3TmJNVUhLYQpFMXJhcm0xUGx5SGpmUk5RS0tocWZXdDNIYVYwcHV2'
    b'aC9zR1EveHArenBzSGhQWmJvSW9hN1BoWHdhYi9mdzJsa2QrUDRBcmxyUUk1Cmh5OHZyQlRr'
    b'bGZPU1g3WW1GYlYrb0Yzd2dhVGF6eWZZZys3blF2VjJKRk5KV0JvSnMzcmhVUXptbDUwL1BX'
    b'MFZ5QnZZMG9JS2ZsNDUKLzFrZXE3QlNuUk11dFIzM3c3WEw1emEwYnAvTnVienVzY0plenor'
    b'dTRUc3BsREMrRCsvb3VSSXc4VEt5S0JscXg0eEtoSzhpYkx1NwpVdjNkYUM3V1JBSkdrWEJX'
    b'Q2dDMlpwS3E4NkVTSmFheVNaeGZ6czh0NDZmOWlXaXZOY3AzYnVuNFNUd0FxT1E1Z2I2TXg5'
    b'YkhiRi9lCkNnQS9YRE5WMkkvUi9PN2pSQm5RM2F5N0c4M1BoV3BqaHFkVHNOdFdEQkk1QnYv'
    b'NHl3U2VTTUVYeVl1cmhma1YvS3pYM05oc0ZsL1UKbVJFL0RCclZ4OWMwckt0SmQxZXFqeFBG'
    b'bElvMW9XRHBaQ3dXZzBhWlVYRm1WQnhZUTBBWDJuU3dBWUJtcnV4Mk12UHN3OXFrb3RaUApl'
    b'U29PaXhvVFp2bk5ZTHZJUUlacWJ4RmQ2ajkwQVNkL3h2UFlPeE1tVEhTekpZWDdxR3NRMzlT'
    b'TG91TWJ6OFRVdnFrWDNTZ2Uvb3ZzCmQyZGJHT0Z3L1M2aXgzVVp6cWFlQ1gwRHdlSjRiUFBi'
    b'WEpmeGZGM1V1VHBUQnpodFcrMnJGYTRWRlNveGJtc0JTZ25MM2RuWjNZNGMKRWNBQWdPOVo2'
    b'azZTZnE1aWFPSUN6bEI1VzRrZTl3NkFaZzRJVVlZRjdxT2RyanRhZzBRS04xNk5CQWVVcXcx'
    b'cHpsQzdxZjJ0M2UzMApBSTlidDI1MnRVd3c2ZmFiQ1FWclFzRUNFTHdkS2VQQzFXbkxzZG1z'
    b'ODQvcjdxUXcyOE95UHBCNis1ck9IV1kzSnN5U1FjTjlxQTF2ClFjZk5HV28zWjZoZFlhWGcx'
    b'SVBhMzU3V2YyeGZhZzk3OHB5aGR0OE10ck0yYXhkbkhUOSsvTzVuaExJNzg0WU1HVXFsYXNH'
    b'NExyYWsKOVZOZDFrMXhlWnJMMm5PaUpxUG85M0IvbUJ4ZWUvZEpFeEIxZHBJbFdWVTFnSU0x'
    b'alBGNmRwYXIxeVkyM01ja2tGYlIzdzhBUUtrRQpxb21lQVY5WFY2ZmhlbDFkbmJPejlpaVo3'
    b'cXhVQWhvTi9ZSmdLWjZkSTNDT0wyRHJ4cUxIZUQ3RG9LR3lIb0JrWlNDMEp3NXBBSUQwCkln'
    b'anBOWGpkZ3NESUlNYmJLVEY4UGovbHJ5aFFFclpzSG05RXArSFJvMEl0Um9WYU5MQ2w1eC9W'
    b'blhsWTk3cnU0K3EzemVtNHJ5SnMKbzRiYit6aFJPdTY1K1RwVERpL3cvQ0hLNDNrKys2L1U1'
    b'clJYclFVVmd2WjJHN0F4dy91NVV2dDJNeHNkYWhIUTVmM2J2SkxKWkFGaAo3Tm9wMGZ0MnJk'
    b'Mng1N2loWllTQ2lBQ0c1K2FJaDZjZzNCOGlROEg1ZVhFOTFrYWJyRUcwcW1xQWNIOFkzNXR6'
    b'N25xWnE0ZHZkMWZxCklIL0dtRjZXemxiRWRTdVArTGdCQURSendOTEt6b0RydmxacXJoZlc2'
    b'U1dLV2RzNE1EbGd6UUFmTnlBa1BYdDJjRTV0aStSdUN2TngKRml1dm5GOVdVamhoSkFjQXFo'
    b'cEFkLzdoc1doclRIRkVDQUJBVVJsYzJETEkwZEc0VWord1orMkthYXpkZjA0bGs5K0ZlTnFZ'
    b'NGRkTgpkVmszMVNYN0RlOXVDak9oa0pOWHptOWtHd2QwNldTc255dTFweWQ5ZEtoRlB6K3pE'
    b'OEhSUDhoZngySlFFUUVNbFF4RUVLaHRrWEQ0Ck1wNUl3UmNwVUNnd29XQnBKSXlGQ1Y2RG5r'
    b'b2trck5uejVKSXBCNDllbmg0ZUx6anpxTW56TTkvRmUyRVBabVhONzk3ZHlQdXU0Mk4KVFVN'
    b'TENnQ3h0WUN2Z2l1MzdoNVkweXptOE9VOGtZSXZsQlJjUVFFZ2cwTmhjOHViYmR2bjZYalVD'
    b'SXA3WC9WM0l3dHNiUFM2cXpVMQpWSmk0QVFDWVVLRXB2MEtQNjliV2pTMWd6UUFBd0FvZUFv'
    b'QzlPV0hCU0ljRkl4MEFZTnZXMjRONkFnQlVONkx1SDRpa2tQQTBNdGFVCmduV3dJSDYvL295'
    b'Tk9RQkFFeHRsOERndEpwK2Y3NG8vbVZVTVl5Yk9lL2VBbDVhV1ptUmtpRVNpNmRPbkIwNTMw'
    b'eURXTFZ3WlQ2Um8KRmNnUkJLZ2tESTJFTWFYaVZQc09mWncxOTdFWG9GRGdZRUY0OTVNSUJJ'
    b'S3JxK3Y1bnlhUzZ0a1hYcG1TN09jdFhMeVd3V0M4ZmVhQQpBUU5XbkdjY1hNS2F2L2VyWDM3'
    b'TFJyKzFDU3dPaDVNcHlBQUNBSkJ5ODdBWWxJczFDZHE4M01RekpnQWNBaDRFdFZjQTltbXVL'
    b'aWdvCkNPdXFOdVVhVzhER1U0OE53dFkzV2xTR1Uyb3d5WnJhMms3MjlHSldWbGJxeW45QjNS'
    b'VlZyaTlIU0I4ZW91ZHF5L2xxMkVDbUlPRncKT0dOUkNlVEVnUmtubGlxWEhUWS85TzBBNHlo'
    b'RlM4dko0L3ZFZGI4R2U3Ykd4SnQ5cy9RR2dVRFFqVTVabW5ST3A4dS95M01iT0hEZwozcDhM'
    b'WTNLQzU0emlMQjZ3LzhRV3Awc1h6eHQ1UEJwdDZqSkxKSUVGSS9QT25UM2R6anhUNjFXY3Nz'
    b'b1F4UU0xTzBNOGExNisxR1lCCnA2YW1CclZ0SDliUUFyYTJlbDZXaEYraDgzZWx3VnB2YWpQ'
    b'ZGc3d2hMaTVPYzZpNHVMaW5SNDM2S3NSd05lT1VtcndhNDFiWStYT24KRjR6SUU0akF6SFVX'
    b'MnRnT3h4Y3ZuRDM1dmROM0F3L01HdG42TUxmSHZwTkZBd2NPL0NmNjZ4d081eDFIYlcxdGo1'
    b'OUx2Wks5TWlrWApOczBXZEZITTJySStTdkZXZ3Y3VUwrYjhHUWZCWGVGVjRuSW0wMWpqQWtS'
    b'dFJwaFQyUktKM3ZidGFLS0w2by9odmVIT3JXaXQ1cTR1CmNteGJpaXd1MFBXYjBpZ2x0VWIv'
    b'QmdBNm5jNXE4MW9jcmFHNlFndjgzYmwxYlhoNDIwUWs2Sm1IRW9uRWdzYldnczF2VVhOejg1'
    b'dVUKNWY2ZWNQTXBUUDFpdGlIYUxaZHZYamZiRStac25DVk15SUdyMmF1T25VMXBUMDE4eU1p'
    b'L1g4TDMrQzZOVHNiUVNGZ3pHdGJIaWVydgpSdTNoUVRlbmYxQ2NoMFFpWGJ0MmJlclVxZTM2'
    b'aXhqTXhpMC9uRDdsZnZuQnQ5T0hJMmIwMHlNbXRacUhibWtWeUhraXVWQ2lSS1BBCmhJSTFL'
    b'WENlTWFKeXd6ZkNiNWN0T0h2dXVvR1BSOENweDlIZEVTa3ZML2YyOXRZYXZYUlBnQmdBb0pH'
    b'aHZ1UWl3RmExcWR5cTVTV04KRER3ZXY3UkJrVnZHeXkvblZ6U0tYYmhhQzQ3UHE1K3lLOS9S'
    b'a3VEblN2VjNvOWxRQkRTS1ZwZnAzcWVoOUJKMVNOc3IwZlJ5cXNySwp5dHdka1RZNzNKRHJZ'
    b'cWx5K2NyNXgrY0tBT0JXbXZNbGthaFZrS1pFZ0V4QTAwaFlFd3EyT1hucjBXOXVlam5EeFhz'
    b'b21lM1BHNytiCi8rNWh2M2J0MnJoeDR6NDhFSmRSeXMwdDR4ZFc4amw4T1U4azV3b1YyTGQ3'
    b'V3FoYyt3bDlyS1lQdEhrMyt3a0VncTJ0N1lFREIxYXYKWHQzZU9TVzF3Z3I4NEl1eDYraVVQ'
    b'YVA3d2Y2cDE4UDNNb1Eyay9TZVdEMml2dmxuV3dzWTBmV21XY1N4RVVNR1RPbG5QUzdjVWxV'
    b'TwpRaUtvalhZUEozajkrclV1MXkxdFBIbENkYTlJZitleXNySXlOemMzQUFCRTYyY3k2TkE5'
    b'NmttalJBdWc3dkhXMWxlYlViajdYMmhUCkt5MXd6TE1ST2xKR3FSWXQ1ZVhsM1ozVTFvQklB'
    b'bWFXbmdiR2wxZmJqaEdhdDVYS2xiZVNtTkh4amZjZlBUczcvQ2FkQW5WTXVGTSsKUWlIWEs4'
    b'T2dORVFuYjdqcDVReTNuOEhtcCt1LytpYXl0RmJvMFg1T3c0RURCMEpEUTNYMXZWRnE1c291'
    b'UDYyL21jZzBHb2d6SXVFVgpTdVI1UG52cHo2OGNacnlZdnEvZ1dSNzdIY25UL2ZyMUszOVQ5'
    b'TXVKL1c5UDhDdHhEWVBXWm5yUFRkcDF0YnlhTUdqbStjazFqZUR2CkNUK09QQVVpUFdCY1lS'
    b'MXhOUVlOQU5PSFF4anN1WmxRTjIxUHZzUDBGeXQrTFNtczRFbGw2c2U3MmtGK1hvYnVoVTVP'
    b'VHBWdGR4cmQKRC82OGViMHRRcWhkY082TzBGaWxVL2lqa05neXRDNlFIVU1LQ3EzV2FLNTU2'
    b'ZTZvSjN0VmYveDU4L3JvZm0xSWNBTTRPN3ZvdmtaQgpYb1pybTI4b2tTTEYxWUxWcDBzZHBp'
    b'ZE0zWjEvNDBWZE9IclB0S0VBQUZkaTBBcnJDTDFoRXRZZEhudkd6eDJxR3VDYkMxT3FDQU4z'
    b'ClhTMzNtcHMwYUczbTFXY05iMWQ1L25KaWYwWFp5Mzc5K3JYSERnU0Jwem1zTC9jV09FeC9z'
    b'ZXhrU1h3KzJ5akcraTY5cnVMY3dEV1oKN3JNVFYvNWFFcGRyZkxlNFhYc09aai9mYytIc1VR'
    b'Qm80a2h2SkRUTi9LSFFmdnFMNmZzSzRuSzFNNFp0UFh2amFWTUFtRGRlMlZONQpRTzhXZUpO'
    b'THliNHFvWHA4YVFPdStycHF0aDY2V2RWdFFhcFFxcFkzQkR5MGxGOHo0SHBWRzVCdllRb2wy'
    b'ZWRPeDlTTytUNzNScXFXCnI3NWR3QW10RTd5UnROanF4RTFzTFFFa0xaci91bUFTdStwa2Fk'
    b'eElsUTdmbEgzeVhzMnI3SE9haHFSVkRlRGtwTGNaREtzeUd0OG0KRTRWU25NKzg1Qi8rcUdT'
    b'MlNnRUFYM1A5K0ZMMUsvNlczQTN3ZW0xTlE1RURjOFlvQVdERHIyWWNtMWthenNYbHNyL2NX'
    b'MkQzNVl0dgpmaXk4bWRpa1NyMjZjUFpvOXZNOU8zZi8rRFlMZUNKRlhDNTd4YThsWFdZbFJx'
    b'ekxNanBqUHRweks2c1hIYnhaZGZCbUZRb0ZyallrCkh5ZUtDUVdyMGtsS0pkSXFsSmZnVjRW'
    b'Vkw3VWJXRnRQaUd6ZjU4TmVmalZqZDlNeGV5dlk5V1gra0F1RllLcEZTWE5FNHdyZTVIZnIK'
    b'QWo1dXNLTFh4WDJ2QjJtaWtNVzFkQUExWTd4dFg0MVk4OVRTeXBwT3hsS0lHQzVYMWwwbnNP'
    b'TG44Q3BxYnp3UUxkRUNSNGtVTlBzLwpmaEVRdjY5cUtXQ0lScmh1QVNCcEFiSWRBSUJDL0VW'
    b'QWdzNmtoeHFoVTFWR1MweEM4Ykd3WXMzdmxmWHc1MU1aUGZPMVVLTGdDdVhNCnhzWUp0dHFF'
    b'K2VJNlU2MW9GRFd1Q3IvbzVRd0FrRmNLdWVLeGVnUEN6dDgxcXdDRmdwcEcrUDNOVjJCdnlB'
    b'c1dUM2JoY2YyRngvVUEKWUN1SjNUMWdmd2xoNTdwTERTYmtaalFhMVNxUWM0VnlybEJlVkNY'
    b'UTVnUCtIZjQ2Z2tCWnZhaXMvdTNHaWFHb2VxOExVL2FQT1lzUgptN2ZyYnlncysxNkpPYjc2'
    b'YTJSd0tQaGYvajBYZEFMblZtR1hIdUQzTFpZQ3dPYlo4cXZ6RDFZNXFQM3ZuSG9QRGRjblJ5'
    b'SWJ2L3V4CnlYYTU1cm9OampnQXRSWWZOd0NXM0UxQW5NWXJTVTRsVmVEbnJqNW44U1Rwd2JV'
    b'UFpYWmpqWE5kckk2eTR4b2ZmYnRDS3lSZVZZQ1MKNUFnQXFLYUVjVG9PZGxVajd1YzBEb0Rh'
    b'aXJhdVAzVDFtSGJJY3hyY29RMlljR0VmMmpoTHJTTitpOEdEVlpqdWFBVGlyNm5ndkNzeApL'
    b'SVZsbjNjTU83RWw3dnlzL2Z0dWVjV2hRK0x1ZDZScjE5L2xyOGZKTjFjMFlLSm43TUd4a3Rv'
    b'My94ajNjOVVDZEZaNE9zaDEraTJoCjhWZXkrNm9LN2lna09Ed3JDNXJVOXlrVjllQzBtVjht'
    b'Vk5neEpnWjQ1ZHFWMTJLcStkdkJHa0pNSHdJQU1QenZKV0owZjUvb2VsWGwKU2VQbFRick5v'
    b'eGwwSUNoVjRnS1o2SHJGUVFkNnVaZUlBVVlBQUlTWVBiTFhBZDJyV0RyWDg4cDNqb3VodDVu'
    b'OUxhM3dXaGpjQmdFbQovelFyazB4VXh3S3VaUGNGTkY0WDFwblpTMjJqUE1oekJieFp1eEVz'
    b'VmxMMGpEMlZqWmluMHMzL3ZQZzYwV3IxdlZuQjNzaHZrN1poCldCbnRuWlhTMUVjbUJ3Q1lP'
    b'bGlCYmRUYk1xOEdQeXF1N2JyeEEyR2syU0ZRaUFGQWFkbjNmcUlXVzQ0YXB4eEQyd2dLdGJ5'
    b'cDBzOXUKR04vakRVaFlnQ0hkemRXTHdpMFozd0xOR1FCZ1E2clZqWW1nVUdCRHFnTUFhRTVm'
    b'TXI1Rjk1Szd1VjZBSVlLVVBhSEhHNzI0dnVhSgpDdkZZK2thVllsWlI5R09VMHJLdjZ0Qm84'
    b'NE5qMmdMb1Q5T2hscUNYU29WcGpKc1NxUUFBbVJ4U0dudTM2L3F5TWk1TjNCYnNqYXk1Ck4w'
    b'c3Y4dlNKOGZXTlg3aXE4dTVhdUxLaUtrRlp2VWpaMFhySFZ2UEozeDU5ZUd0N2xWQzhhZmI5'
    b'L1lpcElhNk94Nkx0WExvWGxZRy8KSjlpWXd4ZGRZK3lHTFZFOXZaRWp6UzhQK2kzV05DSkVM'
    b'VG1QTE9NOFhYMUI1RElmQ0l4Zll6MitIRmFpNGRPRjljekFaZnNxckw4SApnQ3F1SFlEV1JK'
    b'OHdDTlk5U1FMSFVhbk5nMWpjSWtZYlBOT3JPL1FnUnVOOUlpMHJEUEdOUUVlT2s2dXBORDI2'
    b'bDg3N05uTWduVFVJCnlBQ05pZU9YNkExSVphc2RtQU1BdUxMMm5EL0kxSjFERjE1NEE0VUJB'
    b'T1NhQzBjT2FCLzBXNnlwYlpjZ1AxZWF0U21lUnNMUXlOaTYKbUFjcVJWUDRCdXhjL1d0UTZM'
    b'ZExnRkdjdk5Pak5rMGRyQnkzeFlsalBybmpLeHVGY3JNbCtUcFR6T2s0S2hGREkyT3hPMmQy'
    b'MFQxRApJRmFrRnJmZVNXbStsZFQwMGIwa1VLamJuQzNSc2ZPK0dhVVFTdFl1amp1STBMc0NR'
    b'TEFIZlZ5NDVhZ1FpMjR1MVBvNmoyZm5WL2w3CkFnQU1DeWdORzRCMmM5UDYzNXMzenhlSzk2'
    b'bWtvcHM5ckI5MGMwdmVVS0M2UEJjc3VKZXdZbVNiN2pPbHdkVmxpZjBPUFpEWkRLOFYKT0Np'
    b'VWdHbVRXUjVPMEkzMHFBQkdLVXo5MHd0aHFFNUs5SlNlQlF1MmVlOWJiNWd4NEd2TFdiM1o0'
    b'OVQzQmJvL3BoV0N3dFFmQUxxUgpIbnZvR094S0pkUUlITUVjY0EzM3I2NUlNdFdKTE42Tmgx'
    b'UnBGRkFBK0JVYkJ0MTBhZlBsaEdKdzlKbFh0MFByYnIxNTh5YTFRWTMvCjU1YkNzNU5UYk8w'
    b'Y0NpcjQ5OUthLzB4aXFoQVVGUGZsMFVGcnZ4bWxpSTVGMytac0FlcEhKOGU3V0pQRzk3WWNF'
    b'MmJaMDVOT0lXTGUKWmMxUmlKaEJBWXhCQVl5RDh6MWlzMWluWW1wdjNia1BkWThpdXBiVGla'
    b'SVdJVFdud1pORkNBUHpJRDB0cFNHcTg1TG9TUkU5bzcrZApLQmVJVjJVUnIyMk1pdXptb28y'
    b'ZE96bzZWaldSQVlRcTQrdkkxVFByTnU3U0hKMDVjKzd0NkgxZnROVVhyL2xhZVduZWdWTHFN'
    b'VER6ClczNHhkSEJvcXNaQkN2T0RiZjErMnBBYklNZmIxREhCVVVjZlR3aCtWZkNhNit6aVhx'
    b'MWYyRG9pWFA3MDZWT00wakNiQ29zd256NTkKT3FLM25sTmEyd1FlSGg2bFZhd0p3Y1c2djlj'
    b'M2d4UnJBNkw2blFPT2hIYlRpUWpJWU1XbEVMRDBBMEM4dUFkV2ZhVmR1TGVld2N5WgpVYm8z'
    b'dWY3N21TVnRKbTkxRThYUjBSRUFBcnJRQXJyUU5uN2hXbERCMzNVcU5raThhdEVrZVVzckxJ'
    b'bWVCQmJ0N0IrcGxFSkxscmswCnhkKzZ4SnpNNTRvSlQxNjZndDJRQ1dOSFJnMjNIeFJnMWw3'
    b'UEMvUTd4TUtRWVBQckc3dlhQbHl4YlBuYVJwbHZnSE5UOU1iU2xvdjMKTWxkdS90WmlFcTMy'
    b'dkM2K29iVnZiT2R1UEcwTkFLdW5TNE5FTTlCQ3c1Q0pBRkZyWERJUitKVkhlRHd0VXVidTdw'
    b'NVozbFZyL09IaAoySUtTa2ZaWnZzNlVVc3AzeDZMMUp1eXFHUW9QL2xFZ1dsWHE1MEtPSDZC'
    b'YzBhZW03RkwvNWxZOUFNdkxCWXBmRnBCd2hoS2VoT1VVCnY4ejNkRFlBTW9tdnp2WmYwNzky'
    b'L0FBOXdhdUtySHZ4ank3L1VtK1dISTNHdktZdThYYWtqTERQUHJhd2hLQ3pJakxMdTdxN3Uy'
    b'disKeStWeStaVkh5RVREMGRDT3ZMQXFVRGhqOVhRcEFHdzhiYzJ6bld2TUhaTFE2ODR0c3Bp'
    b'VXRXcHo4NFY3MFJ0TEE1eWJtbVRkbHE5WQpXL2RveGJVTmZwR0JqSGUwT1htLzUyWmxpait3'
    b'WWlpc0dGcGEwYkRoNEVFNi84U0dyd1hIVjRrMk5GMWVkalNtbUxySHdhTUhqWVMxClllQjlu'
    b'YWwrTHRSQWQxcHUxcTFIS2VGRHdwRFZNd1Riai9mNllsbUdicFNkWUI0aGsyZXJlcDR0LzRK'
    b'Ly9Nak9kUnUxUVZMUEhvc2IKV1l1czI1eWZJV0VRL1dUWGhWL25DaFNCbXplOTRBbC9vYldC'
    b'bFRnczdKcWF2ajl6V3BWK3htV0FGeHgvY0J1TldpS1Y0d0VrT2xrQwpVRnVSMXQzS01Dbkl3'
    b'a1NXVzVtRzFjK0psY2l3S0JTdzN0d0swTTlucjZ5SEhxNndya2U2YnM4MnJnQnlXdWVXUjAr'
    b'Z1lZWHI1ZytOCkROVWVhbVNCVncrOS9PampSM2F1K0ZLZ2tSQWt5MGdEY1BlUDQ3MjJ6QkVB'
    b'd0tNVTFLd2x0dzhGOXN3cTVlWlg4SXVxQkEwc0tVOGsKcnlsTjc4cmZjUGhBaTUwbHNMaXc2'
    b'aWlWUjF1MGV0V3lEYzRmdWtuYlI5andIaTQydnh6WnYrV24rb01QNTUrL2k3YXpoT3M3V3Ri'
    b'NApMWmp1bFJXOTBlL0lRcS81SSt6RGZVeEllSFJZV0ZoSzNTeStFQUJnODJ6dStRT2hGUlhh'
    b'NE9id2taTmoyMnJMelUzQVRQU2picTM1CnBNblRyc2ZxY1dCYkZHL3JwaFZPVnNUZFd6ZXJn'
    b'RnNOalJzQVE5M0txaHNOSjdVNUpwN1A1eE53aHFLb3FiSGU5cTJFWmx0TFlESU4KdXh3UWNG'
    b'S0JRR0NPTWV4c1VOMklHdUw2ZW94K2R1dVZHUFMrN1Z0Y3JFbmJ0cXpjRnFYWFJQVjZMR2JT'
    b'NUdsYUZ5WWx4Vnh5VUdOagpQazZGNFNPMUlZbkt5c3J6UDRSdG5zMEZBTDRRVXVwbWhZYUdx'
    b'cnI4TGhqcGNHU2hWL1JHdnk4OU05ZjZMWXplMFdKckFlZnZvZzgvCld2RDkwZnBmanV4MWQv'
    b'NklmZmsrMm5PajBXZzc5cHowSDVPeDlMQzFSQXBmalZCYTgrZGV2SERLNExRVjYzNzY0U3BE'
    b'WlhMdm1NYysKdmoya3RsWU5ML1RzMmZOZW1sYWV6cCtndUh0MlNIR3hXbjB5R0l4S25oN09i'
    b'RzhGYnFTTGlZbUo5dmIycjVyODlYeFpMRWladDdnaQp3OTJiUnZlVFIwZEhtNUFOVTQ3S0sy'
    b'cFVYQmRKZ00wRnJrQU4xSlJYR0VJZnBoVHB0V3ZYUnZjMUZBeXRJaE5aOHkyRDVvd2xUZjUy'
    b'CmRuWkpTVWxkeUJmdDlLc25Lbm45Tk9ra3hjWEY5ODROblRkZXF4cnVwem4zNktFdW9LeXRy'
    b'VDIyUFdSSEZFc2xtSCs0eWxpeDdpZUQKcDE4NDk0dXRJR3JHQ0tWWUNrc08yd1NNemR5Kysy'
    b'ZmRsTU1QTmJ0MSs5THdlRHl4V0d4cGFma2hWelkxTmUxY0ZYQjRTVDBhRFRlZgpvaWwrOTRZ'
    b'TzFXdno4dWhSRExWMmVMaS9LcUlEcTQ3WnI5dVhxU29IUEh2MmREL3pLRTJjUTZtRUhXZkpB'
    b'NmM5VU1VVmJ0NjgyUldaCnFJdUh5eFh3eFRiUHE3Y0tUeHcvTWl0NEpVMG5JblhzR3FxMDBm'
    b'V25KV1Y2NFdjZVJDeTJHaEhXaE1kQlBSUGtDaTJLWWtvRExBYXcKR0tCUlFDd0JrUVFVU21C'
    b'emdVRlg3L0NHUW9HMU9VaWs4Q2pEOHQ2UFRIdDlKM25wRVZkUG00cEZVM1FHVFFqbk1uLzhk'
    b'dEdTTDhiNQpYdDFhb3FzcFhwYkRTOVNOQ1JNbUFFQjhmSHpjNzhNM3p4WnFNaXJlMU1BejVx'
    b'OXo1a1NwQm5QM21xQWZGOWVxbkpHa1hPRGJQeGd5ClJHODhZMkllQ0F0R1RoaUVLSld3OUNl'
    b'N0xRZHpQcEJUVENhVFNDVFNhRnAvQXpYN1lDR05oS1dSTU9aMG5JOFRwYUVrSHFNVVRwOCsK'
    b'L1VOdVYxeGMvT2hzdHlYVEZBQ3cvUXhsL3BZM0JqV2U2NWFOM1RidGpzcTBrY25odThOT1lk'
    b'TWZNVVZFSmx0VS9WZmsxYTE2Syt6YwpIYlRDNmRlNXMrZElKSkw5Szh3Mno5SERmUk56SVlO'
    b'N3FFK2Z2cHowSGlvZ1UwWFBNbUh2YjNaWHR0V2w1a042RVpUWEFob05OREw0CnVJRzNDempi'
    b'Z3AwbGZHVGZWR2hvZ2VvR0tLbUNvakpvYUFHbEVoZ20wTk1IUXJyQm9oL3QxazJ2Nngrc1BU'
    b'azJGY3hDTWhJU1h2U2cKTCsrdEo0bGc1MW5TNmgvWkJBTGgxSm5UbU9yNXM4Zm9HWVpSKzIz'
    b'TklwNWFtcEdzS1pLa1MwT09MSzFVZVNnU0tXejlmY3pldzdkMQpUMjVzYlB4bHU5dVdPVUlB'
    b'T0h3Vk0zeHVvWmVYMTRkOHkrWExseFZvc28xbnY4SktBWXNuNDRrVVBKSGNTRTJyQlMvV0Mv'
    b'OTgrYVl6CkV3YjV2TGVFZXNlMkRUTjc3bkd5QWFrTTFwd2RkUGlYSndZNUpLZDN1cXo3V3FD'
    b'Slo0eGE3L0FFY3d5d0ZPQVVYaHUvYk1wZ3ZiczkKU1lORjBkOThPV2R6NDR2MVIrZEdHeVFh'
    b'TGRwUFd2OUR5ZVVEem10bktsVjNpMHVIZXdtUW5BZjlncUJYZCtqcEE2NzI4SGRRU3l1awpG'
    b'MEpxQWNRa2diY0xET3dCdzhMQmlnRUFzTzhDWnNhYXlqMnJQSTZ0MXB1bVNpVXNPVFBGdXUv'
    b'ZUs2ZTJIWnQ2UVhlbUFzRE5wekR4Cmo4Tmc2Z3R5UVlSaThWOTdhb2h0WnYvZWk1UzVteW9z'
    b'TFBRTWtHWHpJL2JQZm9ySFFXVTlYTXhZdjNucjd2ZEdURzQ4S2JweTR1dUUKcGtnbTFUQWta'
    b'cVIrWFVod1U0b2J6R29XZjN1Y0l5SjZldGlScWUxM1R3Z0pEZDl6NE5laG9VSU1Cc3hKNWZH'
    b'RjduNSthb2lyc0ZKdworRTdUaVFla1llNHZWUG1qV0F4TTdNZDlIcE5hallrRXNsMU1NaWJT'
    b'STBkWGhMclpRN2hUenFKOU5mSE40UVB0SHJyb0Z4cUUrTWgzCm5LaVRpaHJxbTRSSGZvY0hT'
    b'V0JuQWJQR3dJb1pNQ3djZkx1QTJkKzJleGVaQ082T01DQVk1bzZESVdIQTVzRzVPL0RiZlho'
    b'ZERSVk4KWmkrU1gyK2JtVVBXNzFjU253V0w3czNKZlhicTF0TGZEV1JBYWdHTS8zbVd6RElD'
    b'RktMZTRtWDM5bFJwcnMwcmhhZy8xM0R4bms1VwpSRTF1NU5VcnYvVjNQT2hrQXdDdzQ3emxw'
    b'dDEvR2szSVZBc3F0dlRZbmFvRmE3NlBvTXg1VU5hN0ZHTUUxRFBldFlDSDk2dXVsNStkCmZ2'
    b'TENiL2VYWExQT3JsUktwSWlqSlpIOFZ1TUNIQTVYMlVpeFFOODNwWUc5RmZ4NSt4SForYXZm'
    b'WDNCV25TcmRjTzUxYW5Hcm1PQ1MKa1pBemUwaVRhdUhpY1RDeEwrZnh2Y3g2WEtTVUhuanJJ'
    b'WHQ4VUlsdU9NVFdBZ1o2dkx3WTc0SGlGby9wb3pYQ1pYSjRtZzZQNGdwNQpQR0ZrS0N5ZUN1'
    b'TUhncDg3VUVqd0h5WWNGcm80d0xCd21EQUlhQlRJS0JDOUxpbFVJdERGRVVnNkFNR3VpL1RD'
    b'SnFjbnF5NzIwTytMClVGSUprYnRIdHRwRmdVSVN6RnY1Y084YlRjNldRZ2xqdG5jcm95MUlL'
    b'VzQ5Y2JjbU5wdlZLcEJqNWEycGZ3Ny9jcWdNQUNycWdFUGYKSDlZcjNHanlUSFI4NC9lL2xT'
    b'MDhFTitOTy8zQ3dzZmZYUjJiSWwxZzNKcDdSOWNDWjk2WnVIVy9QMDdIcnI0ZnhiVVlqMGFo'
    b'WFcySQovbTQwVHdleUtRVnJSc1hSeUJpNUFtbmg4QnNmK08vNVZxU1N1b0hmaFJhYjc5UlB6'
    b'MkR1RDVxNWVvWk1WMkFPV05PdHdHdy9vTER1CnpadVNENlJabU9wZGNmQXladnZ0OFBwTEww'
    b'Z0VxR3FBMDM5Q1dTMk02Z3RqQitpTjdEK0VFQVFTY3VEeUF3Q0FiMFpEbUIrSXBXQXoKbzgr'
    b'MkNVbExwK25wY2lZYmVxME9lV081RXhCRk4vYWFaL3Z6ZFdmOEQ1ZHhxek12QUZIUFJ2TnUy'
    b'WkI5TkYwbC85Y2VJOW1PekRVMwpwV0l4S0o1UXdlYkxPQUw1cTJwaFhqbXZyRUdFSUlnZFB6'
    b'cDI1VmtQQitYQW5hTVNKRXZidGVIZjNhdkNoWHZ5K2FZYkFCQjF1TXNqCnlWWWcyUm85emF6'
    b'K1pNM1BOMVJpS2prUCtoOWVMck1ab1lkL05kek0yL2F6Ym5KU1F3djBYeGRVWXJFTGxJcXgy'
    b'Rm0zZHVsbHg4b1YKNFBPMS9aekJ0YVhWWUVLRmVSUEF5eG4rK2NUaXd2azdrSndQempad045'
    b'Tys4RUt0QWZnemZZZkZGZjU1UUdNOW1Cdmk5MlhaNkZUSQp2SzRHLzYwTGhUWVQ5T0pWRFg4'
    b'OVgvNVRtSjhhejdkZk1KRmpaM3o1Z3FoaG5kL2FIZC9Vb1FBaWRneDlMbG4xanZkc3R5K04y'
    b'Z1VpCjlManptRHVyLzZ0dng3SWRKSGZpYy9FU2tzL2JaZGxpdkp1VDVHYVByZ2dBT0ZxRE95'
    b'SDF6Mnh2aEtTMXJPUVU3NEtraEs4SGN6U1gKVXNrd0xyVCt6OXRsSEZyRUswN1hJR3FNbDR2'
    b'MmhzbjVrRmZJbzVCaDUwSVlPd0FNSk1FL2xrZ0U2TlVkSmd5QyttYW9yZVVwbE5EZApBelQ3'
    b'SEQ1Smc5VUp1NEZrN2R5dzdkbWVkSHRMUFdreGVidExxY2thM2JGRnM5SXZUZG96ckUyY243'
    b'bU52dEd5RmJDa3QwV052ZUJ5CjJvcnZwdzNrSVFnTTNoSHhUTExtM2UvNUhxNERBSnNRY3Zk'
    b'eHk4U2VwUU9Da2VraFdTOVRYcndXQlJzV2UySkp1Vm1WQzRkWHFxYTIKbnp2WVNKODl6REpY'
    b'VWowMDRiZ0tjWUNkK0c1d1Y2Mm5hMEtGMGNFMWY5eXA1bGxNek04bytuWlVQUUFVdklFdEo0'
    b'SEpoa09yWUhTLwpmNkk4ZnoveWhZWkFMNWd4QWxvNHNPa0VDTVhnNXc0b0ZJemRHZFJrOW9W'
    b'ZC9aNW5PeE1NRE5YVHQ5Rkh5MzRBdkhaMjR4cnVueGl4CmQrWW9wY2I5bVh5b1A5ZDBxT0hE'
    b'aExVYmZMKzlzeTdSeWd3VVNoaTZjOEJUeVliM3ZpRm05SXlWZGd5Q09SMlB3NkxhSzF0a0VY'
    b'cmQKZmRnd01hVE13UXBtUkhLY3BIZmpzOUZpc3EvdXhPUmlmWEIxZHdZRXFkK3lSMWRrdUVk'
    b'eWNseHVrOUpML1RGNGt4ZVo4cS9DOCtrNgoxWllNT296d3I0eDl4cTRuamdta1BUcDBHY3Bx'
    b'WWVzOEdOb0xDRGo0LzA1dURqQitFT1NWd3E0eklCVEQ5WnBWenNMb2Urc2VHV2lyCk9pYU1P'
    b'elpOd2hpZy9qKy93bysvNCs2SzI2UDdJanF1UCs2dVlEZGdkZkFwUk9uSXY1QzJhdWVVQVh3'
    b'MENwUktHTDBuL0pGb1MzdXgKTkVjcm9yc2QyZHVSN09kSzA4UG0rQ0pGUVNVL3VhajFUZ296'
    b'b1pDajN6RU04V3JkRTdjdFRvVm8xamJCdkVPTzk0WGZBMFViZk1iVwozWHUyL0xDdWw2SlV3'
    b'cFVZMlAxWHVFdWZUVk9IQm5SM0paN2JFWGhrcWVIV1FGa3ZJV3EvblRXdDd0aGFjTE9IejQv'
    b'NFF0aHdESktMClRILzRqcU9MOEtob3lVL09zemRuNTVhTG94L21WaVR1MkRBcTZZdWhvSXRW'
    b'Sk9iQ2dFUEw1SFk2NWZ1Q3FrMkI2NzcvaW9uQkFBQW8KRVJpenUrYzl3UzRBbEU2MENkWFB6'
    b'MngwcUVXdnJpYSt6bFJkOTd2ZFR1Rk5IT21GMlByVEQycExhalVsMUVqWDFoMXhPMTVvQW1M'
    b'bgovMEl2dnpXZFl6a2RVT283T2pkdVQ5enp3Z0RGbEN2Z1NneTZRdkxOdDh2MmxaV1ZWY1NG'
    b'VFJtc2ZXamhHOWh5RW1hTmdWRjk0Zk9tClY1V3c4VGhNR3dLVEluWERNeWluL3NsZHVuUTVj'
    b'WGlOSy9IQ0YwT1ZCZ1pnSFJQQzEvV3R0RzVieElqQ2lYL3U4WnBvejdacUd5VUMKNDNZRjNS'
    b'WHUxYkRjeTRFY05keitIVDBhVVFpQzVPVGszTGw1VnRENGtJcHJSQkFab0dtdEVuc0xwOEVq'
    b'eDN6cDU5Yzl2b0I5N2xIZAozWlJtRms4R0NPTEwyL3AwZTdJVlEvdE84dy9aLzhYYkNqUlhB'
    b'QUJFN3RHOE1XNVhsdjFiT1Y0aUNmejBPOUVwNU9Tcm9wUWxrU2ZOClRVQ3BoSDBYb0k0Sk83'
    b'OEZFeXI4RzBpcGhCUFhJZk1sL0xBY3pFMmdwUldPUEo3djZSTlduYjVnNlRUSjIwWk1iUk1N'
    b'M0JoVWFyRUwKVUZnQUFGNzV0cEQxRzZlM2FIS0hsQWlNMysxL2gzOEFVQ2h6T201MHFPV3NJ'
    b'Ylo5dTVubDVlWEczajlIa3Q1M3NXd2c0TVJLSmFhZQp6V0FxUmthTS9EWWdJQUJWVTFQenl5'
    b'OG5CVTFQcUpEcjd5NE04d05WMUVnaWhkdlBJZWxWMTJGVERnNGJOa3l1UUpLS09LbXZ1SGx2'
    b'CnVCV1A1dC9ja0d5cGs5VjU2VDc2aCtkZmg0MWNHZWhoR3VwRnVYd2thcXovamI2QlJqNzdl'
    b'U1k4TEkyU01HK3RtYzVjZVJDbURmMzgKbC9qYlZGRUhhMzZDUlZQZ1RwSUZ3WEw4Q085VGZR'
    b'S01uQmFmQmJkekowNWZjaXIxbFNDN2xQMHlidStGcUt0dTlsb3hxVVJnMWlGLwpwUHVsN203'
    b'MEVDOTZiMTlUREJyMTRNR0R5clFGSTBPckhLMjA0RThqQ3dyS2NLOGF2SnFSY1ZGUjg3VVNI'
    b'a0dRa3BLU3BLU2svSlF6CkxpYkpreU9WS2hXZW1BczMwaUxYYkwya3FiS1V5K1Zydmh1MmNj'
    b'b1RYWVNodmhuMlhYV2R1ZVJHWUdBZ0FGeS9mdTNsczlucnZoYmkKMzVJeDZZVXdjNmVqbTFY'
    b'MXI1dkF6aEwrblNTVndicWo4RGlEY1dZREs2U2JrYU83ejVOOEI1MmJQSGtxQUdSbloyZjhO'
    b'WHpPaUViZAp6ZTRSQkg2OEZicHNhNEttazI1OWZmMXZ4OGJOSDU1R0o2dm5STjVyMUxOQ2Z4'
    b'UFhKZUhoNFo2ZW5wcStxTWIxT292RnV2emIrWWFDCjc5ZDl6YU9SUVNLRm5lZm93MmMrQ0E5'
    b'WE80OVNxWFROZDBPMmZQR2NvZS9CWFgySUxwY3RYN2wyRjRGQXFLbXAyYlZ4d3ZxcDZVNzYK'
    b'OGY1ZmIwSjZJWnhZLzlHaHNNK1A3c2JEN3cvaHhIbzlCVmZiQkR1dTlOeTArNmFEZzRORUlq'
    b'bHhhT1Y0dnhNdXRucHNRZ0IrK0NObwo2ZmZKZUx3YXEwOU1UT1RtUkE3dkpWWWR2WnRBckVI'
    b'dm1QYmxiS1BOSXQ2MTd3dWJ6ZDY0YXNxS01iRXFUTzNNYll4VjhCK2p4NHhUCkhaVklKQ3NY'
    b'RHR6eGRiSkJ6S09oQmZiODVqUmo4Ujg5ZS9hVXkrVnJsbis1ZU1oMWxXVXVsY0dpdmRBL0dH'
    b'YU1nUCtSSnR5eTZRUWMKV3d1cXRWSEhoS01QSit6WWZ3Mkx4YWFucCtmR2pKdzlnb2xHR1FM'
    b'QUI2NTNYN290VFZQWmV2ZjJEVTlrc3BjVG9ncFk3SXJ1czNUagpIVE96ZGlzcjNyUGJqMEto'
    b'V0w1bzRzclJ0NTF0QVFDdXhLREpYYVBIalorb050QkVvcFVMKysrZWxXNzZWdXVoM3graVhn'
    b'a1hyOTI0Ckg0ZkRMVnM0ZXV1MEIwUThSTzJFaFpPZ1g5RC9lSzFIalN5WXV4MTJMQVJIRzlo'
    b'eGJlakJFL2VsVXVuUkg1ZE9DZnJWMmRvSTVyLy8KdXMrU3JSa2traHFrdTNVek9vQXdUU1VN'
    b'NUFyWTljZlF6WHZ1RzIySDhhRmNWMm54Rll2R3JKK296dHEvZEIvTkNMdzFjdVJvdGQ4bwpF'
    b'S3hjMEhkZlZQYmJSbmdqQzNaZHRKKzJJRG9nSUdEVlhEZFdTK09tdWRDdHkvKzRiSVI0UWxp'
    b'd0MxQjRpMSt2VnViazVCUTlHVDE3CkJBdjlWbklEQXJEL2Q4L0ZXN01vRkRYVWRlL2VYVGZK'
    b'Mks0dWlNcHEyeDNkZjhPZUp4ak1lM3E2L3gvYkV2R21FdklPeFFBQUFDVjAKUlZoMFpHRjBa'
    b'VHBqY21WaGRHVUFNakF5TXkwd055MHhObFF4TnpvME56bzFNQ3N3TURvd01GRjBZKzhBQUFB'
    b'bGRFVllkR1JoZEdVNgpiVzlrYVdaNUFESXdNak10TURjdE1UWlVNVGM2TkRjNk5UQXJNREE2'
    b'TURBZ0tkdFRBQUFBQUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJpbWFnZTUzMzUiIC8+CiAg'
    b'PC9nPgo8L3N2Zz4K', 'CA_BC')

CA_BC = b64_CA_BC
index.append("CA_BC")
index.append("Canada British Columbia")
catalog["CA_BC"] = CA_BC
catalog["Canada British Columbia"] = CA_BC
country["Canada British Columbia"] = ('CA_BC', '', 1)
lookup["CA_BC"] = ('CA_BC', '', 'Canada British Columbia', 1)
lookup["Canada British Columbia"] = ('CA_BC', '', 'Canada British Columbia', 1)
details["CA_BC"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-08:00","altname":""}
regional["CA_BC"] = ('CA_BC', 'Canada British Columbia', 1)
regional["Canada British Columbia"] = ('CA_BC', 'Canada British Columbia', 1)
#----------------------------------------------------------------------
b64_CA_MB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDIxNyIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01hbml0b2JhLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MDIyMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEwMjE5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwMjIzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBTwpYVWxFUVZS'
    b'NDJ1MmRlWEFVMTUyQTM5SEh6UFJjR3QxSXcyRk01SEFmU3FCczF0aEp2QVpNaXNKWnh5U0J4'
    b'QldIdFVXU3F0UldLc3RXClhLbXRUVkp4VWx0SnlzU0ZVNWhkbjJXbjhEcHgyWUVjYXhKamJF'
    b'TWdXSUFCZ1l3c0pNMk1Sak9hczd1bnovZjJqeEd5RUJJN0VqUEQKU0hyZlA2aWExelBkcjcv'
    b'NS9kN1YzZkRzdlY5dDJ0WG11MnNOR0lkem5aR2YvZnBQTDc1MjNMWUpLQ29QYkZ6NW0xOTlJ'
    b'Ly8zc2FwbAoxeW01T25rcS84ZUQzM3A2LzRHVHhUME1oT0I5ZHkvKzkrOXNXckVvYUN0cTdQ'
    b'bmZobit4enh3WUhGbkdzM3A1MDY2MmppMlBBRVpoCmNObGo3UjFiSHNsWDNKaDZMVnpRK014'
    b'L2Z1MTdqL3hqaWZTNmlZeFNxditwRjhkVXF2RTdYNjlhdjQ2NU1qR3g4di9NTkwyWVVpVVgK'
    b'aXd2NHJVUnFwRjdldGExTnU5cThkN1JPUzcydVVrcFd3ajkvT3ZMazg4TTFrTWQ3UjJ2VHJq'
    b'YnYybGJteCtUcmVmbnBnM04rOGoyKwpybnA0VStiSWlmT2JIajYzL212cHZ4NGRjNSs4WHFj'
    b'T2ZQK3I5Ni9HR0UwaHBUNy8yU1hIWDl2MTJ0NjJwWE9yKzU5NjhkU3F6L2YrCmNQZElxenly'
    b'bDMvaXBTYysrY1krWnRXTjFuWkhPTjN3NkZlV25YeGpsRjc1NlBYLzZ0Vis0UHNQYmxxRkVL'
    b'eHdwUjdjdE9yVXdjYysKVm1ybHBzdi85ck9SdVMrdjFNSS9QRHRlN2p2YkdXRzZUS0RPbDIz'
    b'NDBlWWRlMDUzRDA1T3IwVUxHbDk2NHVIVEJ4K3J6T2cxSEtWZQpldUxoMjJiNUpxZlV1YzdJ'
    b'UTk5OWR2bkdIek5kQ2dmQ2VXMFQ2bklYY1dDaXBNTU5CWjdSOVp2bm84N292ZVE3ekppSmlU'
    b'WFJFWjJpCjZGVWlzVXFoVkI0bTFpVEZLck5lUlJlcmRFb3hzWW9nVnRuMEtxSllwVmFLaVZV'
    b'MHNjcWdWMUhFS285U1RLd2lpMVZTdlc1UXJISXEKeGNRcWlWZ2wwbXZTWXBWZktTWldDY1Vx'
    b'dWw2NlliMzB4TU1URW12cnQvZmxOS1A4U2pHeFNpNVdFZlhxaXlTYkc2c21KTlpIdllQegpn'
    b'dFhsVjRxSk5XR3h2dmpOdlRkZ0pWeTVPUGpBeGxYemd0VzJyRVQzdnF5YzdoaFZ4cnUydFhi'
    b'YkZpUUsxLytvQXNVQ0FHaWQzWkU5Ckwxako5RldpQzN6dDl2dXZNOEhYRjBtKzlyK25qeHov'
    b'a0JBNjZmUDlseGQzTTJNS2RZTlNXZ25IVWJoWUZYdVFqS3QrNnF3S0dFd3MKeHRSSmhVZjlT'
    b'MWt0TUZqRVlqQ3hHRXdzQm9PSnhXQmlNWmhZREFZVGkxSHBjS3dLS29RMHNOKzZ2YVhhN3kr'
    b'd3ZHRlpaMDZlZENBTQpBTkNJdlhqbENwSGpDOXczM2hmZWZEck14Sm9SYUpUZXMvTWJkOTIz'
    b'b2NEeXFWVHF6N2ZkUFZzbkFJQStEcTU3OHVjMU5UVUY3cnZ2CkJ6OEVwMThwclZoVFluNTNo'
    b'a3hDMCtuMHdCVVdLaW9HU2lrVGkxRUNZR1VzWVNwT0tuendXMDlQdmlKR0xQUWJyMHpteUlu'
    b'WTg2OFMKdzd6cVc2dDhqVzNiSEF2bUZ1czBpRzdFWHZodDVzaUpVZHVscGJmVjc5aUszVkp4'
    b'RnZxVjhrb1FBUHE2dWp2YlR4ZFlQcFBOQXZEeAp1WFI5Y0M1WmNNTS9rVXlXL0VkeTQwdVR4'
    b'eXVUUGZwKzZLZFBqWHJvQXhmdzErL1kycmh6Ty9hNko3MDArVHJmR1A3bGY2WCtlSGk4CmI2'
    b'emtwY205eERndVdQZVlZdUc3U0JBaEFBRUFCRkJsSW1sMGZ5MytlcnpDeENxS1VrVzVtYUw4'
    b'ZXBWVXJNdEVQK2NBR3d3UmxKNFgKYXZHMm1GMHBiYXlSejVjYTc3cG1qNzdmc2VXUmN4c2VH'
    b'bWtWRi9BMy9ldWp5OS8vZmZPdXRndlI3RVBmZlhiWnhoOC85K3F4U1dRbApTdW5yYjU3NTFP'
    b'YkhOKy9ZOC83WjNqSExlTmFzYUhsNTk4S0R6L2p2dlhONG81VkloWDc2VlB1Sysvb2UzOU5T'
    b'NzVtS3ovZWFZbTJzCnNrYXAvL2lmb2p3SGtCRDYrcHRuZnYrWEQ2NXpWSG05UmtXdnZGN1J2'
    b'Uy9YNzlqYXNuTjdSVDJka0FMUXc0TjJqNlB3WFZvU21wTUMKQUlBR2FFZTFzL0FkQjBFT2dO'
    b'SSswbXdDdDlqZllPSXJ3eTMycFU2T0pVMkZZV3I2ZnZXRHoyemJXbUQ1cXdkSTZicnpoeVkw'
    b'UUxwNAo5eXMzSjJKVldwU2FFZEZyR2cyUWNsTlhxZW1uRnlYVFZLeXBxTlMwMG12NmlUWFZs'
    b'Wm9HZWxFQUxueDQwWFBrOExYLzVSU2RQT0lBCkFOZ2pBVGpVNk01a01wZHNWU1VBQURCZzAy'
    b'QlhWN0xnWWMrMExKZjZkQ0NldjdOMHpmUHJVNFpYbmhTM2FYOGsvbmJwcmtTSUdtMjMKUkcz'
    b'ZmpRNS9PTzByajdDRzQvYjdhcUpvVDdTdXRHSjljREc4YUVIanBKVTYyeG41MGU0RCt3K2Nu'
    b'TVNnVk5uZXBZTVFmR0RqeXNlKwp2Zkg2WjNwOXZjNTJSdVJQcnkvZGxZaFNjK2VTbUZremhs'
    b'Z0JubHZqOTRVVkxjZ0pIb3BORHJ5clp1T21xVTgyZFFZN3daT2hodEttCnd2SHFlcW9rdmdL'
    b'VDQyL2UrUHYrQXlkdkpEbmV0blA3aVZJZUpBSVFqZlhiREFxT0wzZ0RJR2V2RHRacE9TdmFv'
    b'N2dGdElHNE1ZOEEKb3JhSVk5UjZPNWROR0VhbDl3b3pSMDZFSHQrVGVlZkVLS1VhdjdtOS9w'
    b'Ky9oTjNTRkZKcWNtMnZ6RHNuUW8vdkdaN1NIdFlMbEZZcwpBTW5vNUxYVzdWL2o5aERWRk4w'
    b'Y2hzRHA0dVorMHEvSlpsT1RtOUtoWEdkYXBDVXRuWkdWWXdPcGhGM1FSQTJpNVJXcnNMYlVL'
    b'MVA2CkpVMkY2T1c5bzlYNytyNXJvMWRKRHd6RG9ZZzFXM0RjNHdtNEpjaWJFQkNxcExSc3lw'
    b'aTN0RXJWYkFRaGdFQjA4eFFBaENDSElhVUEKUVRDblJwcFRMZDBYck1zYVprSTNMOHU1azRP'
    b'WkQxWHQ1a2VzNlpUNFN0cHpMSEhIa0xhNmZXdEZqNXpSakJ5MkVMUjFnUUNCRUozbwpSTmN0'
    b'QUNFbFZMQXA5RHRFQWNLaGFSazgzSzkwaUtoS0V1ZjZwWFZOMVYwcDlWZzhkU29sWnkzN0pv'
    b'aVZlZWRFNkNmVE1QRVZQemxlClUwdEZIMjRBRUt6a25XcFM5N3FGL240RkFIRHJrZ1dhSXN2'
    b'cDdHQllyWjRqV1pxRk9PeVdPQVRCRmFzb0paQUFDcTVrUmc0RG5rT0UKMEZzRDBpMSsxeGFM'
    b'aG1UbHVVdjljZE1VQWREeis1VCsxVWZzYVRPVlFvTGFqeTRjK01xODJsemNRQWdoQktvYlBB'
    b'M0JoUmZQdEhPYwpMVG94aEZEMGNHckttdFVrZWYwQ2dnQUNNS292VGlpRkFJbzh3aGptWmRV'
    b'Tm9tbFd6alovMGRFWDFPMExrS3FBbHFOWHlLNW9oVUFCCnBRQWtKT0NYc2VEQWpYTmNGc0c5'
    b'WGUxZUw2aXE4K1FVSzlTZGJXbXVKcW9kNlpNTjIrbDJDeGhEQ0FDQ2dGSmdFMm9ScXFRTVU3'
    b'V0QKOHowWVl3QUFCTUN5YklRUjB0SDYycXB3MzZBVEFwWFNVaTl0QUd6TmV5V0pCUUNpNS9W'
    b'Y29NSGxjR0ZadGhOcGc5aFVrZTFVVEkrSApWWWVUeXlZTnlTL1d6SEtGTG1VdG0raUdyUm0y'
    b'cXRzNXd6WXNRZ2hGRU5UUGx2REhiL21qcGswaEJCeUdqWWhYM01JdFB0Znd0ekd4ClpvcFlG'
    b'SUJMc3RvTERVMG02WmdHVkZOWExRU0FwMEgwVlFuK2dDQUlpRmlFV0pRWGtaSTFSMzhDb2Jw'
    b'cTh4emt1S0hMYXR2VXRJbVcKTTZNaHhldmdqeW01Rm8rRUlDakRQUnRNckVxS1dCQ2FoTzZQ'
    b'eGtnejM5RGs5bmlGV3haVjFUZEw4UzRaY3pBWjFiSUpuUk1SNXBDMwpTdXp1U0kzeXc5UklU'
    b'ckYwalpnMk1TemJ0T3lNWW1HSUV0R2NQS2hqRHM2WG5DYWtIb1NaV0RPcmpRVW96UnYyaDRH'
    b'RVlWUEp5eVVqClN2ZkZWRHFsUnlLcXI4YUJNZXJ2a2lHa0NBRmVRR3JHekRla01JSUNoMlJD'
    b'TG5OR09xc2JCa2xseldUV3RBa2xKa2tOYUp5QTBsbmoKY3cwQkY0Y3lkamxHSDFqanZZSWlG'
    b'cm55TSs5VnRiMWF1RVZ3ek5jNVlBT2VReGV3b2NSSU1PaXU5cnJVck1YeldQSUtIMTFJdFN3'
    b'TQpCR3BFemFaLzdJc2RHa2lhaElheHRhM2F4V0ZrRStJUThmbDRHbERRZktzdm5UTi9mYW1u'
    b'Zk9OWTdJcFdVQ29jT2ZwQXJQYzAyUVBjCmZoRVBZT3NTMUQrQ3BoblQvZ241QXRVaVJNQWZF'
    b'Qk1EdVZDZjNKWExIVXdrK3JXaHVjS2pnNWs1a3ZNZkdnTTJRUmpCdHpPWk80TmUKaktHL1Nn'
    b'VGRZMzhYUzRYVHYvRStpc05BT1lUa1ExU0pFanRDVFV4b2h0aW1TUkdQTVlLQlJ0ZTd0dkpN'
    b'dUgvWXFqeXY5c2JhQnpPUQpBZ0FBUXZEWnlFQUcyVzZSbSsyNGNtOFpaR0xOck1iNzZJMGFv'
    b'SEZnVzFlVWkxcm1ZU0luNHRwZ1ZJVVlpaElYaHVhMU9wcVV2QmROCnhTT0tZbHArQVN2RURp'
    b'azZJZFFxNHkzOFRLd0thcndYTXRQU2J4dDFUUzQ1YmZSMVozVktmUkNQV1d5eDI4VkwvTDZM'
    b'b2NPeE5BQkEKUkxBN3E0WjFvMnlwa0xXeEtpa1ZGaEJSMWxYNWErcGNkVFdPaTZITWM1Rm9t'
    b'bHJYbGxubWsxcHJmRzlFWWhleWFuNExEMUcvYW96WApubU5pVFdzZ0hETml6WkxFTHdmcTZr'
    b'elVUOHczazhuYlhaNTRXUEhYT3k1bDlXdXQ4bko0UTFQMU1vZlVsVkhlaWcrOUlBMEQ0Qk81'
    b'CmtLcVg4MnlZV0JVVHNTaUFFSTZNSlR2cUdsdzZhR3FTbkJUYUJwM25FalpTbUVvYmJvay85'
    b'ZTRBNTRPdHRkNlFvbWNNUzdIc3ZFQ2YKYy9qbTJrSnZUN1lkNUlZL1ozMWpqVWZnbEJIRFYy'
    b'VlkzY0RFcWhScUFhNUp3SmdmMURxRU5UVytaa2xvMW5oUFVNUVlRUWhjSXM3cApWazJkSzBD'
    b'cGFkSlZuNjV6T2ptSGs4dTM5OU9LYVpva25kWTExZXp0bFhHVENBMStqY2QvUEpwYTc2LzZW'
    b'TFhudnp2REhSbEZSTWpGClk0bkhBYjNrNjVqWnNwa0s0bTg0ZDZCUnZldXpqWFA5RGkxbllR'
    b'NmFCakYxUWdIZ0JZUjRaR3JFTm14UG5RTmh4SE1RQXFxck5pY2cKaDhnWmhwMlRUWTlQUUR3'
    b'eURFSk40dlJ3Ri9veUpFZGt6UW91OEtLa3hVRjRQcTcyZHNnUGREb2JUTXpFbWxtY0ZmUy96'
    b'akdxUHVINgp6SW82RGw5SldnUmtrM28wcEZnR0NjeDJVMEp0a3lBTU9SNUJCSFhGeW1XTVhN'
    b'WjB1cm41U3dLVVV0T21sRklPby96eUdjMGdoMDVHCnM1MjUrN3VkallRdncxa3dzU3FVRkxS'
    b'L04wdk5OT043YjYrdjlvcTJTYkpKd3lseHZJampFVldWTGFlUEl4UUlMazdQbXFaT2ROVXkK'
    b'RkFzQU1IOXBRTTBhYXRhU3ZIeWd3ZGtYeTcxM0t1N3R0TDRRbFJ5d2ZLTkxUS3lLeGdMMFFK'
    b'WFNNdzh1V1ZxMWNMWjNvRWZPSkhSLwpuY01iY0toWkF6Z3dRakFiMTFMaG9hWTZRbkQrc29C'
    b'dGtXaVBuRktzUzJGMWFTZThYWFhkaEQ0dUUydEtjQUViZndscTRnTEgzU3ZxCjNNNmhMcGR0'
    b'MFZoVVZRWjFoS0ZUNGwwZVh2SUpTY1Y0cXowR0w1dWJMenZxeTVMMW1GaFRuaHdsZi9hcm9T'
    b'YmdiQmJ2WEZycmxUN3UKMUVjR2MzODduelFpUmtzUFdpYzdjUm1tQTVsWTA5S3dJNTVjVHgw'
    b'eFBRZ1FJS2JJb2dHOFNyLzVQZzNEeHJHbUpFNkk3cEVsSUZmdQpFYkpKYUFZVGk4SEVZakN4'
    b'R0F3bUZvT0p4V0JpTVJoTUxBWVRpOEhFWWpDWVdBd21Gb09KeFdBd3NSaE1MQVlUaThGZ1lq'
    b'R1lXQXdtCkZvUEJ4R0l3c1JoTUxBYURpY1ZnWWpHWVdBd0dFNHZCeEdMTUVQNFBwbmNpVGk0'
    b'bW9VWUFBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmwKQURJd01qTXRNRGt0TURoVU1qQTZNRGc2'
    b'TVRBck1EQTZNRENtcDAzbkFBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl6TFRBNQpM'
    b'VEE0VkRJd09qQTRPakV3S3pBd09qQXcxL3IxV3dBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAg'
    b'ICAgaWQ9ImltYWdlMTAyMjUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'CA_MB')

CA_MB = b64_CA_MB
index.append("CA_MB")
index.append("Canada Manitoba")
catalog["CA_MB"] = CA_MB
catalog["Canada Manitoba"] = CA_MB
country["Canada Manitoba"] = ('CA_MB', '', 1)
lookup["CA_MB"] = ('CA_MB', '', 'Canada Manitoba', 1)
lookup["Canada Manitoba"] = ('CA_MB', '', 'Canada Manitoba', 1)
details["CA_MB"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["CA_MB"] = ('CA_MB', 'Canada Manitoba', 1)
regional["Canada Manitoba"] = ('CA_MB', 'Canada Manitoba', 1)
#----------------------------------------------------------------------
b64_CA_NB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTIzNyIKICAgd2lkdGg9'
    b'IjE2MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05ld19CcnVuc3dpY2suc3ZnLnBuZyIKICAgeG1sbnM6'
    b'aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUi'
    b'CiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RU'
    b'RC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5'
    b'OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1s'
    b'bnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0i'
    b'ZGVmczExMjQxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3'
    b'MTEyMzkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTEyNDMiPgogICAg'
    b'PGltYWdlCiAgICAgICB3aWR0aD0iMTYwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBw'
    b'cmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmlu'
    b'ZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZzti'
    b'YXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtBQUFBQmtDQUlBQUFDTzFLellBQUFB'
    b'QkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFk'
    b'VEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUE3Cjkw'
    b'bEVRVlI0MnUxZGQ1aFd4ZlYrNS9iNzliYTlONWFsQ2lKVlVWRlFGTEZFN0NXeFZ6U1dXR09p'
    b'OFJkRnJMR1gyR01FdTJDbldCRHAKU04wRnR0ZnYyLzE2dTkvdHZ6OTJxU0lCSmFMUjgreXp6'
    b'KzV0TTNmZW1UUG52T2ZNWExMRU5RUy95Zit1VUh0MWtXQ3dYdlczeHZvbApDdlBkUTY3UjhZ'
    b'Snp1bldKYXY1SFFjNkpJYVdiNjNyRFZ6T3pzZTZtTWoxTjc5L2kzWWZGNUM0dVhTOEM0TEpV'
    b'KzZCVWFLRUxnRmlhCnlYVHlwa0wyM0RtRlBKbXhHN1JWcHl3NnhaaVV4WUFKeG1vUXhqUlVB'
    b'b0F3Smd6b0tWcEwwRnFLVm9OTXBvMDNEYkxuV3RGV2czV3EKbVU1Kzc0Y0pZOVcwQkxQN0pu'
    b'Wm9XcHo1R1FFY1hlSlFlampYNkxoclJGSXN6bENzQVJQdEwrZFlLeVdLTjZQTDdUKytWUHVR'
    b'bE5RawpGRjNjWmF1UkdtY1dlbytLNUp3UTVndmt6YmVXT1VjazNHUGpZb2xjZTMzNWQyOWtz'
    b'MVQzeUlSOVVFb29sb1ZDbWJIcDM3MUdpekJTCkc2OUdXS1diTVUxaWFPQzhxcFpnS01FQU1S'
    b'bUhUbHQwcUZTcVFZaXZzNlkyV1dEdWZEOUI2VFh0Z1hkOTZOejFPT3ZTTE9XWmRBTnYKR3BR'
    b'VzM5N1hzNDhMNTAzcmFaeFpwTVpvUFVHcFVSWTBzbzZLaEw1d2lrVnk4V1ZkelkvbjIyclN3'
    b'VS9kcHJhOWIva21STFVFcmFVcAp1Wk5qM1hxNlVmaHZBRXkrYnc3bXN0U2hMOWNwUVRhNjFK'
    b'N2FiQ201c2pQNmpTUFZJUHJmOFAzSUlxMzlwTUx6L0t4WFN6ZUp0RlVYCkN6TnNsdHI2ajRL'
    b'Y2FVRWpRMEdIR3FQYlg4eVZXblo2WVQ1UEtUdzM0RGtpWnFna3V0U3VwMmhUSVNEUTA3U3BF'
    b'U1hFV0tzbDJxWlQKak9FNUxMN2JjazJkNkNsS0NYREpUWmJrSnBGemFaWitHV3QxT3JuR210'
    b'b2lLa0hXTkFqclVUMkh4NlI2SWRQRitkL1ovcWFFTTcySAp4aXpWa3ZlSXFLa1QyYy9xQ2Jw'
    b'aFJyR2VwaGlINWh5UkxMbXlrN2JxbmEvbStJNEpOOTFmR0Y5amM0K0xGVi9zMTFLVXJiK2t4'
    b'aGdZCkpMbEIzSEpYaWFrVEFObFRRcXhiTC95OVgwL1NEZmNWbGwzWDBmUlFRV1NSYzc4RFRG'
    b'OGs1T3oyaEM3VERHODZocWJFRXJuMTJieWMKRTBLR1RKSWJyZWtHOFFjWDVqZ281UnlSc0pS'
    b'bUNBMzNtQVJVT0ljbldiY3UrM25Hb1R1SEpYcys5cWpkckVtSXRTTERlclJ0WlhGWgo2c0JI'
    b'R3V4RFVnRFVJRXZ4cHRRa1pOcUUxR2FMM01YcktjbzBTZGNiMmI3RFk4RjVic2VRRkcweGVt'
    b'K1V1N251OTcyQmQ3eUI5NzFkCnM3STdaMlYxei9WcE1Wb3NsdTJEVTQ1aEtkYWxjVGtxWVUx'
    b'TFdjWStKTWw2dE5oS0c1ZWxCZDczNm1tYXR1cDhyc3BscTN5VzZqc20KNGg2VDRMd3FZOVA1'
    b'WEZVc2xoMURrOGs2aTU2Zys5M1p5cm8waWpFZHc1S01YZmRPaUxJdVhlN2lMSldTZllBRWdC'
    b'WU1XalRFWXBuegpxVWFHaGtZbzBTai9ZenNJS003MGpJL1RGc005THM0NGRFdVpMSlptTE9V'
    b'WlBrZmwzSnBwUWsvUiszOEUyL3FueTY1clQ2eXo5bnpvCktmMWpSK0picTNOa3dsS1JXZlA3'
    b'Nmt3Yi80TUhidW0xN1l4RDUzeXFIbWQyYTdXMVBaZGJkSkVmZ0JxbjExOWFwWFJ6dmNmelR1'
    b'c3AKdnJTcjkrL0kxODdOZDVUc3RnZytSeW4vVTN0NGtVUElVOFFpMlRZb1RWdjZkTGllcEtO'
    b'TEhXcWNvbm1UNGd4S01OUE5mR0tkbFZEZwpjaFE5d1lRK2QvYnFZYkZJeVFUWW5DbWhySWtS'
    b'c1RSRFdIUFA3MlVvaE9MTWZXNE9BOXIzR0RRVVoxS2NzZTFmcFlkTE53aVJyeDNoCkw1emF2'
    b'b085SzhDMi9tbjcwR1JzaGFQNDBrNVRKNFExWTh2czJ4clgvMFpXNjdPNXZVcG1YNlhndkVE'
    b'T2xIRFBSKzdzcWVIdWo5M3AKT2t2aHhWMUtOK3NZbW9JT1BVUFQxajR3d3ArN0RBMk45eFZ0'
    b'SzhoM2RLVGlsclkrcU5KMHgwczVQWis0dGNSdTNwYmlEVnROV3NoVAphYWNpRml1V3NveFFM'
    b'TWRYVy9VRVl4dVE3bmcxeHpzaEFvTElJcWZjeFZxcU1wYXlEQzNxTUlscFFrdlFhZzhiK3RK'
    b'cHFxVHc5d0ZECnB0UVlyU2NZVXlkNm1nSmc2TVJJVVNBZ3hOUlNqR21BRVhWQ2cvREc3a0dV'
    b'cVQyWVY0UTFxSzI5eHpTSWtkbnEwWmd3ZFJBS1lBMXIKVmNZOU5tNGZtQUtnSmVuV3AvSjZQ'
    b'dkw4S0lDZHc1TjZpcllQUzdoSEp6TWRMQXppSGgvYlpzdG9DU2E1U1d5YVdhZ0UyWDBGT0hk'
    b'YQpqNUNqT0VZbXhRSzVhMVpXYXJNb3RRak9FWW5peTdwNjVucXpqZzloYTdlcC9WTlo2UlZk'
    b'YXkvc3Q3Mld0Rm4xbHhiSHdjbmdaeTVHCk5CMkhKQmlybm1uajFEZ0R3TWhRcGtZSURVclVh'
    b'Y0dnZU1QVWlaWmtFbXV0NFMrY2Vvck9QemNnbG1TNlhzOHV2clJyMDU5THZlTmoKSUNZb01E'
    b'YU5zS2FwVUpSZ2FFbmFrQ2hkb3RVd1RRaE1neERXcEVXRDBDWnQxV0VRU2pSQW14UU53dXBh'
    b'akNFVTBTVmk2c1RVaVo2awpLY0VBb012YjNVN2FvcE90L3hIR0pMUnBLcFJwYnUrSTI5QWxO'
    b'QWh0R2hxaFdJUGlEVm8wS05HZ2VjTTBBUkNwaFZkNjJNTHpBN1JOCk4xUlNlMjJsYzBUQ1Bp'
    b'UkZhRlB4YytIRmpzZ1NCL1I5TmJJSUNHZG1Ud3JURmlPeDNscDFWelByMG1RLzEvcFVYdFZm'
    b'V3pLZFhPT00Kb3NSNjY3N1o2dzV0OEROYldKZEdXRk9Oc2oyZnVQMXYrQ3lsbWFLTC9CMnpz'
    b'bmlmYXFoRXlGTnlUZ3hSZ3RINTcreTI1M0ozcWhGdApacDhROW95UG1ncVZXRy9WSlFvR0RJ'
    b'VVlLclhObVRmU2xCYW5UWTFRdkduQzVEd2E1OVpNQTdGVmR1ZkllTzhnYm40ODN6RTBxY1Zw'
    b'Ck5jVHFLVnJQVUtaSzhETVdMa2ZOUFRuSStWVFArSmdoRTRCRWw5bFRXd1RlcHptR0owMGRS'
    b'cG9PZk9DSmZ1M1FValRGbTRaTTlzcUsKQmlEa3l4VTN0eVUzaVFESlBTV1kzR0RoY3RUa1Jv'
    b'dlN3MlpQQ1FmZTgzYitLMXRMMG50dFlTV3IvdHFpQkZrOVJkc0hwUURvYVNyZApJQ1RXMmFJ'
    b'cmJZek4wQ0owMFlWK3NUekQyUFNlVDl4TkR4WHU2RlJzSHhtaUlaWkxZcEhDK1JUV296RXVq'
    b'UkRvU2RyVVFZa0dDREV6ClJJMHhXcFRKQkZpcFdjaTA4d0FvMGNpZUhJNnZ0cVdiZnBRM1Fs'
    b'aVQ4MmkwVldlc091Rk54cW9Eb0t3NklRQnRHZ3BGS0pOUU1CU2kKSldnOXpxZ3hXZ2x3eG8v'
    b'clE1YXl6T0RuTmdOb3ZMK28vTHEyNkJJbllRMWFNTUpmT3lKZnVReWRaQjBiRmt0azI0Qmsv'
    b'VjBseVRyTApYZ0ZNaVVidWlVRTV3SExaR3VQUThzL29BV0RJSlBTRnl6azhXWDkzY2ZXOVRV'
    b'YWFqaTJ6eTM0MjNTd2theTNmcDdmRklybDBlb2Q5ClNLcm5VemRqTjBJTEhSUm5GcHpiM2ZP'
    b'cG03SHFXWlBEakUxUGJyQlN2R0dwbE9RQUYzalA1NXNZYm44aEo3SjR2N29OTlBhZ3lyWVoK'
    b'T0h5dXdyZzAxcW14Ym8xeGE1UmdRQ2N3UWR0MVBsdXhEVWd6OXYvd0ZDTkQ1QUJ2cWhSdDEv'
    b'aHN4VFNKRnFmMUJLM0dHVFhDNkhGYQpUZEphbE5IaWpCYWx0UlN0UlJtNWh6VWthcmRxenow'
    b'bWtYVmN5RDRvblZocjdaN3JzUTlOTlQxWUNFQW9sSDBUSTY1REVuSTNsNjduCmJZT2t4R3Bi'
    b'NTZ5c3ZmV0RQZVBpbG1xcGE3WVBCQU5tTmxxcXBHMm4waTJDa2FSc0E5Tzkxa0Z3dml1OVdU'
    b'UVVpckFHREVKbzA1QXAKd2hxbVRta0p5a2pUcGtaTUUyYUdjbzZPMDZLUmJoSnpmOWREMGVh'
    b'NlM2dGNoOFp6VHdyMUdoRzlWa25IcTluVy9tbkg0UFQ2S3lybApMbTcvT1B1TXlYazEycVl6'
    b'TnAyMmFZek5ZR3c2WmROWnAwNXhocUVTVTRlcEVsREVWSWthWWtDQkVKTXdKZ2hvdTg1N05k'
    b'YW5jbGtLCjU5T29IZTBwQTRtTjFsU2RSUWt5dEZWblhScmpOR2k3Um5HbUhxZDFuUmhwU284'
    b'emhKaTZTcGthTVEwWWFjclFDVlF3THAxMWFwVE4KNE54cUx4bEhPSk9ZcHBhaURZVVlNa1VJ'
    b'T0ovSytsU0tNMlUvRjF0bEM4MXpGWjdUdmVrdnBiMFczL2J4VTVZUjhoUTV3TzdXZy8xZQpn'
    b'QWxsOWxKNmZMNTgwTXViRFBVL09BTkdobEo2V0xtSFZiczVKY0xJWFp6VXl1c3BtclpyT1Nl'
    b'RXU5LzNxZ202ZEhxSFkwaXFhM2FXCklWRjVaL1MwUFpmckdKNTBISlRzK2RBcnRYSUZaL2NR'
    b'emd5ODc5R1RkS3BlY0k5TTdOWkZJYXlCSFJRZUlTQTBBSk1RbU9qOXRYVzgKR2pCTm1EcUJB'
    b'Vk9qREkwUUFqMU5tWUNwRWxNbHBrNWdndldvakZOblhScnIwVmlIeG5xMFhvdHB6NkwwY1BG'
    b'dkxXcUUxVE1VVEVKUgpCbVUxVEpOa212bDBDeTgxaUlaS09LL0d1RFhHb2JGT2piRVp0RU5q'
    b'N0Jyck5DaXJEb1BBTkEyVk1sV2lKV2hEb2JRRVpXcUVaazF3CnBwR21kSWt5VlVwWENFVUFD'
    b'dmFhdEhWWXNubG1ZYkxXc24rWXJPMWF3cTdWM045VWYwL3hvS2MydzhRMm1HVS9aOGlVV0pM'
    b'Wmc2c1gKWGU1b2ZqVGZVcG9SUytYQWUxN3JnRlROaktiUUFwZi9qU3cxUWRPOGtYZFd0NUNu'
    b'TkQxY1VINURlM1N4QTdRcHRmS1J4VTVMUlViSQpsd0dZQmd5SjNySGJzVjZ0MXlnbGpHbnFo'
    b'TkNBYVZLaVNZczZ4WnUwcUZPQ1FWdDEybUxRRnAwU1ROcGkwS0srVjQxaFFHcmxwWFpCClQx'
    b'R2dZSzJRTEdVWjdNWHNxVWFaNUFaTHNrNlVtZ1VUeEZvaFdTb2t4bWtvZmpiZEtLU2JoSFNq'
    b'cUlaMzd5OVJ2TUZscTdURm9GaUQKNGszYXBoT0FzdXFtUVFobDBvS2hKV2cxd3FoaFZtcmxH'
    b'WmRHQzBhdlZmSER1ZWhkcWQwRTAvRkt0dFRNU3kxQzA0T0ZOUTgwMEtKaApLS1RuUTA5MHVi'
    b'M2tpazZhTnl6OXBOMVM4SzVSY2U4Nmk5VEM1NS9WSFZ0dHpUbzZBaUMxeWVLZEdGRWpqQlpq'
    b'SWw4N1l5dnNOZmMzCldQdEpSb2F5RDA0WkttbDhBSnhIeTUwVzVEejdNNFJsNmtTTk1xWktD'
    b'QUhyVVhlakhpandCUXJqMHRVZ0kzWHlQUjk3VXZXaWEzUTgKZDJwb3oyT2FkV251Y1hIM3VI'
    b'aXY1WmhZYTQydnRTWnJyYVpLK0Z6RlhwUDJUWXhTbkdIb2ZTcEU2V1l6clVLbWswczNDNFpN'
    b'N1ExMwpKT1FxcFZkM1dQdGxUSkNHZXdvenJmeCtBeGhBZUpFVFFHeTVQYlZKREMxMHF6MU0z'
    b'cG5kK2VjRURKVnN1YXVFODZtV2NpbjNsS0RzCjV5MWxHY0lhQUZpM1JoZ1RRS2FMUzI2eVJC'
    b'WTdXTHZSOVVhMmxxQmpLMjJ1TVhIWHlFVEhyQ3lhTTdLUERWdjdTUUFpaTV5dHorVzYKUnlW'
    b'bzBVZzFDSVF5ZnhpUWhrTDBGQk5mYVpNRHJCcG1UUk9zUjZORjNWQXB4cTRSQXRxdVc4cEFX'
    b'TEJPamVLTjhDSm5ZbzFGU3pLYwpWK1Z5VlZ0VjJsb3RXY296dEdENEprVVM2NndicDFlVVhO'
    b'WFYrblN1a0srVS9hbWRZdmNFTm0weFhLTVRydEVKQUtaQ3BIWmU2ZWJVCkdLTUdPVjJCdFZM'
    b'eUhwSGNjVjdMdEhOU2k1QnVGYVFXUHRNc1NPMzhqc0VQUGsreFZrbnVVUWxESmFHRnJwNVBL'
    b'RU1sbGJlM3REeGEKbUZobjJUOHFla2ZuR0NhY0k1S3luL1VlSGlPY21UTTFLTFVJN1MvbHhG'
    b'ZmJyQlVaTFVsNWo0b21OMXFkaHlUU20wWDN1TGpjemJhLwprR09yU2RjODFLaW5xYzEvTGtt'
    b'c3RSVmQ1STh1dFdjZEc5RVNWT2VyMmFYVE83MUhSVnNlSzRndXQvVXFIMHU1VkhCZXQzTjRj'
    b'aHUzCjlSOVZxNmtUUFUzTEFWWkwwVDF6UE9rR1VVdlJybEVKMjRBVXhaaEtrRTNXaW5JWEwy'
    b'ME5RVnFycGF4andxNVJpYWFIQ21JcmRvMlAKY1Q3VlVDa3RSbE9zV1hGcmE3cEI5TC9yTGJy'
    b'UTMvRmlUczdKUVd1MTVCcVorREc2SkxMWUlaWmtFaHV0WXFFc0ZzbjBEakV4STBOcApNVVpM'
    b'VUxSb1VvSkIyL1hvRW9mVXhQUDVzdVBnRk9kUm0rNHI4aDRWc1E5TjlYemthWDR5MzVUSi9n'
    b'TjQ1eWFnN1RwcjB3c3Y4QnNTCmJkSm1iSWs5OG8xRDluTTdXbmRTa3dEQU1UeFpNN01SZ0tG'
    b'UVhiTjhuc1BpN1MvbFNPMUMzclR1eGhsRmVhZjNtQVppeSsxRkYvbHQKTmVsMGc3RHA5akpU'
    b'SVlPZjNXd3B6MmdKbXJIcGhrb294dFJsbXRBbXhSbTZSS2tSaHM5UnRRUXROUXRTazBBRUk3'
    b'bmVrdHhnTldUSwpjM2pNUGlTcHAram9VbnRrcWNOSTcrcCtGUDQra0hkNk44V1pSb1lLem5m'
    b'SFYxbWpxK3o2MXZBZjY5V3NWV2srUzNXTVNHcEJsaS9QCk5OeFZwRVpZeHFhWFRPOW9mU0tm'
    b'ejFYS2IyZ25uQ2tVeUQ5TXdRVGU5NFUrZGJuR3hUdGV6bUY5YXVubFhaNGpvbnQ1ZTlNRGhm'
    b'bG4KOS9DNWNuU0pQYkxZR2Y3Q3VXY3E0bnVqU1hzV1BVMXJVVWJ1NXZRazQzL1htemN0MlBP'
    b'UnQ5OWZXdmdDT2Uva2tHdHNJdFBPUzAwQwpKUmltUm1RL1o2dEpDd1dLRm1kY294S3BMV0xv'
    b'TTdlbFhPSnoxUGhxbXhaaVdZZWVkM3JRY1ZDS0VOVGVXSzRuNmJ4cFBZNWhxY1FhClcyaWVH'
    b'd1RwQmpHMTJhSkxWR2lCaS9OcThWWDI0S2NlUWhCYTZBck9jMGVYT1ZLMUZyRkl5VHMxNkJv'
    b'VFQyMjJkUDByUjJvV2toc3QKMnduZWJZenB5Y0dpaS8yRTduT2ZySldTRW1ZbzF0d1duVFFW'
    b'WXF1V3NvNkoyQWVuN0lOU3pROFdwQnZGM3Q1cHlsVDVqZTA5bjNpawpKaUc2ek1IWWROYWp3'
    b'eUNFTWFVV25yWVkzWE44bHZLTUdtVUM3M3F0L1RPRU5ucys5bENNd2JyMEhTZzV5SjE4WUk0'
    b'M3NjWUd3RWpUCjRhK2NZcjRjVzJtVE8vakVPaHRBT04vdWpROHRTVVVXT2JPUEN3TVFDaFZi'
    b'UHltNjNLNkcyQjhDTUdQWFMvL1lrVzRRYlZVUzY5YSsKajhTUTJuZ2pRNmxCTHJyTUxyVUpn'
    b'WGQ5V3BKSnJyZlNGc05XazRaQnRCUnQ2eWZGVjl0Y0l4T3RUK1o1eHNlMEdKTnFFTXV1NjdE'
    b'MwpUK2VjRk1vNUplUWFsUkNMNVBEbnpzMS9MVldETEczVHhXSTVWUzlLYlh4OHRVMzI4NHhk'
    b'Yi85bm5wNmhZOHZzMFNXT1RBY25CN2pJCjE0NVVnK2dZa3NvN3JTZDNha2dKc3AyenN2MXYr'
    b'dEwxb3FFU1M2VlU5WmZXeUJkT1E2WjJ0SVJMcDNkd1BtMG5VaGFRZzV6VUxQWngKbGlhaGJJ'
    b'Yno0SVNRci9RNkMvRnZiYjNYWmpwNE5jeVdYdHVSMkdDTkxuYUV2M0pwVWFiblk3ZVJvR21M'
    b'MGY1Y3JoYWpPMTdPSVJTaQpTKzNkNy9rbzNqQXlWTU85eFRSdnNHNjlsOUkzRk1yL3RxL1ha'
    b'MldzdW1ONDBqVWl3ZVVxMW40WlFvUFBVUWx0c2k0dDhwVXJ0TUF0CisxbWhRTm5HV2hzS1pS'
    b'MllJb1JRbktsR21iYm5jd2xqWnRxRUg2aWloUUpaS0ZROFIwVlRtOFhnUng0OXRWY0pYUFpC'
    b'S2NmUVZDYkEKOHRtcWEwVEMwaytpUmFQaG5xSlVnMGhSNXFCbnR2VEdpQUx2ZVhOUENlNXly'
    b'OXpKcmZsRE5XUFZ3Wmc3ZGt5S013eUYydVlwMlFhawpIU09Tem9PU1FwRWNXMjRQZmVHTUxi'
    b'UDNoWjRvd0VTdm5XSXBsN2hzMVQwNklaVEt0ZGYyNVljVVhlRFBPNk1uL0tYVFVwWVJTN2Y3'
    b'CmVGMXZaTFUrblFjVFlNeWM0OElGNTNhekhoV0FscUNiSHlsUVkweDh0YTMzc2F4WExUaTNt'
    b'L09xUFIrN284c2N2ZDJDZFdtc1c5c3oKRDhyNVZLRkFZZXc2NjlLRWtneGhURFhHcExjSVVy'
    b'TWdkM0hiRW9sWXAyN3RuM0tOVGxoSzVPWkhDbWk3TnVEaGh0NCthaWhVL2QzRgoyWlBEcmpG'
    b'eE5jYVlCbWwrc0NDeTJMSHZWalFCYmRVekhYejVUZTMyQVNrMXdKWk9iMjk1cEZCTFUzdUcx'
    b'anNoU2hpVGRXc0Y1eWNJCmJXNlBmU1pvcVVtZ0xFYjBHNGRyVE56VVNPQmRuMmQ4akJhTnJ0'
    b'bForV2QyeDlkWXcxODU1VTdlMUVuL21ZMThqcnJwMXJKVXZjQm4KcTR4RHB4MGE1OVlzNVpK'
    b'WW5yRlVaSXdNRlY5bDY1N2ppWHpqM0VicjlPTGhISm9XU2lWQ2s4N1hzb1FDcGZLTzFyWm5j'
    b'N1hZOWxtcQovYVVjU2pDOFIwZTdabVhKZnRaN1ZOUXpKZzRLT1NlRnhHSlpTMUMyQWVuZXNi'
    b'dE5rMVhlM3BwdUVMcG1ad1hudVFHb0liYjU0UUxXCnBibkdKRW91N1RLTlBnZE1DYkNFTlZP'
    b'YlJjZXdwSDFRbWhKMGlqY296bVFjT3V2U0dJdGhtRkNqVEthRlM5ZGJPbC9QMnJFSEY1d2IK'
    b'U0c2MFVMeXBCTm5VWmpHNjFCRmQ2dUJ5bGVJL0JPcG5GS2FiUkV1NUJDQ3h3Ukw1MmxGOFdh'
    b'Y3VVZUV2blA2M2ZQL1JKMmErRytwbgozYnFXcEFZODFCQmU1UFRQOWlWcUxGbVRJNnhiZFkx'
    b'TUpqZUppcC9WVXJTcFVWcWNUamNLdWtSeEhzMVNMcm5HeGkxbEdTWEk3dGc2CmZlTXl4Rm5L'
    b'Wk8vaGJVS3B2UEhhaXNxYjIvZzhPZFBCdFQyZlczeWh2K1BWN0o1NUx0ZndwTlFxSkRkWWNr'
    b'OE5XaW95U2crclJPanEKZTVvY1ExTUFUSlZrMnZqVVprdmtLMmZiYzNuSk9ndDJkbFZzQTFN'
    b'RlozVUg1N2xkSXhOY3JrSUpobTFBY3N0ZlN0VVE2ejBpUmxtTQp3Qnh2N3l4ajZxVGxpZnp1'
    b'T1Y3bnFJUnJSRkxwNGdKenZONmpvNHhWZDQyS2YxOHpCZDczY1I1dEYzS2o1eU4zRDl6ZnZU'
    b'aSsyaFpmCll4TUxaY0laRkc4UUFpM0daTHE0M2NaT2VxWGp0Unpuc0VUSkZaMkVOVGRlVzlI'
    b'TDBTb0J6alNKa0tkeTJYMU5HcHJuWnB3YUllaCsKenl1V3lRTWZxNis3c1R5MVJkeGJGVTNi'
    b'OUx4cFFUMU5zUzdOVWlrNWh5ZU5EQlgreWtsYkRQZTQyRTVFWFpCVndvemN4UWtGQ2kwYQpl'
    b'Mk5QUnI5eHBCb0YvK3dzMHlDc1YzVU1UV1U2T0Zvd0VtdXRnNS9kYkNpVWxxQzVMQzIwMEVt'
    b'eFJ1ZXNiS1dIQmNDNlZZb3psU0M3CjV5d0R3cGk5emVlZEVCSHlGY0xBZTJUVTFDQVVLYjJL'
    b'SkxWWmJMaW5XTnFaSCtDOHFudGNQUGUwSGlGUCtlNHplejd4cUZFNi8vU2UKMEVJWHhSdWQv'
    b'ODVLYnJSaXZ3cWZyYnBHeCtPcmJWSWJ6N2kxOHV2YTNXUGpVZ3ZmOG1RK2JkVzlFMktwemFL'
    b'dFg3cVhRZ2wrNW01LwpNY2Q3VktUb2drQmlneVcyMUJINjNKWHA0UFpoQk90SnV2MkZuTjVz'
    b'VnFtRlQ2eTFDa1d5VUpTeDllOGpxclE0elRqNkRNTFFKMjdDCm1yUmd4dXJGL0xNRDMydHZT'
    b'MVJzbWNOU0pza0JydjM1WEFDMm1uVHg1WjMyZ1dsRG9SSWJMSHlCRXZqUXA4Y29RcHRDc2R6'
    b'MWVwWWEKMjE0ck5iSlhtUVc5NkRvUFRscXJKYWxaakh6cDFGTjA4V1dkT3p5SHFaN1JsUGpX'
    b'S2dkNElVOW1YQnJuVllRUzVidDBpdFRCOTh4eApNdzRqT005ZGZIbEhwb1BuODJWYnRaUlli'
    b'OTJQQU5OV3czbHd3bEJJNlRVZHBrNFM2eTJoK1c0dHhnQVFTK1QrOXpadERmbkVldG14CnRu'
    b'L21oUmM1K0N5dDhQeHVMVWxicXlRdHh2VE1kLzNRbkt4cXFmeUdOcE1nMDg3VFZ0MDV2STk4'
    b'NlhncHg5UlJlRUVBZ0JxaldZZHUKNm9UUTVpNkVyYW1SK0xjMklVK09MSFdrdG9qUnhZNWVY'
    b'ODE1U0NMbnhKQjdWQndVRElWS3JMVUt4VEtmcmJROW05ZjVldGFQYjdXaQpDLzIrNDBQaEJX'
    b'NXJwV1NwbEdqUjJPcGQwTFhYVlpSZDB4bjUyaTYxQ3YzdWJ0cXVUbGZacEhhZXoxWFVNTnY5'
    b'Z2R1UWFEbkU4dG1xCmIwSWthMHFJZ0lRV3VFS2Z1OUl0dkJiWm43bk5lZE9Db016Z1BGZk8x'
    b'TEJyZEZ4cUZtd0QwcjMwKzNkSFNQM2RKZkdWTnR1QWRQK1oKallRMlF3dGN6WS9tNzJXdTll'
    b'NEI1dk9VeWx0YWFic2hOZkdzVnpVMTRqZ28xYXZvR21jV0RYaW9BYlM1cmZsMjZ2N05mT0I5'
    b'TCtkVAo0MnZzc1JXMjNzd1YyOEMwYTJUQ05USWVYZUswRDBsYSswbXhsWFpUSWZFMTFxNjNz'
    b'cXdWa2hwaGZrQU8wSzVOZG1xUTRnMmxtK1VLCmxmUW1vZDlkTFlaTWdRTEZHWkVsRGlOREVt'
    b'dHR6aEZ4UTJLOFIwVzIzZFh5ZUY3M0hDL2pNTGdzbVM5VWJGV1NwVXF5RDA2SDVydlUKR0Uw'
    b'b3REeWUvOS9MMXZBY0dzK2FFdXArMXljVXlWSWJWM0psNXpZTFJ1bm10azI5TzNKMlhXLzVh'
    b'TUZVUW16SEs5ay9rSXUyVkVvRgo1d1Zhbjh2TE83MDd0c0xlL1luSGQxU2tlNjZYY2VpbUFV'
    b'clE1VzZ1YTdhdi9FL3RxVTFpc2xaTWZHc3Z1N0ZOOFhOcWpDR01TU2dJClJZcVdrRkwxb250'
    b'MFBQL003bVN0aFJCVEtGQ3MvZE8xMTFaa1RRbHpYclh0aGR4ZUIyUFBOc0krS0QyNzN2T1J1'
    b'NWRLRy9wS1hicGUKbEFOc1lxTlZMTTFrVFlxWUtyR1V5anY2UmIxU2NtVlgvbGs5ckZ0TGJS'
    b'YVZBTWU0dFV3cjMvcFV2cEN2OU9WWi9qY2x2TWdSWHVSdwpIeG9ydnFRVEZOSk5RbWloeTN0'
    b'a0ZFRDNCeDRsd3BSZTNhbjRXZGFuOWc2bm5ubnV4SHJyUHFWUDcyWUVXNnNrcVlVM0ZFb3N5'
    b'V3pqCmQ0b3U4TWRXMlV5ZEpOWlorVHhGQ2JMT1ljbGtyYVh3OTRIWWNwc1Nack9PQzdjOWs1'
    b'dHpVaWkwd0tXR0dmZllPSituOUh6cTFoS00Kdlg4cXZ0Ym1ISkd3bE1yK3Q3My9jZVhJanhl'
    b'S056eUh4emlmeHJwVi85dSttZ2NhK1J4RmpUQ1pEczdJME00UmlkQjhsMWdxaHhhNgpjcVlH'
    b'YTIrb0VNdWxWSzJGdGhsU0s4OTUxVjc3N2ljUTFxVld6Mmh1ZXpxUHR1bjJ3U21sbStWelZk'
    b'YXBDWVd5TGxNYnI2bHdERTNtClRndjYzL1E1aHFYRWtreXlUdXg2UFh1Zml0aGJManJ2MUo3'
    b'QUhLOGhVL2dsaUh0OExQdVk4S1kvbDFHTWFTaUV5MUx6cHZWWXFxUzYKRzhvcGkxRndkbmR5'
    b'dlNXOHlBa0toRFlKWUJ5Z3ZEdkdwdE1XUSs1bUFSU2VGd2d2ZHJCMm5TOVFLVjRMTG5ScjRm'
    b'MHc2Kzh0d0l4RAozM0UxenM5Y2FLdSsrd1VCQkRCL0FmVVhpak55Rjc5ZjBqMzN0by84Z3RB'
    b'RnZuKzVoL25McUgrbWRiOHRSQ005LytjeENYNlQvMDB4ClFjeVZ2NkwzZmY5THJLckY1TEVZ'
    b'TmZqWDhzci9nd0JyU1ZwcTRwVWVUa3ZRdEdCeVdiSlFKbk51cmRXUHNoTmdHQ2pPUTh2Y1h3'
    b'dkEKelAvU3kwUVdPd0p2K3hMcnJidGF4WlJwcmN6WUI2V21qQWdzcXRNdk91bFhwTFIrR1FE'
    b'M2ZPTHh2KzJWR2dYR29kc0dTSjdEbzk3RApvN3VrUlhiOEs3djloVnlZNEh5cWZWQ0tMNUJa'
    b'dTI0U0dBcWxobG01blFzdWNCVjVZdUY0YW1qVkQ2K0pZV0I5QXpZMlljSWh5SGIvCkJ2RCtr'
    b'TlFtUytQOWhUREEySFJUb3lLTDdaSEY5dmFYc3JPUEMyZE5qckN1dmloZXp3ZGVtTWlaR3Vv'
    b'TnV1Mmt0SFhNWHdhYmdEWDMKMDNrK3ZEVWZHUVZsK1RoazRGNGh1clllYXpaajdSYXMyWXcx'
    b'bXhHTWdxTHd6Z09ZT3Y0M2dQZUhxR0c2RjkzaGIyd0VFRjlyQzg1MwpoUmU0MnA3TDYveDN0'
    b'bmRDTFB2NGtMVktLcnpRMy9EM29rd1g5OTJFNTR2L0JzTkVPb05CZy9RRk4rS1lLL0hlRjRq'
    b'RWNNaEEzSG5aCmQxd3NZeWM0MTI1QktBWUFGSVdCNWVCWVhIOE9UcCswVjUzak55TnJMNzFh'
    b'ckx1aUtsMHYxanpRNkRpb0w2NlY2UkM2WnZsQ0MxeTYKUklHQ3RUSk5jV1ppdlpYenFzTm0x'
    b'ZTRZM1FwR2NkMERjRHR3NjRVSVJpREpzQXJJemNMdi80S0pvOUFkUnBZSHcvcGpjd3ZXYk1i'
    b'YQp6Vml6R1pFRUFCQ0M2aEtVNVdObExWSVp2SDAveGcvSGtSZGowZk9nZnpta3dDOWhEcWJo'
    b'R0pwSzE0czc1dVFLQlpteTY5b0xML0FIClAzVkhGdG1sTmtGTE1KWVN1ZkNDcm0zb0tpcGUv'
    b'eFJiV25IM0ZUam5OcHgwSGFJSjFEVmovSENFWTdCYUVFOWhVd3RlL1JCTld3UEgKVlVXWWVn'
    b'UU82b2NoVlVobjhOWUNmTFRFRVV2R1o4M0FwTkg0OEd1TU8raVhoTzRCQTFpTk1vbDFsa3k3'
    b'b0lSWWFJU0lPdTlSYWJmTwpleFRhWmZEWnl2YjlrVXpFMTFxalN4MEErS3hkdzJlc1M4czdy'
    b'U2Z2dEo3dkZ2SFdmQ3hlZzk5UHhUbVQwZENCcTg1RWZScytXQVFBCkd4c1JqQUxBMG5Yd09E'
    b'QmlJSTRjaVRjK3c5R1RUdjU4d2NlZDNWSW9pa2RlZ3pONzZMbm5udnR0NnlzUFRGOXo0dUVB'
    b'OFBZQ1hERDEKTnl0Nmo1SnVFRHRmeTByVmk1eFhwU3hHNzVwRU5janFPeVl3bTJCZE9pWG9K'
    b'a2p2QWxRQTlvRXArOURVM2hUeHhVcThQQmNsZVhBNwpjTWVUV0xFUjdkMDdkeThObDV5QzBZ'
    b'TXhhaUFjZHJ6K0NXYStoRW5IL3U3VlYxK05ScVByMTY4M1RiTzR1TGlvcUdqYXRHbkhEVjl6'
    b'CjltUUFpQ1hSMElheFEzOGpPcjZmTmdzdGRDbEIxamtxWWRsbFRhSUpPY0FwUGF6U3pja0J0'
    b'dmNQTlU0YkdZcGlUZGFyMmdhbXNrOEkKTTkrL2ttVlRDOVp1d2JwNkxOK0FUNWZBMkpxTHdM'
    b'RVlWSUZCRlJoUWhnRVYrUFFidkx1NGtHVlpPZEZVa285WUVxMEJidVNvUTYrNgo2cW9UVHp5'
    b'Um9uYUtsZDF3d3cxMVN4NTQ1MEd3REFBOCt3NGtHZFBQK0EzZzc4TlhKb1Exc1QvaWpacU9k'
    b'VnV3ZGd0cW0vRHRadFExCm82VnZHeUJrdWNIU1NNajJSQ0p4eHlXNDhUell4TDd4OTlDLzhP'
    b'cThrdmZuZkZoVlZiVmh3NFpZTE1Zd3pNQ0JBMTB1MTNlTCtQTEwKTDgvNDNZVGxyK2dGVzhP'
    b'dngxeUoxLzRPci9NWEJ2QlBwNklKLzJORE9jazBibjhDeXpaZ2ZUMFM2YjZETmhFSEQ4REpS'
    b'Mko0RFlaVgpRMUV4NlVyY2UrKzlraVRkY2NjZGkxYW5xMHZoRDJMaGNvdzcvUGlQUDNtNHNy'
    b'SVN3RUVISGJTbmdwTEpLNis4OG0rWGJVZjNtN1VvCkwvemxvZnZ6dGFLalNXeHF4ckJxY0R2'
    b'a1ZueXpEby84RzNZTFJnOUdVUTZlZng5Rk9manpSVGgySEt3QzF0WGpoZmZ3N0x2VWxWZi8K'
    b'NmRKTEw2VnArcnp6emx1d1lFRW9GRHJVNWJyckgwTUdEUnEwbDZVLzlkUlR1WmIxZnpoeCs1'
    b'Rm4zc1lmei81RlVwVS9Vejk0MEduWQowSUJwRXpINzNoMlV2SWs1WHlLYXhIbkg0NlU1V05S'
    b'K1VYVjE5VnR2dmJWcTFTcE4wMHBLU280ODhzakxMcnZza0VNTytURkZKeEtKCm1wcWFWKzdv'
    b'T0hMRTFnbStHWGM4aFZuMzd0RXYwUEQyQW9nOHBoNysyd2plaGNaSTBscVM1ck9WM3VuWjFJ'
    b'a2NZQ2VQVVZRVmswZnYKM0JrSnBoNk9QejhKMDhTeURUajArRVBQUC8vOEcyNjRBWUFzeXp6'
    b'UDc1ZjZQUC84OC8wTHRxTUw0UEhadVB6VS8zRFhpM053eWQwQQo4T0UvTUhuY2J3QnZtKzAy'
    b'V21xdnF6QlV3dVVvenVGSlE2SmpLMnhha3A1YUU3Ky90WG55WWJ1NVpkeFFMUG9XRGUyNGFN'
    b'ajJaS1A5CmhTNkFWMTU1WmVvTzZEWjFvdG1QSTNZNG9rYll4RVlMYTFkdE5SSmhUUzFKcGVx'
    b'c2szUDFvMGFtSGJhZHJ2d05ZSWhsY3UvdWZrcUEKMjNFWFJqcjJ2WG1OeDQ3RkhVK2pMVURL'
    b'eXNyMmUzM1dyRm5qYjF1NTBZdlpuK0cwaVFCdy95dTQ2clNkcm1sK05DLzhoUXNBNjFiRgpV'
    b'am01V1RSU05JQmhCYTN4d3FqSS93YndqaXlrcUxOT1hRbnRXelZ5UFpDTXd0MjZOejlTNXM2'
    b'ZE8za2NIcjRldi84TEtJSUI1ZWpvCndhU2Rad3ByUlNiOFJkOVEzbkZsRGYyelRIMDY4R213'
    b'dlh1MTdKTWNjVEJZVHZ4dlZHYng0c1VUUnNBcTRxVzc4TTVDbkhjSHJ2K08KOGN5NGRQeHk1'
    b'QUFEckVzMG42TVVudWN2dXNEdk9TeG1INVR5VFl6a25CUlN2QmtBeHZkQTN4MEJ5KzcvM0hS'
    b'ZDExZXNXSEZRTlFCWQpCRngyS2hnR2o3Nk8yQzRNNlM4cVIvRkFxMmhlcjNtbzRidkhIM2tB'
    b'QU42Y3R4dHE4SU92Y04vTElHVC9OM05iVzV1YTZhNHNBZ0JaCnhiMHZZczVEcUd2R1diZmlo'
    b'bk94M2E0MnpaTEx1cmhjV1l1elVoTUhRc1JDUlV0UjBZODFSZnNONEwzUUlMRWs2cG9CNEt0'
    b'Vk93RnMKbXJqekdiUjA0WjM3TWZUc0prVlJPSTdiajNYeCsvMGx1WDNNODhQL3d0bkhJc3VO'
    b'TERmNmwrTEdSL0RtUE54eENYSTh5RDQrL04xNwpXLzFZTWdlMlZpVFRzRmwrUmdEL0hKZWlQ'
    b'UDhlRGhzR0FBTXI4TVdxdm9QeEZNNy9NN3hPUFA4WGVKd296a3ExdHJidVovb3NHdlc2CkFL'
    b'QzJDU3ZyY09heGZjZXozSGp4cnpqdVVKeDhIZTU2RnBuZExCYkhrMi9DYm9IZGdsYysvRzBP'
    b'M3FNWUJsYldZbGcxQUp3MUdmLzYKRUFCcW0zSFdiYmpvRkZ4OUJucDE4NkJLYk5teVpYOFhi'
    b'WEFzTkIyM1BZRjdyc0l1azhEeGgyTGVVMkJvSEhVWlB2aHFwMVB4RkxyRApzRmxRbkl1dlZt'
    b'MlBaZjBHOEc3a2pYazRacXRiNHJEQ2FjTlRiK0QySi9ERXpSZy9mUHRsaHd6QWwxOSt1Witu'
    b'SzRhUkZkejNFbjQzCkFSV0Z1N25BSXVEV0N6RDdYc3hiam9tWFkvNnk3U3JuckszRC9jaEQr'
    b'dElLZmdONDkvTHU1NWcyYWR1c0M0SEhDM1B3MnYraGVLY04KL2pGNkNCWXVYTGgvaTNhNzNl'
    b'c2JzYVVOdlJIKzc1T0NiRHgwSFo2NEJiTSt3OGszWUVVdGxtL0VVU1A3enA1ekhONmEvK3My'
    b'c3BKcApQUE1PV3J0MjQyL0lLcElTYm40VTBRUkdEOFk1dHlNdG96QVg5NzRJdzRDc0FJREk0'
    b'YkpwR0ZpT1JIQlpVMVBUZnVTekVvbUVvbURtCk5YdDFjVlV4bnJrTm0xdHc3WU5JcFZHM2RW'
    b'Y0lrVWRKUHBhdXg2aEJQd3VBZitwbzBqZHJjZVc5cUNyRzFNTkI3NkErRkFYUzN1MzgKR0lw'
    b'ajNsSzhOUk4zL3hPNVErNjc4Y1liOTB2RjR2SDR5U2Vmdkc3ZDJqV3ZCUE4ydDEvSW9qVzQ4'
    b'Mm5vM3lFNW9nbGtGRFIxb0NBSApOSUZGZ0taRDFmQmR6cEpRT0dZTS9uNGxDUGtmQmZpMWoz'
    b'SHVuL2VQRGVLMjQ0MzdjUDFUUTFldlh2M2pmV0pkMXkrNTVKTFRUei85CnVlZWVPMi9jRzFP'
    b'K0UrU0lKVEI5Smo1YWpHZHZ4OTVRTEtxNm0vNnFHN2o5Y1Z4N0ZxYWYrZE5oL0pPcTZMT09S'
    b'VVVoYm5nSVhpY3UKK2QwUGY4Nk1GekZ0SWlZY0F2THdtcVZMbDQ0ZVBmcEhWdXlXVzI0Wk8z'
    b'YnNwRW1UNnVycVZtN2NEY0FmZllOM0ZpSXA0YzVuZm5ncAppb2JtTHN4NEdjY2RocXFpLzlF'
    b'NWVOUWdmUEk0VHJrQngwL3ZPektnSE5VbGlDYXdjTVgyeXk0NEVlRVlQbCtCNk5iZHN3L3Fo'
    b'K3BTClJPTDRkQWtBbkhzOENNSGxwK0tsbDE3NmtRRGZjODg5THBmcndnc3ZCREIrL1BpYi9y'
    b'MmJhODZZaExvbVBQOGV6ai9oaHhlMGVBMjgKVHN4NUdBN3JUOWZnQjhESXNnaDQ3ZzRNUEJY'
    b'eEZLWWNoZ21IUUJRUVQyTFVZTno3QWdqQnkzY2hGRVUwaVZPUHdnMlB3Qi9FOFlkaQowbWpR'
    b'Tk5JWmpCeUV1NS9iYnJJKytvZC85L1RjbFpXMXAyMjIwdW4wNHNXTDE2eFo0L2Y3V1phMTIr'
    b'MlZsWlZqeG93cExDeDg3cm5uCm90SG9qQmt6ZXE4Y09uUm9qenlrMWI5MkY2TzlWOW9DdVBa'
    b'K1ZCUml5bUh3T0xDaUZwK3ZSQ0lGbXNiSUFaZ3lIbFlSajgvR2xsWUEKNkYrSzR3OURsaHZM'
    b'TjJEQmNrVGk4TG53OWZNL0tib0E2TDllaWdPQzhlY3IwTmlCU1dOUTM0Wm4zd0hEb2lnYjM2'
    b'ekRxRUZnR1h6OApEUmF2Z2FvajI0MjZacHd3SHJWTmVQb3QwQlRLQ3JCa0xRcXlNYUFNV1c2'
    b'a0pYbHRVODdZc1dPL3p6Q2VNV1BHTlZlZHgwYWU0S1JQCi8vYnc0blJ3MFVrSHozLzNuVGNl'
    b'ZnVUUmQrY3VibXRyZStxcHA3Yk40b1NRbHBhMmpzWkYzN1dCUDErSkwxYUNvWEhObWVCWVpH'
    b'VFUKbE1GaHhicDZqQitPTTQ3QitucFlCQncxRXNzM1FGWnh6ZGxRTmNTVDZGZU1MRGUrM1lU'
    b'WDd6a0FhZFVIQnVCTnpmamJQOEZ6YU85RwplemQ0RHY0Z3Z0ME11d1dKTkdxYmtFekRCRnI5'
    b'OElmZ2RxQ3VHUjNkRUFVRXdsaFZCNHJDVjkvQzQ4Umh3MUJUam12dldudmFtWCt3CldIYWxn'
    b'RnRhV2s0LzlUZzE4TnFFRWNtN0xvUFhoY2RubzM4cFpreEhZUzU0eHZoMlhVTXFXcnV1TGpK'
    b'Ky9QaHR0TFlvaWs4OCtmd3UKcXZpbHVYajFBM1FGSVFxd1dmRFpVc3hkQk4wQVRhR3VHVDRY'
    b'T3J2eDNoZjRkaE5VRlQwUnlBcXNJcjVhamJsZlFWYVJ5cUN4QTVxQgpqSXloL2Y3WC9XQUFO'
    b'ZVg0KzFXWSs5V3VzZlM5bERZL05qVGcxZ3Y2ek9rTHAvZ2ZlZVNSdSs2NmE2ZHIydG9tVFpy'
    b'WVAzZExTUUU0CnBvODIyU1pMMTJMSk9vd2ZqbjdGNWtPdi9XUEZpdVhQUC85Q2RYVTFnRkdq'
    b'UmtXMG9XczJyOWtSQ2FjTnZmMW44amprZXBDL3cwZXkKcnpvTkdRV2F2cDBlMlVaNmpCbU1N'
    b'VnYzaWpoc09ENWNoRU4vSlNNWXdOQXFwRE40OFgyc3FvVmhvaXVJYkRjMk5LSTlnTzR3dkM1'
    b'OAp1d2xkUVRBTXduRUVRc2oxWVZVdExDTGUrQXpqaCtQaVU1RGo3WHZVOFA3NDYwTkxxZ2RO'
    b'S0M0dTN2YjhpeSsrV0FwOWRjUUlmTEFJCnpSMDRiU0ppU1R3K0c2VjVxRzBDdzhCcHhZUkRV'
    b'RmFBSEM4T3EybS84SSt6KzljTXJxeXNwQ2lLb3FqNW44NDlaZ2V0Mzc4VXhibDQKY3o0OERp'
    b'Z2E0dW1kZnRJeU1zcC8rS2x2eFpCS1BIN3pyd1pnbXNhSUFTak14b1Avd3RvdFdMc0ZwMHpB'
    b'QysvMUpkUWRkeWp1ZVI1cgp0NkM4RUxXTjJOQ0lZOGZnYjgvaER5Y2dITWQ5MTJ4SHQvZFJO'
    b'U1g2NVg5ZWV0Wlpad3VDQUdEaHdvV2Z2blhUYVVkamVBMU9PaHhwCkdXL05oOCtOMXo5QktJ'
    b'NHJUOFBGSjJQRlJsUVU0cVc1SU1ESVFUamxpTlNGMTg2bU9kZW9VYU9xcTZ0ditzc0wweVlr'
    b'clR1a2paUVgKNE9oUmVIcytZZ2xNUFJ4MkVVT3JvQ2dveTBkSkxnaFFYb0E4SHhnS0RpdEdE'
    b'WWFpd08zQXlJR3dpZWhmaW9KczNEdjlwN2F3RGp3WApmZHloZlpGQkFJcUszZ1kxVEZCa094'
    b'MnRHekJORUFKVkE4dEMzdDMzS3NZTXhXRTFHNjY0NGdwTjB3RE1talhyc3Q5aCtVWTgveTVX'
    b'CmJJVEk0NUViTWZ0VEFCZzFFTCtiME9lVmdzTFFmcmp0UXF4dnhLRUg0YlBIMVJjZW4zN1ZW'
    b'VmN4REhQR09aYy8rODV1Zkx3SHIwZFMKZ3RlRlo5OUZlUkVlbTQwWDV5S1Z3V096OGQ2WDZJ'
    b'N2dzZGw0YkRaMEhZL054dHA2ck42RVJkOGltVVpUQndxekQwQUxIMkNBNjVwdwoyZGFVNDQ0'
    b'ZTJDMEFrSksycjhGVmRUanRhTzFDUVRaTUV4eUw1czdkUCtyL0xrZmordGV1dnZwcTB6Uy9Y'
    b'dlJsUlNGOFRyanNtRGdhClBJdkhaMEVRQUdCTEc5NmNEOE5BVlJIVzFXTjFMZDVlZ000QUFG'
    b'UVdZLzdUYUYzNytKUXBVODQrKyt5M0ZwVTN0TzlhU21VeElnbmsKZVJFSUljc0ZBQzFkY05v'
    b'QW9EMkE0cnl0QkNFQmdPTVB4ZHd2UVFnSVFUaDJZRnI0Z0FIODZPdjQ0LzBZZnpGNklqajhZ'
    b'QUJvYkVmVgoxam1VMlFwd1V3Y0dsQ0dWQVFHY05zZ0syZ0o5K1I2N2lOT08yZmRnNFVkUDNY'
    b'ZmZmWlRXMk55RlNXUGhkdUxaZC9ETTJ4aFVpUnZPCkFZQ0tRb2djcHMvRWhnWmtPWEhzT0J4'
    b'MkVLd1dhSHFmeWZibVRBek9tWC9DQ1NlY2MvNlYxOTVQRkhWWCs3K2lFSUV3V0daN0wreE4K'
    b'QXBFVmlOejJrRU9lRDZZSmZ3Z0VJQVIyNjY4TTRLZmV4Q2RMY05udk1IRTBiam9mTklXVmRU'
    b'aTRaaXYzbTBSRkVRQjh1Nm5Qci9oawpDUzQ2R2U5K2pzdE94VFgzOSsyeXNJc1U1ZUxUeC9I'
    b'bUt6ZXJpcnh5SStZdHcrY3JNSElncG96SGNZZjJCYTlNRThjZmhzZHV3b1NSCmVIUVdYdjhF'
    b'bC93Zk5yZGh3OWJNTUk3RlE5ZmpxaE5yWjk3MzkyNzVrR3Z2eDdidnNyY0hjTXVqT0cwaVBs'
    b'dUtVWVBRMmdVQUZoRTgKQ3dDNXZyNTE1UjRIREFQWG40TVgzNGZJNDlKVGNkMDUrUGZmRDB3'
    b'N0g3Q2NyQ05HWU9sNlhIRWF6cjhEL1V0eDd2RjRjUTRLc2tFSQpUQk1mTDhiSlIrRCtWeURK'
    b'Q0VZeHZCcVAvaHVmUFlrTDc4S2swYUFwakw4UUJka1FkN2VsbzlPS0ZSdndmMDA0ZGl3aWNi'
    b'eitDVFkwCm90VVBLUU1BNit0eDhnMEFRSUJZRWs0YkZxOUZlaGsyMUNQWHQ5TnpSRHEwYkZs'
    b'bzJUSnNia1cyQjkxaHJLckZpWWRqVUNWdStnZWUKdUxrdnNEK3NYOStzVVZFSWZ4QUFLb3JR'
    b'dTlKNFF5TWV2Z0duSG5VZ0o4RUR0dmdzRk1PeFZ5RWN3K00zSTVIQ1FkVVlkUjZ1T2gyZgpy'
    b'OFJYcThGemVPZCtUTHNKS1FsbCtYanlWcHg4UFliMHd6OXV4UDB2OXkxU1loakVFLy8xL0Jp'
    b'N0ZkdldoUXNjR2p0eDkzTTRiaHl1Ck9ST0hYUWhaeGFOL3dndnZZMVVkSHZzVEhua2RXMXB4'
    b'NDNtNDVpeU1QQmVkUFhqM1FaeDRRSmVqSGJBUjdIVmkzbE80OFdHY2VCMHUKT2htVHh1THVL'
    b'M0h2QzdqallueTFHcktDTitiaHF0TXg0MFUwZGVMcHQvRGtyWmgrSDg2K0RiZGZoS3BpTEYy'
    b'SCtqYklDdlNmTmdHSwpwakJqT29iMnc1bTNRbFl4c0FJZUoxYlZ3ZU5BdHJlUGhUNW1EQjU1'
    b'RFowOU94a1R2enFBZTNYcE03Zmg1Q053eGIxWXVnN3ZQNFM1Clh5SXA0WkNCV0w0Qkw4M0Y3'
    b'SHR4NUFnc1hJRjNGa0pXOFBMZjhOUmJ1T0JPV0hnTXFrUisxdTR6NHdtQjNZSmtldnRaaW9C'
    b'bGR2V3YKZUs0dlJXUzdQVUsrTjlWK1IzbHJQcTY0QjVxT0hBOW1Yb1BySGdTQW0vK0FGOTRE'
    b'Z0pFRGNkUklQUFVtS0FxR0FWWDdGUVBjSzVQSAo0ZXZuTWZscVhIQW5IcjhaazYvR2pPazQ4'
    b'MWJJQ2k2L0I2L2VEVUt3WURrKy9CckxOK0xTMytHaUU5SFlnUlViMGR5SjdnZ1NxYjVCCm5N'
    b'NUFVZUYyNEkwWmtHUzQ3TGovRmJ6M09hNCtIZWVmZ0VnY3RVMjQ0V0VvS2lhUHhkOHVoMkdp'
    b'MVkvTC80NmVLSTRaZy91dUFRRTIKdGVLU3YrM2VndHRGL1J4eE1DNDZHWGMrZzdwbW5IZ0VQ'
    b'RTU4dEJnQXJqc0hHNXVnNnVBWVpKUStBL3ZYT0FmdklsK3Z3YUVYWU9sTAphT3pBS3g5Zy9I'
    b'RGMvQ2dBWkx2eDZFM1kwSURIWmlFY0I3YnVPRmRaaExJQzVQbGdHT0JZV0VXd0RDUVpBOHJ4'
    b'K3NjWVhvUFBsdUR2ClYyUFJhb3dhaUZzZXg3aURJQ3NZTXhoZFFZd2VnbXRtWXN3UVNCa2NO'
    b'dzViMmpCK09LNlppVUdWVUZXY05na2JHLzlEYlhVZEc1dncKMGh5RVlqaGxBdjR3RldmZGlr'
    b'UWEwNDdHYlJmaXNkbDQ3cDArZzd6eGZSUmsvN3BIY0s4TXJnUkZvYllaUTZzd3VCSXRYYmp4'
    b'WE14OApCZDBSbkhrclRwdUlaMjZIWVdMSk9xeXZSME03dmxpRmR6L2Y3c0JzazJIOU1mME10'
    b'UGtCWU40U1hINFAzcG9KbWtKNUFkWnR3VFV6CnNhRVJNNlpENURGeUlENzRDbjk5QnZPVzRr'
    b'L253eUpnOGxpOE1BY1AvUXV2ZjdKWGRlNWZpcnV2Qk1mZzdOdVJTS09tREJlZGhJdnYKeG5W'
    b'bjQ4WDNZWnE0N1lJRGpPN1BhQVN2MkloRHpzV25UMkRtUy9qajJmakg2L0E2TWFRZjduNTIr'
    b'MzRydVQ0TXJjTEFDaFRsd3VlRQowNGJ1Q0F3RGhPeGt5eFJtNDRrM1VWbUVxa0xJR2pnR3lU'
    b'UWtHWFV0R0ZvSjNRVExnR01SREtPdUZXTUc5NjFVS01qRzRtOFJqdVBvClVYMmJVKzVac3Qy'
    b'Z0tiejhRVjkyZEdrZVhyZ1RXMXB4eWQxNDZIb2NPd2FxanNHVkI3NWhmeTRBUC9FR2Juc2NX'
    b'OTVEMlJUNFhIanoKUGx4OUh3d2RsMDNEcDB2dzFud282ajQ4YmZRZ25Eb1JzejdGOGcxOXB1'
    b'L0UwWERhOGQ3Q1BqZ0p3Y1JSOExueC9oZElidTFBb3diago4R0Y0NlFNRVF2dFcrZEdEOGZ4'
    b'ZmNPRmRtRG9lSHl6Q04ydHh5eDl3NTJXZ2ZnWlo1eitYeFBjM1BzUFJvN0Q0V3lUVGFPN0Vo'
    b'WGZpCnlWdEEwN2o0YjZBSVpsNkR2MStGazQ1QS85SzlNbHNDWVVRUzJ5TVd1b0ZvQW9mVW9G'
    b'L0oxaENHaVhBY1E2dFFVN0w5TGtPSHo0MkMKZmZuR25zamp6eGZoNDhkdzJ4UDRaaTN1L2lj'
    b'dVBBa0hEOERkLzhTWnR5S1IrbTBFQXdCVzFtTFVlWGpuQWJ6MjhmYjVyNklRei80WgpMODdC'
    b'eTNNQklNdU53NGFqcGd6NVBzU1NNRTBvR2hnS0pwQ1JBVURnUVZQUURXUmtFSUlWRzFHY0M0'
    b'YUcyd0VBMFNSeXZWaXdiSHZTClREQ0tvbHg4dGdRVHRtN0trOG1ndmdQeEpFWU0ycG9qOEgy'
    b'dEJuZ2NzRnRBMHpqeENGeitkL3pybzc1VFZoR1AzSWhuMzhiUzliam0KVER4OHc0RUd1TzZE'
    b'M0U4M0RsclhYcGpNQ0NtRk4wRGxPcUkrZTZKZmpuOXdmc2ZRb2phVy9vR3VuRzVTSzVwTFY3'
    b'U1UxUWR5bWtPKwpVTklXbDhTTXhyS016dE9xUTVSeUhiRWlUN2dpTzFDN3NlUHpSZTF6SDh6'
    b'MFAyVzd3dXh0ck5zdVFLNFhkenlOOXNDK2xUNWlBTTQ1CkRxOStpQlViK3d6YU1VTlFVNFkz'
    b'UHV1YllrVWVoeDRFdHdNZkwwWjg2MUFiM2grbkhvMVhQa0J0MDE1Tnc4LzhHYS9NeFZzTGRq'
    b'cHUKRmZIMDdmUzFqeFZWOXN1ZmNyUzNJK0lPSkJ6aGhOMEFpYVZGQUE1TFdtVFZmRmVzeE5O'
    b'VG50VTl1S0JqYUdFclJlM25iLzdFSk12cQp0aUpDalhqQitQNXZ6ZG1Gek1peXhsRmxEV01y'
    b'NnNkVzFidkYvNkIwSkpWYlhGLzFkVVBWa3NieTVVM2x3YVJ0YjNVZHExVGwrRDFzCk82dTFw'
    b'OE50N1MydHJXMnhYaU81dWhSWG5RWlp3VC9mMjZ0Mjc1VkIxZFpUajlKZi9ZaHhsRTgyS1lj'
    b'S3E3OXUzdlFUVzUrZFB6QzcKMzVHeVNrc3FIOTN3OHRrVEkzTlhWaFZYVmhBdG9hdHhQVlov'
    b'eE9EdXVWOW9hemJ2aVNFakJHY2NnM09QdysxUFlGVWRBRkNjSTYrbwp5SmRYd05nS2ttWmha'
    b'N3dnSWUvRHQ0ODhsdFRRb3RhaFJXMURDdHNHRjdRUExtamoyWDBlVjZHVWJWVnJ5WnEyNHJW'
    b'dFJXdmFpMnE3CjhtMmNUREQ4eGIyOG4yZTFZVVV0dzR1Ymh4UzExK1IxWmp2aStmWm9RaEVq'
    b'S2N1VzdweGFmLzdYVzZvV04xWkdVL3RoL1ROTmpCSnYKZDQ2MTNZWU9Rd29tWWlHaVJZZVZw'
    b'L0k4Y1dLYUd4clIwb25XQU5JWll0SjJrN1pRbk5QcWRJdDJEK0d6TkNZdnF1VkdJa3E1L0to'
    b'VgowTmRwbDhKU0FnRGhiNlpVZjd4MG5kR1RlMmVmOGRIOXlZV0hmdjdLeDFhbC9QYStncFZn'
    b'VnVnaG40ZFJQQ2U0SEFhdDlhaXBVRG9XClNhZkNrWjZ3cW1rVlJlekl3ZUs0Zy9uMUxhN2xX'
    b'eHdtbDV0R1lVOG1QNUR3NmVaK00yaXNnandncjNOZ2Z1ZUEvSTU4WjZUQUhjMnkKeFJuSzRH'
    b'aE40TlZvMmhKTlcyS1NHRWxhTzZMdTVwQ3ZLWmpWRlBSdENlUm94azdVcUkzZkY0Qi9Ec0xU'
    b'bXNBcEFBRXhBVWd5citqZgp5L1phbXY4Ni9iVFV2ZStPUWY0cEFLQkw3cTQ3RHgzT3pOa3lE'
    b'YzZoQUpEcHF0UWVOMHlta2JrQVlsOHNtcXEvOS94all5OThlVWpmClhiOWs0Um1WMmNxaG16'
    b'Njc1TEptSElJaXFXd3N6UWRpb3FMdEg2YWNwc3dzdTVUbFNJdWNKbkFxVENJcGpLelRzc0tF'
    b'azBJa0pXaDcKL1QxU1dXZGthVy9KbVRSVDdiTXY0MUlyRlp3Q3dHbWpWSkk5ZmxEamwrdS9j'
    b'UHZLb21rZUZvKy9sdnJERk8zUlQ1WnRBOWh3SHV3UApmV2xUdjAyYUo0TDhxQlp3VzJTM1Ri'
    b'WUxNZ0UwZy9RR3BDbGltaVlWbDdoWW1vdG5PT08vK1MxV0V4Uno0M2tEUnczS0hqUFVsKy9i'
    b'ClNiVW0wdHFHaHNqR3B1anF1c2pxdXRDYUxaRmtlbTlkVVp1RkhWTGxHbExsR1ZMbEhsVHBI'
    b'bExwZHRxK2Q4VldSdEZiL2VuTzdsUnoKVjdJdGtHcnVUTFowcFpvNms2MWRTVTNmWjd1RG9V'
    b'bGhqcldpMEY1UmFGZUNVeHI4N2FNR2FkZmVYSFRzcFBFV2dYbitlYWJsMjRlRwpsVXB2dm5h'
    b'VzErc0ZjTk5ORFlOOWJ3MVkzdmowUDQ4TlJ1WEc5dVQ2V3MvN3ozd3llb2hyZnR0YTB6RnNy'
    b'MlpRQnord3dsVlZiQzhyCnNKZm0yVXJ6YmRrZXNTQkx0SXIvb1M5S0dhMitQZEhSSXpXMkp6'
    b'WTBSRGMyUnRjM1JvSVIrWWZCeVRKVWVhRzl1c1RScjloUlhlcXMKTG5VTUxPR0phZTVWSTBx'
    b'eXZxb3V0TDQrMnRDZWFHaFA5RVF5OFpTU1RHdWFaanBzak1DekJkbENZYlp0VUlWcmFELzNz'
    b'R29Qei8zWQowUjlMS25YTnNTMnRpZnEyZUV0WHFyTW4zUjJXVWhsZFVYU2Vvd1dlcG1uSzYr'
    b'UThEajdMTGVSNGhMSUNlMFdSdlgrSjArM29TNXhKCkpwTW5IamRtNmhHMFg1MTh6ejMzQUFp'
    b'RlFxZE1QWFRLNGF5ajVNcExMNzBVd0dlZmZmYit2MjlwOHh2WDMvTElZWWYxTFRxYk5HbmkK'
    b'MU5FTkg2MGVmTVhOVDZ6YkhON2NHZy9GbEVoY2ppVlZRdUN5c3phUnpjK3lWQlU3eWd0dE5h'
    b'WE9takxYZmx3dFdOK2VhR2hMYkdtTApON1FtdWtKU0pDNUhFNnFzNktwbXBET2FZY0lpMERZ'
    b'TGF4Rm9uMXZJODRyRnVkYWlYR3Q1Z2EybXpPV3c3anlRakRUTW4xYkNNVG1XClZINnk0bzZi'
    b'ZlBSWEwzcXJxNnNNdzloNlpPSlhMN21QUHVydzNuOVZWUjB6Y3NCejl3eS81cHBydHQzMTJH'
    b'T1AzWGpad2VOR0RXaHQKYlRWLzBhS255RC9mM2JKOFkzQjFYU2dTVjZKSmhhYUozY0s2N1Z4'
    b'NW9iMHMzemF3d2pXa3lqT3dmTjk2cUdsaWMydHNRME9zdGltNgpwUzNlNWsrMUI5TGh1SnhJ'
    b'YWJMYXQ0TGFKckp1Qis5ejgvaytzVGpQV3Bwbks4bXpsZVpicTRvY0h1ZVAzZSt4eFo5czlh'
    b'ZGJ1NUx2CnZmM3ZzUldyNXl3U0haV25TWm9ZVFNqQlFIdVJOOXdXb0JXK2pLWUlBU3hhNDRs'
    b'ak9yNVl3UjA5NWF6K3BjNytwVTZ2UlRyaCtDUE8KTzhFbFcwKzU1WlpiOXI3Y1ZFYXJhNG8x'
    b'ZGlRYjJoT043WW0yUURJWVZYb2ltVmhTTmdIVElJUXlCWllSQlRyTEpYaGRYSjdYVWxaZwpy'
    b'eWl5VlJUYXEwdWNMdnQrMnhXcXFTTzVyaUVTQ01iMnlvck9jZ3REKzNtR1ZMa0hWamdIbHJ1'
    b'K1c1V1dydVRHeGxodFU2eXVKVmJYCkZOdllHQW5GbEI5cWtaSENIRXQ1Z2IyODBGNWVZQy9K'
    b'czJaN2hCeXZtT1hpODNhMkVoVFZhTzVLZFhRblcvM3A5a0NxMVo5cUM2VGEKQXVuMlFDcWFV'
    b'SDVNNnppc2JJR2w1ZHdqMmhldDVpKzc2cnFhTWtkSnJvMWx0bnRCaG1HMmQ2ZjlRYWt0a0dy'
    b'cVREYTJKeG82RW8zdAp5VlovVWxGL1lJcEpyL1ZRV1dTdktMUlhGRHJLQ3F6bEJZNDhuN0RM'
    b'VysvS0pobG1XeURWMFowT1J1V083dlRtbHZpR2h1akc1a2huCnR3U2dOTi82UTl3a21pSTVY'
    b'akhMTFJBZ28rZzlrVXdvSnVPL0x6WUxtK01WUkk1SnB0V01vb2ZqOGc5dXpSOWd2N2pzbkZW'
    b'a1RBUHAKako2VVZFbitpWEkxYkJiVzYrUTRsaFlGbXBnRUJJbVVvaHRRVkNNdHE0cGk3cUVt'
    b'MlI3aEYrWUgveWI3SkY0WC8wdjl2S3pBRVlINwo1WCs1bkdBdnZaaDlzWUMyNzFsaUY3WC9C'
    b'Mlora2llVUFvRDBBQUFBSlhSRldIUmtZWFJsT21OeVpXRjBaUUF5TURJekxUQTVMVEE0ClZE'
    b'RTRPak15T2pVd0t6QXdPakF3aWs5RFl3QUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0FNakF5'
    b'TXkwd09TMHdPRlF4T0Rvek1qbzEKTUNzd01Eb3dNUHNTKzk4QUFBQUFTVVZPUks1Q1lJST0K'
    b'IgogICAgICAgaWQ9ImltYWdlMTEyNDUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'CA_NB')

CA_NB = b64_CA_NB
index.append("CA_NB")
index.append("Canada New Brunswick")
catalog["CA_NB"] = CA_NB
catalog["Canada New Brunswick"] = CA_NB
country["Canada New Brunswick"] = ('CA_NB', '', 1)
lookup["CA_NB"] = ('CA_NB', '', 'Canada New Brunswick', 1)
lookup["Canada New Brunswick"] = ('CA_NB', '', 'Canada New Brunswick', 1)
details["CA_NB"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-04:00","altname":""}
regional["CA_NB"] = ('CA_NB', 'Canada New Brunswick', 1)
regional["Canada New Brunswick"] = ('CA_NB', 'Canada New Brunswick', 1)
#----------------------------------------------------------------------
b64_CA_NL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTI1MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05ld2ZvdW5kbGFuZF9hbmRfTGFicmFkb3Iuc3ZnLnBu'
    b'ZyIKICAgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFj'
    b'ZXMvaW5rc2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNl'
    b'Zm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93'
    b'd3cudzMub3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAw'
    b'L3N2ZyIKICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRl'
    b'ZnMKICAgICBpZD0iZGVmczExMjU2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBp'
    b'ZD0ibmFtZWR2aWV3MTEyNTQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRl'
    b'cmNvbG9yPSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlc2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAg'
    b'aW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdy'
    b'b3VwbW9kZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJn'
    b'MTEyNTgiPgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMjAwIgogICAgICAgaGVpZ2h0PSIx'
    b'MDAiCiAgICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9Imlt'
    b'YWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRh'
    b'OmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQU1nQUFBQmtDQU1B'
    b'QUFEMFdJODVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFB'
    b'UG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDNGxCTVZFWC8vLy80K3Z1'
    b'R29iWXpZSVM1CnlOWHBzcjNJUFZuU1lYanBzNzc5OS9qQXp0a3ZYWUVBT0dXbnVzcmpucXk2'
    b'REMvQ0tVZllkWW52eHM3Ly92NzkvZjZodHNZWFNuUEMKS0VmdjgvVjNsYTBIUFduQkprWFYz'
    b'dWJYNE9kSmNaSEZNVS9vcnJyaWw2YkxSMks3RGpIQUkwUFhjNGZ1eGMzKy9mMW9pYVF4WG9Q'
    b'Qgp6OXE3eXRZclduL0tSRi82N3ZEbXBiTFBWRzI3RURLL0hUN1RaWHZxdHNEKysveE1jNVBl'
    b'NWV2NisveVFxTHdRUkcvNjcvRzdFVE8vCkhEMysrdnNKUDJyeTlmZnQ4ZlJ1anFjRE9tZjc4'
    b'Zk84RWpTK0d6ejkrZm9iVFhYKy92N1czK1pIYjVEOTl2aTlGamU4RlRiODlmYzEKWVlYRzA5'
    b'Mnl3OUFoVW5tOUZqajg5ZllCT1daZGdaM243UEg1K3ZzTlFtMitHRHE4RkRiODlQVUxRV3gv'
    b'bTdMMytmcmw2KzltaUtNQwpPbWI5K1BtK0dUcThFelg3OHZRa1ZIdXF2Y3pLMXQ4NlpZaisv'
    b'UDNXYllLK0dqdTdEekZDYkkzUjIrTWVUM2ZBSVVIaGxhVDU2KzRFCk8yZnE3L0wwOXZnSVBt'
    b'ckFJa0w1NmV3UlJXK0lvcmZpNk8zQkpFUDQ1K3NuVm4yMXhkSyt6Tmd1WElIejF0emFmWkRG'
    b'TkZIZmpwNzQKNXVwRWJZNFdTWExjaFpmRExVejIzdUlGUEdqeDlQZnU4dlVHUFduRUwwMzEz'
    b'T0VVU0hIOC9mM1k0ZWRMYzVMMDJ0OHlYNFBDejlvcQpXWDcyNE9URk0xRDAyTjdmNXV3UFJH'
    b'NzI0ZVhES2trS1FHdno5dmpzOFBUMzR1ZTZEVERDS2tqTzJlRTlhSXIzNU9nMllvYkgwOTBn'
    b'ClVYajY3Ty9vN2ZIMitQb01RV3o2N2UrL0hqN2s2dS9KMWQ0NVpJZjc4UEpEYkkzUzNPUVlT'
    b'M1ByNy9NU1JuRDcvUDNiNCtsVmVwalEKV25MU1lIY29WMzIzeDlTOXk5Y3RXNERkNU9xWnI4'
    b'RVZTSEw3OC9RWlRIVEQwTnNqVTNwY2dKM202L0Q1NnUwY1RuWS9hWXZQMnVMdAp2c2p2eU5E'
    b'd3k5TEpRRnpSWFhTK0ZDelVSUjNXU1J6UU95QzlFaTMzNCtmRUlpanJlQTcvcEFEOW53SHRl'
    b'dzNZVGh2QkhDck1OU0x6CmlnajBpd2pkV0JmSUt5YlEydVBFMGR2VDNlUWxWWHM0WklmTjJP'
    b'RktjcElkVDNjK2FJcS96ZGdOejRpOEFBQUFBV0pMUjBRQWlBVWQKU0FBQUFBZDBTVTFGQitZ'
    b'RERnMFJJYnplLzhFQUFBU1JTVVJCVkhqYTdaeG5XTk5BR01keGk1NVVxcWlJRzVVbzFsUmJC'
    b'MjRSQnlwTwpCRkVSSjRyaXhpMXVjTldGRy9jV3Q2Q291UGZlZSsrOTEzY0xqNlIzYVZPUzlK'
    b'cVNNKyszSm5kNTdrZG8rci8vKzc1eGNsSkNDU1VFClJKYXMyV3lKN09uWHlaRlRvc2lWMjVr'
    b'REpVOWVJRDd5cFYvRlJTVkY1SGRWRitDK0tRWGRDc2tDcExCVmlyUW80bDQwczRONGNGSVUK'
    b'S3doL0tsNENBMGpKVXZpaWRCbFBFMFhaY3VXOU9POENWYUVpOHRtN2tzMGdHbHhQb01xMHRn'
    b'cERVVlducjJadE1BVkE5UnJ3Z1pvKwp0VElGU0cxYVc0ZWhxS3ZUMTh0Z3ZCRUUxSGR2QUI5'
    b'cTZOdkkwU0IrdExZeFE5RkVwMithOFJRcWJTSE4zUHpoZzgxYk9CS2twVjRYCndGQzAwdEt0'
    b'ZWMyaS9pMmxUVnZrY0x2MkRnSXhVZ1RDRkIzNFRrd0hBVUhCSGVIaklUNmRwQWR4MXVzNk14'
    b'UmR0SFNvZ0xtVWFUVmQKdzdyQlo3cjM2Q2twU0MrOXJqZERFYTZsK3dpYlRzSHI2UnVCbk92'
    b'WFh6S1FTUFdBZ1F6RklJMkxuK0FyVU9pS0JnK0JUL3BIREpVQwpKRkx0T2d5aWlCb3U1b2F5'
    b'UU1DSUhpUGgwNlBDUnRzWnhFdnRPb2FoOE5SRWpSWDUvYUxNRmpVdU9nUWVNRDdZamlCR2ln'
    b'a3d4VVR4Cmp6dkt3ckltVFVhR1RKbHFKNUNZV0ErVGtKbzJmWVpOdno2VXhZWE5iSTRLL0Zu'
    b'NFFXSU1zeUVLd3h4YnhZQmxFRERYZHg0OGFyNTcKSEZhUUdNTUNtR0loQm0xR2NhMXRrYzlp'
    b'ZU55U3BkaEFZZ3dsWVlwbGVLUXl4YjI2K09Xb3dGK0JBMlRsOUZVd3hXcHNyZ05sN1E5ZApm'
    b'UTBxOE5mYUNMSXVTbU9pV08rcXhtbWZXQVVCRzl3M3dvTTNjUWw4UGlDYm96UmJHSW9FdkJR'
    b'WmdwZ0ovSzNieElGc2h5bDQyQWY0ClFRRFlzUk1WK0xzRWcreDJnU2c4N0VIQkN3VDBETjRE'
    b'ejBpTVRoSUNzaGZlZU8vVDZTUHRaREZTZktSVTE3QXM4SnprNENDZUlJTHMKQXdsQXpBVCsv'
    b'Z004UUE0S3RBOGtBUUVnNVJBaThOME9Xd2NSWVI5SUJHSVUrRWM0QlQ0TEJMRVBBclNsZWts'
    b'Z3cxTUNkdVpIZlk3QgpVNCtmc0F5U2NMSVZReEY0S29lek5Qa0VJU0FBbkQ2RFRENTd6cXIz'
    b'SzlBK2tCTEVxRnJPdzdPUFhiaklCUkt1cFM5Sm1lRVJDZ0xpCldBTGZkNFFGRUZIMmdjUWdB'
    b'RnkrWU9iZ0l5Qmk3UVBKUVFESWRnVlZMVmROSURiWUJ3NEFBVUhYa3BFTTVIVkdxTjl3VkJa'
    b'VUhJaFIKNEljbFpxNTBybGdRQUc2aUFsKytJQURjdWswSUNGdmd5eGNFZ0ZyUmlNQjNhbjBI'
    b'ZTl6bHAvMkxlOXNZNTlIcjNidVBQU1ZkOXdIdAo1NEJiN0VXUFVha2VQbnFNTFo0OFRmdU5m'
    b'U1k5U3FnaFhQWDh4VXRzOGVyMW03ZXBKbGlzZlRiNzFtTGhBNVhxM2Z1WEdPUER4MCtwCkc0'
    b'UUI5dCtnbVlOOGtEMElJZjlhOXZxeWIvOWZIci9FL0NBcUVpVlZOSDVXWkx5eXNWSzJ1cGJO'
    b'aHk5RW1BK0UyRUdrR0hTRVdLYUUKbU5pRXBCWE1FajFGNVpub1NmbEtST3J0R3lzWitsMmV5'
    b'ZEFrTXRMVHBCUU1FRkxDd1JMclAyUmFWRU5LbVJNaGhXZnhhS1pRcnFXQQo3T0xNbi9Jc3pp'
    b'U2xYSmFRQW1aQ1NzckhvV0pkcmtYK3BMUmRERWJyNUNKK3liTVJocERXSkVLYXhWanRlNG5S'
    b'TW0zZkk2U2hrbFVCCmYvdTNQRnRjV1UzSG0rVGFkTXhickdmdU5uQlNHdk9KZVZVQ0hMSitl'
    b'WVVRc1M2UDE0bjhJZU1GTHdTOWNrY0pKWlJBNGk5ZzhPTVEKcFpab1hBQUFBQ1YwUlZoMFpH'
    b'RjBaVHBqY21WaGRHVUFNakF5TWkwd015MHhORlF4TXpveE56b3pNeXN3TURvd01HNzkrbUFB'
    b'QUFBbApkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNakl0TURNdE1UUlVNVE02TVRjNk16TXJN'
    b'REE2TURBZm9FTGNBQUFBQUVsRlRrU3VRbUNDCgoiCiAgICAgICBpZD0iaW1hZ2UxMTI2MCIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'CA_NL')

CA_NL = b64_CA_NL
index.append("CA_NL")
index.append("Canada Newfoundland and Labrador")
catalog["CA_NL"] = CA_NL
catalog["Canada Newfoundland and Labrador"] = CA_NL
country["Canada Newfoundland and Labrador"] = ('CA_NL', '', 1)
lookup["CA_NL"] = ('CA_NL', '', 'Canada Newfoundland and Labrador', 1)
lookup["Canada Newfoundland and Labrador"] = ('CA_NL', '', 'Canada Newfoundland and Labrador', 1)
details["CA_NL"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-03:30","altname":""}
regional["CA_NL"] = ('CA_NL', 'Canada Newfoundland and Labrador', 1)
regional["Canada Newfoundland and Labrador"] = ('CA_NL', 'Canada Newfoundland and Labrador', 1)
#----------------------------------------------------------------------
b64_CA_NS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTc5MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05vdmFfU2NvdGlhLnN2Zy5wbmciCiAgIHhtbG5zOmlu'
    b'a3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgog'
    b'ICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQv'
    b'c29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5'
    b'L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5z'
    b'OnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRl'
    b'ZnMxMTc5NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEx'
    b'Nzk0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2'
    b'NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0i'
    b'MiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2Vj'
    b'aGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVy'
    b'IgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzExNzk4Ij4KICAgIDxp'
    b'bWFnZQogICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJl'
    b'c2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6'
    b'b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFz'
    b'ZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFBQUJH'
    b'ZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRB'
    b'QUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBUQpWa2xF'
    b'UVZSNDJ1M2RlWGhVMWRrQThQZXVjKy9NWkNhVDJaanNDV0dMSXFrQzhpVktLTkJpTFVnRnhl'
    b'SkQwVktLOHFnb3RTeFd2MzVhCmViNjYrMEdsVkd3eFVDMXVLQ0NyQXNybUdvaGdaQWxKeUo1'
    b'TVppYXp6OXk1Ni9kSFJxQkFRVUptTXBrNTV3OGU1cm43ZTM1NXo3bG4KN2oyRHdhUnRjSFhG'
    b'a2s3L2JsckJnbC9rc1RRQnFQVG53b3R5eFVldGYzcXp0dFhGWGVXdXNLdUhoWGdoVWpHRWhY'
    b'Z2hVakdFaFhnaApVakdFaFhpbE1xbVl3MEs4VXBOVW5HQWhYcWxHS3E2d0VLL1VJZFVIc0xw'
    b'THBsRzFaTWJBZVQvTFlXZ2MxWHBNQzhmTHE3YzNQL3RPClhac3JFdWREOXdFc2xMMlNOVXNs'
    b'QkN6RUsxbEpSV0V0MzlqUUo2a1NOWTdKMVBCZFdKdVlvaWdKWWh4bHIvNmVwYzZ0UVV4UmxJ'
    b'UTkKT1NTbVA1S0tOb1ZuWUNGZWlGUXYxdFQ1c0JBdlJLcFhhdWZpc0JBdlJPb3FhK1JTc0JB'
    b'dlJLckh0WEI1V0lnWEl0V0R5UDlRV0lnWApJblZGMGI0eVdJZ1hJaFZEV0lnWEloVkRXSWdY'
    b'SWhWRFdJZ1hpbDRNWVNGZUtHSXhoSVY0b1NqRkVGYmlCKzY5dDlkME9kdmpkZzRaCkp0c2Rk'
    b'ODFKdFQrOFdNRks1Q0ErK2Z2Ykhwb3V4ZTNvZjlsQVBQbkM1bFRMNVdSTXI0RW04WG0zNXR6'
    b'NzA2eStEV2luaDErNjV1UkwKNzUvdURpaEZFUVlkSG81SXJJb0locVRQMzNaY1A5bVlZYVl1'
    b'c1llNjA4R3dXd0lBdFlFb0xOQmNZazJYa3orNjFUMW1ocEZseWU1RApVQlNXZ3QyRDJHYXN4'
    b'TXhlZCtoZStNdkRxcTFyV29VRHZDTlROcmJpK3NucUNkT3RsOWpxeTcydXl1V2RnTUdvaDYy'
    b'angyWmNZczNkCkcreStMU0ZIbG1ScEk5aHladEk5dG9XdkNCdDh2MCsxSG1mOFlDVU9yeW5z'
    b'Y3h1WDZidWMvTi9tMUlCZDloTVNnUU1BZHVtdEpGNEIKQUlMR0xyZDdSWkloVFNJd0szNS94'
    b'V0JEQnYyTEo3d2ZoaGVuMmswTUdlZnJUSkRHRVFBK2VibmRSNG5aRXpWNVAySWl2dDdzY3Fs'
    b'MApoTHVLYXpvZTNQTlMrL1JsZWFsNVgwejJ5VFVuQWk5YWd3OFlyU2JEZU9lN2ZrOEQ3ekhM'
    b'ZzRacjFlcUxCS1R0UkNnb1NXd3JBSUNZCmk2a3czRFpFZmVGcXdaQllYeDNRZGVMcCtUUTdU'
    b'SlU1V2szTFJBcVM2a3RZaWNCcnloOXlkdTIyMSs0UGlLQ1lCekhYanRQY09UZm4Kb21zZVdO'
    b'L3AvanJzSW5uQXdHUlJHVVl4WmIrMFhIVE5kMTVyc3U4TmNZSUVBTmVPMGsrY1lFMUJVbjBQ'
    b'SzNHeVYrR2Qra2xUQnZ5bgpwVGZOdE1CTStQakZOa21XYjFtVWZaRmVsUUlZQmdBdy9UYzUy'
    b'ODBkeDlkM3BXYVdPcmNreW50ODNienExNWEvdXVEYUxDTVQ1Nk9YCmpqY1JlTFJYN3ZVTHRj'
    b'Y0RGNjV6L1d6VGozNWx2dWptWCt4Mkh0N2JCUUFFanQwMHdSUi9Vcy9NR2RLd2J0eVNHWVdK'
    b'OHpVRENZbFUKK2p4N3JYcSsxdXdtbXh0RHMxNGVhTGFvemwxa05OTUEwRDAwRmIxUGxKV0RH'
    b'enFiZGdlRU9xRmdRUWJLVW9rTHEyOTU3ZDNwRUw4VwphMXRDUnB3V0pQbThwVlg3dWpvUGhV'
    b'ODFCbi8xVklGZVR3SEE5dVV0UVkra202Z3VySlliM3cwZHpmTElFdVFQMWFRNHFjUnFDdjhU'
    b'CnI5clh5NWZQTDg0MHF1Snd4UEpKNXJKRlZ2TlFkZ1NvdjFydkZLWG9DTitCSFk2Tk0rdGZm'
    b'UFNrNWoyeHJGTDkraC9xOXU1eWVIeEMKMC83QTVNWFphVjZvbGNMNTlkVEI1K3dtRXgzcms4'
    b'dzBxcGJQTDI1YzkrT0Vhdmo2RTZ6dXd0RDRncWw1cDllT2kwUGY2OUNYN2s5WApkUmhWVkRn'
    b'ZGl0N0hQL2hqSXdCVWZ0ejFaWlhiM0VKT05wZzRSYVlCSy90RzQ2dU4xQjRQMk5JWmpZYVVM'
    b'VGhCWVE1U0hEUWlMYnRBCkhldStWTzNyNVF1bTVpWCtKQmNrOUljU244YnhoaHNOaGNPMERJ'
    b'VnRXTm5DZkFDRis4aXZkcm5VZXRKd0hIWVYrSEt2VlVjMnlnQVEKVUVTbGsxQndoUXRKQUVE'
    b'anVDaGk5ZU5FT1NpR09DbEdwUHJkQTR6OWFYYVhPTnc1R25RVXk1S1Q1MlVkVGc4eUN0Ynlu'
    b'dSthVWZxeAovNU5sNXlPdTFnak40Z0Nnd1lpMlkyR0xpWWxJY3ZWaDd6Vmo5Q2VMSW1sRFZY'
    b'T1hEVlF6UkN5eVZLTGQ4U1Vick5qeCttQlI0N2NICnZHYytwdXNvWHdFSW9CUjhSKzM0Unh1'
    b'T3c0VFJscXhzdFlNUUFJREdjSk5BWWhqa1RkTjl0OUpGVXZpQ2RjUHVuSjBOQU44ZThINncK'
    b'dUNIRlNmVlhXTDNGNjZNdDlxYjZVUFNER2x6Ti85YThaZ3hqY0FCUlZ1Z0tmdXRUemQ5OTVR'
    b'bDlHQm9SMGdDQXJDajFGQ2Q0cFIvUApIS0FhUm0xYjJoUUlSbHZBcm1aT1lxUGpZUTExb1kr'
    b'MjJGT1FWUCtHZFpXOEJGRjIxWEgyZGY1b2lxb0N6L2JnMXY5cjRiam9LTU9NCldkazc4N3dl'
    b'UlR3WThmaVBSVzV1U2hzajY3b1gxY3NjeFdNYUN3VUFVeC9Ob1hLSnpZODFCb0xpOWhXdDd1'
    b'M0JqTVBSUXpqKzZYZlYKY1lJb3B4cXBaSURWWTE0VWlhdk5sSnNWdXo5NkdFbkl4SFY1Tk1O'
    b'RUE2TFhVM2M5WFJBd3lEd29ma1g2WFBUS29OUks0U05Tc0VQTgphd2ZTaGd3YUFMYjh0U1Z6'
    b'bkZiRkV2c3E3S1loTEcvRHZheDBacDlhSzBXUmVLcVJTaDVZUGVObHpXZktGOXE2LzY4cXBF'
    b'eURtWnR2Ci83ZXZsazkvNWUvaWhFbDB4bWhTNTFlay9ZSjN0K0RaSjNoRUNvckg2a05ocWFN'
    b'OUVuS0lIVHNEbWpLVmZWZHd4UGgweTFDR0dSaDkKRW5Yc3dnSG1YQ1lGU2ZXbjRZWllERXlN'
    b'S2MzWXRUdmFCMUxsa1lVM3BaMVo1SEpFOXIzUWtYY1FId05wZ0VFR1FYb1ZrUVNzak5MNQpG'
    b'WW4xRVFxQUpNcHJucWd0YTlXNmM1WE9ZLzYwQUY1ZDVTc3NTM001ZVhBQUFLaFUrSmpTakNR'
    b'YlJFaGRXRDBiOTVvdzMzWmtZOWVKCnpaNjA2MVQrUmtIWUd4bmNRQUdBQWlCZ1NnUVVubFZL'
    b'QkMzMS9WT210V3NEMnA4YUxTcjZCQnN1bTU5SjRKanI0YTVRbDVBN09sMTMKUDEwLzE1OTg0'
    b'MUlJMXZtOFprL00raUZ6Q1h2MThwSDluckVidFVhTUVJSDRtZ25VTTV5MmlNNFpwbEZvdUNI'
    b'UGFuL0J5N21sUElLaApBQ3Zzb0w3YTVmSmE1QmxMOG94bWlpRHhhdHBlWkw1OE1GTm5mbWdT'
    b'a3IzZ09EQVVqbDN1a1hidVkyNklXbjJ5T09JektaUkRHYmZBCmRrZUJtcWFKeWtwM2FhbFJr'
    b'cFg2UExxMU12anBXNjZmT1BRNFlLRzF3VnYvT3pNemh5RndiT3ZxVnNLS0R5OUp2K3pKaUpJ'
    b'U2prZ0sKS0VrZjltU0dkVVV2YnZERmVQa1U4OGZ6bTI5ZGFETm1xS3hXMVVmYk95U2Y0bTNs'
    b'Y1E1cnIvRFNqYkpjUWhxcGFOL2MwSWEzTGVvNgpQZHdqQmlXbFZSNjgxRWdTbDMzUDR2d1gw'
    b'VkJUbU15a3VzdXMrWGx1ajFCNG42RjRXSFM4S3R2RXZyMithV3hER3IwaE9CaWpBUUFPCm5Z'
    b'MVkvYzJTS1lmQkhSSTlpQjcrV0hwV3poVjgvWndLdlBEa0k3VjZXM1BoUFh2dlcxRjlXVlVZ'
    b'am9PaUFIVC9BNFowYXR4a0N3QkUKZUJrQVFyaXNNWkRITXNKdVVyeHdXelZGakw5L0FCUVFI'
    b'Q09mcXlyNk5wMmlZRGorUTNqbHovNzAyWGZxdzd5RU1sYS96MUtDRksxeQpXNDdxaEYrbWRV'
    b'U1hsemZvb20yY3ZZTjdldjUzUlJidEk2OE9HWG1Ed1I4UTl5eHNnZVBRbVM0cTAxVGVRMXg2'
    b'bFdMQjZmdzkrTnJECk5kbGRsTE5Fa21jcCtQZFBOcnM4dkVwUFNsN1pZSW51a0pmd0ZNeGVl'
    b'S3BsS1FBSThkSEtzeGdacmxOVVdjaVdwdkNacFZzcTJxNXoKcWJtcXlQdExHamU5MUZ6NWxw'
    b'UFhLd0FnVDFXTm56UEFkcHVXeHlDZ1NDUmdOM3EwR0dDWmRjU21mN1dkMmJ5bE1VUlpDTTRo'
    b'WnR2WQo2T0VpbC8vclRiN3NoYWNVcWU3aUNFWUh4RFAwVktoRm9Jdkk2Zy9PdmxlRGNZcnBS'
    b'bFpmd2hCSHhJSHY0NVlLcWZnTEdnQmtVQUloCnNiZzBQWkFtYXpHaVdjUHpvR1RpdEowVmgx'
    b'eDNkbkQxMkVZM081Z0t0QXRtZzZxN1pld00vdEF2TVpPSkY1NVNwTHBMcXpDMCtwUWYKQUhB'
    b'YzAxL0R5QVRtcWVRaXZIeGd2d3NBNWp3NThHZkxjalROa0xGSVh6MVdPSmticVRmeEo5UEM3'
    b'WHVDYjY5cVhybWtKcVNYbTZZRAovbHZXd1FvQTRHVEZkRE1GQUFmMnU3aUk3RDdFU1FENjRV'
    b'ejNDMkZIYTN3ZDBwQXJPcjNrNEJYdnVSdjY1STd2Z3RHazRBUDVMNjVZCmFBV0FxbTg4ZTU1'
    b'dlowZlFnazhLTjRtV1luYk8wZ0tmVDlpK3J2MnVCM01Cd0c3bjJ1ckRHSW5uNUxOR00vM08r'
    b'dWF1UnY2L2ZtTFMKYVluNmhVNVJobzVSOGoxUEY2NTU1clRqZUpqSkpsVVpCUGNOUC9aUjIv'
    b'VWw2UUR3d0F2MnZ6VXZBcEx0MlpuMjN6RjZNclZJUlM5YQpzNzlHSjBvS1NXQ05tNzJkRG02'
    b'UW1lSDJjMFZPNmhRWnJxeDBqeHhwNkZZRkFGWXJZN1dlYmN0bXpNd0pjOUlYVzUybmowUnl2'
    b'VVJsCmZtajBWR3RscGJ1ekpqU3dobXJ1RXNocFZGc0gxN3JWZjMxSnVpREtCMnZUUWNQMitF'
    b'ejdiOWNlN3kra2V0endYYlI4aDkrNXJNSUoKQUpaaHJOWkFlbDRQV3UvVjFha2k0Kyt6alJ4'
    b'cHVQUzJyeTQ0WlgvUmwvR0ozR2ptMlJLNlpHVDZ5SkdHOG5tMkJoVS80TmM2MTlxQQpMb00w'
    b'RG1FQTRPazFqbVA0N1ZkL3R2MnhjVXgwV0J3dnI5alVXSERQcDcxRnFydElUTmFibjF1ZGJ0'
    b'NDJYRDA2bUpZaEVZNjF2cHlICjB2Yy8xbnJrcU9mUzJ4Wk8xRGt4dm0yWVJFOWlWUFVLQUh4'
    b'VDVUMzRlRnZXUS9xT0NwOVpvRWFGMG16RFdaZUhmK2R3bHNUbTlOWTUKZC9NcSt2WGVGWnNh'
    b'T1Y1TzhJcEwzRDVXekdmU0VrTzNVTS9QTFJKVkhZcFRGTnByd25RSXM4M1Z0YS8yMnFicGZu'
    b'bkJCQ0gxSjRJVQppZVVVcVZ2cVF1dWZhaGhjcGl1LzIxcDd5RjlURStqWTZMZk4wM2U4NWcy'
    b'cmxaeWhHaU5PU2RuWXFwUEVUbUZ4ajN0WC9iM3ZsWWl3CjRqWTVHeFZ1dW0vd3V1V1BtRHZh'
    b'dU9wTmJxeUlPUEpzcCtrM091Zm5JYjVEblBGY1FXSCsyZGVhdHozVmpHUFlMWC9NQmdDdlQx'
    b'UmsKMmVVVzNsM2NRR1VTcGh0WjV4cC95VktyVWlOY044MW9HYUJhOExMOXRWT3plTFl3cHVl'
    b'ZnlMd1NDMWI4NS92TENCNTRaTXpleCsrTgp6dVRSMUJwZU42OVdkNE5LTjFUbFhCOVE1Wk5U'
    b'bHVTYzJORGxQQmpHRkF3d1JWUVU2ODJhb2RNTW01NXRGaHBFMDB5dDd6anZyK0ptCnJ5N0t5'
    b'WXdtcDJVVnp1VmZsSGRwYm9yUEpTUW1yMFNCMVlkVFNLWUZEODBzM0x4cWNXYTAreVVyYjZ4'
    b'b2NHd0o2dTdRRURUbTNod0kKU2JMdDUybFp1ekVGVStyS0pQZXVrSnJBRFZPMGtpRDczZ3Ra'
    b'YnRQT2VqRHZ6R1ExUzFZNlhqczYwYXNkRStlclNEUmVmUThyRVdZbApaVVBIcGxyZlhiM0Vy'
    b'R0dqdGVMczR0LzZjMk9naWpOTTBWQm13cmNyN0Q0WkFRRERFSlZ1SWlzNEpQZUhRZTMxek16'
    b'SDhveUc2SHdOCndiQTA3eG5IcHM0N3crcml2cnFReE9IVmw3QVNhcExxdTh2VUwvL3ZRN2VY'
    b'dXN0S3RHY1dlUVBDZTY4MDJYZUVkR09adEd0VkFPQ3YKanZqMmNkWmIxSGM4bUt2WG5wM0J1'
    b'L0pZOEYrNzJkODkvdGNkM3lyb1Z6bjZERmJDem52K1JzWEtVMGMzeloxQ1pKMHpPWllneXM4'
    b'LwpVU044eXNrQVVpbjV4SitMR2RYWllab1dPL2VQTGZLZzY2Yk91dmVCQkwrNlpJYVYrRUVQ'
    b'aFVKL1gvV01yK096V1pQSVhGdDB6RDBRCkVwMXRFUUF3WmFxMDMwK0EyOVRPdmJGVDFBMG9u'
    b'VHQvcVZxdDduZFhtaVN3K2xlZ0E0SEFtMnRYTnAvYWY4dG9yblNFOXJ5bG54M3gKN2ZpU3pC'
    b'MHkvdTdaRDJxMTJxUzU2bjRHcS84R1Y1YmxiVnMySE5qMXovTGhnVW1sT2dEWStabHZYM1Zh'
    b'MllSWnQwNmVqdU40MGtjZwpRV0VsVFVBLzJiTmoyNFpYQU9EbjB4OGFOMzVTaWtlakwyRWxY'
    b'eEM3QTRWaEdJcE0zOEJDOTBRb1NvQit1aGZ4Z2tUKzZWNUVDa1d2CmwyRWhVb2hYTDhOQ3BC'
    b'Q3ZYb2FGU0NGZXZRd0xrVUs4ZWhrV0lvVjRYVkhrTHc4TGtVSzhlbEFMbDRLRlNDRmVQYTZS'
    b'aThOQ3BCQ3YKcTZ5ZDgyRWhVb2hYcjlUVVdWaUlGT0xWaTdXR0tZcUNTQ0ZldlY2RDJQS05E'
    b'WmVkcWpyV0pYVW1xWTVwNFhqNWgwdzhIcC9heEdEUwpOcFNsVVBicTlkSm5zQkNwNU9iVkI3'
    b'QlF3NWNLaldOY1lhRXNsVHJaSzA2d0VLbFU0eFZ6V0loVWF2S0tJU3hFS3BWNXhRUVdJb1Y0'
    b'CjlUSXNSQXJ4Nm1WWWlCVGkxY3V3RUNuRTY4THkvOHh2MGQzeUNJeHpBQUFBSlhSRldIUmtZ'
    b'WFJsT21OeVpXRjBaUUF5TURJekxUQTUKTFRBNFZESXdPakkwT2pVMUt6QXdPakF3TW9VMTlR'
    b'QUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0FNakF5TXkwd09TMHdPRlF5TURveQpORG8xTlNz'
    b'd01Eb3dNRVBZalVrQUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAgaWQ9ImltYWdlMTE4MDAi'
    b'IC8+CiAgPC9nPgo8L3N2Zz4K', 'CA_NS')

CA_NS = b64_CA_NS
index.append("CA_NS")
index.append("Canada Nova Scotia")
catalog["CA_NS"] = CA_NS
catalog["Canada Nova Scotia"] = CA_NS
country["Canada Nova Scotia"] = ('CA_NS', '', 1)
lookup["CA_NS"] = ('CA_NS', '', 'Canada Nova Scotia', 1)
lookup["Canada Nova Scotia"] = ('CA_NS', '', 'Canada Nova Scotia', 1)
details["CA_NS"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-04:00","altname":""}
regional["CA_NS"] = ('CA_NS', 'Canada Nova Scotia', 1)
regional["Canada Nova Scotia"] = ('CA_NS', 'Canada Nova Scotia', 1)
#----------------------------------------------------------------------
b64_CA_NT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTI0MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9Ob3J0aHdlc3RfVGVycml0b3JpZXMuc3ZnLnBu'
    b'ZyIKICAgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFj'
    b'ZXMvaW5rc2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNl'
    b'Zm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93'
    b'd3cudzMub3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAw'
    b'L3N2ZyIKICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRl'
    b'ZnMKICAgICBpZD0iZGVmczE1MjQ2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBp'
    b'ZD0ibmFtZWR2aWV3MTUyNDQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRl'
    b'cmNvbG9yPSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlc2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAg'
    b'aW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdy'
    b'b3VwbW9kZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJn'
    b'MTUyNDgiPgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMjAwIgogICAgICAgaGVpZ2h0PSIx'
    b'MDAiCiAgICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9Imlt'
    b'YWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRh'
    b'OmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQU1nQUFBQmtDQUlB'
    b'QUFCTTVPaGNBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFB'
    b'UG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVAr'
    b'Z3ZhZVRBQUFRCmRFbEVRVlI0MnUyZGVWd1QxOXJIejh4a0pTc0VJa0dRM1FWYVJWRVFVVnVY'
    b'NGk2Z29GWlJVRnUzMXEzMEtxKzczdmF0clY1YnQwdTkKWHZlcXRQYXF1TlNxcGFpc0drRkZB'
    b'WldnSUdGTjJBTFpKc25NKzBkVXdsSmVWSHhmeVp6dkozK0U1emx6TW5uNDVjeVQ1OHc1UVh6'
    b'Ngpyd2Z2SHJuWld3Q2tZL2dPMlBBT25oVUsvekVRS0N3SUZCWUVDZ3NDZ2NLQ1FHRkJvTEFn'
    b'RUNnc0NCUVdCQW9MQW9IQ2drQmhRYUN3CklCQW9MQWdVRm9SNjBLejR2ZDI4ZVhQdWdrOUlr'
    b'dnkvZjJtU0pBMGFMUk5GRVFScHV3V0NIRHg2TERBd0VBcXI2NkZTcVR3OFBYWnQKLy80ZFBM'
    b'ZlZ5NWFwVkNvNFluVlZ1RnllaDRmSE8zaGlQQjRYNWxnUUNCUVdCQW9MQW5Pc3JvcThwUGE3'
    b'SGIvenVLeGVQUjJEQWozWQpiRVk3alF1ZktESnZGWmFWMTdPWU5CZG51MkhCM2lKUmU1bVFz'
    b'cm94SmEyZ3BLUUdOeGdsam9LZ1FFOFBkNGQyMm11MWVIcG00YVBICkZZMXFmVkZwUFJSV0Yr'
    b'WlpVZTJSbjlLZjU4dGMxdlRJUWJObkJ0azNsd3RKa3RkVEh1OC9sSEwzM2pOTE80YWg0OGE4'
    b'TjIvTzBGNDkKSFZ0MCsvQlJ4WUhES1pldjVwb0l3dEx1Mzk5MWZzeXc0VU85VzFRWkZNcUdZ'
    b'OGN6ZnY1VjJxaldteTJOTlhWUVdGWkNRNlB1MzRkUwpqaDdQQ0ozb0YvWHhZQzlQc1ZhTFgw'
    b'bktPM1EwdFVCVzFicTl5VVJjK0MzbjRxWDd3VUZlYytjRUR4cm9CZ0M0SlgxNitGaDZXb2Fz'
    b'CnpmSlkxcDNpckR2RjNsN2l1WE9HaG96eVliTVpCYktxNHdtWmlSZnU0cmdSWGdxdEdSdzNu'
    b'anA5KzlUcDIydzJBOWNiV3d3NXJTRkoKTWpXOUlEVzlnTUdnSVFEb082Q1BBbG5WbWcybjEy'
    b'ODZ5MlRSTkJvYzVsaFdTTS9lNHAwN0Zpa1VEZWN1M3IyYWxFY1FwR1hHMDZLeAp4RkV3YzNy'
    b'Z1FIODN2ZDc0WjNMK2Y4NW1xelY2UzBXMmFNK3hZVTROOXgvNVlXOG1reWJOS2pyNTg4M3lp'
    b'cWJNeVVRUUxWU0Zvc2hICm8zeENKL3JaMi9OV0xic0RoZFdGc1hmZyt2WnhBbjNBaDhON0ZU'
    b'K3JQbmcwOWR5RmU2MGwwcWUzSkRwcXlMaVE5Mmcwekd3WjVPKzIKZU1HSEozNjVkZnhrWmsy'
    b'dHVrVjdzUU52NXZUQTZSR0QrSHkyMmRMM1BlZm9XVUVYZjc5LzhFaXFyTERsaFpYRm9vZE42'
    b'ajluVnBCcgpENUhaMHMyZUE0VmxKYmoyRUcxZUY3cDA4YWlMbDNKdVp4ZFZLUnE0SEthN204'
    b'UG9rWDBHQjdSUm5lZnoyWXMrK1NCbTlwQXJmK1NsCnBoZVVsdFppR09va0VRWVA4Um96MnBm'
    b'QmFCazZHZzBMbmVnM2VVSy9qTXpDUDY4L0xKQlZHWTBtZXhIWGY0RHJ4UEg5N0d3NWdFcFEK'
    b'THNleUYzR2pvNFpFUnczcFlIc1drejU1UXIvSkUvcDFzRDJDSUVPQ3ZJWUVlUUZxQXd1a0VD'
    b'Z3NDQlRXTzRKR28ybHRsTXZscmF0UQpHbzFHcVZTMmJseFNVdEpCbzFLcGJQMXlKRW5LNWZM'
    b'V2pkVnRuUmdVVnBjaE5ldlc4Zi84WW1tUkZSYU9tQk14ZjhrQ1N5T080N0VSCkVYSGhZZlgx'
    b'eldaYWRtL2FGQmNTSWsxUHN6UkswOVBpUWtKMmI5cGthYXl2cjQ4TEQ0dU5pTUR4WmlXR0RR'
    b'c1dySmt3L3FsTVptbTgKa0pCd1B5MGRDcXNyMDAydzZxZmQ1eTlmTXY5VlVWRVIrdmxjV1gv'
    b'Yjh6bHBYeTFmYmphYVRLWlZzMmJPa1JYRVZsYitMU3hNclg1ZQpYRGl5Y3lmcmw1KzNrc1RK'
    b'SlVzZTNMMXJOajdNemYxcHlXZGJTWUw3YzhLQmJkdk1ScTFXdXlvaVlrVkZ4ZHlDeDdIVHBo'
    b'bU56OHNaClg2OVkwZi9HOVMwNjNkWVpNOHBlakZzcFY2L21mUE9OTjRaQVlYVnR5cno1bisz'
    b'KzZvOXJmeXFWeWpGenArZjF0Z0VZU3JCUjBjV0wKUDZ4ZFM1TGttbm56UW5OeVhGQ1VoNkpM'
    b'U3VXeFU2ZnE5ZnJUaHcvWC9XdmZPSUpBQUZpaDArMk5pWG1VbDFmNCtQR09xRmxmNkxRSQpB'
    b'QitScFA3UW9ZUjkrd3dHUTJ4azVNS2lwMElNYzhLdzZYbTVxMmZQSmtseTc1WXRici8vSG9B'
    b'Z05BVDVXNE5xM1pRcGxaV1ZOMU5UCkVtTy9tS1BYd1hLRE5WRGlJMXk0ZmFPQW9PWDBZZ0U2'
    b'QmdBZ1VQUjlncENkT1QzMVd2SkNwZEw3eFp5eFBZckdGTXJtakJ3NVVLWDYKMkdSNitlRmJy'
    b'ZFY4R3gwTkFGaWowV0F2R2s4bVRDZjM3SWs2ZW5SbFZhVVllMTVaZFVQUmtPeXNxVU9ESjlm'
    b'V2ZnQ2VaM0lzQkZsVgpWeHNYSG02bjBhekFLVEhKWStYQ2N0T1hMZGFyQUFBSDZZSW5ydDNC'
    b'aTZvbXU3NU9RNktqQ1NKQW9lQ2p6WVp0Wnd6YnFLaHFZYVFoCnlKZXFldk1UUy92SEJueUNv'
    b'b3IvUWxWbWZCSGtxMWJkY2xGMHRWSmhnNklJb0FSV2ZpbnMyWjMyOVV6dTF6TzVESXdFbHJW'
    b'eVByMFkKeFFFQUxmNzl6NTF0R1prSXdteHJ5VTNIZStDaUtIV3FPeFN0WTlINXJEeXUvZzA3'
    b'ZVlyamMwdExOZTNlSDNHeG9XRlRsWUtrWG9TcApXaUJGZ1BzZyttUFRHMm5yMjdyNndPVXJJ'
    b'a3JMNUFiRFM2UGVva0tXVUYvL0E5dUdDQXRMdGZhcUZVV1Q5emI1Zkw1dG5GeFJMVE1GCjBX'
    b'eGU0M0FqU1JyOS9QcjE2eGR3OG1UVXRHbUxiSVZuY1lPMnU1T05RS2d1TGZXc3FmRmxNczQ3'
    b'dTJ4ZXZackw1U1ltbmgxbVl3T0YKUlkyeEdnWGZiWFk0ZmFsaFoxSzEvQWt5bXNZYXltUnhP'
    b'cHdGcFd1MGc0S0RTWklNQ0Fqb1BYcTBNQ3pzeXN5WlJVVkZPSTdUNlhRTwpoN05vMGFLL0wx'
    b'dDI5dXpaK1BqNGRVd1d2QlJTaXluamVOdTJPNlFGT2l3TWRoa3RJS2NTNnYxYU5kR0JBODgz'
    b'TklTSGg0OGRPelkrClBuN2x5cFh6NXMwcktTa1JDb1ZPVGs1YXJWWWtFcTFidDg1Z01FUkdS'
    b'bUlZTm1EOCtQczZQYVVDYStVamxzRkkxamFZMnZ3SXZiQUQKQUFDQzBrM090bkpuV3prQWQ4'
    b'cnJrMjhVSEdVSmFFaDdsWUU4anMyQUFRTUFBRE5tek9qVHB3OEFvRmV2WG1hWFdDd0dBQXdk'
    b'T3JTNAp1TmpWMVJVQU1HYk1tTlJ6aWUrem1GQllWc0tOTW83dk1UNEFRT2tvc0xTWE96cjZI'
    b'bXVhRnJUMEdpU0M5REUrNjY4OC9JYkZieS83CnI2OVBTa3J5OGZHUlNDUVpHUmtxbGNyTHk4'
    b'dlQweE1BVUY1ZW5wdWJhekFZZUR5ZVJDS1JTcVZTcWJSYjgxb1hGRmJYeG1URFZYYnIKMXNa'
    b'SVpzTXF0L25Mdk1ja3RFbXhaV25WSlB1dnk1a01nbnoyN0ZtUEhqMGtFa2xRVUpDbFN5S1JT'
    b'Q1FTODNPZFR1Zm01cGFjbkJ5TgpVQ3Zyc09aM2k2SW9BSzlaUXBMN09sM0YvM0pHVDBNUURv'
    b'TUgrL2o0c05uc0pyRmFGQjFlUG1leFdBOGVQTmkzYjk4OWZiTWNpd0NrCmRaZExyZm05OFhn'
    b'ODFQQWlFY2VOb0U3VDlHaXhucUtWMXlRUlhFVCtjcVhYSXh6L1lPeFlzVmlzVUNpTVJxTk9w'
    b'NnVzck16SXlIaCsKWVZVcXBWSnBkWFUxU1pKR285RmtNdm42K3NydDdDeDdVSkdrUUNDQWw4'
    b'SXVDWi9QUjE0SXlMbEV2bnRZMDJLYnBTa2N1YWZieXovYgo5RDVoMDBnQ3RIa3RaQ0dJV3Ex'
    b'MmQzY0hBQ1FtSnNiRXhBd2NPREFpSW1MNDhPRUFBSHQ3KytuVHArTTRqdU40WW1MaStQSGpB'
    b'UUJBCnJ3TVdwYXdHYXhlV05ZOVlBb0VBNko4TEMwVkFXQkQ3NWFORjd0U210OVROTGtmZmRv'
    b'M0FsVTVQdVhyVi9EdzBOSFRMbGkwT0RnN0YKeGNWbVMyRmhZYmR1M1VRaVVVSkNncU9qSXdC'
    b'QUtwVzZORFpiUTZZbUNEaGlkVldFUXFGSisvclZvNFkra3UxNUZjZEFHelVDR3hUMQpldmd3'
    b'SVNGaHlwUXBPcDF1NmRLbFM1Y3VmZW4xOVBROGNlS0UrYmxDb1JBS2hYR3JWbTBVTnBPUjJr'
    b'VEFFYXVyd21helVZSUVKdUkxCmo4ZlFXNE42Yk5hbzJzei9ZKzFGUHl4WUVCd2NmTy9ldlhi'
    b'NmlJdUxHK2p2SDVLZjc4Rm8ydWdHSjBrU296R1pUQ2lzcm9xSGx4ZG8KdFk2NTQyamNIWTUr'
    b'NkJtaFZoNEd0WG00M2xLaEhCUTk2dGlObTUrZm1KaG90bVJsWmRYVzFnSUFrcEtTQ0lJQUFH'
    b'ZzBtb3Zuem4yaQpWTXhxUGx6SmNOemQzUTJXRzdvd0FRUDhnYkxoVFhyQUhRVVZnWTZMZGdy'
    b'cm80dy9lbFR2NUZYSE42ck10OHJZb09pL25KelNqeDByCktTazVjK2FNVENhenRiVTFHbzMr'
    b'L3Y3eDhmRVBIano0L3Z2dmwySm9PTDlsb2ZXUlhqOXc4R0FvckM1TTBNQUFUbTBuM0Fwc0w4'
    b'UWkKSi9EK2U2UER0ajBPUjkvalRzUjBhUVk5QUlDTkl2RjgzdUtwVTIvY3VHRnZieDhiRyt2'
    b'bjUxZFNVcEtlbnA2Y25GeTBlMWUwVU5pNgpONm5KRUJnOHpMb2piK1dWOTFHalJqSFdybElI'
    b'QVFCQTFrUExnbWZMbTFnNjdrVzVOZ1dUZXE2K25IdEtiWlRRYUNJTTIxQlR2ZVBRCm9aVkpT'
    b'ZDdlM3FXbHBVZU9ITGwyK3ZUN1NVa2IybElWQU9BR2J0ZzJjcVIxUng3eDZiLytIVHl0M093'
    b'dG5aWm0rZlI2T3J3N29HTkEKcFcyeTh0bkFjdHRJTGY3S1h0d1lmalpubDhWODRwWXF4VFdS'
    b'YU1USWtXY1BIejRnY2ZSanRUMWxWR293eGhERy9LZkZuZlVHZlFkcwpnQ1BXL3dNUlllSC95'
    b'TDVFOUhVRzdXeEF5bWE4c3BkQnkrZlFTVk5UQlhXRDJDSEdZQ2k3ZE9sTFY5ZDJKaG12cUJ0'
    b'RFo4KzIrckJiCi84em85S21Sd3VLMzhoc1FwYTUyZWMzWGN2V2cwd2Zic05udHJzVDUxWURQ'
    b'bUJWbDlXRzMvaEhMMzk5ZmlESnJhdFhBWW9jcVRLMWoKMXpaOVc5VGE4a3djMXF0NkNRNTJD'
    b'dGY0TWhnZFA1bENITWNGQWo4L1B5Z3NheUQyOCtXclR1eFJCelVKcTN0bFJmTE1wcUw4aUJQ'
    b'cQpaeDV1citIZDhkUUlHbC9oVEE0ME5xejQrMWRVaURrbGJoS2FIUlZGbHltQXdkUXNxZTlP'
    b'Zi9sb0krWHZtTGZmRUVhZXZxT3pSaHFDCnVLTEhaMUhnT2tnVllmRjR2SmlvMmN6N1paM2Vj'
    b'L1Ewd1ZwYzFVQjBhTlpvbjBvMU15YWF5K1ZDWVZrUEc5ZXV0OG12QXAyOTJUcUQKamxUNGk4'
    b'TnB1cjNhUm9XeHZjNGJDT0tFVHJ0KzB4YUtCSndxd2hJS2hRdm16bWZkSyszOENES3dSeFA3'
    b'YmczcE9WWkNuNEJxbGpiVQpYREkyTnJZYXczYlYxMzJ5NUROYlcxc29MR3RqN2VvNGZtRWRx'
    b'SDg3aTVKdGJhcUNQSE1tOXMwZUxBN1l5RHpwVy9jVHFIdDVXMFFSCmJyaEFrSEZyMTFFbjJo'
    b'UVNGby9ITy9EUEg0V3BSVy8zWlJEUXJ5ZHpjNXo5aUM5c0RpQzFadHVLdXBvOSsvL040VkJv'
    b'UjI1cXJZU2UKT0hGaS83MjdianlzTU5MQW50K2FoaTRqMFN5aE5oS2Q0NVdKVFhLNUlWT25F'
    b'L241aFlhRlVTclUxajlYMklLeXNySytBZjdWNDNvMQptNldoWXdDekdMeE5STFBheEd0NzlZ'
    b'YklDM25wT3Z4MmJyNzVIdVczd2JzNVYwaTVKZlpPVGs3SDloOFVKTWtBSFFNcyt2TUgxandP'
    b'CkdOcmtlaE12ajMxVnB6OXcvT1RiVXhYTXNkNGh4bzBiRnhVYXdja29ldHN2eEVsOUVqMXYv'
    b'cGl4WXlrWVpJcnVOck56K3ovdWo3dWYKbVZPSzkrME9BR0RYTjRxcm1uNVpxVW9zMWdxYU1x'
    b'Zlg4ekllbFBkbGk3ZC84eTAxSTB4UllXRVlkdjdYTXdNR0J6emxLUWwzZTRkcQpaVkZjazlk'
    b'MW0vS1poWFJldzRzOFViZ1VheTVuWHFmUktCcGg2bTVqeE9memt5OWZGVXZMa1pLYVR2NUNW'
    b'RkxUN1hiRnRjdC84SGc4CnlvYVgwdnRqdWJpNFpGNVBjY3dzMVNzN3JXcUtWMnZGR2ZMVXBH'
    b'Um5aMmNxeDVicUc2KzV1cnBldjVKa3lGZGR6dXdFYmYyV3JqYmsKcTlLU3JwbjNNNExDb2pU'
    b'ZTN0NDUyVG5MZmlUK2VhYitUZm81Y0VHMS9FZFQ5cTFzcUNwQTVUMUlMZW5ldlh0RzJyM1JJ'
    b'Y0d5c3VwdAppMFd2ZXJpSkFGL3NyVTU3N0hBck01VTYwOHh3eE9vUWRuWjJtZW4zYW1pamhp'
    b'OHJKL1Ntamg5STZFMURQeTlUTVVlbHA5NkJxb0lqClZoc3dHSXpEQjA4ZVBMZy9kczEvSVN3'
    b'KzZlNWd0dXNCdHZKWTB5M3dlaUJzK2dMNFJORW9WUzdjdWlNbVpqNE1JQlJXZTh5YjkrbUkK'
    b'RWFQRFowUStmVnFnQ3V3Qk9NeEtENWNmZ0V0VEMvTVBrNnYxL014bkhuVEJtY3piYm01dU1H'
    b'N3dVdmkvNCs3dW5wMXg2N3VGWDRvUwpjMW5TWXFBM05IUHJEU3hwc1NneGQvdVMxVm5wTjZH'
    b'cW9MQmVKUzRvdXZEVEJZVzVEMk0vbUdKM0trZHdyUkRrbDRIOE1rRnlvZWpYCm5GVWpJcC9r'
    b'UGZwMC9ud3EvZXpTcTBHNTIyWmVBeHpITDErK25IUTltU1RKajBhTUNna0pZYnpLV3NLM0RW'
    b'eGkzNFdUK2ttVEprMmEKTkFtR0FsNEtJVkJZRUNnc0NBUUtDd0tGQllIQ2drQ2dzQ0JRV0JB'
    b'b0xBZ0VDZ3NDaFFXQndvSkFvTEFnVUZnUWErRi9BQWZ1MjdidApPVHF2QUFBQUpYUkZXSFJr'
    b'WVhSbE9tTnlaV0YwWlFBeU1ESXlMVEF5TFRJelZERTFPakF5T2pFekt6QXdPakF3MGhzVjdR'
    b'QUFBQ1YwClJWaDBaR0YwWlRwdGIyUnBabmtBTWpBeU1pMHdNaTB5TTFReE5Ub3dNam94TXlz'
    b'd01Eb3dNS05HclZFQUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAgaWQ9ImltYWdlMTUyNTAi'
    b'IC8+CiAgPC9nPgo8L3N2Zz4K', 'CA_NT')

CA_NT = b64_CA_NT
index.append("CA_NT")
index.append("Canada Northwest Territories")
catalog["CA_NT"] = CA_NT
catalog["Canada Northwest Territories"] = CA_NT
country["Canada Northwest Territories"] = ('CA_NT', '', 1)
lookup["CA_NT"] = ('CA_NT', '', 'Canada Northwest Territories', 1)
lookup["Canada Northwest Territories"] = ('CA_NT', '', 'Canada Northwest Territories', 1)
details["CA_NT"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["CA_NT"] = ('CA_NT', 'Canada Northwest Territories', 1)
regional["Canada Northwest Territories"] = ('CA_NT', 'Canada Northwest Territories', 1)
#----------------------------------------------------------------------
b64_CA_NU = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTg4MiIKICAgd2lkdGg9'
    b'IjE3OCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNzggMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX051bmF2dXQuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczEx'
    b'ODg2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTE4ODQi'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTE4ODgiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMTc4IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUxJQUFBQmtDQUlBQUFDdGovME5BQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFPCkYwbEVRVlI0'
    b'MnUyZGZYU1UxWjNIdi9jK0wvTSttVXhlVEVCSklFaDRLUTBCTllwMUcycmQ1ZXpLYWlXMEIx'
    b'djI3QjUzUlZaMHUzVVIKZ213bHRidTBpNnZkYmVsYVBCeGRWMXU3VXNSRjhZUlRqYXU0VUJE'
    b'a1JRekJFQWdFU0VpY0pQUDJ6UE4yNy80eFNTbzJsQXpNMEhsbQpudTlmejNubVBqZjV6Zm5N'
    b'Ny83dS9kMzdlNGg1QkxhYWQrSWZuNFk3T1BmZk4yeVlOV3VXL1lYUVBMZGYxZkRBNC9qVHBa'
    b'QlB5QVA3CjkzL3BsbHUyYmR0bVkwSHkyVnQwOWFCaE9RNjNrVWEzdDhIcFVqbGZGWTIrWStp'
    b'L2V2WFZPKys4MC9ZVythaDNQOENOQzNHMm5mNlgKdjdEQjZRTGdJT1JKbjY5ZWtocnV1YWU1'
    b'dWRuR0l1LzBpemZ3Si9kaGtpTDkwaGVjTG9vajl3Vmd2ZGQzcXlCKzdhNjczbnZ2UFhzUQp5'
    b'U005L1o5WXNSNTNPNTFOWHI4d1dnT044MlhSeUNkTzU1NTkreVpObW1SamtmdGErU1NlZkE3'
    b'M3V6MFBlenprNHMzQ25DK09oTjJWCmxidjI3UEg3L2ZZZ2tzdGF2d2xQUFk4MVh0L2YvVjRt'
    b'QVBnSitZbkhlNmFqNDV1TEYzUE84dzBMNGZFSDg4WFV6YzFZdGhiLzRQVXUKY2JuSDByNlEw'
    b'bW9xUFAzUjRjTEN3cHR2dnRrZVJISlQzM29VcmIrV1h2SVhwdlRVdW1oMEszaEhaMmRKU1lr'
    b'OWlPU2d6dmVoSEVLcQpUOTNuZGtjVlpjK2VQWFpza1pzeURJZ2s1YWRjaEFCUVZkWEdJbWQx'
    b'R2JIaklHTUFBb0dBSlF6OCtHek14aUxGNkZvQVMvMnBBYzRBCkJJTkJTOWpZdUtXOTVXaS9q'
    b'VVVLOG5nUVE4cnU0b3pKQUV5WU1NRVNOazRJT2hmOCtNQmJyYUhQM2QvWlByRG0xZU0yRnFQ'
    b'STUwR2MKcE93dnVrelQ3L1ZheFZ0VWw3bmptbm5YVHc2T2tMR3pmZUQyZjkzM1J6Lzg0S3ZU'
    b'VXpCQnpDOHNMc05iTUhOU1ZaVlZiSnhXN2dHUQpKT05mRmwyLytZT2VkOXI2QWR3K0xWaGZY'
    b'V2hqTVRvV3NkUmp6aTdPcTZaTXNSWVdTVEtXdjNSMDVQNTNGNlNXMmFFMkZwZkFBckNRCnQr'
    b'anFWd1g2K1ZuNC9DOFUzWFo5YWpPcFBQSVdmZzlpWm1wWW1NQlpUYXVzck14KzYvYWZpcXg5'
    b'N2ZqcmgvcCs5Nk83YTB0VDdTMi8KQmhIRjVDWlNXT2s4WlpvNlk5WFYxZGxzMTVHenNlOXQ2'
    b'OWk4citkaXJ2QTd2enhXVmVLNmZWb0tJV2NlRFNKRkFmRGg1YWt4cXRYUQpBZFRVMUdTdFVi'
    b'MFJiZXVINTBWS1psM25jOHVqQTUrTVFOOCtHcks5eFNncUNRSkFIMk5CT3RZZlE1dGhYRnRX'
    b'Vmx4Y25MMUcrZVRICi9teGk4cHB6ZElhVWwvZjByTjdTbnJ3amkxUXpXSktNUC8veHdmOTVx'
    b'T1lyVTRNMkZoZW90QWdBUXFsNGk2T00xYzZaWXhVRENVRmwKa2V1ZTJhVkpMQ2doZTlmY1ZG'
    b'N2dhRDBYTzlvZGF6c1grMmxMMTdpQVkycVp4OGJpdDdvbWlRVlBBWXMyeGg2WVBkdGFaazRx'
    b'Y1RsRQpxaHBzMFEybE04ZDdBZHgyZlNEVm1VZ2V4UlplTjl3eStzYnNMVUtNOVdwYU5nY1dv'
    b'Ly9RS2FrcWRRbVVwTHBXa2FmZUFrQnBJUWxGCnhvckZVY1BJOG5qellwcFc1cGs5d1QreXRH'
    b'VmpjY253Z29jR3g3cDBjY0RRZ3dVRlZkWlp5eHJSalBIZXhUZVZYVWtQK2JYZll2dzQKZEhO'
    b'empJMzNtdWFYNitzSklaWXo4K0hicjZzdWM5dFlqRGtjdXc1ZEdCTVdHdWVIZFAzTDgrWlow'
    b'Y3lnUjdyU0FDVUxyVHAwREorYwpSTEFBcFVVb0NhS2tFT242eFY1ZmdiTzZxWU5MdUVTUHUz'
    b'VTlZWnAzM0hFSDhsSlpoOFhMMjdIa1VURCsyZEFheFFVb0RhS2tHSUVDCitMM3dlK0gzREYw'
    b'RWZDandnUko0UFJBRnVGMXd5SERLY0RraGlmQmU2RXB2cm9IT3NDZ2NxaVh5VEVtcUVJUnJL'
    b'QzJsVlA0TWR6cDQKajhtMkpoTFZreWRQbno0OVA3SEl1Z01CdDM0RG5uYkhEN3orRUdOOWpJ'
    b'VVk2K1BzVThaQ2pQVXpIZ1dMRWg0RGkzQWVOWG5FdUhUOApLRkQ0WENBRUFROEI1WjNkRnpD'
    b'WFZJRkVSbjRrWVYxUGZsNVRVek4vL255bjArbHl1WWFtdUY2dkpBMzU1MEFna0F3N0tLVUZC'
    b'UVhKCm03SXNlenhEOGIvYjdYWTRITWxybjg4bml1Sm5IN2V4U0hING40ZjVVYy9EbnJGT3Jp'
    b'S2N4em5YT1U5d3JnSTY1d3JuSmhEam5BTVIKemdDRUdRY1E0OXdBVnpqWE9UVHdCT2NBZEVE'
    b'aEhCU0VRT0dDeGprUktFQml6RFE0QjZVQXdvWUJBSVFZak1XUzE1YzM1QWNDdjltNwpkL0xr'
    b'eWZZZ2tyTEtTOUViTnNmZTNrZUk3dzh4V2RBNFR3eGZLNXpydytuTEtQL3RWQ2M4dkhSbUFE'
    b'SE9HeU9SOTk5LzM4YmljalN4CkFoM3RadlovY1RJaDh2QzFmd3hjSGpFTXpUUW5UcHhvaVVF'
    b'azZ5YW9jMmJnb0c3RWMrNDA4Q3NKWlh4WjJkeTVjMjBzTGtkZit5cFUKeHQvVnRGeGlvcHVa'
    b'cjJuYVE5Lyt0aWlLTmhhWG84cnhtRjJOWmkyUlMxaHNqTWY5ZnYrREQxcW1Pa0Eycm5MKzlU'
    b'ZndscXFlTU0zYwpZT0ljTTdlbzZvcFZxN3hlcjcxdWNmblNEVlQvTVdhR25ULzA1a0labXJY'
    b'UnlOdE81OGxUcHl5RVJUWjZDMG5FeXFWNE01Rm91NEpGCmdpeFJtUE90cXJxeXNkRkNUQ0Jy'
    b'eTU1b09tNXFnSGxhZk1sWEtGc3doem1pYlluRTZtaWs2OHlaOHZKeUMvM2JXWnBCbFNVODl3'
    b'TjAKTU9QN3NhaWx2Y1hidWo2bnR0WmFUQ0NiRSt1MTA3RHhDV3hKS091aUVZc0duekhPZHhy'
    b'NndxOS8zWEwvZVZaUG83KzVBQWtWeTVxVQpWbTQ4NHZUV1dDVFBOS0wvVmhRRFdMSmtpWTFG'
    b'bW5WZkE2WldZZWthL2Q2VC9RR0pYQ05RRWNRQjRnQVJHZHlFRU1CSEtBQWZKUVJ3CkV5S0J5'
    b'QVJPUWdRUXoxQURBc0JMQ1FWeEV5SUJFaUV1UWdUQWs3SEE1YkNoYjBnb3k1WXZIemR1bk9X'
    b'd3NFYWxQYzd4emg3cy9RamQKZllnck1CbkNVUURvRHdNR3dqR1lCb2tudUtvUlZlTnhGU1pE'
    b'UkVtaC93S0pnTU1yT2lqZ0lrUUdrVGgzRWdpbW1lVEdUK2d3V01NTgpDRnlFVU1CTEtJYlRJ'
    b'aDVDS0VFZlk3czFmYk91M1ZoWDkrYU9IVzYzMjhZaVc3UnBNeDVZaSsrNHZYNUtWQTZGOHpC'
    b'bkhJaHhuanlmClBKSjI1MENFY3lKQWc2QndyaE15eU5pQVlhakQ2Mmx1bDJ2bWpCbTZxaWtK'
    b'SlpGSWFKb1dVeFJtbXVIWVJRdFZsWldVTEZ1K2ZPWEsKbFNOYkxtd3Nza0wxMzRMUUttL3dC'
    b'UzY3QjRYelFjNWVUNmcvaXNkMjdkcFZWMWMzYXJPQmdRSE9lVFFhMVhWZFVSVFROTXZMeTYx'
    b'ZQp4RE0zc1lnblVIQURIdmY2a20rRXVLTHhDN2czRXI1dTNyelh0MjlIM2lnM2QzNjNuUURq'
    b'bUNLa0lhQW13SHhSYkdscHlhdlNuTG1KClJYc25BRlNtS1l0ZEo4bnhSR0xmdm4wMkZ0Yldt'
    b'Zk53Q2NTZnBzbG5wU0FBNk9qb3NMR3d0bnI2VUNLbWJVSENTVWloTEo4NmRjckcKd3RvNjE0'
    b'Y1NJcVN4UXcrbHNWak14c0xpV1BTZ21LZlROQWxFMTNVYkM0c1BJdWRKTVUybmFUcTRaTFdN'
    b'akkzRjUzVzJsNWZRZEE0aQpnNlpaVkZSa1kyRmh4UlA0TklLeTlIbUxRYzZpdW43dHRkZmFX'
    b'RmhZcDg4QlFMbVFObS94a1c1d29MYTIxc2JDOGxpa3kxdUVHSHMyCm9jeVlPdFVTaHdUVHBS'
    b'd3NrblNzRXpJZGs3Y3dnVTdUT0creUVHY3hQblJxT2NKWmxQTkJ4Z2NKdW9FVHFscGFYUHp5'
    b'TTg4UUsyOHAKdGJIQTBRNVV5cjhQaXJPbTJheXFMYWI2c1c0b0YxWUI5MVBxSmtRQkJvZXo2'
    b'b3NXTGRxNGNhTlZYa3BsWTNGUnRiYWo4bmZzWXNCSgowMmhSdFY4YmljUHFVRmtNcDBEbU9L'
    b'VXZFR21tSkU0U3hBcEJjQTY3aEREblIzVDlKVFh4eWl1djFOWFZQZkxJSTNtRlJVNGwxai9w'
    b'CnhLWmY0Wm1mSTZMQUxaQ2dTSnlFT0FnSm03eFhaOG1DRmhOa1lSYVZ2aWhLTlpKVUxZcVhI'
    b'R2wrRklzK3I2cXRiVzFXTExsbmV3dnMKL1FoZitRdjRPYjJOeWg0bk1jQkRuQStDdVRpcElM'
    b'VEtMVXdSeEJwSktrb3hGUDFidCtkbFhkK3laY3VLRlN0c0xLeW52LzgrcWlBKwo3eTkwcGpV'
    b'MmxBa1pMNHFuVDUvT3EwRWtSeWFvSFYzWWRSajNPenpPRE13WEdKQlgwNURjd1dMWGg2QUVO'
    b'OHB5SmpyWE9KeE9wNDJGCjlYVDhOSW9sbXFFaVdpcTRqWVVsMVJ0Q2tHYkt6NnVNV1hSZmY3'
    b'NWpvZXB3SUZOWWFJelozc0tTY3NwUWtaRXFiQ3JuTWNPd3lsdVQKYlN3dVVIRWgrbGxHc09o'
    b'bWpBTVZGUlUyRnRiRXdtQ1o2UG1jYWNMR3dxS2FVQTZOb1p1bHZ4REdjZE4weW5KZTdjRkJ6'
    b'cXh5MW4wUgprb0NmSzhvZERvZkowV0dhL1l3QktLYTBoTkppU3F2R2tQNFlWWHNOL1lZNWMr'
    b'VE1ySWpZV0dSV0pVR3NYb29uL2lPK0tSNGZ0VUdCClFPWktqbHNrYVpvb1RSYUVNZGJqNm1Y'
    b'c1hWMy81NFlHNUpseUtvTjY5NFBZLzMvMHV5NS9JYVZPQWdlSW01QnpqQjNTOVVPR2ZzRFUK'
    b'VCtrbUFJR2dRaGJHUVNnalFwbEFQWVI0Q1IycGY2S0RoeGc3ejlqSGpCL1F0V3ZLeXZZZlBK'
    b'aFgrM3VSUzZteTQ2Znh4djlpcmRmegpwUXNkZnBEU0dhSzRHQzRBbnpKMlVOY1BHSHFiYVJ6'
    b'bnhrNzFvaVdrQlVLY2dxQ2FwbUVZTFMwdERYbm1NSExIVzZ6ZmhPLzlHOWxaCldPd1k4eEo0'
    b'blBNZU52UU9HejRjZ1JkVE9rNFFpaWtWZ0hiRDJLQW9PeExLdW5YclZxMWFaWHNMNittTkZ0'
    b'd2l5WTVVMGlKdVFpWUsKd3NTTGIvQ2JMSXBQKzN6UENMU3hzWkV4dG5yMWFudUNhaVV4aHYy'
    b'dG1DMW01T0RYQTI3UFF4N1BtalZybXB1YmJTeXNwSTR1eEJMcApxWE15cXBhNlBiYzZISCs1'
    b'WkVsZlg1K05oV1YwK0JnQVRNblkyem9JOEU4ZWIySmdvS21weWNiQ1NsZ1VTV2sranZ3NUZW'
    b'UDZWN0xqCjJaLzlMQjgyOE9VSUZpZlBZSUtROGZENVhwZkxROGhUVHoxbFkyRU5uVHVQSXA1'
    b'eFc5eUUzQ21JdjNqeFJUTlhYb0dUNDFpYzcwVkcKUjVBUnpYYzRldnI2ZHUvZWJXTmhBWFgz'
    b'b2VpcVlERlRrbVJLRHgwNlpHTmhBUTFFRVNEMDZueGY1YkxjMmRscFk1SHRNa3drZExpdQp5'
    b'bEVPRXdpYnpEUG1kMzNiV1B6QkZJc1B4WU5YNFcvOU5CYUxNSFBod29XNWpVVXU1RVJNZHBV'
    b'czJhdHJ6eXJ4cGllZW1ENTl1dTB0CnNsMkZmcmhsZEdaNDBuakVNQjZPeGVycjZ4c2JHKzEx'
    b'Q3d1SUVEVE14d3RhL0d6R3lQaU5ydDBmamN5b3JYMzF0ZGNvcFRZVzF0RDYKUitFdlpZdkNv'
    b'ZWZpOGVRdXpuU0pBNXZpOGI4WkhLeXJyMzl6eHc2Zno0YzhVTzVzd3htSVlOV1RlR0VyREJO'
    b'VEhlSkVMbGFJUW9VZwpCQWwxRVNJUlVuQ1JtRFRLK1lpVENROGp4WUFvNXdDMjY5cGJpY1Jq'
    b'anozVzFOU1VEMzRpMTdCSXFqZUU3ZS9pL1EveFNRZU9uVUIzCi81VjJHUEQ3WDNqeHhRVUxG'
    b'aUNmOVA5VVlKbFpFUUJjUUFBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TWkw'
    b'eU5sUXgKT0RveU5qbzFOQ3N3TURvd01PZ3M1WW9BQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1'
    b'QURJd01qTXRNREl0TWpaVU1UZzZNalk2TlRRcgpNREE2TURDWmNWMDJBQUFBQUVsRlRrU3VR'
    b'bUNDCiIKICAgICAgIGlkPSJpbWFnZTExODkwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'CA_NU')

CA_NU = b64_CA_NU
index.append("CA_NU")
index.append("Canada Nunavut")
catalog["CA_NU"] = CA_NU
catalog["Canada Nunavut"] = CA_NU
country["Canada Nunavut"] = ('CA_NU', '', 1)
lookup["CA_NU"] = ('CA_NU', '', 'Canada Nunavut', 1)
lookup["Canada Nunavut"] = ('CA_NU', '', 'Canada Nunavut', 1)
details["CA_NU"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-07:00 | -05:00","altname":""}
regional["CA_NU"] = ('CA_NU', 'Canada Nunavut', 1)
regional["Canada Nunavut"] = ('CA_NU', 'Canada Nunavut', 1)
#----------------------------------------------------------------------
b64_CA_ON = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjEyMiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09udGFyaW8uc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczEy'
    b'MTI2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTIxMjQi'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTIxMjgiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMjAwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQU1nQUFBQmtDQUlBQUFCTTVPaGNBQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFOCjFrbEVRVlI0'
    b'MnUyZGVYUVQxUjZBZnpPVFNkSTBTWnVtYVVnWG9VRHBLcFMyUUJXT0N5QzdjQUFSZlUvRUky'
    b'S3B5OVBud2lKOTcvaGMKUU5IejNBVkZmQ29pSUlwNlJFQVVGMmdGcExRVVNxbVdwYlJOazJa'
    b'dDltVXlNKytQYUMyMUxVM0laTUg3L2RQSlpPN012VE5mN3YzZAplMmVtMkttcGQ2YXRMRSs0'
    b'b1JUNm9LRkpzKzZ0ZlZ1K09FclRESVNVQlRPS3RyOStqMy81aUd4VVAxdU9NOWY1RnhZKzhN'
    b'Nk8zVFdoCnpRYU9Zek52TEhqeTRWbWo4ek5vaDFPLytiUDJselpST21QM2JTVGpDdE5XbGpm'
    b'T0xRUEV3T0Raamh4dm5Gdm1QM0c5NnBXWHBYcnYKeGNYTHk2WndwRmNFNmFHVWRzT1dYcFZT'
    b'UFh5M2JOcjF5SlhBeFBMLythdnBoWlRpWEN4ZVVxTFAxTmxkTCttRWtyU1Y1ZEx4SlZlawpY'
    b'aGNwWlhlMC8vY2R6UnVidTg2QUgrbjRrclNWNWRJSkpjaVA0TTl6NFlrOWc5Y3VKMVBrWGF1'
    b'c2xkV25aeTFwbUxiWThzUGhYdFA0CjlhcmJ2ZnJPZWVNSUFvOGhwVzZlZFBYUkwxWitzYkY4'
    b'NUJDNWRzT1d1dUtiVzU5K3JidFZrbkdGSTdhK21ydHJFN0xxY3M5Mlk3dGwKMExLL2o2clox'
    b'VU12ZisxMVNiMk83MTY5Y0ZZeGptTlJydFRDV2NWMWV5citVS3BvMW9WVjY3cTNmWDZsOHZh'
    b'KzMxZmJWLzlyTzlJbApnSE0rYXZvemM1YXVQOUZzREU2di9DelYxbGVYbk5oVEVaMjFWMWN0'
    b'dGZYVkpUbXBDY0VwZGFwSmM5ZGo3NCtldVFicE1uQXdMTE04Cm9DNTNDQWNtT0IxdUdHQ0or'
    b'Zy9QVHpWcFh1aFdva1BtS21STVlHSUZPcUlURXIwNEVvc0xwZndnc1lJVUs4eDZoVndzN3BS'
    b'Q1lvVkEKckxEcEZVS3h1RllLaVJVeXNjS2dWMGpFQ285U1NLd1FpOFdwWHBjcFZqaVZRbUp4'
    b'SWhaSGVnVXRWdmlWUW1KeEtGYkk5Zko0ZlZ0ZgpYUktRV0xjOXVNbmw5b1pmS1NRVzUyS0ZV'
    b'SzgyalRsZEpRdElyUE90eHN3TWVmaVZRbUlGTE5hdDkyKzhEQ3V4b29LTUJUT0tNelBrCnRO'
    b'M1JzWEdiNDBSamoyMmtFMG9VZDh6RkJmeitkelZBc1FEQTNkU3NXZitoejJ5NVNIUStxVmcw'
    b'cjU4SnZqYU4rWXR2VDFRZVBjTXcKYk5EbGZXVExhOGlZZ2JyQnNtdzA1R1BnWWtWdEpoRVgv'
    b'ZFRSS1VBZ3NSQ3gweFFlVGh5SnpnSUMxVmdJSkJZQ2lZVkFoQlllT2dVUgpSOGRRSjJsblJB'
    b'NDlraEFwY0JLSmRXVnlrbllheSthWGxwWUdtckQ1OFRXVXdRd0FaTEpzeUF0UEJKcjgwS0ZE'
    b'SjkvZU9SRlBRR0pkCnNaU1dsaTVZc0NEUVZNZWYzdVN4TUFBZ2tDb0xBMC9Pc3V6WnQzZWlH'
    b'QXVCZ25jRUVndWRBZ1FuTVZaTXpPK2lTV2cwM0lBSUJ1T08KM2EwTkFUOXBUVnRzWFF1dC8z'
    b'a2w0SU9lcWtWaVhlR1lkbi9mL2szdzcvM3lXZTN0TDc4YmFDb3oxWWtCVis5RzRDMTg0SjJn'
    b'RTNlLwowYSt2YmF5VjFmck5PeGt2ZGRGUlpRbXE4anVFV1VOQ1ZRekc0OVYvK0ptMXNyckgr'
    b'dmlST2NxbHR4SGkrTkRjNklkK0FRRzRjZG0zCkp2ZTFqZTF3cmZyNURUMWUrc0JMU2xRdXZV'
    b'MTEzeUpDS2c3NjF1UitqdGorOHJ1ZFh4L282NGlYK1haQ2ptNU4zazlaQUdBU21SRG0KYTcr'
    b'ZjZzUUFtOGpOY1MvcllZcWdsUXJKd3hUaDE0czdzVElxSHB3NythWkFFemJkOGJDM3d3Z0Fm'
    b'S1U4NjhPWEEwMis4OXQ5Nm1kZQo1MGdzWGdTVWV1clRyc2UvQXMwdXk3SmY3ai81MWZmMS9l'
    b'UkVVam82ZTl0clBmVHltVHJWejIvbzJMaE51ZlMyN1BzV1JkdnI0NFRECnJoS1hCSHhqSE1i'
    b'bmR5MEVrVng0cmpIQ3dYdklsYnJjaUlxNU12WDZDdzAzUkp0U1NLK1lGeXVhbFVKNnhhUllz'
    b'YUlVMGl0bWhodEMKMk9PTGtoZXZoYmJueUZHdjhEMjM3bUNtTEVXaENIalE1MXdiUnZrQWdD'
    b'VjV6TkQwUUpQcjlQcnJtczJMQlNrY2loVm1wVGdWaXp1OQpPQkxyTzhxeWVqTEI1c3JDWGFr'
    b'MG1OZnVwMi9nYUxnaEZodStTRFdPWEY1a0FDeVkyWlZpbVFNQWpwbmpnendvZHpGVzNaNksv'
    b'Q3hWCjBFcWRhdEk4VTdGOXgrNmF5NWtxQ1lOZUMyWVVWVHc0bzllU0RsQ3Z4OHVtMk1kT2k2'
    b'clM1U2U0WGlscXdURDIzcU9acHl4eFVaVTMKdkMrcmJJZHJHK2VXTlV5L3E3dFZ2S1RFdEJY'
    b'TENtdS9TbDlaL2t1SDdhN0gzaStjOGV6MlhjZWkwNnJ1ZW0zZmRjei80dkhhVTYyOQpidVBY'
    b'SzIvUGU0bFRyK3RhNmRmcitPaVpiYyt0ejFGS3VLdXRnbU4rbWhrSGxnQzRKZDBVQTcxQ2Ey'
    b'VzErcm4xMXFycUhyV1U2djVGCnludHZKOFR4VWRqd2hiWnh0RlpWcTU5YjN6V2wzVlY3Y1pp'
    b'NWdmMHdSVHltTU5FNVRtNXZkZkkvYlV2Q01kYm9JWEFNY0l6Rk1KaWYKYnNvUWVZOFl4Y2M3'
    b'UlU0ZkhrVmlEU3c4L3lTbXUrSUQwVXM2dmtUNjVhWS9ONDRSenp6TllxOFhOZE1zNW1Hd1pj'
    b'TjFSZzh2UytMRwpNYkRUeEw3ckcrTUlobyt6aXdZYnJ0bWZIeTAxVml5RzV4RUo3Y00xQ0FS'
    b'U0htMmhpTzRyaFRoRFlIREVLQzVOdGpkWWhTTVRYZU9TCjdIbzNEOGRnaHFyekYydmNJV1A4'
    b'dGNuMkkwWXhBU3dmQnk5elVSc3I1dEVPbWdqYlM2dHdhMVgxNlZsTC9oeExaZnpyd2NLNjNW'
    b'MngKMUtnWnozNnc4OGdWTm1ibzEydk1uT2N1R1h2bDd0clU2NzlENHlqR1N1TDdqazJ0ZjN2'
    b'TStjSkVwLy9qVzJQT1YwMXVHSk5rcjZoUAovMEVubVpQV3FSQlF0V2FSMXMzWGVjaGFzeWds'
    b'amxvMHhIaEFMNm1vVHg4amQxUk9ibml0NkVJaW53YUFxeE9kYnhRMzEweXBsNUcrCjhQMDIw'
    b'TnRtSXM1UGxHM2xkYXkzTUxscnpkUkJsamRMbXR1Y3BKWGl6YTRjOGVLb2xyRkpkaEdQK2JR'
    b'MWFjM3BWQUJZbGRmK1JHNjcKelVmczB5VGdHSHZUSUt1WVI2ODVuYnEySVJVQUhzM1JMQjVz'
    b'c1BxSUtvTmtSVjNHNXhPYVV2aFVzcEQ2UiszZ3ZackVycVB3YXd6cgpLckZTa3BOT0NYcEtK'
    b'L0tJTVp4MDBOM1g2RHlreVVQVWRZckd5ZTBWZWVxN2grb1BHY1Z1QmovckVBQ0FVa2c5TWtK'
    b'N3dpSXllSGd6CjB6cG5xRHAxYnQ0SmkralJiSzFTU0FHQTFzbTMrNGhEQnZIU29ib1Z1WnBy'
    b'azIzSExDS0xsOUM3TDNxYVh1RHdTWENDcTZZUVhkZUkKazRLVFFxTzMrNXBhcytpb1NUeGRa'
    b'V2wxOHBmbmFMUnVjbDY2MlVYakg3ZktBV0JpaXZVWG16QlA0dnBlSi8zZnVlUjN6eXQrMUVu'
    b'egpKSzVmck1LSktWWUErS2hWN21XeGVlbG1nNGRYa2FkV084bUpDbHVOSmI3SE9LckE1RlZn'
    b'SkVlRlFnOVRSQjRsemhlWVBmN2xRVUtxCmJGZ0hnUUdPd1NBaDFlRW1LUWJyOUJJRkNhNGFj'
    b'L3dVcGVWcmJjTFdGdm5XRm5tTzFOVm9qVnVlb3dHQWRZMnFOOCttTkZwL0d5T2QKb3JRWVBM'
    b'eGltYU91VTZRVVVoU0xENDkzZ1ZIOFZFRWJ3Mkp2blV2UnVFZ0E0SnU5S1RoWFloSDNDSlhv'
    b'MGtZV0RHQXZiVEdNbGcyVAplbDR2dXBDWDRCSVNiSnJRcS9md0pDVHpjYXM4VGVUVnVNalVP'
    b'T3FHRkp2TlI5UmJSQUJnOEpBQU1EN1pEZ0JWQm9uL0l3QXN5REE5Ck5LSkRTdEp1QmlkdzJI'
    b'SWhXUlZIT1dsQ0lmQ1JPT1FudW01TXNSd3hpaTF1SXVPb2VRNmJnR3FzSzVucmZhTEdGcHN2'
    b'WDRCaGtDencKOFRESVQzRGlHTmg5Ukk3VWxTOTFrVGdMQUpVR3lUY2RsMURoUjUxazZWRGRX'
    b'SmtUQUNnR3kwOXc1a3BjSWg3all6R0hqNGpER1JHQgo4M0FXYTdaTzlNVnpGd29oc2FLQzZa'
    b'RHd5VEg5aGN3aFpkV1o1Y002QUtEZUduZjdWY2F6ZGtHeHpHR21lRXQrem14MkNPdyt3dWk1'
    b'CnhDWFRlY2kvSFI0dTV0RnBJdS9tc1dmSHlSMU5kdUdvUk9mMmxpU2Rtd1NBTjg4b3RXNVNj'
    b'VXc3RFJUY2xRaUpGU1ZoRnFreStneHUKV2dQa3YrdlQvUU1LYlM1K1dweDM3ZWxVdFpQL1pJ'
    b'RjZ5Zzg1UGNZOCs4TGc0WFY2aVkxanpxOCttWkVpcEI3SjFtcGM1RG03Y0Yzago3L1BDTGwr'
    b'cWlVN21MTUJDdmNJb1lpbVZKSzNxNlBwNDJDQjIrdkI2aStqdHN5bWZxMlcxWnRHekkxc0h2'
    b'cmNuQzlSTk51SFdGdm42Ck04cEdxOURtSTZwTmYzUUpwVlVkUytra1RvdUR4SW9XeGhMaTFD'
    b'WUh1SDhiMEtyckZNMDhrRDI3Y2dURllBQ3dxaTZqTU5GNWYxYkgKUUhaMXoxRDlCSVh0c2VO'
    b'WEFZQ1h3YVlkeUpsemNFU2RSZFJWWGFXZmNaWGc4VWlzdndyTDZaU2t2VzMrWlpPWHAzV1RY'
    b'Vk43YmdhLwp0V3I0blVNTTh5NTFoOHpOYWVabHd6cHVxY3B5MHI5ZFhKYUZOaGUvS3ppVDdW'
    b'V3ZvQlZjbHdXSkZVWGs0WEVsR2hadnRmZjZyWm5pCnphL01lckpBUFQvRDFJOVZhMGUyemZz'
    b'cHk5QkhqRSswMksvUlFqWWVoOFQ2YTdHS0haUzJweDA4ZEsvZnRybjRNdzlrcjhwcFg1eHAK'
    b'K1BPM3QyYVluaTVReno0NG9zVWg2SDN2SGpwMWovcHhOaHdqbDBpczZDSU93NStpbFBMUFcv'
    b'cmFvTlhKbjM0dzUrNU1mVVdlR3YrOQpqNGhoc0NKWDgxQzJkdXFQMmVmc2dyN1N5bmRlZU5h'
    b'bmlzUENjZEhSM1EzUnlFNjJjME8yenpvcHRhOE54RHo2emVKbUVZOXB0TWF4CkFNUEZiZ3pn'
    b'M3VwTUs5WG5wTExrVzNYNXIrUThMREU4UlVCVE90RklMaWJVR20wdGpJZEs3NzN2NW1Yd3o5'
    b'UkpDcUZ2ZVk1bVRKTGoKb3d2Smo1KzR5a1AzV1JXSkQrbW1OL2lXWU1saEt3SVNLMG9aRCtJ'
    b'T2phV1Y5bmpUK3h3WE9Hb1NDd24yWjZQNCtjYlVmbllWLzdOKwpZbzE3QlRZb25QbEhNVllV'
    b'ano2QThxWmF0L2l3cnA5dDNEVHVvdnU3aUtLaitodXJuYXZEYXhVU0s5cFpBWU51cXZGSTk3'
    b'Y0hrNWdGCjZUZnFhZFh1Q2t3Vi9wd2pzYUxlTFV6NXdLOWswa2RuK3hxRGdENmlzT1J0NThw'
    b'KzVTMkh5SVE2U0t3WVlEWWt2R2hPVHYzZ0xKamMKQTBwZ2RDczNuMWxua3MvSFpaSEtNeEly'
    b'TnNqRDR6WlI2VVhiMVpJRFd1ajJERmU3bTJ6dmZpYzd3OFlmMUJidVVML25TYy9ESS9uUQpQ'
    b'UnJIaWpHK1k2eHZDRXlhbWVtTVN0VHpXdXBkeWwxdGk1M1N1WkdycUpCWU1ZeVZwZGRnSGZV'
    b'S01FeFNnVXdBQUdEMkpPL1hGT2poCkNWWXB4WWhveUNRU0sxWnBaN3d2RWZyVENnd0Fjdlhz'
    b'UDJsRktzNlBudXdoc1dKZUx3Q0lLcVg4b0Z1VFk1c29WQXIxQ2hGSUxBUVMKQzRGQVlpR1FX'
    b'QWdrRmdLQnhFSWdzUkJJTEFRU0M0RkFZaUdRV0Fna0ZnS0J4RUlnc1JCSUxBUUNpWVZBWWlH'
    b'UVdBZ0VFZ3VCeEVJZwpzUkFJSkJZaWl2ay9venNXbkNpWUk4MEFBQUFsZEVWWWRHUmhkR1U2'
    b'WTNKbFlYUmxBREl3TWpJdE1EY3RNRFZVTVRVNk1qazZOVEFyCk1EQTZNREIrRWpjbEFBQUFK'
    b'WFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl5TFRBM0xUQTFWREUxT2pJNU9qVXdLekF3T2pB'
    b'd0QwK1AKbVFBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTIxMzAiIC8+'
    b'CiAgPC9nPgo8L3N2Zz4K', 'CA_ON')

CA_ON = b64_CA_ON
index.append("CA_ON")
index.append("Canada Ontario")
catalog["CA_ON"] = CA_ON
catalog["Canada Ontario"] = CA_ON
country["Canada Ontario"] = ('CA_ON', '', 1)
lookup["CA_ON"] = ('CA_ON', '', 'Canada Ontario', 1)
lookup["Canada Ontario"] = ('CA_ON', '', 'Canada Ontario', 1)
details["CA_ON"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["CA_ON"] = ('CA_ON', 'Canada Ontario', 1)
regional["Canada Ontario"] = ('CA_ON', 'Canada Ontario', 1)
#----------------------------------------------------------------------
b64_CA_PE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjY5MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1ByaW5jZV9FZHdhcmRfSXNsYW5kLnN2Zy5wbmciCiAg'
    b'IHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lu'
    b'a3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdl'
    b'Lm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'CiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAg'
    b'ICAgaWQ9ImRlZnMxMjY5NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5h'
    b'bWVkdmlldzEyNjk0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3Nj'
    b'YXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1v'
    b'ZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEyNjk4'
    b'Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgog'
    b'ICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1y'
    b'ZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFn'
    b'ZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJP'
    b'VjZuQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFB'
    b'Q0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVU'
    b'QUFBegpYVWxFUVZSNDJ1MjlkN2hjMVhrdi9LNjExKzZ6cDgrY09iM3BxS0tDaEFRU3hZQUN4'
    b'allHeHdYYmNXeHdFdmVXWER1K2RwNjRKZmZHCnVaL3R4TDV4YnZMWjF6SHVzUTJ4QVdNd1lJ'
    b'b0ZpQ0lKOVhNa25kNW16dlN5Kzk1cnJlK1BJMEFDak1XaGlRKzl6L2xqWnM1ZWU1WGYKZXZz'
    b'cWlITU9qOVBSTjc4NXJOVmdxYlQ2bm51V1hOYWJuQng3NzN1WFhEeDY4Y1ZkWC9qQ2tvdVhy'
    b'cisrOUwzdkxibDQxeGUrRUwzNAo0aVVYSDN2dmU3M0p5YVdWelZ4N0xZWXo5SXFsMUR2ZWti'
    b'bnV1ak1Rdm1MeGUvdmIyejd3QVFBNEErRXJFNzlycm1uNzRBY1hQNStCCjhCV0kzOXZlMXZh'
    b'aER6M3g5UXlFcnpCS3Z2V3RiUi8rOEltL29CZlFJdFUzYlZweVdlYTZ6cUZEU3k1T0VnbDVZ'
    b'R0RKeFlQNWVUK2YKWDNKeGVXQ0FKQkpMTHU0Y09zUmM5NVFxNnUwZHZQNzZwL2I5Qlp3ZzF1'
    b'N2RTeXRJZ1FNZ0Nyd3UwYXhQNW5HWTRvTE0wYW0vSWF6Vgp3cVhXL3Z6Skd4LzNYcEtLa0NR'
    b'OS9jZFRFcVJWekg5NDN1c2ZYYk5oOFdzRjBURk5lUUZiVmw4ckN4OUpTaDlJci8zcVlQNGNj'
    b'ZFBYCkIrYmFPQWNlQW44eEJvSUJMd3UwdVUwUlBweVNQcGtwdlVhMUVRY0FEdHhEbk1NcmpF'
    b'NkpDNU1NOVpvSE9zNU56Q2ZrOXZzOUNkQWQKRi8vcG45NzJMWU0vWDFVYUFLOE9DbXYvUEtm'
    b'b3d1SXY1MzZnQ3dEaVd3emVKamRIM09RTysvbDNzb0VZbktOR04wUzB0Q2hwbU1oQwpUNHhn'
    b'REl6QndyaEZGd0luaTRUelk4bTFHaEZScXhyVXYxK0psdGx6cllVRER3Qjh4Rm1NQ0ZsQ2ts'
    b'aUlpd3lCRU1GWVdKdzZ4MG1NCkNBZ2hBS0FtZFVxQk4rNEpFLzZTQi9PVUlIU0JYZmFtSU52'
    b'Ym1rL0hGdll0ZEg2czQ2ckp1OGp6bTY2ZXdPbGxrWkNnelZkbm50UUsKWnVpYVZJK1NEVy9N'
    b'QXNCNEFOYjlsdjVjSk9yVGhoWHFXK1hWNzhxSjhqTU1FTWJRdmt4di8yOTZHRExxZysvUjBH'
    b'ZTFhY2ZxeGM4QwpZUWpjUnB6bmlMUk0wWHBsS1NQS1VTSkZzS1FLV0VRWUw2VzFqRUZsd2w3'
    b'NGRqRmE0VTlwUDNwQklKUUJqL3huTWZ2cFhnQ3dNampiCnIwWlM0ZGpQa0JvK0QvYS9McFZi'
    b'cmhrSnNUQm01d2EweFpiT2pWaDk2Nk9qajlSWG5wOEFnT1NnYXYrM2JQaTEwcEpyYVY2Z3Ji'
    b'KzIKRFFEQ2dObTFRSW1La25JU2xveHl6NkhBb1ZueTdWclErR0VsYWFMWUNTTFhRanlJSUht'
    b'TnBnMHFlcGVrcGtSSko2S0lGaHZNT1E5Ywo4RDN1ZWR4c2NoclFFMGIvK09CakFYSjlKNDF6'
    b'R0RBaTRzWGlZUUNpaURDR3pLQ1craCs5Kzc4d3pSR0xiWXN5RGt4RDFvMzFsSWVlCkY0UStn'
    b'cEUxeWFGMVZON2RtanRtNVFaVWVFdkdzOW4rcjg1MGhFdG5qZ0JCOS9ySTdJaUpzVjRZczJZ'
    b'T1c0Qll6NnBJZGQ3VllpVFoKS1M4K0ZzOUp0WG5YakVETVhFb3RJZkFWYjg4QVFLc2F6SDFt'
    b'UnVQSVJaeStKYmJxdGFuRjRmTnNKcWtZWTdRd2J0ZjNtdEx2YkF4OApJWU8xMWJxK1RJbTBT'
    b'M3BTVkhRQllRUUF2c3RkazV0TnhodVVjK0I4RVNXT01IREdNZVlvWk55am9jM0NWaGkyYU5B'
    b'SWtROWVNOFFBCmhYNXAzZFhad0dObU5UajRqZm5OZjl1REk2aFo5R2ErbEpjcDgxVFUrN211'
    b'YUViQ0JLMzVmQmNnUkFOT1F6YTZzeDd6bnA4Z0RZRC8KeC9iM3JNbWlGWmZzZ0V1U2pISXNv'
    b'STdsK3RqdVJuditWTm44bVUxUXpobUYrV00ya1hBMEl6RThXSms2Y3VqKzJ2bHY3VGg4ZnlX'
    b'VwpsUk01SmlvWUFQbzJSUGY4VncxTXRvUmFMTVNKaUFDQUNHaVI5UlNPNkEyTlhmVnc0MXV6'
    b'Z0FCaitQV1h4cnJYUlJOOVN2ZWxTZTNOCldVbkZDQ0VXZ3RsZ3ZzdXRCcGgxeGpubkRBQnhU'
    b'bWxvQms0cGNQSytQK1h6MlVCa0lIT2tjQkJPR0FrQ1FBQVc3YjBJZ0JsSFF4L0wKK2g2Yk85'
    b'Z0svcU1TMXdWQlJDems1ZjFtakFJQVZoeVkrTWJjK3YvUkR3Q2lMTlFYUEs4V2x1Nm82d2M4'
    b'Y2dvRC9Hd1FWa1JwKzBPLwowTHJjNGtBYVkwaTB5NHVRZGErTzdPMnZLeFhXNmhhNkQ5R2xP'
    b'RktBaHUrclpucFV6bUJnUTZ3ME0ydFhZZU5sN2FLS2t4M0s3TENaCm45QjlhNjV6aGQ3V3Ir'
    b'cm42ZUhOclNXb1hvT2orV0dyNjZ5SUdpTjkzK2d0ajloTzFjY0N5aVhFcVFNdHF4NWdncUty'
    b'dFBWdnlaNWsKZmk5UTZqRUUxRzhHNXF4dmo3citVVmZ5UU9OSTVvQUF5UUR5S2R2ekZIajJR'
    b'N25Bb2NmdXFhaTNXaHBndWNuMy9DamZlM0hDd1NBQQpYOFErY3E2eCtIeCsyR3orMDRJS09B'
    b'cHdpZ3p5aDExN0R1QUJzeEczMWl2bmY2VHJ1TjNSb3NQM1ZjUW1pOTNqTEUyV3RoQXpQcGFk'
    b'Ckc3VlZRMWh6WVhMSFQrZk91aWdscTJSc1Q5MXFoSW51QWI4MXMyeFR0RGpsZEs2SXpINXlX'
    b'bDZTVWVNQWc3ZkZCbCtUSlBJekQzY1kKTUtzV3RvcStOZS9aRTU1enhFRTJFempDbkFjSUdP'
    b'WkNtaUNDY1VUQUtoSlVMT2lDUU5EVEJoRWhoQkFIREJDYUFUcEJaTmdLaUJtSgpWa0xONWdn'
    b'NEFIZ055aWtIUUJpQUFTZHRjdHNGUnJKUFhWVE1oejQyRmd1RTM5Y2RaV2hvNEZ2ZmVzN216'
    b'SUdJVm12cnZPYmp2cXcrCk9RcXFJV3k4TW52NHp2S1NaV2tZRjdyV0dOV0N0MkY3R2hBTWJJ'
    b'amJqZkNSbTR1RG0yTHJ0bWVRNERSTDBkOStmKzZLRC9Rc0hEYmwKcFJxbEttRDRlV3Y4NTAw'
    b'N0t5aXJWU2xGa0FqQWtWY092Qm0vTmVOUmo0SUFjcjlpckZRU215TmRyMHZxY1NMS1NDQVlD'
    b'ODlXS1EwaApETGlzL29HR2NRNElMUnJiVEZZUkN4RVdnQVBIQW5DS0tPT3U5WGpmT0J6NWVm'
    b'Rlo4RnU2UmRybXVyWHVQc2M4Tkx2WGJqeHNEZjVKCk50WjJQRVl3ZEZIeTRRTlc1ekE3OVdy'
    b'cmlNYTU0Q0krOE5lZEdJTnJTNlZaUDkwbFJoSmtjbi9yai82c1M0bVFBL2RXQjg0MjhxUFcK'
    b'eHRkbUFLRDIzVnJxK2ZtRkNpQ2x5UHlpMmNEY0pwUU1xY1lxTGJVdTBaK1YxQ2dScGVjMlB6'
    b'aURTb0g2RGs5MS9PRitJd0RmcHBSeQpTU0dWZVFvY0JCRUFBVUlnRUNTcFNET0Ercnd3Yk0x'
    b'L3Y1Z3V2emgrWVZ2STJ1NjlNMzhmTXpPQ3RrV3Z6RGl4TnFsZTlNeGEwTFVpCmN0N0hlZzdk'
    b'Vm5MdmJtVXNkQ3E2VjNocm5LV2xYSzhTU1VvQUhKR3VZL3N5dzdzQ1JkZXhzRmZXQ0FBRUxw'
    b'M1kyMXkrT2U1WTlNRXYKakhlRlFvQ3dlR3E2a0FLRWlBZkFQZUEwTFNqOWl0SXJhem1pcENR'
    b'MVNpUVZDK1I1aFNOOGg1c05GbnFjY3o2eFAraGRROVRJczcyUQpNbGlZWm5vTTIwMzMyTStM'
    b'QmtjWTBLSkhFdFFDdjhHSXh5S0FaWTdTTDJwMEJnQjBqaDJCZDUwWHd3UVdKdXhzbitxMDZN'
    b'ak9XcXBMCldmL0diSGhGcGpCdTFTZGRaOUpsNDc3UzREcEQwak1oT250enJmc2RxUVJITkdS'
    b'RXhFUVk4NjNna1lQMW5CUXUyN0R4NGR2SzFDMTAKcjFSNjFoaU1ja1BCSzk3WEVXOVRBQ0Qw'
    b'V1JoUUhnTDFlQmhTQUtBZVp5RkhCQkVaQVlCQWhFWC9XcFF4a2RDaTQ3VzBjSURyTU0vaQpq'
    b'Q0xPT1VKSTBaRnFJQUF3Njh4ek9BSVFCQlJMQzUyRHlHcjlBVk5aRUtCN3BWZ3RVTjhWK3E1'
    b'TTE3NmFQemtLZ3dDRTV5ZGlua3VZCk81MkgvT2RtQWNDUitNSWZ4OVp0VDBzS3J1WGR4b0xm'
    b'dVZ6dldobnBXaGtCZ0ViUmwxU2hVZlNhSmQ4dEJsNHBvTFVRYWhUVmFDUkUKOGJpb3gwU00r'
    b'YUttYVphcGt1d285NjJzY05yWm1EUGlMY2QxdWxZWkFPQmF0RkgwRUVKMk04ajJxaTlxbUpF'
    b'enFDMHcxNktjQVJKQQprb0JUU2wzcWxmekFZYnpGR1hBWE1aS1NNcjF5TENzVFNXaVVhQ1hQ'
    b'VXUybkJFQXlKL2dPem85RC9LL2E4Lzg3bncweEFGaVlTVmZHCmtoc2pjejhxUlkrRkx3V0VB'
    b'TUFRT012RmxYL2Vyc2NKQUtRNkZjNGg5TmpVb2RiS3JjZXpMYTRadG1wK3FrUE5EV2pWdkN2'
    b'S1dEV0kKUUREbi9MSGZWRmFlWXlBRUNLSFFZNUlxSk5zTjA3U0loenNxSTZtTGx0dmxReGU4'
    b'TGJzWW8xSWpaUGorYXQrNldPcHhUeDhBV2pVVwppYVBGQU9NTGdCeUhlcEU2TFk0UVYzVkFM'
    b'YmU1c3dYN1BZMCt5U09MYXIvMEdtWGROVzJpaEQyYlQrNTNCUkk0bHAvSXltWkRjVXllCmJC'
    b'ZDhsMk1NNVBlclZVbEZiZjFDdFlETy9tYS9YUTBBNDdRb2lESWlNcHBnZ1A0c21WaWhIZjd5'
    b'Yks3K0lrTUlNa3BkSEJNSXpCNHcKRjNiVTQxdU13WE5pZ2M5eWc5cVR1ck5mSzgwNmgrK3Z4'
    b'TEtLNzRRWW96QmdoR0JSRlNJSjNDajU4VFpaajRtTHp2YjY3VHJ3UXZLaAo0VlkxVVpvc2JM'
    b'c3FRMFRNQVlEejBPZGRxeUtwTHZtRUVlYzBnRVg4WEpzcjJ0S0J0QnFzWG1RSWc1RkVRYzBx'
    b'L2JLYUtISVJrUFpNCkQ4K25lZi9XbUNoaEFQQmNicVJGeGduQ1FyWGdOTzZycFlZaXRtVzA5'
    b'NUhabzJIWENsRjRHbHMyeWt4U1FJMWdSY1B4TkFRdUVtVFIKYW5BbEFwcUVnTU9xRDdlclVk'
    b'S3ErTm42VWd6ODV3RGhtTWd0S2JIMjM4c3pDQ1NPTWdCNXM1RWIwakJDaTkxN1l1cG11bFUx'
    b'UXZKagpObWNBbUNPTVJGWFFZK1RobTh2bnZMNU5sSEFZY2tKZ01YQUZDRllkNTJBTFFBQU85'
    b'WUtuUkFpakhBbm9DYU1jQUt3R1I0L1gweWhSCnBYY3B5YzVtbVRhclBCSkQwU1FidTZWU2U5'
    b'QTJPTTcrZmorNnJ2QjFuKzBCNE9WWk45MmxZQVFDQWFCSVN5aUZYYld1M1NIZVhaK1gKcXZs'
    b'TGttc3VqMWJtUWtWRGtjUkpEb2tnQUg5Y1kyclJ4UTRnTFhxQzV4TWxIR0Q4WHd1Ukt5TGFX'
    b'cjErME1LM21kSXBZL2tjUnFFcgpoTnMybmRzMWVsZHltcHFJU3h5eXg4TFpUMDBIR0FVWHFj'
    b'dGVsemFTNGhNUFJ4SmkvOXJJd29UcjJqU2lZZGVpbFhsM3pZWEpWS2NjCkJwelpZY3RoMFJR'
    b'aDBsTW5yV3VIWWNnWjViV0NKeERFS0Z1MEllMG1jMHllNlJRQW9EZ2RwbkxQR1QrN3lSQ0dN'
    b'SUJvZ2g3NVVURisKT0VoeTlPd1JGZ2NZWEJGdGxYMUpFM3lIQWp6dUVnQzNTazVtbDc4WVc4'
    b'bjVBdnltTVgxSHpWNGpwMTRUY3kxWmpSSWpjZnpOaklNawpIWSt5SWdTZXpRT2ZxeEZNeENj'
    b'Rkx3Slk4OWt1SW1MT29icmJsSjhMTC82QmdjZ3IwdDJicjdoeTlhRW9xM3ZYVno3K2pxT3Uz'
    b'Vkg4Cnl4bGJnTXhuTzRwZnp4c3RwREtBZTkyalptblRCem9XZGFIVkNNMUd3SHd1aUdneDFH'
    b'a2tTYkpkUmhoYXRZQUZmRzdVWEw0NTZaZ00KZ0JwSjZRbFRrSWE4V1FrUUlDMUd0TmlUYmFN'
    b'QnQxdWNpQUFJeW5QVVNBaEVQdVY0YkFDVmZCalBDQWlCMndyR2Y3Z1FQeHEyQVFKQQpUU0xj'
    b'ZWQ1bHIzdmdkdTMzZUN5ekF6Z2h3TUtVM1RoZ3QyK05Bb0FrWXhyUVNFS1l2NitaT1RuZ29I'
    b'R3NIUXpnWUxtS21LbEQvSkpvCjI3WjRKQzBTQWtSQ25ISFBEajBicVZFY2VJRlZvbHFTVUNh'
    b'd0VESTlCR05ZTktFUDMxcml3NTZad1VhSnZUQVFUdWt4TFZ4WXRZRVIKSWJwdnhMYWJnUklo'
    b'SllYSlBwZ0wvc0FYdTF0NWo0VWNBRG9JcXM0N29rb1VCU2ZibFZUbnM2WDEyd2EwMEdPZVEy'
    b'bnc1T0FkdnIrcQpKNlF3WUFNYm9nREFHQWZnbm9WcUpScFBZMExBU09GR2tTbmFjUlAvRDZj'
    b'NWJXNDFtQ2loZEtkUW1mUEd2MTlNVDRWWlFDRkFpRURnClBKREN5OWNPaHgxUi9yUG1NNzV4'
    b'YUJ5QzhWYUlPRW5odG40TkFERGhXbFRRWThpcGhWWE1FdXdaMG9NYXg1b0pjSXRadmNVOGxr'
    b'Q28KZzZ6L2FCY2lTRE9FaFdQTm1iK3ZKQmxHQUEyQWFocDZQOVJlblVmcHJ1UFNhTTJWR2Jn'
    b'U2dNTS8vM3hsOS80RFd4Wm1ueStFNTFWSwoxWHh0NHFGSTUzcGovYnR6dnNld2dOWjlaWUJJ'
    b'd0NnSUlsS2pTMXg5UTJSTVpHeFcvYm1qVnF2aVc0MmdaMDAwUDJxdTJKSllWSDdICkhxbDNM'
    b'SSsyYWd4aDBLTFlkMW10d0NKSi9QdXNHQnB5NElBRlpMZFlzOEkwQTRzeVNDS2IzTjEwN20y'
    b'bXk5RE9BUUNOcTlKOTUxMjkKWHR4Lzl2S0srWi9GallQVXplcE5hQW9BRExnSDNCYUFSVEZQ'
    b'Q3poSlNKSklTYUtseEkyRG1xd0pBSUFRaW1jUkFKejM4UjVnYk9TMwpWZVVYcmQrbnR4QkF1'
    b'c2FoRnV6K2g4bDFuK3h1MWZ4bUxVaXg0OG85UU54NGZkeDNhY2R5NVVUM3hxb0htT0MrNmNj'
    b'V0lrbFllTjVjCjZBb2M5MHUxeDB3Z2FPaTgrR0srVkZRUUFBaVBLeEhQWm91SlRVQ0FBR0VD'
    b'TEdDVUFpYUlFRnlhc1YyVHh0dGsxd3BaQ0hwQ1ZDTEgKbHlGZ0VablZJSkdUT3BmcjFYblhk'
    b'OWpRcHZqd3psclBhcU00WlVmVEVxT29mUUF2bXFDU2d1SVpiRFZaNEFFbXlMTjRHSEl0Z3F3'
    b'Rwo4MTJRRkFpRDR3RkpXVVdpVEdmMjFsdDdMSDBzaUhNaGRrS1BCaHcvbVB2VmhSL0pLWnFo'
    b'eFVrdDcyZDZsT0xiRFRGQzFJU1lUQkk5CklUNDlndU5hdkpLbmtvSVVEV0VCQWc4QThWYkpN'
    b'L2RZMmluTTErd01PM3BmTlRtZ05jYWROQ0FBcUF2NDV2T3Yvb3VldmJsZUdIdW8KYnVUa2JK'
    b'OEtBQWpCMGQvVjZHOGFtMElDVUhocVlMbGNMajRsekkzUXMyVXFPUEFIK251di9nalRZK0x2'
    b'Ti9EOE1PQUE0RmtoQzBFZwpvTWRGUUdEVlF3NmdHWVJTM3FyNG9vd1Q3WEt6NkFjQkUwVWNT'
    b'WW11U1YyVFpucVUwZDJOYkovR0tLdmxQZGRpYXk1TUVPbVpUWXo2CkF1VWMwWkNMTW9neTlo'
    b'eUdCU1NyaURObTFZTm0yVFBuZlcvYWd3bFByMFBrOXk5RmFVck1XeW1ycTdYVjI1UFA1bmcw'
    b'V2JQQ0VBS00KUWRhdzFXQ0tqbndIaUFTYWdSdGw2dFp0NGQ4cXA1cVplWnN4ZDhUcU9CQkdP'
    b'UWFBUGNtazB6WFlKWS9FRWpTOHgrejhWSHMwTGUzLwpZV0hUK3pxSmlBcWpWdk4vRlpSVFda'
    b'eUcwTE54NGVGb1luWnc2L0NPMjZOUlZONXJydjJUTmlWQ1JtNHZ1emJkL0NmdHBTbm4yQzlL'
    b'CnE5N1JsbXlYQWFBMFJZT1E1NWJweHlQTE9xbmx2VmhXcWk5NEdLQmpTQWNBV1JQbWoxaVpY'
    b'aFVMNklscHNmcUNwR3VHU29Sa2U3VWQKUDVqYjhYZVRnbzRGRllPTU1RR3NDdWpram9RdXhS'
    b'UzR3N25EbU1WNExWUjhGT0ZJNHpoK2FtbThNRW1NTlZybnh1aGlmdWRKQjRBRAo1OEFZSzAr'
    b'NzZWNVYwYkJkOTZ4eTROdDA0Tng0TEUxOGwwczVSRU11RUtSRXlJRjcvT2pqQ2I4L1NMTy9h'
    b'd3dVa2Z6NHhGcGZyUXJWCjZ1TG40aGFsYlVEemJCYmI2MC92YS9admloNlpXMVlhVEs0Zkg1'
    b'SDU4eE9rdldaajRLNmZTSUF3b1BqYkRTTXRIYnE5SEwzVk1yZEoKcFJsbjZydEZKdk5FVGdh'
    b'QStSR3IrdThMNGxzU3NGSjNXblI2VjhPK3JSNXMxV2J2cTJrUE9mWFZrbE1QdlhrLzJHM0xO'
    b'U1orcHIydApYNXZZMHlnZnREYThJNGNKdXYvTFUvMVhwVU9mUmg5MkV4NEc0QUFVZ0I1Zk8v'
    b'Q0NSaWM0d0h4My9JcUxvd2pReE81bWZuZHoyL3U3CmpqMVFjMnRoNDRDMStSTTkxWGtuLzVX'
    b'ODhaVmVJdUxwZjg1blRGVE84T1VYSkJhRmVXUEJIN3VuWXM3NFpzRkxtU2h4eXJXdlhEakoK'
    b'OERuUmw2S2o5S2JiWWoxNE9zckIra0YxejAyMVJ6c0dra1NSK0NsNStuODQ1UnNnR05QMEJ5'
    b'OTg2OWJxemRranRWUURBQ0JFRUFLMwpWa2dReGJ3WVJDWkRFWEM1R3drdVYwdE0vLzE4a0k5'
    b'eC9UV0crNWlWbW1FQ29GSUhraTR5aEovV0kvd2wyaHB3SUpuWnVmV1AzOVAvCnE4YlJhdUlP'
    b'cC9WSG1qU1k4UjR0cFBmNHhXVTRkVm04L0tPS1RTQzZTYk1QT2QzekFBQ2w4K1RlMXlZWjVj'
    b'MEZyL21UU3RwOGdac2EKSVBqbTVYK1JLUng3OC81N3RlZWFHWDEyWGZnRUxZaUNSYVIreDBF'
    b'dndwaUd3QVZBQ0Y0aUdvN0ZZNTZUY0IyRWtNTFJXRlM2OTZMMwpYUFByYnhzTWxSUVdjNUVF'
    b'S0FSK1l1S3NnR21FSXdRZ3dhbm12SjRydVFoWkdKTDB1YWUyVHhIQy96L1JVMlRUdUs1allI'
    b'Mlc4MHJ0CnoxUE1tY2kyYmN5eTROVkVHMTVSclExck5YdmZ2bWZUaFdmb05DZHJ6NTZwVDM3'
    b'eUtWeDRabi9oSzU3SW1TRllwUExFYUg3MGFEelgKM3IzMjdETVF2akxJYnRSdStzL3ZOd0My'
    b'OVBadnZPS3FuOS93QTJkZ2hiajdvVGU0enNEbWJZeFNoTkQrdTM3ZHMyWjlvclA3RElTbgpJ'
    b'MVZucG9yNTJkbjJibmZ2b3pzZmZhQ2FTRlhtcGhPcDlFMi91dkd2enRuNkgvLzRlWXNJZm51'
    b'bjlOZ2pILy8wRjA5bmpmUHExWVVICkh0cFJUV2VjMERNMTViek4yNVlCT0txVzU5Qms3UHAv'
    b'L05zNUZrNWwyeHYxV3BlQVQzT0w0ZFhMaFplODR6cjlWemY4NSt6VW81UzMKN3IwemFNc3h4'
    b'a3FldDQySWRxTXgwamZJSFNzcVlEMmU4bTNyUDcvKzVWWXNkdDdnOGsxWFhIMkdDMTl1MTU2'
    b'em0vNzk2N3QrYzhzdgpmdmp0dnJQT1hyR1FOMm13UTVKZkcwdEF1ZWhZVmlCSmR3ZkJjS1U4'
    b'WGErOWhVamIzL1huai96cXhqbFZMU2N6NHdmM25oR2tMek01CmpmcDN2L2Izdzc3NzYvMTdI'
    b'bmJzYi83Z1cvdGs3UzJ0cGxHdm5QZTZOMTA2dEhJV2VGY3NQb09RYUxVK2c3Q3FSMnJ6c3cv'
    b'c2ZiU1kKU002WENnOWI1dGpEOXdOQTZIbW5UNmRlRllJMGNKMlJCKzd0V25VV2NEQTU1a1Jv'
    b'VXVJR2ZrV0xGRGgzbXZVM3l1S2hPMys1YmUyVwpaUS9jMHpTcmY0bFF0bTkxcVZKNnlHcnQr'
    b'cStmVUE2ekMzbUU0RnpYd1NMNTZkZi81K1JDd1VoblZ1VTZMbm5YWDV5QjhLV2dlMi84CjhU'
    b'NUJFUGZ2U1VhanJ6MTM2L0MrWGJibk5HclYxVnZPejArT3ZmRVRuM0dhamYyMzNuamcxaHRl'
    b'V3lubnp0N3VtdGI5ZXg2MisvdUIKSTBNVTV5dWxJN0thODV3NXovdVA3MzJyT3JnOHNtSjFZ'
    b'Rm5sdWRrelhQaFMwTVN1aDNZVTVwMVV4czFrQmR2YURPaE5IL3ZNRDc3eQpCVy9OaHFNUFAx'
    b'Qmw3RjgvL1NFYVMraU14d05YTVNLTitTbmJOR2NTQ1YrUTI4c0YzL01QSnVLcGV2V3FUTnVO'
    b'Z0p5b2tYT2RidE5VClBPZnlEMy9xRElRdkJYV3RXYmR5eDI5dnN5M1RjUVlLczRQdmZ2LzlO'
    b'LzVvR2dtOGtPZTkvUzNiYnVpUmhraGFwc2s5LzdYZFhiYnQKM213eFV5YlpXbm1JczJ3MDFs'
    b'dVoweVJpNTZjNnNMaGNVYkoydlNiTEgzei9KMkp0N1djZ2ZGSEl0NjNidnZQTndITm1IZWVO'
    b'bDc5eAo5TDdiVk50VXFzMEhPcm83Wk1WdU5naEFOQXltZmM5dE5YQ3pxV2V6dkY1TjFtdm5M'
    b'Ri9WcnBMOStjSlpIWWxHbzM3ZDFkZHdTZy9lCmRrTW1GVy9XNmozTFZtNGZHZm1tYlRWUzZU'
    b'OTNuWm5SbzhtdTN0T2h2NmR2cGlMd1hMZlZOTkxaNTFUS05WdmYrVDlmYTVZS3RWaXkKaEpG'
    b'ZHpIOXc1WkJoR05QNzlud3ZRR2VWeXNyZ3Noa2lYRXFrdXl2bDhVZzBaVFkvZS9tVlFhc3BH'
    b'OUhlZFJ2My9lSjZKZG01NWUzWAp0c3JGaVlmdnp4OTZOUFJESmRuV1dwaGZkdjZsV0JUZi81'
    b'dGJ4RlI2S0oxZWMvVG8rejd6SlMyV2VDbkhKS3pYN2IxN1h4a1FCbzU5CjQ3OStkWjd6aTll'
    b'ZHZmRzFWNTM0cjBNNzd0ci8yS09xckx6cEEzLzE5SUptdVhUOS8vMlhPdWNsaE9iRElHKzJz'
    b'clhxbFVGTFZ0VHkKK20xVlFrcW11UkQ2QzQxNnIrZnhhcW1rcUQvNTFCZCtjdnV2SElVb2M3'
    b'TnB6K3JvNlBkYjFkQjNBZzd6VFRQWDJmdW1qMzRhWWN6QwpjT0xSQngrNTZhY1BFREc2ZkZX'
    b'cVVYL0wxdGYwblhQZXl6NVd3aGUvK01XWHZSR1AvZWFXUFR2dTdsOTExc3pCZmZmZStvdXBr'
    b'VU94CmFQUyt3d2ZtSWhGaGNod3pldk1OUDU0N3RDK1Z6bFNtSjI2ODVZYXg3dDZxMlJ5S1JD'
    b'dlRFL0gyemhQM3FrbWF2bWIxMnZxUncrY3YKWCtGT2pyNnp2WDM3VUcvL2hyTnI4M09zMWZM'
    b'blpuRXNGbXMxcjhsMUxDc1h6ODNGVnBuTlNqNC9vMm9WaEl2UjZMZ2Zpb1VaU1NCRgpRVDA0'
    b'dUpMMjlKb0M2V1RVeUxROWN1T1BieTBWTWVVZnVmWUQ4cEhoeXk5N2ZkZFpHODRJMHVNTTkz'
    b'Kys5dmZWV0R3OU42UEp5c2pnCml1N3hJMis1NXRvYmZ2NkRoeFJsemN5MEprbkZ0V2RueDQv'
    b'NHNXVGNhdkpNKys4OGU5T1JZYnA2TFpMVWQyNjdxSHZkeG1kOGMrSG8KNFo5LzU1djdaQWs4'
    b'N3l6ZlNicTJISWtUVGJ2aUx6OTMxNzk4ZVdqVGhsMDMzeXdJRU8zdW40d21qNmhhb2RHZ0NG'
    b'MlRTTmJEOE5FZwpRSXFhVXJYT1hUdmY4NG0vdWUyV245OXYyNUt1cDRtWUtzeS83NisvK05q'
    b'dE55M1Vxcm9XdWVSdDczb0psLzZjVGx4bzE2cE9xOEU1ClJ4amZ1K08zaDRsb01vWmlzVEhI'
    b'YWNQQ1F3ZjNJSUM3Z1c5eHJFTkRLMW05MW1ZMlp3azVSTVNpNnh4eTdNMngrQ2pHaklidHRr'
    b'VWsKU1RWaW1KQ25xTkovKzlyZlRRNHVueE9raW1XZUY0K2xZL0hTeEZpNmUyRDg0WHNxMDVP'
    b'dTVXV1huN1hocW5lV1I0OGlGbzVienB5cwpUbG9XakIwN2lFbVJjUldMSzNmdmpQWU9UUC9t'
    b'Rjg3WU1VM0FSeVJGYysxKzM5MTMvMjhmTWx2bFpMSTBQN2Vpcy9zbDFvaW5oVVU2CnN2TjN0'
    b'eDhkYmxhSzJWYno0dTF2MEYydlIyZjdhRGhScXcwQzZ1L3V2V05tWW9ienEyMnJwT3V6NWRJ'
    b'MmdBc3UzSDR1Z2g4ZDNEZW8KNnBkNHpzOForSmljdHpDLzA3SWVEUHpJalQ5KzMxOS9RUkNm'
    b'UEs1ejVONDd4T1VyNDZaMUJRM2liYmsyQWxOTnE3emxvbW5id3ZYVwo4blJHalVZM1hQbm1l'
    b'RWQzZFdZeVVaeGtFMVBUdGFyQ1dWU1c3d3k4WlRSY2ZlRFJyVy82azF6ZjRPaDl0MlI3ZXo5'
    b'WmJXTEhYa2JECng2WW44dXMzUnlpTHRzelZORWgyOTc0YWRhSFhhdXpaK2J0UlRYdUVvK0RR'
    b'WGlzV2M5THBxMW00MG5FKytkbS85MjF6M25QNm92RWgKb0h0YXJRdGx5UlRsQ2JPWjV2Qys5'
    b'MzQ0Zjh0UHp6ci9rbStQam15b2xGaG5UN1d0QTdsdXArK2Z0ZlVpZk1JVzIzaXVvN0wvc1hE'
    b'cwpDRWxsc2hoWHZhQWxLMFhmTHdJYVZiVzdnbkJRSWZWZDl4ZU9IYTNuWjdTb0x0SWd2ZSt4'
    b'MTBlMW8rVXk5b01PRVI5YnNXNStmdnJ3CjZCRnA5TEJuTlpIbGxJT0FjMzVIdGtPMHpaaHBY'
    b'ZUo3Rjd6OVdqMlJlalZDR00yMDBXb2xQVGRkOFAzNXdqemxiSVNqWmExYVgwZm4KNlB6YzV4'
    b'L1pxUkJKRDRJVnFyUjFZT1gxcFVJcEVnMHhicXZYWm84Y25vM0VXSzB5UEQ5YmlVYXpyV2Jh'
    b'Tmk5dmE5Lys3dmVMNmtrYgpWSWdrdDNmMjNEMHp2ZENXRzhNQ3E5ZTZKTEdDc2I2UWR3UWhP'
    b'eis3eHd1aW9oanpUUWk4UkZ1dVBEdS9ZdHZXaGZHeGlJQjNHSW1hCm9xcVNKTWJqRWQzSW1G'
    b'VlZrVE9lZDc1QUJhdTFYSXV1aU1ZVHdEMk1WcTljRTBtbVgxNElYeDVCYWxYTHpzSjh6YlpY'
    b'QXZkeTdXc1EKbUszNnFoVXJxOU16aHlMSjEzZ3UxelRCc1lsQVBOOVBPblplYXIxcDJVck0r'
    b'WDJGT1FWQW5Kdjl4Tm9OZDQwZWpSTVNCNzV6b2RDWApuMnNmV3ZtVVd2Umt1alUvMC9LY2VZ'
    b'RU1pK0trNDN4a3kvbTNtZWFHVnVPdW52N09xYkh2U2NxbUlMZzhGczJ4c0ZVcXRzckZWWmY5'
    b'CmNmL21iWW12LzEyMTVodVJ5UFRzRk84YkVtSnBtZUJXcFU1MDlleGt0aDU2dHpzMko0TG0r'
    b'K3NmMjlXMmJPV3JrUXQvL2IzL2Q2OGcKVGFycWJrVjd5SFc5L094SE5tOXNGSXFIS1oyUkpU'
    b'a2FkVnJtWWVBemhmbFdQSUYxL1k5MDQrSkxYdnV6QjM0N1I5a1czOS9IK005YwpKMVFWTzVW'
    b'QnFrcU1xSmlmSFZoLzB1SHVWcTN5bmYvN0wwYTlvbGJLTTRJd3kxakRiQjBhUG1BTXJaeU9K'
    b'UXlNakdaak5KMkpKdEtBCmhJelYxS1BSL1Bqa1ZYLzdqMmE1Wk00Y3JlcHhoMGlyWEJNbWpx'
    b'MVlmZmI1MTM0azBUMXc4SjY3WXRrTUNmeDRxYlFyREtjQkxzN2wKK2xldmZ6VnlZVzl2LytT'
    b'ak8vdEZrbktjSGxtMWU1ZmRXYXcxTU5tZ2tnZHQyNlBCaDladC9QWUQ5OWFBTDV1ZGJHRnlQ'
    b'ZWYwemx0dgpzKzJoUnVXdWFDcVJqRitwUmZvRC85anM1THJld2NMbzBVdi83cCtlVXNYT1cz'
    b'OXBZMXpxR2VEVjhwVmE1S28zL1BIWWcvY2NIajdnCktHcTNiVWtjdEZTbXdiZ2dxVUxFQ09h'
    b'T1pUcmJSVkc4NzF2L3hQMFc1VkFmV3VuWlppVWF2YnhQMlBxbmZ3RUFJeU1IckZUcWNLNHYK'
    b'UGpOMTNaZi80UTNqeDJnWTlHN1kvQ3AxN2RzR2hxUmF1U09XZVBkSFB6Mzh1N3Nxc3BiSGVN'
    b'NXhiL1pjcFZpSVNZcnN1czFNNWhMUAp6MktlSTFKOGJxWlFLVjNaMFhQVTlib0pFbnpHcW1X'
    b'R2NhVzd2MmdrU0NMWnpsaThvK3VrV0pUcmpOMTMxMEk4ZmhRTEU1V1NmOTl2Cnp6cG5QYTNY'
    b'bkxFeGNYTDBvNS8vZjdaZS9zWmxqUHJ6czVJVzZjV2hyS20rNDJRNmN6UUk3aU9ScGlBc05C'
    b'dTBVVCtXbit0aXJIRGsKOEQzMzN6MjM1bXdJUTZOYVhiWHBYRDJlRkVSUmpjVmZwUkFlL00w'
    b'dDkxWEt1NjNXanYvNmNWUEE4Nm9xMXF2YkJiUmQwOC9ySDl3MwpOM05Fa3RvYXpTU2lNVjFm'
    b'dWZrQ1BEKzVxbTlBTWV0djJISkJzankzZHRQVzc5ZHJjNkpFV2kwNThGYVVDMXZlOUE2Qm5M'
    b'U1BOZFhaCnMrT09tOFhwcVZGQnNCaGJrNS8yV28zcTNOenJQL3hwYStyWW9YdHZGMlYxMVVW'
    b'L1pOaFdaSEsvb21rc0RDVk5LNHlPY2lSMUllR1IKZXJVYzBvV0lNVGc5MXFPVHFaRkRkN1Yx'
    b'TkIxYnFaWXJyZnBEaC9idnV2L3UvUk9qM2FvV3kzVzhHcU16bnRtNjRSdi9jTml4ajJuNgpo'
    b'Tzl0akNjWG10WmZkN2R6TEpZanh1ZjM3NzJVaFdjTDBCR05sV2VuVkQyeTZXM1hkYS9idFBP'
    b'SDMyb3RURVdUcWVHNWNtN1ZXY3l5ClVzbkV5bzNuS3RHNEVqR2VlRG5uN0xadmZlUFlzWkZL'
    b'RUd4T1JGWnNPMy8vbmJmckVXMWhPaDlTbXVudURnUnAvOEJ5LzlHZHF3bE8KcG5QcGpoVEd5'
    b'RzYxR29VaUVxUXJQL2ZWMmVFRHQ5MXk0M2ZDb0s5V2Voc0trejBEeEVpOWQyRWh4Mm5DTnF0'
    b'R3ZEMlY2dEtqT1l5NwpacWZmODZuUHYwb0RiSUhuM3ZTTkx4OG9MVXhpc2xWVHFDaHQ2dTN6'
    b'UFg4NFA5TTdzSHJWV2VzTzNmcXpaRnZhck5YNnp2dWpaZHN1ClhnVG4xbi80dEcrMk5yL3Jn'
    b'ODhTbjd6M3A5L2ZWYTgwRWFyNFBwcWVJTEtjTHViN0JONCt0REtrc0hMN2xUZnMzREh1dWI3'
    b'bmJGeVkKM1hEV0tpSkpBQkI0L3NMNFJLSm54Y1VmL0NzQUtCd2IvdS9mK2dhcDFhNXVqMWZ6'
    b'QlRuVFV4UnhiWDUyT2hJZmpVVE9WbFJaa05LaQplT0hnME5ZL2ZzZkxDK0hMdHZ6cGUvL3l2'
    b'eDd3L1lJUmowV01GaWFyRE4ydHpqZG54emF2M1hqRk82L3RYWHYyYXovNXBWYTVmT3pSClhj'
    b'dTJ2dWJ4K1lhQXNUQUludDJiWHJQMVFyVldjemtQV3MyS3JETGJ5bWthRVlXOStVTGVTSFd1'
    b'WHQvbWUxalZKaWl0OWE4b0Y2cXUKYWJxbVZabWVxY3pPQnI1MytPN2JiL3ZxNTM3N3YvOW5L'
    b'TW03T3JxKzBncTdWeXluamRMbTNwNHlFaVpsU1RUaTZZbnhkNjNiOE9sUApmZTVseHc5ZXhw'
    b'VHZ3d3VGQ1VsYTd6b1hyVnE3ZGZ2clV0Mjl0L3pkWHhWR3gxNy9OMTg1cnFWRnlhbzNBOXMr'
    b'TVloTUF6L3dQRUY4CnRtWm5ldm92dWZEU2gzYzlGSS9vK3l4cll5YTllc3M1dTIrK2FjUzJI'
    b'aWxNKy8vMjFWWHRYYlAzM2pHdjZTM0VXcVdTRVZVa1JZbG0KMDRIdmwwWVBDTlMwU3NWOVEy'
    b'c1Uxek00OU9WbmQwelkzSGFVZkVtTkdFa2xvaUt3MXA5ZFhzakQ2VUV2RzRTZmVmZjdtcFZT'
    b'MzRyVgppWTdqT3hZRUlzWXkyUk9qMVpnZ1FUekpTUEZkbDFQNkIzZWdyejcvNHRYblgvekRy'
    b'M3pwWUNUeWNLdGgvTmROV3oyWGRuYXZKU3AxCm5FZm1aeDdySGN3VTgrZGpuRmd6SktzcUFF'
    b'aXFxc2ZqOVdKeGRtUWt4S0xXcjVpS2R1NzAyTGhoM0pKdVF3aVhXL1ZQdi92OS8zYkwKRFlx'
    b'czZHcGtybEYvdFVNNCtMUU1FV2VoNzUxMGdSZ1JSU0tmZE5FVUM4TXc4RGs3dGNPdEpHa1ZF'
    b'aXZBVmdQa01ybFpCQmhCcFZ5dQpLRXJhYmw2NTVmd3Jybm5QVHo3KzduUnZweDZOQW9EdmVv'
    b'WFI4ZGY5OXk4L2VPZXRWU09LNXFZQkNWZkdranZTR1JRRXNWWTkyZDMzCjRhdmZ2dVBlT3lL'
    b'ZXMvMDk3MysxUS9nTXhMaFZPZWtZbDlEelJmbWt3OVk0WjZLbWNuWktOeXRjOWM3My91TEgv'
    b'M0cyRm5uRFJ6OHoKdHVlUnlRTjdXS3NWZFcyalRDKys5SXIxbDE0QkNDbnhtQ1JMakZFQW1E'
    b'cDR1SC9MYXpJRFE1ZS80N3JjanJzR3pudFhKSlhaditPMwpqZjI3M2U3K1hrYU5USnVSYVh2'
    b'WGhuUGdkS0xUQ0VLRWNSZ0duTFBGYlNpY01RNk1oU2Rjb2NNWVoxU1VSSFpxWEJqTjVxNzl5'
    b'NzlaCi9MenF3a3ZzUmkyYVRDOC8vK0lUbnhFbGhWR202QklBc0pES0VRTUExRmo4M0N2ZnV2'
    b'akF1VmUrWldqRE9TT1A3bHg1eWVWd1d0SnAKQkNFUlJVWFhxUjhRV1FhQU1QQWxWUTM4Sjgr'
    b'ZFlUVEVvdWkyckZNVnBDZk9ENFRQZWVOYm4vNDdwYUZWYjBxcUNnQk9xK20yR2s5LwpKdG5W'
    b'dSszMFdLeDJXa1BJR2FOaDJDeFh3c0JmaEpBRkFhZFVVcDRVcEtIdlM0cGsxK3JvaFZ2b3dJ'
    b'S2dXUzVHMDBuR3VSNlAyZlhUCitzQVBiMnBxNXJPZlBVMGhaRFNrb1o5c2J3czlGeUlHQU5B'
    b'Z0FFQnd3aTJVb2VjQ29EQ2tMK0NHUHhyNHNXeWF5Qkp3bnU3cXF1Zm4KVG1jSXVlOC8vY0xh'
    b'MHdaQ3hqQkNybWxUMzEvOHhiVmFvaUxacHZYRWpTdUI1NHFTSktreUF4YjZ2a0FJd2s5aU9U'
    b'ODkyV2hVQ1JHTAoxYXF1eUk4Y0d4bk01UEwxYWx3M0pxdEY1SVhEMVFWZElLMGdIR2p2Q0Ix'
    b'bldhYk5jaDNCTmxVakczaWUwMnhKbXRJY09YYlgzYmNuCmpSam5QSlZLOWZZUDFSZnkwWFRt'
    b'eENVZFp3VHA3eFdrZ0hBUWVNY083UThuUmcvUHpiUzVMdlk4UlphKyt0MXZOdXZOYWhndUEx'
    b'Z2wKUzI2eitmWi8rcktwcWduSGNuUkRZMHpFQXRTcjg0cFNFMFhWOXlUWDl4UXBFTVJFczFH'
    b'T0p5TzJGWWdrRkFTQk1qRU1IVVdodFFybQozTmovMkxwYTZTMkRYYnBoOEpBcW10WW9sYzFh'
    b'OVc5LytkTzZvaUhnZWtnbHcyaVpwcXdxQ1VsWkw4cUpUSXFHZEt4YXVyaC9lY2g0CnpEQUcy'
    b'dHZqMGNTeUZhdGZSUkN5TUVRQzlpeHJvVmdvRk9ZZHo2T2NqNVlXSHRuNXU2c01JcXZheDIv'
    b'K1dVM1ZHRUM3WlgwbUY3ZWIKelI4ZDJPOFNFUUhNRmdzcmxuWEptdTU1YmtXVzgwWk1EQUxN'
    b'bUdwWmhJUEhlTlEwQVlFbnl3S2xKSEFCSUdxMXFDQmd4amdoaXVkeApqSFRIRnNNd2ExdnJB'
    b'bWRMZDRlaTZZSkVBSUJ6U0hiazFDT1JiVE5UZC9jTm1xcTZvR3FBa0N6SlFSQlFzM1dyS0tO'
    b'S0VYRU9DSFpYCkhpSTBaQmpiaWhKanJGOHprckdvZ1VsZk5McXN2UU1MWkVWUDMzeXhzSFhy'
    b'YTA2VUU2ODhDSzFtQXlPMHNKQ25qRTVOakIwdTVLdU4KMnYwelV6bE5POXBxTWdBWGdBT2lH'
    b'QWVpcUFyQ200a29pcExtdW5QeHBHRlpVYzlWZEZYU3RGQWdtRFBNdUJZR1JCSkZXVXBZWmxP'
    b'VQpxRUE0d3JwakxxUXlpVllUMGJBVmlTVHJkWjlJVkJCa0ZzemtPaEF3eENIUnFHdXVHeEtD'
    b'R2R0YW1OdWdTNW0yRFBEb3d1VDBxZ3UyCkxJeU9wM3U2UTkrZjJIOTQrYmtiMVpHanJmbVor'
    b'M3NIeERCVVhDOFFSUVJBc1NDR0lXYk0xRFJQa2wxWlZWMWI0RFJUclFLSGtjQW4KMVJJZzVN'
    b'Z0tPYkJYRE1OQUVqbUhaYmZmRWdtQ3pxRlZxOU5weWZmYlU1bU42emRGakNpUnBOTWF3cDBQ'
    b'M3JmLzZIRE5jYXF0NXY3Wgp5UVZCQUlSeEVMU01xSzFvb3E0Zlk0eW9tdXk2dmlTcGpzc3c2'
    b'STdkMGF3cmJmMTZJcG90TjV1VmtxbnBhMG9GaEFhQXNVeXJPZGFXCkk1U3VGYkZtR0Fpalhy'
    b'TTUwdEZGQ2JGVnpWVVVTa2d0Rm1jWVljWmJrU2dIMEZ4SHFWWnpsWklZaGh6QVZXVGdVTWky'
    b'aVN5OE0yTGMKcEtycjVxYmZXQ2tNcmw5VEw1VEdoMGRWdzlDaVVRK2g0UU5IMXF4ZEtSNGJX'
    b'MUhOM3lRWk5VV3RSYU1na0dpcjFkSjBUNUhFa0FKbgpDSU1kMFRsSG5xSXlCS0VncXE1TGlZ'
    b'QVk5MFZSOGIxb3F4VVNjdFQzYlZWSDB4UGkrRkhGY1VNaW5IWFhyL05Cc0MyZDN0ZzNlTVds'
    b'ClZ5UXliYWNkaERkOSs1K3YzLy9ZdUNBanhIMVJyblYwMnBvdXU1NFkrSURBMUNNQ1k1cGxW'
    b'NDJJWnRzVUMyYVV4cG9OSEFhWGlZaHoKcmtkalErUFR3NW0ycU9NTXhxT0I3N2NQRFZ4MFpO'
    b'UVVTY1p4aUduV2lrV1BzVGJYWGxZdTdoMVlKb2UrcXlvQkVYWGJCZ0V4QVJ4RgpWUjNYaWVn'
    b'TG9tVHJHZ0JvdHMwUU1nMERjUjR3RmhJcDQ3blhHRklpMnV1NzNzTUw5WHMybkRQa083UmVE'
    b'ek9aWDNxTTdObW42WHFiCnByNmZlYjhNOFlPS2dpbXRKUksycHNtZVowVVVLcENJYVRJc0VF'
    b'b0RTUlpvQ0FTYlVTUGFiTnA2QkhGR2laaHZiNWNDSHpPR0dBY1EKTE1OUVZJY0p3bTdYYTZX'
    b'UzQzNTR5OTdkTng4KzhONExMcm44c2plY1hoQmFWdU5za1Jjb3MzV0RZSklKR1VPQ29DbWs3'
    b'bEROU0RPRwpHS050MlFRQVJnZ0VnWE9PTkQwN09ZcDlmM3I0eUFIVG5XanJBRVZodGwyc04w'
    b'Y1BIek1xbFVjeUhWaFMvTUMvTTVtdDdSOTVwS09uCmNjNVdoRkF1Q01KNEVnbkFpWWc1WTRv'
    b'Q0FGd1FCRW81eHBoeERpQTBtelFXNVp5blJCRzdyaGlHVytjbTE5ck4rVVFxYk5UZFlubm4K'
    b'ZVJkc1dwaHJtWTFtd0hMdDJlcXExZmVNSDFrN2N2amU1UmZHVzgwMWM5TzJHWjl2YStlY1lj'
    b'OEZoTUQzTWJXcEhvRXc0TElDUk9RWQpZOTlEUWNEanNhVHJBaVpBTUpVa0pJb0F3QWtCTEhB'
    b'RUVETVdvL09HN1FraXg2clVLQldIZHovMC9DRjhnVk8rMVBkLzlNOWZvQXRUCmV5S3BJNWt1'
    b'WDlXNTV6RFBGNklHRDBKZ0ZCR1JXaGFXSkI2R1BBeUFjNnhGV0swaUlOUjU3UERNbXZYY3Ns'
    b'RWlDWTZOTEpQcEJ2SWMKaU1hUkpIcVdDUzFUTWd5UUpQQjlEaHpMQ2dpRTJTWnc0SlJDR0NK'
    b'Q1FGR3dyaU9Cc0ZZVEVFYUVJRVZoWmdzcGFxSmVXejU4WUtaLwpxSmhyenhibXR1M2J0V2Y1'
    b'bWxLdS9iSUg3M2xvemRrYzRmUDNQdnpielJmVXRJam0yVGFST0Fla0tzeDFFVUswVVJmaUNX'
    b'NVpTRkZ3CkxNWkRpaEJRczRsQ2psTXBRSWc1Tmw0TTV6SU9oQURuM1BlNDQvSkZjOGExc1JH'
    b'VGdHbTYzbUUzbHRWTGFxdVo2VjN4MWc5OStqbjUKdU82eFkrUHZmLytMQytIeG1sck5SMzkz'
    b'eDlUdzNrcWpPcFpzcTBSanBoY0VBQndKMUxXRFpwUDVBUkJCU2FhSVlUaUZlU2thOTVzTgpL'
    b'WkZpcm8xbG1WcTJvR3NJQ1p5R1dKWllFSElhY2tyRmFKVGFOZ2RBb29RWTVZQUVXYWEyelNs'
    b'RlJQQnFOYUIwY1J6bFZCb1FwcTdOCmdnQmpBVWtTRnNWVWNhR2thaFE0Y0o0Ti9EQ2t6V1JT'
    b'czB3NW9CVmR3NEtRblovTjVlZUhWNS9sWWlMb3VsY3BDWXFLQkFFVEVXR00KQk1JeDRyNlBB'
    b'REhPZUJnZ2pBVkZRUWdCd3RSekY4TkpRSm1VVEZMUDVSeUlxaUlBQllHS1FPZGhxdFhvSzg0'
    b'U05icjlyWC9XczJMTgpVZ2IySllQd1JHcFdTbmZlL09PeDJVa3ZtYXhxc1JxREFJQWlJVVRB'
    b'S2FPQno0RUxBa0VJYzg1OTB3UUV3RG5neFVnM2xiU0lxS3FBClVPZzZackVJd0lrb0JhNHRH'
    b'VEUxa1VBSWU4MG1ZQ1FRRVdFc2lDS2xsSWdpQUZqbE10RVVIb1JZa2ptbGpGS0VFY1lZRTVG'
    b'VHlqbHoKYWpXanZjT3AxMWdRRUZYbFlZaUl3RUtxR0ZGR1E4NDRjSTZJQUlCRWRmR2lYZW8x'
    b'Nm9Jc1k0eXhLREpLbWU5ekRnaWp3TEV4RVltaQpDS0lFd0RFUk1ZQ0VRQWFJaGw3Q2JxWWJG'
    b'YVZTSkoyRGw3NzV1bzYrZ2FYenhzc0M0Uk9lKzBOMzNUSzY5K0c2MVdLcUZFVGpwbUkwCk5N'
    b'T2tOQWg1RUlhY1VjKzJFdTFkNklUajZwMW1Ld3c4QUlpbXM1NWxDcUtJQllHR2xITWVlcDVu'
    b'VzVGRUVtRkVReHE0RGlDRUVBcGMKRnlFdzBoa3NFQlpTMzNVQVFOSlVGZ1N1YlFFZ3UxNVZJ'
    b'bEVpU2RRUE9PSUlZVUpFTEFyQVFkWWpBT0E3bHU4NHNtNXd4Z0NoMFBNQwp6NDBrRWxhekpZ'
    b'cWlyT3UxL0p3V2o3TWdGSWlJUlZFUUNDQXVFSEh4TmtrQmdSZ0dDYXVlYUZiMVdwRzV2dHJl'
    b'TTdSMjgrWkxYdi84CmZjU1hFOEtUc29DK1A3eHI1OWpJbnNyMHVHaFcvZmFlU2pKWFYvUnl5'
    b'eFQxeUVKK1h0WjFJaEJCSlBWU0tacEtjYzQ1WTVLaU9wWVoKK0o2QUJOVXdmTmNSQ0ZIMENB'
    b'QjR0aTBRd2ZkOTdZUjFiQURnZTU3VGFtcUcwYWhVUE5jUmljZ1lNeElKeDdLU2JiblFEd0xm'
    b'cXhVTApoQkJNaUNqSnNxb0N4Z2hoVVpKOHg2RXNSQWdSSWhHUmVJNmpSMk9WUWw3Uk5Jd3hw'
    b'VlNVWlJxR0FvZFVMS29na0FDa3dETWExVVJwCnh2VjhKZHZkT2JCeTR3V1h4ZEtaRjFKRG5T'
    b'WVFudFFteTN6Z04vODFQYktmTnFxOExjZGtMWkJFVjVCY1VRNklGR0pDQVVJQXgvTXgKRVU5'
    b'Y1JPTzVMZ0NYWktWU0xHQ01YZGNCRGgwOWZaUlMyMnlxZXNTeFRNNUJrdVhBOHpBV2lDUktr'
    b'dUo2RG5ET2FJZ1ExaUlHNTl6MwpQTWFvUUFoR2lJYlViTlpsVlhOc1MxVjFRU1NpS0MxbXdR'
    b'Q0FNeDRHdml4TEVrYlNvcHhFWEFwODBYZmtWbDNOejNvY1lqM0x6dDErClZjL3lGeXZlZGpw'
    b'Q2VDTE5IanQ4Y1BmT2FtSGFxWmFSM1ZKcG9HaXFweG0rcWxOSjhTWEZsbFZQVWtKRlI1ckdP'
    b'SEE0L2tmREVHSGsKZTU2aWFwYlpDb0lBQ3pnYWpYdXU0N211SUJDTWNSaUdoQkFpUzQxcUJR'
    b'dUNya2NRd3ExR2czR21xRm9ZK0pTR3FVeTJVYTlqaEtMeApKN2Q4WWdDRVFBQkFucXZZcHVw'
    b'YW9tdUpybzJiamFCWm81S3VaWE9kQTZzMlhuaTVrVWkrNkRQK05JZnc2ZkoyN09CampYcWxX'
    b'YTlZCmpacHJtWjV0aG5hTDJaWkN1SkRPZWZGMEVFc0drczRFekFFWUJ3YkFBUmdBUC9senlG'
    b'a1FoQUFnU3hKYTlNNFFCTDR2RWxIQXgxbWIKTXliZzQxOFE0NGd6RWdTcTAxUmFWYkZaOHlx'
    b'VkFCRFdERFdlaW1YYWM5MTlBNnZXeFRPNWwxcG9QUk9FcCsrNU0wU1NWbXc4OXhuLwpGYmp1'
    b'WXcvZU0zVjB2elY4RUZrTjVQdFlFQWdHU1phd0xJTWdja0lZa1FFQkYwVEFtR1BNQlpFanhC'
    b'N1BHZUV3UklzTGNCakZnWWQ5CkR3Y2VDbnprT3E1bGV3Z3hXWmRpaVdpbUl6ZXd0bmY1cXZh'
    b'K29aZDNRLzFMNTlxL3pFbHR5NndXNTJxbFlxTmVNeHRWeDJ4NXZ1TTcKSm5waXhUT2praDdG'
    b'bUlpS0lva3lGb1dJRWNPSTZGRURBR1JKeWZVdGk4UVRwKzBac3E4d0xsd0N5WHFrdlg5RmUv'
    b'OEtlRFhSbVVzTwpYdkgwUW5LaDliU3pwWjdEVkZJVWRlWFNkenpUZXQyZG5GeHljU21YRTNO'
    b'THQwMjhxYW5uYzFHU3Vtb1Zsay9wYm1KRXlJdXJDdzlmCmNzblNaV0J2NytEMTF5ODlqSGZ2'
    b'dmJOZit0S1NpMmV1dlRaejNYVkxkNGUrK01YbWZmY3R1ZmpnZDc4cjkvV2Q0c1Bsbi96a0tS'
    b'ZUoKbmhHa3J6Qkt2L09kMlpNdG1qTVF2dUpSUEFQaEt4N0ZNeEMrNGxFOGMrM1dLeHRGN25u'
    b'L0grRkl4NkxOVlFEZ0FBQUFKWFJGV0hSawpZWFJsT21OeVpXRjBaUUF5TURJeUxURXdMVEEw'
    b'VkRBd09qUTRPakl6S3pBd09qQXdRMW4ySlFBQUFDVjBSVmgwWkdGMFpUcHRiMlJwClpua0FN'
    b'akF5TWkweE1DMHdORlF3TURvME9Eb3lNeXN3TURvd01ESUVUcGtBQUFBQVNVVk9SSzVDWUlJ'
    b'PQoiCiAgICAgICBpZD0iaW1hZ2UxMjcwMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'CA_PE')

CA_PE = b64_CA_PE
index.append("CA_PE")
index.append("Canada Prince Edward Island")
catalog["CA_PE"] = CA_PE
catalog["Canada Prince Edward Island"] = CA_PE
country["Canada Prince Edward Island"] = ('CA_PE', '', 1)
lookup["CA_PE"] = ('CA_PE', '', 'Canada Prince Edward Island', 1)
lookup["Canada Prince Edward Island"] = ('CA_PE', '', 'Canada Prince Edward Island', 1)
details["CA_PE"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-04:00","altname":""}
regional["CA_PE"] = ('CA_PE', 'Canada Prince Edward Island', 1)
regional["Canada Prince Edward Island"] = ('CA_PE', 'Canada Prince Edward Island', 1)
#----------------------------------------------------------------------
b64_CA_QC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjgyNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1F1ZWJlYy5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMTI4'
    b'MzEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxMjgyOSIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMjgzMyI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUNOMUJNVkVVQVBhVi9udEwvLy84U1M2dGQKaE1ZQ1A2YTJ4'
    b'K1g3L1A0K2JMczVhTG41K3YyN3krY0RQNloybDgvbTdQWVFTYXNPU0tydTh2bDluTkh3OVBw'
    b'cGpjb0JQcVhuN2ZkbwpqTXF2d3VNdlliYXV3ZUxRMis1UGVjRlFlc0hPMnU3UzNlOVJlOEpT'
    b'ZThMUjNPK2Z0dDBlVkxBZ1ZiQ2V0ZDFXZnNQVzRQSFUzdkJWCmZzTUhRcWRhZ2NWd2tzMGxX'
    b'YklKUktqeTlmcDhtOUVGUWFkemxNNHFYYlROMmUzNisvMWxpc21pdU40aldMRmppTWhraWNq'
    b'TTJPMFUKVEt4aWlNaVRyZG45L2Y0N2FycEtkYi9KMXV5c3dPSVlUNjBaVUs2NHllWXpaTGVS'
    b'cTlqWjR2S3l4T1IxbHM1WGY4UlpnY1F5WTdmWAo0Zkh2OC9uTDErMFRTNnkrenVpT3FkZU5x'
    b'TmU5emVpQ29OTWZWYkJjZzhWQ2I3eVdyOW9WVGF6RDBlb0tSYW1jdE55YnM5ekIwT2tXClRx'
    b'MlZydHBEY0wxYmdzV0JuOU1HUXFlWnNkdm83ZmRmaGNlSHBOWGc1L1Jzajh2ZDVmTThhN285'
    b'YTd2ZTV2TnFqc3JmNS9SZ2hzZVgKc05xcXZ1SCsvdi9FMHVvTlI2b1hUcTB4WXJhYXN0czFa'
    b'Yml6eGVTZHROdzBaYmNQU0tyOC9mNjZ5K2RGY2IzQXorbEVjYjBMUmFsMwptTStJcE5VTVJx'
    b'blAydTRJUTZnblc3UHg5UHJ6OXZ1L3p1Zy9iYnM2YWJtNXl1WVJTcXVMcDliRzFPdEdjcjdW'
    b'My9DOHpPZjE5L3NvClc3T292ZUNwdnVHZ3Q5MVRmTUwwOS91bHU5K211K0RZNGZGT2VNSEsx'
    b'K3pJMWV4TmVNQituZEh0OGZsQWJyeGhoOGRZZ01Td3crTngKazgwbVdySk1kOEEyWnJpVXJ0'
    b'a2tXTElFUUtZZFU2K0pwZFhjNVBPQW50THA3dmZyOFBndFg3V28rbkxQQUFBQUFXSkxSMFFD'
    b'Wmd0OApaQUFBQUFkMFNVMUZCK2NJQXdzUEo4dVhJL0FBQUFSYlNVUkJWR2plN2RyL2N4TkZG'
    b'QUR3NWFYbmhkUjhveHhTMHlxTmhaQ0VObTBvCnNhaHBDMmlObEVxdktVRlIyMUpSSVFWRGF6'
    b'RkhLYW0wZm9GU0ZDc3RZQlVhVVBtbVZvVlErZkxIdWJjZG1XR1lUdWYyM2cwTXMvdkQKemM3'
    b'Y2U3dWZ5ZVQyM2U0Y0lhYmFFbGlnTFNHUHN3bVdZRDFsTEZ1Uk5hd2lteG1WOUl4c3Q0SzEx'
    b'Rkg4ckFtV0U4RGx4bWU1WFFCTwpmcFhIU3lkWWhzL1NzMHJjM0t6bCtnUXVCWnVsck5Bam51'
    b'Tm1yV1F6bEdLelNsbkU4OXdzSDhzdncyYVZzNGdYdUZrdnN2eFYyS3dLCkZ1SG5acjNFOGl1'
    b'eFdhdFp4QnB1VmtCUFg0di9KQWIxaUJDUEtMeXVxcHBFYW1oNkxZbUcxdGRoc2VyV2g2S2ts'
    b'Z2JVUkVoMTFicXcKd2FLekFTRDJNcW1uK1J2ZHRDKy9nc042VlFaNExiNlJCdFNUQnRyZllL'
    b'd0lOZXBETjIzYURMQ0Z2SzczSFc5Z3NKb2QrcjAzeVJhQQp6UW5XZjhzUWF5c2J1eVZhQXRz'
    b'UzgvTzBZckRlbnIrNWZSdVVSRnRZdDgwUWF5MkEydDdrU0hhQWZRZTQvRFEvZ01GcTFSY0dG'
    b'NlRzCnNETWVhMnBYRjNtZ0htbnZnUHd1MlFYdnZROGZkUHE3U0RkNGJSaXNwQXE3U1plLzUw'
    b'UFk4eEY4VEZiTDhJa2gxdDU5TGxxNzByMzcKSVh4Z09TR2ZaZzdpL09YNytqK2pwWFlnRFBz'
    b'UHJhQzFOdjM1WG9NclJEemFrUFg2Z2xwV1Bwd2RQQ0poTFJEU2tjSHNZVG1yQlgzZQpiRU0w'
    b'enJGME5UNllJNDY1bk1ZZnhEUnlyZkZEb1ZCSWhYMzBHc1praGVtQVI4RkxyME84MVNlbndi'
    b'Q0NYM3lVWWRCeS9HK251VFNkCjRBdDgxaG9ha0Q3R3pSb3BIb1YwRVQ2cktBMmpYNDZZMkdN'
    b'TXczWXJkajdIb01YVVB2R3JyeVVyV0ZMUE4rYjJyOGV0MmI0ZUYyY1EKZ2lWWUQ3VVRwbHJ4'
    b'UXF4aWMrTVNlQ0tiWUFtV1lBbVdZQW1XWUFtV1lBbVdZQW1XWUQwdTFwaXAxcm5RdUozbXho'
    b'Vm5FSUlsV0ErMQprOWF3VHBwVGxZOUhyR0NkYWcrWVVYMzdIZFJid2VxRzAzVW1XTi9UQ2V6'
    b'NHJBa2EwTUd2K2tHZjRBdys2NHdlc1pTYmxkTFRSeWV4CldXNVpqNWppWnAxbE01ekRacDFq'
    b'RVdlNVdlZFpmZ2lieFQ3ZGdmUGNyQjlaL2lac1Z0LzhFYm01Tlh3NmdzMktUSnVyQXovcDZU'
    b'L2oKUDRrWDlBaXVoU3V3dGVhaWpZelQ5SEl5RTh4ZnN1R3drcGZ6d1FyMkZkNDRTVjZzK2NY'
    b'Z1IxeS9halRUMStVRVVNTmxldjgzQ1lNbAp0ZE5iMnE2d0N1Q01YdEg3Vncwdjd3RFhLalhv'
    b'OWx4bmZUc0c2d2E3VitMcEJxMnlsdlYzR21JZFlEbjlTaHUwL2o0L1R5OEc2Lyt4Ci9vQTJa'
    b'WUIxQnd5eGFIbElYZTJCMHN0US9hZGpkaWF6VUswd3lLTFZMRE16NjFqNUYxd2FncDYvVTR1'
    b'VXRrZmFQM212UXBybFZUdkEKNDI4a1pCWXVLQmdzSlF0VmhOejBlU0JWRVdzbWtwbzMrUEhJ'
    b'cmJIQzdVUm1iamZrVkdlaVVONHI0VHlKMHFHeVF1S0Vtb09qYy84bQpiaGZtYmowMVh5VGR5'
    b'V1F5TWJoTHI1T1lyRWs2NEYySTBlc2QzbVUra29kYUs5NU9sOEhwVS95dmdZVTlBUGZ1NDdQ'
    b'dTN3TzRXZUJtClRXaUx2ZDN5c1RyMDlYMkMvK2ZxNjRlcEVYeVdld3I2RDVyWitveE4yNno0'
    b'YnlXbnpaM0pEQWFzMmI0R0JzVVpoR0FKMXBQUCtnL3UKVkdSMjNTNnlTQUFBQUNWMFJWaDBa'
    b'R0YwWlRwamNtVmhkR1VBTWpBeU15MHdPQzB3TTFReE1Ub3hOVG96T1Nzd01Eb3dNR21rRElJ'
    b'QQpBQUFsZEVWWWRHUmhkR1U2Ylc5a2FXWjVBREl3TWpNdE1EZ3RNRE5VTVRFNk1UVTZNemty'
    b'TURBNk1EQVkrYlErQUFBQUFFbEZUa1N1ClFtQ0MKIgogICAgICAgaWQ9ImltYWdlMTI4MzUi'
    b'IC8+CiAgPC9nPgo8L3N2Zz4K', 'CA_QC')

CA_QC = b64_CA_QC
index.append("CA_QC")
index.append("Canada Quebec")
catalog["CA_QC"] = CA_QC
catalog["Canada Quebec"] = CA_QC
country["Canada Quebec"] = ('CA_QC', '', 1)
lookup["CA_QC"] = ('CA_QC', '', 'Canada Quebec', 1)
lookup["Canada Quebec"] = ('CA_QC', '', 'Canada Quebec', 1)
details["CA_QC"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["CA_QC"] = ('CA_QC', 'Canada Quebec', 1)
regional["Canada Quebec"] = ('CA_QC', 'Canada Quebec', 1)
#----------------------------------------------------------------------
b64_CA_SK = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcyNjU3IgogICB3aWR0aD0i'
    b'MjAwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDIwMCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IjIwMHB4LUZsYWdfb2ZfU2Fza2F0Y2hld2FuLnN2Zy5wbmciCiAgIHht'
    b'bG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3Nj'
    b'YXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5l'
    b'dC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAg'
    b'IHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAg'
    b'aWQ9ImRlZnMyNjYxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2'
    b'aWV3MjY1OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcyNjYzIj4KICAg'
    b'IDxpbWFnZQogICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAg'
    b'cHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJp'
    b'bmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7'
    b'YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFB'
    b'QUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFB'
    b'ZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBQQpC'
    b'M1JKVFVVSDRnd1pBellodUlyYVR3QUFGTWhKUkVGVWVOcnRuWG1ZVk1XNWgzOVZaK3ZUZTAv'
    b'UHZnREROZ01JQWlJb0lBcU9ZQVNOCm9zRmN2WWx4aWQ3NHFERnVlWEs5MGF1Snh0eVlYUE1Z'
    b'WTd3U1RSNmppUXRpQU1Xb2dNcU95TDdOc0RvRHM4LzB6UFI2bHFxNmYwekwKSmdaakJzeEF2'
    b'WC9Obk83cDU4ejUzdjZxNnF1cWM0aHhhemtra3A2R3lrc2drV0pKcEZnU0taWkVJc1dTU0xF'
    b'a3B6SHFQLzhSMng1YQpaQ2duUkZBQjh2ekt1WSs4K1dzWnA5TlJyRDQ1WmJUclJXTHRpS1Y4'
    b'QVNPdEt2eVFHUnprTThweEc2eUZBaUFCb1FiRjMvbGtGdjVPCjFCZVJRVHBOeFFKQXV1YSsv'
    b'NGZxQWJFRG5TN2RQbTdBeGFQV3h6L1UzQmd5MVlvU0ZxSHpYYU9DcGRhcmJnY2hDdHBlMHRN'
    b'N2xlQWsKSjNxdHJReGtiaWV4cWhXbm1SS1AwRXU0WHNZVmY5WTJiazZTRVRxdHhRSXdZVXJO'
    b'M3B2OWlwZFB1M0c5Y0JCN1ErTVdZWjBFS2hTZgpNQ3BZYXJ1U2U0MEZ3RC9lc2VvVXVMRDIw'
    b'Zmh5VlM4U1Rnc0pUWE9TcTlYNE10WHRJT1lncm9TRmI3UXJ3M082aThVRVhmOThhVFFRCkV6'
    b'WjRtckFFU1ZlclNvZ3JQdGd0eEdsUUFIZ3JXV3llcnVVSXFBS0MwQ0FQVG5FSUFVajJROExU'
    b'YlpZZzNla3F2VVBwZUZzUERaTUIKT3IzRlVnZy8rNjY2NW1lTXRsZU0zZC94UjJiYVJqOG1Y'
    b'SGpITUxGY3pleWw4WldxbWlzOFE1aUlFK0hDYmlMT0pyVmpnZVoyVXVGQwpNWVdhSS9RU29S'
    b'ZHh0WkJydVp3b2NPcUpESTlzQ2dFZ2NKNGJtNmNyUHRIMXJtb081dWs2NVgxcnhEaHpLNERt'
    b'cHoxT0N4WDJrVDB6CkZlS3c1czRvNVFXM1pYaWNKUGVxMUlQYzZ5d1pIaWtXQUhnR00zTVlv'
    b'eXFJTGxKYkZOOG85OXk5VzJpdWlLL1V6RW9HY1BzQVZjT0MKK29WZXhyUUNZZGRTcTVhcUVa'
    b'SFpxUUJ3TzBqTEg0M0FSTmMzeG9VQzRSS1pzcVJZMlF4VSttQzY3a2RlclZBUUJmRlZHZ0Nl'
    b'SW9IeApqbDdFN1FQVU00anBwVHg0b2RQNmdoRjdRd2VnaEVTL3B4THg5N1hHcHp5c2s2UzNL'
    b'K2xxQmM4YUFJcnZ6ZmhHeXdDZDltTHRhODN6CnRGdUZnN29LZjVCaEhjU3NZTW1OcXBiUFdB'
    b'ZFZjM2htbDFMMG93eU5ZdFhtUWVPTHE4MUtudnhZc0U2aWhzWCsrNzNScSt3Qkx5VFMKbTFU'
    b'aUZVcEExRC9xY1p1cE1ZREo4RWl4NEc5TXhYNUNNZDREZ0Z1RU1BZ0h3aUZPSzdFYlZCQ29R'
    b'ZjdCOW1HbHo5UTE5UEg0UnZIUQpSWGI3YTRiMUNiWDMwL1FPcGZUaGRIMTVMcGE2aGRFT3Q0'
    b'VVczcEV4eXBrMFM0cUZEZTZBZ1VQMmRDM1NlSWFBQWdKcUxoY1dVVUk4CmRKR2o1bkNvT0cv'
    b'STltMEZ1ZTVpSkZZSm5pRnFWUGpIT2twQUJDOXk5Vkt1ZGJIVWJyUXVNbWdKTVMvZ1JKWFJr'
    b'V0lCVlNNM0xjME0KNFdQRnhJblY2VzJLVmlpSUp0UmNRVFZ4Y0thYk0xSitUK2RIRmVYblhW'
    b'd3RNb1RvUXZFTG9tVmZMYzl0Wmora1MxWVBPNk9pOWtCSApUci9jRmhtZTAxMnNWWTFHUTZN'
    b'UGViVXNxc3h2OFNJUFlBQUQ5aC9yM1dQcUZyUjZzeiszZitiVnZEMnIyZ0c0R3pwOVk2T0tq'
    b'TkRwCks1WUErZVg2MElKTmVUMStjbk1INkRKQ1h3UTk3aG9wRmk4d2pqTnN0N2lSNHBtSTJq'
    b'dkVPb3F3eHMvTlNWV0U3TnFVK2xHTFdXZGwKbXpvQzlEZWRzd3ZTWVpYdDd0Sld0bmtUTE50'
    b'R0ZobnU1TUpVZjUrOUo2bjlyZDdmNXNoRTlZOXg5bzdVbURiM3lTa2ExNCs5ZnNuZgpaaytx'
    b'VGwvYTdQNXFrTEV6NHU5OVl2a1ZmdGZROWttRjZRNkw1dnA0UjZycko1dWlxOXRNQUZYNXlm'
    b'dEh0U3NLR3BMS3pIN0pkMnV0CngydWlBaGdWeWR4L1pudUJ5Vm9UWkhKcCt1TFM1UDNyYyt0'
    b'U01sZDlZWmo0V3BNejA2WlkzUEduRWI2MjRxUHoxb2dOOFIvdWMwWngKQXRCZjBwTlVkZTdo'
    b'QlhwamM5S1hscWVpSmc4cHJzSDU0RHcycTA5Y0pTSlBZOWRWeGd1RFBFQjVHRTVoZ0Uvcmx4'
    b'N3N0d0JjVVJ3ZgpXMnBIZE80RHl6SDR1SHhuWW01YTJ2TEY2YnNyZFpsTkFkeVNJcyt0VGs1'
    b'WTNVV2NRNnZjeHF6dG1yMm4yeW9BNkJ0bnZVOHN2OEtyClNsTWNJRno0TlppNmNCbENCcCtZ'
    b'bTVwU25EUW9wd0tHTG9LR1VEbW5GTk5La3FNaW1hSWdUMlNvcG9pUVI1aFVwQVFaVTJBVkc0'
    b'NDAKNWdzeUxNYTYyeDNxRllNRStiOEQ3TnRMWXNRVkFQclhKSDlWeS96ZEMwZ0lBUFJMOUVL'
    b'eERDcEsvWXdLNGpHSXBvanVqdjNncURzMAo2aFI0M0J5RFc0eEFRRmRBTkZJWTRHY1YySDFO'
    b'cDhqbmNsZFFDbDBEQTN5YUdKTGpEQXhLc2I3d1pXZUNxQWpPdEQyalhjOG9sd0QzCkpjajRk'
    b'WEc5aTkxWmJlVWU3UHZla0FHUWE0bmVKMWFLa1pSTDBveHdnYUFmQVM4NElRd2s1U0RPRkNZ'
    b'QUlRd2Q0U0FNQmJFMGRSbXAKU1dncUZZNkFwaUlZZ005RXdvWktSRjFhbGtlL0tEdUNpaEFJ'
    b'M1pUSmJGU1ZzT2pPVGQ4LzRFNWIyVkhsWkZ0QVlvclVVZzFBbmU4awpiWi9weWZpbE9kVXAv'
    b'S1pRS1FTSG9BZ1lYQkRTbWxMOW1zajFDMG9JaGVBQUphSWt4RDVxMHB2U1dsQVhIaDNNaFNE'
    b'UU5JUTlhRTJqCnc1SUR3MlBqYTdCR0hyRDJoTlcyc0Jic2RDSVp6aGovbTh1dW5xY2J3MWh5'
    b'U1hZTWZvWWdqeVlQOWRORm10ZzFpZ0EyUnRUZUp4YUEKbC9mNlMvMnhQcWJnRkRvZ0NGbldZ'
    b'SHpZNGkweTNhVU5uaWtGU1V1QVVGQ0twalNkdlRPVVptVE9YditzQVFrL1pTcEZHa2d4TXJz'
    b'NgpGSk1WaDg4aDQ2VVA3bk9LS1d2bm1RZ2wzWmZKZ2RJNVc2RStBV0JPMmo3QXVFSndqcWE2'
    b'UUtXbWhBalpHblQ2cHBRbHdMWktyMGd6Ck9JTDRGQ2lrMTRqMXQzcGZhMFo1OFlKR2NDUXRi'
    b'Ty9TYmwyZUw0Q3V1SDdQeXR3NVZVNUZ5SFpjdUE2K3V6Ui9XNWNCNEpkYkk2YksKdnpVd2J0'
    b'bWdETE5yL0s5OEVwQUNmVzV0SWFCdTBsREtrRXNKQUxXUWU4OXprb3QxMWtaWUo1bVR0aTJC'
    b'aEVCZlF0WTU3amFIYjNYZAorMHFOYmVWMjVjZWU1MHExLzFqU01Ta3VjamkyYTFnUlVSWU85'
    b'OFZ6dEY1UWJnQlE3R1BnWUF5cWloSy9lN0N2NklDRUZkZDJRQUNQCmdUTkNoeGFJbHZ0ZGhj'
    b'QnJ3RzlpZU1TVzl2emRpSkZxLzZGTTR6YlMrRnhqdGVvODNKWG13Q2VNZTR2NFVzc1phNmh2'
    b'Wjl5N0E1NHIKd3ZyQ3ZwazdJc2F6ZmZVYjJ2anRDWEltb1dVS25jcnBmN2VKaDFkMEJWcnQz'
    b'aUhXNkVnbVA0cUJmZENuQ0dWaGZ2aExmYUs4ZnduSwppeEVOWTJUMDBQOHpKT29VNUtLa0FF'
    b'RS9Lc0p5Yzg1eDJCWStvcDFabFhJTDY5VnYrWXdYVXRZS3k4MmY0bDVmcXY4MlljM01VLytj'
    b'CnNwUERuY21seWcwMW5nS0d5d1FGb0E5a29Xc3NyWndCbUdiVG1SdVR2YUFwQkpCMFNhd0xY'
    b'UWt3QVVyaHBTekZGUUFVSXA0QUVYQWQKR0RvUzdxR3ZYVXVDdExSREFKU2cwNUc3L28vRCtu'
    b'NmV6YldKa2JtaWU5L3Z4NDY3d29aWElTTE1CekJsU3djdDdNZXVHMDBheSt6NgpqNGppRjYr'
    b'L280VUg4dDk5UGIzclk5THZBdWFMS2ZIbEttdk1YdWNiT3ZGNlF5WmU1UGxYejFnQ2NCZ2NC'
    b'aTdBR0FyTmJFVXVWM2MxCkNzdUdxaUdSd2VHYjhvVWd0Z3NDV0RZb2hGVG5PR1dkcVA1QXBi'
    b'RXV3dkorbWpMUGNXLzFlYTcxNnVGOGNkNERkbUtFK2orN2ZHOUcKbGZydmVHL2ZVckJTMCt0'
    b'WEtOK1lLc3JLTzNjTnRuN2JZQzk5VkkvOXhuUGYrM1pkSW51ZDg0Q1I5WFl2eUZoUk05djhL'
    b'UVFPUTU2SAo3VWtDUUtHUGdZSVFDQUFDRWZPUVFCRlBWajVOUlVqalVwM2pVajNFZDIzR0xQ'
    b'OVRxcUtMaDhKc1hKdFlrWEh6bW5IVnJOUzZ0ODJsCnUvVGNmYVlnMk92NnZuZEY3S1lIblMz'
    b'VjJEOVg2L3dZNDBJYWdBZUM1akpGdkJnaTFTRkZCOXBPd0plNTU4WEs5WEFBUWtCUllMdkkK'
    b'KzlTelBBOUhkL0ZPQUFUUlQyV2lFRkV2aDRBUUlCUVJEMWNnR09RT25lUEFQWFQzVUg5Ymsv'
    b'M3Q5WWtxUlNGeDQ2MG43SzVTOTJmMwpwbSs4Rnd0WEt2QVJFaysvc0ltVkw4T2Q5NUJvbnIv'
    b'NVhQWG1KRStyWkhkRTdTajJRTzA5NVFZQVVaTjFpNVgxekpzVktOL0xBQkNSCi9YWkVqZXp4'
    b'QXNNTkdpS1ZnUUNJUU1BUStZYmJZR2xTbmVOU1ZKdCtaRVA2SEpjUUZWZGVJd1orb3BveGJl'
    b'eUkxS1A5Zlh0clVsV1gKYUcxZUpEWmlzRWY1OHpqUDdqVnNld2QvYVpDNWU1QjVFczd0UkdR'
    b'c0prQTZIWktqQ1UwVitaOEtsTzlobW9vdW13aVhoRlNlNDhsbQpzbnlUS1JRV0p5MDJ6Zk53'
    b'UXhmNVhpYkZPaTdoUnZ2bjYxTmpHQVZBUE1LdVViWms3QU1PZi9VQjh0ZkhyVVUxdUgxeUcy'
    b'TVlPbzVrCk5palJWbHA0UGh1NVNITjJwaC9yTFdJbHJHU2VQM3J3MXdkWDU2eUxHVjJ1b2hJ'
    b'eEtHZ2ZYSG0yK0lDNVlKOTNUMUlYUUxIaFZJU3oKMDh3TkdYWEtYNHQyeGcwT3FFUlVCS3ht'
    b'SzN0V1VWOWtXME9OZE9pWVRLMUpkMXZsbmVoNHhycXNrVjRlVno3cTU2ellMRnFmSTlPVAo3'
    b'SWVQNklQT0VBc3ZWYjBiRlNkR2tqVWFnRWJQU2VwaktPclovK3dOcU1xalpYZFB2Y1h2OGRj'
    b'MDdZNW5FdnRTbXNVcEFBN1NhcWxOCm1hd2x6Um4xNEVSTm5DbjdrdHFuNVFuYVpxdmQ3U01I'
    b'YWJIVUZLUERTeXFmdVByaEM0ZE1mR3poYjNhM2ZDSTEraXlUZHFiSFdhQisKb1lSRmVybVdY'
    b'cWx0M1lvNTIvZ0FoWDZ3a0FiMmFvRTRmVzBMbjNxSlVMZW96bjRGd0U0aUhqL1Rtd3FxdlVP'
    b'c1JUdVcrVHkrT3liZgpjUHVGTjQ0c0c2WVFVdHQrd0hhL3pMcVhrQm00NnF3WlA3Mzh2cDlk'
    b'OFovOTgvcisxeHVQdmJSbXJuVG9tT1EzMmxNVFF0Z2tjSVdkClhxWENKWGtLM2FQcHM0TmVM'
    b'OFYwV3htbUt0Tk5UZHVoQXVBSndvQzcrcWk3S24wbjUvUklUejJaSWorUWU5MjVWODBjUFgx'
    b'azJiQ00KWTcyNy9jTzU2eGUrdFhsUlp6cCszTC8xRzk0Wkk2cG1qcDQrZGVqNWhxcnZiYTM5'
    b'eTlwNXozNzRZa05ua3hUb2M3K0U5ZFpySzVNbApoQ2c1Z3JVVEFUd2FGSCtaRUxJWTUybXJm'
    b'ek81WjFkbUtqdFVMZnlBOE85ZG1uTkNSNEluUkt5RGxPVVVUeDE2L2lYREw2eXFQRStoCmRN'
    b'MitEYSt2ZSt2bHRmTmE0bTFIdmRQVVBGTXFKOHdjZmNsbFowN3pHOTd0RFR2ZjNMeG80WmJG'
    b'Sy9kOExJUXNreDZmS3orSS9hUU4KZi9XSUZSRjFUNEJ1RytJVENuSGpGbWVBcHBxdHFmTnEz'
    b'Vm50L0FKR0Fmd2lLSjZ2eWpscDUwWk8zTE4wSXQ3UXhXZE12blRFMUtuRApKdW1LdnFSNitk'
    b'ejFDK2R0ZkRkdHA2Y05PMy9tNk9tWERKL2lVWTFsdTlZczJQVGV2STN2MUxZZmtLNzhRM2c2'
    b'Mll3VnNRVVRJcG5nCm9WVkdMR0V6ZndDcE5GSnBhdW9lUXM3ZmxCemQ0ajQ5SVpqSTBVNEZz'
    b'UTc5LzVweFllWEVHU011bWpHaUt1d05aUnlMRXZMZTlxVUwKTnIzMzV1WkY3Y21ZVk9UTDQ0'
    b'cWpXamVlZGx6REMwTFEza0ZOWGZXcXgzemJxU0RXb1pFQ1ZjN3BQenJpRFMzZXNUeGx5NjA0'
    b'Sndvbgo2UXEvSDRra0ZVejFmelViNlU3cTBuTEcyZkpkSDhuQW4vQnNJWmdBWUpyVVNueFY1'
    b'eURYcUp5Q0tEcUY3ZEJrbkpxNkZFdlNjeGxMClU0bnJrSzgwdHNUZExOY1JuR29rTEpUUExu'
    b'dndyT2JienZuS2JoQ3N5anZJbm9JalJRNEhsQXQ4TnJnZjc2ZlBiVFEzTlNodHRwYm8KeUJT'
    b'RTZZV0QrTStxa2oydWdkd1gycHQwdWZrVkxUK3M5SW53Z0FGS0lBUlc3eU50RmgyY1I4ZVcy'
    b'SmRVWktmUmJCZXVvT0l6YTlwKwpzY3p6aS9VNTdXa0ZmcSt2cXkzdHlhdVB1eHQyZW90OW45'
    b'd3gzcEppbmFhb0ZQODl6YjMzSGYzWnpZRk9tQUJBQU5jRjQ5aXJlSDNhCnZmVk5QNTZjQm1B'
    b'ek9Kd2NQbm5oY3R3NjMvK0hYVkZPUUgzR0RhWDduNXFlZkxPNjQ5VWE3L3hxNjcxYWp4VHJ0'
    b'S1pQUkx4OGRmSkEKWityVnJjYStMaTNsRWdCQ1lPMStaVnRNZjJSamdhazEzak14azNIQUNS'
    b'R0hkYmx1V2hCNGJVOFltdUxWY1BlUXVnZW5wQUZjTnRTOQpiR2pYam1iNnZ4LzJ2QVpTck41'
    b'SFNVamNPVDREWkE0L3VHQ0hkc3ZDMEVOcjgwcUNqY09pTGtDNEFJRG1CUG5HYStIbFRWNzRQ'
    b'QU9NCnhJL1BidnYza1Vkc25hak01ODljMWZPYktXUzU0UlJoUnFVejU4cFloRmgzTFltdXE2'
    b'Y2dSQWl5djROYzhtSm9lWk5QQzVpemlwc1gKejJvOHlxb1RXRzVnVytTdzhOUmhZWTE2M2NL'
    b'OEtFdnNOSXJ1N0Y4M3YxcmZqZWhBWCtyZVVlMDNqam1wVzh5bFdMMmJSQWFMZDlIVwp0Skow'
    b'YWNxbEtZZHNiYWJ6dDJtc0lOOW9hV0krNzllS3VwNitQRm5vUDluTGtLUll2UlVoY09WTDN2'
    b'azd2VUtoTUQySGpoS0NSQklGCmVXanJnRWNubXRiSFNJM015NHpLelV6dGI0MHQ0MUlzeWVm'
    b'U21pSTN6UFcvVlJla3pDMlBzSUZSWHVKM0MweDNkUzFkOVltU2hpcnkKOC9TbXhqUDZhVnVi'
    b'RlFzYUtJRnA2bkFuNU1RdTc1KzQ2U3piVUtWWWtpUDVjSzl5ODV2QlhlbkFBRy82MVN0YVJ4'
    b'UUxBSzl2MVI1YQpIdHdhTXd1Q21Kclg5a0pMMzJLckpVRGQ1NzhlWDFhbkwydndMTmxueEtG'
    b'RFVlQXhLdldPMjRaMzNETFdPbkh6TGxLc1hzYkRpL1FuCjFvVzlIanB6UU9MSDV5ZnpmRUlJ'
    b'ZlA4dDMrOXJvaFluSTNJeXY3MndkV3VUY3N2YS90Y1YxczNkSHlraWlUbXp1aXJ6ZVgwbitj'
    b'TUcKeit1N3pBMXRKa0NwMTFNVmJYMmlxbk53SHBkaW5kWWtMVno2ckFyVE0zT1lmZDFJTy9C'
    b'cHQrcXVoZWFUdTRwRnhpa1B1M011YlJ4Ugp5SCszV3I5dFhmOEhodFRhRGg3Ym1OZmZsMzcr'
    b'YTIwVCtqRUFuT1A1ZGZyajYzTjJkdW9ncENKay9XVkc4L0RDbm5kTDFyRjZEU21YCnpQdXV1'
    b'L2pHeEczbkhMTHE4V1dlcDNlWGlGUW02c2VUazVwSEZISUFMczlXNUIrcVNrMHI2ZHpUcFYv'
    b'N2RzR2NMUm9BU25IakdIdngKTjV1dTdCdWpDcTN1MEc5NU84YytBYmNrazJMMUd2Sjh3bi9r'
    b'UXlmZXJGWi92cVhRU1dWOEFmMnhjWTBYVjJRRmNRVUJ3QUdGNEttTApPd2ZtOFAyZDVQb1B5'
    b'eDVha3QxY1h4UVFMMzhqL3V0ejY0c01hMDJiNzZjZm1GSXNTWllkemZRSFMvTmpuYTV1cWcr'
    b'T2FMaCs5S0g2CnA4dXpsUWNBL1NMaU41T2JmUjZhU3Jsejl4NXhjOWZ2amJQZXU3cmwzSERz'
    b'K2MyK3BDWEZrZ0JKQ3pjdWpPeHBJK1VoZC9ha0EzZE4KUEdMZThOT21NTnQ3cmhyb1hsWGFC'
    b'bUI3STJGSEZrb3I4dm1TNjdzdUxvdi9mazBQbHgva0pIU3Y1THZ6QXF2cjllbmw4U2VueHZ2'
    b'awpIRjFWZDdvejFtRkhiaDZUL3VNT200UHNhY1dnSTUvL3AxSThlNldWN09uNUhwbXhlaDhQ'
    b'dm1lOHMwZDdkRUxzamF1N1BtdlY0WDJzCmd3d3ZFcWJHQ1VWZHg3RWo3dE9sV0tjM3o2MVI1'
    b'MjhtaTcvZGNkK2t6T2VWTncrT0NnL2kxUkhXR0RlOU8xdE9VblZKTm9XOWpGaFMKclAxK2h2'
    b'N2RoT0IwaTNYazB1U0txTnZRUVE1a2RPQmtiQldXR2F1WGNmZGtSbzhYdE81UklUK3lrYngr'
    b'Uklwa3JEV3g0TWs1VHluVwpLVWgzSCt1b0cvWmNPOUtaVWRheG9WR1JZa20rckZqWnB2Qm9Y'
    b'cG1WS0dSZDg3Y29VaXpKbDhINUhMRTBCV3R2U3d5SWNpbVc1TXMxCmhjZm9ZMlVIYXhSRGk0'
    b'UVVTL0psWUlkTjZYeFZTTEZPeFl6RkFJQi9wVS8za0dLZGluMnNZNDBLcFZpU0V6VXFsR0pK'
    b'L2lsc1YyWXMKeVFsQVlRNDY0MEwyc1NROXl6WERNNXJQYUlveEtaYWtKL25tbWM2LzlXbXhY'
    b'U0hGa3ZRd3o4eUlqeSt4dnNJVGtOdS9KREpqU2FSWQpFaW1XUkNMRmtraXhKRklzaVVTS0pa'
    b'RmlTYVJZRW9rVVN5TEZra2l4SkJJcGx1UmZtLzhINHRrd21DNGZDQlFBQUFBbGRFVllkR1Jo'
    b'CmRHVTZZM0psWVhSbEFESXdNVGd0TVRJdE1qVlVNRE02TlRRNk16TXJNREE2TURBR25YUWhB'
    b'QUFBSlhSRldIUmtZWFJsT20xdlpHbG0KZVFBeU1ERTRMVEV5TFRJMVZEQXpPalUwT2pNekt6'
    b'QXdPakF3ZDhETW5RQUFBQUJKUlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTI2NjUi'
    b'IC8+CiAgPC9nPgo8L3N2Zz4K', 'CA_SK')

CA_SK = b64_CA_SK
index.append("CA_SK")
index.append("Canada Saskatchewan")
catalog["CA_SK"] = CA_SK
catalog["Canada Saskatchewan"] = CA_SK
country["Canada Saskatchewan"] = ('CA_SK', '', 1)
lookup["CA_SK"] = ('CA_SK', '', 'Canada Saskatchewan', 1)
lookup["Canada Saskatchewan"] = ('CA_SK', '', 'Canada Saskatchewan', 1)
details["CA_SK"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["CA_SK"] = ('CA_SK', 'Canada Saskatchewan', 1)
regional["Canada Saskatchewan"] = ('CA_SK', 'Canada Saskatchewan', 1)
#----------------------------------------------------------------------
b64_CA_YT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjk4MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1l1a29uLnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBl'
    b'PSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxu'
    b'czpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBv'
    b'ZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5r'
    b'IgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0i'
    b'aHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMxNjk4'
    b'NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzE2OTg0Igog'
    b'ICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAg'
    b'ICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2Vy'
    b'Ym9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAg'
    b'IGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE2OTg4Ij4KICAgIDxpbWFnZQog'
    b'ICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1p'
    b'emVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlW'
    b'Qk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFBQUJHZEJUVUVB'
    b'QUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdB'
    b'QUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBYgpWRWxFUVZSNDJ1'
    b'MmRlVnhUMTliM1YzSXlrd0FKa0FBQndpUXp5Q1NDZ0RNNG9BVlVyRVBSdG1vcjR0RFdXOGRX'
    b'cWRTcEtMV3QydHRxCnJUTzFLSFZHQVhGRVZFWlJFSkFabVJJQ0pHUWV6bm4rZ0t1Vkt0cm4z'
    b'dnUrRDNDK2Y1RnpWdlkrV2Z3K2E2K3M3SUZndnBFQUE0U2MKVHl2c1RZYkJVS1dxVWVZeCsr'
    b'cEFlVm9pNE9EZ3dzTEJoWVdEQ3dzSEJ4Y1dEaTRzSEZ4WU9EaTRzUDdiYURRYTNBbi9KaVRj'
    b'QlgxWQp2bnk1UXFFWVBYcDBSRVNFbVpuWjY4eEVJbEZtWmlhVlNnMFBEMmV4V0xqZjhJajFC'
    b'bXBxYXVSeXVWYXIvZmpqajZPam8rVnkrVjl0CjB0TFMydHZiNTgyYk4zUG16Tk9uVDNkM2Qr'
    b'Tit3NFhWSDFWVlZUdDI3T0R6K1VsSlNXbHBhYnQyN2RxNmRhdGVyLyt6elpVclY4YVAKSCsv'
    b'cTZ0cnpjdDY4ZWRuWjJianJjR0c5bHZyNitzTENRamMzdDAyYk5pVW5KNk1vNnVEZ3NIbno1'
    b'dWpvNk9ycTZ1ZG01ZVhseHNiRwpBS0RUNlFBQVFSQVNDYzhvOEJ6cjlSZ2FHdExwOUxxNnV2'
    b'cjZlamFiWFZOVDQram9xTlBwY25KeW5KMmR4NDhmSHhvYVNpS1JvcUtpClRwOCtuWjJkWFZC'
    b'UXNINzllb0ZBNE9mbmgzc1BGOVpyWWJQWmZuNSt6NTQ5MjdOblQyUmtaR0Jnb0VLaEtDc3Jj'
    b'M0p5S2k4dno4ek0Kek16TUpKUEpGaFlXaXhZdFFsRVVBRkpUVTBlTkdoVWZINDk3RHg4Sys4'
    b'UFMwaklnSUdERmloWE56YzA1T1RrNm5lNysvZnM1T1RtcgpWcTNxTWRCcXRZc1dMVXBKU2Js'
    b'MjdacUJnUUdYeTJVd0dMamY4SWoxVm9TRmhYMy8vZmNORFEyblRwMUtTa29pRW9sY0xqY3dN'
    b'SERPCm5EbjI5dlliTm13SUN3dERVVlN2MTgrYU5hdXFxZ3IzR0M2c3Q0SkFJTVRGeFgzd3dR'
    b'ZDc5dXhSS3BVb2lpWWxKZDI0Y1VNZ0VBREEKcUZHamVoS3l0V3ZYQ29WQ1MwdEwzR1A0VVBp'
    b'MlJFUkVIRDE2OVBMbHk3bTV1Wm1abVd3MjI5allXS3ZWWHI1OCtjeVpNeDBkSFdReQplZTdj'
    b'dWNYRnhRRUJBYmk3Y0dIOURTWlBuaHdTRXBLYW1xcFdxMjFzYkZKU1VxNWZ2eDRlSHE3UmFC'
    b'SVNFcHFhbXB5ZG5URU1Nekl5CnduMkZDK3Z2WVd4c2JHWm1abTl2UDNIaXhLVkxsNGFIaDVO'
    b'SXBLVkxsd1lGQlNVbUpyYTB0Q3hldlBqKy9mdTRvM0JoL2Uxa3F5ZUYKaW8yTmZaR1dra2pM'
    b'bGkzajhYaTdkdTB5TlRVdExDekVIWVVMNis4aGtVajRmSDVKU2NuejhVNG1rMGtrRXFsVXlt'
    b'YXpQL3Jvbyt6cwpiSHdxQlA2dDhPK3hhOWN1dVZ3ZUdocTZkKy9laElRRW5VN0g0WEJNVFUz'
    b'YjI5dmxjam1QeDB0TFMyTXltUVlHQnJpdmNHRzlGVEtaCkxERXhFY013YzNQempJeU1SWXNX'
    b'L2ZtdVZxdDkvUGl4cmEwdGlxSTBHaTBuSjJmeDRzVzQwM0JodllHQ2dvTDA5UFNZbUppNnVy'
    b'cW0KeGtwTlYvYXB3eWt5YVQxWmo1bG1hS3FwREVNakl3Z1owZDFaWm00MWdzL244M2k4QXdj'
    b'T0xGbXlCSGNkTHF6WG90Rm9kbTVielRNbAo3cGoyblp0U2JrdEdSdjh1RTNaQVF6T0Vqb0NM'
    b'dHhpK1NuMkxUTktTWGhOeFNKVlRBUGRLeUZVWjdsMEVKQ1FrNVBsRUdoeGNXSDFaCnZUTGls'
    b'NFNiMWZYd3cxV3lwWWFpUStHSER5bUVjWnFtVnNpNkF4SUgxTGtZNVdLWVRUY3A1UndFK1VG'
    b'WWlQYmlyMDh0ZEVqVzJHRGkKclZ4bloyZmNoN2l3K3BLZG5UMGpOT3ZhWFJCM2d0U2RVa1Ni'
    b'NU9EbytFNTRlR2hvS0lWQ1VhbFVOQnF0czdQendZTUhRcUdRMWxSNQpyL1RNL2hOMVhLSTJo'
    b'b0I0QVhyeDhLL08yM2ZnYnV5dDFBemxUVUhXcjErUFlkanpsMHFsc3JMMGlwVzVwclhMeWNI'
    b'UmxVYWpQYjkxCkx6TVRBd3dBRUFRWkhoeENwVko3cnV2MSt2cTZPa3IrZlpwS3BSNDduaSt3'
    b'ZmVGWkFtSDc5dTMvd2FjZFdKdUNET21JeFdLeE5telkKOERhV1pjY09BSW9DQUJDSmJ0L212'
    b'YzFidG0zYmhnK0ZPRytnUW90bTZHZ1VnTEVrbFJ2dWpyY0FyN3kvQWFGUUZQYk9va1dzMlkx'
    b'egpmcXA2OTZkRmhqR1RvNVowZG5iaW5zRWoxdjhlblU3MzhmSjFiZFJJQlZkN2RQdGtBTEFz'
    b'MW5ZWVVKYXQraUxsNkQ3Y1A3aXdYazMzCjFjdTF1VGY2TVRqVnFWNmJ2THVvZ1oxWDFtSE1J'
    b'Z1BBM01rMm9kNm1YQkxsNE5peEUxaVUvaHFYS3VEdEVqaGNXSU11SUlsRXlrcGgKUHdaMzFN'
    b'WUpxK3JuVE1KR3VMRU5RdElBSVBrejd4c0ZvdDh6SkZNcmEwZFJwZjAxenViaU9SYk9xOUVB'
    b'Q1FEV0xIQ09uKzFvektSdwpqS2h4c3h4V3h6b0JBVkVEZ3ZzSGoxai9TNXhCUnZVaDBhaEli'
    b'Wk44K1J4SGhFaW9iWkt6R09RSjNrUzdDaVh1SDF4WXI4Wnc2blQ3CmhiSDlHUHlqdlgzRDBm'
    b'U0FXSkFwZGI5czhnY0ExMWxYakpua2NSYlhFOUxUbVAwdS9ESThjZ3dYMWhBRjRYQm9uc1A3'
    b'TVJBQVRHcnUKTFB4bmxvWTBPbklzSHdEaXR0N2phck9pSTZlYWpneDZVK09YY0dIaHZKWUY4'
    b'MmY1ZWJ0dmlwcS9NalpkbzlOT2JpdmRscDdxNk9pQQpld1lYMXIrTHU3dHJvcUllY21vQkFJ'
    b'aEVYRlc0c041QTZ1bnpsNjdjZWFPWlhxOVRFUmhVSTZhaVMwSkF3V2pzMUo2ZkRkOVF5OUFw'
    b'Ck4rQjFyS0ZKTjluemlYYnkyMWp1L01iTDE1VzlZZStqQzN0Qy9OL0xmQ1o4ODFkQ0svVEtV'
    b'UFl0WHNkNmlZa2plYSs4Ym1GR0w2K1QKK3J1elJaMnFWNnJxZFcvRWhZVURBSEJxZTZDWDB5'
    b'dFdOcXMxZWdxWjJDWFZVaWtJa2RoM0J0c3dHMWJxemlBaTdzc2hLS3lHOHFkVgpoWS83dDFr'
    b'Y1pVL1hxeEtYZXZ6MVZxdFlaV2xHdjFFb01qR2syRm4yTFY5OXM5S1RxbFV1aVg1RFVsOVYr'
    b'TGl4dkFvWDF1QkJxOVdlCm5yZWgrTUFmL1p1dGZzK3BjZkdDRUJmbVgyUFBNNkhDeW96ZUls'
    b'SzJTelMrTHB3K2QwUGRXQTN6WXo2ZDY5aC8rOFVIMGxMbnI5ZHEKdGJpd0JnbS94SzNuUjRm'
    b'TTNQOUZQellPMWt3K1dTNi9lUjBlRnl5ZDJUZjJ5SlY2S2dVQkFJME9wVk5mY3RyU1dRNkUw'
    b'a0xGZzN0OApzc0xWenJDZkxtYnUvNUlmR1h3b2ZpTXVyRUVDM1o2c2JteTljL0IwUHpaSnE3'
    b'eWtLY2NBb08yckw1Ykg5QldXcVRGVkl0ZFN5RVEyCmsxelgvTklHM1N2ZmRSVHUrQm9BSkNl'
    b'UDdGamgyVThYZHc2bXFwOEpqZHhZdUxBR0NUVWx0MXlpSnpxT2YrMUdWa1FpalBVMEVpWi8K'
    b'QXdDcTBzZFdKSm10eFVzTDV3VVdqSVlXZVlBN0J3aUUvQ2N2cG85YTh4aFdpRXhaa0FjQXd0'
    b'M2ZqUFl3SkpGZTYxTEg4U05kb2ljOAp1WGNGRjlhQVI5d3EzQm01eE1JeEFFTVFDd2ZCNjh3'
    b'K20rK01sZVNEUm9NWVl3QWdUVTM1T3Y2bEZKN1BwVGUwS3Z4YzJjL2FGQXJWCmkyM2Z0eTMz'
    b'a0o1T0FRREVHQU9kRGkzTys4ZDdUcS9yeGNKQmdDSkVjOGVBYjZJKzZtZ1Q0Y0lhd0NpNzVl'
    b'UGVuOVdVWHlGYzl0UGQKODY5ZE94VTMwNzR0Y1RNN1N1MTBRY0tOVjdaL216VEpqLzFuQXhv'
    b'RlVhajFOQXFpMGIxVWRKL2t6Mm4vZGhkM21kTHBnb1FkcFc1TAoyUEJ4dE4zcmVybDc3cXBv'
    b'MmM5TmVSVmpZbWNvcExMQjdmbEJYbm0zR21abmJzdG5XbEIwVXJMQTM3MXY3a1ZEUUFQRG5Z'
    b'ek1kQjFWCkpjVk1md3dJUU9KZ3FFcEZxaXFkTjhYbVpIcERqNlZNb1RNMElMZUlWRVpNTW9F'
    b'QVBZc1JZeVpha2F2TFVLV0NaSUlCQVJBT3Bpb3IKczlaMWp2VGczSC9jUVVMNmxydmNRd1Bx'
    b'OXh2WXN6VE8vaUVrTWdXUFdBT1luR04vWFBqeDUvTDgyMWNQSFh0dzRFeWZ1eXdHQ1FDUwpW'
    b'ZzN2UFBRekFJaVAwT3JqbWExSmRBQVFiay84ODZEMlRLaXdNV2ZjTEJUeHVYVEJ2OUt2OWUr'
    b'N0NKTzJBMEJyRXIwK25paytRZ09BCmpnUC8zQnJ2Q1FDR1RIS2Y3dTcvZlBycW9XUGxCYmN2'
    b'L1Bqem5hTnB1TEFHTUFWbnM0S2lvbHRxSzBjdm1OMWVWTkhucnFFQmlVb20KQmpneXhQL2NC'
    b'd0NZSGhRUFNhaUtBQUR5dTNjY1dGb3pkdStLNS9wbXVRMlBVVkhmclZMclI3aHhBSUJqUkhF'
    b'dzFNcHZYZ2NBVkVWUQpQQ1JoZWdBQThjLzdBeHpvREJySnhLaXZzTVJGbFdNV3ptbXByUXlL'
    b'aWk0OGR3MFgxZ0JtNVpsOTVqWjhOczl5NU5RSjAzL2VwTkZvCmFzcWZQci9yNW1DeWRvRzlO'
    b'dmRtenlwbnNnWEtXNm1rT2ZmbTVvcExaN2ZFOWFid0tBWkVCREFNMCtteG5yWDJpWEVlaXN2'
    b'bmV6TXcKWnoxdmxaSnNnUUlBb0tnNjUrYjZoWFpPZ2hkMTFPb25sUnFOWnZxQlRRRlR4ckhO'
    b'TE14dCtDdlA3TU9GTlZCUnE5VTlmK2gxV2dCUQpLeFcvamZtb01uVHQ0OXo4bmkwYmxyd2ZZ'
    b'NndyYWt2NHNzZU1NMWZObWEwMi9WRFY4N0p0ZTJKVWNPOTVoVGJtakNhaDB0YkN3SUJHCnlp'
    b'dnRCSURvVUc3YmpzVGVLdGVIS2s2TW1qTzN0N3UyaEMvbzhyeWxpMllEQUlaaGorN21WWTFl'
    b'bnpMMkk3VlNBUUI2dmE3UDQrSEMKR2toYzNmclRSZWYzTm9mT3Jpd3NRVkc5VkN6TVREbGd2'
    b'ZndkUnZKNzdvRitPZWVQQTRDcnEwdlYxYk9hdXBxZXQwaXZVT1JGSk9ubAozclFhbFVycExi'
    b'VlRnczBCd05iU29MWkpQbkVrdDFta3JHK1Jod2VhTTFycjBLNnVIa3ZKSllxOGlDUzkwdnRH'
    b'VFgxdGRlWjVWMWNYCkFNaTVjTUlqeUorMmU1NU5mR1RXYndlbFlpR0dvaFVGeFp0RFlpNDZ2'
    b'M2QxMjArNHNBWVlUaEdobkEwejEyVWNFYlhXRUFqRVAvWi8KSGIxMHRhSzZSZlJqZXZhUFI3'
    b'dmEyM3JNeHN5TExXRDBsc0tWWlVqRENxYjA1b3ZjU1BUdE4xOHNjZ01BVTJOcWgxUnJha3dW'
    b'ZHFvQgpZTk1TdC9idmtwK2JkZDhpTjZ4Z0tzdDZGNFRsMDVoajUvV3UwZWdTdG1UdlA5Yit6'
    b'eXVLNnVhb2p6ODdzM2NMZ1VnVUMrdlhaUjdsCmJKanBIREVhRjlZQXc0REw4WjRSUnFmVEE4'
    b'TWpxa3NlU0R0RmQwNWRza3krN2ZwRTBYanJqdWhSMDZtWnExdnFHaU5qWnQ1Mjh0UzkKcHBI'
    b'dVN4YzhlTUJpa0VnSVFhM1ZhN1FvbFV3MG9KTTh6RUY2L3RWZjY3UVk1TGg2UmM2ZTFWTFhl'
    b'R3JHWjhMU3BxWmJkMXlmS0N5UwpiK2VrWHBaMXRkYyt6ZzhNajZEVDZjT2pKeHB3T2Jpd0Jo'
    b'SWFqZVpLMkNkM1FqKzVmU3dOSVpHbkwxNkRvWHBoWjNucUtKSEl2b2xECnVlZVEwdVNaM1Zx'
    b'dzZ4Z0FyTjM3dzBucjEwNU1VR1ZuZnJuWWpVZ2trQkJDczBocGJjN1l2TVJOZlNQcmRmWW5M'
    b'TzNXN3RzSEFBVkoKeHp5dnR6bWNiR2JSY2tSMlRhZEhpZHJFVDFCVVAyM3hHaUpDdW5YMHpO'
    b'M1FUOUxEVmczVzNid0haNEdVUXFGNGZSc3ZMcTlsV0pnKwpxeXAxR3puMjNLWnYvWTQrRkdC'
    b'cysxK3llTjZTMG9kVzBNQUJwUllBSEJ6c2g4ZXZ2TGJ0cXdsUzhWK2Jha3ZjTkNlcm9MVkxx'
    b'OU5oCk53cEVoZ2FrK1pPczJpWkd2ckxmbThabTNpdFcyZHZaQWdDbTFBS0FpVVgzNk0xbGJZ'
    b'VkdwQ1VUc0hzUG43Z0lYYjhlODZ5cTFNRFMKVExzczNNdkZqa0toNE1JYVNIaUhoMEo0YU0v'
    b'ZnVaZCtVMnBsaGhpL2prOFM1Ymo0RlhXbFdIWjZoWHA3UklYMUdNeGRHTHU3dHJibworRUVm'
    b'ZWQ5anczWENOaU5KczliSVNxYlF0YlNybmdsVnRycld0cGFXVjlUTWFBYksyZlBqUGxqWTg5'
    b'SnU3b1FTcHZwaFpYWDhyODZGCktqYVJieUJvMHNrMXNvZTNyd1JOZmRmS0VXRGlvRTJ3QnEy'
    b'd3hLM0NtOXNPRWpFd0RmWUltZlBPeUNreE9aZCtLL1cwNVk1eHJieEQKbGg1U2VidlR5UjZH'
    b'VFA2THVhQ3JFemJ0VkNyUU15ZjkvcUl0OFUvN3FCdDMzaXBxQndDTlZ0OXg0TWUvOXBodndH'
    b'cWJOZS96cnpZLwp2OExrRzlEY1dMNkZIdEs5eXBhWk5NZlZZMHB2UGJHa0swZE9uZ1VBT2I5'
    b'ZEVPVThRZ2t3WnVNU0U1NFpubU1ORENRaXNhendxZFB4ClV2cXlreW16LzlFcEZDOVluMncy'
    b'U2FBalMza213d0NBWGlzWk4zZVpXcVZBLzNSQy9kcWRPelJ4cTlLWnhuMWE2enAraEVuVWxk'
    b'ZEsKU1NTaW94bXg4L2poUGdaWG1NYTZ1RldmNzNpeHN5MnEwMm5VeXJGejRoaTFYUURBTlhQ'
    b'R2FBclRjRUhzK3QyZFFuRkt6RC9veTA0NApIUy90THF5U2lzU0Q4bCtBTUVjUG1NMXRGd1d0'
    b'WUROTTNzYXlvYkJVY2I2QUxOZldleGd6M1FVUENyT29ORUpOYVQ3UDJzRnhURWlGClhHeThZ'
    b'SnhUb0krSmhYWEpuYXNjbnRXTjc0NlhmUFZyTjQwd2JmRUNndWZ3WCsvbU9rbTdhSVFYbm1F'
    b'R0JCQUY5cU84VEFOVlpaSXoKcWMrdnl6RHNKTjkyZEZKeTlJS0ZlYW5wZVo5KzN5d1M4bjJj'
    b'Uys5bHV3ZU9wOUZvYlJ5azJSaThsa3hYZG5mVVB5a21rY2czejZTWgpzcmhDall6YXJ0U1ND'
    b'QWFqWEhpT2dyZjVVQjFTemY3VWFud28vUC9KOENsajdVZjVObFRYeFBoNjkxeTVudnJMdzV0'
    b'WEZOMFMxSVJ0CjgvbDBiOGZlNnc1ZUFkZFREMHAvdWVmZUFyV0MvRW9IbG0vZ1NQY2J0eE1Y'
    b'TG5Bc2VCQ3E3VjNwSmZ4NjA0ZW5zZ0dnYmQ2TEV5aHUKaytsVmZnRmZIRDVDbzVBckMzT0VH'
    b'UVZPZVIybFRablhUYVhCa2UvMTJJUitNTE00dE9oWmEzM3AzY3luaGJrMkxzTVhmOTBiMkVv'
    b'TAppejBjN0ZsR2huaTVZU0RCTWpKMC81ZXFBR0JjekNLUFVSTUxzczRKVEswM0hGdnp0S1VT'
    b'QUo0OXJiMzYwVGRWQllWNk5sa0YrbmF1CmpNM2pVK2tNUTBQRHBEL09laDQ2Y3NEUnJSd2hB'
    b'WUM2c3BLcjcrS2lVdldUTWdDb0paRVBEbk1idHYrbnBEL09HaGtaVWVrTVk2NmwKbUNkVEFh'
    b'cmprS3NLaTY0dTJkbFVYUWNBbFUzbEc0NnRGWmhhRjJTZDh3d09HeGZ6NGxnZWQxL3Z3YXFx'
    b'UVRzVXZxaHdka211ZnA1YwptbkM0c3JTY1pFbG1HbkdvZEFiZHlpejU4dlozQTJQdmJqbm9k'
    b'TGFLVml0elhYdEY0aTVFZUROcWtzOHJqU2dXVG5ZQVlHM3ZNT21ECkQ0dU1PQmVFWXFsR3c5'
    b'UHJ1eDhXWmxWV1hSdm14b2xmOWRsM1A5Zzd1L1JtN2hldmxXdytZaHpnUWZJKzRqaitFV1cv'
    b'aGQwVDVST0YKeUdhaS81d2ZJcWY0UnRCYkpFUUU0WmhiVlo3SWZaSncrR2xKS1Q5NE9JVkcv'
    b'VnVmWldBTmhZUDVSK2lXMm9xN0YwL1Iwa3RkbnFwVQpWZlZxbWNiVlpXcGVSdHE4a1BlZlNS'
    b'b1BYdCtQU2hVQVlBWmc0eXQxOXBCYWJjaHl5UkdKY2t1ZnQwQWdFT1l2WHJ3bjY1cnY0Wk9I'
    b'CnhkTERZcW5QcnlkMloyVE9XN3lZK0tjMVl1TGNVdGU3N2Z4MUdVNGUzUUkvcVJrR0FJQktG'
    b'UWV1N1d1U05NNExqczNMVEhOeG5xS1MKcWRRMURTNVBWYlQwMHB3THY3WFVWZUxsaGdGSjdl'
    b'MHk1YTI2ZTFZMVVRTFFrTFZHaCswTnUrb3M0L3pMTWkvd0RXM3UxRnpmL05HbQpTbTNhdmU0'
    b'Nzg2S21YVGR1b3dZajdBb3RUL0NLeGZKQmdRRkJnYTlkaTBFVDhCNmI2cnFjS2JKdGptUEVG'
    b'cWxld2lERFVPZVBJMDhVCmJlSWIyanpPT0cvSkcyRzQ4WktTZzNhNFZVbDlxTmN3Q0xwcFc0'
    b'dVZXdGc2NGNJYWVMUWR6bkl1Nm5LbUNweHUvKzRpSkRkUGN3WUEKVXdxdnRxekluTVF1YW5s'
    b'Zzg2RmJZOFI5bjZKeFNFNTFxSWp4YUpMMWlKMHhFaHBCb1ZRdzZJeTM3RVdoVkJpTmQ3SWU5'
    b'Zm1kVTJjQwo5dWtvR05ISHhZZnV3N1B5ZGk1T2YrQkQ5cXN2ZjJoTjhtTHFLNWtpSkhSTktj'
    b'dE1heFF5R3l1dXE2aVJRR3owWUhYK1lCNEt5U01jCmhDd29qdys4ZDFSUTlMdjlWZCt1SXBw'
    b'RXl5WE9XUFlscTZoQnFoUFh0dFFRaUVUbnNBbDFFd1VGdnNpb2FlK2FXdHBVTmxlc083NzYK'
    b'N1h2NS9QQ3FxdFpLTTc1dDBOU1lBaCtrTGt6Z0ZoNEdBRFZ0MVRKZHAyRlJ3NHhsWDJxNGhH'
    b'S2FKTk5QbXYrN2JlNVJRVm44U0NFTAp5Q01HOHo1Ymd6bGlqZHU0cERGcVRGZkpkVldDUDRJ'
    b'U2pPUDVnZC9ITmxVOE9ycDFsUzNmeWJ0YXpEZTFjcDhiUnlBUWhrOGU4OGYrCnJ4MUdlQkdJ'
    b'Uks2UjJia252MDNLbnhMaC84NGJ1N2lVZi83aTA5TXh3WE5ZYkZQbVNFN3BMTmVwY1JzQndB'
    b'TUw2ZXp1OUs0eXRiTjIKT2JydEU1K3hFVzVaVzI2ZVBrcmF4MUFpZXVRcmxQZmJwd0ZlZy9s'
    b'OHc4RWNzUXdNV1VTYW1zV3k0cXJJWmhxeW5TQzRNdTlXYUZScwovTzRUL29FVCtZMzZSMW5u'
    b'Q2YrcWdsbzdlVmFWM0FjQUZ5dDNETVcyWkt3UmRyWDEzNzZ3cTIxTHhob01CVmNyRHdDb0ty'
    b'bHY3ZVQ1ClBPdC9uSFhCOHBuZVAzQmkvSzdqb1pHeEZYbTM3R3hEekxRa2N4WEZ3TUFTb1dz'
    b'WVRBTThZZzFVckowODdUeEduTDFaUVdIU3A4eVoKVGlRU3RGcDFwMEpheThVQzEyMjhjZTU0'
    b'VTFWWnpLb3RKQXJWS3lUODl6MWZEUE1PNHJGNUhLcEpnNkx5d1BYOUc2Ty82cWZ4QTlsNwpH'
    b'K1NWUEtvRGw4MEZnUHZwcWJNLzNRb0FPbzM2OXoxZlZwVVhCYTNiV01OQXZXU2RiSVpoMlB4'
    b'bGVqMTZ0YVJHTFZkR3Z4dWpWUS95CjNieUgzSG1GRis2ZjNaNldpSksxUWtXekJsTzdkNWph'
    b'aXlsTDF1enhIVDBsUCtzY2dpQSs0NmE5dS9lZDI3VVpsbXgrK29wY002TlgKSHpBaGtnZ25m'
    b'Ui9ZMnRVY2FoZCthdm41Z212bkNRVHdIZjlPNGMzTEI1SStyVEhWUERZV1VSRWFsMjZKYUNu'
    b'clozdzViV1Rrdi9uaworSG1GLzNkQk1kVFIzT25XMXZza0VxbGVXSGMyLy9jNmNZMWMxblhn'
    b'bDYrR25UazBjK25Hdkl3LytNUGNQNW00dHZEZ2d5WmwzYjdNCjVJUlpyejQwZFY5bWNvdXEz'
    b'cERBL1RSc25iQ3hwdlp4Z1g5WVZQS3FtS2VTUm4yRWp4dlRlS3FKZlpUL2JBSFhWcWZUUFcy'
    b'cVJER1UKU0JoQ1c3TU5yWWhWMzFhMzVzRHFJSi9BNkJFeEFxN3RTN1dKaHVxcngzN29FcmFJ'
    b'bXVzLzI1dDJxZnpxeHJPZkdoaFJUeTVNOTdiego3ZE5PY1czaHZDTlQ1RjNxN2RIZlRYRUpT'
    b'NDZQTnVQYnNubVdrMkpYY0szdFgrcFJXUGRIWG1wdTBiMXZsdXdXOEd5SFRzUWFja05oClIz'
    b'ZkhoL3ZtbDRqdmVWbjVqN1FkNVc4OWlrcW15bFF5dVVhR1l2cU9qdGJHbk51U3AwLzVYcjdr'
    b'WVlJZjh2YjYydnFuTGs4bmsxNnMKc05EcXRERjdweFRWNWE4SVdLbXByRzBxS1RRYU5zdzZP'
    b'SlRETVNjU0VBTUtrMGxqcXJYcS9NYTdEK3J2UG16TTkrSUVIbDZSWXZ5WAoyVGk0c0FhVnNB'
    b'QkFwOWR0UExFbTllRlJKYTBEZ0FDRUY4ZENFMUFpNkJBQXpFQkJjT3pnbUhSVG1zbEszL0Nv'
    b'WFV0L2ZtNno5bUJjCmJrYWFsWTdlamFpcVRMb2toaWdBQVVoNmpQaW4vVUl3QWdCR1Y1bThP'
    b'M3hCNHZ5ZEpPUS9rSExnT2RiLytjK01rSFl1U0E1L05HVmIKMnBmbFhTVVlBU01RQUFNTU1B'
    b'SkNRTmgwRTNNVzM5ekd5cGhxd2lBWjBGc2FuMXk3K2Y1VnQrQ1JreEVHN2RidDgrMTZ0Wk5Y'
    b'c0ltTgpuVkt2WUt2RnJmSm5yZDFOblVxeEh0TURBU01BQWNPQWdCR2NqYjAydnBzNHdTc01o'
    b'aVJEZDUvM0NaNWhZOTNIWnhaZGtXbTY5YWdlCkFUS0h5WEhodS9FNFBJVDQ0c2c0aGJTcjhN'
    b'YkZpcnpiTW1FTFNpQ0V1SWE0K0lmNGpwM0dNSHd4dE9sUmZXdEhhMFhUa3c2WldJOXAKRVlU'
    b'RXBMRENmQ2IvdVIxY1dFTUloSWhNOW90NDVTMk5Xdm5rL28zOGErZFJ2UzRnZk1iN20vY2lK'
    b'RElBWUNoYVZYSS9iZDhXaVZqbwpNemJDWjl3MHVnRUxJU0o4VXo3ZmxBODR1TEJlaVZhakty'
    b'dDN2ZmhtdWtvaDh3d09lMi9kYnVyTHYwWVRpTVJoM2tIRHZJTjZMSC8vCmRxTksxdTBaRXU0'
    b'My9oMHF3d0IzSUM2c3ZwVG1adWRjT0NGcXFoOHpZMkhNSjRrTWxsSC85bVFLYmZqb0tjTkhU'
    b'MUYwU3dxdW5kc1YKRjJuR0Z3UlBuKzhlTkI1M0ppNHNBSUNueGJtLzdOdFkwMWc1L1owbGNX'
    b'dDJ5dFNLaXlXWHEwVGxqWjExU3AyQ3crQjZXWHBQOTV0aApZbWdDQUdLcCtIeEIycVBtb2c2'
    b'RmlFNWlXTE50SGMxY0FvUEd4bytmbG5uMnlKWXRDNjI0Z2dXTE5nNGZQV1dJZTNVb2xodWVV'
    b'MXRhCitOdnU5YmsxK2UzdUpvYTJKaktWUXFic2J0YzM2OGt2TFh1M29qcjRtZ1YvR3JFT0FM'
    b'Njl0S05RbFBOTS9kSVVZVVJMTVVVc21YUVcKazhhUTFvbE5TOFZCOXY1elZtKzNjL2Y5RHo0'
    b'dFhtNFlHTnk5bUhJb1labUZyZE8zMzZjN2VQWE9EdFhwZExrVnVjV05lZFh0bFhKMQpOOS9Z'
    b'MnQzQ08zTEVETXEvdGd6OWFlbGhqVlp6TGkrdHRLVzRxYXZSZ01weU5IVWVidTBmNUJ4RUl2'
    b'VTZzK3JoL1NPSks3Y3VuUEJoCnd2NVIwK2JpRVd0b1JhejB3M3ZrMHM2b3BSdElGT3AvL0ZI'
    b'MU9tM0c4WDFFQkprVXV3S1BXRU9MU2JITGljaC82K01qSlBLVTl6OUIKOWJvaDY5NmhleFRh'
    b'ZjA5Vi95Kzd3SVdGZ3dzTEJ3Y1hGZzR1TEJ4Y1dEZzR1TEJ3Y0dIaERCWCtCMTU5ck5qUlo1'
    b'YmpBQUFBSlhSRgpXSFJrWVhSbE9tTnlaV0YwWlFBeU1ESXlMVEEzTFRFNVZERTRPakl5T2pN'
    b'eEt6QXdPakF3Z1VLMkZBQUFBQ1YwUlZoMFpHRjBaVHB0CmIyUnBabmtBTWpBeU1pMHdOeTB4'
    b'T1ZReE9Eb3lNam96TVNzd01Eb3dNUEFmRHFnQUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAg'
    b'aWQ9ImltYWdlMTY5OTAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'CA_YT')

CA_YT = b64_CA_YT
index.append("CA_YT")
index.append("Canada Yukon")
catalog["CA_YT"] = CA_YT
catalog["Canada Yukon"] = CA_YT
country["Canada Yukon"] = ('CA_YT', '', 1)
lookup["CA_YT"] = ('CA_YT', '', 'Canada Yukon', 1)
lookup["Canada Yukon"] = ('CA_YT', '', 'Canada Yukon', 1)
details["CA_YT"] = {"continent":"Americas","capital":"","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["CA_YT"] = ('CA_YT', 'Canada Yukon', 1)
regional["Canada Yukon"] = ('CA_YT', 'Canada Yukon', 1)
#----------------------------------------------------------------------
b64_CC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1jYyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHBhdGggaWQ9ImNjLWEiIGQ9Im0wLTM2'
    b'MCA2OS40IDIxNS44IDIxMi04MC4zTDE1Ni0zNS42IDM1MSA4MC4xIDEyNSA5OS44bDMxLjEg'
    b'MjI0LjZMMCAxNjBsLTE1Ni4yIDE2NC4zIDMxLjEtMjI0LjVMLTM1MSA4MGwxOTUtMTE1Ljct'
    b'MTI1LjUtMTg4LjkgMjEyIDgwLjN6Ii8+CiAgICA8cGF0aCBpZD0iY2MtYiIgZD0iTTAtMjEw'
    b'IDU0LjktNzUuNWwxNDQuOCAxMC42LTExMSA5My44IDM0LjcgMTQxTDAgOTMuMy0xMjMuNCAx'
    b'NzBsMzQuNi0xNDEtMTExLTkzLjggMTQ1LTEwLjZ6Ii8+CiAgPC9kZWZzPgogIDxwYXRoIGZp'
    b'bGw9ImdyZWVuIiBkPSJNMCAwaDY0MHY0ODBIMHoiLz4KICA8Y2lyY2xlIGN4PSIzMjAiIGN5'
    b'PSIyNDAiIHI9IjY2LjciIGZpbGw9IiNmZmUwMDAiLz4KICA8Y2lyY2xlIGN4PSIzNDAuOCIg'
    b'Y3k9IjI0MCIgcj0iNTQuOSIgZmlsbD0iZ3JlZW4iLz4KICA8Y2lyY2xlIGN4PSIxMDkuOCIg'
    b'Y3k9IjE3My4zIiByPSI2OS44IiBmaWxsPSIjZmZlMDAwIi8+CiAgPHBhdGggZmlsbD0iIzgw'
    b'MjAwMCIgc3Ryb2tlPSIjN2IzMTAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTEwNSAyMjZo'
    b'MTcuNXMuNy0xLjYtLjItMi40Yy0xLS44LTQuNy0xLTMuNy0zLjggMi01LjggMi40LTQgMy43'
    b'LTE3LjhhNzM5IDczOSAwIDAgMCAyLTM1LjVoLTIuNnMuNSA2LjctMSAxNS41Yy0xLjQgOC44'
    b'LTEuOSA5LjUtMy41IDE2LjNhNjMuNSA2My41IDAgMCAxLTMuMyAxMS4yYy0xLjQgNC0xLjYg'
    b'NC4xLTMuOCA3LjgtMi4zIDMuNi0xLjUgMi4yLTIuNyA0LjQtLjcgMS4xLTEuNC44LTEuOSAx'
    b'LjYtLjQuOC0uNSAyLjctLjUgMi43eiIvPgogIDxwYXRoIGZpbGw9ImdyZWVuIiBkPSJNMTE4'
    b'LjMgMTIyLjVhMjMgMjMgMCAwIDEtMS4yIDkuMiAyNi41IDI2LjUgMCAwIDAtMi4zIDkuOGMt'
    b'MS44LjYtMy43LTMuOS01LjUtMS4yIDEuMyAzLjcgNC40IDYuNiA2LjQgOS45LjQgMSAzLjQg'
    b'My43IDEuNiA0LjMtNC4zLTEuNS01LjQtNy04LTEwLjNhMTkgMTkgMCAwIDAtMTUuNS0xMGMt'
    b'Mi41LjEtMTAuNC0uNS04LjQgMy43IDMgMiA2LjggMy40IDkuOCA1LjcgMi4zLjIgNi4zIDQg'
    b'Ni4xIDUuNC00LTEuNi01LjgtMy41LTEwLTUuMi01LjgtMi4yLTEzLjctLjktMTcgNC44LS41'
    b'IDEuNS0xLjQgNS44LjUgNi4zIDIuMi0zLjQgNS4zLTcuMyA5LjktNi4yIDMuNi4zLTQgNi43'
    b'LTEuMSA1LjQgMS0uNCAzLTEuOCA0LjYtMiAxLjUgMCAyLjMgMSAzLjQgMS4yIDIuMy4zIDMg'
    b'MS4yIDIuNyAxLjgtLjIuNi0xIDAtMy4zLjgtMS4xLjQtMS43IDEuNC0zIDEuOS0xLjQuNC00'
    b'LjIuNS01LjIgMC0zLjctMS41LTkuNy0xLjMtMTAuOCAzLjMgMCAyLTEuOC0uMi0yLjYuNy0u'
    b'NyAyLjItLjggNC40LTQgNC4yLTIgMi00IDQuMi02LjYgNS43IDEuNSAzLjQgNy4zLTMuNCA3'
    b'LS41LTIuNSAzLjUgMS40IDQuMiAzIDEuNSAyLjktMyA2LjUtNi43IDEwLjctMy42IDIgMS45'
    b'IDMuMi0xIDQuNy0xIDEgMi41IDIuMS4yIDMuMi0uNSAxLjctLjIgMS4yIDIuMiAzLjIuNyA0'
    b'LjEtMi43IDkuMS0uNCAxMy4xLTMgNC4zLTIgLjYgMS41LS41IDIuOS0xLjkgMy42LS4zIDgu'
    b'NC00LjMgMTAuNi0xLjcgNC4zIDEuOSAxMC0xLjcgMTMuMi0uNSAyIDQuNiAxLjggNiAyLjYg'
    b'Mi42IDAgMC01LjggMi41LTYuNiAzLjQgMiAzLjItMy44IDIuNS01LjYuNC00IC42LTguNiAy'
    b'LjYtMTIuMyAyLjItNC41IDQuMiAxLjkgMS44IDMuNy0xLjQgNC4xLTMuNCA5LjQtLjMgMTMu'
    b'MyAxIC4yIDEuNyAyLjQgMi44IDMgMS4yLjcgMi44LS4xIDMtMi4xIDEuNi02IC44LTEyLjQg'
    b'My0xOC4zIDEuNS0xLjggMy42LS4zIDQuNSAxLjQgMyAzLjUgNS4xIDcuOCA4LjcgMTAuN2Ex'
    b'NSAxNSAwIDAgMSA3LjggNy4zYzAgMi42IDcuNCAzIDUuMiAwLTIuMS0yLjctLjctNS42IDEu'
    b'NC03LjUgMS4yLjMuOS0xLjggMC0xLTEuNS0uMy0xLjYtMyAuNC0xLjcgMy41IDEuMS0uMi0y'
    b'LjUtMS41LTIuNi0yLjktMS44LTYuMi0zLjgtNy42LTcgMy44IDAgNy43IDIuMSAxMS41Ljkg'
    b'My4xLTEuNiA2LjIgMCA3LjMgMi44IDIuNC0uNCAxLjQtMi44IDAtMy42IDEuNy0uNyAzLTIu'
    b'Mi44LTMuNS0xLTEuNCAxLjUtNC0xLjctMy44LjEtMi41LS44LTQuNy0zLjUtNS42LTIuNy0y'
    b'LjItMTAuNiAzLjQtMTAuMy0xLjctLjgtMi44IDMuMi0uNCA0LjMtMS44IDEuMS0zLTUuNS0y'
    b'LjYtMy4zLTUgMS40LS44IDguMS0yLjEgMi45LTMuMWE4LjMgOC4zIDAgMCAxLTctMS4xYy0x'
    b'LjkgMy4xLTcuMi0xLjgtNi4zIDMuOC0uNyAyLjEtNS41IDcuNi02LjggMy40IDEtMy4zIDYu'
    b'OC00LjMgNS04LjgtLjMtMi43LTIuNi41LTMuNi4zLS42LTEuNyAxLjYtMy44IDMuMi00LjIg'
    b'MyAyLjQgMy0zIDYtMi41IDIuMS0uNS0uNy0xLjQtMS4zLTEuOC42LTEuNSAzLjktMi4zLjct'
    b'My43LTIuOS0yLTUgMi4xLTcuMyAyLjMtMi4yLTIuNSAyLTMuNyAzLjItNSAuMS0xLTIuNC0u'
    b'My0xLjctMS4yLjctMS4xIDUuMi0xLjIgMy0zYTE0LjcgMTQuNyAwIDAgMC0xMC4yLjZjLTIg'
    b'LjYtMi41IDUtNC4yIDQuOC0uNy0yIC4zLTUuOC0yLjQtNi4zem0xNSA0Mi4zYzIuNC0uNCAw'
    b'IDMuNy0xIDMuNiAwLTEuNC0zLjYtMS4zLTEuMy0yLjZhNy4zIDcuMyAwIDAgMSAyLjMtMXoi'
    b'Lz4KICA8ZyBmaWxsPSIjZmZlMDAwIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgwIDgwKSBzY2Fs'
    b'ZSguMDYzNSkiPgogICAgPHVzZSB4bGluazpocmVmPSIjY2MtYSIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgeD0iNzU2MCIgeT0iNDIwMCIvPgogICAgPHVzZSB4bGluazpocmVmPSIj'
    b'Y2MtYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iNjMwMCIgeT0iMjIwNSIvPgog'
    b'ICAgPHVzZSB4bGluazpocmVmPSIjY2MtYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIg'
    b'eD0iNzU2MCIgeT0iODQwIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNjYy1hIiB3aWR0aD0i'
    b'MTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI4NjgwIiB5PSIxODY5Ii8+CiAgICA8dXNlIHhsaW5r'
    b'OmhyZWY9IiNjYy1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI4MDY0IiB5PSIy'
    b'NzMwIi8+CiAgPC9nPgo8L3N2Zz4K', 'CC')

CC = b64_CC
index.append("CC")
index.append("CCK")
index.append("Cocos (Keeling) Islands")
catalog["CC"] = CC
catalog["CCK"] = CC
catalog["Cocos (Keeling) Islands"] = CC
country["Cocos (Keeling) Islands"] = ('CC', 'CCK', 0)
lookup["CC"] = ('CC', 'CCK', 'Cocos (Keeling) Islands', 0)
lookup["West Island Cocos (Keeling) Islands"] = ('CC', 'CCK', 'Cocos (Keeling) Islands', 0)
lookup["CCK"] = ('CC', 'CCK', 'Cocos (Keeling) Islands', 0)
lookup["Cocos (Keeling) Islands"] = ('CC', 'CCK', 'Cocos (Keeling) Islands', 0)
details["CC"] = {"continent":"Oceania","capital":"West Island","currency":"Australian Dollar","web":".cc","lang":"ms-CC | en","tz":"+06:30","altname":""}
#----------------------------------------------------------------------
b64_CD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNkIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwN2ZmZiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2Y3ZDYxOCIgZD0iTTI4LjggOTZI'
    b'OTZsMjAuOC02Ny4yTDEzNy42IDk2aDY3LjJsLTU0LjQgNDEuNiAyMC44IDY3LjItNTQuNC00'
    b'MS42LTU0LjQgNDEuNiAyMC44LTY3LjJMMjguOCA5NnpNNjAwIDAgMCAzNjB2MTIwaDQwbDYw'
    b'MC0zNjBWMGgtNDAiLz4KICA8cGF0aCBmaWxsPSIjY2UxMDIxIiBkPSJNNjQwIDAgMCAzODR2'
    b'OTZMNjQwIDk2VjAiLz4KPC9zdmc+Cg==', 'CD')

CD = b64_CD
index.append("CD")
index.append("COD")
index.append("Dem Republic of the Congo")
catalog["CD"] = CD
catalog["COD"] = CD
catalog["Dem Republic of the Congo"] = CD
country["Dem Republic of the Congo"] = ('CD', 'COD', 0)
lookup["CD"] = ('CD', 'COD', 'Dem Republic of the Congo', 0)
lookup["Kinshasa Dem Republic of the Congo"] = ('CD', 'COD', 'Dem Republic of the Congo', 0)
lookup["COD"] = ('CD', 'COD', 'Dem Republic of the Congo', 0)
lookup["Dem Republic of the Congo"] = ('CD', 'COD', 'Dem Republic of the Congo', 0)
details["CD"] = {"continent":"Africa","capital":"Kinshasa","currency":"Congolese Franc","web":".cd","lang":"fr-CD | ln | ktu | kg | sw | lua","tz":"+01:00 | +02:00","altname":""}
#----------------------------------------------------------------------
b64_CF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNmIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImNmLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTEyLjQgMzJoNjQw'
    b'djQ4MGgtNjQweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBjbGlwLXBhdGg9InVybCgjY2YtYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRl'
    b'KDEyLjQgLTMyKSI+CiAgICA8cGF0aCBmaWxsPSIjMDBmIiBkPSJNLTUyIDMyaDcxOS4zdjEx'
    b'OUgtNTJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmYwIiBkPSJNLTUyIDM5MS42aDcxOS4zVjUx'
    b'MkgtNTJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDA5YTAwIiBkPSJNLTUyIDI3MS4zaDcxOS4z'
    b'djEyMC4zSC01MnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0tNTIgMTUxaDcxOS4z'
    b'djEyMC4zSC01MnoiLz4KICAgIDxwYXRoIGZpbGw9InJlZCIgZD0iTTI0Ny43IDMyLjVoMTE5'
    b'LjlWNTEySDI0Ny43eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmMCIgZD0ibTk5LjMgMTM3Ljct'
    b'MzEuNS0yMS44LTMxLjMgMjJMNDcuNCAxMDEgMTYuOSA3OGwzOC4yLTEgMTIuNS0zNi4zTDgw'
    b'LjMgNzdsMzguMS43TDg4LjIgMTAxIi8+CiAgPC9nPgo8L3N2Zz4K', 'CF')

CF = b64_CF
index.append("CF")
index.append("CAF")
index.append("Central African Republic")
catalog["CF"] = CF
catalog["CAF"] = CF
catalog["Central African Republic"] = CF
country["Central African Republic"] = ('CF', 'CAF', 0)
lookup["CF"] = ('CF', 'CAF', 'Central African Republic', 0)
lookup["Bangui Central African Republic"] = ('CF', 'CAF', 'Central African Republic', 0)
lookup["CAF"] = ('CF', 'CAF', 'Central African Republic', 0)
lookup["Central African Republic"] = ('CF', 'CAF', 'Central African Republic', 0)
details["CF"] = {"continent":"Africa","capital":"Bangui","currency":"CFA Franc BEAC","web":".cf","lang":"fr-CF | sg | ln | kg","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_CG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImNnLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTc5LjUgMzJoNjQw'
    b'djQ4MGgtNjQweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI2NnLWEpIiB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSg3OS41IC0zMikiPgogICAgPHBhdGggZmlsbD0iI2ZmMCIg'
    b'ZD0iTS0xMTkuNSAzMmg3MjB2NDgwaC03MjB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDBjYTAw'
    b'IiBkPSJNLTExOS41IDMydjQ4MGw0ODAtNDgwaC00ODB6Ii8+CiAgICA8cGF0aCBmaWxsPSJy'
    b'ZWQiIGQ9Ik0xMjAuNSA1MTJoNDgwVjMybC00ODAgNDgweiIvPgogIDwvZz4KPC9zdmc+Cg==', 'CG')

CG = b64_CG
index.append("CG")
index.append("COG")
index.append("Congo")
catalog["CG"] = CG
catalog["COG"] = CG
catalog["Congo"] = CG
country["Congo"] = ('CG', 'COG', 0)
lookup["CG"] = ('CG', 'COG', 'Congo', 0)
lookup["Brazzaville Congo"] = ('CG', 'COG', 'Congo', 0)
lookup["COG"] = ('CG', 'COG', 'Congo', 0)
lookup["Congo"] = ('CG', 'COG', 'Congo', 0)
details["CG"] = {"continent":"Africa","capital":"Brazzaville","currency":"CFA Franc BEAC","web":".cg","lang":"fr-CG | kg | ln-CG","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_CH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNoIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSJyZWQiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogICAgPGcgZmlsbD0iI2ZmZiI+CiAgICAgIDxwYXRoIGQ9Ik0xNzAgMTk1aDMw'
    b'MHY5MEgxNzB6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNzUgOTBoOTB2MzAwaC05MHoiLz4KICAg'
    b'IDwvZz4KICA8L2c+Cjwvc3ZnPgo=', 'CH')

CH = b64_CH
index.append("CH")
index.append("CHE")
index.append("Switzerland")
catalog["CH"] = CH
catalog["CHE"] = CH
catalog["Switzerland"] = CH
country["Switzerland"] = ('CH', 'CHE', 0)
lookup["CH"] = ('CH', 'CHE', 'Switzerland', 0)
lookup["Bern Switzerland"] = ('CH', 'CHE', 'Switzerland', 0)
lookup["CHE"] = ('CH', 'CHE', 'Switzerland', 0)
lookup["Switzerland"] = ('CH', 'CHE', 'Switzerland', 0)
details["CH"] = {"continent":"Europe","capital":"Bern","currency":"Swiss Franc","web":".ch","lang":"de-CH | fr-CH | it-CH | rm","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_CI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNpIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMGNkMDAiIGQ9Ik00MjYuOCAwSDY0MHY0ODBINDI2Ljh6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmY5YTAwIiBkPSJNMCAwaDIxMi45djQ4MEgweiIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0iTTIxMi45IDBoMjE0djQ4MGgtMjE0eiIvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'CI')

CI = b64_CI
index.append("CI")
index.append("CIV")
index.append("Côte d'Ivoire")
catalog["CI"] = CI
catalog["CIV"] = CI
catalog["Côte d'Ivoire"] = CI
country["Côte d'Ivoire"] = ('CI', 'CIV', 0)
lookup["CI"] = ('CI', 'CIV', "Côte d'Ivoire", 0)
lookup["Yamoussoukro Côte d'Ivoire"] = ('CI', 'CIV', "Côte d'Ivoire", 0)
lookup["Ivory Coast"] = ('CI', 'CIV', "Côte d'Ivoire", 0)
lookup["CIV"] = ('CI', 'CIV', "Côte d'Ivoire", 0)
lookup["Côte d'Ivoire"] = ('CI', 'CIV', "Côte d'Ivoire", 0)
details["CI"] = {"continent":"Africa","capital":"Yamoussoukro","currency":"CFA Franc BCEAO","web":".ci","lang":"fr-CI","tz":"±00:00","altname":"Ivory Coast"}
#----------------------------------------------------------------------
b64_CK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNrIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwNiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiBkPSJtNDcxLjYgMjEzIDUuMi0xNi43LTE0LTEwLjYgMTcuNi0uMiA2LTE2LjUgNS42IDE2'
    b'LjUgMTcuNy41LTE0LjEgMTAuNSA1IDE2LjctMTQuNS0xMG0yNy4xIDEzIDEwLjQtMTMuOS05'
    b'LjctMTQuOCAxNi43IDUuOCAxMS0xMy41djE3LjZsMTYuNCA2LjQtMTYuOCA1LS44IDE3LjUt'
    b'MTAuMi0xNC40bS05OC40IDE1LS43LTE3LjUtMTYuOC01LjJMNDMxIDE5OHYtMTcuNGwxMC45'
    b'IDEzLjUgMTYuOC01LjYtOS44IDE0LjcgMTAuMyAxNC0xNy00LjVtLTM5LjYgNDAuOS03LjQt'
    b'MTUuOC0xNy40IDEuOCAxMi44LTEyLjNMMzg0IDIxMWwxNS4yIDguMiAxMy4zLTExLjgtMy40'
    b'IDE3LjQgMTQuOSA4LjktMTcuMyAyLjVNMzg5IDI5MS44bC0xMy4zLTExLjEtMTUgOS4yIDYu'
    b'NC0xNi43LTEyLjktMTEuNiAxNy4zLjcgNy0xNi40IDQuMyAxNy4yIDE3LjIgMS41LTE0LjYg'
    b'OS44bTMuMiA2MC40LTE2LjUtNC44LTEwLjEgMTQuNS0uNy0xNy45LTE2LjQtNS41IDE2LjEt'
    b'Ni4ydi0xOGwxMC43IDE0LjEgMTYuNC01LjYtOS42IDE1bTI5LjUgNTAuOC0xNyAyLjQtMy41'
    b'IDE3LjQtNy44LTE2LTE3LjEgMS42IDEyLjItMTIuMy03LjEtMTYuNCAxNS4zIDguNSAxMi44'
    b'LTExLjhMMzkzIDM2Mm00NSAzOC0xNS4xIDguMiAyLjYgMTcuNi0xMi43LTEyLjQtMTUuNiA3'
    b'LjYgNy4zLTE1LjktMTIuMy0xMi45IDE3LjMgMi42IDgtMTUuNSAzLjQgMTcuNG01My44IDkt'
    b'OC4zIDE1LjMgMTEuNyAxMy4yLTE3LjQtMy4zLTguOSAxNS0yLjQtMTcuMy0xNy4yLTQgMTUu'
    b'OC03LjQtMS43LTE3LjUgMTIuMiAxMi44bTU3LjQtMTMuMS0uNSAxNy40IDE2LjMgNi40LTE3'
    b'IDUtMS4yIDE3LjUtMTAtMTQuMy0xNyA0LjQgMTAuOC0xMy45LTkuNC0xNC43IDE2LjYgNS43'
    b'TTU1OSAyMDkuOGwxMiAxMi42IDE1LjktNy40LTguMyAxNS44IDExLjUgMTMuMS0xNy0yLjgt'
    b'OSAxNS41TDU2MiAyMzlsLTE3LTMuNSAxNS43LThtMzQuMiAyMSA1LjUgMTYuNiAxNy41LjMt'
    b'MTQuMiAxMC43IDQuNyAxNi44LTE0LjEtMTAtMTQuNiAxMC4xIDUuNC0xNi44LTEzLjgtMTAu'
    b'NiAxNy42LS40bTE5LjUgMzMuMi0yIDE3LjQgMTUuNyA3LjctMTcuMyAzLjYtMi43IDE3LjMt'
    b'OC43LTE1LjEtMTcuNCAyLjkgMTItMTMtOC4xLTE1LjUgMTYgNy4ybTMgMzkuOC03LjggMTUu'
    b'Nkw2MDMgMzc5bC0xNy40LTIuNy04LjQgMTUuMy0zLTE3LjMtMTcuNC0zLjMgMTUuNi04LTIu'
    b'My0xNy40IDEyLjYgMTIuM20tOS44IDM5LjEtMTQuNyA5LjIgMy44IDE3LjMtMTMuNS0xMS41'
    b'LTE1IDguNiA2LjMtMTYuMy0xMy4xLTEyLjEgMTcuNCAxLjUgNy0xNiA0LjQgMTcuMiIvPgog'
    b'IDxwYXRoIGZpbGw9IiMwMDYiIGQ9Ik0wIDBoMzIwdjI0MEgweiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Im0zNy41IDAgMTIyIDkwLjVMMjgxIDBoMzl2MzFsLTEyMCA4OS41IDEyMCA4'
    b'OVYyNDBoLTQwbC0xMjAtODkuNUw0MC41IDI0MEgwdi0zMGwxMTkuNS04OUwwIDMyVjB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0iTTIxMiAxNDAuNSAzMjAgMjIwdjIwbC0xMzUu'
    b'NS05OS41em0tOTIgMTAgMyAxNy41LTk2IDcySDB6TTMyMCAwdjEuNWwtMTI0LjUgOTQgMS0y'
    b'MkwyOTUgMHpNMCAwbDExOS41IDg4aC0zMEwwIDIxeiIvPgogIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik0xMjAuNSAwdjI0MGg4MFYwek0wIDgwdjgwaDMyMFY4MHoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjYzgxMDJlIiBkPSJNMCA5Ni41djQ4aDMyMHYtNDh6TTEzNi41IDB2MjQwaDQ4VjB6Ii8+'
    b'Cjwvc3ZnPgo=', 'CK')

CK = b64_CK
index.append("CK")
index.append("COK")
index.append("Cook Islands")
catalog["CK"] = CK
catalog["COK"] = CK
catalog["Cook Islands"] = CK
country["Cook Islands"] = ('CK', 'COK', 0)
lookup["CK"] = ('CK', 'COK', 'Cook Islands', 0)
lookup["Avarua Cook Islands"] = ('CK', 'COK', 'Cook Islands', 0)
lookup["COK"] = ('CK', 'COK', 'Cook Islands', 0)
lookup["Cook Islands"] = ('CK', 'COK', 'Cook Islands', 0)
details["CK"] = {"continent":"Oceania","capital":"Avarua","currency":"New Zealand Dollar","web":".ck","lang":"en-CK | mi","tz":"-10:00","altname":""}
#----------------------------------------------------------------------
b64_CL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNsIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImNsLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBjbGlwLXBhdGg9InVybCgjY2wtYSkiIHRyYW5zZm9ybT0ic2NhbGUoLjkzNzUpIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0yNTYgMGg1MTJ2MjU2SDI1NnoiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiMwMDM5YTYiIGQ9Ik0wIDBoMjU2djI1NkgweiIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTE2Ny44IDE5MS43IDEyOC4yIDE2MmwtMzkuNSAzMCAxNC43LTQ4LjhM'
    b'NjQgMTEzLjFsNDguNy0uNUwxMjcuOCA2NGwxNS41IDQ4LjUgNDguNy4xLTM5LjIgMzAuNCAx'
    b'NSA0OC43eiIvPgogICAgPHBhdGggZmlsbD0iI2Q1MmIxZSIgZD0iTTAgMjU2aDc2OHYyNTZI'
    b'MHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'CL')

CL = b64_CL
index.append("CL")
index.append("CHL")
index.append("Chile")
catalog["CL"] = CL
catalog["CHL"] = CL
catalog["Chile"] = CL
country["Chile"] = ('CL', 'CHL', 0)
lookup["CL"] = ('CL', 'CHL', 'Chile', 0)
lookup["Santiago Chile"] = ('CL', 'CHL', 'Chile', 0)
lookup["CHL"] = ('CL', 'CHL', 'Chile', 0)
lookup["Chile"] = ('CL', 'CHL', 'Chile', 0)
details["CL"] = {"continent":"Americas","capital":"Santiago","currency":"Chilean Peso","web":".cl","lang":"es-CL","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_CM = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgdmVyc2lvbj0i'
    b'MS4wIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iNjAwIiBoZWlnaHQ9IjQwMCIg'
    b'dmlld0JveD0iMCwwIDkwLDYwIj4NCgk8cmVjdCB3aWR0aD0iMzAiIGhlaWdodD0iNjAiIGZp'
    b'bGw9IiMwMDdhNWUiLz4NCgk8cmVjdCB4PSIzMCIgd2lkdGg9IjMwIiBoZWlnaHQ9IjYwIiBm'
    b'aWxsPSIjY2UxMTI2Ii8+DQoJPHJlY3QgeD0iNjAiIHdpZHRoPSIzMCIgaGVpZ2h0PSI2MCIg'
    b'ZmlsbD0iI2ZjZDExNiIvPg0KCTxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKDQ1LDMwKSIgZmls'
    b'bD0iI2ZjZDExNiI+DQoJCTxnIGlkPSJjIj4NCgkJCTxwYXRoIGlkPSJ0IiBkPSJNIDAsLTgg'
    b'diA4IGggNCB6IiB0cmFuc2Zvcm09InJvdGF0ZSgxOCAwLC04KSIvPg0KCQkJPHVzZSB4bGlu'
    b'azpocmVmPSIjdCIgdHJhbnNmb3JtPSJzY2FsZSgtMSwxKSIvPg0KCQk8L2c+DQoJCTx1c2Ug'
    b'eGxpbms6aHJlZj0iI2MiIHRyYW5zZm9ybT0icm90YXRlKDcyKSIvPg0KCQk8dXNlIHhsaW5r'
    b'OmhyZWY9IiNjIiB0cmFuc2Zvcm09InJvdGF0ZSgxNDQpIi8+DQoJCTx1c2UgeGxpbms6aHJl'
    b'Zj0iI2MiIHRyYW5zZm9ybT0icm90YXRlKDIxNikiLz4NCgkJPHVzZSB4bGluazpocmVmPSIj'
    b'YyIgdHJhbnNmb3JtPSJyb3RhdGUoMjg4KSIvPg0KCTwvZz4NCjwvc3ZnPg==', 'CM')

CM = b64_CM
index.append("CM")
index.append("CMR")
index.append("Cameroon")
catalog["CM"] = CM
catalog["CMR"] = CM
catalog["Cameroon"] = CM
country["Cameroon"] = ('CM', 'CMR', 0)
lookup["CM"] = ('CM', 'CMR', 'Cameroon', 0)
lookup["Yaounde Cameroon"] = ('CM', 'CMR', 'Cameroon', 0)
lookup["CMR"] = ('CM', 'CMR', 'Cameroon', 0)
lookup["Cameroon"] = ('CM', 'CMR', 'Cameroon', 0)
details["CM"] = {"continent":"Africa","capital":"Yaounde","currency":"CFA Franc BEAC","web":".cm","lang":"en-CM | fr-CM","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_CN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1jbiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHBhdGggaWQ9ImNuLWEiIGZpbGw9IiNm'
    b'ZjAiIGQ9Ik0tLjYuOCAwLTEgLjYuOC0xLS4zaDJ6Ii8+CiAgPC9kZWZzPgogIDxwYXRoIGZp'
    b'bGw9IiNlZTFjMjUiIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogIDx1c2UgeGxpbms6aHJlZj0i'
    b'I2NuLWEiIHdpZHRoPSIzMCIgaGVpZ2h0PSIyMCIgdHJhbnNmb3JtPSJtYXRyaXgoNzEuOTk5'
    b'MSAwIDAgNzIgMTIwIDEyMCkiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNjbi1hIiB3aWR0aD0i'
    b'MzAiIGhlaWdodD0iMjAiIHRyYW5zZm9ybT0ibWF0cml4KC0xMi4zMzU2MiAtMjAuNTg3MSAy'
    b'MC41ODY4NCAtMTIuMzM1NzcgMjQwLjMgNDgpIi8+CiAgPHVzZSB4bGluazpocmVmPSIjY24t'
    b'YSIgd2lkdGg9IjMwIiBoZWlnaHQ9IjIwIiB0cmFuc2Zvcm09Im1hdHJpeCgtMy4zODU3MyAt'
    b'MjMuNzU5OTggMjMuNzU5NjggLTMuMzg1NzggMjg4IDk1LjgpIi8+CiAgPHVzZSB4bGluazpo'
    b'cmVmPSIjY24tYSIgd2lkdGg9IjMwIiBoZWlnaHQ9IjIwIiB0cmFuc2Zvcm09Im1hdHJpeCg2'
    b'LjU5OTEgLTIzLjA3NDkgMjMuMDc0NiA2LjU5OTE5IDI4OCAxNjgpIi8+CiAgPHVzZSB4bGlu'
    b'azpocmVmPSIjY24tYSIgd2lkdGg9IjMwIiBoZWlnaHQ9IjIwIiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgxNC45OTkxIC0xOC43MzU1NyAxOC43MzUzMyAxNC45OTkyOSAyNDAgMjE2KSIvPgo8L3N2'
    b'Zz4K', 'CN')

CN = b64_CN
index.append("CN")
index.append("CHN")
index.append("China")
catalog["CN"] = CN
catalog["CHN"] = CN
catalog["China"] = CN
country["China"] = ('CN', 'CHN', 0)
lookup["CN"] = ('CN', 'CHN', 'China', 0)
lookup["Beijing China"] = ('CN', 'CHN', 'China', 0)
lookup["CHN"] = ('CN', 'CHN', 'China', 0)
lookup["China"] = ('CN', 'CHN', 'China', 0)
details["CN"] = {"continent":"Asia","capital":"Beijing","currency":"Yuan Renminbi","web":".cn","lang":"zh-CN | yue | wuu | dta | ug | za","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_CO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmZlODAwIiBkPSJNMCAwaDY0'
    b'MHY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDE0OGUiIGQ9Ik0wIDI0MGg2NDB2MjQw'
    b'SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZGEwMDEwIiBkPSJNMCAzNjBoNjQwdjEyMEgweiIv'
    b'PgogIDwvZz4KPC9zdmc+Cg==', 'CO')

CO = b64_CO
index.append("CO")
index.append("COL")
index.append("Colombia")
catalog["CO"] = CO
catalog["COL"] = CO
catalog["Colombia"] = CO
country["Colombia"] = ('CO', 'COL', 0)
lookup["CO"] = ('CO', 'COL', 'Colombia', 0)
lookup["Bogota Colombia"] = ('CO', 'COL', 'Colombia', 0)
lookup["COL"] = ('CO', 'COL', 'Colombia', 0)
lookup["Colombia"] = ('CO', 'COL', 'Colombia', 0)
details["CO"] = {"continent":"Americas","capital":"Bogota","currency":"Colombian Peso","web":".co","lang":"es-CO","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_CR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWNyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjMDAwMGI0IiBkPSJNMCAwaDY0'
    b'MHY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDc1LjRoNjQwdjMyMi4z'
    b'SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDkwMDAwIiBkPSJNMCAxNTcuN2g2NDB2MTU3LjdI'
    b'MHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'CR')

CR = b64_CR
index.append("CR")
index.append("CRI")
index.append("Costa Rica")
catalog["CR"] = CR
catalog["CRI"] = CR
catalog["Costa Rica"] = CR
country["Costa Rica"] = ('CR', 'CRI', 0)
lookup["CR"] = ('CR', 'CRI', 'Costa Rica', 0)
lookup["San Jose Costa Rica"] = ('CR', 'CRI', 'Costa Rica', 0)
lookup["CRI"] = ('CR', 'CRI', 'Costa Rica', 0)
lookup["Costa Rica"] = ('CR', 'CRI', 'Costa Rica', 0)
details["CR"] = {"continent":"Americas","capital":"San Jose","currency":"Costa Rican Colon","web":".cr","lang":"es-CR | en","tz":"-06:00","altname":""}
#----------------------------------------------------------------------
b64_CU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWN1IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImN1LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTMyIDBoNjgyLjd2'
    b'NTEySC0zMnoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgY2xpcC1wYXRoPSJ1cmwoI2N1LWEpIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgz'
    b'MCkgc2NhbGUoLjk0KSI+CiAgICA8cGF0aCBmaWxsPSIjMDAyYThmIiBkPSJNLTMyIDBoNzY4'
    b'djUxMkgtMzJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLTMyIDEwMi40aDc2OHYx'
    b'MDIuNEgtMzJ6bTAgMjA0LjhoNzY4djEwMi40SC0zMnoiLz4KICAgIDxwYXRoIGZpbGw9IiNj'
    b'YjE1MTUiIGQ9Im0tMzIgMCA0NDAuNyAyNTUuN0wtMzIgNTExVjB6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJNMTYxLjggMzI1LjUgMTE0LjMgMjkwbC00Ny4yIDM1LjggMTcuNi01'
    b'OC4xLTQ3LjItMzYgNTguMy0uNCAxOC4xLTU4IDE4LjUgNTcuOCA1OC4zLjEtNDYuOSAzNi4z'
    b'IDE4IDU4eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'CU')

CU = b64_CU
index.append("CU")
index.append("CUB")
index.append("Cuba")
catalog["CU"] = CU
catalog["CUB"] = CU
catalog["Cuba"] = CU
country["Cuba"] = ('CU', 'CUB', 0)
lookup["CU"] = ('CU', 'CUB', 'Cuba', 0)
lookup["Havana Cuba"] = ('CU', 'CUB', 'Cuba', 0)
lookup["CUB"] = ('CU', 'CUB', 'Cuba', 0)
lookup["Cuba"] = ('CU', 'CUB', 'Cuba', 0)
details["CU"] = {"continent":"Americas","capital":"Havana","currency":"Cuban Peso | Peso Convertible","web":".cu","lang":"es-CU | pap","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_CV = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWN2IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImN2LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTEyMy40IDBoNjgy'
    b'LjZ2NTEyaC02ODIuNnoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgY2xpcC1wYXRoPSJ1cmwoI2N2LWEpIiB0cmFuc2Zvcm09InRyYW5z'
    b'bGF0ZSgxMTUuNykgc2NhbGUoLjk0KSI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLTEy'
    b'My40IDIzM0g3MjN2MjA2aC04NDYuNXoiLz4KICAgIDxwYXRoIGZpbGw9IiMwODE4NzMiIGQ9'
    b'Ik0tMTIyLjggMGg4NDZ2MjU2LjZoLTg0NnptLjMgMzg1LjloODUyLjFWNTEyaC04NTIuMXoi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiNkZTM5MjkiIGQ9Ik0tMTIyLjUgMzAyLjZoODQ2djM5LjZo'
    b'LTg0NnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmNlMDgiIGQ9Im0xMzEgMzk5LjIgNi42IDIw'
    b'LjRIMTU5bC0xNy40IDEyLjcgNi42IDIwLjVMMTMxIDQ0MGwtMTcuNCAxMi43IDYuNy0yMC41'
    b'LTE3LjQtMTIuN2gyMS41TTMxNyAyNTAuNGw2LjcgMjAuNUgzNDVsLTE3LjQgMTIuNiA2LjYg'
    b'MjAuNS0xNy40LTEyLjctMTcuNCAxMi43IDYuNi0yMC41LTE3LjQtMTIuNmgyMS42bS0yMjIg'
    b'NjQuNCA2LjYgMjAuNWgyMS41TDk5IDM2OC42bDYuNyAyMC40LTE3LjQtMTIuNkw3MC45IDM4'
    b'OWw2LjYtMjAuNC0xNy40LTEyLjdoMjEuNU0zMTcgMzI5LjVsNi43IDIwLjRIMzQ1bC0xNy40'
    b'IDEyLjcgNi42IDIwLjQtMTcuNC0xMi42LTE3LjQgMTIuNyA2LjYtMjAuNS0xNy40LTEyLjdo'
    b'MjEuNm0tNDAuNS0xNjEuNyA2LjcgMjAuNEgyOThsLTE3LjQgMTIuNyA2LjYgMjAuNS0xNy40'
    b'LTEyLjctMTcuNCAxMi43IDYuNy0yMC41LTE3LjUtMTIuN2gyMS42bS02NC41LTQ1LjIgNi43'
    b'IDIwLjVoMjEuNWwtMTcuNCAxMi42IDYuNiAyMC41LTE3LjQtMTIuNi0xNy40IDEyLjYgNi43'
    b'LTIwLjUtMTcuNC0xMi42SDE5Mm0tNjQuNSAyLjkgNi43IDIwLjVoMjEuNWwtMTcuNCAxMi42'
    b'IDYuNyAyMC41LTE3LjUtMTIuNy0xNy40IDEyLjcgNi43LTIwLjUtMTcuNC0xMi42SDEyMW0t'
    b'MzQuOCA0My4yIDYuNiAyMC41aDIxLjZsLTE3LjUgMTIuNiA2LjcgMjAuNS0xNy40LTEyLjct'
    b'MTcuNCAxMi43IDYuNi0yMC41TDU4IDI3MWgyMS41bTExOS4yIDE0OS40IDYuNyAyMC41aDIx'
    b'LjVsLTE3LjQgMTIuNiA2LjcgMjAuNS0xNy41LTEyLjctMTcuNCAxMi43IDYuNy0yMC41LTE3'
    b'LjQtMTIuNkgxOTJtODIuMi00MS43IDYuNiAyMC40aDIxLjVMMjg1IDQzMi4zbDYuNyAyMC41'
    b'LTE3LjQtMTIuNy0xNy41IDEyLjcgNi43LTIwLjUtMTcuNC0xMi43aDIxLjUiLz4KICA8L2c+'
    b'Cjwvc3ZnPgo=', 'CV')

CV = b64_CV
index.append("CV")
index.append("CPV")
index.append("Cabo Verde")
catalog["CV"] = CV
catalog["CPV"] = CV
catalog["Cabo Verde"] = CV
country["Cabo Verde"] = ('CV', 'CPV', 0)
lookup["CV"] = ('CV', 'CPV', 'Cabo Verde', 0)
lookup["Praia Cabo Verde"] = ('CV', 'CPV', 'Cabo Verde', 0)
lookup["CPV"] = ('CV', 'CPV', 'Cabo Verde', 0)
lookup["Cabo Verde"] = ('CV', 'CPV', 'Cabo Verde', 0)
details["CV"] = {"continent":"Africa","capital":"Praia","currency":"Cabo Verde Escudo","web":".cv","lang":"pt-CV","tz":"-01:00","altname":""}
#----------------------------------------------------------------------
b64_CW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1jdyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGNsaXBQYXRoIGlkPSJjdy1hIj4KICAg'
    b'ICAgPHBhdGggZmlsbC1vcGFjaXR5PSIuNyIgZD0iTTAgMGg2ODIuN3Y1MTJIMHoiLz4KICAg'
    b'IDwvY2xpcFBhdGg+CiAgICA8cGF0aCBpZD0iY3ctYiIgZD0ibTAtMSAuMi43SDFMLjMgMGwu'
    b'Mi43TDAgLjRsLS42LjQuMi0uNy0uNS0uNGguN3oiLz4KICA8L2RlZnM+CiAgPGcgY2xpcC1w'
    b'YXRoPSJ1cmwoI2N3LWEpIiB0cmFuc2Zvcm09InNjYWxlKC45NCkiPgogICAgPHBhdGggZmls'
    b'bD0iIzAwMmI3ZiIgZD0iTTAgMGg3Njh2NTEySDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZjll'
    b'ODE0IiBkPSJNMCAzMjBoNzY4djY0SDB6Ii8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNjdy1i'
    b'IiB3aWR0aD0iMTM1MDAiIGhlaWdodD0iOTAwMCIgeD0iMiIgeT0iMiIgZmlsbD0iI2ZmZiIg'
    b'dHJhbnNmb3JtPSJzY2FsZSg0Mi42NykiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2N3LWIi'
    b'IHdpZHRoPSIxMzUwMCIgaGVpZ2h0PSI5MDAwIiB4PSIzIiB5PSIzIiBmaWxsPSIjZmZmIiB0'
    b'cmFuc2Zvcm09InNjYWxlKDU2LjkpIi8+CiAgPC9nPgo8L3N2Zz4K', 'CW')

CW = b64_CW
index.append("CW")
index.append("CUW")
index.append("Curaçao")
catalog["CW"] = CW
catalog["CUW"] = CW
catalog["Curaçao"] = CW
country["Curaçao"] = ('CW', 'CUW', 0)
lookup["CW"] = ('CW', 'CUW', 'Curaçao', 0)
lookup["Willemstad Curaçao"] = ('CW', 'CUW', 'Curaçao', 0)
lookup["CUW"] = ('CW', 'CUW', 'Curaçao', 0)
lookup["Curaçao"] = ('CW', 'CUW', 'Curaçao', 0)
details["CW"] = {"continent":"Americas","capital":"Willemstad","currency":"Netherlands Antillean Guilder","web":".cw","lang":"nl | pap","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_CX = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1jeCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMDIxYWQiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiMxYzhhNDIiIGQ9Ik0wIDBoNjQwdjQ4MHoiLz4KICA8'
    b'Y2lyY2xlIGN4PSIzMjAiIGN5PSIyNDAiIHI9IjU3LjgiIGZpbGw9IiNmZmM2MzkiLz4KICA8'
    b'cGF0aCBmaWxsPSIjMWM4YTQyIiBkPSJNMjg0LjcgMjE0YzQgNS41IDEwIDE0LjYgMTQuOCAx'
    b'Mi4yIDMuNyAwIDUuNy4zIDYuMiAyLjhhMzcgMzcgMCAwIDAgMzMtMTQuM3MuOCAwIC41LTQu'
    b'NWMwLTIgMi44LTEuNiAyLjgtMSAuNCAxIC40IDEuNy45IDEuOCAxLS40IDIuNy0zIDQtNC42'
    b'LjMtLjcuMS0xLjUuMi0yLjQuNy0xLjcgMi40LTEuMyAyLjgtLjRsLjYgMS42YzEuOCAxLjIg'
    b'NSAwIDUuMiAwIC4zLTEuNCAxLjItMS4yIDEuMi0xLjIgMS4yLS4zLjctLjIgMS41LjItLjcg'
    b'Ny43IDEuNSA4IDEuMyAxMiAuMSA0LjQtMS4zIDUuNi0xLjMgNy4zLjQgMiA3IDIuMSA0LjYg'
    b'My45LTIgMSAwIDMtMyAzLjgtOC44IDQuNS0xMC40IDguMy0xMC40IDguM3MtMi4yIDQuMi0y'
    b'LjUgNC4yYy0xLjUgMi44LTMuMyAxLjItNC40IDIuNi0uNSAxLjctMSA1LjUgMCA3LjQuNSAy'
    b'LjcgMCA0LjItLjcgNi45LS42IDUuNi0yLjggNi41LTMuMSA4LjQtMSAyLjIuMiAxMi0uOCAx'
    b'Mi02LjUuMi0xMS41LTEuMi0xNC4xLTEuNyAyLjUtMTAuOSAxLjUtMjAuNCAxLjUtMjEuNC0u'
    b'Ni03LjgtMTEuNi01LjktMTMuMy03LTEuNC0uMi0yLjMtMS4zLTIuNy0xLjgtMS42LS4yLTIu'
    b'Mi0uNi0zLjctLjctLjguNC0uMy44LTIgMS4zLTQuNS41LTYuNC0zLjgtNi40LTMuOC4yLTEu'
    b'NS05LjkuMy0xNS4zLTEtMi4zIDEuMy0zLjMgNS01LjEgNS40IDAgMS4xLTMtMS0zLjYtMi0u'
    b'Mi0zLjQgMi44LTQuOCAyLjgtNC44IDIuNC0xLjcgMy44LTIgNS0zLjEuNS0yLjkuMi01IDEu'
    b'NS03LjEgMS0xLjcgMi41LTEgMy41LTEuNiAxLjEtLjggMS42LTUuNi42LTdsLTQuNy00LjJj'
    b'LTEuNC00LjEgMS43LTYuOCAyLjYtNi41eiIvPgogIDxwYXRoIGZpbGw9IiNmZmM2MzkiIGQ9'
    b'Ik01NjEuOSAxNDIuNGMtMi42LTEwLjMtMjYtMzIuNy00My43LTQ2LjktNC4yLTIuOC03LTEu'
    b'MS02LjQgMyAyLjIgMy42IDMuOCA3LjYgNiAxMS4zLjYgMi41IDEuOCA0LjIgMi40IDYuNiAw'
    b'IDAgLjIgNC4yLjYgNC42IDUuNCA2IDYuMiAxMS4xIDYuMiAxMS4xYTQ5IDQ5IDAgMCAwIDEx'
    b'LjUgMTUuNmM2LjIgMy45IDEuNiAxNiAxLjggMjIuNSAwIDQtMi45IDMuNi01LjUgMy0yMC4x'
    b'LTE4LjUtNDAuMS0xOC41LTU3LjgtMjMuOS02LjgtLjctNyAyLjYtNC43IDQuNGExMjkgMTI5'
    b'IDAgMCAwIDM5LjEgMjkuNmw3LjcgNC44IDguOCA3LjNjNi44IDQuNCA3LjMgOC40IDcuMyA4'
    b'LjguMiA4LjItNC4yIDE0LjYtNS41IDE3LjItMi4zIDguNy03IDEwLjItNyAxMC4yLTM3LjYg'
    b'MjUuNC01Ny40IDMyLTExOC40IDI0LjEtMS0uNC02LjguNSAwIDMgMTUuNSA1LjIgNTMuNyAx'
    b'My41IDkwLjYtNCA5LTYuMiAxNC44LTQuMiAyMS4zLThhMjg3LjMgMjg3LjMgMCAwIDEgMjgu'
    b'My0xNS40YzguMy00LjUgMzEuMy05LjQgMzYuNi0xMy44IDYuMS0uNSAxMi40LTEuMyAxMi44'
    b'LTYuNSAyLTEuMyA1LS4zIDcuMi00LjYgNC44LS45IDQtMi42IDQtMi42LTEuMi0zLjQtNS44'
    b'LTQuOC05LTcuMy00LjgtMS42LTgtMi0xMS41LS40bC0zLjMgMS41cy01LjEtLjctNS4xLTEu'
    b'MWMtMTEuNC0uNi0xMC4zLTM4LjMtMTQuMy01NHoiLz4KICA8cGF0aCBmaWxsPSIjMWM4YTQy'
    b'IiBkPSJNNTg4LjYgMjA0LjJhMi44IDEuOCAxNiAxIDEtNS40LTEuNyAyLjggMS44IDE2IDAg'
    b'MSA1LjQgMS43eiIvPgogIDxnIGZpbGw9IiNmZmYiIHRyYW5zZm9ybT0ibWF0cml4KC42NCAw'
    b'IDAgLjY0IDAgODApIj4KICAgIDxwYXRoIGlkPSJjeC1hIiBkPSJtMTg4LjIgMTkxLTEyLjgt'
    b'MTItMTIuOSAxMS44IDEuNC0xNy40LTE3LjMtMi44IDE0LjUtOS44LTguNi0xNS4yIDE2Ljcg'
    b'NS4zIDYuNS0xNi4yTDE4MiAxNTFsMTYuNy01LTguOCAxNSAxNC40IDEwLTE3LjMgMi41IDEu'
    b'MiAxNy40eiIvPgogICAgPHBhdGggZD0ibTIzMy40IDMzNS41LTEzLjgtOS4xLTEzLjQgOS42'
    b'IDQuOC0xNS41LTEzLjYtOS41IDE2LjYtLjQgNS0xNS41IDUuNiAxNS4zIDE2LjctLjFMMjI4'
    b'IDMyMGw1LjMgMTUuNHoiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2N4LWEiIHdpZHRoPSIx'
    b'MDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjIuNSIgeT0iMjY5LjEiLz4KICAgIDx1c2UgeGxpbms6'
    b'aHJlZj0iI2N4LWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii0xMTIuMSIgeT0i'
    b'MTIzLjIiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2N4LWEiIHdpZHRoPSIxMDAlIiBoZWln'
    b'aHQ9IjEwMCUiIHg9IjEwOC40IiB5PSI4NSIvPgogIDwvZz4KPC9zdmc+Cg==', 'CX')

CX = b64_CX
index.append("CX")
index.append("CXR")
index.append("Christmas Island")
catalog["CX"] = CX
catalog["CXR"] = CX
catalog["Christmas Island"] = CX
country["Christmas Island"] = ('CX', 'CXR', 0)
lookup["CX"] = ('CX', 'CXR', 'Christmas Island', 0)
lookup["Flying Fish Cove Christmas Island"] = ('CX', 'CXR', 'Christmas Island', 0)
lookup["CXR"] = ('CX', 'CXR', 'Christmas Island', 0)
lookup["Christmas Island"] = ('CX', 'CXR', 'Christmas Island', 0)
details["CX"] = {"continent":"Oceania","capital":"Flying Fish Cove","currency":"Australian Dollar","web":".cx","lang":"en | zh | ms-CC","tz":"+07:00","altname":""}
#----------------------------------------------------------------------
b64_CY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1jeSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgw'
    b'eiIvPgogIDxwYXRoIGlkPSJjeS1hIiBmaWxsPSIjNDM1MTI1IiBkPSJNMzA3LjggMzk4LjZh'
    b'LjguOCAwIDAgMS0uMi0uMmgtLjFsLTEuMy0xLjQtMy44LTQuNS00LjktNi4zLS42LS45LTYu'
    b'Mi0xLjktNC42LTIuMSAyLjQtMi43IDguNCAzLjUgNi4yIDEuMyAxMS41IDguNS0zLjMgMi45'
    b'YTM3LjIgMzcuMiAwIDAgMC0zLjMgMy41bC43LS41LjguNi0xLjYuMnptLTQyLjYtMTIuOGEz'
    b'MS43IDMxLjcgMCAwIDEtMTYtNC41cy43LTEuMyAyLjMtMi40YzEuNi0xLjIgNC40LTIuNSA5'
    b'LTIuNiA1LjQgMCAxMiAxLjkgMTkuNSA1LjRhMjguOCAyOC44IDAgMCAxLTE0LjggNHptLTIz'
    b'LjUtNS4yYy0xIDAtMi0uNC0yLjYtMWE1LjIgNS4yIDAgMCAxLTEuMS0yLjQgMTEuNyAxMS43'
    b'IDAgMCAxLS4zLTMuNCAzLjUgMy41IDAgMCAxIDEuMy0uMmMyIDAgMy42IDEuNyA0LjMgMy40'
    b'LjQgMSAuNSAxLjguMiAyLjUtLjIuNi0xIDEtMS44IDF6bTQxLjMtNC44Yy0xMy45LTItMTku'
    b'OC03LTIyLjMtMTAuOS0yLjYtNC4xLTItOC0yLThzLjgtLjIgMi0uMmMzLjggMCAxMy4yIDEu'
    b'OSAyMi4zIDE5em0tMjguNS0yLjhjLTUuOSAwLTEwLjQtMS0xMy40LTNhOC4zIDguMyAwIDAg'
    b'MS0zLTMuMyA1LjQgNS40IDAgMCAxLS40LTEuNiAxOC4yIDE4LjIgMCAwIDEgNy4yLTEuNCAy'
    b'NyAyNyAwIDAgMSAxOC45IDguN2MtMy40LjQtNi41LjYtOS4zLjZ6bS0yOC43LTFjLTYuMiAw'
    b'LTE0LjgtMi0yMC4yLTcuMyAwIDAgNS45LTEuNSAxMi40LTEuN2gxLjJjNS45IDAgMTAuNCAx'
    b'LjEgMTMuNCAzLjQgMSAuOCAxLjYgMS41IDEuNyAyLjIuMS42LS4yIDEuMi0uOCAxLjctMS40'
    b'IDEtMy44IDEuNi03LjIgMS42aC0uNXptLTIwLjMtMTAuNWEyLjYgMi42IDAgMCAxLTItMSA0'
    b'LjcgNC43IDAgMCAxLS44LTJjLS4zLTEuNC0uMi0yLjgtLjItMi45YTIuNCAyLjQgMCAwIDEg'
    b'MS0uMmMuOSAwIDEuNi41IDIgMWE1LjYgNS42IDAgMCAxIDEuNCAyYy4yLjkuMyAxLjYgMCAy'
    b'LjIgMCAuNC0uNiAxLTEuMyAxem00Ni45LTFjLTEgMC0yLS40LTIuNi0xYTUuMiA1LjIgMCAw'
    b'IDEtMS4xLTIuNCAxMS43IDExLjcgMCAwIDEtLjMtMy40IDMuNSAzLjUgMCAwIDEgMS4zLS4y'
    b'YzIgMCAzLjcgMS43IDQuMyAzLjQuNCAxIC41IDEuOC4zIDIuNS0uMy42LTEgMS0yIDF6bS0y'
    b'Mi44LTFjLTEyLjYtLjQtMTkuMi00LTIyLjQtN2ExNC42IDE0LjYgMCAwIDEtMy40LTQuM2Mt'
    b'LjUtMS0uNy0xLjgtLjctMnMxLjItLjQgMy0uNGguNGM0LjIgMCAxMi45IDEuOCAyMyAxMy43'
    b'em0xMy42LTEuMmEzMC44IDMwLjggMCAwIDEtMTguOS05LjMgMTkuNCAxOS40IDAgMCAxLTQu'
    b'MS03czEuMi0uMyAzLS40YTE0LjIgMTQuMiAwIDAgMSAxIDBjNSAuMSAxNC4zIDIuNCAxOSAx'
    b'Ni43em0tNTItNWE0MiA0MiAwIDAgMS05LjUtMWMtNS4zLTEuNC03LjYtMy40LTguNi00Ljlh'
    b'NSA1IDAgMCAxLS44LTIgMy40IDMuNCAwIDAgMSAwLS44czMuNS0xIDguNC0xLjFhMzUgMzUg'
    b'MCAwIDEgNy40LjYgMjEuNyAyMS43IDAgMCAxIDEyLjggOC4xcy00IDEuMi05LjcgMS4yem0y'
    b'My41LTguNGEzLjQgMy40IDAgMCAxLTIuNS0xIDUuMiA1LjIgMCAwIDEtMS4xLTIuNGMtLjQt'
    b'MS42LS4zLTMuMi0uMy0zLjRhMy41IDMuNSAwIDAgMSAxLjItLjNoLjFjMiAwIDMuNiAxLjgg'
    b'NC4zIDMuNS40IDEgLjQgMS44LjIgMi40LS4zLjctMSAxLjEtMS45IDEuMXptLTE3LjYtMi41'
    b'YTM4LjYgMzguNiAwIDAgMS05LjYtNC4yYy00LjQtMi43LTkuOS03LjUtMTAuNS0xNWwxLS4x'
    b'aC4zYzEuMyAwIDQgLjMgNy4zIDIuOCA0LjIgMy4yIDggOC44IDExLjUgMTYuNXptMTEuNS0u'
    b'NGEzMS4yIDMxLjIgMCAwIDEtNy42LTQuOSA0OC41IDQ4LjUgMCAwIDEtMTMuMy0xOC42cy45'
    b'LS41IDIuMy0uNmEzLjMgMy4zIDAgMCAxIC4yIDBoLjRjMiAwIDQuOS45IDguMSA0LjQgMy44'
    b'IDQgNy4xIDEwLjYgMTAgMTkuN3ptLTI5LjktLjljLTMuOSAwLTUuMi0yLTUuNi0zYTYgNiAw'
    b'IDAgMS0uNC0zIDguNSA4LjUgMCAwIDEgMi0uMiA4IDggMCAwIDEgNi41IDNjLjIuNC44IDEu'
    b'NC4zIDIuMy0uNC42LTEuMyAxLTIuOCAxem0tOC41LTEwLjhhNTEuMSA1MS4xIDAgMCAxLTkt'
    b'LjdjLTMuNC0uNi01LjMtMy41LTYuNC01LjktMS0yLjUtMS40LTUtMS40LTUgMTAuNi4zIDE1'
    b'LjcgMy40IDE4IDZhOS40IDkuNCAwIDAgMSAyLjYgNS41cy0xLjYuMi0zLjguMnptMTEtMTFh'
    b'NDIuNyA0Mi43IDAgMCAxLTIuNC0zLjRjLTEuMy0yLTIuNC00LTIuNC01LjYgMC0xLjctLjQt'
    b'NS0uNi03bC0uNi00LjVjLjMgMCA2LjYgMi40IDYuNiA4LjRzLS42IDEyLS42IDEydi4xem0t'
    b'OC4yLS42aC0uMmE0My43IDQzLjcgMCAwIDEtMTguMi0xMC44Yy0xLjctMi0yLjgtNS4yLTMu'
    b'MS05LjQtLjItMyAwLTUuNSAwLTUuOGEzLjMgMy4zIDAgMCAxIDEuMS0uMWMxLjQgMCAzIC42'
    b'IDUgMmEzOS42IDM5LjYgMCAwIDEgNS4yIDQuNGMzLjIgMy4yIDUuNyA2LjQgNS43IDYuNC4z'
    b'LjQgMiAzLjcgMy41IDYuOWEyMiAyMiAwIDAgMSAxLjYgNC42Yy4xLjYuMiAxIDAgMS40YS43'
    b'LjcgMCAwIDEtLjMuNC45LjkgMCAwIDEtLjQgMHoiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNj'
    b'eS1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09Im1hdHJpeCgtMSAw'
    b'IDAgMSA1OTMuNyAwKSIvPgogIDxwYXRoIGZpbGw9IiNkNDc2MDAiIGQ9Im01MTkgNzYuNC0x'
    b'LjguNy0uOC4zLTIuMi0uMS0yLjIgMS0zLjggMi42LS4xLjEtMS41LjQtMS4zLS42LS43LjQt'
    b'LjMgMS41LS43IDEuMS0uOS42LTMgLjMtMi41IDEuNC0zLjQtMS0xLjUuNy0zLjMgMy0xLjcu'
    b'N2gtLjVsLTIuMy0uMS0uOS4zLTEuNCAxLjMtMi42LjItLjkuNi0xLjMgMi42TDQ3NiA5Nmwt'
    b'LjguMS0uOC0uMy0uNy4xLS4zIDEuNy0uNi43LTEuOC42LTEuNCAxLjItMS4zLjZoLTJsLTEu'
    b'NyAxLTMuMS4yLTEuMyAxLjItLjMuMy0uNi4zLTEgLjYtLjIuMi0xLjItLjItMS40LjUtLjYt'
    b'LjgtMSAuNS0xLjIuMS0xLjYtLjctMS4zLS42LS45LjItLjMgMS41di4ybC0xIDEuMi0xLjcg'
    b'MS4xLS4yLjMtMiAyLjYtMy44IDQtMy4yIDEuNi0zLjMgMS0yLjMgMS45LTYgMy05LjcgNC44'
    b'LTIgLjYtMi44LjQtNSAxLjktNC40IDEuMy0uMy4xLS44LjMtNi4zIDEuOS0yLjktLjQtMS43'
    b'LjctNC41LS41aC0zLjFsLTIgLjQtMy43IDEuOC02LjMgMy0yIDItMy4yIDEuNi0zLjggMS4y'
    b'di0xLjZsLTEuMy40LTEgLjMtMyAuNGgtMS43bC0xLjEtLjNoLS4ybC02LjIgMi4xLTcgLjct'
    b'My41IDEuMUgzMzNsLTEuNi41LTMuMi40LTEuMi0uMy0uMi0uMS05LjQuNC00LjMtLjUtMiAu'
    b'NS0zLjUtMS4yLTUtLjYtMS4yLS4zLTIuNi0uOC0xLjIuNy0xIC4xLTItLjhoLS44bC0xLjgu'
    b'Ni0xLS4yLTEtLjgtMi4xLS4zLTEuNC0xLjEtNy41IDEtMi0uNi02LjktMmgtMWwtMS40IDEt'
    b'MiAuOC0xLjkuNC0yLjQuMS0yLjgtLjctMi44LTEuNC0xLjEtLjMtMi40LjNoLS43bC00LjQt'
    b'Mi4zLTUuNi0zLjUtMy44LTEuOS0xLjUtLjItLjIuNy43IDIuMi4zIDIuM3YybC0uMSAxLjMu'
    b'MyAxLjEgMS40IDEuNi42IDEuNS40IDQuMnY0LjNsLS43IDYuOC0uMiAxLS44IDMuNi0uNyAz'
    b'LjMtMi45IDguNy0uNyAxLTIgMS4zLTQuMyAzLTMuMiAxLjgtMSAuNC0yLjYuMkgyMTlsLTIt'
    b'MS4xLTItLjUtMi42LTEuOS0yLjgtLjYtMy4yLTEuOC0uOC0xLTEuNy0uMi0yLjQtLjctLjkt'
    b'LjMtLjYtLjEtMy0uMS0yLjktMS4zLTEuNS0uNGgtMmwtMi4xIDEtMS4xLjQtMS40LS41aC0x'
    b'bC0xIDEuNy0uMi4zLS44LjRoLTEuN2wtLjguMy0xLjEuNS0xIC40LS41LjJoLS4zbC0uNS4y'
    b'aC0uNmwtMS4yLS42LS42LS4zLTEtLjItLjUuMy0uMSAxLjktLjUgMS4xLTEuNiAxLjQtMS42'
    b'IDEuNC0xIDEuNi0zIDYuNy0xLjkgMi43LS41LjctMiAyLjEtMS43IDEuMy0zLjkgMy0zLjcg'
    b'MS41LTMuMi42aC0xLjZsLTMtLjQtMi42LS44LTMtMS44LTMuMS0yLjYtNC43LTQuNS0uNi0u'
    b'NC0uMi0uMS0xLjQtMWgtMS4xbC0uNC44LS4zIDEtLjIuOS0uNSA1di4zbC4zIDIuMSAzLjYg'
    b'NSAxIDIuNi4yLjMuNyAxLjIuNiAxIDEuMyAzLjYtLjkgMiAuNCAxLjQtMSAuOC0uMiAxLjIg'
    b'My4xIDQgLjcgMS43LS43IDIuNC0xLjMgMS40LS4zLjMuMiAxIDEuNCAxLjQgMi41IDIuMiAx'
    b'LjMgMy4yIDEgMSAxLjItLjMuNi41aDFsMSAxIC42LjIgMSAuNS44IDEgLjEgMy4yIDEuNSAz'
    b'Ljh2Mi41bDEgMS41LjIgMS4yLS41IDMuMyAxLjIgMSAxLjItLjIuOC4xIDEuMyAxLjEgMS42'
    b'IDIuNCAxLjYtLjIgMSAuNCA0LjcgNC4zIDEgLjYuOS40IDEgMSAxLjQtMWguMmwxLjYtLjIu'
    b'Ny41IDEuNC45aDEuN2w0IDEuMiAxLjYuNCAzLjQgMi4xIDEuNS45LjguNyAxLjIgMSAyLjIg'
    b'MSAyIC40IDEgLjIuOS4zIDQuMiAxLjcgMi4zLjUgMiAuOCAxLjYuNWgxLjJsMS42LTEuM2gx'
    b'LjVsMS4zLjIgMS4zLS4yIDItMS4yLjMtLjYgMS40LS42IDQuOC0uNiAxLjQuNCAzLjYtMS41'
    b'IDIuNC42IDItLjcgNC43IDEgMS4yLjkgMS40IDEuNWgxLjdsLS43IDEuMSAyIDIuMiAxLjkg'
    b'Mi43LjEuNCAxLjMgMy45IDEgMS40LjcgMS45djEuMmwtMSAuOS0uMi40di4ybC4yLjUuNC0u'
    b'Mi43LS40IDEtLjIgMS42LjIgMS4xLjEgMS43LS44IDEuMi0uNiAxLjguOGgybC45LjMgMi40'
    b'IDEuMSAxLjIuMS40LS4zLjMtLjYtLjEtLjgtMS0xLjEtMi0yLjQtLjgtMS4yLS42LTEuNy0u'
    b'Mi0yLjItLjItMS41LjMtMiAuNS0uNy40LTEuNi4xLS40IDEuMi0xLjUgMy0yIDMuMi0yLjgg'
    b'Mi41LTEuNyAyLjYtMS4xdi0uM2wuNC4xIDYuNi0yLjMgMy0uNSAyMCAxLjQuNy0uMi43LTEu'
    b'OS4zLS4zLjMtLjIgMi4yLTEgMS0uMiAyLjguNyAxLjIuMyAxLjktMWgxLjNsMi43LTEuNWgx'
    b'LjdsLjctLjIgMy4zLTIuNCAzLjEtLjkuOC0uNC4zLS4yIDMuMy0xLjcgMi0xLjYgMS44LTEg'
    b'Mi0uNCA1LS40IDEuMS0xLjcgMi4yLS4zIDEuMy0xLjUgMS41LS42IDEuMS0xLjYgMS0xLjMg'
    b'MS4yLS43IDQuMS0uMyA0LjguNi43LS40IDEtMy45IDEuMi0uNyAzLTQuNXYtMS42bC4xLTEu'
    b'NC41LTItLjMtMy40LjQtMy42IDEuOS00LjUgMS43LTEuOCAyLjctMS45IDEuNC0uNiAyLS4z'
    b'aC4ybC41LS4yaDkuMmwyLjMtLjEgNS43IDFoLjRsMS45LjcgMi4yIDEuNyAyLjQgMi4zLjQu'
    b'NCAxLjUuNy41LjIgMS4yLS4yIDEuOC0xIDEuNC0xIDEuOC0xdi0uMmwxLjEtMS41LjQtLjcg'
    b'My42LTEuNCA0LjItLjIuNS0uM2guMmwxLjEtMS40aDFsMi42IDEgMS43LS40IDEuNC41IDEu'
    b'MS0uMSAyLS4zIDIuMyAxLjYgMS4zLjIgNC41IDIuNmguNGwuMi4xLjUtLjIuOC0uMmguMWwu'
    b'MS4xLjYuNy43LjEuOC0xLS4zLS42LS4xLS4yLTEuNy0uMy0xLjQtMi41IDEuNC0xLjUtMi4y'
    b'LTIuNi0uNC0uNXYtLjFsLS44LTEuMi0zLjgtNS44LTUtNC0xLjctMS4zLS42LS41LTIuNy0y'
    b'LjctMS45LTIuNS0uMi0uNS0uNC0uOS0xLjEtMi40LTItMS41LTEuNi0xLjgtMy40LTQuNi0u'
    b'NS0uNy0uOC0uNWgtMS43bC0uMS0uMmgtLjF2LS4xbC44LS44IDEtLjIuMy0uOS0xLjctNC45'
    b'di0uMmwtLjEtMS41IDEuMy03LjEuMi0uOSAyLjQtNC43IDEuNC0xLjIgMS42LTMuMSAxLjQt'
    b'MiAxLjMtMS4zLjItLjEgMi4zLTEuNCAyLS4zIDEuOS0uMyAzLjMgMWgzbC43LS4xIDEuNC0u'
    b'MiAyLjMtLjcgMS4xLS43LjYtLjggMS4yLTQgLjQtMS4zLjctMS40IDQuMy00LjkgMy4yLTMg'
    b'Ny4yLTUuMiAzLjUtMi4xIDEuOC0xLjEgMTYuMS03LjIgNC4yLTQuMiAyLjItMi4yIDMuOC0y'
    b'LjYgNC41LTEuOSA0LTMgLjgtMS4xIDEtMy41IDEtLjIuNy0xLjcuMy0uNSAzLjEtMi4yLjQt'
    b'LjIgMTIuMy02LjIgMS44LjMgMS0xLjUgMy41LS42aC43bC45LS41LjctMS4zdi0uM2wuMS0z'
    b'LjQuOC0uOS40LTIuMi40LS42LjQtLjUgMS0uNy0uMi0uNHoiLz4KPC9zdmc+Cg==', 'CY')

CY = b64_CY
index.append("CY")
index.append("CYP")
index.append("Cyprus")
catalog["CY"] = CY
catalog["CYP"] = CY
catalog["Cyprus"] = CY
country["Cyprus"] = ('CY', 'CYP', 0)
lookup["CY"] = ('CY', 'CYP', 'Cyprus', 0)
lookup["Nicosia Cyprus"] = ('CY', 'CYP', 'Cyprus', 0)
lookup["CYP"] = ('CY', 'CYP', 'Cyprus', 0)
lookup["Cyprus"] = ('CY', 'CYP', 'Cyprus', 0)
details["CY"] = {"continent":"Europe","capital":"Nicosia","currency":"Euro","web":".cy","lang":"el-CY | tr-CY | en","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_CZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWN6IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2MjQwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2Q3MTQxYSIgZD0iTTAgMjQwaDY0MHYy'
    b'NDBIMHoiLz4KICA8cGF0aCBmaWxsPSIjMTE0NTdlIiBkPSJNMzYwIDI0MCAwIDB2NDgweiIv'
    b'Pgo8L3N2Zz4K', 'CZ')

CZ = b64_CZ
index.append("CZ")
index.append("CZE")
index.append("Czechia")
catalog["CZ"] = CZ
catalog["CZE"] = CZ
catalog["Czechia"] = CZ
country["Czechia"] = ('CZ', 'CZE', 0)
lookup["CZ"] = ('CZ', 'CZE', 'Czechia', 0)
lookup["Prague Czechia"] = ('CZ', 'CZE', 'Czechia', 0)
lookup["CZE"] = ('CZ', 'CZE', 'Czechia', 0)
lookup["Czechia"] = ('CZ', 'CZE', 'Czechia', 0)
details["CZ"] = {"continent":"Europe","capital":"Prague","currency":"Czech Koruna","web":".cz","lang":"cs | sk","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_DE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWRlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmY2UwMCIgZD0i'
    b'TTAgMzIwaDY0MHYxNjBIMHoiLz4KICA8cGF0aCBkPSJNMCAwaDY0MHYxNjBIMHoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjZDAwIiBkPSJNMCAxNjBoNjQwdjE2MEgweiIvPgo8L3N2Zz4K', 'DE')

DE = b64_DE
index.append("DE")
index.append("DEU")
index.append("Germany")
catalog["DE"] = DE
catalog["DEU"] = DE
catalog["Germany"] = DE
country["Germany"] = ('DE', 'DEU', 0)
lookup["DE"] = ('DE', 'DEU', 'Germany', 0)
lookup["Berlin Germany"] = ('DE', 'DEU', 'Germany', 0)
lookup["DEU"] = ('DE', 'DEU', 'Germany', 0)
lookup["Germany"] = ('DE', 'DEU', 'Germany', 0)
details["DE"] = {"continent":"Europe","capital":"Berlin","currency":"Euro","web":".de","lang":"de","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_DE_BB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjxzdmcKICAgIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4xLyIK'
    b'ICAgIHhtbG5zOmNjPSJodHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9ucyMiCiAgICB4bWxu'
    b'czpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICAgeG1sbnM9Imh0dHA6Ly93'
    b'd3cudzMub3JnLzIwMDAvc3ZnIgogICAgeG1sOnNwYWNlPSJwcmVzZXJ2ZSIKICAgIGhlaWdo'
    b'dD0iNjAwIgogICAgd2lkdGg9IjFlMyIKICAgIHZlcnNpb249IjEuMCIKICAgIHZpZXdCb3g9'
    b'IjAgMCAxMDAwIDYwMCI+CjxyZWN0CiAgICBpZD0iV2Vpc3NlX0ZsYWVjaGUiCiAgICBoZWln'
    b'aHQ9IjMwMCIKICAgIHdpZHRoPSIxMDAwIgogICAgeT0iMzAwIgogICAgeD0iMCIKICAgIHN0'
    b'eWxlPSJmaWxsOiNmZmZmZmYiIC8+CjxyZWN0CiAgICBpZD0iUm90ZV9GbGFlY2hlIgogICAg'
    b'aGVpZ2h0PSIzMDAiCiAgICB3aWR0aD0iMTAwMCIKICAgIHk9IjAiCiAgICB4PSIwIgogICAg'
    b'c3R5bGU9ImZpbGw6I2U2MDAwMCIvPgo8cGF0aAogICAgaWQ9IlNjaGlsZGZsYWVjaGUiCiAg'
    b'ICBkPSJNIDM1MC40OSwxMjEuNjkgViAyNDguMyBDIDM1MC40OSwyOTAuNDcgMzQ3LjQ1LDMz'
    b'NC45OSAzNTYuNTcsMzY5LjExIDM2NS4xOSw0MDEuMzkgMzgzLjkxLDQyNy4wMSA0MDYuODgs'
    b'NDQ1LjY5IDQxOC40Myw0NTUuMDggNDMxLjIsNDYzIDQ0Ni45Nyw0NjguOTEgNDYyLjQ4LDQ3'
    b'NC43MyA0ODAuMTgsNDc5LjMxIDUwMC4zMyw0NzkuMTQgNTQwLjU4LDQ3OC43OSA1NzEuMTIs'
    b'NDYzLjk0IDU5My43Niw0NDUuNjkgNjE2Ljc1LDQyNy4xNyA2MzUuMjUsNDAwLjg5IDY0My41'
    b'MywzNjguNTYgNjUyLjMsMzM0LjI5IDY0OS42MSwyOTAuMSA2NDkuNjEsMjQ3Ljc1IFYgMTIw'
    b'Ljg2IEggMzUwLjc2IEMgMzUwLjQ0LDEyMC45IDM1MC40NiwxMjEuMjkgMzUwLjQ5LDEyMS42'
    b'OSBaIgogICAgc3R5bGU9ImZpbGw6I2ZmZmZmZiIgLz4KPHBhdGgKICAgIGlkPSJVbXJhbmR1'
    b'bmdfQWRsZXIiCiAgICBkPSJNIDUyMi45OSwxMzkuMSBDIDUzNC40LDE0My4yNyA1MjkuODYs'
    b'MTY0Ljg2IDUzOS4zLDE3MC4wNiA1MzcuOTIsMTcwLjggNTM1LjMzLDE3MC4zMyA1MzMuNzcs'
    b'MTcwLjg5IDUzMy44OCwxNzcuMjMgNTI5LjA0LDE4NC4yIDUyOS45MSwxOTAuNTIgNTMwLjIz'
    b'LDE5Mi45MSA1MzIuMTUsMTk0LjA3IDUzMi4zOSwxOTYuMDUgNTMwLjM0LDE5Ny45OCA1Mjcu'
    b'MTUsMTk2LjQzIDUyNC45MywxOTUuNSA1MjIuMTMsMTk5LjMxIDUxOS4zNSwyMDguMjUgNTIz'
    b'LjU1LDIxMi42NCA1MjAuNTcsMjEyLjMzIDUxOC43NiwyMTMuMTkgNTE3Ljc0LDIxNC44NSA1'
    b'MTYuNjIsMjIwLjAyIDUyMC44MywyMTkuNTEgNTIzLjU1LDIyMS40OCA1MjUuODIsMjIzLjE0'
    b'IDUyNi4zMSwyMjQuOTMgNTI3Ljk3LDIyNi40NiA1NTQuOTksMjI3IDU3Mi4zMiwyMDkuODQg'
    b'NTcxLjM3LDE4Mi4yMyA1NzAuNzgsMTgxLjE3IDU2OS4yOCwxODEuMDEgNTY4LjA2LDE4MC41'
    b'NyA1NjguNDEsMTg4LjAxIDU2Ny41MywxOTUuMTQgNTYzLjkxLDIwMC40NyA1NjEuOCwyMDMu'
    b'NTkgNTU2LjgyLDIwNy4xOSA1NTQuMjMsMjA4LjIxIDU1MC4yNCwyMDkuOCA1NDMuOTMsMjA5'
    b'LjQ0IDU0NS45NCwyMDMuMjQgNTUwLjkzLDIwMS41MSA1NTYuOCwyMDAuNjUgNTYwLjA0LDE5'
    b'Ny4xNiA1NjAuODMsMTk0LjU0IDU2Mi43NiwxOTIuNTcgNTYzLjYzLDE4OS40MiA1NjQuMzIs'
    b'MTg2Ljk0IDU2NS4zNSwxODIuMDkgNTY0LjQ2LDE3OS4xOSA1NjQuMDksMTc3Ljk3IDU1OS4y'
    b'OCwxNzQuMzYgNTU4LjExLDE3My4xIDU1NC45OSwxNjkuNzcgNTUxLjc1LDE2NS43MiA1NTIu'
    b'MywxNTguNDUgNTUyLjY2LDE1My42OSA1NTQuMzEsMTQ4LjkyIDU1Ny4yNywxNDYuMDEgNTYz'
    b'LjE0LDE0MC4yNiA1NzUuMiwxNDEuMjQgNTg2LjAzLDE0MC43NiA2MDAuNDIsMTQwLjEzIDYx'
    b'My42OSwxMzkuNzEgNjI1LjI4LDEzNi4zNCA2MjUuMzksMTUyLjc2IDYxMi43LDE1Ni4zNyA1'
    b'OTguNzQsMTU4LjczIDYwMC45LDE2MC41NiA2MDQuMTUsMTYxLjIyIDYwNy4wNCwxNjIuMDUg'
    b'NjE2LjY4LDE2NC44MSA2MjguMDEsMTY2LjE3IDYzOS42NiwxNjcuNTggNjM3LjI0LDE4MS42'
    b'NiA2MTkuOTEsMTg0Ljc2IDYwNC4yNywxODAuMjkgNjEzLjc2LDE5MS45MSA2MjYuNjYsMjAy'
    b'LjUxIDYzOS42NiwyMTEuNTMgNjM2Ljg3LDIxNC40NCA2MzMuMDMsMjE2LjE5IDYyOC4wNSwy'
    b'MTYuMjMgNjE2LjIzLDIxNi4zMiA2MDkuMDksMjA2LjUgNjAxLjUxLDIwMS44NiA2MTMuNzEs'
    b'MjI2LjYxIDYyNy4zOCwyNDkuODkgNjQyLjQyLDI3MS44IDYzMS41MSwyNzUuNTEgNjI0LjA0'
    b'LDI2Ny4xMiA2MTguMzcsMjYxLjAyIDYxNC45NiwyNTcuMzQgNjExLjQ5LDI1My42OSA2MDgu'
    b'NDIsMjQ5Ljk2IDYwMS42OSwyNDEuNzggNTk1Ljg5LDIzMi45OSA1ODkuOSwyMjYuNDYgNTk0'
    b'Ljc4LDIzNC42NyA2MDAuMjQsMjQzIDYwMy4xNywyNTMuNTUgNjA2LjA4LDI2NC4wNiA2MDcu'
    b'ODMsMjc1LjY5IDYxMC4wOCwyODcuMjggNjE0LjQsMzA5LjY0IDYyNSwzMjcuOTcgNjMxLjY0'
    b'LDM0Ny4yNyA2MjUuODUsMzQ2LjY4IDYxOS4zMiwzNDUuOTkgNjE1LjYxLDM0Mi44NSA2MTMu'
    b'MzYsMzQwLjk1IDYxMC43NywzMzYuOTkgNjA4LjY5LDMzNCA1OTQuMSwzMTMuMDEgNTg2LjU5'
    b'LDI4MS4yMSA1NzYuNjMsMjU2LjA0IDU3NS45MywyNjAuMDUgNTc2LjcxLDI2NC40MyA1NzYu'
    b'OSwyNjguNzYgNTc3LjIxLDI3NS40OCA1NzYuOTgsMjgyLjQ3IDU3Ny43MywyODguOTQgNTgw'
    b'LjMzLDMxMS4zNiA1ODQuMDQsMzMzLjQxIDU4OC4yNCwzNTIuOCA1NzEuMjMsMzUxLjUyIDU2'
    b'NC4xNCwzMzYuOTggNTU4LjkzLDMyMi42NyA1NTMuNTMsMzA3LjgxIDU1MC4wNiwyOTIuMjgg'
    b'NTUxLjE5LDI3My4xOCA1NDYuNiwyODQuNTQgNTQ5LjM0LDMwMy4yMiA1NDUuMTEsMzE0Ljkz'
    b'IDU0My41MSwzMTUuODEgNTQxLjQzLDMxNi4yMiA1MzguNzUsMzE2LjAzIDUyOS43NCwzMDcu'
    b'MTYgNTMxLjkyLDI4Ny4xIDUyOC44LDI3Mi4zNSA1MjQuNjgsMjg5LjMxIDUyNC40NiwzMDku'
    b'NjggNTMyLjY3LDMyMC43MyA1MzMuODIsMzIyLjI5IDUzNS40NywzMjMuOTEgNTM2LjI2LDMy'
    b'NS43MSA1MzguNCwzMzAuNTcgNTM3Ljc3LDMzNi4yNiA1NDAuNDEsMzQwLjY0IDU0Ny42Niwz'
    b'NTIuNjUgNTU0Ljc5LDM2Mi43MSA1NjEuNDIsMzc0LjA5IDU2Ni40NSwzNzUuOTcgNTY5Ljgs'
    b'MzczLjQ3IDU3MS4xLDM2OS45NCA1NzEuNjEsMzY4LjUzIDU3MS4yLDM2Ni41NiA1NzEuOTMs'
    b'MzY1LjI0IDU3Mi45NCwzNjMuMzkgNTc2LjUyLDM2My4yMSA1NzkuMTEsMzYxLjY1IDU4MC4x'
    b'OSwzNjEgNTgxLjQ2LDM1OS4xMSA1ODIuNzEsMzU4LjYxIDU4NS42OSwzNTcuNCA1ODkuNzIs'
    b'MzU4LjY5IDU5Mi4zOCwzNTkuNzEgNTkwLjA4LDM2MC4yNyA1ODYuOTIsMzU5Ljk2IDU4Ni4w'
    b'MiwzNjEuOTIgNTg2LjM0LDM2My45MiA1ODguMzYsMzYzLjMgNTg4LjUxLDM2NC45NyA1ODgu'
    b'ODQsMzY4LjY2IDU4MiwzNjkuMTEgNTc5LjM5LDM2Ny43MyA1NzguMTQsMzY4LjI4IDU3OS4z'
    b'MywzNzAuMDggNTc5LjM5LDM3MS4wNSA1NzcuODUsMzcyLjczIDU3NC45NiwzNzMuMDcgNTc0'
    b'Ljk3LDM3Ni4zIDU3OC4yNSwzNzcuOCA1ODEuOCwzNzYuMjMgNTg1LjIsMzc0LjY0IDU4Ni41'
    b'MywzNzQuMDIgNTg4LjE2LDM3Mi41OCA1ODkuNjIsMzcyLjcgNTkxLjE3LDM3Mi44NCA1OTIu'
    b'OTQsMzc1LjQzIDU5NC41OSwzNzYuMDIgNjAwLjgyLDM3OC4yNyA2MTAuNDIsMzc0LjIxIDYx'
    b'MS40NiwzODEgNjA5LjY1LDM4MC4wOSA2MDYuNTQsMzgwLjI4IDYwNS45MywzODIuMTEgNjA2'
    b'LjAyLDM4NC4xMSA2MDcuODcsMzg0LjE0IDYwNy41OSwzODUuOTcgNjA3LjI5LDM4Ny44OSA2'
    b'MDQuNzQsMzg4Ljc1IDYwMi4zMywzODcuOTEgNjAwLjQxLDM4Ny4yNCA1OTguNTMsMzgyLjky'
    b'IDU5NS40MiwzODIuOTQgNTgxLjc5MjU5LDM4NS4xNDgwNSA1NzAuOTM0ODUsMzgyLjUyMzE1'
    b'IDU4OS44OSwzOTMuOTkgNTkwLjc2LDM5NS40NCA1OTEuMDgsMzk3LjQyIDU5MS4yOCwzOTku'
    b'NTIgNTg5LjM2LDM5OS41IDU4OS43NSwzOTcuMTggNTg3LjY4LDM5Ny4zMSA1ODUuNjYsMzk4'
    b'LjI2IDU4Ni40Niw0MDAuNzYgNTg0LjY0LDQwMS40NiA1ODAuOTcsNDAyLjg3IDU3OS4xOSwz'
    b'OTQuNTYgNTc1LjI0LDM5NC4yNyA1NzUuMDMsMzkzLjE5IDU3NC4yMSwzOTIuNzIgNTczLjg2'
    b'LDM5MS43OCA1NzEuMTksMzkwLjMgNTY4LjE2LDM4OS4xOSA1NjUuODQsMzg3LjM2IDU1OS41'
    b'OCwzODYuMDQgNTU0LjgyLDM4Ni4wNCA1NDguMTUsMzg3LjA4IDU0Ni42NiwzODkuMjIgNTM5'
    b'LjE3LDM5MS40MiA1MzguMiwzODcuNjMgNTM3LjYxLDM4NS4zNCA1MzkuMzUsMzg1LjA0IDU0'
    b'MC4xMywzODMuMjEgNTM5Ljc4LDM4MC4yMyA1MzYuNjcsMzgyLjk3IDUzNi4yNiwzODIuMzgg'
    b'NTM5LjE3LDM3NS4wOSA1NDguNTYsMzgzLjEzIDU1NS4zNCwzNzkuNjIgNTQ4LjA3LDM2Ny4w'
    b'NyA1MzkuNSwzNTUuODMgNTMwLjE4LDM0NS4zMyA1MjkuNDMsMzQ2Ljg4IDUyOC4zOCwzNDgu'
    b'MTQgNTI1Ljc2LDM0Ny44MiA1MjUuMDUsMzQ4LjQ5IDUyNS4yOCwzNTAuMSA1MjQuMSwzNTAu'
    b'MzEgNTE3LjU1LDM0OS41NyA1MTkuMTksMzM5LjIgNTE3Ljc0LDMzMy4xNyA1MTcuNDksMzMy'
    b'LjE0IDUxNi43NSwzMjguNjcgNTE1LjI1LDMyOC40NyA1MTIuMjksMzI4LjA5IDUxMS4zOCwz'
    b'MzcuODQgNTExLjM4LDMzOS44MSA1MTEuMzgsMzQ2LjUzIDUxMy4xOSwzNTcuMTYgNTIwLjIz'
    b'LDM1OS45OSA1MjcuMjQsMzYyLjggNTM2LjA4LDM1OS4xOCA1MzkuNTgsMzY0LjQxIDU0MC41'
    b'MSwzNjUuOCA1NDEuMSwzNjkuMDcgNTQyLjA3LDM3MC43NyA1NDMuMzIsMzcyLjk3IDU0Ny4w'
    b'OCwzNzYuMjcgNTQxLjc5LDM3Ni44NSA1MzkuNzYsMzc3LjA4IDUzOC43OSwzNzUuNTYgNTM2'
    b'LjgyLDM3NS4xOSA1MzEuMTMsMzc0LjEyIDUyMi4zOCwzNzYuNzUgNTE2LjkxLDM3NC42NCA1'
    b'MTQuOSwzNzMuODYgNTE0LjE3LDM3Mi40OCA1MTIuNDksMzcxLjMzIDUxMi45NCwzNzYuMDgg'
    b'NTE1LjE2LDM4MC43NiA1MTcuNDYsMzg0LjMyIDUxOS43MiwzODcuODEgNTIyLjkyLDM5MS4z'
    b'OCA1MjcuMTQsMzkzLjE2IDUzMy44LDM5NS45OCA1NDIuMDIsMzk2LjQgNTQ5LjUzLDM5Ny44'
    b'NiA1NjQuNSw0MDAuNzggNTc3Ljc3LDQwNS4yOSA1NzguMjgsNDIyLjc0IDU3OC43Myw0Mzcu'
    b'NjggNTY1LjI5LDQ0OS4xIDU1MC4zNiw0NDEuODIgNTYwLjcxLDQ0MS42MSA1NjkuODEsNDM2'
    b'LjA0IDU3MC4yNyw0MjUuNzggNTcwLjcxLDQxNS44NyA1NjIuNTgsNDA5LjMxIDU1My45Niw0'
    b'MDcuODEgNTU1LjM2LDQxMy4zNyA1NjQuNDYsNDE2LjQ2IDU2NS41Nyw0MjMuMyA1NjUuOTcs'
    b'NDI1Ljc3IDU2NC44NSw0MzAuMzkgNTYxLjcsNDI5LjkzIDU1OS40Niw0MjkuNiA1NTcuMzYs'
    b'NDI1Ljk1IDU1NS4zNCw0MjQuMTMgNTQ5LjA0LDQxOC40MiA1NDAuMzksNDE0LjMyIDUzMi42'
    b'Nyw0MTAuNTggNTI2LjkzLDQwNy43OSA1MjEuMzYsNDA1LjA3IDUxNy40Niw0MDEuNzMgNTEz'
    b'LjAzLDM5Ny45NCA1MTAuMzksMzkyLjE5IDUwNy4yNCwzODcuOTEgNTA4LjkzLDM5Ny42IDUx'
    b'MC40MSw0MDYuNSA1MTguMjksNDExLjY5IDUyMi4zNyw0MTQuMzYgNTMwLjU3LDQxNS4zOSA1'
    b'MzQuNiw0MTguMDQgNTM3LjUyLDQxOS45NiA1NDAuMjYsNDIzLjYzIDUzNi44Miw0MjYuODkg'
    b'NTQwLjU2LDQzMC44OCA1NDUuNDEsNDMzLjc4IDU1MC45Miw0MzYuMDEgNTI2LjQ0LDQzNi42'
    b'MiA1MTUuMDMsNDIxLjc3IDUwNC43NSw0MDcuMjYgNTAzLjA1LDQxOS40MiA1MDQuODksNDMx'
    b'LjM2IDUwOS40NSw0MzkuMDUgNTEwLjk5LDQ0MS42NSA1MTMuNjksNDQ0LjAxIDUxNC40Myw0'
    b'NDYuMjQgNTE1LjkyLDQ1MC43NiA1MTMuMDUsNDU3LjM4IDUwNy4yNCw0NTUuOTIgNTA0Ljgx'
    b'LDQ1OS44NSA1MDIuMzgsNDYzLjc3IDUwMC4zMyw0NjguMDggNDk3LjMxLDQ2NC4zNyA0OTUu'
    b'MzEsNDU5LjY0IDQ5Mi4zMSw0NTUuOTIgNDg3Ljg2LDQ1Ni4zNyA0ODQuOTYsNDUzLjIgNDg1'
    b'LjY3LDQ0OC4xOCA0ODYuNCw0NDMuMDcgNDkxLjk3LDQzOS40NyA0OTMuNjksNDMzLjI1IDQ5'
    b'Ni4yNiw0MjMuOTQgNDk1LjUyLDQxNS4xMSA0OTYuMTgsNDA1LjA1IDQ5NC4yLDQwNi40MSA0'
    b'OTMuMzMsNDA4Ljc2IDQ5Mi4wMyw0MTAuNTggNDgzLjEyLDQyMy4wMyA0NzAuNDksNDMzLjU0'
    b'IDQ0OS43NCw0MzQuNjMgNDU0LjgyLDQzMS44OCA0NjAuMzMsNDI5LjU1IDQ2My44Myw0MjUu'
    b'MjMgNDYyLjIsNDIzLjExIDQ2MC43OCw0MTkuOTMgNDYzLDQxNy40OSA0NzAuNzUsNDEyLjky'
    b'IDQ4Mi41OCw0MTQuMTcgNDg2Ljc4LDQwNi40MyA0ODkuMzgsNDAxLjY1IDQ5MC45NCwzOTQu'
    b'OTIgNDkyLjAzLDM4Ny45MSA0ODkuMzYsMzkxLjkyIDQ4NS44MSwzOTYuOTEgNDgxLjUzLDQw'
    b'MC42MyA0NzMuMzIsNDA3Ljc1IDQ2MC43NCw0MTAuOTcgNDUxLjEyLDQxNy43NyA0NDkuMjEs'
    b'NDE5LjExIDQ0Ni45Miw0MjAuOTIgNDQ0LjQ4LDQyMy4wMiA0NDIuMSw0MjUuMDYgNDM2Ljc0'
    b'LDQzMi40NiA0MzUuMzYsNDI1LjIzIDQzMy4zOCw0MTQuODEgNDQ1LjE1LDQxMS42OSA0NDcu'
    b'OCw0MDQuNzcgNDM4Ljc0LDQwNS4xMiA0MjkuMzIsNDE0Ljg3IDQzMS43Nyw0MjUuNTEgNDMz'
    b'LjU5LDQzMy40MiA0NDAuNjUsNDM4LjcyIDQ1MC4yOSw0MzkuMzMgNDQwLjIzLDQ0NC40NSA0'
    b'MjguNzMsNDM4LjY2IDQyNC41OCw0MzEuMzEgNDE5LjUzLDQyMC4zNyA0MjQuMzcsNDA3Ljcg'
    b'NDMwLjk0LDQwMi41NiA0NDMuMDgsMzkzLjA1IDQ2OC4zOSwzOTguODQgNDc5LjU5LDM4Ny42'
    b'MyA0ODMuMzIsMzgzLjkgNDg0LjgyLDM3OS4yOSA0ODYuNzgsMzczLjI2IDQ4My40NCwzNzQu'
    b'NDcgNDc3Ljg1LDM3Ni41NiA0NzIuMTMsMzc2LjMgNDcwLjIyLDM3Ni4yMSA0NjguMTYsMzc1'
    b'LjI0IDQ2Ni4zMiwzNzUuNDcgNDYzLjEsMzc1Ljg3IDQ2MC41MiwzNzkuNDUgNDU3Ljc1LDM3'
    b'Ny4xMyA0NTkuMzEsMzc0Ljk5IDQ1OS45NywzNzMuMTUgNDYwLjc5LDM3MS4wNCA0NjIuMDMs'
    b'MzY3Ljg3IDQ2Mi4zNSwzNjMuOTcgNDY1LjQ5LDM2Mi40OCA0NzEuNDQsMzU5LjY1IDQ4Mi42'
    b'MywzNjIuNTUgNDg2LjUsMzU2LjM5IDQ4OC41OSwzNTMuMDcgNDg5LjUzLDM0NC45NyA0ODku'
    b'MjcsMzM4Ljk3IDQ4OS4wOSwzMzUgNDg5LDMyOC4xMyA0ODYuNSwzMjcuOTIgNDg1LjQyLDMy'
    b'Ny44MiA0ODQuMTYsMzI5LjI1IDQ4My43NCwzMzAuMTMgNDgyLjA2LDMzMy42NSA0ODIuNDQs'
    b'MzM4Ljk2IDQ4MC45NywzNDMuMTIgNDc5LjkzLDM0Ni4wOCA0NzguMjIsMzQ4LjMxIDQ3Ni4y'
    b'NywzNTAuMDMgNDc0LjI0LDM0OS40OSA0NzEuNzksMzQ5LjM1IDQ3MC43NSwzNDcuODIgNDYx'
    b'LjYxLDM1OC41OSA0NTIuMzMsMzY5LjIyIDQ0My4zOCwzODAuMTcgNDQ5LjAxLDM4Mi44IDQ1'
    b'Ny4zOSwzNzcuMDkgNDYxLjYyLDM4MS4yOCA0NjAuNjEsMzgyLjY1IDQ1OC41MiwzODIuOTYg'
    b'NDU3LjIsMzg0LjA0IDQ1Ny40NywzODYuMDkgNDU5LjM2LDM4NS41OCA0NTguODYsMzg3LjYz'
    b'IDQ1OC4xNywzOTAuNDQgNDUxLjcyLDM4OS40NyA0NTAuNTYsMzg3LjM1IDQ0NS40NywzODgu'
    b'MDUgNDQxLjYyLDM4NS4yIDQzNy4wMiwzODYuOCA0MzQuMTgsMzg3Ljc5IDQzMi41LDM5MS4z'
    b'NiA0MjkuMjgsMzkxLjc4IDQyOC4wOSwzOTYuNTggNDIxLjQ2LDM5Ni40NyA0MTkuMzIsNDAw'
    b'LjM1IDQxOC4xNiw0MDIuNDYgNDE5LjAzLDQwNS4yMiA0MTcuMTEsNDA3LjI2IDQxNS42OSw0'
    b'MDcuNTcgNDE0LjUsNDA4LjM3IDQxMi45Nyw0MDcuODEgNDExLjg2LDQwNy4zNiA0MTIuMzgs'
    b'NDA1LjI3IDQxMS44Niw0MDQuMjIgNDA5LjYsNDA0LjM1IDQwOS4wMiw0MDYuMTcgNDA4LjU0'
    b'LDQwOC4wOSA0MDcuMSw0MDUuNjYgNDA3LjkxLDQwMS42NSA0MDkuMSwzOTkuNTIgNDA5Ljg2'
    b'LDM5OS4wOCA0MTAuNzIsMzk4Ljc1IDQxMS41OCwzOTguNDEgNDE0LjgsMzkyLjIyIDQyMy42'
    b'NiwzOTEuNjkgNDI1LjY4LDM4NC4zMSA0MjMuMDEsMzgzLjg0IDQxOS43NiwzODEuODEgNDE2'
    b'Ljg0LDM4Mi4zOCA0MTUuNTUsMzgyLjYzIDQxNS4yNSwzODMuOTMgNDE0LjA3LDM4NC4wNCA0'
    b'MTIuNTcsMzg0LjE4IDQxMS44MSwzODIuNzQgNDEwLjQ4LDM4Mi42NSA0MDkuMTYsMzgyLjU3'
    b'IDQwNi4zOCwzODMuODYgNDA1LjUsMzg0LjU5IDQwNC4wNiwzODUuNzkgNDA0LjEzLDM4OC4y'
    b'NiA0MDIuNDYsMzg5LjU2IDQwMC43NCwzOTAuMzcgMzk3LjksMzkwLjE3IDM5Ni4zOCwzODku'
    b'MjkgMzk1LjI2LDM4OC4wNSAzOTYuNzEsMzg1LjkzIDM5NS41NSwzODQuODYgMzk0LjE0LDM4'
    b'My42NyAzOTMsMzg2LjI4IDM5Mi4yMywzODUuNjkgMzkyLjA4LDM3OS4wNCA0MDAuMSwzODAu'
    b'MjQgNDA2LjA1LDM3Ny40IDQwNy42NywzNzYuNjMgNDA5LjU3LDM3NC40MiA0MTEuMzEsMzc0'
    b'LjA4IDQxNi4yNCwzNzMuMTMgNDIxLjE0LDM3Ny41MSA0MjUuNjgsMzc3Ljk2IDQyNy43Mywz'
    b'NzMuNzYgNDIyLjc3LDM3Mi4xIDQyMS41MywzNjkuMzggNDE2Ljg4LDM2OC4zNCA0MTMuOTUs'
    b'MzY5LjU4IDQwOS42NSwzNjkuMTEgNDA4LjM3LDM2Ny4zIDQwOS42MywzNjUuMTUgNDEwLjQ4'
    b'LDM2My44NiA0MDkuNTcsMzYyLjI3IDQwNy4wNSwzNjEuMTQgNDA0LjY3LDM2MS45MiA0MDYu'
    b'MSwzNjAuMzMgNDA4LjE5LDM1OC43OCA0MTAuMiwzNTguODggNDExLjYsMzU4Ljk1IDQxMi42'
    b'OCwzNjAuNDMgNDE0LjA3LDM2MS4wOSA0MTguMjIsMzYzLjA2IDQyNC4yMiwzNjQuMTcgNDI4'
    b'LjQ1LDM2NS4yNCA0MzAuNTUsMzY2LjcyIDQzMS4wOCwzNzYuODYgNDM0LjgsMzc2Ljg1IDQz'
    b'Ni42OSwzNzYuODQgNDQxLjE2LDM3MC4yNSA0NDIuMjcsMzY4LjgzIDQ0OC44NSwzNjAuNDMg'
    b'NDU1Ljg2LDM1MC4xNCA0NjEuNjIsMzQyLjU3IDQ1OC42MiwzMzYuNCA0NjMuNDksMzMyLjQ4'
    b'IDQ2Ni4wNCwzMjkuMDIgNDcwLjMxLDMyMy4yNSA0NzMuOTMsMzE1Ljc4IDQ3NC42MSwzMDUu'
    b'OCA0NzQuOTgsMzAwLjQ0IDQ3My42NSwyOTUuMTEgNDcyLjY4LDI5MC4wNCA0NzEuMjEsMjgy'
    b'LjQxIDQ3MS4zNiwyNzYuMzEgNDY5LjY0LDI2OC4yIDQ2Ni42NCwyODMuMjYgNDY5Ljc1LDMw'
    b'NC40NCA0NjIuNzMsMzE1LjQ4IDQ1My4wNywzMjEuMTEgNDUxLjYsMzA2IDQ1MC44NCwyOTcu'
    b'NSA0NTAuMDIsMjg4LjM0IDQ0OS43MiwyNzkuOTIgNDQ3LjUyLDI3NC4yOCA0NDguNzIsMjk1'
    b'LjYgNDQ1LjIsMzEzIDQzOC45NSwzMjkuNTggNDM0LjI2LDM0Mi4wMSA0MjguNDcsMzUzLjUx'
    b'IDQxMi45NiwzNTQuNzMgNDE3Ljk2LDMyNC43MSA0MjIuMTQsMjkyLjM5IDQyMS41MywyNTcu'
    b'NyA0MTkuMDMsMjYzIDQxNy4zMiwyNjguOTcgNDE1LjQ1LDI3NC44NCA0MTAuMzcsMjkwLjc4'
    b'IDQwNS44MywzMDcuMjIgMzk5LjE0LDMyMi4xMiAzOTguNzIsMzIzLjA1IDM5OC41NywzMjQu'
    b'OTMgMzk3LjIxLDMyNS4xNiAzOTQuMjIsMzMzLjI1IDM4OC42LDM0NC4yNyAzODAuNjIsMzQ4'
    b'LjY1IDM3Ny45MSwzNTAuMTQgMzc0LjEzLDM1MS4yIDM2OS4yOCwzNTAuODcgMzc1LjE2LDMz'
    b'MS43NyAzODUuNjIsMzEzLjc3IDM4OC45MSwyOTEuNDMgMzkwLjY3LDI3OS41MiAzOTEuODcs'
    b'MjY4LjA2IDM5NC40NCwyNTcuNDIgMzk2Ljk5LDI0Ni45IDQwMC43OCwyMzguMDkgNDA2LjA1'
    b'LDIyOS43OCAzOTYuMzUsMjQxLjM1IDM4Ny44LDI1Ny40IDM3NS45MiwyNjguNDggMzcxLjYy'
    b'LDI3Mi41IDM2NC45NCwyNzguMjQgMzU3LjY4LDI3Ni41IDM2OS41MywyNTIuMjMgMzgzLjI3'
    b'LDIyOS44NSAzOTQuMTcsMjA0LjYyIDM4NS45OSwyMTEuMjMgMzcxLjYxLDIyNi41OCAzNTgu'
    b'NzgsMjE1Ljk2IDM2OC45OCwyMDQuNDEgMzgxLjgxLDE5NS40OSAzOTAuODUsMTgyLjc4IDM3'
    b'Ny4yNCwxODcuNTkgMzU5LjI2LDE4Ni44NCAzNTcuOTUsMTcxLjE3IDM3MS41OCwxNjkuMjMg'
    b'Mzg0LjE2LDE2Ni4yMyAzOTUuMjcsMTYxLjc3IDM5My45MSwxNjAuNCAzOTEuNjksMTYwLjY1'
    b'IDM5MC4wMiwxNjAuMzkgMzc4LjQ2LDE1OC42MSAzNjguNjYsMTUzLjczIDM2OC43MywxMzku'
    b'OTMgMzg0LjM5LDE0NC41NiA0MDUuNTksMTQxLjI1IDQyMy43NSwxNDIuNjkgNDM2LjE1LDE0'
    b'My42OSA0NDIuNDgsMTUxLjggNDQxLjcyLDE2My4xNSA0NDEuMTIsMTcyLjEgNDM1LjQsMTc0'
    b'Ljg1IDQzMC4zOCwxODAuMjkgNDI5LjkyLDE4OS4xOSA0MzMuNCwxOTcuNjEgNDM4LjY4LDIw'
    b'MC43NSA0NDEuNjksMjAyLjU0IDQ0Ni4xOSwyMDEuNzIgNDQ5LjczLDIwMy43OSA0NTEuMTEs'
    b'MjA2LjMyIDQ0OS43MSwyMDkuMDEgNDQ4LjA4LDIxMC4xNSA0MzMuNjcsMjA4LjU0IDQyNS42'
    b'NCwxOTcuODUgNDI3LjM0LDE4MS45NSA0MjUuNDIsMTgxLjc4IDQyNC40MywxODIuNTQgNDIz'
    b'LjQ3LDE4My4zMyA0MjIuMDksMjA5LjEyIDQ0Mi40NywyMjguMTkgNDY2Ljg3LDIyNy4wMSA0'
    b'NzEuMzksMjI2LjggNDczLjcxLDIxOS41OSA0ODAuNywyMjEuNzYgNDgyLjEyLDIxOS44NyA0'
    b'ODEuMiwyMTUuNjMgNDgyLjYzLDIxMy43NCA0ODEuMjIsMjEyLjIxIDQ3Ny45NiwyMTIuNTIg'
    b'NDc1LjcyLDIxMS44MSA0ODMuNzUsMjExLjM4IDQ4NC44NywyMDYuMTYgNDg4Ljk5LDIwMC43'
    b'NSA0OTEuMDIsMTk4LjA4IDQ5My42MywxOTYuMTUgNDk1LjYyLDE5My4yOSA0OTAuNTIsMTkw'
    b'LjEgNDgyLjk5LDE5My44NSA0ODAuOTcsMTk2LjMzIDQ4Mi44LDE5MC4yNyA0ODcuODEsMTg4'
    b'LjUzIDQ5NC41MiwxODUuODIgNDk4LjczLDE4NC4xMiA1MDYuNiwxODEuNjMgNTAzLjM2LDE3'
    b'Ni4xNSA0OTguNzEsMTczLjQzIDQ5MS44OCwxNzIuODkgNDg2Ljc4LDE3MC42MiA0ODkuNTgs'
    b'MTY0LjA2IDUwNy44MSwxNzMuMDkgNTA4LjYyLDE2NS4zNiA1MDQuNiwxNjMuOTEgNDk4LjM0'
    b'LDE2NC4wNSA0OTMuNjksMTY0LjI2IDQ4OC4xMywxNjQuNSA0ODIuODQsMTY1LjIyIDQ3OC4y'
    b'MSwxNjYuNDcgNDcxLjE3LDE2OC4zNyA0NjUuOTQsMTczLjA1IDQ1OS4xMywxNzQuMjEgNDcy'
    b'LjExLDE2Ni42NyA0ODcuNzMsMTU2LjE4IDUwOC44OSwxNjEuMjIgNTA5LjcyLDE1My4yOSA0'
    b'OTkuMDgsMTUwLjMyIDQ5NC41MiwxNTUuMTQgNDg4Ljc2LDE1MC40NyA0NzguNjcsMTUwLjQy'
    b'IDQ3Ni41NSwxNTguMTggNDc2LjExLDE1OS41NSA0NzcuNjEsMTYwLjQxIDQ3Ny4xLDE2MC45'
    b'NCA0NzIuNjYsMTU3Ljk1IDQ3My42MywxNDkuMzggNDc3LjM4LDE0Ni4yOSA0NzguOTksMTQ0'
    b'Ljk2IDQ4MS40NCwxNDQuODQgNDgzLjQ2LDE0My41MiA0ODUuODIsMTQyIDQ4Ni40NiwxMzgu'
    b'MTkgNDkwLjY1LDE0MC4yMSA0OTIuNCwxMzkuMzIgNDkyLjQyLDEzNy44IDQ5My42OSwxMzYu'
    b'ODkgNTAyLjQ4LDEzMC41OCA1MTkuNDUsMTQxLjg1IDUyOC41MiwxMzQuNjggNTI5LjA2LDEz'
    b'NS4yNyA1MjcuMDUsMTM1LjkyIDUyNi4wMywxMzYuNjEgNTI0LjksMTM3LjM4IDUyMy42NCwx'
    b'MzguMzcgNTIyLjk5LDEzOS4xIFogTSA0MzIuMDQsMTk0LjM5IEMgMzk3LjM0NjY3LDQ2NC43'
    b'OTY2NyA0MTQuNjkzMzMsMzI5LjU5MzMzIDQzMi4wNCwxOTQuMzkgWiIKICAgIHN0eWxlPSJm'
    b'aWxsOiMwMDAwMDAiIC8+CjxwYXRoCiAgICBpZD0iVW1yYW5kdW5nX1NjaGlsZCIKICAgIGQ9'
    b'Ik0gMzUwLjc2LDEyMC44NiBIIDY0OS42MSBDIDY0OS42MSwxNjMuMiA2NDkuNiwyMDUuMjkg'
    b'NjQ5LjYxLDI0Ny43NSA2NDkuNjEsMjkwLjEgNjUyLjMsMzM0LjI5IDY0My41MywzNjguNTYg'
    b'NjM1LjI1LDQwMC44OSA2MTYuNzUsNDI3LjE3IDU5My43Niw0NDUuNjkgNTcxLjEyLDQ2My45'
    b'NCA1NDAuNTgsNDc4Ljc5IDUwMC4zMiw0NzkuMTQgNDgwLjE4LDQ3OS4zMSA0NjIuNDgsNDc0'
    b'LjczIDQ0Ni45Nyw0NjguOTEgNDMxLjIsNDYzIDQxOC40Myw0NTUuMDggNDA2Ljg4LDQ0NS42'
    b'OSAzODMuOTEsNDI3LjAxIDM2NS4xOSw0MDEuMzkgMzU2LjU3LDM2OS4xMSAzNDcuNDUsMzM0'
    b'Ljk5IDM1MC40OSwyOTAuNDcgMzUwLjQ5LDI0OC4zIFYgMTIxLjY5IEMgMzUwLjQ2LDEyMS4y'
    b'OSAzNTAuNDQsMTIwLjkgMzUwLjc2LDEyMC44NiBaIE0gMzUzLjUzLDEyNS4yOCBWIDI0OS42'
    b'OCBDIDM1My41MywyODAuNzUgMzUyLjQ4LDMxMy4zNyAzNTQuOTEsMzQxLjQ3IDM1NS43LDM1'
    b'MC42NiAzNTcuODQsMzU5LjA0IDM2MC4xNiwzNjcuNDUgMzY0LjczLDM4NC4wMiAzNzEuMTcs'
    b'Mzk3LjkgMzc4Ljk2LDQxMC44NiAzODIuODUsNDE3LjMzIDM4Ny44NCw0MjIuMTYgMzkzLjA2'
    b'LDQyNy43MiAzOTguMTksNDMzLjE3IDQwMy4yMiw0MzguNTQgNDA4LjgyLDQ0My4yIDQxOS43'
    b'Nyw0NTIuMzEgNDMzLjMzLDQ2MC4xIDQ0OC4zNSw0NjUuODcgNDYzLjQ3LDQ3MS42OSA0ODEu'
    b'MDUsNDc2LjEgNTAwLjMyLDQ3Ni4xIDUxOS43OCw0NzYuMSA1MzcuMDUsNDcxLjQ5IDU1Mi4w'
    b'Miw0NjUuNiA1NzUuNDgsNDU2LjM1IDU5MS45NSw0NDMuODYgNjA3LjMxLDQyNy43MiA2MTIu'
    b'NTgsNDIyLjE5IDYxNy40Nyw0MTcuMDMgNjIxLjQxLDQxMC41OCA2MjkuMTksMzk3LjgzIDYz'
    b'NS43NCwzODMuNDEgNjQwLjIxLDM2Ny4xOCA2NDkuMzMsMzM0LjA1IDY0Ni41NywyOTAuNTQg'
    b'NjQ2LjU3LDI0OS4xMyBWIDEyNC40NSBIIDM1My44MSBDIDM1My40OCwxMjQuNSAzNTMuNSwx'
    b'MjQuODkgMzUzLjUzLDEyNS4yOCBaIgogICAgc3R5bGU9ImZpbGw6IzAwMDAwMCIgLz4KPHBh'
    b'dGgKICAgIGlkPSJSb3Rlc19HZWZpZWRlciIKICAgIGQ9Ik0gNTY1LjU3LDE3OS43NCBDIDU2'
    b'Ny4wOCwxODEuNSA1NjcuNDMsMTg0LjYgNTY3LjIzLDE4Ny4yIDU2Ni4zNiwxOTguMDkgNTU5'
    b'LjU3LDIwNy4yNyA1NDguMTUsMjA3Ljk0IDU0Ny4xNiwyMDYuODUgNTQ2LjMyLDIwNS4wNCA1'
    b'NDcuMzIsMjAzLjc5IDU0OC4zMiwyMDIuNTUgNTUxLjIsMjAyLjkzIDU1Mi4zLDIwMi42OSA1'
    b'NjEuMjUsMjAwLjcyIDU2Ni43MSwxOTEuNjQgNTY1LjU3LDE3OS43NCBaIE0gNDMzLjk3LDIw'
    b'Mi40MSBDIDQzOCwyMDQuOTEgNDQxLjk5LDIxMC4xNCA0NDguNjMsMjA4LjIxIDQ1MS4xMiwy'
    b'MDIuNTMgNDQ0Ljk2LDIwNC4xMiA0NDEuMTYsMjAzLjI0IDQzNy44MSwyMDIuNDYgNDMzLjg3'
    b'LDE5OC4yMyA0MzIuMDQsMTk0LjM5IDQzMC4xMiwxOTAuMzcgNDI5LjU3LDE4Ni41MSA0Mjku'
    b'MjcsMTgxLjQgNDI2Ljc3LDE4OS4zMyA0MzAuNjYsMTk3LjU5IDQzMy45NywyMDIuNDEgWiBN'
    b'IDUxNy4xOSwxNDIuMTQgQyA1MTguNCwxNDQuOTkgNTIyLjI5LDE0NS4xNSA1MjQuOTMsMTQ2'
    b'LjU3IDUyNi4xNCwxNDcuNzQgNTI5LjA1LDE1MS4wOSA1MjkuOTEsMTUwLjcxIDUyOC45Miwx'
    b'NDQuNzkgNTIzLjIxLDEzNy45IDUxNy4xOSwxNDIuMTQgWiBNIDUxMC44MywxMzcuNzIgQyA1'
    b'MDQuNzksMTM5LjQyIDQ5Ny4xMSwxMzkuNDggNDk1LjA3LDE0NS4xOSA0OTIuNTMsMTQ1LjEx'
    b'IDQ5MS41OCwxNDMuMDEgNDkyLjAzLDE0MC43NiA0OTMuMTksMTM0LjkyIDUwNS4yMywxMzUu'
    b'OTMgNTEwLjgzLDEzNy43MiBaIE0gNjI3LjIyLDI1Ny45OCBDIDYyMC40NiwyNTEuMjggNjE0'
    b'LjU3LDI0Mi41NSA2MDguOTcsMjMyLjI3IDYwNS40MiwyMjUuNzQgNjAwLjU3LDIxOC41IDU5'
    b'Ni44MSwyMTEuNTMgNTk0Ljg1LDIwNy45MSA1OTMuMDUsMjAyLjM4IDU4OS4zNCwyMDYuMjgg'
    b'NTk0Ljc5LDIwOC42OCA1OTUuNTgsMjE3LjIyIDU4Ny42OCwyMTYuNzggNTg4Ljc1LDIxOS4x'
    b'MyA1OTEuMywyMjEuMTMgNTkwLjQ1LDIyNC41MiA1OTguNzcsMjM1LjE2IDYwOC4xOSwyNDgu'
    b'NTUgNjE3LjgyLDI1OC44IDYyMy44MiwyNjUuMjEgNjI5LjE4LDI3Mi43MyA2NDAuNzYsMjcx'
    b'LjggNjM5LjQzLDI2OC40NyA2MzYuOTksMjY1LjYgNjM0Ljk2LDI2Mi42OCA2MjAuMDEsMjQx'
    b'LjE2IDYwNy41MSwyMTYuODkgNTk0LjU5LDE5My41NiA1OTQsMTk0LjgxIDU5Mi43MSwxOTUu'
    b'MzcgNTkxLjI4LDE5NS43NyA1OTMuMzMsMTk3LjE3IDU5Ni4yNywxOTkuODcgNTk0LjMyLDIw'
    b'My41MiA2MDUsMjIyLjUxIDYxNi41NCwyNDIuMTEgNjI4LjMyLDI1OS4wOCA2MjguMzIsMjU4'
    b'LjggNjI4LjEsMjU4Ljc1IDYyOC4wNCwyNTguNTMgNjI3LjcyLDI1OC4zOSA2MjcuNDIsMjU4'
    b'LjI0IDYyNy4yMiwyNTcuOTggWiBNIDUyMC4yMywxMzguMjcgQyA1MTYuNDUsMTQzLjk1IDUw'
    b'My43MiwxMzkuMTIgNDk5Ljc3LDE0NC4zNSA1MDEuMzUsMTQ1LjQgNTAyLjA5LDE0Ny4yOSA1'
    b'MDQuMTksMTQ3LjY3IDUwNy4xOCwxNDguMjIgNTEwLjM3LDE0NS45NSA1MTMuMDQsMTQ1LjQ2'
    b'IDUxMi45MiwxNDQuMTEgNTEwLjQsMTQ1LjE2IDUxMC4yOCwxNDMuOCA1MTUuNTUsMTQwLjcy'
    b'IDUxOC43OCwxNDguMDcgNTI0LjM4LDE0OC4yMiA1MzEuMywxNTIuMzYgNTMxLjczLDE2Mi45'
    b'OSA1MzYuMjYsMTY5LjUxIDUzMi44LDE2OS4zOCA1MzIuNjQsMTY1Ljk0IDUzMC40NiwxNjQu'
    b'NTQgNTM0LjYxLDE3NS4xOSA1MjYuMTMsMTg2LjU3IDUyOS42MywxOTUuNzcgNTIyLjQxLDE5'
    b'NS4wOCA1MjYuMTUsMTg1LjI3IDUyNy42OSwxODEuMTIgNTI1Ljg1LDE4MS4yMiA1MjUuMTks'
    b'MTg0Ljg4IDUyNC4xLDE4Ni42NSA1MjQuODIsMTk1LjM3IDUxOC41MSwyMDAuNyA1MTkuOTUs'
    b'MjEwLjE1IDUxNy4yNywyMTIuMTYgNTE1LjMyLDIxNS4zMiA1MTYuNjMsMjE5LjgzIDUxNS41'
    b'MiwyMTkuNjQgNTE1LjA1LDIyMC4wOSA1MTQuMTQsMjIwLjEgNTE1LjcsMjE1LjIxIDUxNy42'
    b'LDIwNy40IDUxNC43LDIwMi42OSA1MTUuMTUsMjEwLjYxIDUxMy4zMSwyMTguMTIgNTEwLjI4'
    b'LDIyMy40MiA1MTcuODEsMjE5LjYzIDUyNC45OCwyMjMuMDggNTI3LjE0LDIyOS41IDUyOC4z'
    b'LDIzMi45NiA1MjguMzQsMjM4Ljc4IDUyOC41MiwyNDIuNzcgNTI5LjI1LDI1OC44NiA1MjUu'
    b'OTUsMjc1Ljk4IDUyNC4zNywyOTAuODcgNTIzLjkzLDI5NS4xIDUyMy42LDI5OC45NiA1MjMu'
    b'ODIsMzAyLjQ5IDUyNC41OCwzMTUuMDEgNTMzLjE3LDMyMC40MiA1MzUuOTgsMzMxLjI0IDUz'
    b'NC4xNywzMzEuNTMgNTMzLjMxLDMzMC4xOCA1MzEuODQsMzMwLjk2IDUzMC4xLDMzNS41OSA1'
    b'MjkuNTMsMzQxLjM3IDUyNy45NywzNDYuMTcgNTI2Ljg1LDM0Ny4wMSA1MjYuNjgsMzQ1IDUy'
    b'NS4yLDM0NS4zNCA1MjMuOTksMzQ1Ljc5IDUyNC4zMywzNDcuNzkgNTIzLjI3LDM0OC4zOCA1'
    b'MTkuNjYsMzQ2LjA5IDUyMC4wNSwzNDAuMjEgNTE5LjQsMzM1LjExIDUxOS4wNCwzMzIuMjkg'
    b'NTE4LjIzLDMyOS41NyA1MTguMDEsMzI3LjA5IDUxMS4xOSwzMjIuNjUgNTEwLjE4LDMzMy42'
    b'MSA1MTAsMzQwLjY0IDUwOS42NSwzNTQuMjggNTE0Ljc3LDM2MS44NSA1MjYuNTgsMzYzLjAz'
    b'IDUzMS42OCwzNjMuNTQgNTM2LjA2LDM2Mi4zMSA1MzguMiwzNjUuMjQgNTM4LjgsMzY2LjA4'
    b'IDUzOC42NywzNjcuMzkgNTM5LjAyLDM2OC4yOCA1MzkuOSwzNzAuNDcgNTQxLjc4LDM3Mi4w'
    b'NiA1NDEuNzksMzc0LjA5IDUzOC43NCwzNzMuOTggNTM2LjEyLDM3My4wMiA1MzIuOTQsMzcy'
    b'Ljk4IDUzMC4zMiwzNzIuOTYgNTI4LjExLDM3NC4wNiA1MjUuNzUsMzc0LjM2IDUxOC4zMywz'
    b'NzUuMzMgNTExLjMzLDM3MC4wOCA1MTAuMjgsMzYzLjU4IDUxNC45MSwzNjcuMSA1MjQuMDEs'
    b'MzcxLjQ4IDUzMS4yOCwzNjguMDEgNTMzLjE3LDM2OC4yNCA1MzMuNDksMzcwLjA1IDUzNS43'
    b'MSwzNjkuOTQgNTM0LjgxLDM2Ny42NyA1MjkuODEsMzYzLjM3IDUyNy4xNCwzNjcuNDYgNTE1'
    b'LjM1LDM2Ny43MiA1MDkuODksMzYxLjY3IDUwNi45NiwzNTMuMDggNTA2LjYyLDM2OC4xNiA1'
    b'MTIuNjYsMzc5LjI2IDUxOC41NywzODkuMDIgNTI5LjgzLDQwMi4wNyA1NjIuOTksMzk1LjA1'
    b'IDU3My4wMyw0MTAuMDMgNTc1LjU3LDQxMy44MiA1NzcuNDYsNDIwLjczIDU3Ni4zNSw0Mjcu'
    b'NDQgNTc0LjgsNDM2Ljc1IDU2OC43Nyw0NDIuMTYgNTU4LjEsNDQyLjkyIDU2NC43NSw0Mzgu'
    b'NjEgNTcyLjMyLDQzNS4xOCA1NzEuNjUsNDIzLjU3IDU3MS4wMSw0MTIuNTYgNTYwLjg0LDQw'
    b'Ny4wNyA1NTAuNjQsNDA0Ljc3IDU1MC40NCw0MTIuMDUgNTYxLjM5LDQxNS45NiA1NjMuNjMs'
    b'NDIyLjE5IDU2NC41MSw0MjQuNjMgNTY0LjQzLDQyNy42NCA1NjEuNjksNDI4LjI4IDU1OC45'
    b'Myw0MjYuNjYgNTU3LDQyMy45NyA1NTQuNTEsNDIxLjkxIDU0Ni45OSw0MTUuNyA1MzcuMjMs'
    b'NDExLjI1IDUyNy45Nyw0MDYuNDQgNTE1LjI1LDM5OS44MSA1MDcuNCwzOTAuMjIgNTA1LjAy'
    b'LDM3My4yNiA1MDQuMjksMzg2Ljc3IDUwNy4wOCw0MDAuOCA1MTMuMzIsNDA4LjkyIDUxOC4x'
    b'Niw0MTUuMjMgNTI3LjgxLDQxNC43MyA1MzQuNiw0MTkuNyA1MzUuODUsNDIwLjYxIDUzNy4x'
    b'Niw0MjEuOTUgNTM2LjgxLDQyNC4xMyA1MzYuMTYsNDI1LjA0IDUzNC4xMiw0MjQuNTcgNTMy'
    b'LjY3LDQyNC42OCA1MzQuNzgsNDI5LjM5IDU0MC4yMSw0MzAuNzcgNTQzLjQ1LDQzNC4zNiA1'
    b'MjIuMTgsNDMwLjkzIDUxMS41OCw0MTYuODMgNTAzLjA5LDQwMC42MyA1MDMuMDMsNDE0LjI2'
    b'IDUwMi4yMSw0MjguMzEgNTA2Ljk2LDQzNy40IDUwOC40LDQ0MC4xNiA1MTAuNTIsNDQyLjE5'
    b'IDUxMi4yMSw0NDUuNDIgNTEzLjI0LDQ0Ny4zOSA1MTMuMzIsNDUxLjY4IDUxMS45Myw0NTMu'
    b'NDMgNTEwLjEyLDQ1NC4zNyA1MDcuNTgsNDU0LjgzIDUwNS4wMiw0NTQuMjYgNTA0LjQzLDQ1'
    b'OC4yNyA1MDIuMzksNDYyLjMxIDUwMC4zMiw0NjMuOTQgNDk5LjIyLDQ2My40OSA0OTguMjQs'
    b'NDYxLjk5IDQ5Ny41Niw0NjAuOSA0OTYuMzgsNDU5LjAyIDQ5NS40NCw0NTcuMzcgNDk1LjM1'
    b'LDQ1NC4yNiA0ODkuNTIsNDU1Ljc3IDQ4NS42Myw0NTIuMzYgNDg3LjYsNDQ2LjggNDg4LjM5'
    b'LDQ0NC41OCA0OTAuNTcsNDQyLjkyIDQ5MS43NSw0NDAuNzEgNDk3LjE3LDQzMC42MiA0OTcu'
    b'NzYsNDE0Ljg2IDQ5Ny4wMSwzOTguOTcgNDg5LjA2LDQxNS4xNyA0NzcuNTksNDI3Ljg0IDQ1'
    b'OC4wMiw0MzIuNDIgNDYxLjE5LDQyOS41OSA0NjUuMjQsNDI3LjY1IDQ2Ny43LDQyNC4xMyA0'
    b'NjUuNzcsNDIzLjEzIDQ2My4xNCw0MjMuNTIgNDYzLjI4LDQyMC41MyA0NjMuNTQsNDE0Ljc3'
    b'IDQ3Ny44Myw0MTUuNjEgNDgyLjM1LDQxMy4wNyA0ODkuMSw0MDkuMjcgNDkyLjc3LDM5NS45'
    b'OSA0OTMuNjksMzg2LjgxIDQ5NC4xLDM4Mi42MiA0OTMuODcsMzc5LjIgNDkzLjk2LDM3NC4z'
    b'NiA0OTIuMjEsMzc4LjY0IDQ5MS44NywzODIuODggNDkwLjM3LDM4Ni41MyA0ODEuNSw0MDgu'
    b'MDIgNDUxLjQ1LDQwOS4wNSA0MzguMTIsNDI2LjYyIDQzNS42Nyw0MjUuMSA0MzYuOCw0MjAu'
    b'MSA0MzcuNTcsNDE4LjYgNDQwLjE5LDQxMy40NCA0NDkuNTksNDA5LjU2IDQ1MC44Myw0MDIu'
    b'NTYgNDQyLjM0LDQwMy41IDQzNC42LDQwNy44IDQzMS40OSw0MTQuNDUgNDI4LjYsNDIwLjYx'
    b'IDQzMC4yNSw0MjguNTEgNDM0LjI1LDQzMi45NyA0MzYuOTMsNDM1Ljk2IDQ0MC42Niw0Mzcu'
    b'MzMgNDQzLjM3LDQzOS44OCA0MzAuOTMsNDQwLjA0IDQyMi42Nyw0MzIuMDUgNDI0LjAyLDQx'
    b'OC44NyA0MjQuNjUsNDEyLjc0IDQyOC42LDQwNS42MyA0MzMuNDIsNDAyLjU2IDQzNy45OCwz'
    b'OTkuNjcgNDQ0LjY5LDM5OC41NyA0NTAuMjgsMzk3LjU4IDQ1Ny4wMywzOTYuMzkgNDY0LjQ3'
    b'LDM5Ny4xNSA0NzEuMjksMzk0LjgyIDQ4Mi40MiwzOTEuMDEgNDg3LjUyLDM3OC45NCA0OTAu'
    b'NjUsMzY3LjE4IDQ5MS43OSwzNjIuODUgNDkyLjk3LDM1OC44MyA0OTIuODYsMzUzLjA4IDQ4'
    b'OC44OSwzNjEuMDQgNDgxLjU5LDM2OC4wNSA0NjkuMzYsMzY1LjI0IDQ2Ny45LDM2Ni40NSA0'
    b'NjYuOTYsMzY4LjE5IDQ2Ni4wNCwzNjkuOTQgNDY3LjY4LDM2OS44MiA0NjcuOTEsMzY4LjMg'
    b'NDY5LjA4LDM2Ny43MyA0NzguMDksMzcxLjQ1IDQ4NS41NiwzNjQuNjUgNDg5LjgyLDM2MS4w'
    b'OSA0ODguMzksMzcwLjIgNDgyLjM4LDM3NS43NCA0NzIuNjgsMzc0LjM2IDQ3MS43NiwzNzQu'
    b'MjMgNDcwLjczLDM3My41NCA0NjkuNjQsMzczLjUzIDQ2NS44NCwzNzMuNDkgNDYzLjQ0LDM3'
    b'Ni43NSA0NTkuOTYsMzc2LjMgNDU5LjkyLDM3NC4yOCA0NjEuNDYsMzczLjc2IDQ2Mi4xNywz'
    b'NzIuMTUgNDYzLjYsMzY4LjkzIDQ2My4xOSwzNjQuNSA0NjcuMTUsMzYzLjMgNDY5LjcyLDM2'
    b'Mi41MyA0NzIuNDYsMzYzLjE5IDQ3NC42MSwzNjMuMDMgNDgwLjExLDM2Mi42MSA0ODUuOTUs'
    b'MzYwLjkgNDg4LjQzLDM1Ni42NyA0OTIuODUsMzQ5LjE2IDQ5MS41MywzMzYuMjggNDg4Ljk5'
    b'LDMyNi4yNiA0ODguNTIsMzI2LjI3IDQ4OC4yNywzMjYuMDUgNDg4LjE2LDMyNS43MSA0Nzcu'
    b'MzgsMzI0LjUyIDQ4My40NCwzNDUuODggNDc1LjcyLDM0OC4xIDQ3NC43NSwzNDcuNzggNDc1'
    b'LjUyLDM0NS43MiA0NzQuNjEsMzQ1LjMzIDQ3Mi45MiwzNDUuMjEgNDczLjk0LDM0Ny43OSA0'
    b'NzIuNCwzNDcuODIgNDY5LjkyLDM0NS40IDQ3My4zMSwzNDAuMjEgNDY5LjM2LDMzOS44MSA0'
    b'NjYuODMsMzM5LjU0IDQ2Ni4yNCwzNDMuMDcgNDYyLjczLDM0MS40NiA0NjEuNTUsMzMzLjQ5'
    b'IDQ2Ny41NCwzMjguODEgNDcxLjAyLDMyMy4yMiA0NzMuNTIsMzE5LjIxIDQ3NS44NSwzMTUu'
    b'MDcgNDc2LjI3LDMwOC44NCA0NzcuNzksMjg2LjU3IDQ2Ni45NSwyNjYuMzMgNDY4LjUzLDI0'
    b'MC44MyA0NjguODgsMjM1LjE2IDQ3MC4yOCwyMzEuMTcgNDcxLjg1LDIyNS45MSA0NzQuNTgs'
    b'MjI0LjIxIDQ3Ny40NSwyMjIuNjYgNDgyLjM1LDIyMy4xNCA0ODMuMjcsMjIwLjA5IDQ4My40'
    b'MywyMTYuMyA0ODQuNTcsMjEzLjQ3IDQ4Ni42MiwyMTIuMzkgNDkwLjY4LDIxMy4zMiA0OTIu'
    b'NTgsMjEyLjA4IDQ5MC4yNywyMTAuODkgNDg1LjcxLDIxMS45NSA0ODIuOTEsMjExLjI2IDQ4'
    b'NS44MywyMDkuMjkgNDkwLjE2LDIwOC43MyA0OTQuMjQsMjA3Ljk0IDQ5My4wNSwyMDYuMzYg'
    b'NDg5LjIzLDIwNy40MiA0ODYuNzgsMjA3LjExIDQ5MC43OCwyMDAuOTggNDk0LjE3LDE5NC4y'
    b'MiA1MDEuOTgsMTkxLjkgNDk3LjkxLDE5MC42MyA0OTEuNDksMTkxLjcgNDg2LjUsMTkxLjM1'
    b'IDQ5MC41MywxODQuNjkgNTA0LjI0LDE4Ny43MSA1MDYuNDEsMTc5LjE5IDUwNi44MSwxNzcu'
    b'NzUgNTA1Ljg0LDE3NC45NCA1MDcuNzksMTc1LjA0IDUwOC4yLDE3Ni43NyA1MDYuMzEsMTgw'
    b'LjkyIDUwNS44NSwxODMuNjEgNTA5LjY4LDE4Mi42NSA1MDkuMDQsMTc0LjgyIDUxMy4wNCwx'
    b'NzMuMSA1MTMuNzEsMTc0LjY1IDUxMy4yOSwxNzcuMjcgNTEzLjg3LDE3OC45MSA1MTUuMTcs'
    b'MTc0Ljc2IDUxNS45OCwxNjguNjkgNTE5LjEyLDE2Ny4zIDUyMCwxNjkuNjIgNTE4LjUyLDE3'
    b'MS41NyA1MTguNTcsMTczLjkzIDUyMy4zNiwxNjkuNzYgNTIwLjIzLDE1OC42MyA1MTcuNDYs'
    b'MTU1LjY5IDUxOC45NCwxNTUuMjMgNTIxLjA1LDE1NS40IDUyMi40NCwxNTQuODYgNTE1LjI5'
    b'LDE1NC4zIDUwOS44NCwxNDkuMjUgNTAzLjA5LDE0OC4yMiA1MDAuMywxNDcuOCA0OTguOTIs'
    b'MTQ3LjU4IDQ5Ny4wMSwxNDYuMDEgNDk4LjI1LDE0MC44MiA1MDUuMDMsMTQxLjM0IDUxMCwx'
    b'MzkuOTMgNTExLjEyLDEzOS42MSA1MTIuMiwxMzguNSA1MTMuMzIsMTM4LjI3IDUxNS42Niwx'
    b'MzcuNzkgNTE4LjEzLDEzOC42NCA1MjAuMjMsMTM4LjI3IFogTSAzNzAuNjcsMTQxLjg3IEMg'
    b'MzgxLjI4LDE0NC4yIDM5My40NSwxNDQuOTQgNDA2Ljg4LDE0NC4zNSA0MTcuMDYsMTQzLjkx'
    b'IDQyNy4wNywxNDQuMTUgNDM0LjUzLDE0Ny42NyA0MzguNjMsMTUxLjUzIDQ0Mi4yNywxNjAu'
    b'MzcgNDM5LjIzLDE2Ny44NSA0MzguOCwxNjQuNjIgNDM5LjUzLDE1OC4zMyA0MzUuOTEsMTU2'
    b'LjggNDM3LjQxLDE2MS44NyA0MzcuNDEsMTY4Ljg3IDQzNC44LDE3My4xMSA0MzEuOTIsMTc3'
    b'Ljc5IDQyNS4wMywxNzkuMTQgNDIwLjcxLDE4MS45NSA0MjAuNTQsMTgzLjA0IDQyMi4yMiwx'
    b'ODIuMjggNDIxLjgxLDE4My42MSA0MjMuNDksMjEyLjI1IDQzOC43MiwyMjcuMzMgNDY3Ljcs'
    b'MjI4LjY3IDQ2Ny45LDIzMC4xNiA0NjcuNDgsMjMxLjAzIDQ2Ny4xNSwyMzEuOTkgNDUwLjgz'
    b'LDIzMi4xNCA0MzguOSwyMjcuMSA0MzAuNjYsMjE3LjYyIDQyMi40MSwyMDguMTIgNDE3LjU0'
    b'LDE5Mi4zOCA0MjAuMTUsMTc2LjcgNDI5Ljg4LDE3OS41OSA0MzEuMTksMTY1LjY3IDQyMi4z'
    b'NiwxNjYuNDcgNDI2LjMzLDE1OC43MSA0MTQuMDIsMTU1LjIgNDEyLjE0LDE2MS43NyA0MTIu'
    b'NDgsMTYzLjM2IDQxMi44MywxNjQuOTQgNDEzLjI0LDE2Ni40NyA0MDQuNDksMTY0LjU4IDQw'
    b'Ni4xOSwxNzkgNDE0LjA3LDE3Ni43IDQxMy43MSwyMTYuMjMgNDMxLjcyLDIzNy4zOCA0NjYu'
    b'MzIsMjQxLjk0IDQ2OC40MiwyNTMuODMgNDY4LjksMjY4LjUyIDQ2Ny43LDI4Mi44NiA0Njcu'
    b'MDcsMjkwLjQgNDY2Ljc1LDI5OC4wMiA0NjYuMDQsMzAzLjg3IDQ2NS40MiwzMDkuMDEgNDYz'
    b'LjI0LDMxNy42MyA0NTYuOTIsMzE0LjkzIDQ1Mi42OCwzMDguNzggNDUyLjI3LDI5OS4xOCA0'
    b'NTEuMzksMjkwLjA1IDQ1MC41LDI4MC43MyA0NDkuMzcsMjcxLjUxIDQ0Ni42OSwyNjQuMzQg'
    b'NDQ3LjQ5LDI5Ni4xIDQ0Mi45LDMzMS4xOCA0MjcuMDYsMzQ3LjI3IDQyNC4zMSwzNTAuMDcg'
    b'NDIwLjE1LDM1Mi4xMiA0MTUuMTgsMzUyLjI1IDQyMC42MiwzMjAuOTQgNDI0LjQ5LDI4Ni44'
    b'NCA0MjMuMTksMjQ5LjY4IDQyNy40NSwyNTIuNjQgNDMxLjcxLDI0OS4zIDQzMy43LDI0Ni4w'
    b'OSA0MzUuMjUsMjU2LjEgNDMyLjY5LDI2NS40NyA0MzEuNzYsMjc1LjEyIDQyOS45MSwyOTQu'
    b'NDcgNDI5LjY0LDMxNC43NCA0MjUuNjgsMzMyLjM0IDQyNy45NSwzMzAuNDggNDI3Ljg4LDMy'
    b'Ny4xNSA0MjguNDUsMzI0LjMzIDQzMi40MSwzMDQuNTEgNDMyLjUyLDI3OC4yNCA0MzUuNjMs'
    b'MjU3LjE1IDQzNy44MiwyNTguNTMgNDQwLjMyLDI1OC41OCA0NDIuNTQsMjU3LjcgNDQ0Ljcz'
    b'LDI1Ni44MyA0NDUuNiwyNTQuNjYgNDQ2Ljk3LDI1NC4zOCA0NDcuNDgsMjU5LjQ0IDQ0OS40'
    b'NSwyNjQuMDYgNDU1LjgxLDI2Mi40IDQ1OS4xMywyNzMuMDIgNDU1LjcyLDI5Mi4xMyA0NTYu'
    b'OTIsMzA1LjI1IDQ1OS4xNiwyOTIuOTcgNDYwLjYsMjc0LjI3IDQ1Ny4yLDI2Mi4xMiA0NjAu'
    b'MjgsMjU4LjE3IDQ2NS4yNiwyNTMuMjcgNDYzLjU1LDI0Ni4zNiA0NjAuNDMsMjUxLjcgNDYw'
    b'LjE2LDI2Mi41OSA0NTAuODQsMjU5LjkxIDQ1MC4wMiwyNTguMDggNDQ5LjEyLDI1Ni40OCA0'
    b'NDguOSwyNTQuMTEgNDQ4LjUyLDI0OS44OCA0NTEuNzEsMjQ0Ljc5IDQ0OC42MywyNDMuMDUg'
    b'NDQ2Ljk3LDI0Ni4yMiA0NDYuNjgsMjUyLjIzIDQ0My45MywyNTQuNjYgNDM4LjQxLDI1OS41'
    b'MyA0MzUuNDEsMjUzLjIgNDM1LjkxLDI0Ni42NCA0MzYuMTcsMjQzLjE4IDQzOC4zMSwyMzgu'
    b'OTggNDM1LjkxLDIzNy44IDQzMi44OCwyNDEuMDIgNDMyLjM3LDI0OS4yOSA0MjYuMjMsMjQ4'
    b'LjU4IDQyMy45NCwyNDguMzEgNDIyLjc4LDI0Ni4wNSA0MjMuMTksMjQyLjc3IDQyMy43NSwy'
    b'MzguNDEgNDI4LDIzNCA0MjcuMzQsMjMxLjQ0IDQyNS4xLDIzMS43NCA0MjQuMTQsMjM0Ljc5'
    b'IDQyMi4wOSwyMzYuNDEgNDIwLjMzLDIzNy44MSA0MTguMDMsMjM4Ljg4IDQxNC45LDIzOC4w'
    b'NyA0MTIuOTMsMjM1LjAzIDQxNS4wNywyMzIuNDQgNDE2LjU2LDIzMC4zMyA0MTguMTEsMjI4'
    b'LjEzIDQyMC41NCwyMjYuMTUgNDIwLjcxLDIyMy45NyA0MTcuNDksMjIzLjAyIDQxMi4zNiwy'
    b'MzAuMjcgNDA4LjI3LDIyNS45MSA0MDguMzMsMjE5Ljk4IDQxMy42OCwyMTkuMzUgNDE2LjAx'
    b'LDIxNS42OCA0MTQuNjgsMjEzLjY2IDQwNi4xMywyMTkuOTQgNDA0LjY3LDIxNS4xMyA0MDMu'
    b'MzYsMjEwLjc4IDQxMC41NCwyMDkuMjggNDEyLjY5LDIwNi44MyA0MDguOTgsMjA1Ljk1IDQw'
    b'My4xLDIwNi41NCA0MDIuNzQsMjAzLjI0IDQwMi4zMSwxOTkuMjQgNDA4LjUsMjAwLjQgNDEx'
    b'LjAzLDE5OC4yNiA0MTAuNDUsMTk2LjIxIDQwNy40OSwxOTcuNDIgNDA1Ljc4LDE5Ni44OCA0'
    b'MDQuMTQsMTk2LjM2IDQwMi41NywxOTQuOTQgNDAyLjc0LDE5My41NiA0MDMuMDcsMTkwLjc1'
    b'IDQwNy43MiwxOTIuMDEgNDA5LjkyLDE5MC41MiA0MDguNDgsMTg4LjI0IDQwNC41MiwxODku'
    b'NTIgNDAzLjAxLDE5MC41MiA0MDEuNjksMTkxLjQxIDQwMS43NSwxOTIuNDMgNDAwLjgsMTkz'
    b'Ljg0IDM5OC4wNywxOTcuODggMzkzLjU1LDIwMi43NSAzODguOTIsMjA3LjExIDM4MS44Niwy'
    b'MTMuNzUgMzczLjQxLDIyMS4zOSAzNjEuNTUsMjE1LjY4IDM3Mi43MiwyMDIuOCAzODYuODEs'
    b'MTkyLjg0IDM5Ny4yMSwxNzkuMTkgMzg2LjAxLDE4My4zOCAzNjIuMDksMTg5LjI3IDM2MC4x'
    b'NiwxNzIuODMgMzc1Ljc1LDE2OS40MyAzOTEsMTY1LjcgNDA0LjY3LDE2MC4zOSAzODguMiwx'
    b'NTkuMzUgMzcxLjQ3LDE1OC41OCAzNzAuNjcsMTQxLjg3IFogTSA0MDMuMDEsMTQ4LjIyIEMg'
    b'NDA0LjI4LDE0OS4xNiA0MDYuMiwxNDkuNDYgNDA2Ljg4LDE1MC45OSAzOTYuMDIsMTUxLjc1'
    b'IDM4NC41OSwxNDkuNjIgMzc2LjQ3LDE0Ny42NyAzODUuMjQsMTUxLjQ3IDM5OS41OCwxNTMu'
    b'MzggNDExLjU4LDE1MS4yNyA0MTAuMDgsMTUwLjY1IDQwOC41MywxNTAuMDcgNDA3LjcxLDE0'
    b'OC43OCA0MDkuNjcsMTQ3LjYgNDEzLjE5LDE0Ny45OSA0MTUuNDUsMTQ3LjEyIDQxMS44Mywx'
    b'NDYuOTYgNDA2LjY5LDE0Ny41NCA0MDMuMDEsMTQ4LjIyIFogTSA0MDEuNjMsMTY4LjY4IEMg'
    b'NDAxLjYsMTY4LjM1IDQwMS41NSwxNjguMDMgNDAxLjA4LDE2OC4xMyAzODkuOSwxNzIuMDYg'
    b'Mzc4LjM2LDE3NS42MyAzNjQuMDMsMTc2LjQyIDM3OS41MiwxNzcuODYgMzkwLjQsMTcyLjQx'
    b'IDQwMS42MywxNjguNjggWiBNIDM5MS42OCwxOTIuNzMgQyAzODcuMjcsMTk3Ljk2IDM4MS44'
    b'MywyMDMuMDYgMzc2Ljc1LDIwNy4zOSAzNzQuOTksMjA4Ljg5IDM3Mi45NywyMTAuMDUgMzcx'
    b'Ljc3LDIxMS44MSAzODEuNzMsMjA1LjA5IDM5MC4zMiwxOTcgMzk3LjQ4LDE4Ny40OCAzOTQu'
    b'OTgsMTg4LjY2IDM5NC40NiwxOTEuODMgMzkxLjY4LDE5Mi43MyBaIE0gMzU5LjYxLDI3NS42'
    b'NyBDIDM2OS43MywyNzQuOTUgMzc1LjU0LDI2Ni45NiAzODAuOSwyNjAuNzQgMzg3LjgxLDI1'
    b'Mi43MSAzOTQuOTgsMjQ0LjM4IDM5OS45NywyMzUuMDMgNDAzLjMxLDIzMy4wMSA0MDQuOCwy'
    b'MjguNjggNDA2LjMzLDIyNC44IDQwNy4yNywyMjIuNDIgNDA4LjgsMjIwLjIzIDQwOC41NCwy'
    b'MTguNzIgNDAwLjcsMjE5LjI2IDQwMS44MiwyMTAuODEgNDA2Ljg4LDIwOC4yMSA0MDUuNzUs'
    b'MjA3Ljg3IDQwNC45NiwyMDcuMTkgNDAzLjU3LDIwNy4xMSAzOTEuOTcsMjI1LjQ3IDM4My45'
    b'OSwyNDguOSAzNjkuMjgsMjYzLjIzIDM4MS4zOCwyNDUuMTkgMzkxLjk4LDIyNS42NiA0MDEu'
    b'NjMsMjA1LjE3IDQwMS4zNSwyMDQuMjYgNDAwLjgsMjAzLjYxIDQwMC44LDIwMi40MSA0MDEu'
    b'NjQsMjAwLjU4IDQwMywxOTkuMjcgNDA0LjY3LDE5OC4yNiA0MDMuMDYsMTk3Ljg0IDQwMi4x'
    b'MywxOTYuNzUgNDAwLjgsMTk2LjA1IDM4OC4yNywyMjMuNzkgMzczLjg0LDI0OS42MyAzNTku'
    b'NjEsMjc1LjY3IFogTSA1ODYuODYsMjQyLjc3IEMgNTkyLjI1LDI2MS41IDU5OC4xNSwyODAu'
    b'NTQgNjA0LjgyLDI5OC4wNiA2MDcuNTIsMzA1LjE1IDYxMS41OCwzMTEuODEgNjEyLjU2LDMx'
    b'OS42MyA2MDYuMDMsMzA3LjYgNjAxLjMxLDI5NC4yIDU5Ni41MywyODAuNjUgNTkxLjcsMjY2'
    b'Ljk1IDU4Ny42MSwyNTIuNTYgNTg0LjM3LDIzNy41MiA1ODEuOTQsMjM4LjkxIDU3Ny44Mywy'
    b'MzguMyA1NzUuNTIsMjM3LjI0IDU3NS41MiwyNDcuNTQgNTc4LjU5LDI1Ni42NSA1ODEuODgs'
    b'MjY1LjE3IDU4OS44MywyODUuNzUgNTk2LjEyLDMwOC41NSA2MDYuMjEsMzI2LjgxIDYxMS4z'
    b'NywzMzYuMTcgNjE3LjQsMzQ1LjI1IDYyOS43LDM0NS42MSA2MjIuNDgsMzI3LjYzIDYxMi42'
    b'MywzMDguMTMgNjA4LjQyLDI4Ni4xNyA2MDYuOTgsMjc4LjY3IDYwNi4xLDI3MC44MSA2MDQu'
    b'MjcsMjYzLjIzIDYwMy4yNCwyNTguOTggNjAxLjM4LDI1NC40IDU5OS44NSwyNDkuOTYgNTk2'
    b'LjY4LDI0MC43OCA1OTMuMTEsMjMzLjEgNTg3Ljk2LDIyNi43NCA1ODYuNDEsMjI4LjEzIDU4'
    b'My4yOCwyMjYuNDkgNTgxLjg4LDIyNy4wMSA1ODUuMzgsMjMwLjY0IDU4NS4yMywyMzcuMTMg'
    b'NTg2Ljg2LDI0Mi43NyBaIE0gNDA4LjgyLDIyOS4yMyBDIDQwOC44LDIyOS4wNiA0MDguNzgs'
    b'MjI4LjkgNDA4LjU0LDIyOC45NSA0MDIuOTcsMjM3LjU0IDM5OS4wMSwyNDUuOTUgMzk2LjM4'
    b'LDI1Ni44NyAzOTIuOCwyNzEuNjkgMzkxLjYyLDI5MS4zMyAzODcuMjYsMzA2LjA4IDM4Mi45'
    b'NiwzMjAuNiAzNzYuMDQsMzM1LjUyIDM3MS43NywzNDkuNDggMzczLjk0LDM0OS4yNSAzNzUu'
    b'NTgsMzQ4LjUgMzc3Ljg2LDM0OC4zOCAzODYuMTIsMzQ0LjYgMzkwLjQ2LDMzNi44OCAzOTQu'
    b'MTcsMzI4Ljc1IDQwNS40MSwzMDQuMSA0MTQuMjEsMjc1LjI5IDQyMi4wOSwyNDguMDIgNDIw'
    b'Ljc0LDI0NS44MyA0MjEuMjcsMjQxLjU2IDQyMS44MSwyMzguOSA0MTkuMzUsMjQwLjMxIDQx'
    b'Ni40NiwyNDAuODYgNDEzLjI0LDIzOS43MyA0MDguMDQsMjY1LjcxIDQwMC42MiwyOTAuNzcg'
    b'MzkxLjk1LDMxMy4yNyAzOTAuNzIsMzE2LjQ2IDM5MC4xNCwzMjAuMTkgMzg3LjUzLDMyMi42'
    b'NyAzOTQuMTMsMzAxLjcxIDQwMS40MywyNzkuOTkgNDA3LjE2LDI1OC41MyA0MDguMTcsMjU0'
    b'Ljc1IDQwOC45LDI1MC45NCA0MDkuOTIsMjQ3LjE5IDQxMS4wMiwyNDMuMTkgNDExLjM1LDIz'
    b'OS40OSA0MTIuMTQsMjM1LjMxIDQxMi42MiwyMzIuNzMgNDE0LjQ4LDIzMC4xNiA0MTQuMzUs'
    b'MjI4Ljk1IDQxMi41MiwyMjkuMjYgNDEwLjc0LDIyOS43NCA0MDguODIsMjI5LjIzIFogTSA2'
    b'MjMuOSwxMzguNTUgQyA2MjMuMjksMTU0LjUzIDYwNy4wNCwxNTcuMjYgNTg5Ljg5LDE1Ny42'
    b'MiA2MDMuNTgsMTYzLjM4IDYxOS44NSwxNjYuNTYgNjM3LjE3LDE2OC42OCA2MzUuNjUsMTg0'
    b'LjIgNjEwLjU1LDE4MS44MyA1OTguMTksMTc2LjcgNjA4Ljk3LDE4OS4zMiA2MjMuMzQsMjAw'
    b'Ljc2IDYzNi44OSwyMTEuNTMgNjMzLjUsMjE0Ljk1IDYyNi4yOSwyMTUuMDcgNjIyLjI0LDIx'
    b'NC4wMiA2MTcuNjUsMjEyLjgzIDYxMy4yMiwyMDguOTQgNjA5LjI0LDIwNS40NSA2MDMuODYs'
    b'MjAwLjczIDU5OS4zOSwxOTcuMjUgNTk1LjcsMTkxLjkxIDU5My44OCwxODkuMjcgNTkwLjQ5'
    b'LDE4NS41NCA1ODYuMDIsMTg4LjAzIDU4Ni45OCwxOTAuMjIgNTkyLjU3LDE4OC4yMiA1OTMu'
    b'MjEsMTkxLjA4IDU5NC4yNCwxOTUuNjQgNTg2LjgxLDE5My4zMyA1ODUuMiwxOTYuNiA1ODgu'
    b'MDUsMTk4LjE4IDU5NC4xLDE5Ni41NSA1OTMuMjEsMjAxLjg2IDU5MS40LDIwNC4wMSA1ODcu'
    b'MzQsMjAzLjkxIDU4NC4wOSwyMDQuNjIgNTg1LjA1LDIwOC4xIDU5Mi41MiwyMDcuNDIgNTkx'
    b'LjgzLDIxMy40NyA1ODkuMTcsMjE2Ljg5IDU4My4yMSwyMTIuODcgNTgwLjc3LDIxMy43NCA1'
    b'ODIuOTYsMjE3LjI4IDU5MS4wMywyMTkuNTQgNTg3LjY4LDIyNS4wOCA1ODMuMjgsMjI2LjAy'
    b'IDU3OS43LDIyMi40MiA1NzYuNjIsMjIyLjA0IDU3NS41OSwyMjQuNTYgNTgwLjMyLDIyNi44'
    b'NyA1ODIuMTUsMjMwLjA1IDU4My4yNiwyMzEuOTcgNTg0LjI3LDIzNS40IDU4Mi4xNSwyMzYu'
    b'NjkgNTc1LjQ0LDIzNy40MSA1NzMuOTQsMjMxLjQ2IDU2OS45OSwyMzAuMzMgNTY5LjM4LDIz'
    b'MS43NSA1NzAuOTYsMjMzLjU4IDU3MS45MiwyMzUuMzEgNTczLjU0LDIzOC4yMSA1NzUuOCwy'
    b'NDIuMDkgNTczLjU4LDI0Ni42NCA1NjYuMDgsMjQ4LjkxIDU2NC45OSwyNDAuNDMgNTYxLjY5'
    b'LDIzNi42OSA1NTkuMjYsMjM3LjQ1IDU2MS4yNSwyNDAuMTkgNTYxLjY5LDI0Mi41IDU2Mi41'
    b'MiwyNDYuODEgNTYyLjMyLDI1Mi4yMyA1NjAuMzEsMjU0Ljk0IDU1MS44OCwyNTYuNDQgNTUx'
    b'LjU3LDI0Ny43MiA1NDkuMjUsMjQyLjIyIDU0Ni41OSwyNDQuMDggNTQ5LjIsMjQ4LjY1IDU0'
    b'OS4yNSwyNTIuNDUgNTQ5LjMsMjU1LjU0IDU0OC42MSwyNTcuNzEgNTQ3LjA0LDI1OS42NCA1'
    b'MzcuODYsMjYxLjEyIDUzNy44MywyNTEuMTkgNTM0LjMzLDI0Ni4wOSA1MzMuMDYsMjUzLjcx'
    b'IDUzNy43MywyNTcuNzkgNTQxLjI0LDI2MS41NyA1MzguMjEsMjc1LjAzIDU0MC4zNCwyOTIu'
    b'MDQgNTQyLjksMzA0LjcgNTQzLjMsMjkxLjQgNTQwLjQzLDI3Ni4zMSA1NDIuMzQsMjYyLjQg'
    b'NTQ4LjQ4LDI2Mi42MyA1NTEuMjUsMjU5LjUxIDU1MC45MSwyNTMuMjggNTUyLjk3LDI1Ni4x'
    b'NyA1NTkuMTYsMjU4LjU3IDU2Mi41MiwyNTYuMDQgNTY2LjA4LDI3My42IDU2Ni41MiwyOTQu'
    b'MjUgNTY5Ljk5LDMxMS42MSA1NzEuMzMsMzE4LjM1IDU3MS41NiwzMjUuNCA1NzQuOTcsMzMw'
    b'LjY4IDU2OS45NiwzMDQuNzMgNTY2LjY4LDI3NC42NSA1NjMuOTEsMjQ1LjU0IDU2NS40Mywy'
    b'NDUuMjQgNTY3LjE5LDI0OS4xNSA1NzAuMjcsMjQ5LjQxIDU3MS45MywyNDkuNTQgNTczLjI1'
    b'LDI0OC42OSA1NzQuNDEsMjQ4LjMgNTc1LjI4LDI4NS41IDU3OS40NSwzMTkuMzggNTg2LjU4'
    b'LDM1MC4zMSA1NzkuNzEsMzUxLjE5IDU3NS45MSwzNDYuNiA1NzEuOTIsMzQzLjY4IDU1Ny45'
    b'NywzMjQuMjcgNTUwLjksMjk3Ljk4IDU1Mi41NywyNjIuOTUgNTUxLjMsMjY0LjY2IDU1MS4x'
    b'OSwyNjcuMTMgNTUwLjY0LDI2OS4zMSA1NDguMjgsMjc4LjY0IDU0Ny4wMywyODkuMDggNTQ2'
    b'LjQ5LDMwMS4zOCA1NDYuMywzMDUuNzUgNTQ2LjA1LDMxMC4xOSA1NDQuNTUsMzEzLjgyIDU0'
    b'My4zOSwzMTQuNzIgNTQwLjk2LDMxNS4zOSA1MzkuMDMsMzE0LjY1IDUzMy4wNSwzMDcuNjcg'
    b'NTMzLjI0LDI5Ny4wMyA1MzIuMTEsMjg1LjYyIDUzMS42MywyODAuNjkgNTMwLjQyLDI3NS40'
    b'NSA1MzAuMTgsMjcwLjE0IDUyOS43NCwyNjAuNTUgNTMwLjEzLDI1MC41IDUzMS4yOSwyNDIu'
    b'MjIgNTYzLjQ3LDIzNi4wNyA1ODIuNDYsMjE2LjczIDU4MS4wNSwxNzYuOTggNTg5LjAxLDE3'
    b'OC40MSA1OTAuNDksMTY0LjIxIDU4MS4wNSwxNjYuMTkgNTg3LjIyLDE1NS44NSA1NjUuODEs'
    b'MTU1LjYzIDU3MS42NSwxNjYuMTkgNTYyLjM4LDE2NS44OSA1NjYuMTUsMTgwLjQgNTc0Ljk3'
    b'LDE3Ni43IDU3NiwxODAuNTUgNTc2LjcyLDE4NC4yMSA1NzYuMzUsMTg4Ljg2IDU3NC4yNywy'
    b'MTQuODcgNTU3LjE4LDIzMS41NSA1MjkuOSwyMzEuOTkgNTI5LjU5LDIzMS4wMSA1MjkuNiwy'
    b'MjkuNzEgNTI5LjM1LDIyOC42NyA1NTcuNjQsMjI2Ljc0IDU3Mi42NSwyMTEuNTIgNTczLjU4'
    b'LDE4Mi4yMyA1NzMuNDcsMTgxLjI4IDU3My42NywxODAuNjUgNTc0LjY5LDE4MC44NSA1NjYu'
    b'MTQsMTc2LjUgNTU2LjQ3LDE3My4yNSA1NTcuODMsMTU5LjU2IDU1Ny45NiwxNTguMiA1NTgu'
    b'MjUsMTU3LjAxIDU1OC45MywxNTUuNjkgNTU1Ljk4LDE1NS45NyA1NTQuNTEsMTYzLjI2IDU1'
    b'Ni40NSwxNjYuNzUgNTU2LjM4LDE2Ny40NiA1NTUuOTcsMTY2LjM3IDU1NS4zNCwxNjYuNzUg'
    b'NTUxLjczLDE1Mi44MSA1NTguMSwxNDMuNTggNTcxLjEsMTQyLjY5IDU3OC43NywxNDIuMTcg'
    b'NTg4LDE0Mi41MyA1OTYuODEsMTQyLjE0IDYwNy4xNywxNDEuNjkgNjE2LjcyLDEzOS42OCA2'
    b'MjMuOSwxMzguNTUgWiBNIDYxNS4zMywxNDUuNDYgQyA2MTYuMTQsMTQ1LjA4IDYxOC40MSwx'
    b'NDMuODggNjE2LjcxLDE0NC4zNSA2MDguOTgsMTQ3LjQxIDU5Ny40NiwxNDkuNiA1ODcuNDEs'
    b'MTQ4LjUgNTg3Ljk4LDE0Ni44NyA1OTAuMjQsMTQ2LjkyIDU5MSwxNDUuNDYgNTg3LjU2LDE0'
    b'NC44NSA1ODMsMTQ1LjM1IDU3OS4xMSwxNDUuMTkgNTc4Ljc1LDE0NS4xNSA1NzcuMTEsMTQ1'
    b'LjE0IDU3OCwxNDUuNDYgSCA1ODAuMjIgQyA1ODIuMjUsMTQ1LjgzIDU4NC41OCwxNDUuODkg'
    b'NTg2LjU4LDE0Ni4yOSA1ODUuNTgsMTQ3Ljc4IDU4My43OSwxNDguNDggNTgyLjcxLDE0OS44'
    b'OCA1OTUuMTgsMTUwLjE3IDYwNy40MiwxNDkuMTkgNjE1LjMzLDE0NS40NiBaIE0gNTk0LjMy'
    b'LDE2NS45MiBDIDU5My44NSwxNjUuODUgNTkzLjYzLDE2Ni4yMyA1OTQuMzIsMTY2LjE5IDYw'
    b'NC41MiwxNjkuOTIgNjE3LjUxLDE3NC45MyA2MzEuMzYsMTcyLjI4IDYxNy4zNywxNzIuNzkg'
    b'NjA1LjYyLDE2OC45OSA1OTQuMzIsMTY1LjkyIFogTSA2MjQuNzMsMjA3Ljk0IEMgNjE0Ljg0'
    b'LDIwMS40MiA2MDYuMTQsMTkyLjI1IDU5Ny45MSwxODQuOTkgNjA1LjM5LDE5My45MiA2MTQu'
    b'NCwyMDIuNzkgNjI0LjczLDIwNy45NCBaIgogICAgc3R5bGU9ImZpbGw6I2U2MDAwMCIvPgo8'
    b'cGF0aAogICAgaWQ9IlJlY2h0ZXJfRmFuZyIKICAgIGQ9Ik0gNTM1Ljk5LDMzNS42NiBDIDU0'
    b'NC4xLDM0OS4zIDU1Mi45MiwzNjIuMjIgNTYwLjg3LDM3Ni4wMiA1NjUuNjksMzc2LjUyIDU2'
    b'OC45NCwzNzYuMSA1NzEuMSwzNzIuOTggNTcyLjUxLDM3MC45NCA1NzIuMjgsMzY3LjczIDU3'
    b'My41OSwzNjUuOCA1NzUuODEsMzYyLjQ5IDU4Mi43OCwzNjMuMTUgNTg2LjU4LDM2NC45NyA1'
    b'ODYuNiwzNjcuNjEgNTgxLjA5LDM2Ny45MiA1NzkuOTQsMzY2LjA3IDU3OC41NCwzNjYuMzIg'
    b'NTc3LjY1LDM2Ny4wOSA1NzYuMzUsMzY3LjQ2IDU3Ni42MSwzNjguODEgNTc3Ljc3LDM2OS4y'
    b'OSA1NzcuMTgsMzcwLjc3IDU3Ni40MiwzNzEuMjEgNTc1LjUxLDM3MS41IDU3NC40MSwzNzEu'
    b'NiA1NzQuMTQsMzc0LjE4IDU3Mi43NCwzNzUuNjQgNTcxLjM3LDM3Ny4xMyA1NzcuNywzODEu'
    b'NjYgNTgzLjY0LDM3NC45NCA1ODkuMzQsMzc0LjkyIDU5NC4wNywzNzQuOSA1OTYuMzksMzc5'
    b'LjgyIDYwMi4zMywzNzguMjQgNjAyLjI1LDM3OS4xNiA2MDIuMDUsMzc5Ljk4IDYwMS41MSwz'
    b'ODAuNDUgNjAyLjQsMzgyLjk3IDYwNS40OCwzODMuMjkgNjA2LjIsMzg1Ljk3IDYwMy40Nywz'
    b'ODkuMDggNjAwLjU0LDM4NC41NCA1OTkuODUsMzgyLjExIDU5Ni43OCwzODIuNTEgNTk1Ljgx'
    b'LDM4MC44IDU5My43NiwzODAuMTcgNTkzLjY2LDM4My41NCA1ODguOTEsMzgzLjYzIDU4OS4w'
    b'NywzNzkuOSA1ODEuODYsMzgwLjMzIDU3My4yMSwzODUuMzkgNTY3LjUsMzgxIDU2Ny41OSwz'
    b'ODMuMTEgNTcwLjE2LDM4My44MyA1NzEuOTMsMzg0Ljg3IDU3My42NCwzODUuODggNTc1Ljk1'
    b'LDM4Ny4wMSA1NzcuNDUsMzg4LjE5IDU3OC4zOSwzODguOTMgNTc4LjkxLDM5MC4xIDU3OS45'
    b'NCwzOTAuNjggNTgxLjQ5LDM5MS41NSA1ODMuNjQsMzkxLjM1IDU4NC4zNywzOTMuMTYgNTgz'
    b'LjE1LDM5NS41IDU4NS41LDM5OC4xNyA1ODQuMzcsMzk5LjUzIDU4MC4zNiw0MDAuMTkgNTgx'
    b'LjE2LDM5My43MiA1NzYuNjIsMzkzLjk5IDU3NS42MSwzODkuMDIgNTY5LjE0LDM4OS41IDU2'
    b'Ni42NywzODUuOTggNTY0LjIzLDM4NS43NSA1NjEuMywzODYgNTYwLjU5LDM4NC4wNCA1NTgu'
    b'NDcsMzg0LjQxIDU1Ni45NCwzODUuMTYgNTU0Ljc5LDM4NS40MiA1NTIuNjksMzg1LjY5IDU1'
    b'MC4zMiwzODQuODIgNTQ4LjQyLDM4NS4xNSA1NDUuNTMsMzg1LjY1IDU0Mi41OCwzOTAuNzYg'
    b'NTM5LjU4LDM4Ny4wOCA1NDEuMDEsMzg0LjgyIDU0NC41NCwzODQuNjcgNTQ1LjM5LDM4MS44'
    b'MyA1NDkuMSwzODEuNjcgNTUyLjUyLDM4MS4yMyA1NTUuODksMzgwLjcyIDU1Ny43NSwzNzku'
    b'MjQgNTU1LjQzLDM3Ni40OCA1NTMuOTYsMzc0LjA5IDU0Ny4yNywzNjMuMjkgNTM3Ljg3LDM1'
    b'Mi41OSA1MzEuMjksMzQyLjU3IDUzMS41MSwzMzguOTIgNTMyLjE5LDMzNS43MyA1MzUuOTks'
    b'MzM1LjY2IFogTSA1ODIuMTYsMzYxLjY1IEMgNTgyLjYzLDM2Mi4xIDU4My4xNiwzNjIuNDkg'
    b'NTg0LjA5LDM2Mi40OCA1ODQuNTIsMzYxLjUyIDU4Ni43MiwzNjAuMDIgNTg1LjQ3LDM1OS4x'
    b'NiA1ODQuNSwzNjAuMTMgNTgyLjI1LDM1OS44MSA1ODIuMTYsMzYxLjY1IFogTSA2MDMuNDQs'
    b'MzgwLjcyIEMgNjAzLjc1LDM4MC43OCA2MDMuODcsMzgxLjAzIDYwMy45OSwzODEuMjggNjA1'
    b'LjkyLDM4MC43MiA2MDcuODQsMzgwLjE1IDYwOC42OSwzNzguNTEgNjA2LjkyLDM3Ni41MSA2'
    b'MDMuMzcsMzc3Ljc5IDYwMy40NCwzODAuNzIgWiBNIDU0My4xNywzODIuMzggQyA1NDMuNTYs'
    b'MzgxLjk0IDU0NC4xNSwzODEuNyA1NDQsMzgwLjcyIDU0My43OSwzODAuNjYgNTQzLjY4LDM4'
    b'MC40OSA1NDMuNzMsMzgwLjE3IDU0MC4wMiwzNzguNjEgNTM5LjksMzgyLjI2IDU0My4xNywz'
    b'ODIuMzggWiBNIDU4Ni4wMiwzOTUuOTMgQyA1ODcuMjMsMzk2LjI5IDU4OC42LDM5Ni40OCA1'
    b'OTAuMTcsMzk2LjQ4IDU5MC41NSwzOTMuODkgNTg1LjY5LDM5Mi4yMiA1ODYuMDIsMzk1Ljkz'
    b'IFoiCiAgICBzdHlsZT0iZmlsbDojZmRlNDRhIiAvPgo8cGF0aAogICAgaWQ9Ikxpbmtlcl9G'
    b'YW5nIgogICAgZD0iTSA0NjkuMDksMzQ2LjE2IEMgNDYyLjk0LDM1NS43OCA0NTIuOTYsMzY1'
    b'LjkzIDQ0NS4wMywzNzUuNzUgNDQ0LjM2LDM3Ni41OCA0NDEuOTYsMzc5LjMgNDQyLjI3LDM4'
    b'MC40NSA0NDMuMTIsMzgzLjY1IDQ1MC4zNywzODAuNjcgNDUzLjA1LDM4MS41NSA0NTMuODMs'
    b'MzgyLjc5IDQ1NC4zOSwzODQuMjYgNDU1LjI2LDM4NS40MiA0NTYuMTEsMzg1Ljg2IDQ1Ny43'
    b'NywzODUuNDkgNDU3Ljc1LDM4Ni44MSA0NTYuMSwzODkuNTIgNDUyLjA2LDM4Ni44OCA0NTAu'
    b'ODQsMzg1LjcgNDQ5LjQ3LDM4NS45IDQ0OC4wOSwzODYuMDggNDQ2LjQyLDM4NS45NyA0NDQu'
    b'MjUsMzgzLjMzIDQzOC44NSwzODUuMjcgNDM1LjM2LDM4NS40MiA0MzQuMzcsMzg4LjAyIDQz'
    b'Mi4yNCwzODkuNDkgNDI5LDM4OS44NCA0MjYuOTEsMzkzLjU2IDQyNC4zMSwzOTYuNzcgNDE5'
    b'LjMyLDM5Ny41OSA0MTcuODMsNDAwLjY1IDQxOC40LDQwNy4xMiA0MTQuMDcsNDA2LjQzIDQx'
    b'NC4yMyw0MDMuODUgNDE2Ljg5LDM5OS45MSA0MTMuNTIsMzk3Ljg2IDQxOC41OSwzOTIuNjIg'
    b'NDI1Ljg3LDM4OS41OCA0MjkuNTUsMzgyLjk0IDQyNS42NSwzODEuODYgNDIwLjE2LDM4Mi4z'
    b'OCA0MTYuODQsMzgwLjcyIDQxNS43OCwzODIuNTcgNDEyLjc0LDM4NC4xMiA0MTEuODYsMzgx'
    b'IDQwOS4xNSwzODEuNDIgNDA3LjY5LDM4My4xIDQwNC45NSwzODMuNDkgNDAzLjQ5LDM4NC45'
    b'OCA0MDMuMzUsMzg3Ljc5IDQwMS42MywzODkuMDIgMzk1LjEsMzg5Ljk2IDM5Ny43MSwzODQu'
    b'NDYgNDAwLjUzLDM4My4yMSA0MDAuOTYsMzgxLjcgMzk5LjU3LDM4MS4wNiA0MDAuMjUsMzgw'
    b'LjE3IDQwMS41NCwzNzkuMTkgNDAyLjQ3LDM3OS44NyA0MDMuNTcsMzc5LjYyIDQwNi45Niwz'
    b'NzguODQgNDA5LjI4LDM3NS4zNSA0MTIuNDEsMzc1LjE5IDQxNC43MywzNzUuMDggNDE4LjMx'
    b'LDM3Ni42NyA0MjAuOTgsMzc3LjQgNDIzLjY2LDM3OC4xNCA0MjYuMjgsMzc5LjUgNDI5LjU1'
    b'LDM3OC43OSA0MjYuNjYsMzc3LjA4IDQyOC4wOCwzNzEuMDUgNDIzLjc1LDM3MC43NyA0MjMu'
    b'MjYsMzY5Ljk3IDQyMy42NSwzNjguMjkgNDIyLjkyLDM2Ny43MyA0MjAuOTQsMzY3LjQ0IDQx'
    b'Ny4yMywzNjguNzggNDE1LjczLDM2Ni45IDQxNC4yLDM2Ny4yMiA0MTIuMDUsMzY5LjQgNDEw'
    b'Ljc1LDM2Ny40NSA0MTEuMTYsMzY0LjcyIDQxNC4zMiwzNjQuNzYgNDE1LjczLDM2My4wMyA0'
    b'MTkuNiwzNjQuNjkgNDI0LjkzLDM2NC44OCA0MjguMTcsMzY3LjE4IDQyOS45LDM3MS42NCA0'
    b'MzMuMiwzODIuNTQgNDM4LjQsMzc2LjMgNDQwLjQ4LDM3My44MSA0NDIuMjIsMzcwLjY1IDQ0'
    b'NC40OCwzNjcuNzMgNDUwLjI2LDM2MC4yNyA0NTguMTcsMzUwLjA1IDQ2My41NiwzNDMuNCA0'
    b'NjMuNTEsMzQzLjE2IDQ2My42NiwzNDMuMTQgNDYzLjgzLDM0My4xMiA0NjQuODksMzQyLjcy'
    b'IDQ2Ni40NywzNDMuOTEgNDY3Ljk4LDM0My45NSA0NjguMTksMzQ0Ljg1IDQ2OC41NiwzNDUu'
    b'NTkgNDY5LjA5LDM0Ni4xNiBaIE0gNDEyLjk2LDM2My4zMSBDIDQxMy40NCwzNjIuODcgNDEz'
    b'Ljk3LDM2Mi40NyA0MTMuNzksMzYxLjM3IDQxMi40MiwzNjAuODEgNDEwLjk5LDM2MC4zMSA0'
    b'MDkuMDksMzYwLjI2IDQwOS42LDM2Mi4wNiA0MTAuOTYsMzYzLjAxIDQxMi45NiwzNjMuMzEg'
    b'WiBNIDQ1OC41OCwzODAuNDUgQyA0NTguMzEsMzgxLjc0IDQ1Ny4zNSwzODIuMzUgNDU1Ljgy'
    b'LDM4Mi4zOCA0NTQuNSwzODAuNjIgNDU3LjIsMzc5LjUxIDQ1OC41OCwzODAuNDUgWiBNIDM5'
    b'OC41OSwzODEgQyAzOTkuODcsMzgzLjQ3IDM5Ni43LDM4NC4yNCAzOTQuNzIsMzgzLjQ5IDM5'
    b'NC45NywzODEuNDYgMzk2LjUzLDM4MC40NiAzOTguNTksMzgxIFogTSA0MTMuMjQsMzk5LjUy'
    b'IEMgNDEzLjIsNDAwLjQgNDEzLjk4LDQwMC40NSA0MTMuNzksNDAxLjQ2IDQxMi4yOCw0MDIu'
    b'MTUgNDEwLjkxLDQwMi45OSA0MDkuMzcsNDAzLjY3IDQwOS4xLDQwMC43MyA0MTAuNjYsMzk5'
    b'LjYxIDQxMy4yNCwzOTkuNTIgWiIKICAgIHN0eWxlPSJmaWxsOiNmZGU0NGEiLz4KPHBhdGgK'
    b'ICAgIGlkPSJSZWNodGVyX0tsZWVzdGVuZ2VsIgogICAgZD0iTSA1ODAuMjIsMTYwLjY3IEMg'
    b'NTgxLjQ0LDE2My4wNyA1ODAuMjIsMTY1LjQgNTc5LjM5LDE2Ny4zIDU4OS4wNywxNjQuNjIg'
    b'NTg4LjQyLDE3OC40NSA1NzkuMzksMTc1Ljg3IDU4Mi4wOCwyMTMuNTIgNTY0LjQ0LDIzNS41'
    b'NCA1MzEuMDEsMjM4LjkgNTMwLjcyLDIzNy40NCA1MzAuMzEsMjM2LjEgNTMwLjE4LDIzNC40'
    b'OCA1NDMuNjMsMjMyLjY0IDU1NS40NiwyMjguOTQgNTYzLjkxLDIyMC45MyA1NzMuNzksMjEx'
    b'LjU2IDU4MC42OSwxOTIuOTUgNTc1LjUyLDE3NS4zMiA1NzEuNzksMTc2Ljk5IDU2NS4xNiwx'
    b'NzQuNzQgNTY3LjUsMTY4LjY4IDU2OC42OSwxNjcuNjYgNTcwLjI0LDE2Ni45OSA1NzIuNzYs'
    b'MTY3LjMgNTY5LjE3LDE2Mi42MSA1NzQuODIsMTU2LjczIDU4MC4yMiwxNjAuNjcgWiIKICAg'
    b'IHN0eWxlPSJmaWxsOiNmZGU0NGEiIC8+CjxwYXRoCiAgICBpZD0iTGlua2VyX0tsZWVzdGVu'
    b'Z2VsIgogICAgZD0iTSA0MTguNzcsMTc1LjA0IEMgNDE0LjY2LDIwOS41OSA0MzIuOSwyMzMu'
    b'MDggNDY2LjMyLDIzMy45MyA0NjYuNjgsMjM1LjIyIDQ2Ni42LDIzNi45NiA0NjYuNiwyMzgu'
    b'NjIgNDUwLjUsMjM5LjE5IDQzNy4wMiwyMzEuNjIgNDI5LDIyMi41OSA0MjEuMTEsMjEzLjcx'
    b'IDQxNy4xMywyMDEuMDIgNDE1LjczLDE4Ny40OCA0MTUuMzMsMTgzLjYyIDQxNS41MiwxNzku'
    b'NTggNDE1LjczLDE3NS42IDQwOC40OSwxNzguNzcgNDA1LjQyLDE2Ni41IDQxNC4zNSwxNjcu'
    b'MyA0MTQuMTksMTY2LjI0IDQxMi44OSwxNjMuNDYgNDEzLjgsMTYxLjIyIDQxOC4xMiwxNTYu'
    b'NTIgNDI1LjQyLDE2My4xNSA0MjAuNDMsMTY3LjU4IDQzMC4zNCwxNjUuNCA0MjcuNjksMTc5'
    b'Ljk0IDQxOC43NywxNzUuMDQgWiIKICAgIHN0eWxlPSJmaWxsOiNmZGU0NGEiIC8+CjxwYXRo'
    b'CiAgICBpZD0iTWF1bGlubmVucmF1bSIKICAgIGQ9Ik0gNTEyLjc3LDE2NS4zNiBDIDUxMi42'
    b'NiwxNjcuNDcgNTEwLjg4LDE2Ny45IDUwOS4xNywxNjguNDEgNTA5LjU2LDE2Ni41OCA1MDku'
    b'OTksMTY0LjggNTEyLjc3LDE2NS4zNiBaIE0gNTEwLjI4LDE2MS40OSBDIDUxMS4yNiwxNjEu'
    b'ODkgNTEyLjU3LDE2MS45NyA1MTMuNiwxNjIuMzIgNTEzLjI0LDE1OC4xNyA1MTEuMzMsMTU1'
    b'LjU1IDUwNy43OSwxNTQuNTggNTA4Ljc4LDE1Ni43MiA1MTAuMDgsMTU4LjU2IDUxMC4yOCwx'
    b'NjEuNDkgWiIKICAgIHN0eWxlPSJmaWxsOiNlNjAwMDAiIC8+CjxwYXRoCiAgICBpZD0iU2No'
    b'bmFiZWwiCiAgICBkPSJNIDQ5MC4wOSwxNzAuMzQgQyA0OTcuMTksMTY2Ljk0IDUxMC43OCwx'
    b'NzQuMTYgNTE0LjQyLDE2Ni43NSA1MTUuNjEsMTY0LjMzIDUxNS4wOCwxNjAuNDYgNTE0LjQy'
    b'LDE1OC43MyA1MTIuMDcsMTUyLjU0IDUwMC4zNCwxNDguODggNDkzLjk2LDE1My40OCA0ODku'
    b'MzEsMTQ5LjExIDQ3Ny41LDE0OS4zNSA0NzYuMjcsMTU2LjUyIDQ3My41LDE1MC4wNiA0Nzku'
    b'MSwxNDUuMjggNDg0Ljg0LDE0NC42MyA0ODYuMTMsMTQzLjM2IDQ4Ny4wNSwxMzkuMDIgNDkw'
    b'LjA5LDE0MS4zMSA0OTEuNCwxNDkuMjMgNTAxLjA3LDE0OC4zOSA1MDguMzQsMTUxLjI3IDUx'
    b'Mi40OCwxNTIuOTEgNTE3LjgzLDE1Ni44OSA1MTguNTcsMTYwLjY3IDUxOS4zOSwxNjQuODIg'
    b'NTE2LjcsMTY5LjExIDUxNC40MiwxNzAuOSA1MDguMjksMTc1LjY5IDQ5Ni4zMiwxNzIuNjUg'
    b'NDkwLjA5LDE3MC4zNCBaIgogICAgc3R5bGU9ImZpbGw6I2ZkZTQ0YSIgLz4KPHBhdGgKICAg'
    b'IGlkPSJadW5nZSIKICAgIGQ9Ik0gNTExLjY2LDE2My40MyBDIDUwMS4xNywxNjIuNCA0ODcu'
    b'MywxNjIuNzkgNDc3LjkzLDE2NS4zNiA0ODUuNjgsMTYwLjE3IDUwMS42NCwxNjAuNDIgNTEx'
    b'LjY2LDE2My40MyBaIgogICAgc3R5bGU9ImZpbGw6I2U2MDAwMCIgLz4KPHBhdGgKICAgIGlk'
    b'PSJHZWZpZWRlciIKICAgIGQ9Ik0gNTkwLjQ1LDE5MS4zNSBDIDU5MC4wNywxOTIuNTMgNTg3'
    b'LjEyLDE5Mi4zNCA1ODYuMDIsMTkxLjkgNTg2LjIzLDE5MC4xMSA1ODkuMzksMTkwLjg2IDU5'
    b'MC40NSwxOTEuMzUgWiBNIDU4NC42NCwyMDAuNzUgQyA1ODYuNCwyMDAuNTcgNTg4Ljg4LDIw'
    b'MS4xMSA1OTAuMTcsMjAwLjQ3IDU4OC42LDIwMC4yNyA1ODUuMzcsMTk4LjQ5IDU4NC42NCwy'
    b'MDAuNzUgWiBNIDU4Mi45OCwyMTAuNDMgQyA1ODUuMDUsMjEwLjc2IDU4Ni43NywyMTIuNTkg'
    b'NTg5LjA3LDIxMS44MSA1ODcuNjQsMjEwLjI5IDU4NC45LDIxMC4wOCA1ODIuOTgsMjA5LjA0'
    b'IFogTSA1NzkuMTEsMjE5LjU1IEMgNTgxLjc4LDIyMC4xMSA1ODMuMzMsMjIxLjc4IDU4Ni4w'
    b'MiwyMjIuMzEgNTg0LjMyLDIyMC4zMyA1ODEuNTUsMjE5LjQyIDU3OS4xMSwyMTguMTcgWiBN'
    b'IDU3My41OSwyMjguNCBDIDU3Ni4wNCwyMjkuMzUgNTc3LjU1LDIzMi43MiA1ODAuMjIsMjMy'
    b'LjU0IDU3OC4yNiwyMzAuMTcgNTc2LjM2LDIyNy43NCA1NzMuNTksMjI2LjE4IDU3Mi45Mywy'
    b'MjYuODMgNTczLjYzLDIyNy41NCA1NzMuNTksMjI4LjQgWiBNIDU3MC44MiwyNDMuMDUgQyA1'
    b'NjkuNDMsMjM5LjY1IDU2OC40NywyMzUuODIgNTY1LjU3LDIzMy45MyA1NjYuODEsMjM3LjQ3'
    b'IDU2OC4wNSwyNDEuMDIgNTcwLjgyLDI0My4wNSBaIE0gNTU3LjgzLDI1MS4wNiBDIDU1Ny41'
    b'OSwyNDcuOCA1NTYuNDMsMjQzLjA2IDU1NC41MSwyNDAuNTYgNTU0LjUxLDI0NC4xIDU1Ni4y'
    b'NywyNDguMTcgNTU3LjgzLDI1MS4wNiBaIE0gNTQ0LDI1NS4yMSBDIDU0My43NiwyNTEuNCA1'
    b'NDIuNTYsMjQ4LjU0IDU0Mi4wNywyNDQuOTggSCA1NDAuNjkgQyA1NDEuMzYsMjQ4LjgyIDU0'
    b'MS43MiwyNTIuOTggNTQ0LDI1NS4yMSBaIE0gNDA5LjY1LDE5NC4xMiBDIDQwOC42NiwxOTMu'
    b'MjYgNDA1LjM0LDE5NC43NCA0MDUuMjIsMTkzLjAxIDQwNi42LDE5Mi43OCA0MDkuNiwxOTIu'
    b'MjIgNDA5LjY1LDE5NC4xMiBaIE0gNDA1Ljc4LDIwMy4yNCBDIDQwNy44LDIwMy4wNSA0MTAu'
    b'MjUsMjAzLjI4IDQxMS4zMSwyMDIuMTMgNDA5LjY3LDIwMC42NSA0MDYuNzMsMjAyLjI0IDQw'
    b'NS43OCwyMDMuMjQgWiBNIDQwNy4xNiwyMTQuMDIgQyA0MDkuNzcsMjEzLjQgNDEzLjI5LDIx'
    b'My43IDQxMy43OSwyMTAuOTggNDExLjY3LDIxMi4wOCA0MDguMzksMjEyLjAyIDQwNy4xNiwy'
    b'MTQuMDIgWiBNIDQxMC43NSwyMjMuOTcgQyA0MTMuNDgsMjI0LjE4IDQxNi44NiwyMjIuNzMg'
    b'NDE3LjY2LDIyMC4xIDQxNC45OCwyMjEuMDEgNDEyLjg4LDIyMi41IDQxMC43NSwyMjMuOTcg'
    b'WiBNIDQxNy4xMSwyMzQuNDggQyA0MTkuNzgsMjMzLjk4IDQyMy40NiwyMzAuNzIgNDIzLjQ3'
    b'LDIyNy41NyA0MjAuOCwyMjkuMzIgNDE5LjA3LDIzMi4wMSA0MTcuMTEsMjM0LjQ4IFogTSA0'
    b'MjYuNzksMjQ0LjQzIEMgNDI4LjYxLDI0NC4xMyA0MjguOTEsMjQxLjY3IDQyOS41NSwyNDAu'
    b'MjggNDMwLjMyLDIzOC42MiA0MzEuMiwyMzYuOTIgNDMxLjc2LDIzNS4zMSA0MzEuNDEsMjM1'
    b'LjI5IDQzMS4zOCwyMzQuOTUgNDMwLjkzLDIzNS4wMyA0MjkuMzcsMjM3Ljk4IDQyNy43OCwy'
    b'NDAuOTEgNDI2Ljc5LDI0NC40MyBaIE0gNDQwLjMzLDI1Mi4xNyBDIDQ0MS4xOSwyNDguNzgg'
    b'NDQzLjEzLDI0NS4wMyA0NDMuMSwyNDEuNjcgSCA0NDIuMjcgQyA0NDEuNTIsMjQ0LjcxIDQz'
    b'OS44MywyNDkuNzEgNDQwLjMzLDI1Mi4xNyBaIE0gNDU0LjQzLDI1NS43NiBDIDQ1NS44OCwy'
    b'NTIuOTcgNDU2LjcsMjQ5LjU2IDQ1Ni42NCwyNDUuMjYgSCA0NTUuODIgQyA0NTUuMTIsMjQ4'
    b'LjM0IDQ1NC4wMiwyNTIuNDkgNDU0LjQzLDI1NS43NiBaIE0gNDk5LjQ5LDMxOS4wNyBDIDUw'
    b'MC4xOCwzMjMuMyA1MDAuNjgsMzI4Ljc3IDUwMC4wNSwzMzMuNDUgNDk4LjY3LDMyOS43MiA0'
    b'OTguNjYsMzIzLjQzIDQ5OS40OSwzMTkuMDcgWiBNIDQ5OS4yMiwzNjUuOCBDIDQ5Ny41Niwz'
    b'NTEuODcgNDk2LjE3LDMzNy42OSA0OTQuMjQsMzI0LjA1IDQ5My43NywzMzQuNDggNDk1LjE3'
    b'LDM0My42NSA0OTYuNzMsMzUzLjkgNDk3Ljk0LDM2MS44NSA0OTguNzIsMzcwLjI3IDQ5OS4y'
    b'MiwzNzguNTEgNTAwLjE2LDM5NC4wNCA0OTkuMjQsNDEwLjEgNTAwLjA1LDQyNS43OCA1MDAu'
    b'MTQsNDI3LjU0IDUwMC4yNiw0MjkuNDMgNTAxLjE1LDQzMS4zMSA0OTguMDUsMzkzLjk0IDUw'
    b'NC4xNSwzNTcuODQgNTA2LjEzLDMyMy43NyA1MDQuODIsMzM4Ljc3IDUwNC40NiwzNTQuNzIg'
    b'NDk5LjIyLDM2NS44IFogTSA1MTYuNjMsMTkxLjkgQyA1MTcuMzcsMTkxLjkyIDUxNi4zNywx'
    b'OTYuMDMgNTE3LjQ2LDE5Ni42IDUxNy45NSwxOTYuNjggNTE4LjMyLDE5NS4zIDUxOC41Nywx'
    b'OTYuMDUgNTE4LjMyLDE5Ny40NiA1MTcuNiwxOTguNCA1MTcuNDYsMTk5LjkyIDUxNS4xNywx'
    b'OTguNTcgNTE2LjU1LDE5NC42NCA1MTYuNjMsMTkxLjkgWiBNIDUxMC4yOCwyMTQuNTcgQyA1'
    b'MTAuNDIsMjEyLjMyIDUxMi4xNCwyMTAuMTggNTExLjk0LDIwOC40OSA1MTEuMTYsMjA4Ljky'
    b'IDUxMS4xOCwyMTAuMTMgNTEwLjI4LDIxMC40MyA1MDkuNTEsMjA5LjUzIDUxMC41LDIwNi44'
    b'OCA1MDkuNzIsMjA2IDUwOC43NywyMDguMTIgNTA3LjU1LDIxMy40NCA1MTAuMjgsMjE0LjU3'
    b'IFogTSA0OTYuNDUsMjM2LjE0IEMgNDk2LjczLDIzNC40OCA0OTcuNjYsMjMzLjQ3IDQ5Ny4y'
    b'OCwyMzEuMTYgNDk1Ljg3LDIzMC44NiA0OTcuNTksMjMzLjY4IDQ5Ni4xOCwyMzMuMzcgNDkz'
    b'LjAzLDIzMC43MyA0OTUuNTIsMjIyLjE3IDQ5NC41MiwyMTguNzIgNDk0LjE3LDIyNC4zOSA0'
    b'OTIuMTIsMjMzLjI3IDQ5Ni40NSwyMzYuMTQgWiBNIDQ5Mi4wMywyMjguNjcgQyA0OTEuODcs'
    b'MjI2LjgyIDQ4OS45NywyMjcuMzUgNDg4Ljk5LDIyNi40NiA0ODcuMjEsMjI0Ljg0IDQ4Ny42'
    b'MSwyMjIuNTQgNDg3LjA1LDIxOS41NSA0ODYuMTcsMjI0LjE2IDQ4Ny4xLDIyOC45OSA0OTIu'
    b'MDMsMjI4LjY3IFogTSA1MDMuOTIsMjMzLjY1IEMgNTAzLjk4LDIzMy40MyA1MDQuMTUsMjMz'
    b'LjMzIDUwNC40NywyMzMuMzcgNTA0LjY5LDIzMi4zMyA1MDQuOTUsMjMxLjAzIDUwNC40Nywy'
    b'MzAuMDUgNTAzLjMxLDIyOS42MyA1MDQuNDMsMjMxLjQ4IDUwMy42NCwyMzEuNDQgNTAxLjE4'
    b'LDIzMC4xMiA1MDEuMjYsMjI2LjI2IDUwMC4zMiwyMjMuNDIgNTAwLjYzLDIyNy43MiA1MDAu'
    b'MSwyMzIuODYgNTAzLjkyLDIzMy42NSBaIE0gNDk4LjExLDI2MS4wMiBDIDUwMi41OCwyNjAu'
    b'NSA1MDMuMDgsMjUxLjE1IDUwMy4wOSwyNDYuMDkgNTAxLjc4LDI0OS40MyA1MDEuOTUsMjU5'
    b'Ljg3IDQ5Ny41NiwyNTkuNjMgNDkzLjQxLDI1OS40MSA0OTMuMzgsMjQ5Ljc2IDQ5Mi4zMSwy'
    b'NDYuMDkgNDkyLjY0LDI1MS45MiA0OTIuODgsMjYxLjYzIDQ5OC4xMSwyNjEuMDIgWiBNIDUw'
    b'Ny41MSwyNjguNDggQyA1MDguMiwyNzMuOTQgNTA1Ljk1LDI4MS45NSA1MDguMzQsMjg2Ljcz'
    b'IDUxMi41NSwyODcuNDggNTE0LjQ3LDI4Mi4yMSA1MTUuOCwyNzkuMjYgNTE3LjM4LDI3NS44'
    b'IDUxOC41NiwyNzIuNDMgNTE5LjEyLDI2OS41OSA1MTkuMzYsMjc3LjEgNTE1LjcyLDI4My4x'
    b'NCA1MTIuMjEsMjg3LjgzIDUwOS4wOCwyODkuNjMgNTA2Ljk2LDI4Ny4yMyA1MDUuODUsMjg1'
    b'LjM0IDUwMy41MSwyODguMDggNTAyLjgsMjkyLjk2IDQ5OC42NywyOTMuMDggNDkzLjk5LDI5'
    b'My4yMyA0OTIuOTYsMjg3LjE4IDQ5MS4yLDI4My4xMyA0ODkuMjMsMjg1LjE1IDQ5MC4yMSwy'
    b'ODguODUgNDg2LjUsMjg4Ljk0IDQ4MC43NCwyODkuMDggNDc4LjYsMjc1Ljg2IDQ3Ny4xLDI3'
    b'MS4yNSA0NzguNiwyNzMuOTUgNDc5LjQyLDI3Ni45MiA0ODAuOTcsMjgwLjM3IDQ4MS45OSwy'
    b'ODIuNjIgNDgzLjk4LDI4Ny42MSA0ODYuNSwyODcuNTYgNDkxLjI2LDI4Ny40NSA0ODkuNjMs'
    b'Mjc0LjAyIDQ4OS41NCwyNjkuMzEgNDkxLjA5LDI3Ny45IDQ5Mi41OSwyODYuNTQgNDk3Ljg0'
    b'LDI5MS40MyA1MDUuOCwyODguNTIgNTA1LjUyLDI3Ny4zNyA1MDcuNTEsMjY4LjQ4IFogTSA1'
    b'MDUuODUsMjk0LjE5IEMgNTA3LjQ0LDI5Ny45IDUwMy4yOSwzMDUuNzMgNTA3Ljc5LDMwNy43'
    b'NCA1MTMuMDcsMzA2LjIgNTEzLjE2LDI5OS40NyA1MTUuMjUsMjk0Ljc0IDUxNS4zMiwzMDEu'
    b'NTUgNTEyLjI0LDMxMS42OCA1MDQuNDcsMzA4Ljg0IDUwMy40OCwzMTAuNTIgNTAyLjU2LDMx'
    b'Mi4yOCA1MDEuMTUsMzEzLjU0IDQ5OS4zOSwzMTMuODYgNDk4LjY0LDMxMy41OSA0OTYuNzMs'
    b'MzEzLjU0IDQ5NS4zNywzMTIuMDUgNDk0LjI4LDMxMC4yOCA0OTMuNDEsMzA4LjI5IDQ4OC4x'
    b'MywzMTQuNTIgNDgzLjU3LDMwMi43NyA0ODIuOTEsMjk2Ljk2IDQ4NC44NiwzMDAuNTYgNDg1'
    b'LjQ3LDMwOC44NiA0OTAuMDksMzA4LjI5IDQ5NC43NSwzMDcuNzIgNDkxLjA4LDI5OS41MSA0'
    b'OTEuNzUsMjk0Ljc0IDQ5My4wOSwyOTkuODIgNDkzLjU3LDMxMi4yNiA0OTkuNzcsMzExLjYx'
    b'IDUwNC44NSwzMTEuMDcgNTA0LjE2LDI5OC40MyA1MDUuODUsMjk0LjE5IFogTSA1MDUuMywy'
    b'MTUuNjggQyA1MDUuMDYsMjIwLjYyIDUwNS40NSwyMjcuMDcgNTA4Ljg5LDIyOS4yMiA1MTAu'
    b'NDYsMjI5Ljc5IDUxMC4yNywyMjcuNjkgNTExLjExLDIyOC40IDUxMS44LDIyOS4yOSA1MTAu'
    b'ODMsMjMwLjM3IDUxMC4yOCwyMzAuODggNTA0LjkzLDIyOS42NiA1MDQuNjYsMjIxLjk5IDUw'
    b'NS4zLDIxNS42OCBaIE0gNDc3LjY2LDI0Mi40OSBDIDQ3OS4xMywyNDYuODMgNDgwLjEyLDI1'
    b'My43MiA0ODIuMDgsMjU3LjQyIDQ4Mi41MSwyNTguMjQgNDgzLjg5LDI2MC4zMyA0ODUuMTIs'
    b'MjYwLjE5IDQ4Ny45NiwyNTkuODUgNDg4LjgxLDI1MC4yMiA0ODguOTksMjQ2LjY0IDQ4OS4w'
    b'NCwyNDUuNTYgNDg4Ljk1LDI0NC4yIDQ4OC45OSwyNDMuMDUgNDkwLjk2LDI0OS4xMiA0OTAu'
    b'NjQsMjU5LjA4IDQ5NC41MiwyNjMuMjMgNDk2LjAxLDI2NC44MyA0OTcuNzgsMjY1LjE5IDQ5'
    b'OS43NywyNjMuNzggNTA0LjQ3LDI2MC40NCA1MDUuNjEsMjUwLjkzIDUwNi40MSwyNDMuMzIg'
    b'NTA3LjI4LDI0Ny4wMyA1MDUuNzcsMjU2Ljk5IDUwOS4xNywyNTkuOTEgNTE0Ljg0LDI1OC4x'
    b'MSA1MTUuMTIsMjUwLjkzIDUxNi4wOCwyNDQuNDMgNTE3LjMyLDI0Ny44IDUxNi4xOSwyNTMu'
    b'NTQgNTE4LjU3LDI1NS43NiA1MjMuMSwyNTMuNTYgNTIzLjcyLDI0Ny40NSA1MjQuOTMsMjQx'
    b'Ljk0IDUyNS41MSwyNDQuODggNTIzLjM0LDI1OC40NyA1MTguODUsMjU3LjcgNTE2Ljk2LDI1'
    b'Ny4zNyA1MTcuNDgsMjU0LjM3IDUxNS44LDI1My4yNyA1MTUuMDUsMjU4Ljk4IDUwOC42NSwy'
    b'NjYuNjUgNTA1Ljg1LDI1Ny43IDUwMi44MSwyNjAuODMgNTAyLjgxLDI2NyA0OTYuMTgsMjY2'
    b'LjU1IDQ5Mi41NiwyNjMuOTkgNDkxLjQyLDI1OC45NSA0ODkuMjcsMjU0LjkzIDQ4OC4xMiwy'
    b'NTcuMDEgNDg3LjQsMjU5LjUyIDQ4Ni41LDI2MS44NSA0ODEuNywyNjIuOTIgNDgwLjk0LDI1'
    b'Ny45MiA0NzkuNTksMjU0LjY2IDQ3OC4wMSwyNTUuMSA0NzcuNzcsMjU2Ljg5IDQ3Ni41NSwy'
    b'NTcuNyA0NzEuMzcsMjU1LjYgNDcxLjc3LDI0Ny45MiA0NzEuMywyNDEuMTEgNDcyLjU2LDI0'
    b'Ni44NSA0NzIuNCwyNTQuMDIgNDc2LjgzLDI1Ni41OSA0NzkuNTQsMjUzLjg0IDQ3Ny42OSwy'
    b'NDYuNzQgNDc3LjY2LDI0Mi40OSBaIE0gNDkyLjg2LDI3Ni41IEMgNDk1LjA0LDI3OS41OCA0'
    b'OTUuMjIsMjg0LjY1IDQ5OC4xMSwyODcgNTAxLjg1LDI4NS41NyA1MDIuMDIsMjgwLjU5IDUw'
    b'My4zNiwyNzYuNzcgNTAzLjM2LDI4MS40MiA1MDIuNDgsMjg4LjkyIDQ5Ny4wMSwyODguMTEg'
    b'NDk1LDI4NC44NiA0OTMuNzksMjgwLjgyIDQ5Mi44NiwyNzYuNSBaIE0gNTAzLjkyLDI5Ni40'
    b'IEMgNTAzLjc1LDI5NS4wNCA1MDQuNzMsMjk2LjY5IDUwMy45MiwyOTYuNjggNTAzLjUsMzAx'
    b'LjEzIDUwMi42NywzMDcuNTkgNDk5LjIyLDMwOC4wMiA0OTUuMzQsMzA4LjQ5IDQ5NC45Niwz'
    b'MDEuMzMgNDkzLjk3LDI5Ny41MSA0OTUuNjcsMzAwLjQxIDQ5NS45LDMwNC43OSA0OTguOTQs'
    b'MzA2LjM1IDUwMS42NiwzMDQuMSA1MDIuNDIsMjk5Ljg4IDUwMy45MiwyOTYuNCBaIiAvPgo8'
    b'cGF0aAogICAgaWQ9IkF1Z2UiCiAgICBkPSJNIDUwMi44MSwxNDMuOCBDIDUwMy42NiwxNDQu'
    b'MDYgNTAzLjY4LDE0NS4xNSA1MDQuNzUsMTQ1LjE4IDUwNi4wMSwxNDQuODggNTA2LjUzLDE0'
    b'My44MyA1MDguMDYsMTQzLjggNTA5LjM0LDE0Ni4zNiA1MDIuMTYsMTQ3LjI4IDUwMi44MSwx'
    b'NDMuOCBaIgogICAgc3R5bGU9ImZpbGw6I2ZmZmZmZiIgLz4KPC9zdmc+', 'DE_BB')

DE_BB = b64_DE_BB
index.append("DE_BB")
index.append("Germany Brandenburg")
catalog["DE_BB"] = DE_BB
catalog["Germany Brandenburg"] = DE_BB
country["Germany Brandenburg"] = ('DE_BB', '', 1)
lookup["DE_BB"] = ('DE_BB', '', 'Germany Brandenburg', 1)
lookup["Germany Brandenburg"] = ('DE_BB', '', 'Germany Brandenburg', 1)
details["DE_BB"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_BB"] = ('DE_BB', 'Germany Brandenburg', 1)
regional["Germany Brandenburg"] = ('DE_BB', 'Germany Brandenburg', 1)
#----------------------------------------------------------------------
b64_DE_BE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhRE9DVFlQRSBzdmcgIFBVQkxJQyAnLS8vVzNDLy9EVEQgU1ZHIDEuMS8vRU4nICAnaHR0'
    b'cDovL3d3dy53My5vcmcvR3JhcGhpY3MvU1ZHLzEuMS9EVEQvc3ZnMTEuZHRkJz4KPHN2ZyB2'
    b'aWV3Qm94PSIwIDAgMTIxNTAgNzI5MCIgd2lkdGg9IjFlMyIgeG1sbnM9Imh0dHA6Ly93d3cu'
    b'dzMub3JnLzIwMDAvc3ZnIiB2ZXJzaW9uPSIxLjEiIGhlaWdodD0iNjAwIj4KIDx0aXRsZT5G'
    b'bGFnZ2Ugdm9uIEJlcmxpbjwvdGl0bGU+CiA8ZGVzYz5kaWUgRmxhZ2dlIHZvbiBCZXJsaW48'
    b'L2Rlc2M+CiA8cmVjdCB3aWR0aD0iMTIxNTAiIGZpbGw9IiNlMjM4MmEiIGhlaWdodD0iNzI5'
    b'MCIvPgogPHJlY3QgeT0iMTQ1OCIgd2lkdGg9IjEyMTUwIiBmaWxsPSIjZmZmIiBoZWlnaHQ9'
    b'IjQzNzQiLz4KIDxwYXRoIGQ9Im01NTIwIDIxMDVjLTU2LTI3LTE1Ny0xMS0yNTAtMjYtMTg3'
    b'LTMwLTIxMC04My0yMTAtMTIyLTEtNDEtMzgtNDMtMzggMSAxIDI2MCAzOTIgMTI3IDUwMyAx'
    b'OTRtLTEyNzctMTM2YzEtNzAtNDctMTE1LTg5LTExOSAyNSAyOSAzMCA3MSAzNCAxMTItOC01'
    b'OC01MS05Ni04OC05OCAyMCAyMSAzMSA2NCAzMyAxMDYtNi0zMi0zNi04MC04Ni04NSAyMyAy'
    b'NCAzMCA2OSAzNSAxMTAtNy0zNS00My03NS04My03OCAxNyAxNCAzMSA2NSAzNCAxMDQtNS0x'
    b'Ni0zMy01NS03Ny02MCAyMyAyMSAzMyA3MiAzNyAxMTJtMTc1IDk1NGMtMTItNTUtNjAtMTEz'
    b'LTExNC0xMDYgMjUgMTcgNDQgODEgNTEgMTIyLTE3LTQ2LTU5LTk1LTEwOS04OSAyNyAyNCA0'
    b'MyA4MyA1MyAxMjctMjctNTEtNjAtODktMTA5LTgzIDMzIDMyIDQ1IDg4IDUzIDEzMS0xNi0z'
    b'Ni01My04MC0xMDMtNzUgMzEgMjggNDQgODkgNTUgMTM0LTIwLTI3LTUwLTY1LTk3LTYxIDMx'
    b'IDMwIDQ1IDg5IDU4IDEzNG00MjIgMTcyM2MtNTMtMzItMTI2LTIxLTE2MCAyMyAzOC03IDk0'
    b'IDE0IDExNiAzMi0zNi0yMy0xMTEtOS0xNDAgMzEgMzQtOSA4OSAxNCAxMTggMzEtMzgtMTMt'
    b'OTctMTAtMTM0IDM1IDMxLTcgODIgMTAgMTE1IDI5LTQ3LTExLTkzIDctMTIwIDM5IDQxLTkg'
    b'ODcgMTUgMTE1IDI4LTUzLTEtODUgMjAtMTA0IDQyIDM0LTcgODYgMTEgMTI0IDMxbTE0NjEg'
    b'OGMtNjktOS0xMjYgMzMtMTQzIDgyIDE5LTE1IDc5LTI0IDExOC0xMi01NC0zLTEwOCA0MS0x'
    b'MTkgODEgMjItMTggOTItMjMgMTE4LTEyLTQ5IDItOTYgMzktMTEwIDgwIDIzLTE1IDg3LTIx'
    b'IDEyMy0xMi01MyA4LTkxIDQ2LTEwMyA4MSAzMi0yMSA3NC0xOSAxMjYtMTYtNTQgMjAtNzIg'
    b'NDMtOTAgNzkgMzAtMTkgODMtMjAgMTM1LTE2IiBmaWxsPSIjZTIzODJhIi8+CiA8cGF0aCBk'
    b'PSJtNTM2NiAxNjg5bC0yNDQgOWMtMTIgMS0yMSA3LTIxIDIxIDEgODggMTggMTQ1IDgxIDE5'
    b'MS04IDQ5LTMgNzQgNDggMTE1IDUtNDAgMjEtNTggNDYtNzUgMiAxIDQgMSA1IDItMyAxOC0z'
    b'IDM3IDEgNDggMTAgMjggNTkgMjkgNzIgOSAxMiAyOSAzNyAzMCA1NyAzMCAyMSAwIDMxLTE1'
    b'IDM4LTI5IDEyIDEwIDI0IDIxIDM1IDM1IDM1IDQ4IDQxIDExMCA0MSAxNjlsLTMzIDN2LTI0'
    b'Yy0xLTM0LTgwLTQwLTk4LTExLTIwLTIyLTgyLTE4LTgyIDE3djExYy0xNC0xOC0yNS0zNy0z'
    b'NC01Ni0yNSAxNi00MCAyOC0zNiA4NS0xMSAxLTIyIDItMzIgMyAxIDY2IDMwIDg0IDI2NiA3'
    b'OSA2IDY2LTYwIDEwMy0xMDkgMTM0LTEyOCA3My0yNjMgMTUzLTMzNiAyODctNjEgMTA2LTc2'
    b'IDIzMi02OSAzNTRsNzAtMzEgOCAzOGMtMTI2IDYwLTM1NiAxODItNTA3IDI1Mi0zNyAxNy0x'
    b'MzMgNDEtMTUzIDctNjktMTE5LTEyNC0yMDktMjA0LTMwMC00MS00Ny0zMTMgMTc4LTI2MyAy'
    b'NTQgMTE0IDE3MyAzMDAgNDIxIDYxMCA0MjMgMzIxIDIgNjAwLTExNiA2NjEtMTM0bDEzIDQx'
    b'Yy00MSAxOC03NyAzMS0xMjAgNDUgNTYgMjIwIDEyMSAzMDYgMjcyIDQ0MGwtMzEgMjNjLTI3'
    b'LTE2LTczLTY3LTk4LTkxLTMyMSAxNTItNDQxIDMwNC01MTggNDYxLTg1IDE4OS02OSA0MDQt'
    b'MzMgNjAzIDcgMzMtMjkgNDktNTYgMzktNzQtMTctMTE1LTkxLTE4Ni0xMTgtMzItMTQtNzQt'
    b'MzAtMTA5LTI0LTU3IDEwLTExOCAyOTgtNjAgMzI2IDEwOCA1MyAyMjYgNjQgMzQ2IDEyNiA3'
    b'OSAzMiAxNTUgODQgMjQ1IDcwIDUxLTUgMTAyLTQwIDEwNy05NCA0NS0xOTQgMTA4LTQwMCAy'
    b'NTYtNTQwIDcxLTcwIDE2My0xMjYgMjU0LTE2OS0zNi0xMzgtNjMtMjc2LTYwLTQyMGw0NC0y'
    b'YzMyIDU0OCAxNzggNjYzIDQzNSA5MTggMjYgMjYgMjQgNzUtMTQgOTAtNTAgMjUtMTA5IDI2'
    b'LTE2NiAyOS02MSAzLTE1IDM0MSA3NSAzMzggMTU4LTUgMzIyLTEyOCA0MTctMjQ5IDQwLTUw'
    b'IDg4LTEwMCAxMjYtMTQ5IDQ3LTYxLTQtMTMyLTE4LTE4OC0zOS0xNjAtNTctNjIwLTU5LTY4'
    b'NGw1NiAxIDgtMTE2Yy0xNjctMjA3LTE0MC01MzEtMjA5LTc0MC0yNy04NS01Ny0xNzMtNTct'
    b'MjYzIDAtMTIyIDEzOC0zNTEgMTM1LTU1NS0xLTg2LTQ5LTE5OC00OC0yNDkgMS0xNDggODYt'
    b'MTE2IDg0LTQyNC0xLTg1LTExLTE0OC0zMy0yMzUgMTQ5LTE1Ny01Ni0zMTQtMTc0LTIxNi05'
    b'NS0yNS0xMDctNTAtMjkzLTUwLTE1OSAwLTI1MCA0My0zNDkgMTA5bS0yODggOTE4Yy0xMDUg'
    b'MTI5LTE2NCAxOTQtMTYwIDUwNy05OTEtNTY2LTcwMS02NDctOTE4LTk4NS0zNC01MyAxODct'
    b'MTc2IDI1Ny0xMjQgMTQxIDEwNCA4OSAzMDAgMjA2IDM4OSAxMTYgODggMzIzIDEyNyA2MTUg'
    b'MjEzbTYwNS03MjdjLTE1IDAtNDItOC01MC0xOS04Ny0xMzMtMTA5LTg1LTEyMi0zOS0xMSA0'
    b'MS01OSA0Mi00NS0xMyAzNS0xMzUgMTMwLTExNiAyNDggNzFtMjU1LTEzNWMyNC0zMiA2MS02'
    b'MyAxMDEtNzYgNTktMjAgODMgMjggMzYgNDQtMzkgMTctNzIgNDEtMTAwIDY5bS04MTMgMTM2'
    b'YzE1IDkgMzYgMjAgNjcgMjktMTcgMTQtMzMgMzQtMzggNTYtMjctMTktMzgtNTQtMjktODVt'
    b'MTYwIDUzYzAgMTMtMyAyNi03IDMyLTEwIDE2LTQ3IDE1LTU1LTctMy05LTMtMjUgMS00MCAy'
    b'MCA1IDQxIDkgNjEgMTVtMTIgM2MyNyA4IDUzIDE3IDc2IDMyLTUgMTItMTQgMjQtMzIgMjQt'
    b'MTYgMC0zNC0xLTQ0LTIwLTUtMTAtMy0yNCAwLTM2bS0xMTMgMjY1Yy0zLTI4IDAtNTIgMjIt'
    b'NjggMTEgMjAgMjMgMzkgMzcgNTZ2N20xMC0wLjV2LTMxLjVjMC0zMyA3MC0zMSA3MSAwdjI1'
    b'bTktMXYtMjhjMC0zMyA4MS0zMSA4MS0xdjIyIi8+Cjwvc3ZnPgo=', 'DE_BE')

DE_BE = b64_DE_BE
index.append("DE_BE")
index.append("Germany Berlin")
catalog["DE_BE"] = DE_BE
catalog["Germany Berlin"] = DE_BE
country["Germany Berlin"] = ('DE_BE', '', 1)
lookup["DE_BE"] = ('DE_BE', '', 'Germany Berlin', 1)
lookup["Germany Berlin"] = ('DE_BE', '', 'Germany Berlin', 1)
details["DE_BE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_BE"] = ('DE_BE', 'Germany Berlin', 1)
regional["Germany Berlin"] = ('DE_BE', 'Germany Berlin', 1)
#----------------------------------------------------------------------
b64_DE_BW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1MDAiIGhl'
    b'aWdodD0iMzAwIj48cGF0aCBmaWxsPSIjRjlDNzAwIiBkPSJNMCAwaDUwMHYzMDBIMHoiLz48'
    b'cGF0aCBkPSJNMCAwaDUwMHYxNTBIMHoiLz48L3N2Zz4=', 'DE_BW')

DE_BW = b64_DE_BW
index.append("DE_BW")
index.append("Germany Baden-Württemberg")
catalog["DE_BW"] = DE_BW
catalog["Germany Baden-Württemberg"] = DE_BW
country["Germany Baden-Württemberg"] = ('DE_BW', '', 1)
lookup["DE_BW"] = ('DE_BW', '', 'Germany Baden-Württemberg', 1)
lookup["Germany Baden-Württemberg"] = ('DE_BW', '', 'Germany Baden-Württemberg', 1)
details["DE_BW"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_BW"] = ('DE_BW', 'Germany Baden-Württemberg', 1)
regional["Germany Baden-Württemberg"] = ('DE_BW', 'Germany Baden-Württemberg', 1)
#----------------------------------------------------------------------
b64_DE_BY = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSIgc3RhbmRhbG9uZT0i'
    b'bm8iPz4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIg'
    b'Imh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+Cjxz'
    b'dmcKICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB2ZXJzaW9uPSIxLjEiCiAgIHdpZHRo'
    b'PSIxMDAwIiBoZWlnaHQ9IjYwMCI+DQogIDx0aXRsZT5SYXV0ZW5mbGFnZ2Ugdm9uIEJheWVy'
    b'bjwvdGl0bGU+DQogIDxkZXNjPkRpZSBSYXV0ZW5mbGFnZ2UgZGVzIEJ1bmRlc2xhbmRzIEJh'
    b'eWVybjwvZGVzYz4KICA8cmVjdCB3aWR0aD0iMTAwMCIgaGVpZ2h0PSI2MDAiIGZpbGw9Indo'
    b'aXRlIiAvPgogIDxwYXRoIGQ9Ik0gOTYzLjU2MjUsMCBMIDc0Mi4zNzUsMCAxMDAwLDU3MCAx'
    b'MDAwLDYwMCA3OTIuMzc1LDYwMCA1MjEuMTg3NSwwIDMwMCwwIDU3MS4xODc1LDYwMCAzNTAs'
    b'NjAwIDE1MCwxNTcuNSAwLDExOS4yNSAwLDMxNSAxMjguODEyNSw2MDAgMzUwLDYwMCAwLDUx'
    b'MC43NSAwLDMxNSAxMDAwLDU3MCAxMDAwLDM3NC4yNSAxNTAsMTU3LjUgNzguODEyNSwwIDMw'
    b'MCwwIDEwMDAsMTc4LjUgMTAwMCw4MC42MjUgeiINCiAgICAgICAgZmlsbD0iIzAwOThkNCIg'
    b'Lz4KPC9zdmc+Cg==', 'DE_BY')

DE_BY = b64_DE_BY
index.append("DE_BY")
index.append("Germany Bavaria")
catalog["DE_BY"] = DE_BY
catalog["Germany Bavaria"] = DE_BY
country["Germany Bavaria"] = ('DE_BY', '', 1)
lookup["DE_BY"] = ('DE_BY', '', 'Germany Bavaria', 1)
lookup["Germany Bavaria"] = ('DE_BY', '', 'Germany Bavaria', 1)
details["DE_BY"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_BY"] = ('DE_BY', 'Germany Bavaria', 1)
regional["Germany Bavaria"] = ('DE_BY', 'Germany Bavaria', 1)
#----------------------------------------------------------------------
b64_DE_HB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz48c3ZnIHhtbG5zPSJodHRw'
    b'Oi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjYwMCIgaGVpZ2h0PSI0MDAiIHZpZXdC'
    b'b3g9IjAgMCAxMiA4Ij48cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwSDEyVjhIMCIvPjxwYXRo'
    b'IGZpbGw9IiNkMDAiIGQ9Ik0wIDBoMVY4aDFWMEgxMnYxSDB2MUgxMnYxSDB2MUgxMnYxSDB2'
    b'MUgxMnYxSDAiLz48L3N2Zz4K', 'DE_HB')

DE_HB = b64_DE_HB
index.append("DE_HB")
index.append("Germany Bremen")
catalog["DE_HB"] = DE_HB
catalog["Germany Bremen"] = DE_HB
country["Germany Bremen"] = ('DE_HB', '', 1)
lookup["DE_HB"] = ('DE_HB', '', 'Germany Bremen', 1)
lookup["Germany Bremen"] = ('DE_HB', '', 'Germany Bremen', 1)
details["DE_HB"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_HB"] = ('DE_HB', 'Germany Bremen', 1)
regional["Germany Bremen"] = ('DE_HB', 'Germany Bremen', 1)
#----------------------------------------------------------------------
b64_DE_HE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'DQo8IURPQ1RZUEUgc3ZnIFBVQkxJQyAiLS8vVzNDLy9EVEQgU1ZHIDEuMS8vRU4iDQoJImh0'
    b'dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8IS0t'
    b'IFRoaXMgZmlsZSBpcyBpbiB0aGUgcHVibGljIGRvbWFpbiAoUEQtRmxhZy1HZXJtYW55KSAt'
    b'LT4NCjxzdmcNCgl3aWR0aD0iMTAwMCINCgloZWlnaHQ9IjYwMCINCgl4bWxucz0iaHR0cDov'
    b'L3d3dy53My5vcmcvMjAwMC9zdmciDQoJdmlld0JveD0iMCAwIDEwIDYiPg0KCTxkZXNjPkNp'
    b'dmlsIGZsYWcgb2YgSGVzc2U8L2Rlc2M+DQoJPHJlY3QgaGVpZ2h0PSIzIiB3aWR0aD0iMTAi'
    b'IGZpbGw9IiNFMTAwMDAiIHg9IjAiIHk9IjAiLz4NCgk8cmVjdCBoZWlnaHQ9IjMiIHdpZHRo'
    b'PSIxMCIgZmlsbD0iI0ZGRiIgeD0iMCIgeT0iMyIvPg0KPC9zdmc+DQo=', 'DE_HE')

DE_HE = b64_DE_HE
index.append("DE_HE")
index.append("Germany Hesse")
catalog["DE_HE"] = DE_HE
catalog["Germany Hesse"] = DE_HE
country["Germany Hesse"] = ('DE_HE', '', 1)
lookup["DE_HE"] = ('DE_HE', '', 'Germany Hesse', 1)
lookup["Germany Hesse"] = ('DE_HE', '', 'Germany Hesse', 1)
details["DE_HE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_HE"] = ('DE_HE', 'Germany Hesse', 1)
regional["Germany Hesse"] = ('DE_HE', 'Germany Hesse', 1)
#----------------------------------------------------------------------
b64_DE_HH = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIgd2lkdGg9IjYwMCIgaGVpZ2h0PSI0MDAiPg0KPHJlY3Qgd2lkdGg9'
    b'IjYwMCIgaGVpZ2h0PSI0MDAiIGZpbGw9IiNkYTEyMWEiLz4NCjxnIHN0cm9rZT0iIzAwMCI+'
    b'DQo8ZyBmaWxsPSIjZmZmIj4NCjxnIHN0cm9rZS13aWR0aD0iMS4yIj4NCjxwYXRoIGQ9Im0z'
    b'MDkuMyA3NS4zN3MwLjUwNzgtOC44NDgtNy4yODctMTAuMjR2LTkuNTI1aDYuMjd2LTQuMDY3'
    b'aC02LjI3di01LjIwNGgtMy44ODZ2NS4yMDRoLTYuMjd2NC4wNjdoNi4yN3Y5LjUyNWMtNy43'
    b'OTUgMS4zOTEtNy4yODcgMTAuMjQtNy4yODcgMTAuMjQiLz4NCjxwYXRoIGQ9Im0yNzcuOSA5'
    b'NC45MWg0NC4xNGMxZS03IC0xMS45OC0xMS4xMS0yMS41OC0yMi4wNy0yMS41OHMtMjIuMDcg'
    b'OS42LTIyLjA3IDIxLjU4eiIvPg0KPHBhdGggZD0ibTMyMi45IDEwNS41IDIuNS0wLjg1M3Yt'
    b'OS43NDdoLTUwLjczdjkuNzQ3bDIuNSAwLjg1M3oiLz4NCjxwYXRoIGQ9Im0zMjIuNCAyMDAu'
    b'NnYtOTUuMTFoLTQ0Ljg1djk1LjExIi8+DQo8L2c+DQo8cGF0aCBkPSJtMjA3LjkgMjc2Ljdj'
    b'Ny4zNzEtMzMuNCA0LjY5OS02Ni40OCA0LjY5OS02Ni40OGgxNzQuOHMtMi42NzIgMzMuMDgg'
    b'NC42OTkgNjYuNDhjNy45OTkgMzYuMjYgMTUuMTcgNDguOCAxNS4xNyA0OC44djE0LjU5aC0y'
    b'MTQuNWwtMC4wMTktMTQuNTlzNy4xNDgtMTIuNTQgMTUuMTUtNDguOHoiLz4NCjwvZz4NCjxn'
    b'IGlkPSJiIiBmaWxsPSJub25lIj4NCjxnIHN0cm9rZS13aWR0aD0iMS4yIiBmaWxsPSIjZmZm'
    b'Ij4NCjxwYXRoIGQ9Im0yMzMuOSA4Mi4zOWg4LjM2NXYxMS4xM2g1LjR2LTExLjEzaDguNjg4'
    b'djExLjEzaDUuNzE3di0xMS4xM2g4LjMxOXYyMS45MmwtMi43OTIgMS4yMDVoLTQ1LjQ2bC0z'
    b'LjM2MS0xLjIwNXYtMjEuOTJoOC43NDV2MTEuMTNoNi4zODN6Ii8+DQo8cGF0aCBkPSJtMjIy'
    b'LjEgMTA1LjVoNDUuNHY5Ni40M2gtNDUuNHoiLz4NCjxwYXRoIGQ9Im0yMzIuNiA2OS4zIDQu'
    b'MTItNy4xMy00LjEyLTcuMTNoOC4yNGw0LjEyLTcuMTMgNC4xMiA3LjEzaDguMjRsLTQuMTIg'
    b'Ny4xMyA0LjEyIDcuMTNoLTguMjRsLTQuMTIgNy4xNC00LjEyLTcuMTR6Ii8+DQo8cGF0aCBk'
    b'PSJtMzAxIDE4NS40aC04LjAzMXYxMy4wNmgtMTMuMDV2LTEzLjA2aC0xNC4zNHYxMy4wNmgt'
    b'MTEuOTZ2LTEzLjA2aC0xMy44OHYxMy4wNmgtMTEuODd2LTEzLjA2aC0xNi4xN3YyNC43NGwz'
    b'Ljg1MiAwLjkzOTVoODUuNDUiLz4NCjwvZz4NCjxwYXRoIHN0cm9rZS13aWR0aD0iMiIgZD0i'
    b'bTIyMi4xIDEwNmg0NS4zNiIvPg0KPHBhdGggc3Ryb2tlLXdpZHRoPSIyLjUiIGQ9Im0yNjYu'
    b'NCAzNDAuMXYtNzMuNzhjMC02LjY4NyA5LjA0NS0zMC44MSAzMy42LTMwLjgxIi8+DQo8cGF0'
    b'aCBkPSJtMjc3IDM0MC4xdi02OS44NGMwLTExLjM5IDkuMDc0LTI0LjQzIDIzLTI0LjQzIi8+'
    b'DQo8cGF0aCBpZD0iYSIgZmlsbD0iIzAwMCIgZD0ibTI4My45IDMyMS4zYzAtMy4xNiAxLjE4'
    b'LTMuMTYgMi4xLTMuMTYgMC45MyAwLTAuMTEgMS4yNy0wLjExIDNzMSAzLjMgMC4xMSAzLjMt'
    b'Mi4xLTAuMjgtMi4xLTMuMTZ6bS02LjktMC4xaDYuNDUxIi8+CjxwYXRoIHN0cm9rZS13aWR0'
    b'aD0iMiIgZD0ibTE5MyAzMjUuNWg3MyIvPg0KPHVzZSB4bGluazpocmVmPSIjYSIgeT0iLTUw'
    b'Ii8+DQo8L2c+DQo8dXNlIHhsaW5rOmhyZWY9IiNiIiB0cmFuc2Zvcm09Im1hdHJpeCgtMSww'
    b'LDAsMSw2MDAsMCkiLz4NCjxwYXRoIGQ9Im0yMTIuMiAyMTAuMmgxNzUuNm0tMTEwLTEwNC4y'
    b'aDQ0LjE2IiBzdHJva2Utd2lkdGg9IjIiLz4NCjxwYXRoIGQ9Im0zMDAgMjQ1Ljh2OTQuMjci'
    b'Lz4NCjwvZz4NCjwvc3ZnPg==', 'DE_HH')

DE_HH = b64_DE_HH
index.append("DE_HH")
index.append("Germany Hamburg")
catalog["DE_HH"] = DE_HH
catalog["Germany Hamburg"] = DE_HH
country["Germany Hamburg"] = ('DE_HH', '', 1)
lookup["DE_HH"] = ('DE_HH', '', 'Germany Hamburg', 1)
lookup["Germany Hamburg"] = ('DE_HH', '', 'Germany Hamburg', 1)
details["DE_HH"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_HH"] = ('DE_HH', 'Germany Hamburg', 1)
regional["Germany Hamburg"] = ('DE_HH', 'Germany Hamburg', 1)
#----------------------------------------------------------------------
b64_DE_MV = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz48c3ZnIHdpZHRoPSIxMDAw'
    b'IiBoZWlnaHQ9IjYwMCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNMCAwSDEwMDBWNjAwSDAiLz48cGF0aCBmaWxsPSIjMmI1OGEz'
    b'IiBkPSJNMCAwSDEwMDBWMTYwSDAiLz48cGF0aCBmaWxsPSIjZjlmNDAwIiBkPSJNMCAyODBI'
    b'MTAwMHY0MEgwIi8+PHBhdGggZmlsbD0iI2RlMDAyOSIgZD0iTTAgNDQwSDEwMDBWNjAwSDAi'
    b'Lz48L3N2Zz4K', 'DE_MV')

DE_MV = b64_DE_MV
index.append("DE_MV")
index.append("Germany Mecklenburg-Western Pomerania")
catalog["DE_MV"] = DE_MV
catalog["Germany Mecklenburg-Western Pomerania"] = DE_MV
country["Germany Mecklenburg-Western Pomerania"] = ('DE_MV', '', 1)
lookup["DE_MV"] = ('DE_MV', '', 'Germany Mecklenburg-Western Pomerania', 1)
lookup["Germany Mecklenburg-Western Pomerania"] = ('DE_MV', '', 'Germany Mecklenburg-Western Pomerania', 1)
details["DE_MV"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_MV"] = ('DE_MV', 'Germany Mecklenburg-Western Pomerania', 1)
regional["Germany Mecklenburg-Western Pomerania"] = ('DE_MV', 'Germany Mecklenburg-Western Pomerania', 1)
#----------------------------------------------------------------------
b64_DE_NI = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5OTE3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfTG93ZXJfU2F4b255LnN2Zy5wbmciCiAgIHhtbG5zOmlu'
    b'a3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgog'
    b'ICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQv'
    b'c29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5'
    b'L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5z'
    b'OnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRl'
    b'ZnM5OTIxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3OTkx'
    b'OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'CiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIi'
    b'CiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hl'
    b'Y2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIK'
    b'ICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc5OTIzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBUAprVWxFUVZS'
    b'NDJ1MmRlMENUVjVyR255OFhFbkl4UmhTSTNNb2xsSXZpQlJFV3JVWUtVblVjcklyZ1NtMFZ0'
    b'WXF1NnpyMTBqS09Pekt1Cmw1WnBPMVFkTzZoWXhUTHNDS01WS2c2Q0lrVkJCS1FLTFFnU2xK'
    b'aEF1QVFpSkNFazgwY3FvNks3YXFza2VuNS9rZk9kODcySFBEbVgKOXoxdnZnQUVBb0ZBSUJB'
    b'SUJBS0JRQ0FRQ0FRQ2dVQWdFQWdFQXVGVmhScEUyellXOVU2MUFVYnllYkZvR0tSamorUVRJ'
    b'TVRzeGNzSApma00rVzQrREF3ak1Ya0tPZVhlUFJtWklTOGNpSlRRQUJ4a01BUHZaN0E0aW9j'
    b'WDErQXFOdHNQYXVtWHAwcVZjYnNDUkkxZkpQc3V5CnVxc0dzbUppVnNYRjBlbjA4Z2tUUEQw'
    b'OVU1eWRwelkya2xGb0dlaUJpM1I2dDByVjJOam81T1EwYnR5NHI3NzZTaHNhK2hlZzZCVjIK'
    b'Mml4R1FpUHdzVWcwcTZFaFlkY3VYMTlmUHAvdjQrT3pidDA2TFVWRmxaZDM3ZDJiVENRMFo3'
    b'cUIvVk9tYkR4L25zbGtwcVdsM2JoeApvNmFtaHNQaE9EZzRoSWVIdi8vKysxRlJVVk95c3Nw'
    b'ZVNRbnBnMnQrRnVEeC85VTV4MlJlaUkxZCtlbW5iRFpiSkJMNSsvdjcrZm5aCjI5c0RvQ2pL'
    b'eDhlSHorY2ZQWHAwcWtUeTV6Tm54clMzYzMvcFR0WUJXUUFOTUpCUitBeWN0clllY3V6WWF4'
    b'TW50cmEyamh3NUVnQ2YKeisvczdBVFExZFdsVkNybGN2bU1HVFBHamgwTDRFOUZSVnRmZjUx'
    b'TXBPWkZ2YTJ0bzZNamo4ZHpjbkxxTHl3cEtRSFExTlNVbHBiRwpZckVFQW9GRUlxSFJhRWFq'
    b'VVRCbVREZHhLc3dLR3lBb0tDZ29LS2lpb2tLbjA3SFpiTFZhM2Q3ZWZ2cjA2VHQzN2pDWnpH'
    b'SERoZ0VZCk9uU29WcXZsOFhpVEprMDZsNVUxOCs1ZHNoYWF5MXJZcGRYK282Zm43ems1eDQ4'
    b'ZjkvTHkrcC9nNE1zZmY5eWVubjVhcmJhenMxdTkKZWpWRlVRQnFhMnRGSXBGVUtuVjJkdjZy'
    b'VERhaHVwcjF5cXlGNWk2aGsxN3ZmZUhDNVlzWHU5anNXOGVPYlZZb0pobU5yd1BXNjljNwpP'
    b'anA2ZTN1YnF2WDI5c3BrTXAxT0p4UUt0WHA5ZDNhMnd5c2pJU05wa0F4cmdRK2V1UElxb3hF'
    b'VkZmMHZqL1A1YStmTmEybHA2Uy9oCmNEZ3NGb3VpS0NhVFdWQlE4TzV6NlBBdXdNbzhKWnc1'
    b'ZUs3ZUI4L1VzQUp3L3VRVEd4c2JHNXNIanYyVlNxVlFLT1J5dVJzM2Jzd3AKTC9lcXJmMWxP'
    b'enpkWEUrZExDek1yUUN1YmRnUXUyTEZRK1ZNSnBQTDVYWjBkS2hVcXR6YzNHNTdlK0pVbUNs'
    b'cDN0NGJ0MjJUU3FVUApsZk40UElGQXdPVnkyV3gyUTBQRDBBc1hudXEyUFlEbHVpSVdkbEl4'
    b'WXM2Y2E5ZXVhVFFhRnhlWCs4c3BpcnA5KzdhUGowOTlmYjI3CnUzdmZFOSt3a01Gb1hMclVL'
    b'eXhNcTlGOG41WVdrNVhGSWFQdytiRWJDQTROdlh2MzdzU0pFMnRxYW96R0J3NG5BZ0lDa3BP'
    b'VDVYSjUKbjE3LzJwUGRzSXJCY01ySitlMysvVysrK2Fhcm0xdENadVkzOGZGZnpwOS9rc1Vp'
    b'by9CbjBRR2tMMS91R1JRRXZmNzI0Y01MaW9xcwpnSDlRRkNNdWJ0cTBhVGR2M3J4OCtYSndj'
    b'TERKSSt5SHkrVlNGTFZ2M3o3bjgrY2puOHpROTFGUkg0YUVHSTNHOHZKeWc4SEFaREtuCnpK'
    b'aGh2MlJKeCtiTlo5NTRZM3BQRHhtRno4Z3hENCtWSDMyazFXclZHczNhckt4VFc3Y2VjWEFv'
    b'OWZWOSsrMjNpNHFLYW1wcUJBTEIKUS9vQjBHcTFDeFlzV0xKa2lST2ZyM3N5UTladWJxWkpP'
    b'Q1FrSkRRMFZLVlMxZFhWV1ZsWitmdjdLNktpeUVUNmpHVHcrZTlsWmpZMQpOZFVYRkRBTkJq'
    b'NmZ2M3JUcG1YRnhZTHc4Q2xUcGlpVnl1N3VickZZUExDaGxaVlZZV0doVUNoY2VmMTZmbUpp'
    b'eW9RSnVReEdMWEFICnVBWGNBcm9HTkZHZU9kUGIyOXYvVWlBUUxGNjgyQlNNNVRnNmtvbjBX'
    b'Y2htc2NablpucDZldjZIcCtjbXFWU2FscGFrMGF4Y3Q2NnQKcmMzWjJmbjI3ZHZPenM1Y0xw'
    b'ZjE0Rm9sbFVwZFhGd29pZ29QRDVmSlpCcU5adFg2OVZpL3ZydTdXeTZYdDdlM0ExQ3IxYlhO'
    b'elZYNQorY3hqeDM2dFVsa0RBQ0tMaTNldFcvZmJQWHNlOGI1b05FVENwOE1BL01YV2RtWjYr'
    b'dFNwVXcrbnBFUkxwVDJBQzlDMFpjdTVNV09PCkhEM3E1dWFtVXFuczdPeE1SMDczazVPVHMy'
    b'TEZDZ0QyOXZiMjkzbUVIQTdIemMzdGdhcVJrVjI3ZHUzYnZ0MDVNWEdpWHM4SDFCa1oKMkxO'
    b'SHFWUldWbFlHQndlejJXeFRSWmVKRTJYQVNES1JQamtucmEzWGxKWWFEWWJWaXhkWGJkcjBQ'
    b'WTlYY3VCQTZydnZ5dGpzQTlIUgpHbzNHeDhmbjZ0V3JJcEhvb1lhNXViazAybFA4RjN3K2Yr'
    b'UE9uV01xSzlOalk1UEhqL2ZjdGczQUI5SFJoWm1aVFUxTlAzMmVESWE1CmtaSGYrdnVUVWZn'
    b'VXFFYU4wbWcwbVFjT0xFNU5iV0F3N0hKeTlBYkRrcFNVdmdNSGZ2enh4OHJLeXJhMnRyeTh2'
    b'TkRRVUFlSGYwV3cKZTNwNjVISTVqOGQ3V25QZTN0N3VlL2RLcFZJK243OHJQajcyN05tckJR'
    b'WE9mL3hqLzdBT0RBeGtlM3ZqeWhVaTRaT2l2WEZETEJiSApiZG55ZVhPenNMNStlMGpJdFd2'
    b'WFVsSlMzbnJyTFI4Zkh4OGZId0RUcGsyN2N1VktjM1B6dUhIalRLMTZlM3Y3LzM0cW1wcWEr'
    b'dnI2CjFxOWFOZmZzMmRrQURXaGZ0b3pKWkFMUTZYUXRMUzF5dVZ4dklibU41aktSV2xsWmRY'
    b'WjIwbWcwVjRsa2FHTWpnTjBmZmpoeXlaTFAKL1B6S3lzcjZoODdzMmJQdjE0ekg0ems2T3Zy'
    b'NitqNnRPUWNIaCtycTZqVWJOZ3dIMk1BcE83dk5uMzl1dW1RNnRLcXZyN2N2S1NFUwpQZ1gw'
    b'cnE3aTRtS3hXTnoyd3cvV3ZiMGFqV2FvWHU4QnJHaHArV2I2OVB6OGZJVkNZZkxoN20rbFVD'
    b'aXNyYTJmd2R5bFM1YzZPenVECmc0TXZNUmdBZWh3Y2REcWRWcXZ0NmVuUjYvVXltYXk2dWpy'
    b'QVFqYWw1aUxodk83dS9EVnJzck96MmJtNUhFQ24wN2xKSkNhWDdaM1cKMXJMdzhKVGs1SXNY'
    b'TDE2NmRLbXVyZzVBUlVWRmVYbjVzbVhMenAwN1YxeGNiUEljbmhDajBWaFZWVFZxMUNnK245'
    b'L0Y0UUJnMXRjcgpGQXFGUXRIZTNxNVdxeW1LWXJGWU9TeFd1U1ZJU05VTmt1RnVZRFN3Rndp'
    b'L3I3QWNjQVZLckt6ZTEyZ2FHaHJPZUhxRzZmV21TN2VBCnJ4MGRSMFJGalFvSVlMRllQVDA5'
    b'U1VsSmtaR1JBUUVCY3JtY3dXQkVSRVFNRE5rODJvRXhHSEp6Y3dVQ2dZdUxTN3lYVjd4S3BR'
    b'TE8KSlNRNGUzdTd1TGpJWkRJL1A3ODVBUUd1RE1ZN2N2bFk0QXl3Q3ZqZVhNOEx6Y3UxTjYx'
    b'eUhTTkdVQlNsMFdpcU9aeXd6azdUSlNkZwo0KzNiZlltSjU0RnpFZ2tsbFM2NGVmTnlaK2ZJ'
    b'a1NNakl5TWY2VmYwOWZVMU5qWmFXMXZiUDNoOFNGR1VTQ1RpOFhpTmpZMUdmMy9rCjVRa0Ex'
    b'OS85cm1IbnpyeThQRnRiMjhyS3lyQ0ZDNWNtSlZsRXROc2N3OXdxa1VpcFZCNWN2MzdOUGYz'
    b'K3RXUUNJVURJdVhPbWw3KysKZnIwNE92cmRMVnM4b3FQL2JmSmtOemMzR3hzYnRWcDk2OWF0'
    b'YTlldVhiOSsvY2FOR3drSkNYZnUzSGxvNDlyUzBxTFJhQndkSFlkNQplQ0F2RDRDZjBWaDQr'
    b'SEIyUzh1a2tKRHJSVVVyNCtPbGdDZVI4Qm5YNThwS21Vem1PMy8rbnRiV21XVmw3bjMvMS9G'
    b'ZklCQllXOXVkCmtGQUJsQUpkQUIrd0J4eUFYdUE0c0xLbEpUQXdNQ3dzakVhakdRd0dGb3Ns'
    b'RW9ra0VrbFpXVmxiVzV2MlhnSk9EVkJhVlJVQmRCOC8KL3BaWUxLdXJtMm9oQVRiYTRCcCtw'
    b'RGh2NkhSOWZYM3Z4Y1l1VDBuSkMzbWk3K0p6Z0dBZ0dsZ09SQU1Td0J1WUFSd0VoQXpHckZt'
    b'egpFaE1UeFdKeFlHQ2cwV2pzNk9qbzYrdHpkM2YzOVBSazh2bGFBSUFuY0JBWUQ2elU2NlUy'
    b'TnJ5REIvdVRuZlJtdGZFekh3blpBUDB4CjZRNWk0TlQrL1VxbGtzUGgyQVlFL0J3ckhzQm5G'
    b'eTlTTTJaTUx5anc5L2FPaW9vYU1tVElsQ2xUbUV5bVVDaWswV2p6VnF3NEZoYlcKWDc4TTJB'
    b'd0VGQmJPYTIzdEwxUURESUJOSkh6azBIbWtoQlFnU2t2THpjMTFjbks2ZTI5SCtzeXdBREd3'
    b'RUNnMUduOS8vdnhwaWVSWQphdXBQcXdpRE1XblNwSldIRHAyOGx3eTNGdmd6RVBIZ0hlNENQ'
    b'Smd2Z3luaE1LRGxNWmRDVkNyZXdvVWJoRUx0Z1FPL1dBQUljQUxlCjYrMnRqSW1KaVlrcExT'
    b'M3RqOVNNVGt0THNiSFJQcVpoTXlBMFl3bnAvemw0dGdzQU5mQzRSTllSd0VTZGJ0eHp5SDRZ'
    b'QStUWTJEUTAKTnljbUp1cDBPajgvUHc4UEQ3L1kyUDh1TFEyOGVYUGdCdThJSUFSbUV3a0hj'
    b'aDI0Q2l3YWpKbEhvVlRHWjJlUEhqMzZpK2pvczk5OQo5NnVvS0I2UHg3S3phMDVOdFJ0UVB3'
    b'a1lEMHdtRStsQXZJRWJqOHFIZUFIOFNxM09PWDA2TUREUWRjS0VSVGs1T3hNU0FMaTZ1ZzQ4'
    b'Cm0yZ0hiZ0krWkMxOEpNRkFIM0I1TUV3UEJYNG9MQVF3ZHVGQ0NxQjI3bFFvRko2ZW51VURV'
    b'Z0l1QWdZZ2tFajRTT3dBVjZCd2tLeHIKVkNvQXk1Y3Z6L1h3bU5mYm01R2VUbEdVWGNSRHUx'
    b'RVVBaDZBSFpId2NVd0hUajNHd1grdTlBSm5LeXRyYW1yb2RIcVBueDhMa0JVVgpBUWlkTjYv'
    b'OHdXbzVEd2JpaVlRUE14ZG9IWXlCK0hkNys1TTVPYmEydHBPR0RYUE55QUNncWE0R0lKRkl2'
    b'dlh5NnE5MkZ1Z1k0Q1lTCkNSK09ub3dCanJ4WW8vbEM0ZmhEaDRZUEg1Nzh4UmM3T2pybW1B'
    b'WWNsd3VBVHFlUGlZdVQzYXY1RlRBT2NEZHZDUm5jMEVIdXdlb2IKV05HQTY0RHZDekZYQmZq'
    b'bjVibTR1SFIxZFZXbnBzN3QxN1crL3NTSkV4RVJFV0t4dUFFWUNaUUR4VUN5RTdqbS9SQU55'
    b'ampZejlzeApHT0ExQ2E1YTdIc2g1cElEQXJZWEYzZDBkTWpsOHZqRml6OHBMUVZRUUtjN25q'
    b'NDllZkxrWllzVzhiT3lWbXUxSENBR2FHT2k2anZRCnpQdnJYNE1mZjZmUmtQQU96Z0FGejkr'
    b'V0hKaXdhUk5GVVhRNnZlektsWkRHUmdEZldWdlR2L3d5TkRRME15TmpWa2JHQnEyV0EyUUIK'
    b'RjRHRUtIUFh6eXhHb1luUU1OUzFJdXM1SHdpMEFOODRPTkRwZEp0YnR3S01SanRBQ3h5T2kx'
    b'c2JIOS9lM3Y2YlJZdjJYcjBLUUExTQpCOFlJa0pNM3VBK2dmN0sxMEV6NnNXODN4c2JpRDhB'
    b'Zm5xZVZFY0RTZXluYlAyMU5CWUwxVzdmYTJ0cXkyZXdodzRlYkNqOEM3Z0pmCjdMQUEvV0Er'
    b'QjVuaWNVaUt4dGZBcVJkcnR6a2lncUtva3BLU3ozYnNDQ3dvQUhBTXlBS1NJaUFPZ2tWZ0xo'
    b'T3BpY1Z6OGJjR0hBWmUKMkxjWkNvQU93QTRZRHpDQkM4QXlJTVlSaDA3Q1VqQXZDWFVhaE05'
    b'RVJRZStIb3pVbzBwZ0VSREV4N2VuWU1XM0dBbk5LeVBFaW8wVAo2WEMxeHI4REwvaWgyOFhB'
    b'WXNDTGhjeDBTOUlQWnBqVU0yUTQ4bzdEaDQ4WUlPOUZHYzBDbGdCak9jaE53eEE3V0JibW1K'
    b'YzExQjY1CldaaHVpeFhBeDg4NUNLNERmZytzQldZTng1bFRFTHJBNGpEVDFEbzJENW5mWW1j'
    b'SURnSUxnS3JuWTZVQ21BZjhGZGc5QVgvTEJuc28KTEJIejJzNE01TklKTE51QkgzU0lBVmIv'
    b'Y2orMnBnRCtCS1FEbzVqNGNnTUM1OE55TVhjSkFlaTErSFFUdGwrQXpvZ29ZQ253Y3g1VQoy'
    b'UWdrQS84TGNJR1BndkZmdTBIbndLS3hBQWxOdE12d1dRTDJsS0RkaUFCZ0RpQUJiSjltMk9V'
    b'RG1jQVZ3SVpDbkMvV2JZUHdOYndFCldJeUVKcnBia2I0SHFYbkk3MFFmNEFGTUFEd0FkMkFr'
    b'd0FGTWo4ZS9DM1FEVFVBZFVBZVVBUFVBQTVqR3c2SnBtQjhIcmgxZUdpeE0Kd242VXRjZzlq'
    b'cnhpbE1oUTMvdllORGcrNE01RWdBZ2hFeEU2RjhPOThQSmhxUkxlajFHTDIxZlJXQWVWQ3Aw'
    b'ZEFNQVhZS2dBenU1dwo5QU5salplYmwwSENWeHp5RTVSRVFnS1JrRUFrSkJJU2lJUUVJaUdC'
    b'U0Vna0pCQUpDVVJDQXBHUVNFZ2dFaEtJaElSbjVwOUE5TFdHCkNoSzN3Z0FBQUNWMFJWaDBa'
    b'R0YwWlRwamNtVmhkR1VBTWpBeU1pMHdNeTB5TUZReE1EbzFOVG95T1Nzd01Eb3dNSWhxZmNJ'
    b'QUFBQWwKZEVWWWRHUmhkR1U2Ylc5a2FXWjVBREl3TWpJdE1ETXRNakJVTVRBNk5UVTZNamty'
    b'TURBNk1ERDVOOFYrQUFBQUFFbEZUa1N1UW1DQwoKIgogICAgICAgaWQ9ImltYWdlOTkyNSIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'DE_NI')

DE_NI = b64_DE_NI
index.append("DE_NI")
index.append("Germany Lower Saxony")
catalog["DE_NI"] = DE_NI
catalog["Germany Lower Saxony"] = DE_NI
country["Germany Lower Saxony"] = ('DE_NI', '', 1)
lookup["DE_NI"] = ('DE_NI', '', 'Germany Lower Saxony', 1)
lookup["Germany Lower Saxony"] = ('DE_NI', '', 'Germany Lower Saxony', 1)
details["DE_NI"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_NI"] = ('DE_NI', 'Germany Lower Saxony', 1)
regional["Germany Lower Saxony"] = ('DE_NI', 'Germany Lower Saxony', 1)
#----------------------------------------------------------------------
b64_DE_NW = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIj8+CjxzdmcgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIw'
    b'MDAvc3ZnIiBoZWlnaHQ9IjQ4MCIgd2lkdGg9IjgwMCIgdmlld0JveD0iMCAwIDUgMyI+Cjxk'
    b'ZXNjPkNpdmlsIGZsYWcgb2YgTm9ydGggUmhpbmUtV2VzdHBoYWxpYTwvZGVzYz4KPHJlY3Qg'
    b'aGVpZ2h0PSIyIiB3aWR0aD0iNSIgZmlsbD0iI0ZGRiIvPgo8cmVjdCBoZWlnaHQ9IjEiIHdp'
    b'ZHRoPSI1IiBmaWxsPSIjMDA5MTM2Ii8+CjxyZWN0IGhlaWdodD0iMSIgd2lkdGg9IjUiIHk9'
    b'IjIiIGZpbGw9IiNlMzAwMWIiLz4KPC9zdmc+', 'DE_NW')

DE_NW = b64_DE_NW
index.append("DE_NW")
index.append("Germany North Rhine-Westphalia")
catalog["DE_NW"] = DE_NW
catalog["Germany North Rhine-Westphalia"] = DE_NW
country["Germany North Rhine-Westphalia"] = ('DE_NW', '', 1)
lookup["DE_NW"] = ('DE_NW', '', 'Germany North Rhine-Westphalia', 1)
lookup["Germany North Rhine-Westphalia"] = ('DE_NW', '', 'Germany North Rhine-Westphalia', 1)
details["DE_NW"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_NW"] = ('DE_NW', 'Germany North Rhine-Westphalia', 1)
regional["Germany North Rhine-Westphalia"] = ('DE_NW', 'Germany North Rhine-Westphalia', 1)
#----------------------------------------------------------------------
b64_DE_RP = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjk5MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1JoaW5lbGFuZC1QYWxhdGluYXRlLnN2Zy5wbmciCiAg'
    b'IHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lu'
    b'a3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdl'
    b'Lm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'CiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAg'
    b'ICAgaWQ9ImRlZnMxMjk5NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5h'
    b'bWVkdmlldzEyOTk0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3Nj'
    b'YXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1v'
    b'ZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEyOTk4'
    b'Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgog'
    b'ICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1y'
    b'ZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFn'
    b'ZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJP'
    b'VjZuQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFB'
    b'Q0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVU'
    b'QUFBTgpLRWxFUVZSNDJ1MmNlMVJVMTcyQXZ6UER3REM4MFFFVVVSd1FWRUR3V2dJYWNqV0dS'
    b'N1JxMURRK0VqVSthalJ0MVRTbWlVMXVhcHZVCkc2OVJFMDAwdHVscW9ubFpFeHZqTldvVk5D'
    b'cjRDQm9SRUVVZXlrc1lZRVFlTXd6RHpKeitnU0l2YmY1Z2tyalcvaFpyemN6ZWM4NVoKNi9m'
    b'TjcrekgyUnNRQ0FRQ3dZL0g0RUNtakwxcnJjcEpST2luUWNwb1VrYmo2ZGExUE1pZjB6c3dI'
    b'T1d4Y1YyckpJbmswUnpjZ2lTSgorRGtjUmR0TGVIRFAxVEhoL044S05yMklYZTVVcnZYQlVJ'
    b'K2ZEN1Uza1dXbVBkeXBWcGFabFVMMEVJWU43dm0waVhFb0ZDTDR2VWRBCkgrcU9NWDhLMERX'
    b'eUF3UFFwNUt6Qy9zNWxzM0N4UmxBcWVEZ0ZxN3N3WHFXa3grUyt6bjZWSWJlL2hHRUI1Tzlp'
    b'NW9qWE56Tmp0ZHgKMTNTOTNQTnphRDdOMkZFaThMMlhoVlVHOXFlVEZNOXJ6N0x0WmZ4OGI5'
    b'WE5TT0xRZStodllLZ25QWXZ4c2Roc0RBekFadWRnQmtFQgpITTNrMkRuOCs1QnhnZUlLeG81'
    b'Q2traUlRZTNNNlJ3VUVzbngvRHpoVnRZQ0Q4ZVN1bzNGMDhuSzU3dExJdmk5ZWlQMWNHUGNL'
    b'S0xECm1KakF5SEFHQnhJWlNub1dOeHZ4OXVEai9Renc0NlhOdUd2NGVqT3hFYno5S1k4c0lU'
    b'R08yQWhPNS9Dci84WGZsOC9YTVNhYS9la1UKVjFCVFIwQWZkcWZ4ajBPc1c4SHZGNkpVOFBK'
    b'Q05Hb0N0UlNVMG1nU3dlOVZoZjIxZkxpWHlmL05ubS80MXltV3orWXZyNkEzTUdZKwo2ZWRa'
    b'UHB1djA2bXFSU0hSMkl6ZGpvOEhWaHZBeUhBS3kwRmlhREFWZWdwTE1UWlRYTTZqWXppWHg2'
    b'ck5LQlg0ZWxGV2hjM09obytJCkRHSGJGNVRyUmVSN0RXWGJpLzRHY3lkUldNcWMvMEdXOGRB'
    b'd0tvSnZjd25veTFNVE9aWEtsQW00cWxuNk9Gb2ZJa0tJR2Nxdm4rRFUKV2Q1ZlRlSlVwbzVq'
    b'ekFqTXJjeEtaa0lDSVlHOCt6eHpsdUNtSVRtZUlVRVlHamlWVFptZW53Mm4xY1pMbTdEWlJm'
    b'QjdoenU5L25FLwo0K3ZOdkxPVFZpc0pNZmg2WW1qZ2FnVnhrZXpjeklMZmNTb2JUM2VVQ3Bw'
    b'TUdNMG9KR1F3bVhGVEE5anN1S2lRb2JHSjBJRmNyeUkwCkdFc3J6UzFFaFZKbHdGVk5vNUdZ'
    b'Y0NLblUxd3BJdThBaGFOaHdYT01pcVdrRWlRc3JUUWFzZHB3VW1LelliTWpnNHVMdTBYMnRk'
    b'aTkKV20zT0NpY1BwZExKY09hWXByRVZzRWs0ZWFEVTROb0hsUyt5QktCMlJsSmdzU0JKS0JS'
    b'bzFHZzlXZk1ianNvaThyM0duUm1VRWkzTgp6bVRtMFdqRVNhV3lxU0lLemxUNGZWZmoyY0FB'
    b'RzhXd3FLckszOSsveS9HL2MzVmRZRzd0VW1nSEExeUhTakE0WWUyRHl5QzhJM0hXClVXRmcz'
    b'QktPYmhPUmQ0REN3VUd1eFkxSk1iR1B4VWJIUkVaR09qczd2elp0MnB5NlBXMjFGbENyMVYw'
    b'T2JtNXVMaktiZSt3amFVRUwKMFlBVjlLQ0hiMm1Bcy9CeFNCQ1VpZEQzdnNMU21yN0x4ejAx'
    b'WThhTU8xMGRKNmVPMzdQYnUvWkFLaXNyaSs5K2FqTzBnRWQ3cnhjOAo0Yi9BdzBzckZEcEVJ'
    b'U0IxbnROVWRQaG83MG5oNWN1WGkwRHUyS0pDQS94VHArdTNhRkZnUkVSMVRZMWt0VmJzM3o5'
    b'cTM3NWhzbWdBCkhUa3UvRDdkbnU0S2MzTnptK0JhaDVLTENrWDYycld2WHI0OElDTGl3dW5U'
    b'RmFXbFdDekx0bS92ZS9Mazd2Nzk2U3hiME1zS0pVbVMKT3lkS3h5eFU5S1R3eElrVHdMZTNQ'
    b'OWFDZnZQbVNUTm52aFFXNWpkMXFqSXJLeXc4UEg3RmlyLzE2OWRZWFQzdDJMR0RYbDRxc0Zn'
    b'cwpJdTZPVW1pejJUcW5ublNQdHRCa01oMDVjZ1E0Y3J0ay8vanhBMEpDVnN5Y09lWGFOUzIw'
    b'Z3JOYXJZU1VscFpQbHk4dktpcHFXcm15CkNSVGlJWVdERkZvc2xpNlNiQjBVS3JzcFBIRGdn'
    b'TWxrQWpMQUREZGgyT0xGK1hsNXIyN1pvanB4NHIyUUVLTy8vNW5UcHoveTg4dmMKdW5YYmxT'
    b'djc5dTc5OWZQUHAyczAzYk5aMER2ZEdWbVdNL2J2cjg3SlVTZ1ViVkUyWjJXMTEzckIzeFlz'
    b'MEdnMFZxdTFyZVRMa3BKYgpRd3M0QWw0d0lUSHg3VWNldWZEaWkxVXpadmd2WFRyeDBVZkxD'
    b'd3BVRXlmbW5UMzc1OEdEQS9WNnA0MGJqZEhSOXZwNkVYZUhLTFRiCjdjSEhqejlXWHQ3ajl3'
    b'YkQ0TU9IMnovV3dCODYxUDRUbmdBdkx5KzV2djVobSszOFo1OFp4bzNidDNGanplSERxN0t5'
    b'UGs5SytwWE4KZGhhc1ZxdE5vMEVvZE5DTjFHNjN5OTk3b2NSbllPM3c4VGhJVUZKUzBqcDgr'
    b'TGJ4NDhOemNnb0tDdWF1V2ZPbi9QdzMxNjE3K2RxMQpZMisrZWNEZjM5WFZWVlZSb1ZLcFJO'
    b'eDdFV1g3TzdWYW5hQldELzhlS1dLRzU2QzVRNGtNQWRDaTB3Mk1qOWM5K0dEcVcyL0ZmL0RC'
    b'CmV4a1pwd29MVTlhdi8yTG56bjRwS2E2UmtYYTczWFBEaG1NQkFYcTllTnJrbUxhd1FKS09R'
    b'OVB0RW45b1h4MVJENW1lbmlpVlRaQnQKTk43b05qRDRBZ1p1MkpCdzhPQ3VyVnVUdi9vcUVQ'
    b'TGo0aDZZUEZteGNlT1RsWlZiMTY5Zm5aR3hic0dDWjBBV1kzd0g0ZTN0dlduVApwaHUzTVp2'
    b'TmF4Y3ZMb0sydjYrZ29LQkFsbVd6MmF6VDZUb2U2QWRlQUx3QUx5WW5tMHltSGUrODgwZGYz'
    b'eVdUSnExZHUvWlZGNWMxCjgrY2JqY1pOcTFlZmd5SVlFUlVsb3Uyb0xGU3IxVDQrUG5kdXNo'
    b'MEdjTzJONUpZdFc0cUw3OHlNTG9NSG9BQU93dC9oNEtGRGErUGkKRXRhdm4xTmJtNTJkWFY1'
    b'ZVBzRmt5c3ZMV3pkejVvUjkrN3h2WDBuRTNTRUt1MlB2ck5CbXN4a01oalZyMXJRWDl2V20z'
    b'MnlzbmpoZgo0dHhlM04zNXE0bmY1K1JVcEtTODRlOXZqNGlRbkp4eWYvdmJpTUxDZVVMYkQ1'
    b'T0ZYYWE1VVNvN2pmUnR0aGRlZUdGbzQ0MHlCZjN0ClhJR3dRU3g4SEkwTFRZK3dQWXZLV2dx'
    b'aXVYQ2VhSmlsMTNPM1BvdlE2YUJCaFN6THJhMmRIdDVLbmJNd0xTMnRNbTE3eWlSTy9EKzYK'
    b'Sk55aE5ZZkVhYnk1ZzM1OW1mb3dreDVDMjRkVllMN25KZTFkcHZFRXZhWFFhclYybmIzc2tK'
    b'UldXTFZxVldHOUhCQU9rSHFXTWpEcgpXTFNFaFk5aHRwQ1JoYXNMbzRaeEJkNjQ5eVdGUWdm'
    b'ZFNMdWtZTnRvcjUwUHdHUXkrWTFBRjR4R3pkSmZVRmxMVWp5SmNWZ3NuTW5CCnpSV05taXNs'
    b'QUovQVE1QjRONFZpcDBYdktuejM5cnYwYmlPMjl0bm9qK0FyQU01ZG90R0lxNXBucHRQVVRQ'
    b'VU5QdHpMZ3pHNHVhSTMKRUJxRTJvV0lFQzRXc1JLK0JGMVBsOVFwRkw4VWdlOUZoUlBhQis5'
    b'V2E1YzZGMWRYNEJpODN2NXRKVzk5ak41QVhCUktCWUYrSUZGVQp6cWNIeUM3QTI0TjF6MUZR'
    b'aXQ1QTdVMmVodDNnMSsyU0xxMnRFMFRnSFhFajlZSzZ1cnBPWFZCWnZnakxvSzN0MHZwUTEw'
    b'QlFBS1ZWCkdKc1oxQThaaXN0cGF1Wm9Ka0JHRmxjcjZLL0ZhdU9iczF5SCtiQUQrblk0WndQ'
    b'NE9EdUx1RHVrTytNTFpXV2RWaVVaWlhraEdHRTgKakZCUlUwZG9FR2xueU1vbk1oUnZENjVY'
    b'OC9Sa1huK1dMemZnN1lITnpwRk1YbHBBaStYVzNwcDhtQThkZnhmWHdVOG9kSkRDWVZEZQpR'
    b'V0ZlWHQ3N24zeFNDMG1RdEpSZC8rQ2pQL1BoYS94cks1KzlnYmNITlhYTStUa21NeGNMU1I3'
    b'TjE1dHhWdkgzUGRUVzhld1RtTXkzCjlybGRncmxRZS91MHhXcDFvTkVvNHU0UWhaN1FXbHA2'
    b'OWVwVklETXpjK3pZc1JVVkZVQW1LQzV6NENSVHhoSVp3b2doWEsraHJvR0MKVXBLZlpkWXFp'
    b'aXVvTWpBbW1wVnpzZGxKUFVOTUdGUEgwZGY3MXViQ1N6RDc5ckxEYTRNRzZZcUtSTndkTmNF'
    b'V1ZsMmRscGJtNCtNegpiOTY4dGtVVmdBazJmb1ArRzg3bFVWS0psenNuemlQTEtKWFVOUUQ4'
    b'OGpXK2ZKdUFQcXljeTdzN2FXcW1zcGJ5YWlKREtDaWx5UVJRCkRKUGhkU2h4ZGg0a1ptZDZG'
    b'YWxqUnVUQ080bUphV2xwOTM0ZTVPSk12NzVFaGZMa284amNraFFiUWRRUXp1ZWpkdUh3S2Ri'
    b'djRIcE4KdHdOZFhGWUZCczRyTGhaeGQxUVdSb0pYZGJWS3BmcVA2d1FIQnJCeUhnOUVZSmZa'
    b'ZTVUVmYrR1ZSUXdOWnVjQlBqMUlaVzNQUncwTgpDVW5KeXhOQmQxUmIyTWJVN096ZzRPQjdI'
    b'OU5pUWVYRW9BQ2F6VXhmeVpPdllMVXhPcHE2UnZyNDNOV2ZsNWRYaXNYaUwwTHUwQ3dFCnhr'
    b'Q00wVmpyNjN2anhvMGVKbFlnd0owNkxSTVRjSFVoUFl2VU13QzZRQUsxMURmaDdzWWZucUhK'
    b'Ukc0UmgwNTFPalpXcDN2cS9Ia1IKOFY1SHVhSmIwY2pHeHJOQlFWVU5EVjBXZkdvZ1BwRDN0'
    b'NU1ZVDJJY2ZiMzU3akpmcEFJME5LR1FTQm1ObXl2R1pxNWRaOWVoVHVjYwpQblRvaXF0WGRk'
    b'Mm1ZUVc5ZnlNRitzQ3lLMWRpWTJLNlBMZ3dnYjZaYjdNWjFBK0ZSTG1lUFVkdkpiS21uc0l5'
    b'Z09KeTRxTTRuOS9wCmhHRmhZUXZyNitQRWNQQUg2SkYyNUxna2JZMkt5cnAwcWVNVGpDRVE3'
    b'TUxoRmg0YWlWMG10NUQ2SnBUd3htVG1MYWVwbVNCL2RxZngKNU10M3poTVJFZkZFVGMzYzZt'
    b'b1I2eDlhSVhBRzNoODE2c0xWcXoyMmkzZjZLVEE3bEtkZjVUZHJrU1RLOU9nTkFKSWtKY1RG'
    b'VFM4cwpuRkpiS3dMOTR5Z0VhdUh0QVFOeWZYd3VYcng0dDcwUUVpaGdxZ2U3Rys4VWhvYUdS'
    b'bmw2THNyS0dpWjJVUHk0Q3RzNExFbXBVVkdWCkhoNjV1Ym4xOTF3ckxFbFNlSGg0QUNSWFZU'
    b'MSs4NmI0WDRnL0ZZVnRuSUtUZ1lINVd1MzFsaGFsVW1tMVdzdkt5bHBhV3JSYXJhZW4KcDBh'
    b'amtWcGFSc3J5UTRXRkQ3YTJpdjFuUDBXRmJjaVFEL2xnOFBIQng4Y0NhcFBKcmFvcUhJYUIy'
    b'QzF4SHlnVTNBZmpRb0ZRS0JBSwpCVUtoVUNnUUNnVkNvVUFvRkFvRlFxRkFLQlFJaFVLaDRI'
    b'N0J5UzFKQk9IK1JwSy9FMEVRTjFLQlVDZ1FDb1ZDZ1ZBb0VBb0ZRcUZRCktCQUtCVUtoUUNn'
    b'VUNnVkNvVUFvRkFpRlFxRkFLQlFJaFFLaFVDZ1VDSVVDb1ZBZ0ZBcUZBcUZRSUJRS2hFS2hV'
    b'Q0FVQ29SQ2dWQW8KRkFydUwvNE5EUVVIdllpNnlaQUFBQUFsZEVWWWRHUmhkR1U2WTNKbFlY'
    b'UmxBREl3TWpJdE1EY3RNVFpVTURNNk5UYzZORGdyTURBNgpNREFsSVIzMkFBQUFKWFJGV0hS'
    b'a1lYUmxPbTF2WkdsbWVRQXlNREl5TFRBM0xURTJWREF6T2pVM09qUTRLekF3T2pBd1ZIeWxT'
    b'Z0FBCkFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTMwMDAiIC8+CiAgPC9n'
    b'Pgo8L3N2Zz4K', 'DE_RP')

DE_RP = b64_DE_RP
index.append("DE_RP")
index.append("Germany Rhineland-Palatinate")
catalog["DE_RP"] = DE_RP
catalog["Germany Rhineland-Palatinate"] = DE_RP
country["Germany Rhineland-Palatinate"] = ('DE_RP', '', 1)
lookup["DE_RP"] = ('DE_RP', '', 'Germany Rhineland-Palatinate', 1)
lookup["Germany Rhineland-Palatinate"] = ('DE_RP', '', 'Germany Rhineland-Palatinate', 1)
details["DE_RP"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_RP"] = ('DE_RP', 'Germany Rhineland-Palatinate', 1)
regional["Germany Rhineland-Palatinate"] = ('DE_RP', 'Germany Rhineland-Palatinate', 1)
#----------------------------------------------------------------------
b64_DE_SH = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBzdGFuZGFsb25lPSJubyI/Pgo8IURPQ1RZUEUgc3ZnPgo8'
    b'c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKCXZlcnNpb249IjEuMSIK'
    b'CXdpZHRoPSIxMDAwIgoJaGVpZ2h0PSI2MDAiPgoJCiA8cmVjdCBpZD0iYmx1ZV9zdHJpcGUi'
    b'IHdpZHRoPSIxMDAwIiBoZWlnaHQ9IjYwMCIgZmlsbD0iIzAwMzlhZCIgLz4KIDxyZWN0IGlk'
    b'PSJ3aGl0ZV9zdHJpcGUiIHdpZHRoPSIxMDAwIiBoZWlnaHQ9IjYwMCIgeT0iMjAwIiBmaWxs'
    b'PSIjZmZmIiAvPgogPHJlY3QgaWQ9InJlZF9zdHJpcGUiIHdpZHRoPSIxMDAwIiBoZWlnaHQ9'
    b'IjYwMCIgeT0iNDAwIiBmaWxsPSIjZDYxODEwIiAvPgo8L3N2Zz4=', 'DE_SH')

DE_SH = b64_DE_SH
index.append("DE_SH")
index.append("Germany Schleswig-Holstein")
catalog["DE_SH"] = DE_SH
catalog["Germany Schleswig-Holstein"] = DE_SH
country["Germany Schleswig-Holstein"] = ('DE_SH', '', 1)
lookup["DE_SH"] = ('DE_SH', '', 'Germany Schleswig-Holstein', 1)
lookup["Germany Schleswig-Holstein"] = ('DE_SH', '', 'Germany Schleswig-Holstein', 1)
details["DE_SH"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_SH"] = ('DE_SH', 'Germany Schleswig-Holstein', 1)
regional["Germany Schleswig-Holstein"] = ('DE_SH', 'Germany Schleswig-Holstein', 1)
#----------------------------------------------------------------------
b64_DE_SL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMzIwMiIKICAgd2lkdGg9'
    b'IjE2NyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NhYXJsYW5kLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MzIwNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEzMjA0'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEzMjA4Ij4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE2NyIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFLY0FBQUJrQ0FJQUFBQnNDTGVoQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBVgppVWxFUVZS'
    b'NDJ1MmRkMXhUVi8vSFA5a0pJWXhBV0xLWEdxWVdaMVdVb2tXc1VxdW9xTlhpejFscmZlcHFy'
    b'VkpySDJ1SFZXdnIxbFlyCkRyU3RFeFFFeEFFSUlpQkRJT3dsSklTWmtKM2MvUDZRK3JOOXBP'
    b'M3ZEMzA5c2ZmOUYvZmNzM0krOTV6elBkOTd6Z1VnSVNFaElTRWgKSVNFaElTRWhJU0VoSVNF'
    b'aElTRWhJU0VoSVNFaElTRWhJU0VoSVNINXAwSXhyZXJhMjlzSEJBVDh0OVdxdExSVUxCYWJV'
    b'RFBTVFV2MQo4ZVBIK3djTlRjNHUvZnRKREhvZGpjNzR6M0J6bXNiVHlhYS9WSXFXRm5wcks0'
    b'UEoxR20xSFJ5Ty9jQ0JOQnJ0bVRGZFhWMEZBc0daCk0yZEkxWjhqMTdLS2E3d1dXM1lVeUJr'
    b'Q2c3bVRvN3hRYkJrQ0N0Vk9VYVpVYVhwdGh6eU94cFVWZWhxejFEcDYzS2hmUDc2NzBrRGoK'
    b'ZHNIRDF0Z3U1bzh5NnRTMDlqSmZUdGYrL1Z2N0srVndWRlQ0dlh0TW9WQmJWcllPK096c1dY'
    b'dDcrMmZHWExac21jbTFJZFUwNXlXcQpRTjk4Y0xybEJGNzFWQi9LWk9wTkFKTWNPOGN3aTQw'
    b'R1hWOFhwNW5IZUNldEN2NWxrSnR1Zy8vK0laVHpFYTZxVUdjZFU5dTFjV2lYCmtGcjFUNTdY'
    b'NlNaYTcxcFdBSjNCakI3bHBsY3JpaW95WUlQRUJtNm5PcGhxd1FCZzFmVmdtSzFxd1BCTFJZ'
    b'VUZ3LzFuVWVSM3E4dEUKZFUyV0hucnh4dERPbWRQZXNPWlFqbDEvK0k5VjNTVDd1b3VxZE5k'
    b'a016YUxPZlgxTUdjbkIxRjFIWUF1TXgrcVkyRGd4ZlhlZVNjWgpUT2E3MGFHMmZPdWdvQ0Ft'
    b'azVtVGswTnB2RU1ReEFSLys1MnBMYlBtTCtxV3RzSklrS3FiRXRMMmp2alVvaVZMbDVXV2x2'
    b'SjR2TzgrCmZWOS9lNmVSTUFDVVFodjNoYmsvdlphMGQwL1V2TTJob2ZmVDBnd0d3NW8xYTZK'
    b'bnZHV2tVRHZiV3ZVODV3cWJ5SzIvbGhzSlBUbkMKbXhKcWw5QjhJR2dzMXV4TkNyWW5SZ1Q2'
    b'SmgrT0t5NHQyMzZqb1hmc3luVld6cTVXVkNzdTU0TTNnK2wwdWxnczd1bnBFZGp3YWJydQpi'
    b'ZzNOcHp0OStJalJGaUYraWJsVnBPb21CcUdSUHpBUGc1SFE1KzZhUEg3a2lSTW5Ra0pDVm9V'
    b'WU9SYVBhbm1Xdmg3T2RCYkgxOWRYCnI5Y2JqVVkybTMwKzhicnlrWGtQb1I0M1pGQmlkdUhP'
    b'ZFc4bjVsU1NJN3dwWVRUb05nUzBlVWl2VStqc2NrSFVWenQyUmtaR1ptWm0KOW5SM0JRN3lt'
    b'RGRyZWtoSXlKQkFmMHRMUzUxT0o1UEplRHhla1FSbWpqNWFDcnZid0s1bCtuMjg2eWZTaGpl'
    b'NWhSdXRwa2tpMWxzQwpZRGdNTG1hYUpXV1ZEQjA2VkNnVVNxVlNsVW8xY3VSSXFWUktwVkpW'
    b'S3BWSUpPSnl1ZDFPNDZrMGVxaFh6L0V5SXNLMjZWclBLSDlHCkE5blhUVXoybit1dDFjNWpB'
    b'SmgxbGk0UWFrY0ZEV1F5bVFrSkNVbEpTUllXRnBtWm1UZHYzbXhwYVZHcFZOYlcxdHYySnpn'
    b'eVpLdUYKYmExeWc3bjBQc2ZLTWFBM3c2alhrSDNkeEtEWmVoc05lZ3FOb2JRSlBKOS81L3kx'
    b'akMyTFhsK3laRWxTVWxKQ1FvS0hoOGV4WThkNApQRjUwZEhSdWJxNkVzR2JUSEcvbFhCYVp2'
    b'N3A0QW5QZjNjN1RheGU5dXkzK3k1VXIrOHRmVWw0ZS90VGwzZzgvNUhLNXo0eloyZHJLCk1E'
    b'YzNNZFVYbU5RYkdEdWdDUUJnVmZQcmduRWVSd3NKbFUzQUpELysrMXMzMTlaVUp5Y244M2c4'
    b'alVhVG41OXZOQm9YTFZvVUhSMjkKWXNXSzJKWHJyeHE1QmJ4SnpseERzN2g5b3BPaHRPWVJy'
    b'NzVxMW8zTS9ncHFCODREYzRCTHdIckEvcWQrN1FCUlFJQ2R2LzlDMDFKOQppMGxWOXlhUUJR'
    b'QlFPbyszNUN1K1gyQ3ZOeGplbkxaQ0lwSGN1cGtoa1VpQ2dvS21USm1pMCtsdTNickZaclB6'
    b'OC9NOVBUMFBmN3Q5ClE5eS9UM2JZMlZnenFSUm1pSyt6dGtmS1pOSVlucDc5RmVRSXZBWjhy'
    b'ZEhFZW5yYS9ua0xNcGtEQWRQeXhadW1OV2ZRREdFMzVaVXIKT0RSaTRzU0pjcmw4dzRZTjgr'
    b'Yk5Heng0Y0ZwYW1scXR2bmpweXYwcThhcTNwd2tFZ3Z6OGZBOFBqODgvK1doT1NVbnMxaDls'
    b'QS93KwptVG5qODY5MzZTbHNYVzN0bno5aE00VEM5TEt5dC82ME12ci92amUvTDZmcUUxbjVm'
    b'TDFZclNVVUtzSEZpeGRuelpxbFVxbFdmN1MxClFjR2syZm93N1BnTXI5VTBWOVgzbGRLVHQ0'
    b'NHdKSVZUSWljUEd6WXNNakp5LzRhWXN4ZVNidHk4blZmWjFrVmpKdlJmaEJ5WUJyZ0EKYk9B'
    b'bzhDZnpkamVEUWFyK0lyalc3bVlrbkZ4Wjhqa0J3dWdWY2NsM0NpdHBJYjMra3dlWXNRUE54'
    b'Q044QlJHam5icGw4dEpTS1JWagptcHJjVHB3NG9WS3BvcUtpMnRyYWZuNGd2OXRWLzM1MDJP'
    b'RXI5eGNtTi9kWHhDK3hzZmFwcVFBRVFBV3dPVCsvdnpldDFYRnhVS3RKCjFaKy9BVzgxQUVD'
    b'elZKU2FucUYzRCt0eGRPbnVaazdpRm05Nkw5YlBMeVkxTmJXK3ZpNHNMS3hES3BITDVVd20w'
    b'MkF3VEp3NGtTQ0kKKy9uNXRJQVpZanB6ei9tZitUWTJBd1lNNks4SU5wdjk5S1dUazVPRGc4'
    b'TXpZektaVEpOVDNUVFg2d0NoN0tKWXV4M3RmTlhXeVdWSApqTi9BdGl2cG1wRG90YnVibXBy'
    b'YTJ0cEVJbEYrZnNIeEs1bEhyeGJHWnoxeUh6MDlJQ0NBdytGTWpvaHdyaityNzZnWDZ5Myt5'
    b'YjQ1CjAvVEk2bFM3d25SMmxmRVVPa3R1N3JQeTgyTWl1NmtVQzBmR2dDQXJLNnZlM2w2QlFQ'
    b'RERMeW01RmxHVkR0TjdCOCtOR0NtVXlXVFYKMWRWQlFVRXB4NzlNK1plL3Q3NmNWTjNVYkhn'
    b'RzUyUnFjWXVTemxhMVVqcHJtd1hqNlh3M0MxWEQwbEdXTlRVMVFVRkJkbloyc1crRgowK296'
    b'akpwZVhadG83NFhjaVBlLy9lckFTU3FWcXRGbzJHeTJWUHlJVk4zMHlGTTQwWVBuam1CWEhv'
    b'NjJjZU1vZkkyVloxY0V1anZ5CmFUUmFkWFUxbjg4L2RlNjhwYkZuaFdlOWgrd3VkZGhpQk02'
    b'N3EvS3VxNnZyN2UybDAra2NEcHRVM2ZSZ09BZ3BkRlpXbmE2NnV2cmcKb3VEVDZ5TllUSVpP'
    b'cDVQTDVWRlJVZWN1SkZZMlNUdGNwNGc3WmIwYUlxZ3JjYmtncDZ1MWpzM21hRFFhSG85bmFX'
    b'UC9UMWJkVlAzdwpRZXFzQUFmYTYvOEswNm1WZkQ2L3RyWldxOVc2dTd1WGw1ZG5abWIrZkt0'
    b'VTV6S09RbVA4WEtxamVVVXpqYTFqUXdjNk9JcFlMR1puClowZGFXbHBScDlsUWUxSjFVNlBR'
    b'Nk4rVWRpam5WdHJSQTk5bFpHUlVWbGFXOTdBTE1oSzFxbDYxVitUR21FaHhVMTJDUnNmd0dE'
    b'TlkKazdkOG9wZGMxak03ZXVhREJ3L0VZdkVYcCsrd2h5MkZPb2RVM2RSbUpvNWw1eXZyZWhX'
    b'UGZ2anhXTUt0U2w5bi9rUG50NG5Rb1JRVwoxNHpHUEpSYllHenZvUWdaQUVxNnVaLzlkS05U'
    b'enduK0pjM1Rna2dYVzFHR0xxU3d1RkNUZmQxMFlPcmt0T3dqai84MkFLY01la0pICmxJZ2th'
    b'RDdHTURkU0tjYkg0U0FJUnVrUkFBeEFCdEFoSzIxRlpVT25sc2xuOVRRQWFGVzBidHUycmI5'
    b'U0hqWTExUUxtN2UyOVFDV3cKZS9kdUhvLzN6SmdTaVFRY0RxbjY4OFc5cS9XSHZNdDl2aHFB'
    b'Q2h5S2pWMGVGNWNRR1FtcmlvMWYvdDE4MW4rTHVMaDBCcUI3eXJMOQp3MlpwV2x1Yko5QUpp'
    b'TC8rT2g0SUFhNDhYanBTc1BRdG5FdUZUby9BNE5Gd2N5TnQrQmRFRVZCNjdseTZueDlicWZU'
    b'dzhKaC8vVHFyCjJPSFlqLysvVENaeFVYSU9mbDRJOE1ZMC9oL3ZFc0EwWUFVd0gvZ0llTExH'
    b'TnhvUklzVDRWL0RhY0hLRWY0SG9BVWZnVkdycWEzRngKc3B3Y0FDNHVMdjdIamxXOEdaWGhx'
    b'NTB3NXUvbWs2U0E5WEhjK1FGTkVyejNKZEQ1ZjdmcytQQnlSaUVMZzd5NDVTNEtSMXNJTG9L'
    b'VgpEeW9GenZZSThJR3ZHMHFxY2ZvMnVWNS8vc2lZVENWd2FkMDZlV0tpZVVxS25ZdkwydDI3'
    b'QWVoMHVvNnVydW81TWZmV29PcnZiWVNrCkFXdG1ZK1ZzOVBTQ3pVUkZmVjlnS0FCQXBVYmNF'
    b'c3JXRlpRZ1g2T25NeHBhRWZvS0V2ZkEweGx1anBBck1ESUE1YldrbCthRlFMR2wKZk1RQWg4'
    b'dWRPR1hLRncwTm8wZVBCa0FRUkdGaFlXTmpvMUt0dmtGbm4zZ0gzZksvenNvRFVIZmluWTl4'
    b'dXdEdVR2aGthWitGMkEzTQpCb1lyc1gwamQ5Tkd1Nk9uZFNvMTVrK0J1Ums2ZXRBa2hyOFh4'
    b'ZzFGb3hocDkwalZYd2oyMXVwM1BrZmV0bTJweWNtUFF4UUtSVnRiCjIvWHIxN1BUMGpnM2Ju'
    b'eW1Wci9UZzY4WFEyLzRpNnlxZ2YycG9MZEFya1JCQlNKRzQ4REhjSFZBRVhBV1NBY2F6WHZm'
    b'V3RpOWJLN0IKd2h4cURXaFUwR2xnczZBM3dHc2Foc2FncG9tYzExOFVNOE54LzZFaE1TYkdM'
    b'VGUzdUxqNDNyMTc0cnE2RFZ1MklEMzlMYW4wc1lkOQpmaFYyYk1MZk1la2ZHdkhEUlF6M1Ew'
    b'RUZ4b2Rnd1J0NFl6WFVHcmpZWSt4UU9OdHA2SFFRQkl4R0RQYkFuVUlNc0VQaUhUUkx5UFg2'
    b'CkMyZjdLc3lzNnY0aEtzcGk3bHg5UndmbDZ0VVRITTZhTTJlT2pCOC9UeVFDSUFLRTEzSE1G'
    b'N0dML2pxMytoWmN6UVNYZzVFQnFHeEEKeWo2azNNWFlJYUJSWVc2RzYzZmg2WXlxUmdUNll2'
    b'MjNtUHdxbEdvdzZJaFBoTGlEVlAzNVl5UUlDb1VLZ0VyRmoxOWcydHlLc1FVRgowdUxpZVVw'
    b'bHlkbXpPNXFiQjNkMEFDZ0Z1Q2twZW8ybWUvYXNXd1BWb2EvK1JiWmRNaHk1Z05QYmNlTWVV'
    b'dTVpM0ZBRStxQlpBb1VLClF3WmgwaWgweThGaDRjb3QyRnFDemNTdWVLaTF2ODJSVktxUk1M'
    b'RkQwYVkycjJzMERHYmZhUVFySGc1L2o3dkpGOFBFWWw5Z2hsYTcKTWlPajE5NytSbHljaXNG'
    b'UUtoU1JVNmY2bkRxZHRaWmEzZmpYR1Q5cXc4YnZJZTNDc2hudzg0S2xPWHhjd1dHam9oNmRQ'
    b'V2lTUU5TQQo5NzlHZ1FqVnpYMlNtN0VCd016TXpLalJrS28veitwMmRZSGgrT1J5a0RzKzNJ'
    b'bHNsZkpKaUxhbVp0Q2tTVzNMbDZ2a2NnQnZUSjlPCis5ZTZvd3Yvd3FUZnZRNG50K0dkcVZD'
    b'b2tYZ0hUQVlheFdnVXc5Y1ZYVEpjdVkya08waElnVmFQRUNGc0xQRitES1pQNkV0cmJXMU4K'
    b'Nis0bVIvam5DS2Vod2VYTktKWG1OSWZWRi9MNktCU3N4TG05Q0FleU5tMmlWVlY5RnhHUklK'
    b'TlJxVlFBQm9OQndXTEpnc1o5K1QrMwp0NTBCbmZhTXA1NEF0aDVDVHk4Y2JVR2g0Tk5scUcy'
    b'R3Z6Y1NVaEEyREUxaVhNK0J1QjBaOTJFMFF0cUZpU09SVjRvTEdYMDVDSVZDClJuNCsyZGVm'
    b'STdiTnpUNCt2by9hZmhmNFVTeEt3M0VUbUxsaXhkcXpaL2ZXMWo2V1hLUFJ4TWZIKy9uNTFY'
    b'WjNLNnV4WTlNek1nem0KWVA4R2FMU3d0a0JNQktvdVljWnJDQjhCZ3dFZVRuaFlneEFoam0r'
    b'Rmt3QkdJd0RjTDhQaDg2QUFZNGRBWUEwQWJtNXVBMnByU2RXZgpJNjRFUWFkU0N5cCs3N2Vo'
    b'NE1pL2tlS0w3K2JNMFdnMGRuWjJCb05CcVZUS1pMTHk4dkxEbXplUGFtMWRCVXk0anYvMDBo'
    b'UE9VR2h4CjUwZWMrd29yWitHQkNHVzFFSGZBM1FuaEkwQ25vNm9KVkNvK1hZNGhnL3FTckY4'
    b'QUhRRzlBZEl1QU9Dd1dDNmtOZmU4SjZRZWtlaGUKMlIvUG9uQlkrT0ZiM0MzTy9HTHAwbzZP'
    b'anFLaW9uMzc5bjIwZHUyYjA2Wk5rOG5tU2FVMHdBNFE3RVBHVXdjYTNZQ0pQaGpvRG5FNwpy'
    b'SGl3dGtCSk5YSktzR1luQnMvQTJQL0I4Y3RvbGVMbWZYZzU0K1lSMlBFQm9LQWNYczU5TGlC'
    b'emMzT0RXR3h5cmk3YWFsT3JjU1dkCkxuZnpleTN3ajk4TnN6U0hiekIrL2J4SVpXbjE2NlZM'
    b'eXNaRzNiVnJObVBHQ0pjdkx6MS8za1d0TmdMdFFGMGFMQ2ZCeGdxcE9iaFcKaE93cS9KcUdx'
    b'YUdJMjQrcWJNVGZBWUR4SVZnNUMyb3RHbHFSZmc5NVpWZ1VoZHhTTU9uSUtVSGVRd1Q1b3Jr'
    b'TkxWSk1uVHJWdGFiRwpVeVFpKy9yenhUc3RiZGlZbUtKbmZWVG0xV0JNL2hDbGNYRUJIaDZ5'
    b'N093NVBUMnBhOWNtbnpnaDZPa0JjTXJhMnErMnRpdDI2VSsvCjk5SWI5UGoySzl4N0NKazFM'
    b'dXpFNmUxWUhZT3dZUmc3Qkdac05MVGk3U2tBd0daaS9oVE1ERWY0U0lDQ3g3UE03Tm16UFZK'
    b'VFRhNE4KVFU5MUY2MVcyOW9hZiszWk8xdVd6d1QxVFVQbnNXUGhZckVQOEtGWS9NNmhRNFd4'
    b'c2NsUlVZUld5K2Z6UHp4d2dETng1dGVMb2YvdAp3Mk1HSUxzVG9hOWdWQ0NFbm1odHg4RmZj'
    b'UGtXYmhmQTBoeE9BaXllamtZeEZDcDg4QTJhSlRBWWNQUUNDQUtXbHBhcTJscFBsWXBVCi9V'
    b'V2cyTFBINDVYTlBiMzlMTDQzb01pMnhaVWdBRHcrYnRwY1VEQnUyelp0Y0xCRUlxRlNxY3NQ'
    b'SHVTYUJXVmQrRjJxaHpYWXRCZWkKZXV3N0M3MEJ4Vlc0bW9tbU5wejdDalFxYXBwdy9BcHVG'
    b'eUNuQkJsNTBHZ0I0SU1QUHFBZE9tU0tEVWlYZmcrS2lYMHVIQU1Ob25ZWApqNzNubUpzV2Fm'
    b'L3pMcE9CNDdzd2N3NzJ0cU5JSURELzdqdjdIVHQrL1BUVFhabDlocHpCWU9pWU1NSHowYU04'
    b'VmZ1VFZHMmRBS0RUClk2QTdiQ3h4N3lFYXhWZytFNFFSQUh6ZDhNUk9wMUpCRUdDejJmNUNI'
    b'NmNQNnRwTnNPTlFqQVdtK0xEaVVzN2dGbUp4aE50YWozNk8KcFQ0UUlXNGhKbmdMVnhjWEV3'
    b'U2hWcXNmYjNmVTYvVTdkdXl3dHJhK3ZISGp0ZC83MU96NE9QTUZ4Z1NqVUFRdUcwUG5nbStK'
    b'aEM4UQpJb1M1R1lxcndHYmlWajRLUlRqd00zYnUzRG5RL09pVVlTWjVYczVVOTgxTkcxRnVZ'
    b'ODNZODR0cmZ4R0NCMkxlVnRTVWxlM2NzSUhCCllQQjRQSUlnVkNwVlZsYVdScTFPLytZYkhw'
    b'M3VCdGovNXVNYjRZOWZ2NEdkZFovcC9rZ0tuUjZTRGl6K0RGd091dVZnTXlIdHd1MEMKSk42'
    b'R3Q3ZTN3TExYUkNVSFFQdDBtVW5XbTBJQlhYM2Iydjk0NW8yRUlZT016NHpqNzQwc0xZd0g3'
    b'cmE2dXhNVVNsNWUzc1dMRjNubQo1bDExZFNPVGtxUktaVHFRdUI5VlRkaThCQXZlUUlBMzdw'
    b'YmdUZ0U4QjJEWFNUUzBnaUFRT3cxV0Z1QmJvSzRGelcwNCtBc2tYZlQ0CitCT0I3TlUybGpw'
    b'UzlSZU5yYVd1cUtTRzRmcTVTbkp4Z04yejQwd1locjJsc0Q2U3JCMHpKajAxdFNBbHBUNCtm'
    b'dlBaczdsY2JzUE4KbThYQUFIdWMrRGMwV2d4eXg3ZW5BTURUR1RQV29hd1dCQUVMTHVLM3dj'
    b'RUd5ZGtJRVdMelBoUlg0ZENoUS9TT2I4YjRtZkJIQ2sxNApaelNBNk5HNXZlSnJpUTlqNjF2'
    b'NitYbFUvUGdsTGdzMFZldlcyV20xWGwxZDg3cTdZeUlqdXpzN3VZQVRHK0ZDeEc0Qm5ZYTQv'
    b'WkNrCjRzcHR6RnlQVVNvc21RQU9DK3NXd01JY0pkVVlIWVNmVTVGeEgrKysreTVUbmZiV3lQ'
    b'c20zVzZtYXMwOVFhZkhxWUtQSzBUMWk4ZWYKOW5icHg1M1hnT1h6TU56R0pieXB5UlBvQldq'
    b'QVh1QXFvR0NoUTRPTnczR3FFYjNpdm8zUmRCb09iZ0xmRW9QYzBTWEQvVExjS2NTRgpHNGla'
    b'T3o5c3RPT0M0VHRvcHQxWlRIbUU3L3NCVkFqdDdvaDFFUVdOdzgyTk9mYlArdjg5Tmxhd0c0'
    b'amNzN0kzSHkvdEFBYVFEYVFECktnTUFsRDVDZXkrVVR3MkFZY01SNEFPakVSdjJvUG9pRXF2'
    b'eDNudXJ3a1k3end6WXptVEExREY1MVFIUWFCRGFaZGUwZVRUcWx1WmsKWFIvdTl3emp6c2NW'
    b'SWhaS2N1SC9XMGcyOEdTWVZnTlBweGtBOUNodytBb2VQVUJCUFNvMDlHOTI3WEt6cVo4YnNv'
    b'ZGwrcEtiL0x6Kwp0R2ZtbmJGblBGZ0h2RUl2cjk1dDN5SjlScHdOQzFIMk92TCtSbTVOUUhJ'
    b'UnFwdHdzZ0JtVmw2WHIxNFZFTWNYalQxQnA3MGNyV1g2Cjgvb2ZFRFZ4ODlvM3lwUXNTZW5t'
    b'dGZNMUZyLy80cTlhaTJrTDhha0lEc0FPNE9DZlpzWGo4YlpzMldKdnJSbG11MzJnaStKbGFx'
    b'V1gKVGZYSHBEOXc3VEw3cExhbXNyZHg3L3dJcGU5VFIwNmJKSmczQndkNnNMZC8xVzFzYkZh'
    b'dFd1VXZkR04xZmpWbFdJWEplYXovb2FvRAowQnVRV3VEUlNYL2JRUE44bUo5Z3ByODkwbDha'
    b'NUFzSEcyUSt3SjRsc0RIZ0QyOU8rSHgrZUhoNFRFeU1XbDdOVXgySmVLV1NSbjA1CkcrZWxW'
    b'ZjBKNGc1S1p0VTRnamZaeUhEUmFnMlNsb3FlOW9ycUJxVmFyS0RiMnpzNk9qbzVPYm02dWxy'
    b'd3pIbzdpdWpLOU9HZTJhNzIKaHBlN1RWNSsxWittdFIxVkxZSk8xUUMxZ1UraFVGbDBCUU55'
    b'QzFhTHAwTm5mOTQ5VW5XU2x3UXEyUVNrNmlTazZpU2s2aVNrNmlTawo2aVNrNmlTazZpU2s2'
    b'aVNrNmlTazZpU2s2aVNrNmlTazZpU2s2aVNrNmlTazZpU2s2aVFBZ1A4RjJRRDlJT1NhMFdr'
    b'QUFBQWxkRVZZCmRHUmhkR1U2WTNKbFlYUmxBREl3TWpJdE1URXRNVGhVTURnNk1UTTZNVGty'
    b'TURBNk1EQk5kTEtEQUFBQUpYUkZXSFJrWVhSbE9tMXYKWkdsbWVRQXlNREl5TFRFeExURTRW'
    b'REE0T2pFek9qRTVLekF3T2pBd1BDa0tQd0FBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBp'
    b'ZD0iaW1hZ2UxMzIxMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'DE_SL')

DE_SL = b64_DE_SL
index.append("DE_SL")
index.append("Germany Saarland")
catalog["DE_SL"] = DE_SL
catalog["Germany Saarland"] = DE_SL
country["Germany Saarland"] = ('DE_SL', '', 1)
lookup["DE_SL"] = ('DE_SL', '', 'Germany Saarland', 1)
lookup["Germany Saarland"] = ('DE_SL', '', 'Germany Saarland', 1)
details["DE_SL"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_SL"] = ('DE_SL', 'Germany Saarland', 1)
regional["Germany Saarland"] = ('DE_SL', 'Germany Saarland', 1)
#----------------------------------------------------------------------
b64_DE_SN = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1MDAiIGhlaWdodD0iMzAwIj4KPHJl'
    b'Y3QgZmlsbD0iIzE2NmMyMyIgd2lkdGg9IjUwMCIgaGVpZ2h0PSIzMDAiLz4KPHJlY3QgZmls'
    b'bD0iI2ZmZiIgd2lkdGg9IjUwMCIgaGVpZ2h0PSIxNTAiLz4KPC9zdmc+', 'DE_SN')

DE_SN = b64_DE_SN
index.append("DE_SN")
index.append("Germany Saxony")
catalog["DE_SN"] = DE_SN
catalog["Germany Saxony"] = DE_SN
country["Germany Saxony"] = ('DE_SN', '', 1)
lookup["DE_SN"] = ('DE_SN', '', 'Germany Saxony', 1)
lookup["Germany Saxony"] = ('DE_SN', '', 'Germany Saxony', 1)
details["DE_SN"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_SN"] = ('DE_SN', 'Germany Saxony', 1)
regional["Germany Saxony"] = ('DE_SN', 'Germany Saxony', 1)
#----------------------------------------------------------------------
b64_DE_ST = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIKCSJodHRw'
    b'Oi8vd3d3LnczLm9yZy9HcmFwaGljcy9TVkcvMS4xL0RURC9zdmcxMS5kdGQiPgo8IS0tIFRo'
    b'aXMgZmlsZSBpcyBpbiB0aGUgcHVibGljIGRvbWFpbiAtLT4KPHN2ZwoJd2lkdGg9IjEwMDAi'
    b'CgloZWlnaHQ9IjYwMCIKCXhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKCXZp'
    b'ZXdCb3g9IjAgMCAxMCA2Ij4KCTxkZXNjPkNpdmlsIGZsYWcgb2YgU2F4b255LUFuaGFsdDwv'
    b'ZGVzYz4KCTxyZWN0IGhlaWdodD0iMyIgd2lkdGg9IjEwIiBmaWxsPSIjRkNEMTE2IiB4PSIw'
    b'IiB5PSIwIiAvPgoJPHJlY3QgaGVpZ2h0PSIzIiB3aWR0aD0iMTAiIGZpbGw9IiMwMDAiIHg9'
    b'IjAiIHk9IjMiIC8+Cjwvc3ZnPg==', 'DE_ST')

DE_ST = b64_DE_ST
index.append("DE_ST")
index.append("Germany Saxony-Anhalt")
catalog["DE_ST"] = DE_ST
catalog["Germany Saxony-Anhalt"] = DE_ST
country["Germany Saxony-Anhalt"] = ('DE_ST', '', 1)
lookup["DE_ST"] = ('DE_ST', '', 'Germany Saxony-Anhalt', 1)
lookup["Germany Saxony-Anhalt"] = ('DE_ST', '', 'Germany Saxony-Anhalt', 1)
details["DE_ST"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_ST"] = ('DE_ST', 'Germany Saxony-Anhalt', 1)
regional["Germany Saxony-Anhalt"] = ('DE_ST', 'Germany Saxony-Anhalt', 1)
#----------------------------------------------------------------------
b64_DE_TH = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBzdGFuZGFsb25lPSJubyI/Pg0KPCFET0NUWVBFIHN2ZyBQ'
    b'VUJMSUMgIi0vL1czQy8vRFREIFNWRyAxLjEvL0VOIiAiaHR0cDovL3d3dy53My5vcmcvR3Jh'
    b'cGhpY3MvU1ZHLzEuMS9EVEQvc3ZnMTEuZHRkIj4NCg0KPHN2Zw0KICAgICAgICB3aWR0aD0i'
    b'NTAwIg0KICAgICAgICBoZWlnaHQ9IjI1MCINCiAgICAgICAgeG1sbnM9Imh0dHA6Ly93d3cu'
    b'dzMub3JnLzIwMDAvc3ZnIg0KICAgICAgICBpZD0iQ2l2aWwgZmxhZyBvZiBUaHVyaW5naWEi'
    b'Pg0KDQo8IS0tDQogICAgICAgIFRoaXMgZmlsZSBpcyBpbiB0aGUgcHVibGljIGRvbWFpbg0K'
    b'LS0+DQoNCiAgICAgICAgPHJlY3QgaGVpZ2h0PSIxMjUiIHdpZHRoPSI1MDAiIGZpbGw9IiNG'
    b'RkZGRkYiIHg9IjAiIHk9IjAiIC8+DQogICAgICAgIDxyZWN0IGhlaWdodD0iMTI1IiB3aWR0'
    b'aD0iNTAwIiBmaWxsPSIjRTEwMDAwIiB4PSIwIiB5PSIxMjUiIC8+DQoNCjwvc3ZnPg==', 'DE_TH')

DE_TH = b64_DE_TH
index.append("DE_TH")
index.append("Germany Thuringia")
catalog["DE_TH"] = DE_TH
catalog["Germany Thuringia"] = DE_TH
country["Germany Thuringia"] = ('DE_TH', '', 1)
lookup["DE_TH"] = ('DE_TH', '', 'Germany Thuringia', 1)
lookup["Germany Thuringia"] = ('DE_TH', '', 'Germany Thuringia', 1)
details["DE_TH"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["DE_TH"] = ('DE_TH', 'Germany Thuringia', 1)
regional["Germany Thuringia"] = ('DE_TH', 'Germany Thuringia', 1)
#----------------------------------------------------------------------
b64_DJ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWRqIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImRqLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTQwIDBoNjgyLjd2'
    b'NTEySC00MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgY2xpcC1wYXRoPSJ1cmwoI2RqLWEpIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgz'
    b'Ny41KSBzY2FsZSguOTQpIj4KICAgIDxwYXRoIGZpbGw9IiMwYzAiIGQ9Ik0tNDAgMGg3Njh2'
    b'NTEySC00MHoiLz4KICAgIDxwYXRoIGZpbGw9IiM2OWYiIGQ9Ik0tNDAgMGg3Njh2MjU2SC00'
    b'MHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmZlZmUiIGQ9Im0tNDAgMCAzODIuNyAyNTUuN0wt'
    b'NDAgNTExVjB6Ii8+CiAgICA8cGF0aCBmaWxsPSJyZWQiIGQ9Ik0xMTkuOCAyOTIgODkgMjcw'
    b'bC0zMC43IDIyLjRMNjkuNyAyNTZsLTMwLjYtMjIuNSAzNy45LS4zIDExLjctMzYuMyAxMiAz'
    b'Ni4yaDM3LjlsLTMwLjUgMjIuNyAxMS43IDM2LjR6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'DJ')

DJ = b64_DJ
index.append("DJ")
index.append("DJI")
index.append("Djibouti")
catalog["DJ"] = DJ
catalog["DJI"] = DJ
catalog["Djibouti"] = DJ
country["Djibouti"] = ('DJ', 'DJI', 0)
lookup["DJ"] = ('DJ', 'DJI', 'Djibouti', 0)
lookup["Djibouti Djibouti"] = ('DJ', 'DJI', 'Djibouti', 0)
lookup["DJI"] = ('DJ', 'DJI', 'Djibouti', 0)
lookup["Djibouti"] = ('DJ', 'DJI', 'Djibouti', 0)
details["DJ"] = {"continent":"Africa","capital":"Djibouti","currency":"Djibouti Franc","web":".dj","lang":"fr-DJ | ar | so-DJ | aa","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_DK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWRrIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0i'
    b'TTAgMGg2NDAuMXY0ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjA1LjcgMGg2'
    b'OC42djQ4MGgtNjguNnoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAyMDUuN2g2NDAu'
    b'MXY2OC42SDB6Ii8+Cjwvc3ZnPgo=', 'DK')

DK = b64_DK
index.append("DK")
index.append("DNK")
index.append("Denmark")
catalog["DK"] = DK
catalog["DNK"] = DK
catalog["Denmark"] = DK
country["Denmark"] = ('DK', 'DNK', 0)
lookup["DK"] = ('DK', 'DNK', 'Denmark', 0)
lookup["Copenhagen Denmark"] = ('DK', 'DNK', 'Denmark', 0)
lookup["DNK"] = ('DK', 'DNK', 'Denmark', 0)
lookup["Denmark"] = ('DK', 'DNK', 'Denmark', 0)
details["DK"] = {"continent":"Europe","capital":"Copenhagen","currency":"Danish Krone","web":".dk","lang":"da-DK | en | fo | de-DK","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_DM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWRtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImRtLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1IDBoNjgyLjd2'
    b'NTEySC04NXoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgY2xpcC1wYXRoPSJ1cmwoI2RtLWEpIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSg3'
    b'OS43KSBzY2FsZSguOTQpIj4KICAgIDxwYXRoIGZpbGw9IiMxMDhjMDAiIGQ9Ik0tMjU4LjMg'
    b'MEg3NjkuMnY1MTJILTI1OC4zeiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZDYwMCIgZD0iTS0y'
    b'NjAgMTc4LjJINzcyLjZ2NTAuMUgtMjYweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZDYwMCIg'
    b'ZD0iTTE4MSAwaDQ4LjV2NTEyaC00OC40eiIvPgogICAgPHBhdGggZD0iTTIyNy44IDBoNDgu'
    b'NHY1MTJoLTQ4LjR6Ii8+CiAgICA8cGF0aCBkPSJNLTI2MCAyMjYuNkg3NzIuNnY1MC4ySC0y'
    b'NjB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLTI2MCAyNzYuOEg3NzIuNnY1MC4x'
    b'SC0yNjB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjc2LjIgMGg0OC41djUxMmgt'
    b'NDguNXoiLz4KICAgIDxyZWN0IHdpZHRoPSIyNzMuOCIgaGVpZ2h0PSIyNzUiIHg9Ii0zOTQu'
    b'NiIgeT0iLTM5My45IiBmaWxsPSIjZTcyOTEwIiByeT0iMTM3LjUiIHRyYW5zZm9ybT0ic2Nh'
    b'bGUoLTEpIi8+CiAgICA8ZyBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Im0y'
    b'NTAuNSAxMzcgNS42LTE2IDUuMSAxNS43czE3LjEuNSAxNy4xLjItMTMuNSAxMC4zLTEzLjUg'
    b'MTAuM2w2LjEgMTcuNmMtLjItLjUtMTQuOC0xMC45LTE0LjgtMTAuOXMtMTQuOCAxMC40LTE0'
    b'LjUgMTAuNCA1LjYtMTcgNS42LTE3bC0xMy4zLTEwLjEgMTYuNi0uM3oiLz4KICAgICAgPHBh'
    b'dGggZmlsbD0iI2ZmZTcwMCIgZD0iTTI1MS4zIDEzNy43IDI1NiAxMjRsNC40IDEzLjZzMTQu'
    b'OS40IDE0LjkuMi0xMS43IDktMTEuNyA5bDUuMiAxNS4yYy0uMi0uNS0xMi44LTkuNC0xMi44'
    b'LTkuNHMtMTIuOCA5LTEyLjYgOSA1LTE0LjggNS0xNC44bC0xMS42LTguOCAxNC40LS4yeiIv'
    b'PgogICAgICA8cGF0aCBmaWxsPSIjMTA4YzAwIiBkPSJtMjUzLjMgMTQwIDIuOC04IDIuNiA3'
    b'LjlzOC41LjIgOC41IDAtNi43IDUuMi02LjcgNS4ybDMgOC44Yy0uMS0uMy03LjQtNS40LTcu'
    b'NC01LjRsLTcuMiA1LjJjLjIgMCAyLjgtOC41IDIuOC04LjVsLTYuNi01IDguMi0uMnoiLz4K'
    b'ICAgIDwvZz4KICAgIDxnIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0ibTM1'
    b'Ni45IDIxMS44IDUuNi0xNiA1IDE1LjdzMTcuMi42IDE3LjIuMy0xMy41IDEwLjMtMTMuNSAx'
    b'MC4zbDYgMTcuNmMtLjItLjUtMTQuNy0xMC45LTE0LjctMTAuOXMtMTQuOCAxMC40LTE0LjUg'
    b'MTAuNCA1LjYtMTcgNS42LTE3TDM0MC4zIDIxMmwxNi42LS4zeiIvPgogICAgICA8cGF0aCBm'
    b'aWxsPSIjZmZlNzAwIiBkPSJtMzU3LjYgMjEyLjYgNC45LTEzLjkgNC40IDEzLjdzMTQuOC40'
    b'IDE0LjguMi0xMS43IDktMTEuNyA5bDUuMyAxNS4xYy0uMi0uNC0xMi44LTkuNC0xMi44LTku'
    b'NHMtMTIuOCA5LTEyLjYgOSA0LjktMTQuOCA0LjktMTQuOGwtMTEuNS04LjcgMTQuMy0uMnoi'
    b'Lz4KICAgICAgPHBhdGggZmlsbD0iIzEwOGMwMCIgZD0ibTM1OS43IDIxNC45IDIuOC04IDIu'
    b'NSA3LjggOC42LjItNi44IDUuMXMzLjIgOSAzIDguOGMwLS4zLTcuMy01LjQtNy4zLTUuNGwt'
    b'Ny4zIDUuMSAyLjgtOC41LTYuNi01IDguMy0uMXoiLz4KICAgIDwvZz4KICAgIDxnIHN0cm9r'
    b'ZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0ibTMyNS45IDMzMC42IDUuNi0xNiA1IDE1'
    b'LjhzMTcuMi41IDE3LjIuMy0xMy41IDEwLjMtMTMuNSAxMC4zbDYgMTcuNWMtLjItLjUtMTQu'
    b'Ny0xMC44LTE0LjctMTAuOFMzMTYuNyAzNTggMzE2LjkgMzU4czUuNy0xNyA1LjctMTdsLTEz'
    b'LjMtMTAgMTYuNi0uM3oiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZTcwMCIgZD0ibTMyNi42'
    b'IDMzMS40IDQuOS0xMy44IDQuNCAxMy42czE0LjguNSAxNC44LjItMTEuNyA5LTExLjcgOWw1'
    b'LjMgMTUuMmMtLjItLjUtMTIuOC05LjQtMTIuOC05LjRzLTEyLjggOS0xMi42IDkgNC45LTE0'
    b'LjggNC45LTE0LjhsLTExLjUtOC43IDE0LjMtLjN6Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiMx'
    b'MDhjMDAiIGQ9Im0zMjguNyAzMzMuNyAyLjgtOCAyLjUgNy45czguNi4zIDguNi4xLTYuOCA1'
    b'LjItNi44IDUuMmwzIDguN2MwLS4yLTcuMy01LjQtNy4zLTUuNGwtNy4zIDUuMiAyLjgtOC41'
    b'LTYuNi01IDguMy0uMnoiLz4KICAgIDwvZz4KICAgIDxnIHN0cm9rZS13aWR0aD0iMXB0Ij4K'
    b'ICAgICAgPHBhdGggZD0ibTE3Ny4yIDMzMC42IDUuNi0xNiA1IDE1LjhzMTcuMS41IDE3LjEu'
    b'My0xMy41IDEwLjMtMTMuNSAxMC4zbDYuMiAxNy41Yy0uMy0uNS0xNC44LTEwLjgtMTQuOC0x'
    b'MC44UzE2OCAzNTggMTY4LjIgMzU4czUuNy0xNyA1LjctMTdsLTEzLjMtMTAgMTYuNi0uM3oi'
    b'Lz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZTcwMCIgZD0ibTE3OCAzMzEuNCA0LjgtMTMuOCA0'
    b'LjQgMTMuNnMxNC44LjUgMTQuOC4yLTExLjcgOS0xMS43IDlsNS4zIDE1LjJjLS4yLS41LTEy'
    b'LjgtOS40LTEyLjgtOS40cy0xMi44IDktMTIuNiA5IDQuOS0xNC44IDQuOS0xNC44bC0xMS41'
    b'LTguNyAxNC4zLS4zeiIvPgogICAgICA8cGF0aCBmaWxsPSIjMTA4YzAwIiBkPSJtMTgwIDMz'
    b'My43IDIuOC04IDIuNSA3LjlzOC42LjMgOC42LjEtNi44IDUuMi02LjggNS4ybDMgOC43YzAt'
    b'LjItNy4zLTUuNC03LjMtNS40bC03LjMgNS4yIDIuOC04LjUtNi42LTUgOC4zLS4yeiIvPgog'
    b'ICAgPC9nPgogICAgPGcgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAgICA8cGF0aCBkPSJtMTUw'
    b'IDIwOC43IDUuNi0xNiA1LjEgMTUuOHMxNy4xLjUgMTcuMS4yLTEzLjUgMTAuNC0xMy41IDEw'
    b'LjRsNi4xIDE3LjVjLS4zLS41LTE0LjgtMTAuOC0xNC44LTEwLjhTMTQwLjggMjM2IDE0MS4x'
    b'IDIzNnM1LjYtMTcgNS42LTE3bC0xMy4zLTEwIDE2LjYtLjN6Ii8+CiAgICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmU3MDAiIGQ9Im0xNTAuOCAyMDkuNSA0LjgtMTMuOCA0LjUgMTMuNnMxNC43LjUg'
    b'MTQuNy4yLTExLjcgOS0xMS43IDlsNS4zIDE1LjJjLS4yLS41LTEyLjgtOS40LTEyLjgtOS40'
    b'cy0xMi44IDktMTIuNSA5IDQuOC0xNC44IDQuOC0xNC44bC0xMS41LTguNyAxNC40LS4zeiIv'
    b'PgogICAgICA8cGF0aCBmaWxsPSIjMTA4YzAwIiBkPSJtMTUyLjggMjExLjggMi44LTggMi42'
    b'IDcuOSA4LjUuMS02LjcgNS4yIDMgOC43Yy0uMS0uMi03LjQtNS40LTcuNC01LjRsLTcuMiA1'
    b'LjJjLjIgMCAyLjgtOC41IDIuOC04LjVsLTYuNi01IDguMi0uMnoiLz4KICAgIDwvZz4KICAg'
    b'IDxnIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0ibTMyNC42IDE3NC4xLTUu'
    b'NiAxNi01LTE1LjdzLTE3LjItLjUtMTcuMi0uMyAxMy41LTEwLjMgMTMuNS0xMC4zbC02LTE3'
    b'LjVjLjIuNSAxNC43IDEwLjggMTQuNyAxMC44czE0LjgtMTAuMyAxNC41LTEwLjMtNS42IDE3'
    b'LTUuNiAxN2wxMy4zIDEwLTE2LjYuM3oiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZTcwMCIg'
    b'ZD0iTTMyMy45IDE3My4zYzAgLjMtNSAxMy45LTUgMTMuOWwtNC4zLTEzLjZzLTE0LjgtLjUt'
    b'MTQuOC0uMyAxMS43LTguOSAxMS43LTguOWwtNS4zLTE1LjJjLjIuNSAxMi44IDkuNCAxMi44'
    b'IDkuNHMxMi44LTkgMTIuNi05LTQuOSAxNC44LTQuOSAxNC44bDExLjUgOC43LTE0LjQuMnoi'
    b'Lz4KICAgICAgPHBhdGggZmlsbD0iIzEwOGMwMCIgZD0ibTMyMS44IDE3MS0yLjggOC0yLjUt'
    b'Ny44cy04LjYtLjMtOC42LS4xIDYuOC01LjIgNi44LTUuMmwtMy04LjdjMCAuMiA3LjMgNS40'
    b'IDcuMyA1LjRsNy4zLTUuMmMtLjIgMC0yLjkgOC41LTIuOSA4LjVsNi43IDUtOC4zLjJ6Ii8+'
    b'CiAgICA8L2c+CiAgICA8ZyBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Im0z'
    b'NjcuMyAyOTAuMy01LjYgMTYtNS0xNS44cy0xNy4yLS41LTE3LjItLjJTMzUzIDI4MCAzNTMg'
    b'MjgwbC02LTE3LjZjLjIuNSAxNC43IDEwLjggMTQuNyAxMC44czE0LjgtMTAuMyAxNC41LTEw'
    b'LjMtNS42IDE3LTUuNiAxN0wzODQgMjkwbC0xNi42LjN6Ii8+CiAgICAgIDxwYXRoIGZpbGw9'
    b'IiNmZmU3MDAiIGQ9Im0zNjYuNiAyODkuNS00LjkgMTMuOC00LjQtMTMuNnMtMTQuOC0uNC0x'
    b'NC44LS4yIDExLjctOSAxMS43LTlsLTUuMy0xNS4yYy4yLjUgMTIuOCA5LjQgMTIuOCA5LjRz'
    b'MTIuOC05IDEyLjYtOS00LjkgMTQuOC00LjkgMTQuOGwxMS41IDguOC0xNC40LjJ6Ii8+CiAg'
    b'ICAgIDxwYXRoIGZpbGw9IiMxMDhjMDAiIGQ9Im0zNjQuNSAyODcuMi0yLjggOC0yLjUtNy45'
    b'cy04LjYtLjItOC42IDAgNi44LTUuMiA2LjgtNS4ybC0zLTguOGMwIC4zIDcuMyA1LjQgNy4z'
    b'IDUuNGw3LjMtNS4yYy0uMiAwLTIuOSA4LjYtMi45IDguNmw2LjcgNS04LjMuMXoiLz4KICAg'
    b'IDwvZz4KICAgIDxnIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0ibTI2MS40'
    b'IDM3NS4zLTUuNiAxNi01LTE1LjhzLTE3LjItLjUtMTcuMi0uMyAxMy41LTEwLjMgMTMuNS0x'
    b'MC4zbC02LTE3LjVjLjIuNSAxNC43IDEwLjggMTQuNyAxMC44czE0LjgtMTAuMyAxNC41LTEw'
    b'LjMtNS42IDE3LTUuNiAxN0wyNzggMzc1bC0xNi42LjN6Ii8+CiAgICAgIDxwYXRoIGZpbGw9'
    b'IiNmZmU3MDAiIGQ9Im0yNjAuNyAzNzQuNC00LjkgMTQtNC40LTEzLjdzLTE0LjgtLjUtMTQu'
    b'OC0uMiAxMS43LTkgMTEuNy05bC01LjMtMTUuMmMuMi41IDEyLjggOS40IDEyLjggOS40czEy'
    b'LjgtOSAxMi42LTktNC45IDE0LjgtNC45IDE0LjhsMTEuNSA4LjctMTQuMy4zeiIvPgogICAg'
    b'ICA8cGF0aCBmaWxsPSIjMTA4YzAwIiBkPSJtMjU4LjYgMzcyLjItMi44IDgtMi41LTcuOXMt'
    b'OC42LS4zLTguNi0uMSA2LjgtNS4yIDYuOC01LjJsLTMtOC43YzAgLjIgNy4zIDUuNCA3LjMg'
    b'NS40bDcuMy01LjItMi44IDguNSA2LjYgNS04LjMuMnoiLz4KICAgIDwvZz4KICAgIDxnIHN0'
    b'cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0ibTE2MiAyOTAuMy01LjcgMTYtNS0x'
    b'NS44cy0xNy4yLS41LTE3LjItLjIgMTMuNS0xMC4zIDEzLjUtMTAuM2wtNi0xNy42Yy4yLjUg'
    b'MTQuNyAxMC44IDE0LjcgMTAuOEwxNzEgMjYzbC01LjcgMTcgMTMuMyAxMC4xLTE2LjYuM3oi'
    b'Lz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZTcwMCIgZD0ibTE2MS4yIDI4OS41LTQuOSAxMy44'
    b'LTQuNC0xMy42cy0xNC44LS40LTE0LjgtLjIgMTEuNy05IDExLjctOWwtNS4zLTE1LjJjLjIu'
    b'NSAxMi44IDkuNCAxMi44IDkuNHMxMi44LTkgMTIuNi05LTQuOSAxNC44LTQuOSAxNC44bDEx'
    b'LjUgOC44LTE0LjMuMnoiLz4KICAgICAgPHBhdGggZmlsbD0iIzEwOGMwMCIgZD0ibTE1OS4x'
    b'IDI4Ny4yLTIuOCA4LTIuNS03LjlzLTguNi0uMi04LjYgMCA2LjgtNS4yIDYuOC01LjJsLTMt'
    b'OC44YzAgLjMgNy4zIDUuNCA3LjMgNS40bDcuMy01LjItMi44IDguNiA2LjYgNS04LjMuMXoi'
    b'Lz4KICAgIDwvZz4KICAgIDxnIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0i'
    b'bTE5OC43IDE3NS44LTUuNiAxNi01LjItMTUuN3MtMTctLjUtMTctLjMgMTMuNS0xMC4zIDEz'
    b'LjUtMTAuM2wtNi4xLTE3LjVjLjIuNSAxNC43IDEwLjggMTQuNyAxMC44czE0LjgtMTAuMyAx'
    b'NC42LTEwLjMtNS42IDE3LTUuNiAxN2wxMy4yIDEwLTE2LjUuNHoiLz4KICAgICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZTcwMCIgZD0ibTE5Ny45IDE3NS00LjkgMTQtNC40LTEzLjdzLTE0LjgtLjUt'
    b'MTQuOC0uMiAxMS43LTkgMTEuNy05bC01LjMtMTUuMmMuMi41IDEyLjggOS40IDEyLjggOS40'
    b'czEyLjgtOSAxMi42LTktNC44IDE0LjgtNC44IDE0LjhsMTEuNCA4LjctMTQuMy4zeiIvPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjMTA4YzAwIiBkPSJtMTk1LjggMTcyLjgtMi44IDgtMi41LTcu'
    b'OXMtOC41LS4zLTguNS0uMSA2LjctNS4yIDYuNy01LjJsLTMtOC43YzAgLjIgNy4zIDUuNCA3'
    b'LjMgNS40bDcuMy01LjItMi44IDguNSA2LjYgNS04LjMuMnoiLz4KICAgIDwvZz4KICAgIDxn'
    b'IHRyYW5zZm9ybT0ibWF0cml4KDEuMDQgMCAwIDEuMDQgLTI1MC42IDM1OS40KSI+CiAgICAg'
    b'IDxnIGZpbGw9IiMwMDkyMDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjUiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC4xNiAtLjAyIDAgLjE4IDQyOS44IC0yMTUuNikiPgogICAgICAg'
    b'IDxlbGxpcHNlIGN4PSI2ODAuMiIgY3k9IjU4Ni4xIiByeD0iMzAuOCIgcnk9IjE4OS44IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgxLjQgMCAwIDEgLTUzNC4zIDI2My43KSIvPgogICAgICAgIDxl'
    b'bGxpcHNlIGN4PSI2ODAuMiIgY3k9IjU4Ni4xIiByeD0iMzAuOCIgcnk9IjE4OS44IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCgxLjUgMCAwIDEgLTU0Ny4yIDI2NykiLz4KICAgICAgICA8ZWxsaXBz'
    b'ZSBjeD0iNjgwLjIiIGN5PSI1ODYuMSIgcng9IjMwLjgiIHJ5PSIxODkuOCIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoMS4yIDAgMCAxLjEgLTM2NSAyMTQuMSkiLz4KICAgICAgPC9nPgogICAgICA8'
    b'ZyBzdHJva2U9IiMwMDAiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDcyLjkgLTkuOCkiPgogICAg'
    b'ICAgIDxwYXRoIGZpbGw9IiNhOTU2MDAiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik0zODguNS01'
    b'M2M2LS4zIDMuNC0zLjMgNi40LTUgMy0xLjYgNy4zLS42IDguNiAxLjQgMS4zIDIgLjMgNCAy'
    b'IDRzNDctMi41IDQ4LjYtLjljMS42IDEuNyAyIDUgLjMgNi4zLTEuNiAxLjQtNTguOSAzLTYw'
    b'LjkgMS42cy01LTctNS03LjR6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZmMCIgc3Ryb2tl'
    b'LXdpZHRoPSIzLjkiIGQ9Ik01MjkuNiA0MDUuNWMwIDQwIDQ1LjYgMjcuOCA0Ni44IDYxLjIt'
    b'LjcgMzUuNC03Ni43IDMuNS03OC42LTYxLjIgMS45LTY0LjggNzUtOTggNzYuNy02MSAxLjIg'
    b'MzAuNi00NSAyMS00NSA2MXoiIHRyYW5zZm9ybT0ibWF0cml4KC4xNSAwIDAgLjEgMzQwLjQg'
    b'LTgxLjcpIi8+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZmMCIgc3Ryb2tlLXdpZHRoPSIzLjki'
    b'IGQ9Ik01MjkuNiA0MDUuNWMwIDQwIDQ1LjYgMjcuOCA0Ni44IDYxLjItLjcgMzUuNC03Ni43'
    b'IDMuNS03OC42LTYxLjIgMS45LTY0LjggNzUtOTggNzYuNy02MSAxLjIgMzAuNi00NSAyMS00'
    b'NSA2MXoiIHRyYW5zZm9ybT0ibWF0cml4KC4xNSAwIDAgLjEgMzQ0LjQgLTgxLjYpIi8+CiAg'
    b'ICAgICAgPHBhdGggZmlsbD0iI2ZmMCIgc3Ryb2tlLXdpZHRoPSIzLjkiIGQ9Ik01MjkuNiA0'
    b'MDUuNWMwIDQwIDQ1LjYgMjcuOCA0Ni44IDYxLjItLjcgMzUuNC03Ni43IDMuNS03OC42LTYx'
    b'LjIgMS45LTY0LjggNzUtOTggNzYuNy02MSAxLjIgMzAuNi00NSAyMS00NSA2MXoiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KC4xNSAwIDAgLjEgMzQ4LjcgLTgxLjgpIi8+CiAgICAgICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmMCIgc3Ryb2tlLXdpZHRoPSIzLjkiIGQ9Ik01MjkuNiA0MDUuNWMwIDQwIDQ1'
    b'LjYgMjcuOCA0Ni44IDYxLjItLjcgMzUuNC03Ni43IDMuNS03OC42LTYxLjIgMS45LTY0Ljgg'
    b'NzUtOTggNzYuNy02MSAxLjIgMzAuNi00NSAyMS00NSA2MXoiIHRyYW5zZm9ybT0ibWF0cml4'
    b'KC4xNSAwIDAgLjEgMzUyLjcgLTgxLjgpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjQ3OC40'
    b'IiBjeT0iLTQxLjEiIGZpbGw9IiNhOTU2MDAiIHN0cm9rZS13aWR0aD0iLjQiIHJ4PSIzLjUi'
    b'IHJ5PSIzLjQiIHRyYW5zZm9ybT0ibWF0cml4KDEuMSAuMDIgLS4wMiAxLjE1IC03NS42IDQu'
    b'NykiLz4KICAgICAgPC9nPgogICAgICA8ZyBmaWxsPSIjMDA5MjAwIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iMi41IiB0cmFuc2Zvcm09InJvdGF0ZSgtNS44IDY4OC40IC02MjUu'
    b'MikiPgogICAgICAgIDxlbGxpcHNlIGN4PSI0MjcuMSIgY3k9IjkwNSIgcng9IjIwLjgiIHJ5'
    b'PSIyNC4xIiB0cmFuc2Zvcm09Im1hdHJpeCguMTcgMCAwIC4zMiAzNjkuOCAtMzYxLjYpIi8+'
    b'CiAgICAgICAgPGVsbGlwc2UgY3g9IjQyNy4xIiBjeT0iOTA1IiByeD0iMjAuOCIgcnk9IjI0'
    b'LjEiIHRyYW5zZm9ybT0ibWF0cml4KC4xNyAwIDAgLjMyIDM2NCAtMzYyLjcpIi8+CiAgICAg'
    b'ICAgPGVsbGlwc2UgY3g9IjQyNy4xIiBjeT0iOTA1IiByeD0iMjAuOCIgcnk9IjI0LjEiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC4xNyAwIDAgLjMyIDM2MC42IC0zNzAuNikiLz4KICAgICAgICA8'
    b'ZWxsaXBzZSBjeD0iNDI3LjEiIGN5PSI5MDUiIHJ4PSIyMC44IiByeT0iMjQuMSIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjE2IDAgMCAuMzUgMzY5LjMgLTM5OS40KSIvPgogICAgICAgIDxlbGxp'
    b'cHNlIGN4PSI0MjcuMSIgY3k9IjkwNSIgcng9IjIwLjgiIHJ5PSIyNC4xIiB0cmFuc2Zvcm09'
    b'Im1hdHJpeCguMTYgMCAwIC4zMyAzNzcuNCAtMzc5KSIvPgogICAgICAgIDxlbGxpcHNlIGN4'
    b'PSI0MjcuMSIgY3k9IjkwNSIgcng9IjIwLjgiIHJ5PSIyNC4xIiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCguMTYgMCAwIC4zMyAzNzMuMiAtMzgyLjIpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjQy'
    b'Ny4xIiBjeT0iOTA1IiByeD0iMjAuOCIgcnk9IjI0LjEiIHRyYW5zZm9ybT0ibWF0cml4KC4x'
    b'NiAwIDAgLjMzIDM2OCAtMzg2LjcpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjQyNy4xIiBj'
    b'eT0iOTA1IiByeD0iMjAuOCIgcnk9IjI0LjEiIHRyYW5zZm9ybT0ibWF0cml4KC4xNiAwIDAg'
    b'LjMzIDM2MyAtMzg5LjUpIi8+CiAgICAgIDwvZz4KICAgICAgPHBhdGggZmlsbD0iIzgwNGJm'
    b'ZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDgyLjYtMTQxcy0xMS43'
    b'IDEwLTEwLjEgMzYuOWMxLjggMjcgMjYuNSAzOS41IDI2LjUgMzkuNXM2LjItNy43IDUuMi0y'
    b'OS41Yy0yLTMxLjgtMTMuOC00NS43LTEzLjgtNDUuN2wtNy44LTEuM3oiLz4KICAgICAgPGcg'
    b'ZmlsbD0iIzAwOTIwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIuNSIgdHJhbnNm'
    b'b3JtPSJyb3RhdGUoNC41IDE4MSA3NjkuOSkiPgogICAgICAgIDxlbGxpcHNlIGN4PSI0Mjcu'
    b'MSIgY3k9IjkwNSIgcng9IjIwLjgiIHJ5PSIyNC4xIiB0cmFuc2Zvcm09Im1hdHJpeCguMTcg'
    b'MCAwIC4zMiAzNjkuOCAtMzYxLjYpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjQyNy4xIiBj'
    b'eT0iOTA1IiByeD0iMjAuOCIgcnk9IjI0LjEiIHRyYW5zZm9ybT0ibWF0cml4KC4xNyAwIDAg'
    b'LjMyIDM2NCAtMzYyLjcpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjQyNy4xIiBjeT0iOTA1'
    b'IiByeD0iMjAuOCIgcnk9IjI0LjEiIHRyYW5zZm9ybT0ibWF0cml4KC4xNyAwIDAgLjMyIDM2'
    b'MC42IC0zNzAuNikiLz4KICAgICAgICA8ZWxsaXBzZSBjeD0iNDI3LjEiIGN5PSI5MDUiIHJ4'
    b'PSIyMC44IiByeT0iMjQuMSIgdHJhbnNmb3JtPSJtYXRyaXgoLjE2IDAgMCAuMzUgMzY5LjMg'
    b'LTM5OS40KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSI0MjcuMSIgY3k9IjkwNSIgcng9IjIw'
    b'LjgiIHJ5PSIyNC4xIiB0cmFuc2Zvcm09Im1hdHJpeCguMTYgMCAwIC4zMyAzNzcuNCAtMzc5'
    b'KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSI0MjcuMSIgY3k9IjkwNSIgcng9IjIwLjgiIHJ5'
    b'PSIyNC4xIiB0cmFuc2Zvcm09Im1hdHJpeCguMTYgMCAwIC4zMyAzNzMuMiAtMzgyLjIpIi8+'
    b'CiAgICAgICAgPGVsbGlwc2UgY3g9IjQyNy4xIiBjeT0iOTA1IiByeD0iMjAuOCIgcnk9IjI0'
    b'LjEiIHRyYW5zZm9ybT0ibWF0cml4KC4xNiAwIDAgLjMzIDM2OCAtMzg2LjcpIi8+CiAgICAg'
    b'ICAgPGVsbGlwc2UgY3g9IjQyNy4xIiBjeT0iOTA1IiByeD0iMjAuOCIgcnk9IjI0LjEiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC4xNiAwIDAgLjMzIDM2MyAtMzg5LjUpIi8+CiAgICAgIDwvZz4K'
    b'ICAgICAgPGVsbGlwc2UgY3g9IjYyNC40IiBjeT0iNjA2LjEiIGZpbGw9IiNjOTAwMDAiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiIHJ4PSI1OC4zIiByeT0iMTg2LjUiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC4xNiAtLjA2IC4wNiAuMTUgMzY5LjYgLTE0NSkiLz4KICAgICAg'
    b'PGcgZmlsbD0iIzAwOTIwMCIgc3Ryb2tlPSIjMDAwIiB0cmFuc2Zvcm09InJvdGF0ZSgxIDI0'
    b'Mi40IC0xOTU3LjgpIj4KICAgICAgICA8ZWxsaXBzZSBjeD0iMjE4LjEiIGN5PSIzNTYuOCIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjUiIHJ4PSIxMC44IiByeT0iMTIuOSIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoLjQgMCAwIC4zIDQ0NSAtMjMwLjUpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjIxOC4x'
    b'IiBjeT0iMzU2LjgiIHN0cm9rZS13aWR0aD0iMS42IiByeD0iMTAuOCIgcnk9IjEyLjkiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC4zNSAwIDAgLjMgNDU3LjIgLTIzNikiLz4KICAgICAgICA8ZWxs'
    b'aXBzZSBjeD0iMjE4LjEiIGN5PSIzNTYuOCIgc3Ryb2tlLXdpZHRoPSIxLjYiIHJ4PSIxMC44'
    b'IiByeT0iMTIuOSIgdHJhbnNmb3JtPSJtYXRyaXgoLjM1IDAgMCAuMyA0NTIgLTIzNikiLz4K'
    b'ICAgICAgICA8ZWxsaXBzZSBjeD0iMjE4LjEiIGN5PSIzNTYuOCIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjYiIHJ4PSIxMC44IiByeT0iMTIuOSIgdHJhbnNmb3JtPSJtYXRyaXgoLjM3IDAgMCAuMjcg'
    b'NDQ5LjUgLTIzMy41KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSIyMTguMSIgY3k9IjM1Ni44'
    b'IiBzdHJva2Utd2lkdGg9IjEuNiIgcng9IjEwLjgiIHJ5PSIxMi45IiB0cmFuc2Zvcm09Im1h'
    b'dHJpeCguMzcgMCAwIC4yNyA0NDkgLTIzOCkiLz4KICAgICAgICA8ZWxsaXBzZSBjeD0iMjE4'
    b'LjEiIGN5PSIzNTYuOCIgc3Ryb2tlLXdpZHRoPSIxLjYiIHJ4PSIxMC44IiByeT0iMTIuOSIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLjM1IDAgMCAuMyA0NDcgLTIzOC44KSIvPgogICAgICAgIDxl'
    b'bGxpcHNlIGN4PSIyMTguMSIgY3k9IjM1Ni44IiBzdHJva2Utd2lkdGg9IjEuNiIgcng9IjEw'
    b'LjgiIHJ5PSIxMi45IiB0cmFuc2Zvcm09Im1hdHJpeCguMzUgMCAwIC4zIDQ0OCAtMjQxLjYp'
    b'Ii8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjIxOC4xIiBjeT0iMzU2LjgiIHN0cm9rZS13aWR0'
    b'aD0iMS41IiByeD0iMTAuOCIgcnk9IjEyLjkiIHRyYW5zZm9ybT0ibWF0cml4KC40IDAgMCAu'
    b'MyA0MzIuOCAtMjQzLjUpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjIxOC4xIiBjeT0iMzU2'
    b'LjgiIHN0cm9rZS13aWR0aD0iMS42IiByeD0iMTAuOCIgcnk9IjEyLjkiIHRyYW5zZm9ybT0i'
    b'bWF0cml4KC4zNyAwIDAgLjI3IDQ0NiAtMjQzLjUpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9'
    b'IjIxOC4xIiBjeT0iMzU2LjgiIHN0cm9rZS13aWR0aD0iMS42IiByeD0iMTAuOCIgcnk9IjEy'
    b'LjkiIHRyYW5zZm9ybT0ibWF0cml4KC4zNSAwIDAgLjMgNDQ0LjIgLTI0NykiLz4KICAgICAg'
    b'ICA8ZWxsaXBzZSBjeD0iMjE4LjEiIGN5PSIzNTYuOCIgc3Ryb2tlLXdpZHRoPSIxLjYiIHJ4'
    b'PSIxMC44IiByeT0iMTIuOSIgdHJhbnNmb3JtPSJtYXRyaXgoLjM1IDAgMCAuMyA0MzYuMSAt'
    b'MjQzLjIpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjIxOC4xIiBjeT0iMzU2LjgiIHN0cm9r'
    b'ZS13aWR0aD0iMS42IiByeD0iMTAuOCIgcnk9IjEyLjkiIHRyYW5zZm9ybT0ibWF0cml4KC4z'
    b'NSAwIDAgLjMgNDM3LjQgLTI0My45KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSIyMTguMSIg'
    b'Y3k9IjM1Ni44IiBzdHJva2Utd2lkdGg9IjEuNiIgcng9IjEwLjgiIHJ5PSIxMi45IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCguMzUgMCAwIC4zIDQzOSAtMjQ3KSIvPgogICAgICA8L2c+CiAgICAg'
    b'IDxnIGZpbGw9IiMwMDkyMDAiIHN0cm9rZT0iIzAwMCIgdHJhbnNmb3JtPSJtYXRyaXgoLjE4'
    b'IDAgMCAuMiA0MjEgLTIxNi44KSI+CiAgICAgICAgPGVsbGlwc2UgY3g9IjUyOC43IiBjeT0i'
    b'NTY0LjUiIHN0cm9rZS13aWR0aD0iMi41IiByeD0iNjcuNCIgcnk9IjIwNS42IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCguOTggLS4zIC4zNiAuODcgLTI0NS44IDMyNC40KSIvPgogICAgICAgIDxl'
    b'bGxpcHNlIGN4PSI1MjguNyIgY3k9IjY0Ni4xIiBzdHJva2Utd2lkdGg9IjIuNSIgcng9IjEz'
    b'LjMiIHJ5PSI0MC44IiB0cmFuc2Zvcm09InJvdGF0ZSgtMjMuNCA2MzAuNSA2NjAuOSkiLz4K'
    b'ICAgICAgICA8cGF0aCBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTEzOS45IDY0NGMwIDU3Ljct'
    b'MTguOCA4Ni4yLTM0LjYgMTEwLjMgNy41LTMyLjUgMTMtNTIuNiAxMy0xMTAuMyAwLTU3Ljcg'
    b'MjkuNS04NS4zIDQwLjMtMTAyLTQuMiAxNi43LTE4LjcgNDQuMy0xOC43IDEwMnoiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDEuODggLS40NiAuOTUgMS4xOCAtMzUyLjMgLTEwKSIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMTM5LjkgNjQ0YzAgNTcuNy0xOC44IDg2'
    b'LjItMzQuNiAxMTAuMyA3LjUtMzIuNSAxMy01Mi42IDEzLTExMC4zIDAtNTcuNyAyOS41LTg1'
    b'LjMgNDAuMy0xMDItNC4yIDE2LjctMTguNyA0NC4zLTE4LjcgMTAyeiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoMS44OCAtLjQ2IC45NSAxLjE4IC0zNDguNCA0NCkiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2Utd2lkdGg9IjEuNSIgZD0iTTEzOS45IDY0NGMwIDU3LjctMTguOCA4Ni4yLTM0LjYg'
    b'MTEwLjMgNy41LTMyLjUgMTMtNTIuNiAxMy0xMTAuMyAwLTU3LjcgMjkuNS04NS4zIDQwLjMt'
    b'MTAyLTQuMiAxNi43LTE4LjcgNDQuMy0xOC43IDEwMnoiIHRyYW5zZm9ybT0ibWF0cml4KDEu'
    b'ODcgLS41IC45OCAxLjE2IC0zNjIgMTA1LjgpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjUy'
    b'OC43IiBjeT0iNjQ2LjEiIHN0cm9rZS13aWR0aD0iMS40IiByeD0iMTMuMyIgcnk9IjQwLjgi'
    b'IHRyYW5zZm9ybT0ibWF0cml4KDEuOCAtLjQgLjcgMS42NCAtOTE1LjYgLTIyMSkiLz4KICAg'
    b'ICAgICA8ZWxsaXBzZSBjeD0iNTI4LjciIGN5PSI2NDYuMSIgc3Ryb2tlLXdpZHRoPSIxLjYi'
    b'IHJ4PSIxMy4zIiByeT0iNDAuOCIgdHJhbnNmb3JtPSJtYXRyaXgoMS42MyAtLjIzIC41NCAx'
    b'LjM1IC03MzkuNSAtOTEuOCkiLz4KICAgICAgICA8ZWxsaXBzZSBjeD0iNTI4LjciIGN5PSI2'
    b'NDYuMSIgc3Ryb2tlLXdpZHRoPSIxLjYiIHJ4PSIxMy4zIiByeT0iNDAuOCIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoMS42MyAtLjIgLjUgMS4zNiAtNzUwLjYgLTkxLjgpIi8+CiAgICAgICAgPGVs'
    b'bGlwc2UgY3g9IjUyOC43IiBjeT0iNjQ2LjEiIHN0cm9rZS13aWR0aD0iMi4xIiByeD0iMTMu'
    b'MyIgcnk9IjQwLjgiIHRyYW5zZm9ybT0ibWF0cml4KDEuMyAtLjIgLjQ3IDEgLTUzMSA0Ny42'
    b'KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSI1MjguNyIgY3k9IjY0Ni4xIiBzdHJva2Utd2lk'
    b'dGg9IjIuMSIgcng9IjEzLjMiIHJ5PSI0MC44IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjMzIC0u'
    b'MTMgLjQgMS4wMyAtNTE3LjkgMTIuMikiLz4KICAgICAgICA8cGF0aCBzdHJva2Utd2lkdGg9'
    b'IjIuMSIgZD0iTTE0NS43IDU2OS41YzAgMzQtNi43IDYxLjYtMTUgNjEuNnMtMTUtMjcuNi0x'
    b'NS02MS42IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjAzIC0uNSAuNDYgMS4xOCAxMi44IC0xNC41'
    b'KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSI1MjguNyIgY3k9IjY0Ni4xIiBzdHJva2Utd2lk'
    b'dGg9IjIuMSIgcng9IjEzLjMiIHJ5PSI0MC44IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjMzIC0u'
    b'MTMgLjQgMS4wMyAtNTE5LjUgLTM0LjQpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjUyOC43'
    b'IiBjeT0iNjQ2LjEiIHN0cm9rZS13aWR0aD0iMi4xIiByeD0iMTMuMyIgcnk9IjQwLjgiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KDEuMzMgLS4xIC4zOCAxLjA0IC01MzQgLTQwLjEpIi8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIyLjkiIGQ9Ik0xNDUuNyA1NjkuNWMwIDM0LTYuNyA2'
    b'MS42LTE1IDYxLjZzLTE1LTI3LjYtMTUtNjEuNiIgdHJhbnNmb3JtPSJtYXRyaXgoLjY3IC0u'
    b'NDcgLjQ2IC44IDM5LjUgMTQzLjMpIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIy'
    b'LjkiIGQ9Ik0xNDUuNyA1NjkuNWMwIDM0LTYuNyA2MS42LTE1IDYxLjZzLTE1LTI3LjYtMTUt'
    b'NjEuNiIgdHJhbnNmb3JtPSJtYXRyaXgoLjY3IC0uNDcgLjQ2IC44IDUxLjEgMTI1LjgpIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIyLjEiIGQ9Ik0xNDUuNyA1NjkuNWMwIDM0'
    b'LTYuNyA2MS42LTE1IDYxLjZzLTE1LTI3LjYtMTUtNjEuNiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'Ljk0IC0uNjQgLjY0IDEuMSAtNDAuMiAtMTAuNykiLz4KICAgICAgICA8cGF0aCBzdHJva2Ut'
    b'd2lkdGg9IjIuNyIgZD0iTTE0NS43IDU2OS41YzAgMzQtNi43IDYxLjYtMTUgNjEuNnMtMTUt'
    b'MjcuNi0xNS02MS42IiB0cmFuc2Zvcm09Im1hdHJpeCguNjcgLS41MiAuNDYgLjg4IDY4LjYg'
    b'NzEuMikiLz4KICAgICAgPC9nPgogICAgICA8ZyBmaWxsPSIjODA0YmZmIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMi41Ij4KICAgICAgICA8cGF0aCBkPSJNMjc2LjMgMzQ1LjRj'
    b'LTEyLjMgOS4yLjQgMjUuMiAxMiAzMC43IDEzIDcuNyA4Ni42IDU4LjIgMTM2LjMgMTItNDAu'
    b'OC44LTExOC43LTYzLjItMTQ4LjMtNDIuN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4xNiAwIDAg'
    b'LjIyIDQ1OCAtMjE0LjMpIi8+CiAgICAgICAgPHBhdGggZD0iTTI3Ni4zIDM0NS40Yy0xMi4z'
    b'IDkuMi40IDI1LjIgMTIgMzAuNyAxMyA3LjcgODYuNiA1OC4yIDEzNi4zIDEyLTQwLjguOC0x'
    b'MTguNy02My4yLTE0OC4zLTQyLjd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMTYgMCAwIC4yMiA0'
    b'NTYuNiAtMjIwLjIpIi8+CiAgICAgICAgPHBhdGggZD0iTTI3Ni4zIDM0NS40Yy0xMi4zIDku'
    b'Mi40IDI1LjIgMTIgMzAuNyAxMyA3LjcgODYuNiA1OC4yIDEzNi4zIDEyLTQwLjguOC0xMTgu'
    b'Ny02My4yLTE0OC4zLTQyLjd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMTYgMCAwIC4yMiA0NTQu'
    b'OCAtMjI1LjgpIi8+CiAgICAgICAgPHBhdGggZD0iTTI3Ni4zIDM0NS40Yy0xMi4zIDkuMi40'
    b'IDI1LjIgMTIgMzAuNyAxMyA3LjcgODYuNiA1OC4yIDEzNi4zIDEyLTQwLjguOC0xMTguNy02'
    b'My4yLTE0OC4zLTQyLjd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMTYgMCAwIC4yMiA0NTAuOSAt'
    b'MjMyLjIpIi8+CiAgICAgIDwvZz4KICAgICAgPGcgdHJhbnNmb3JtPSJyb3RhdGUoMSAtNTg5'
    b'LjYgNjgxLjYpIj4KICAgICAgICA8cGF0aCBmaWxsPSIjODA0YmZmIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iMi41IiBkPSJNMjExLjIgMjQ3LjNjMjEuNy0xMiA1Ni42LTkuOCA3'
    b'OS43IDExLjIgMTkuNCAxNyA0NS4zIDc1LjIgNzAuMyA5Mi44YTU3LjcgNTcuNyAwIDAgMS00'
    b'Mi4yLTE1LjJjLTI4LjggMTUuNS0zOC4xIDE2LjctNjQgMTUuNy0zNS44LTEuNC02Mi40LTE3'
    b'LjctNjgtNDAuNi02LjMtMjEuOCA0LjgtNTIuNSAyNC4yLTYzLjl6IiB0cmFuc2Zvcm09Im1h'
    b'dHJpeCguMiAtLjA0IC4wNSAuMTggNDA3LjggLTIxMy42KSIvPgogICAgICAgIDxlbGxpcHNl'
    b'IGN4PSIyODcuMiIgY3k9IjMyMyIgZmlsbD0icmVkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iMi41IiByeD0iMTQuMiIgcnk9IjE1IiB0cmFuc2Zvcm09Im1hdHJpeCguMjUgMCAw'
    b'IC4xMyA0MDEuOCAtMjE1LjIpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjIwNC42IiBjeT0i'
    b'MzQ4LjMiIGZpbGw9IiNmZjAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjUiIHJ4'
    b'PSIyMy4zIiByeT0iMTUuOSIgdHJhbnNmb3JtPSJtYXRyaXgoLjIgLS4wOCAuMDcgLjE3IDM5'
    b'OC43IC0yMDgpIi8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjgzLjkiIGN5PSIzMzMuOSIgcj0i'
    b'NS44IiB0cmFuc2Zvcm09Im1hdHJpeCguMiAwIDAgLjIgNDExLjMgLTIzMy43KSIvPgogICAg'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZjAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSI2LjYi'
    b'IGQ9Ik01MTYuOCAyNjAuM2M0LjQgMTgtNi43IDQzLTMzLjEgNTIuNi0yNi44IDEzLjItNDYu'
    b'MSA0MS44LTU1LjcgODgtNDcuMi0xMDMuMi0yMy0xNDguMyAyMC42LTE2MC4zIDM3LjQtMTQu'
    b'NCA2MC40LTEzLjQgNjguMiAxOS43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEgMCAwIC4wOCA0'
    b'MTcuOSAtMTkxLjUpIi8+CiAgICAgICAgPGNpcmNsZSBjeD0iMTk5IiBjeT0iMzYyLjQiIHI9'
    b'IjQuNyIgdHJhbnNmb3JtPSJtYXRyaXgoLjIgMCAwIC4yIDQxOC43IC0yMzUpIi8+CiAgICAg'
    b'IDwvZz4KICAgIDwvZz4KICA8L2c+Cjwvc3ZnPgo=', 'DM')

DM = b64_DM
index.append("DM")
index.append("DMA")
index.append("Dominica")
catalog["DM"] = DM
catalog["DMA"] = DM
catalog["Dominica"] = DM
country["Dominica"] = ('DM', 'DMA', 0)
lookup["DM"] = ('DM', 'DMA', 'Dominica', 0)
lookup["Roseau Dominica"] = ('DM', 'DMA', 'Dominica', 0)
lookup["DMA"] = ('DM', 'DMA', 'Dominica', 0)
lookup["Dominica"] = ('DM', 'DMA', 'Dominica', 0)
details["DM"] = {"continent":"Americas","capital":"Roseau","currency":"East Caribbean Dollar","web":".dm","lang":"en-DM","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_DO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1kbyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgw'
    b'WiIvPgogIDxwYXRoIGZpbGw9IiMwMDJkNjIiIGQ9Ik0wIDBoMjcydjE5MkgwWm0zNjggMjg4'
    b'aDI3MnYxOTJIMzY4WiIvPgogIDxwYXRoIGZpbGw9IiNjZTExMjYiIGQ9Ik0wIDI4OGgyNzJ2'
    b'MTkySDBaTTM2OCAwaDI3MnYxOTJIMzY4WiIvPgogIDxwYXRoIGZpbGw9IiMyMDFiMTgiIGQ9'
    b'Ik0zMDcuNCAxOTYuNmEzNC45IDM0LjkgMCAwIDAtMTkgNC45Yy0yLjYgMS42LTMuMiAyLjEt'
    b'MS44IDQuN2wtMy4zIDEuMWEzOCAzOCAwIDAgMC02IDIuN2MtMS4yLjctMS42IDEuMi0yLjUg'
    b'Mi4xbDUuMy0uNC0uNyAxLjJjLTEgMS4zLTEuNSAyLjMtMi4zIDMuNyAxLjUtMSAyLjktMiA0'
    b'LjYtMi44IDMuOC0yIDEwLjctMiAxMy41LTUuNC43LS45LjMtMS40LS4zLTIuOCAyLS42IDIu'
    b'OS0xLjEgNS40LTEuNyA2LjEtMS40IDEwLjMuMyAxMy4zLS41IDEtLjIgMS44LS43IDEuOS0x'
    b'LjdsLS41LTNoMTBjMCAxLjctMS43IDQgMS40IDQuNyAyLjguOCA4LjQtLjggMTMuMy41bDUu'
    b'NCAxLjgtLjUgMS4zYy0uMy42LS4yIDEgLjIgMS40LjUuNiAxLjIgMS4yIDIgMS42YTIyLjMg'
    b'MjIuMyAwIDAgMCA1LjYgMmM1LjcgMS4zIDYuMiAxLjcgMTAuNSA0LjYtLjMtLjktMi4zLTMu'
    b'OS0zLTVsNS4zLjVjLTEtMS40LTMuNy0yLjktNS4zLTMuNWwtNi41LTIuNGMuNi0xIDEtMiAu'
    b'NS0zYTI0IDI0IDAgMCAwLTcuNy00LjMgNjguNCA2OC40IDAgMCAwLTctMS42bC02LjgtLjdj'
    b'LS4zLS4zLjYtMi0uOC0zLjMtLjgtLjYtMi0uOS0zLjMtMS01LS41LTExLjYtLjMtMTYuNiAw'
    b'LTEuNS4xLTIuNS4zLTMuMyAxLTEgMS0xLjEgMS41LTEgMy4zeiIvPgogIDxnIGZpbGw9IiMw'
    b'MDJkNjIiPgogICAgPHBhdGggZD0iTTMwOC43IDIwMC4xYy44LS42LjktLjggMi0xLjIgMi42'
    b'LS45IDYuNi0uOCA5LjMtLjggMi4yIDAgNC4zIDAgNi41LjJzMy40LjUgNC45IDEuN2MuMy0x'
    b'LjUuNi0yLjguNi00LjUuMS0xLjgtMS0yLjMtMi41LTIuNi0yLjYtLjYtNy0uNS0xMC0uNWE2'
    b'MyA2MyAwIDAgMC05LjcuNmMtMS4yLjQtMi4yIDEuNC0yIDMgMCAuOS42IDMuNiAxIDQuMXoi'
    b'Lz4KICAgIDxwYXRoIGQ9Ik0yODkuNCAyMDguN2MuNC0uNC4xLS44IDIuMi0yYTM0LjggMzQu'
    b'OCAwIDAgMSA5LjMtMy40YzIuNi0uNSA1LjMtLjUgOC0uMyAxLjIuMSAyLjguMyA0IC4xIDAg'
    b'MCAxLjMtLjMgMS43LS42LjQtLjQuNC0xLjQuNC0xLjQtLjktLjctMy40IDEuOC01LjYgMS0u'
    b'Ny0uMi0xLTEuNC0xLjItMi4zbC0uOC0yLjdhMzUuMSAzNS4xIDAgMCAwLTE1IDIuOGMtMS44'
    b'LjgtNC42IDIuMi01LjcgMy4zLTEgMSAwIDIuNC42IDMuMS42LjkgMS42IDIgMiAyLjR6bTM1'
    b'LjYtNy42Yy0uMiAxLjQuOCAxLjggMi4xIDIgMi43LjQgNi43LS44IDEyIC4yYTM1LjIgMzUu'
    b'MiAwIDAgMSA2LjQgMmMuOC40IDMuNiAxLjYgNC4xIDIuMmwxIDEuMmMuMy0uMSAxLjgtMiAy'
    b'LjEtMi40LjctLjcgMS41LTIgLjYtMy4xYTI1IDI1IDAgMCAwLTUuNy0zLjMgMzguOCAzOC44'
    b'IDAgMCAwLTcuOC0yLjFjLTIuNS0uNC03LjYtLjgtNy42LS44cy0uMyA0LjctMS42IDUuMWMt'
    b'Mi41LjgtMy44LTEuNC01LjYtMXoiLz4KICAgIDxwYXRoIGQ9Ik0zNDUgMjA3Yy0uMi42LS41'
    b'LjcuOSAxLjggMyAyLjYgOC40IDIuNyAxMS42IDQuMSAxLjcuOCAyLjYgMS40IDQuMSAyLjMt'
    b'LjEtLjUtMi0zLjItMi41LTRsNC45LjItLjItLjJjLTIuMi0xLjktNy45LTMuNy0xMC43LTQu'
    b'NmwtMi41IDIuOGMtLjMuMy0uNi42LTEuMy40LS44LS4zLTEuNS0xLTItMS41LS42LS41LTEu'
    b'Ni0xLjMtMi4zLTEuNHptLTIwLTYuNGMxLjcuMSAxLjkuNCAzIDFsMS44LjJjLjkgMCAxLS4y'
    b'IDEuMi0uOS4zLTEtMS4zLTEuNi0yLTEuN2wtMy41LS42em0tMTAgMC0uNC0yYy0xIDAtNiAu'
    b'OC01LjYgMi4zLjIuNy4zLjggMSAxIDIuMi4xIDIuNi0xLjIgNS0xLjN6bS0yNS4yIDguNGMu'
    b'NyAxLjMgMi42LTEgMy43LTEuOC42LS41LjctLjQgMS40LS43bC0uNC0uNy0yLjcgMS4zYy0u'
    b'OC41LTEuOCAxLTIgMnoiLz4KICAgIDxwYXRoIGQ9Ik0zNDUuMSAyMDYuNWMuMyAwIC41LjEu'
    b'OC4zIDEuNi45IDMuNSAzLjMgNC4zIDIuNC40LS41LTEuMy0xLjctMS44LTJsLTIuOC0xLjNh'
    b'MS42IDEuNiAwIDAgMC0uNS42em0tNTAuMi41Yy4yLjcuNS44LS44IDEuOS0zLjIgMi41LTgu'
    b'NCAyLjctMTEuNyA0LjEtMS43LjctMi42IDEuMy00IDIuMiAwLS40IDItMy4yIDIuNS00bC01'
    b'IC4zLjMtLjJjMi4yLTIgNy44LTMuNyAxMC42LTQuN2wuOSAxYTM3IDM3IDAgMCAwIDEuNiAx'
    b'LjljLjQuMy42LjUgMS4zLjMuOS0uMiAxLjYtMSAyLTEuNC42LS41IDEuNi0xLjQgMi4zLTEu'
    b'NHoiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iI2VhYzEwMiIgZD0iTTI5NS43IDE5OS44Yy0u'
    b'NSAwLS45LjItMS4zLjMtLjEgMC0uNS4yLS4yLjMuMi4xLjIuNC4zLjZsLjMuOS41IDEuNGMw'
    b'IC4xIDAgLjQuMi4zbC44LS4zYy4zLS4xLjYtLjMuOC0uN2wuMi0uNWEuOC44IDAgMCAwIDAt'
    b'LjRjMC0uMiAwLS40LS4yLS42YTEuOCAxLjggMCAwIDAtLjQtLjhjLS4yLS4yLS40LS40LS43'
    b'LS40YS44LjggMCAwIDAtLjMtLjF6bS0uMi4zYy4yIDAgLjUuMi42LjVsLjQuNy4yIDEuM2Mw'
    b'IC4yLS4zLjMtLjUuNS0uMiAwLS40LS4xLS40LS4zbC0uMi0uNi0uNC0xYTQuNyA0LjcgMCAw'
    b'IDEtLjItLjhjMC0uMi4yLS4zLjQtLjN6bTEuNy0uOS4zLjMuMi42LjEuNS4yLjcuMi42di42'
    b'czAgLjIuMSAwaC41Yy4xIDAgLjMgMCAuMy0uMmwtLjItLjMtLjItLjgtLjItLjUtLjEtLjQt'
    b'LjMtLjl2LS4zYzAtLjItLjIgMC0uMyAwbC0uNi4xem0zLS44Yy0uMyAwLS42LjEtLjguM2wt'
    b'LjMuOXYuOGwuNiAxLjIuNy40aC42Yy4zLS4xLjYtLjQuNy0uN2wuMS0uOHYtLjdhMi42IDIu'
    b'NiAwIDAgMC0uNC0uN2wtLjUtLjVhMS4xIDEuMSAwIDAgMC0uNy0uMnptMCAuMmMuMiAwIC40'
    b'LjMuNS42bC40IDEuMi4xLjV2LjdjLS4yLjItLjUuMy0uNy4xbC0uNC0uNS0uMi0uOC0uMS0u'
    b'NmMwLS4zLS4yLS42IDAtMWwuMy0uMnptMi4zLS41LS4zLjUuMS43YS44LjggMCAwIDAgLjQu'
    b'NGwuOS41Yy4yIDAgLjQuMi40LjR2LjVjMCAuMS0uMi4zLS40LjJhLjcuNyAwIDAgMS0uNC0u'
    b'MiAxLjIgMS4yIDAgMCAxLS40LS42bC0uMi4xdi42bC40LjIuNS4yYy4yIDAgLjQgMCAuNi0u'
    b'Mi4yIDAgLjMtLjIuNC0uNGExIDEgMCAwIDAgMC0uNyAxLjEgMS4xIDAgMCAwLS42LS44IDQg'
    b'NCAwIDAgMC0uNi0uM2wtLjYtLjVjMC0uMiAwLS41LjItLjVoLjZsLjMuNWMwIC4yLjIuMS4x'
    b'IDAgMC0uMi4yLS41IDAtLjZhMS40IDEuNCAwIDAgMC0uNi0uMiAxIDEgMCAwIDAtLjYuMWwt'
    b'LjIuMXptMTEuMi00LjQtLjkuMi0uNC4xYS43LjcgMCAwIDEgLjIuNHYxLjVsLjEuOHYuNmMt'
    b'LjIuMSAwIC4yLjIuMWguNmMuMiAwIDAtLjIgMC0uM2wtLjEtLjZ2LS42bC42LS4xYy40LS4x'
    b'LjgtLjQuOS0uOGExLjEgMS4xIDAgMCAwLS40LTEgMS40IDEuNCAwIDAgMC0uOC0uM3ptMCAu'
    b'M2MuMiAwIC40LjIuNC41di41YzAgLjMtLjIuNS0uNS42LS4xIDAtLjMgMC0uMy0uMnYtLjZj'
    b'MC0uMy0uMi0uNSAwLS43aC4zem0yLjYtLjRjLS4yIDAtLjQuMS0uMy4zbC0uMi43YTkuOSA5'
    b'LjkgMCAwIDEtLjIgMWwtLjMgMS4yYzAgLjEtLjIuMyAwIC4zaC41Yy4yIDAgMC0uMiAwLS4z'
    b'di0uNXMwLS4yLjEtLjFoLjh2LjZjMCAuMSAwIC4zLjIuM2guN2MuMi0uMSAwLS4zLS4xLS40'
    b'bC0uMi0uNy0uMy0uOS0uMS0uNWE5LjMgOS4zIDAgMCAxLS4zLTFoLS4zem0tLjIuOC40IDEu'
    b'M2MuMS4xIDAgLjItLjIuMi0uMSAwLS41LjEtLjUtLjFsLjEtLjVhNi45IDYuOSAwIDAgMCAu'
    b'Mi0uN3YtLjJ6bTMtMWgtMS4zYS44LjggMCAwIDEgMCAuNWwtLjEuNC4zLS4zYy4xIDAgLjIt'
    b'LjMuNC0uMmguM3YyLjlsLS4xLjJoLjljLjEgMCAuMS0uMSAwLS4xdi0zYzAtLjEuMS0uMi4z'
    b'IDBoLjJsLjIuNGguMmwtLjEtLjVjMC0uMSAwLS4zLS4yLS4zaC0xem0yLjggMGgtLjhzLS4y'
    b'IDAtLjEuMWMuMi4xLjEuMy4xLjV2Mi41YzAgLjEgMCAuMy0uMi40aDFjMC0uMS0uMi0uMi0u'
    b'MS0uM3YtMS4yYy4yIDAgLjMuMS4zLjNsLjIuNWMwIC4yLjIuMy4zLjUuMiAwIC4zLjIuNS4z'
    b'bC4zLjEtLjItLjMtLjMtLjhhMiAyIDAgMCAxLS4yLS41YzAtLjIuMS0uMS4yLS4yYTEgMSAw'
    b'IDAgMCAuNS0uNHYtLjZsLS4yLS41Yy0uMS0uMi0uMy0uMi0uNC0uM2EzLjMgMy4zIDAgMCAw'
    b'LS42LS4xaC0uM3ptLjMuMmMuMiAwIC4zLjEuNC4zYS44LjggMCAwIDEgLjIuNHYuNGMtLjEu'
    b'Mi0uMy40LS41LjRoLS41di0xLjNjMC0uMi4yLS4yLjQtLjJ6bTIuMi40djEuMmwtLjEgMS40'
    b'YS44LjggMCAwIDEtLjIuNHMwIC4xIDAgMGwuNC4xaC41Yy4yIDAgMCAwIDAtLjJ2LTIuN2Mu'
    b'MS0uMSAwLS4zLjItLjR2LS4yaC0xbC4yLjR6bTIuNS0uMi0uMy45LS4xLjUtLjMuOGMtLjEu'
    b'NC0uMi44LS40IDEtLjIgMC0uMS4zIDAgLjJoLjVjLjEuMS4yIDAgMCAwdi0uNmMwLS4yLjEt'
    b'LjMuMy0uMmguNmwuMS42YzAgLjItLjIuNCAwIC40aC43cy4yIDAgMCAwbC0uMS0xLS4yLTEt'
    b'LjEtLjlhMS45IDEuOSAwIDAgMC0uMS0uNXMwLS4yLS4yLS4xaC0uNHptMCAuOGMuMi4yLjEu'
    b'NC4yLjZ2LjhjLjIuMy0uMi4xLS4zLjEtLjIgMC0uNCAwLS4zLS4ybC4xLS40LjItLjUuMS0u'
    b'NHptNi41IDMuNWMwIC4yLjIuMy4xLjR2Mi45YS4zLjMgMCAwIDEgMCAuM2gxLjl2LS44YzAt'
    b'LjEgMCAwIDAgMC0uMi4zLS40LjUtLjcuNWgtLjV2LS41YTMxLjcgMzEuNyAwIDAgMSAwLTIu'
    b'NGwuMS0uNHptMi4zIDMuNmgxbC0uMi0uNHYtMi45bC4yLS4zaC0xYzAgLjIuMiAwIC4yLjN2'
    b'Mi45bC0uMi40em0xLjUtMy43YzAgLjIuMi4zLjEuNHYxLjJhMjYuMSAyNi4xIDAgMCAxLS4x'
    b'IDEuNGwtLjEuNXMtLjIuMSAwIC4xbDEuMS4yYy4zIDAgLjYgMCAuOC0uMi40LS4yLjUtLjcu'
    b'NC0xIDAtLjItLjItLjMtLjMtLjVhMTMgMTMgMCAwIDAtLjQtLjMuOC44IDAgMCAwIC43LS41'
    b'YzAtLjMgMC0uNi0uMi0uOGwtLjItLjItLjUtLjEtMS4zLS4yem0uOC40LjYuMWMuMi4zLjIu'
    b'NiAwIDFsLS4yLjFoLS41di0uOGwuMS0uNHptLS4yIDEuNWMuMyAwIC42IDAgLjguMy4yLjIg'
    b'MCAuNS4xLjcgMCAuNC0uMy42LS42LjYtLjIgMC0uMy0uMS0uMy0uM2E5IDkgMCAwIDEgMC0x'
    b'LjN6bTEuOCAyIC4zLjIuOS4yLjguMS4yLS41YzAtLjItLjEtLjMtLjItLjFhMSAxIDAgMCAx'
    b'LS45LjFjLS4yIDAtLjMtLjItLjMtLjRsLjItMS4yLjQuMWMuMiAwIC4zLjIuNC40bC4xLS4z'
    b'di0uN2MtLjEgMC0uMi40LS40LjItLjIgMC0uNSAwLS40LS4ybC4xLS44Yy4zLS4xLjcgMCAu'
    b'OS4zbC4zLjN2LS43bC0uNS0uMi0xLjMtLjNjLS4zIDAgMCAuMiAwIC4zbC0uMiAxLjctLjIg'
    b'MS4yYS41LjUgMCAwIDEtLjIuM3ptMy0yLjh2LjZsLS4zIDEuNi0uMiAxYzAgLjEtLjQuMi0u'
    b'MS4zbC43LjJjLjIgMCAwLS4yIDAtLjNsLjItLjcuMS0uNGMuMiAwIC4xLjMuMi40IDAgLjQu'
    b'Mi44LjMgMS4xbC42LjUtLjItLjV2LTEuNGMuMSAwIC4zIDAgLjUtLjIuMi0uMy4zLS43LjIt'
    b'MWExLjMgMS4zIDAgMCAwLS42LS44bC0xLjItLjRhMS4yIDEuMiAwIDAgMC0uMiAwem0uOC40'
    b'YS43LjcgMCAwIDEgLjYuNGMuMS40IDAgLjgtLjEgMS4xLS4yLjItLjQuMi0uNi4xLS4yIDAt'
    b'LjQgMC0uMy0uMmwuMi0xYS43LjcgMCAwIDEgLjItLjR6bTEuNSAxLjIuNS0uMnMuMy0uMS40'
    b'IDBjLjEuMSAwIC4zIDAgLjRsLS4xLjctLjQgMS42LS4zLjRjMCAuMi4yLjIuMy4ybC42LjJj'
    b'MC0uMS0uMS0uMiAwLS40bC4yLTEuMmEzMS4zIDMxLjMgMCAwIDEgLjQtMS42Yy4yIDAgLjQu'
    b'Mi41LjNsLjIuNWMuMSAwIDAtLjIgMC0uNGwuMS0uNC0uOC0uMy0uNi0uMy0uNy0uMi0uMy42'
    b'YS4zLjMgMCAwIDAgMCAuMXptMy40LjdjLS4yIDAtLjIuMi0uMy40IDAgLjItLjIuMy0uMy41'
    b'bC0uOSAxLjRhMS4xIDEuMSAwIDAgMS0uNC40Yy0uMi4yLjEuMi4yLjMuMSAwIC4zLjIuNC4x'
    b'IDAtLjItLjItLjMgMC0uNSAwLS4xIDAtLjQuMy0uM2wuNi40di41YzAgLjEtLjMuMi0uMi40'
    b'bC41LjNzLjMuMi4yIDB2LS44bC4xLS41di0uOGwuMi0xLjJjMC0uMi4xLS40IDAtLjRsLS40'
    b'LS4yem0tLjMuN3MuMS4xIDAgLjJ2MS4zYzAgLjItLjMgMC0uNCAwLS4xLS4xLS40LS4yLS4y'
    b'LS40bC40LS42LjItLjV6bTIuMi41LS4xLjYtLjQuNi0uNC43LS41IDFoLS4ybC41LjUuNi42'
    b'Yy4zLjIuOC4zIDEuMS4xbC41LS41YTMuNCAzLjQgMCAwIDAgLjMtLjZ2LTFjMC0uNC0uMi0u'
    b'OS0uNS0xLjJsLS42LS42LS4zLS4yem0uNi45Yy4zLjIuNS41LjQuOCAwIC41LS4yIDEtLjUg'
    b'MS40LS4yLjMtLjQuNi0uNy42LS4yLjEtLjUgMC0uNi0uM2wuMi0uNi44LTEuNGMwLS4yLjIt'
    b'LjQuMy0uNWguMXoiLz4KICA8cGF0aCBmaWxsPSIjMDA2MzAwIiBkPSJtMzA4LjggMjc5LjIg'
    b'Mi41IDEgMS44IDMuNGMuNy41LjYuNCAxLjMuNmwtNC4zIDEuOGMtMS4yLjQtLjcgMS41LS4x'
    b'IDEuNy42LjIgMi0uMyAyLjQtLjUgMi4xLTEgNC0yIDYtMy4zLjMtLjIgMS43LTEuMSAyLTFs'
    b'Ny42IDQuMmMuNi4zIDEuNyAxIDIuMy42LjMtLjIuNi0uNi41LTEtLjEtLjUtLjQtLjYtLjgt'
    b'LjdsLTQuMS0xLjguOS0uM2MuMy0uMi0uMi0uNy4yLS42bDEuOS0zLjEgMi4zLS45YzAtMi4x'
    b'LTE3LjgtMy41LTIyLjQtLjF6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmMCIgZD0iTTMxMCAyODYu'
    b'NWMtLjYuMi0uNSAxLjQuOCAxIC45LS4zLjItMS4zLS44LTF6bTE5IDBjLS4zLjUtLjMuNy4y'
    b'IDEgLjUuMS43LjEgMS0uMi41LS40LjEtLjYtLjItLjgtLjQtLjItLjEtLjItLjQgMGgtLjd6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iIzAwNjMwMCIgc3Ryb2tlPSJvbGl2ZSIgc3Ryb2tlLXdpZHRo'
    b'PSIuMiIgZD0iTTM0NS44IDIxNnYuM2MxLjcgMy4yIDEgMS43IDIuNCA1LjlsLS44LTEuMWEz'
    b'MC4yIDMwLjIgMCAwIDEtMi0zIDEuMyAxLjMgMCAwIDAtLjQtLjZjLS4yLjMuNCAyIC42IDIu'
    b'NS41IDIgMi4xIDQuNCAzLjMgNi4zbC0uOS0uN2MtMS0uOC0uNy0uNi0xLjMtMS43YTIwLjMg'
    b'MjAuMyAwIDAgMS0xLjQtMyA1MS42IDUxLjYgMCAwIDAtLjgtMi4ybC0uMi4ydi45bC42IDMu'
    b'NmMtLjgtLjMtLjYtLjQtMS4zLTEtLjIgMC0uNC0uNi0uNi0uNmwtLjctLjhjLS4xLjQgMSAy'
    b'LjQgMS4yIDIuNi40LjYgMS44IDEuNiAyIDJhMTQgMTQgMCAwIDAgMi4xIDMuN2wuOSAxLjEt'
    b'MS45LTEuOGEzMyAzMyAwIDAgMC0zLjQtM2MwIC40LjYuOC45IDFsMi4zIDIuNmMuNyAxIDEu'
    b'NiAxLjggMi4yIDIuOGwxLjUgMi41YTEzLjggMTMuOCAwIDAgMC0uOC0xLjFsLTIuMy0yLjhj'
    b'LS44LTEtMS42LTEuNi0yLjYtMi40YTI1LjYgMjUuNiAwIDAgMC0yLTEuNGMwIC4zIDEuOSAy'
    b'LjcgMy4yIDMuNGwxLjIgMS4zIDEuMiAxLjNhMzYuMyAzNi4zIDAgMCAxIDEuOSAzbC45IDEu'
    b'NWMtLjctLjItNC00LTQuNy00LjctLjctLjctMS0xLTEuOC0xLjUgMCAuNCAyLjMgMyAyLjgg'
    b'My41bC41LjYgMSAxLjFjLjYuOCAxLjggMi4yIDIuMiAzbC43IDEuNGEyMCAyMCAwIDAgMC0x'
    b'LjUtMiA3LjggNy44IDAgMCAwLS45LTFjLS43LS44LTEuOS0yLjItMi44LTIuOGwtMi4yLTEu'
    b'M2MtLjEuMi40LjYuNi44bC45LjhhMjEuNyAyMS43IDAgMCAxIDMuMSAzLjRjLjYuNiAxIDEu'
    b'MiAxLjQgMmEzLjEgMy4xIDAgMCAxLS43LS43bC0uNy0uNy0xLjYtMS4yLTMuNi0xLjhjMCAu'
    b'MyAxLjMgMSAxLjYgMS4yLjcuNSAyIDEuMiAyLjUgMS45bC43LjdjLjUuNSAxIDEgMS4zIDEu'
    b'NmwxLjIgMS43IDEgMiAxLjMgNC41Yy0uNC0xLjUtMS4yLTMtMS43LTQuNi0uNC0xLTEuNC0z'
    b'LjgtMi44LTMuMy0uNS4yLS44LjgtMSAxLjItLjMuNy0uOC0uMi0yIDJhMTguMSAxOC4xIDAg'
    b'MCAwLTEuMiA0LjN2LjdjLjMtLjEuNS0uOS42LTEuMi41LTEuNCAxLTIuMyAxLjktMy42bC0x'
    b'LjEgNC45Yy40LS4xLjUtLjcuNi0xbDEuNC0zLjdjMS42IDEuMSAyIDcuMiAyLjMgOS4zYTIx'
    b'LjQgMjEuNCAwIDAgMC0xLjEtM2wtMS43LTIuOGMtMSAuMS0xIDEuNC0xLjIgMi4xLS4zLS40'
    b'LS42LTEtMS4zLTEtLjUgMC0uOC44LS45IDEuNGE3LjcgNy43IDAgMCAwIDAgMi4ybC40IDEu'
    b'Ni4yLjIuMy00LjFjLjYuMyAxLjggMyAxLjYgNC0uNiA0LTEgNS4zLTMuMSA4LjZsLTEuMiAx'
    b'LjdhMTAgMTAgMCAwIDEtLjYuOGwtLjcuOGMxLjEtMiAxLjYtMi43IDIuNC00LjlhMjQgMjQg'
    b'MCAwIDAgMS4yLTV2LS45Yy0uMyAwLS4zLjQtLjQuNy0xLjggNS43LTIuMSA2LTUuMSAxMWwu'
    b'NS0zLjNjLS4yIDAtLjIuMi0uMy42bC0uMi42YTE3LjggMTcuOCAwIDAgMS0xLjYgMy42YzAt'
    b'LjMuMy0uOC40LTEuMWEyNiAyNiAwIDAgMCAuNy0zLjR2LS43Yy0uMyAwLS40LjYtLjUgMS0u'
    b'NCAxLjItMSAyLjItMS40IDMuM3YtLjNjMC0uNy4zLTEuOC4xLTIuNXYtLjNjLS4zLjEtLjQu'
    b'Ny0uNSAxbC0uMyAxYy0uNyAxLjktMS41IDMuMS0yLjUgNS0uNi0uMS0uMiAwIDAgMGEyMDku'
    b'NSAyMDkuNSAwIDAgMCA1LjcgMS4xYzIuOC0uMSA0LjYtLjMgNy40IDAgLjQgMCAyLjEuMyAy'
    b'LjQgMC0uOC0uNC0xLjYtLjYtMi41LS45bC0yLjctLjYgNy41LS4yLS42LS40Yy0xLjMtLjUt'
    b'NC42LS43LTYtLjggMi41LS4yIDQuNC0uNCA2LjgtLjQuNy0uMiAyLjkuNSAyLS41LTEtLjYt'
    b'My44LS43LTQuNy0uNmw0LjQtLjJjLjctLjIgNS4zLjggMy43LS4yLTEuMy0uNy00LTEuMi01'
    b'LjQtMS40LjgtLjUgMS41LTEgMi4zLTEuM2E0MC43IDQwLjcgMCAwIDEgNS4zLTEuN2MyLS4z'
    b'IDMuNS0xLjMuOS0uOS0xLjYuMi0zLjUuNy01IC44bDEuMy0uN2MxLjMtLjYgMi43LS45IDQt'
    b'MS4zLjMtLjEuMiAwIC4zLS4ybC0uMi0uMWgtLjhhNjUuMSA2NS4xIDAgMCAwIDctMmMuMyAw'
    b'IC43IDAgLjktLjJsLS4yLS4xYTg2IDg2IDAgMCAwLTYuNC44bC0yIC4zIDUtMmMuNCAwIDEu'
    b'Ni0uMiAxLjgtLjUtLjMtLjItLjYtLjEtMS4xIDBhMzYgMzYgMCAwIDAtNC43IDEuMmwtMS44'
    b'LjVjNS42LTIuMSAzLjQtMS41IDguNi0yLjUuNi0uMSAxIDAgMS4xLS40bC0zLS4yYy0xIDAt'
    b'MiAuMi0yLjcuM2wyLjItMS45Yy42LS41LjMtLjcgMS40LS43aDJjLS44LS45LTEtLjUtMS44'
    b'LS45bDEtMSAuNS0xYy4xLS4xLjEtLjEgMC0uMmgtLjNsLTIuMyAyYy0uNC4yLS4zLjItLjku'
    b'MmwtMyAuNmEyNC43IDI0LjcgMCAwIDEgMy0yLjFsMS43LTFjLjUtLjIgMS42LS42IDEuNy0u'
    b'OGwtMy42LjlhMTkuMiAxOS4yIDAgMCAwLTMgMS41IDQ1LjggNDUuOCAwIDAgMSA1LjgtNS4y'
    b'Yy4yLS4xLjgtLjQuOS0uN2gtLjNjLTEgLjItMy4yIDEuNy00IDIuMWEzNi4zIDM2LjMgMCAw'
    b'IDAtMy44IDIuOCAyNy45IDI3LjkgMCAwIDEgMi43LTIuNmwuNS0uNSAxLjEtMWMuOC0uNiAx'
    b'LjUtMS4yIDIuMi0ybDEuMS0uOWMuMy0uMiAxLS43IDEtMWE1NS4zIDU1LjMgMCAwIDAtNC40'
    b'IDIuN2wtMi4xIDEuNS0yLjEgMS42Yy45LTEuNCAxLjgtMi45IDIuOS00LjFhNDUuNiA0NS42'
    b'IDAgMCAxIDQuNy00LjRjLjQtLjMuOC0uOCAxLjItMXYtLjJjLS40IDAtMS42LjktMS45IDEu'
    b'MWEzOC41IDM4LjUgMCAwIDAtNC43IDRsLS43LjhhMTUgMTUgMCAwIDAtMiAyLjQgNjIgNjIg'
    b'MCAwIDAtMi40IDMuNmMuNS0yLjIgMi00IDMuMi01LjJsMi43LTMgLjQtLjVhMTAgMTAgMCAw'
    b'IDAgMy01LjhsLTEuMyAxLjgtLjcuNy01LjQgNi4zYy4yLS45IDEuMy0yLjggMS44LTMuNWE2'
    b'My4zIDYzLjMgMCAwIDEgNS42LTcuNWwuMy0uM2MwLS4zLjQtLjUuOC0uOWwxLS44Yy0uNS0u'
    b'NS0yLjQuNi0yLjcuOS0yLjQgMS42LTQuMSAzLjktNS45IDYuMWEyNi4xIDI2LjEgMCAwIDEg'
    b'Mi40LTUuN2MuNS0uOCAxLTEuOCAxLjYtMi41bDEuNi0yLjRjLS40IDAtLjguNS0xIC44bC0u'
    b'NS40Yy0yIDIuMy0zLjMgNC44LTQuOCA3LjUuMS0xLjMgMS4zLTMuNyAyLTQuOGwyLjgtNC4y'
    b'Yy0uNS0uMS0yIDEuNi0yLjMgMi0uNi44LTEuMyAxLjYtMS44IDIuNmEzMSAzMSAwIDAgMC0y'
    b'LjcgNS41bC0uMi40Yy4xLTEuOCAyLTYuMSAyLjctNy42bDEuNi0yLjIuNS0uNyAxLjEtMS40'
    b'IDEuMS0xLjVjLS43LS4yLTMuMiAyLjYtMy43IDMuMmwtMS43IDIuNWMuMy0xLjQgMS4zLTMu'
    b'MyAyLjEtNC41bDIuMS0yLjcuNy0xYy0uOCAwLTQgMy43LTQuNyA0LjVsLS43IDEuMS0xLjEg'
    b'MS43LS4yLjMtLjIuM2EzNyAzNyAwIDAgMSAxLjQtNS4zbDItNC41Yy0uNSAwLTEuNiAxLjQt'
    b'MS45IDEuOGwtMS4yIDIuNWMuMS0xLjIgMS44LTUgMi40LTYuNS0uMyAwLS41LjYtLjggMWwt'
    b'Mi4zIDMuOGMuMS0xLjMgMS0yLjYgMS41LTMuNy0xIC40LTIuOCA0LjItMy4yIDUuM2wtLjUg'
    b'MS42LS4yLjZjMC0yLjguNS01LjcgMS04LjUtLjMgMC0uNC4zLS41LjZsLS4zLjctLjYgMS42'
    b'LS44IDMuNGMtMS4yLTEuNy0xLjUtNC44LTMuOS04LjQtLjctMS4xLTEtMS4yLTItMnptMS4z'
    b'IDMzLjhjMSAyLjggMS4zIDMuNyAyIDYuNmEuNy43IDAgMCAwLS4yLjNsLS40IDEuMi0uOC0y'
    b'LjVjLS4yLTEgLjItMi44LS4yLTMuMS0uMi41LS4yLjUtLjIgMS40bC0uNS0xYy0uNS0xLjYt'
    b'LjYtMS4xLS4yLTIgMC0uMy4yLS43LjUtLjl6Ii8+CiAgPGcgZmlsbD0iIzAwOGY0YyI+CiAg'
    b'ICA8cGF0aCBkPSJNMzU0LjQgMjQ1LjFjLjQtMy44IDUtMTIuOCA2LjUtMTMgLjIgMC0xLjYg'
    b'Mi41LTIuOCA1YTU2LjcgNTYuNyAwIDAgMC0zIDcuMyAxNyAxNyAwIDAgMS0uNyAyLjZ2LTJ6'
    b'bTEwLjItMi4zcy0uOC45LTEuOSAxLjhhNDQuMyA0NC4zIDAgMCAwLTkuNiAxMy44Yy0yIDUt'
    b'MS41IDMuNy0uOSAxLjNhMzUuMyAzNS4zIDAgMCAxIDkuNy0xNS4xYzEuNC0xLjIgMi44LTIu'
    b'MSAyLjctMS44em0tMTEuOC04LjZjMC0zLjQuNC00LjYgMi40LTguOCAxLjItMi43IDEuNy0z'
    b'LjUgMS45LTMuMyAwIC4xIDAgLjYtLjMgMWE1MCA1MCAwIDAgMC0zLjQgMTEuNyA1LjUgNS41'
    b'IDAgMCAxLS40IDEuNyA3IDcgMCAwIDEtLjItMi4zem0tNS42IDE5LjRhMjAuMiAyMC4yIDAg'
    b'MCAxLTEuNCA4LjhjLS43IDEuOC0zLjUgNi00LjIgNi40LS4zIDAtLjIgMCAuNS0xYTIyLjEg'
    b'MjIuMSAwIDAgMCA1LTEzLjRjLS4yLTIuNiAwLTMgLjEtLjl6Ii8+CiAgICA8cGF0aCBkPSJN'
    b'MzU1LjggMjUwLjNjLjQgMS4yLjUgNCAwIDUuNWExMSAxMSAwIDAgMS03LjIgNy41IDUuNyA1'
    b'LjcgMCAwIDEtMS4zLjMgNS40IDUuNCAwIDAgMSAxLjItLjcgMTIuNCAxMi40IDAgMCAwIDcu'
    b'My0xMWMwLTEtLjEtMS40LS4yLTEuNiAwLS40LS4xLS43IDAtLjhsLjIuOHoiLz4KICAgIDxw'
    b'YXRoIGQ9Im0zNjUuNyAyNTcuOS00LjQuOGExOTQuOCAxOTQuOCAwIDAgMC05LjMgMS42Ljku'
    b'OSAwIDAgMS0uMS0uMyAxNjguNyAxNjguNyAwIDAgMSAxMy44LTIuMXptLTE4LjUtMzkuN2Mx'
    b'LjUgMS44IDEuOCAyLjYgMi42IDUuNy41IDIgLjYgMi42LjUgMi42bC0uNC0uN2EzNC40IDM0'
    b'LjQgMCAwIDAtMy4yLTcuNyAzLjggMy44IDAgMCAxLS42LTEgNSA1IDAgMCAxIDEgMXptLTEu'
    b'NiAyLjJjLjYgMi4yIDEuMSAzIDMuMyA1LjMgMS40IDEuNCAxLjkgMS45IDEuOSAxLjcgMCAw'
    b'LS4xLS40LS40LS42YTM0IDM0IDAgMCAxLTQuNi02LjkgMy44IDMuOCAwIDAgMC0uNi0xczAg'
    b'LjcuNCAxLjV6bTEzLjQgN2MtMi40IDIuMi02LjMgOS4yLTUuNyAxMC4zLjEuMSAxLjEtMS41'
    b'IDIuMi0zLjZhNDguNCA0OC40IDAgMCAxIDMuNC01LjhsMS40LTItMS4zIDEuMXptMSAxLjhj'
    b'LTIuNiAyLjQtNi45IDEwLjItNi4zIDExLjQuMS4yIDEuMi0xLjYgMi40LTRhNTQuMyA1NC4z'
    b'IDAgMCAxIDMuOS02LjQgMTUuNyAxNS43IDAgMCAwIDEuNS0yLjFsLTEuNCAxLjF6bS0xNS4y'
    b'LTcuMWMuNCAyLjMuOCAzIDIuNiA1LjYgMS4yIDEuNyAxLjcgMi4yIDEuNyAyIDAgMCAwLS40'
    b'LS4zLS42YTM0LjMgMzQuMyAwIDAgMS0zLjctNy41IDMuOCAzLjggMCAwIDAtLjUtMS4xbC4y'
    b'IDEuNnoiLz4KICAgIDxwYXRoIGQ9Im0zNDguNCAyMjYuNyAyLjYuN2MwLS4yLS40LS4zLS43'
    b'LS40LTEuNy0uNS02LjQtMi42LTYuNS0zLjRsLTEtMS41czQgNCA1LjYgNC42em0xNi4yIDgu'
    b'M2MtMy42IDIuNS0xMCAxMS4yLTkuNSAxMi44IDAgLjMgMS43LTEuNyAzLjYtNC40YTY1Ljgg'
    b'NjUuOCAwIDAgMSA1LjctNy4zIDE5IDE5IDAgMCAwIDIuMS0yLjNzLTEgLjUtMS45IDEuMnpt'
    b'LS41IDUuM2MtMS42IDMuMi03LjcgOS4zLTkgOWExNSAxNSAwIDAgMSAzLjEtMy4zIDUxLjgg'
    b'NTEuOCAwIDAgMCA1LTUuNCAxNS42IDE1LjYgMCAwIDEgMS42LTJjMCAuMi0uMyAxLS43IDEu'
    b'N3ptLTIxLjQgMjJjLS42IDMuMS00LjUgOS44LTUuNyA5LjktLjEgMCAuNy0xLjcgMi0zLjdh'
    b'NDcuMyA0Ny4zIDAgMCAwIDMtNS44bDEtMi0uMyAxLjZ6bTEwLTE4LjljLS43LTItMi41LTQu'
    b'NC01LTYuNi0yLjQtMi4yLTMuMi0yLjUtMS0uNWEyOSAyOSAwIDAgMSA2LjMgOC44czAtLjgt'
    b'LjMtMS43em0xLjggMjUuNWMtMi44LS44LTEwLS43LTEwLjUuMSAwIC4yIDEuNi4yIDMuOC4x'
    b'YTQ3LjMgNDcuMyAwIDAgMSA4IC4zbC0xLjMtLjV6bS0zIDEuMmMtMi45LS43LTEwLS4zLTEw'
    b'LjUuNmgzLjdhNDcgNDcgMCAwIDEgOC4yLS4xbC0xLjQtLjR6bS0zLjIgMS42Yy0yLjgtLjct'
    b'MTAgMC0xMC41LjhsMy44LS4yYTQ3LjggNDcuOCAwIDAgMSA4LjEtLjJsLTEuNC0uNHoiLz4K'
    b'ICAgIDxwYXRoIGQ9Ik0zNDYuNCAyNzMuNWMtMi4zLTEtOC42LTEtOS0uMy0uMi4yIDEuMy4z'
    b'IDMuMi4yYTM2LjEgMzYuMSAwIDAgMSA1LjIuM2wxLjguM2E5IDkgMCAwIDAtMS4yLS41em0x'
    b'MS4yLTguOWMtNiAxLjctMTMgMi43LTEzLjQgNC4xIDAgLjIgMi42LS4yIDUuMi0xLjJhNTYu'
    b'NCA1Ni40IDAgMCAxIDcuNS0yLjRjMS41LS4zIDIuNy0uNiAyLjctLjggMCAwLTEgLjQtMiAu'
    b'M3ptNy42LTMuNy01LjIgMWEyMTMgMjEzIDAgMCAwLTggMS41Yy0yLjQuNS0yLjkuNi0zIC4z'
    b'YTEgMSAwIDAgMS0uMi0uMyAxOTcuNiAxOTcuNiAwIDAgMSAxNi40LTIuNXptLTEuOC0xLjUt'
    b'NC4zIDEuMmExNzQuNSAxNzQuNSAwIDAgMC05IDIuNS45LjkgMCAwIDEtLjItLjIgMTY4Ljgg'
    b'MTY4LjggMCAwIDEgMTMuNS0zLjV6Ii8+CiAgICA8cGF0aCBkPSJNMzYyIDI1Mi40Yy00LjEg'
    b'MS43LTEyLjIgOC44LTEyIDEwLjUgMCAuMyAyLTEuMyA0LjQtMy42YTY0LjQgNjQuNCAwIDAg'
    b'MSA3LTUuOCAxOC43IDE4LjcgMCAwIDAgMi42LTEuOGwtMiAuOHoiLz4KICAgIDxwYXRoIGQ9'
    b'Ik0zNjUgMjU0LjRjLTQgLjMtMTMuMyA0LjQtMTMuNSA2IDAgLjMgMi4xLS41IDQuOS0yYTU2'
    b'IDU2IDAgMCAxIDcuOC0zLjJsMi44LS44aC0yeiIvPgogICAgPHBhdGggZD0iTTM2NC44IDI1'
    b'NC44Yy0xMC4zIDguNy0xNi4xIDEzLTE4LjIgMTItLjMgMCAzLjgtMi40IDcuMy00LjdhNzgg'
    b'NzggMCAwIDAgOS40LTdsMy0yLjdhMTggMTggMCAwIDEtMS41IDIuNHptLTExIDIuOGMyLTMu'
    b'NCAzLTQuNCA3LjUtNy4yIDIuOS0xLjggMy45LTIuNCA0LTJsLTEgLjhhNTYuMSA1Ni4xIDAg'
    b'MCAwLTExLjggMTAuN2wxLjMtMi4zem0xLjEtOS44Yy40LTMuOCA2LjgtMTYuNSA4LjItMTYu'
    b'Ny4yIDAtMS41IDIuNS0yLjcgNWE1NyA1NyAwIDAgMC0zIDcuMyA3NCA3NCAwIDAgMS0yLjgg'
    b'N2wuMy0yLjZ6bS0yLjctMTQuNmMtMS4xLTIuNi0xLjItMy42LS40LTcuMi41LTIuMy44LTMu'
    b'MSAxLTN2LjlhMjguNyAyOC43IDAgMCAwIC4yIDExcy0uNS0uOC0uOC0xLjd6bTIgMTMuOWEx'
    b'NSAxNSAwIDAgMC00LjUtNmMtMi4yLTItMi45LTIuMy0uOS0uNGEyNiAyNiAwIDAgMSA0Ljkg'
    b'Ni42bC43IDEuMy0uMi0xLjV6bS0xMCAyLjljMi03LjQgMy43LTYuMSAzLjctNi4xIDQuNCA0'
    b'LjIgMi4yIDE4LjcgMi4yIDE4LjcgMC0yOS42LTUuOS0xMi42LTUuOS0xMi42eiIvPgogICAg'
    b'PHBhdGggZD0iTTM0NS45IDI0OS41YzItNy40IDIuNS03IDIuNS03IDMuNy43IDMuNSAxNyAz'
    b'LjUgMTctMS42LTI4LTYtMTAtNi0xMHptLTIgNS43YzAtNS4zIDEtNC41IDEtNC41IDMgMi43'
    b'IDQgMTMgNCAxMy00LjYtMjAuOC01LTguNS01LTguNXptOS0xNS41Yy0uOC0yLjktMy42LTUu'
    b'OC02LjQtOS41LTMuNS0zLjItNC42LTMuNy0xLjUtLjcgMiAxLjIgNiA3IDcuMiAxMC41LjYg'
    b'MS4yIDEuMSAyLjEgMS4yIDIgLjIgMCAwLTEuMS0uNC0yLjN6Ii8+CiAgICA8cGF0aCBkPSJN'
    b'MzUyLjcgMjM3LjJhMTggMTggMCAwIDAtNS4yLTcuNGwtMS42LTEuNUE2MCA2MCAwIDAgMSAz'
    b'NTMgMjM5Yy4xIDAgMC0uOS0uMy0xLjh6bS0xNSAyOS4zYy0uMSAxLjUtMS44IDUuMS0yLjQg'
    b'NS4ybC44LTJhMjQgMjQgMCAwIDAgMS43LTR2Ljh6bS0xLjQuOWMtLjIgMS42LTEuOSA1LjEt'
    b'Mi41IDUuMmwuOC0xLjlhMjQuMSAyNC4xIDAgMCAwIDEuOC00LjF2Ljh6bTIuMi4xYy0uMiAx'
    b'LjYtMS45IDUuMi0yLjUgNS4ybC45LTEuOWEyNCAyNCAwIDAgMCAxLjctNC4xdi44eiIvPgog'
    b'IDwvZz4KICA8cGF0aCBmaWxsPSIjMDA4NzNmIiBkPSJNMjg0IDIyN2MwIC44LjIgMSAuNiAx'
    b'LjVWMjI3Yy0uMi0uMi0uMyAwLS42IDB6Ii8+CiAgPGcgZmlsbD0ibm9uZSIgc3Ryb2tlPSIj'
    b'MDA2MzAwIiBzdHJva2Utd2lkdGg9Ii42IiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtMTA2LjEg'
    b'LTIwLjQpIHNjYWxlKC44NTIyNykiPgogICAgPHBhdGggZD0ibTQ1NS4yIDMwNC0uOS0uOG0x'
    b'LjgtNC42LS44LTFtLTEuNyAxMy41Yy0uMy0yLjEtMS41LTIuOC0xLjUtMi44bTExLjMgMzBj'
    b'LTUuNC02LTcuMS0xNi43LTcuMS0xNi43IDEuNy00LjYgNC01LjYgNC01LjZtLTQgNS41Yy0x'
    b'LjgtNy0xLjMtMTQuMi0xLjMtMTQuMmE3MC44IDcwLjggMCAwIDEgMy40LTE2LjhtLTMuNSAx'
    b'OS4zYzEuNC02LjYgNi45LTUuOCA2LjktNS44Ii8+CiAgICA8cGF0aCBkPSJNNDU0LjggMzEx'
    b'YzUtMiA0LjMtNi4zIDUuMi04IDEuMy0yLjcgMi4zLTMuNSAyLjMtMy41bS0yLjYgMzIuOWMt'
    b'MS43LTQuMi4zLTUgLjMtNW0tMSAzLjZjLTIuMS0yLjctNC44LTIuNS00LjgtMi41bTMuOS0x'
    b'MC4zYzEuMy0yLjQgMC00LjggMC00LjhtLjYgMTYuMy0zLjgtNC45bTIuMy0zMC40Yy41LTIt'
    b'MS0yLjktMS0yLjkiLz4KICAgIDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKDQ0MiAyMjQuMikg'
    b'c2NhbGUoLjE1NjcpIj4KICAgICAgPHBhdGggaWQ9ImRvLWEiIGZpbGw9InJlZCIgc3Ryb2tl'
    b'LXdpZHRoPSIyIiBkPSJNOTEuNCA0MjZhNiA2IDAgMSAxLTEyIDAgNiA2IDAgMCAxIDEyIDB6'
    b'Ii8+CiAgICA8L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNkby1hIiB3aWR0aD0iMTAwJSIg'
    b'aGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09Im1hdHJpeCguMTU2NyAwIDAgLjE4MTI4IDQ0NC42'
    b'IDIzNS4zKSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjZG8tYSIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoNDQzLjcgMjQ4LjMpIHNjYWxlKC4x'
    b'NTY3KSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjZG8tYSIgd2lkdGg9IjEwMCUiIGhlaWdo'
    b'dD0iMTAwJSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoNDQwIDI1Mikgc2NhbGUoLjE2ODk5KSIv'
    b'PgogICAgPHVzZSB4bGluazpocmVmPSIjZG8tYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAw'
    b'JSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoNDM4LjcgMjU2LjIpIHNjYWxlKC4xNjg5OSkiLz4K'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI2RvLWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHRyYW5zZm9ybT0idHJhbnNsYXRlKDQ0MC4zIDI1Ny44KSBzY2FsZSguMTY4OTkpIi8+CiAg'
    b'ICA8dXNlIHhsaW5rOmhyZWY9IiNkby1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSg0NjMuMiAyODYpIHNjYWxlKC4xMjI4OSkiLz4KICAgIDx1'
    b'c2UgeGxpbms6aHJlZj0iI2RvLWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5z'
    b'Zm9ybT0idHJhbnNsYXRlKDQ2NC4zIDI4Ny4zKSBzY2FsZSguMTIyODkpIi8+CiAgICA8cGF0'
    b'aCBkPSJNNDU4LjggMzE2LjZhMS44IDEuOCAwIDAgMC0xLjEtMS4ybTE0LjcgMjQuMWMxLjYg'
    b'MS4yIDIgLjUgMiAuNSIvPgogIDwvZz4KICA8ZyBmaWxsPSIjMDA2MzAwIj4KICAgIDxwYXRo'
    b'IGQ9Ik0yOTguMiAyNzEuOGMtLjktMy0uNy0zLjYtLjctMy42bS02LjUtMS43cy0uNS0xLjIu'
    b'NC0xLjljLjQtLjQgMi41LjggMy42LTMuOSAwIDAtLjcgMC0yLjEuN3YtLjRzLS40LTEtLjIt'
    b'Mi4zYzAgMCAuNy0xLjEuNy0xLjYgMCAwLTEuMy0uNS00IDIuOSAwIDAtLjItLjctMi4xLTIg'
    b'MCAwLTEgMy0uNSA0LjYuNCAxLjMuNCAxLjggMS44IDIuNyAwIDAgMSAuNSAxLjIgMmwxLjIt'
    b'LjF2LS43em0tMiAzLjRjLS4zLjItLjUuNS0xLjMuNi0zLjMuNC01LjItNC01LjItNC0uMS0x'
    b'IC4zLS41IDEtLjIuOS4zIDEuMiAwIDIuMiAwIDEuNC0uMiAyLjkgMS4xIDIuOSAxLjEuOC44'
    b'IDEgMi4zIDEgMi4zLS4yLjItLjUuMi0uNS4yem0tNC04Yy0zLjQtMS41LTUuNS4yLTUuNS4y'
    b'LS4yLjIuMi4zLjIuMyAyLjIuMyAxLjUuMSAyLjQgMS40IDEuNiAyLjIgNC40IDEuNyA0LjQg'
    b'MS43LjUuMiAxLjEuOCAxLjEuOC0uMi0xLjktMi41LTQuNC0yLjUtNC40em0tNi0xNGMtLjct'
    b'LjUtLjYuNC0uNi40LTEuNC0yLjUtNS4zLTIuNy01LjMtMi43YS43LjcgMCAwIDEtLjUtLjNj'
    b'LS42IDAgLjIgMS4zLjIgMS4zIDEuMSAzLjEgMi4yIDMuNSAyLjIgMy41LTEuMy43LTMuNC0u'
    b'OS0zIC4zIDIuMSAyLjEgMy41IDIuNCAzLjUgMi40IDIuNi43IDMuNyAwIDMuNyAwIC42IDEu'
    b'MSAxIDEuMyAxIDEuMyAyLjQuNyAyLjkgMiAyLjkgMiAwLTIuNi0xLTUuNy0xLTUuN2ExMiAx'
    b'MiAwIDAgMC0zLjEtMi41eiIvPgogICAgPHBhdGggZD0iTTI5Ny4yIDI3Mi43Yy0xLjMuNC0x'
    b'LjQgMS4zLTEuNCAxLjMtMS4yIDEuNy01LjYgMC01LjYgMC0xLjQtLjMtMS0uNy0xLS43YTUu'
    b'NiA1LjYgMCAwIDAgMS42LTEgOC42IDguNiAwIDAgMS0yLjctNWMzLjYtLjcgNC43IDAgNC43'
    b'IDAtLjItMS40LTEuNC0xLjQtMS40LTEuNC0uMy0uNS4zLS41LjMtLjVhNy44IDcuOCAwIDAg'
    b'MSA1IDIuM2MxLjIgMS43LjggMy40LjggMy40LjMgMS43LS4zIDEuNi0uMyAxLjZ6TTI4Mi4z'
    b'IDI1OGMtMS44LS41LTIuOCAwLTIuOCAwLTEgLjQtMi42LS42LTIuNi0uNi0yLjItMS45LTIu'
    b'Ni0zLTIuNi0zIDAtLjMgMS45LS4zIDEuOS0uMyAyLjYgMCAzLjIuNSAzLjIuNSAxLjMuNyAx'
    b'LjIgMS40IDEuNiAxLjdhNSA1IDAgMCAxIDEuNCAxYy4zLjUuNC45LS4xLjd6bTMuNCAxYzEu'
    b'My0xLjUgMy0uNSAzLS41IDIuNS4zIDMuMy0yLjYgMy4zLTIuNmwxLTEuN2MuMS0uNy0xLjEt'
    b'LjEtMS4xLS4xLTIuMi41LTIuMy43LTIuMy43bC40LTMuNGMwLS42LS42LS4yLS42LS4yLTMu'
    b'MSAxLjgtMy41IDMuMS0zLjUgMy4xbC0xLjMtMi40Yy0uNC0xLS43LjEtLjcuMS0uNiAzLS4z'
    b'IDMuMi0uMyAzLjIuNCAxLjYuOCAyIC44IDIgLjcgMSAuNyAxLjQuNyAxLjR6Ii8+CiAgICA8'
    b'cGF0aCBkPSJNMzA0LjIgMjY3Yy0uNS4xLTEuOCAyLjItMS44IDIuMi0xLjYtMy0zLjctMy40'
    b'LTMuNy0zLjQtLjQuMSAwIC44IDAgLjguNyAxLjYgMCAyLjggMCAyLjgtLjIgMS4yIDAgMS40'
    b'IDAgMS40LTIuNS0xLjMtMi42LTEuMS0yLjYtMS4xIDAgMS42IDEuOCA0LjUgMS44IDQuNWw0'
    b'LjUtMSAxLjUtLjJjMS4yLTMuNi4zLTYgLjMtNnpNMjg0IDI1MC44YzEuNi43IDEuNyAxLjgg'
    b'MS43IDEuOC40IDEuMyA0LjEgMS43IDQuMSAxLjcgMy0uMyAyLjctMSAyLjctMS0xLjctMS40'
    b'LTEuMi0xLjMtMi0yLTEuMy0xLjMtMy0xLjQtMy0xLjQtMi4zLjQtMi44IDAtMi44IDAtLjku'
    b'NC0uNy45LS43Ljl6bS0zLjYtNS40Yy0uNy0yLjcgMS43LTYgMS43LTYgMiAzLjggMS43IDQu'
    b'OCAxLjcgNC44YTI0LjYgMjQuNiAwIDAgMS0xLjcgNC41Yy0uNC0yLTEuNC0yLjMtMS43LTMu'
    b'M3oiLz4KICAgIDxwYXRoIGQ9Ik0yNzkgMjQ2LjVjLTIuNSAwLTUtMi45LTUtMi45IDMuOS0x'
    b'IDQuNy0uNCA0LjctLjRhMjIuNyAyMi43IDAgMCAxIDMuNiAyLjVjLTEuOCAwLTIuMy44LTMu'
    b'Mi44eiIvPgogICAgPHBhdGggZD0iTTI3NyAyNDIuOGMtMS42LjMtMy0xLjMtMy0xLjMtMi4y'
    b'LTMtMS41LTQtMS41LTQgLjIgMCAuNC4zLjQuMy43LjYgMiAuOCAyIC44LTMuNi0yLjItMS4y'
    b'LTcuMS0xLjItNy4xLjQtLjUuNi43LjYuN2E0LjYgNC42IDAgMCAwIDEuOCAyYy44IDEgLjgg'
    b'MS40LjggMS40LjMtMS42LjgtMS4yLjgtMS4yLjQgMS4zIDEuOSAyLjMgMiAzLjIuNiAyLjUu'
    b'MiAyLjguMiAyLjgtLjMgMS40LS4zIDIuNS0uMyAyLjUtMS40LS41LTIuNSAwLTIuNSAwem04'
    b'LjQgNmMuOC0xLjIgMC0zLjMgMC0zLjMtLjMtMi4zIDMuMS00LjUgMy4xLTQuNSAxIDEuOS45'
    b'IDMgLjkgM2wzLjItLjhjLjEgMS40LTEuMyAzLjYtMS4zIDMuNiAyLjEuNiAyLjktLjQgMi45'
    b'LS40LTEgNC43LTUuNiAzLjgtNS42IDMuOGE4LjggOC44IDAgMCAwLTMuMi0xLjR6Ii8+CiAg'
    b'ICA8cGF0aCBkPSJNMjc4LjMgMjM0LjljLjMtMi45LjgtMyAuOC0zIC4zLjEuNCAxLjQuOCAx'
    b'LjYgMS44LjggMS44IDIuOCAxLjggMi44IDAgMi4zLS40IDItLjQgMi0yLjUgMC0zLTMuNC0z'
    b'LTMuNHptOC4zLjZjLjktMy4zLjMtMy42LjMtMy42LS4zIDAtMSAxLjMtMS42IDEuNC0yLjMu'
    b'MS0zIDIuMy0zIDIuMy0xIDIuNS0uNSAyLjQtLjUgMi40IDIuOCAxIDQuNS0xLjQgNC44LTIu'
    b'NXoiLz4KICAgIDxwYXRoIGQ9Ik0yNzguNCAyMjkuNWMuMy0zLjMgMS0zLjUgMS0zLjUuMy4y'
    b'LjUgMS43IDEgMS45IDIgMSAyIDMuMiAyIDMuMiAwIDIuNy0uNCAyLjUtLjQgMi41LTMgMC0z'
    b'LjctMi45LTMuNi00em05LjQuOGMxLTMuMi40LTMuNS40LTMuNS0uNCAwLTEuMSAxLjMtMS42'
    b'IDEuM2EzLjcgMy43IDAgMCAwLTMuMiAyLjJjLS45IDIuNS0uNCAyLjUtLjQgMi41IDIuNyAx'
    b'IDQuNC0xLjMgNC44LTIuNXptMy44IDljMi43LTIgMi41LTIuNiAyLjUtMi42LS4zLS4yLTEu'
    b'Ny40LTIuMS4yLTItMS4zLTMuOSAwLTMuOSAwLTIuMiAxLjQtMS44IDEuNi0xLjggMS42IDEu'
    b'NiAyLjUgNC40IDEuNiA1LjMuOXoiLz4KICAgIDxwYXRoIGQ9Ik0yOTEuNSAyNDEuMWMyLjYt'
    b'MS4xIDIuNS0xLjYgMi41LTEuNi0uMi0uMy0xLjUgMC0xLjgtLjMtMS40LTEuMi0zLjEtLjYt'
    b'My4xLS42LTIuMS44LTEuOCAxLTEuOCAxIC45IDIuMiAzLjMgMiA0LjIgMS41em0tOC43LTE1'
    b'LjRjLTEtMyAyLTcgMi03YTQwLjUgNDAuNSAwIDAgMSAxIDMuNGMyLjQtMi41IDQuNi0yLjkg'
    b'NC42LTIuOWwtLjEgMmE2LjggNi44IDAgMCAwIDIuMy0uNmMtLjQgMi40LTMuNCA0LjktMy40'
    b'IDQuOS0xLjIuNy0yLjYuNC0yLjYuNC0yLjIuNy0yLjcgMi4xLTIuNyAyLjEtLjItMS4zLS40'
    b'IDAtMS4xLTIuM3ptNC40IDEwYzEuNC0xLjcgMy41LTEgMy41LTEgMiAuMiAzLjctMS44IDMu'
    b'Ny0xLjhhNS42IDUuNiAwIDAgMSAxLjQtMS44YzAtLjUtLjYtLjQtLjYtLjRsLTEuMS4zYy45'
    b'LTMuMy40LTMuNC40LTMuNC0uMyAwLS41LjItLjUuMi0uNSAxLjUtMi42IDEuNC0yLjYgMS40'
    b'LS4xLTIuMi0uNi0xLjktLjYtMS45LS4zLjYtMSAxLTEgMS0yLjEgMi0yLjEgMi45LTIuMSAy'
    b'LjkuMSAyLjQtLjUgNC42LS41IDQuNnoiLz4KICA8L2c+CiAgPGcgZmlsbD0iIzAwODYzZCI+'
    b'CiAgICA8cGF0aCBkPSJtMjg2LjggMjQ3LjcgMS40LTFjLjUtLjMuMy0uMi41LS43bC41LS43'
    b'LS4zLjkgMS40LS44YzAgLjMtLjUuNS0uOS44YTIyLjYgMjIuNiAwIDAgMS0xIC42bC0xLjkg'
    b'MS42YzEuOC0uNCAxLjQtLjEgMi4zLS4yIDEuOS0uMyAyLjgtMyAzLjQtNC41YTkuOSA5Ljkg'
    b'MCAwIDAtMy41IDEuMWMtMS4yLjgtMS4yIDEuNi0xLjkgM3ptLTQuOCA2LjdjMC0uMy0uNC0u'
    b'OC0uNi0xLS41LTEtLjUtMS4yLTEuMi0yLjNsLS41LTFjLjIgMCAuNi44LjkgMXYtMWMuMyAw'
    b'IC4yLjMuMi42IDAgMSAwIC45LjYgMmwxLjMgMi4yYzAtLjQtLjItLjctLjMtMS0uNC0xLjQu'
    b'NS0zLjEtMy01LjJsLS45LS41YzAgMS43LjMgNC41IDEuOCA1LjRsMSAuNC43LjR6bS0uOC0y'
    b'MS41YzAtLjQtLjMtLjgtLjQtMS4zLS4yLS40IDAtLjMtLjQtLjVsLS40LS41LjUuMmEzLjMg'
    b'My4zIDAgMCAwLS40LS44Yy0uMy0uNC0uMi0uMS0uNS0uNy42LS4xIDEuMiAxLjcgMS4zIDIu'
    b'MS41IDEuNC40IDEuMiAxLjMgMi4zIDAtLjItLjQtLjUtLjQtLjgtLjItLjcuNi0xLjctLjIt'
    b'My40LS41LTEtMS41LTEtMi0xLjlsLS40LS44YTcuNiA3LjYgMCAwIDAtLjQgMS44YzAgMS4y'
    b'LjIgMi43IDEgMy41LjMuMyAxIC43IDEuNC44em00LjUtOC41Yy4yIDAgLjUtLjUuOC0uOGwu'
    b'OC0uNy0uMS0uOGMuMiAwIDAgMCAuMy41bDEtMS40YzAgLjMtLjQgMS0uNiAxLjItLjIuNC0u'
    b'NC43LS44IDFsLTEuNiAyIDEtLjNjMS0uMiAxLjQtLjMgMi4xLTEuNWExMCAxMCAwIDAgMCAx'
    b'LjItMy44Yy0xLjUuNi0zLjEgMS4zLTMuOSAyLjctLjMuNS0uMiAxLS4yIDJ6bS05LjUgMTQu'
    b'M2MtLjUtMS0xLjctMi40LTEuOC0zbC0uMi0xLjNjLjMgMCAuMiAwIC4yLjJsLjIgMSAuNSAx'
    b'YzAtLjcgMC0uNC4yLTEgLjMuNC0uMSAxIC4yIDEuNmwuOCAxLjJjMC0xIC42LTIuNC0uNC0z'
    b'LjctLjQtLjUtLjgtLjctMS4zLTFsLS45LTEuNGMtLjcgMS41LS41IDQuNS45IDUuNWwuOC41'
    b'LjQuMi40LjJ6bTYuOC02Yy42LS40LjQtLjYgMS44LTEuN2wuOS0uOS45LS45Yy4xLjMtLjgg'
    b'MS4yLTEuMSAxLjZoLjZjLS4xLjQtLjUuMS0xIC4zLS4zIDAtMS40IDEuMy0xLjcgMS42bC44'
    b'LS4yYy45LS4yIDEuNSAwIDIuNC0xLjIuOC0xIDEtMi4zIDEuNS0zLjUtMS4yLjMtMi43IDEt'
    b'My40IDEuNi0xIDEtLjkgMS43LTEuMiAyLjZsLS41Ljh6bS00LjggOS4zYTQuOSA0LjkgMCAw'
    b'IDAtLjgtLjhjLS41LS4zLS42LS4zLTEuMi0uNGwtMi0xLjFjLjItLjIuMy4xLjguNGwxIC40'
    b'LS4yLS41Yy4yIDAgLjIgMCAuMy4ydi4zYzEgLjEuOC4xIDEuNy43IDAtLjQtLjEtLjQtLjQt'
    b'LjZsLS41LS41LS40LS42Yy0uOC0xLjItMS43LS43LTIuMi0uOGwtMS41LS42YTUuNiA1LjYg'
    b'MCAwIDAgMS43IDMuMWMuNC40LjkuOCAxLjYuOWwyLjEtLjJ6bS0uOCA3LjVhOC4xIDguMSAw'
    b'IDAgMC0xLS43Yy0uMi0uMi0uMy0uMi0uNi0uMmwtLjctLjJoLjdsLS4zLS4zLTEtMWMuMi0u'
    b'MS4zIDAgLjUuMmwyLjMgMS44IDEuMS42YzAtLjYtMS0yLjQtMS44LTIuOGwtMy43LTFhMTUg'
    b'MTUgMCAwIDAgMS41IDIuOGMxIDEuNSAxLjIgMSAyIC45aDF6bTEuOC04LjEtMS40LTQuNmMu'
    b'Mi4xLjIuNC4zIDFsLjQuOS4zLS43Yy4yLjIgMCAuNiAwIC45LS4yLjQtLjIuMyAwIC44bC42'
    b'IDEuNnYtMWMuMy0xIC41LTEuNiAwLTIuOC0uNS0xLTEuMy0xLjctMi0yLjVsLS4zIDEuOGMt'
    b'LjIgMS4yLS4xIDIuOC44IDMuNS44LjYuMy4xIDEuMyAxem0yLjcgNS44di00LjdjLjIuMS4y'
    b'LjMuMi40djEuNWwuNC0uN2MuMy4xIDAgLjQtLjEuNmwtLjQuOC4xIDIuMS40LS44Yy41LS43'
    b'IDEtMS44LjgtMi44bC0xLjItMy40LS44IDEuNmE3LjMgNy4zIDAgMCAwLS41IDEuOWMtLjMg'
    b'MS42LjIgMS45LjcgMi43bC40Ljh6bTEuOS0yMC4zYzAtLjQuMi0yLjUuMS0yLjdsLS4yLS40'
    b'LS4yLS45Yy4zIDAgLjIuMy40LjZ2LjFsLjEtLjZjMC0uNCAwLS4yLjItLjYuMi4xIDAgMCAu'
    b'MS4yYTMgMyAwIDAgMSAwIC4zYy0uMiAxLjQtLjIgMy0uMyA0LjNsLjQtLjhjLjMtLjcgMS0y'
    b'IC45LTIuOGwtLjgtNC4xLS44IDEuNmMtLjUgMS4xLTEgMi44LS43IDRsLjcgMS42di4yem0t'
    b'MTEgMjMuNiAxLjEgMWMuNy41IDIuMyAxLjIgMy4xIDEuMmwxLjgtLjQtLjItLjgtMSAuMWE2'
    b'LjcgNi43IDAgMCAxLTEuMiAwIDE0LjggMTQuOCAwIDAgMS0xLS4yYy0uNi0uMi0uNCAwLS45'
    b'LS40bDIgLjNjLS42LS40LS40LS4yLS44LS43LjMgMCAuOS41IDEuMi43bDEuNi0uMS0uMS0x'
    b'Yy0uOC0uMy0yLS4zLTIuOSAwLTEuNy42LTEgLjQtMi43LjN6bTIuMiA0LjNjMCAuMyAxLjgg'
    b'Mi4zIDIuMiAyLjVsMy45LjFhMTYuMSAxNi4xIDAgMCAwLTEuNy0uN2MtLjgtLjMtLjgtLjIt'
    b'MiAwIDAtLjMuMy0uMyAxLS40bC0xLjUtLjUtLjItLjJoLjVsNCAxLjVhNC41IDQuNSAwIDAg'
    b'MS0xLjEtMWMtMS42LTItMy4yLTEuNC01LjEtMS4zem0xMy4zLTIxLjMuNS0xYy4zLS43LS4x'
    b'LS43IDAtMS41LjMgMCAuMiAwIC4zLjdsLjctMS42Yy4yLjYtLjkgMi42LTEuMSAzLjJsLS40'
    b'IDFjMS0xIDItMS41IDIuMi0yLjRsLjEtNGMtLjYuNS0xLjUgMS40LTIgMi4xLS42IDEtLjYg'
    b'Mi0uNCAzLjV6bS0xLjggMjQuMiAxLS41YzEuNS0uNC45LjMgMS44LTFsLS4yLjdjLjctLjMu'
    b'OC0uNyAxLjMtMS4yLjIuMy0uMi43LS40LjktLjkuOC0xLjcuNS0yLjIuN2wtMSAuNWMxLjEt'
    b'LjIgMSAwIDIgLjIgMS44LjMgMi40LTEuNiAzLTIuOGwuNS0uOGE5LjYgOS42IDAgMCAwLTQu'
    b'NSAyLjJsLS42LjZjLS4zLjItLjUuMi0uNy41eiIvPgogICAgPHBhdGggZD0iTTI4Ni40IDI0'
    b'Ny41Yy42LS42LjUtMi4xIDEtMyAwLS4yLjItLjMuMy0uNC4xLS4yIDAtLjIuMy0uMi4xLjIt'
    b'LjMuNC0uNC43bC0uMyAxIC4xLS4xYS45LjkgMCAwIDAgLjEtLjJjLjUtLjYuOS0uOCAxLjYt'
    b'MS4ybC0uNy0yLjQtMS4yIDFhNS42IDUuNiAwIDAgMC0xIDEuMmMtLjggMS41LjEgMi4yLjIg'
    b'My42em0tLjQgMTAgMS42LTIuNnYtMS4yYy4yIDAgLjEtLjEuMy43LjUtLjguMi0uNy44LTFh'
    b'NiA2IDAgMCAxLS44IDEuNGwtMS41IDIuNWMuNCAwIC45LS42IDEuMS0uOWwuNi0uNS43LS40'
    b'LjctMy42YTEwIDEwIDAgMCAwLTIuNyAyYy0xIDEuMi0xIDEuNi0uOCAzLjZ6bTMuNS05IDIt'
    b'LjNjMCAuMy0uMy4zLS45LjRsLTMuNi4xLjkuNS44LjRjLjcuNCAxLjQuMyAyLjEgMGwyLjct'
    b'Mi40Yy0xLjQuMy0uNi40LTIuNSAwbC0xIDEtLjUuMnptLTE0LjUtNWMuNiAxLjIgMi4zIDIu'
    b'NiAzLjggMi40LjcgMCAuOC0uMyAxLjItLjdoLS4xYS43LjcgMCAwIDAtLjItLjFjLTEuMi0u'
    b'My0xLjMtLjItMi41IDBsLjUtLjMtLjktLjItLjgtLjRjLjItLjEuMS0uMS40IDAgMS41LjUg'
    b'MS45LjQgMy42LjctLjItLjUtMS41LTEuMi0yLjItMS4zLTEuMi0uMS0xLjYuNS0yLjgtLjF6'
    b'bTEwIDEzLjYtLjUtMy4zYy4zIDAgLjIuMi4zLjlsLjYgM2MwLTEuMi40LTIgLjEtMy4ybC0x'
    b'LjItMi4yYTkgOSAwIDAgMC0uMyAyLjdjMCAxIC4zIDEuMy44IDEuOWwuMi4yem00LjUtMzMu'
    b'Ny40LS41LjUtLjRjMCAuMy0uNC42LS42IDEtLjQuNS0uNy42LS45LjgtLjcgMS0uNi44LTEu'
    b'OCAxLjMgMi40LjIgMy44LTIuNCA0LjgtNC4yLTIuMy4zLTEuOS41LTIuMSAxLjJsLS4zLjh6'
    b'bS44IDEwLjQuNy0xLjFjLjQtLjYuNi0uMiAxLjMtLjgtLjItLjItLjItLjEtLjkuMWwxLjIt'
    b'MS41Yy0uNy4xLTIgMi4zLTIuMyAyLjhsLS44LjljLjUtMS40LjMtMi43IDEtMy4zbDMuNy0y'
    b'LjNjLS4xLjktLjUgMi4xLS45IDMtLjYgMS4xLTEuNSAxLjYtMyAyLjJ6bS05LjIgNC40LTEu'
    b'MS0xLjYtLjUtMi4yYy4zIDAgLjMuNi4zLjlsLjMgMWMuMi0uOC0uMS0uMy4zLTEgLjIuNS0u'
    b'MyAxLjEgMCAxLjVsLjcgMWMuMy0xIC4zLTIuMy0uMy0zbC0xLjctMS44Yy0uNC42LS40IDIu'
    b'NCAwIDMuMy4zIDEgLjcgMS4yIDEuMyAxLjVsLjcuNHptMS40LS4zYy41LS41IDEuNS0xIDEu'
    b'Ny0xLjNsMS40LTJjLS4zLS4xLS41LjUtLjcuN2wtLjYuOWMwLS44LjItLjIgMC0xLS40LjQt'
    b'LjIgMS4yLS42IDEuNWwtMS4xLjhjMC0xLjEuNS0yLjUgMS40LTNsMi41LTEuNGMuMi45LS41'
    b'IDIuOC0xLjEgMy42LS44IDEtMS4yIDEtMiAxbC0uOS4yem00LjYuM2MuNiAwIDIuNSAwIDMt'
    b'LjRsLjgtLjNjMCAuMiAwIDAtLjMuNGgxLjFjMCAuMS4yLjEtLjYuMmwtMiAuMi0yLjcuM2Mx'
    b'LjguNiAyIDEuNiA0IC44IDEuNi0uNiAyLTEuMiAzLTIuNC0yLjYuNi0yLjgtMS41LTUuMiAw'
    b'bC0xLjEgMS4yeiIvPgogICAgPHBhdGggZD0iTTI5MC40IDIzOS43Yy42IDAgLjMgMCAuOS4y'
    b'LS4zLjItMS40IDAtMS44IDBoLTEuOGMuNi44IDEuNiAxLjIgMi45IDEgMS4zLS4xIDEuNy0u'
    b'NCAyLjctMWwtMi0uN3ptLS44IDExLjVhMy4yIDMuMiAwIDAgMC0uOS0uNWMtMS0uNS0yIDAt'
    b'Mi41IDBsLTEuMy0uMmE2IDYgMCAwIDAgMi40IDFjMS43LjMuNS43IDIuMy0uM3ptLjIgMS4y'
    b'LjUuNWMtLjEgMC0uMyAwLS41LS4ybC0uMSAxLjIgMi4zLS4zYTE3IDE3IDAgMCAwLTItMi4y'
    b'bC0uMiAxem0tMyAuNyAxLjQtMWMtLjMtLjQtMS0uMy0xLjUtLjVsLTEuMy0uNS43IDEgLjcg'
    b'MXptNi43LTIwLjZjLS42LjQtMSAuOS0xLjcgMS4yLS45LjQtMS44IDAtMi40LjYgMS41LS4x'
    b'IDIuNS41IDMuNy0uNi44LS43IDEuNC0xLjcgMi0yLjZhMi43IDIuNyAwIDAgMC0xLjIuNGwt'
    b'LjMuNWMtLjMuNCAwIDAgMCAuNXptLTUgMzUgMSAyLjIgMS42IDIgMS0uNyAxLjMtLjRjLS43'
    b'LS4zLS43LS42LTEuMS0uN2gtMS43Yy4xLS4zIDAtLjIuOC0uMmguOGMtLjUtLjUtMS4xLS44'
    b'LTEuNi0xLjJsMS42Ljl2LTEuMWMuNCAwIC4xLjcuMyAxLjMuMS4yLjYuNiAxIC43LjUuMy43'
    b'LjIgMS4yLjRsMS4zLjRjLS41LS44LS4yLjEtMS4xLTEuOGEzLjQgMy40IDAgMCAwLTEuNC0x'
    b'LjZjLTEuNS0uOS0zLjMtLjMtNS0uMnptMS45LTIuM3YtMi43bC0uMy0yLjFjLjIgMCAuMi4x'
    b'LjMuNGwuMS42Yy4yLTEgLjMtMSAuOC0xLjYgMCAuMi0uNSAxLS42IDJsLS4xIDIuNy4yLS4z'
    b'LjMtLjMuNS0uNmMxLjMtMiAuNS0zLjIuNS0zLjhsLjQtMmE5LjUgOS41IDAgMCAwLTEuOCAx'
    b'LjNjLTEgMS0yIDIuOC0xLjMgNC4zbC41IDEgLjQgMS4xeiIvPgogICAgPHBhdGggZD0ibTI4'
    b'OS43IDI3MyAxLjguNmMxLjEuNCAzIC41IDMuOC0uNi41LS42LjgtLjcgMS4zLTEuMi0uOCAw'
    b'LTEuNS40LTIuMi41LS42LjItLjYuNi0xLjEgMWwtLjQuM2MwLS4zLjUtLjguOC0xLjFoLTEu'
    b'OGMwLS4zLjYtLjIgMS4zLS4yIDEuNS0uMiAxLjgtLjYgMy40LS44YS43LjcgMCAwIDAgLjMg'
    b'MGMtMi40IDAtMy0xLjctNS45LjR6bTExLTEuNXYtMS4yYy0uNS0uNC0uNS0uNi0uOC0xLjIu'
    b'MyAwIC40LjUuOS44IDAtLjYtLjMtMS42LS41LTIuMi4zIDAgLjQuOC41IDEuMS40IDEuNCAw'
    b'IDIuNS4zIDNsLjcgMWMuMi0xIDEuMy0xLjcgMC00LjEtLjctMS41LTEuMy0xLjgtMi41LTIu'
    b'Ny4xLjcuMyAxIC4yIDEuOGwtLjQgMS42Yy0uMiAxLjMuMyAxLjIuNSAxLjNsMS4yLjh6bS0x'
    b'Mi0yLjMtLjMtLjhjLTEgMC0xLjMuNC0yLjgtLjYtLjMtLjItLjMtLjItLjUtLjZsMS42IDEt'
    b'LjYtMWMwLS4xIDAtLjIuMSAwaC4ybC43IDFoMWwtLjItLjdjLS4xLS40IDAtLjQtLjMtLjZh'
    b'Mi44IDIuOCAwIDAgMC0xLjQtLjZsLTEuNi4yLTEuNi0uM2MwIC4zLjcgMS4zLjggMS42Ljcg'
    b'MSAyLjUgMi4zIDQgMS43bDEtLjN6bS04LjQtNy41aC4xbC4yLjFhMyAzIDAgMCAxIDEuMS44'
    b'Yy41LjQuNS43IDEuMSAxLjIgMSAuOSAyLjEuOCAzLjUgMWE3LjIgNy4yIDAgMCAwLS42LS43'
    b'Yy0xLjEtMS4yLTEtMS4xLTEuNi0xSDI4M2MwLS4yLjctLjIgMS4yLS4zYTMuMSAzLjEgMCAw'
    b'IDAtLjctLjNjLS42IDAtLjIgMC0uOS0uMi4zLS40IDEuOC4yIDIuNS44bDEuNiAxLjgtLjgt'
    b'MS43Yy0uOC0xLjUtMy0yLTQuNS0xLjdhNCA0IDAgMCAwLTEgLjJ6bTkuNSAzLjljLS41LTEu'
    b'OC0xLjUtMi42LTEuNy0zLjctLjItLjctLjEtLjcgMC0xLjQuNC41LS4zLjguOCAyLjYgMC0u'
    b'Ni0uMi0uOC0uMS0xLjVsLjQtMS40Yy0uMS0uMy0xLjQtMS41LTEuNy0xLjktLjIgMS42LS42'
    b'IDMtLjEgNC42LjUgMS42IDEuNCAxLjMgMi40IDIuN3ptOC42IDggMS4xLS4yYTYuMyA2LjMg'
    b'MCAwIDEtLjctMWMtLjUtLjctLjQtLjctLjItMWwuMS42LjQuNGMuMi40LjQuNi44LjkgMC0u'
    b'Ni0uMi0uOCAwLTEuMi4yLjEgMCAwIC4xLjJsLjEgMSAxLjMtLjRjLS45LTEuNS0yLjUtMi00'
    b'LTIuNmwuNCAxLjguNiAxLjZ6bS0yLTMuMi0uNS0xYy0uNC0xLS40LTEuMy0xLjItMi4ybC0u'
    b'NC0uNC0uMy0uM3YtLjFjLjIgMCAuOC42IDEgLjguNS40IDEuNiAyLjggMiAzLjUtLjEtLjMt'
    b'LjMtLjctLjItMSAuNC0xLS41LTIuNC0xLTIuN2wtMy41LTEuNWMuNC40LjcuNiAxIDEuMi4y'
    b'LjYuMy4xIDEuMiAxIDEgMS4xIDEgMi40IDIgMi43eiIvPgogICAgPHBhdGggZD0ibTMwMi45'
    b'IDI3MC40LjEtLjVjLjItLjMgMC0uMi4zLS40LjIuMiAwIC4zLS4xLjdsLS43IDIuNWMuOC0u'
    b'MS43LS4xIDEtLjcuMy0uNC40LS45LjUtMS4zbC0uMS0zLjMtMSAxLjNjLS41LjctLjIuMyAw'
    b'IDEuN3ptLTEwLjYtNy41Yy4zLS4xLjgtLjggMS4xLTEgLjEuMi0uNS45LS43IDEtLjYuNi0u'
    b'MiAwLTEgMSAxLjYuMiAyLjItMS44IDIuNy0yLjhsLTEuNS40Yy0uMi4xLS4xIDAtLjIuM2wt'
    b'LjEuNGMwIC4zLS4yLjUtLjMuOHoiLz4KICA8L2c+CiAgPGcgZmlsbD0iI2NlMTEyNiIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4yIj4KICAgIDxwYXRoIGQ9Im0zMDcuNiAyODEu'
    b'OCAxLjkgMS0xLjEgMi4xYy44LS4xIDMuNi0xLjEgNC42LTEuNC0uMy0uNy0uNC0uNy0uMy0x'
    b'LjZsLS4zLTEuNS0yLjMuOGExOS4yIDE5LjIgMCAwIDEtMi41LjZ6bTI0LjgtLjMtMS45IDEg'
    b'MS4xIDJjLS44IDAtMy42LTEtNC42LTEuMy4zLS43LjQtLjguMy0xLjZsLjMtMS41IDIuMy44'
    b'IDIuNS42eiIvPgogICAgPHBhdGggZD0iTTMxNC40IDI4NC44YTEyLjQgMTIuNCAwIDAgMCA0'
    b'LTEuNGMuNC4zIDIuMSAwIDIuMSAwYTguOCA4LjggMCAwIDAgMS4xLS4yIDEwLjEgMTAuMSAw'
    b'IDAgMCAzLjggMS42YzEuOS0uMSAyLTEuNiAyLTEuNmwtLjMtMS4zYzEtMS42IDAtMi44IDAt'
    b'Mi44LS42LS42LTMuNS4zLTMuNS4zLTIgMS0yIC41LTIgLjUtLjYtLjgtMi42LS43LTMuNSAw'
    b'bC0yLjUtLjZjLTIuMi0uOS0yLjUtLjQtMi41LS40LS44IDEtLjUgMi0uNSAybC4xIDFjLS40'
    b'IDIuOCAxLjggMyAxLjggM3oiLz4KICAgIDxwYXRoIGQ9Ik0zMjEuNiAyODIuNGM0LjcgMS4x'
    b'IDQuNCAxLjggNC40IDEuOC0uMy41LTEuNy0uMi0xLjctLjItMy42LTEuMi0yLjctMS42LTIu'
    b'Ny0xLjZ6bS0yLjkgMGMtNC43IDEuMS00LjMgMS44LTQuMyAxLjguMy41IDEuNi0uMiAxLjYt'
    b'LjIgMy43LTEuMiAyLjctMS41IDIuNy0xLjV6Ii8+CiAgICA8cGF0aCBmaWxsPSIjYWEyNDFl'
    b'IiBkPSJNMzE5IDI3OS4zYy0yIC4zLS41IDEuOC0uNCAyLjggMCAuNS0uNSAxLjMgMCAxLjUu'
    b'NS4zIDEuNSAwIDIuMSAwIC44IDAgMS4zIDAgMS4yLTEgMC0uNy0uMy0xLS4zLTIgMC0uNi4x'
    b'LTEuNC0uNi0xLjRhMTIuNSAxMi41IDAgMCAwLTIgMHoiLz4KICAgIDxwYXRoIGZpbGw9Im5v'
    b'bmUiIGQ9Ik0zMjEuNyAyODAuNGM1LjMgMCA1LS45IDUtLjltLTUgMi41YzUuNC43IDQuNyAx'
    b'LjUgNC43IDEuNW0tNy45LTEuNmMtNSAxLTQuNSAxLjktNC41IDEuOW00LTMuNWMtNS4xLjMt'
    b'NC42LS41LTQuNi0uNSIvPgogIDwvZz4KICA8cGF0aCBkPSJNMjk4LjEgMjc0Yy0yLjcgMS00'
    b'LjUgMS42LTcgMy4xbC0zLjMtNWE3IDcgMCAwIDAtMi4yLTEuOGMtMS41LS43LTItLjUtMyAu'
    b'M2wtLjYtMS4zYy0xLjMtMi4zLTIuNy0zLjMtNC4xLTUuMmwtMS40LTEuNS0uNC0uNWMuNSAx'
    b'LjkgMSAzLjYgMS4zIDUuNy0uOC0uNS0xLjYtMS0yLjQtMS4zYTkgOSAwIDAgMC0zLS41bDEg'
    b'LjlhMTEuOCAxMS44IDAgMCAxIDMuMyA1LjUgMTYuNyAxNi43IDAgMCAwIDQuMiA2LjUgNy45'
    b'IDcuOSAwIDAgMCAyIDEuNWMyIC44IDEuOSAwIDIuNi0uM2EzMS4yIDMxLjIgMCAwIDAgNC4y'
    b'IDUuOCA4IDggMCAwIDAgNy41IDEuOWMxLjItLjMgMi0uNyAzLTEuMiAzLjQtMiAxLjctMy42'
    b'IDEuMy01LjJhMTA5IDEwOSAwIDAgMSA3LjItMmM1LjYtMSAxNi0xLjIgMjIuNy0uMi42LjEg'
    b'Ny4zIDEuOSA4IDIuM2E1LjQgNS40IDAgMCAwLS42IDIuOWMwIDEuMSAxIDEuNyAyIDIuMmEx'
    b'MCAxMCAwIDAgMCA2LjQgMS4zIDcuNyA3LjcgMCAwIDAgNC45LTMuMmMxLjgtMiAyLjMtMy4y'
    b'IDMuMi00LjcgMCAwIC41LjUuOS42LjMuMSAxLjUgMCAxLjgtLjIuOC0uMyAxLjQtMSAyLTEu'
    b'NWExNS41IDE1LjUgMCAwIDAgNC4xLTYuNiAxMiAxMiAwIDAgMSA0LjMtNi4zYy0yLjguMS0z'
    b'LjguOS01LjQgMS44bC42LTMgLjctMi43LTMuNSA0Yy0uNS44LTEuMSAxLjQtMS43IDIuMS0x'
    b'LjEgMS44LS45IDEuOC0xLjMgMi40LTQtMi4yLTUuOCAzLjEtOC40IDYuNC01LTIuOC05LjMt'
    b'My42LTE1LjItNC43bC0zLjUtLjRhODguNyA4OC43IDAgMCAwLTIyLjcuMmMtMy44LjUtNi4x'
    b'IDEuMi05LjUgMnoiLz4KICA8ZyBmaWxsPSIjY2UxMTI2Ij4KICAgIDxwYXRoIGQ9Ik0yOTMg'
    b'Mjg1LjVjLjUtMS4zIDEtMS42IDIuMi0yLjEgMy42LTEuNyA1LjQtMi40IDkuNS0zLjVhNTMu'
    b'MSA1My4xIDAgMCAxIDcuMi0xLjMgNjcuNCA2Ny40IDAgMCAxIDEyLjMtLjQgNTQuNSA1NC41'
    b'IDAgMCAxIDIwLjYgNS4xYzEuNS43IDEuMy44IDIuMiAyLjIgMS0uOCAxLjktMi40IDIuNS0z'
    b'LjRsMS0yYy40LTEuMS0uMy0xLjUtLjgtMS45LTEuOC0xLjYtNS4zLTMtOC4zLTMuOGE4Ni41'
    b'IDg2LjUgMCAwIDAtNDIuNyAwIDI0LjggMjQuOCAwIDAgMC05IDQuNGMtLjguOS40IDIuNS44'
    b'IDMuMmwxIDIgMS41IDEuNXoiLz4KICAgIDxwYXRoIGQ9Ik0yODAuNSAyNzQuMmMxLjQuMyAy'
    b'IC43IDIuOSAyIDIgMi44IDIuMSA0LjggNS42IDguNmE2IDYgMCAwIDAgMi42IDIuMSA3LjUg'
    b'Ny41IDAgMCAwIDQuMi42IDkgOSAwIDAgMCAzLjUtMS4yczEuMy0uNyAxLjctMS4yYy4zLS40'
    b'LjQtMS41LjQtMS41LTEtLjMtMyAxLjctNC4yIDIuNS0yLjIgMS41LTMgMS00LjctLjUtMS4z'
    b'LTEuMS0xLjgtMi40LTIuNy00LS40LS42LTEtMS41LS44LTIuNWwxLjctMS43LTIuMS0zLjJj'
    b'LS44LTEuMy0xLjMtMi4yLTIuNC0zLS42LS41LTEuOS0xLjItMi44LS43bC0yIDJjLS4zLjUt'
    b'LjcgMS0uOSAxLjd6Ii8+CiAgICA8cGF0aCBkPSJtMjc4LjEgMjY4LjgtMi4xLTEuMy0yLjct'
    b'MSAxLjUgMS43YzEuNiAyIDEuNiAzLjggMyA2LjRhMTYuMyAxNi4zIDAgMCAwIDQuMiA1YzEg'
    b'LjggMS45IDEgMi40LjMuMS0uNS0xLjEtMS4zLTEuNy0xLjZhMTEgMTEgMCAwIDEtMi4xLTEu'
    b'NGMtMS42LTEuNi0uNC0zLjUuOC00LjlsLjgtMWMuMi0uNi0xLjEtMi40LTEuOC0zLjMtLjct'
    b'LjktMi41LTMtMy40LTMuOGwuNSAyLjUuNiAyLjR6bTIzLjIgMTQuMy0uNi0xLjVjLS45LjEt'
    b'NS4xIDItNi4xIDIuNi0uMy4yLTEuNSAxLjEtMSAxLjcgMS43IDEuOCA0LjItLjggNS42LTJh'
    b'My4xIDMuMSAwIDAgMSAyLS44eiIvPgogICAgPHBhdGggZD0iTTI4NSAyNzkuN2MtLjMtLjEt'
    b'LjMtLjYtMS4yLTEuMy0uNC0uMy0yLjYtMS41LTMtMS45IDAgMC0uNi0uNS0uNi0xLjIuMS0u'
    b'Ni42LS43LjYtLjcgMiAwIDQuMiA0LjggNC4xIDV6bTc0LjYtNS40Yy0xLjUuMy0yIC43LTIu'
    b'OSAyLTIgMi44LTIuMSA0LjgtNS42IDguNi0uOC45LTEuNCAxLjYtMi43IDIuMWE3LjUgNy41'
    b'IDAgMCAxLTQuMS42IDkgOSAwIDAgMS0zLjYtMS4ycy0xLjMtLjctMS42LTEuMmEzLjggMy44'
    b'IDAgMCAxLS40LTEuNWMxLS40IDMgMS43IDQuMSAyLjUgMi4zIDEuNSAzLjEgMSA0LjctLjUg'
    b'MS40LTEuMSAxLjktMi40IDIuOC00IC40LS42IDEtMS41LjgtMi41bC0xLjctMS43IDItMy4y'
    b'YzEtMS4zIDEuNC0yLjIgMi41LTMgLjYtLjUgMS45LTEuMiAyLjgtLjdsMS45IDJjLjMuNS44'
    b'IDEgMSAxLjd6Ii8+CiAgICA8cGF0aCBkPSJtMzYyIDI2OC45IDIuMS0xLjMgMi42LTEtMS40'
    b'IDEuN2MtMS43IDItMS43IDMuOC0zIDYuNGExNi41IDE2LjUgMCAwIDEtNC4yIDVjLTEgLjgt'
    b'Mi4xLjgtMi40LjMtLjEtLjUgMS0xLjMgMS43LTEuNi44LS40IDEuNS0xIDIuMS0xLjQgMS42'
    b'LTEuNi40LTMuNS0uOC00LjlsLS44LTFhOSA5IDAgMCAxIDEuOC0zLjNsMy4zLTMuOGMwIC43'
    b'LS4zIDEuNy0uNSAyLjVsLS41IDIuNHptLTIzLjIgMTQuMy42LTEuNWMuOS4xIDUuMSAyIDYu'
    b'MSAyLjYuMy4yIDEuNSAxLjEgMSAxLjctMS43IDEuOC00LjItLjgtNS43LTItLjUtLjMtMS4x'
    b'LS44LTItLjh6Ii8+CiAgICA8cGF0aCBkPSJNMzU1LjIgMjc5LjhjLjItLjEuMi0uNyAxLjEt'
    b'MS40LjQtLjMgMi42LTEuNCAzLTEuOCAwIDAgLjYtLjUuNS0xLjIgMC0uNi0uNS0uNy0uNS0u'
    b'Ny0yIDAtNC4yIDQuOC00LjEgNXoiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iI2VhYzEwMiIg'
    b'ZD0iTTI5Ny40IDI3N2gtLjZsLS45LjR2LjNjLjIgMCAuMS4zLjIuNWwuMi42LjIuOC4yLjhj'
    b'MCAuMS0uMi40IDAgLjNsLjctLjJjLjEgMCAuMy0uMiAwLS4yLS4xLS4xIDAtLjQtLjItLjZs'
    b'LS4xLS42YzAtLjIuMyAwIC4zLjFsLjUuNS42LjNhLjguOCAwIDAgMCAuNiAwYy0uMy0uMi0u'
    b'Ni0uNC0uNy0uN2wtLjUtLjZjLjItLjIuNS0uNS41LS44YTEgMSAwIDAgMC0uNC0uOSAxLjMg'
    b'MS4zIDAgMCAwLS42IDB6bS0uMi4yYy4yIDAgLjMuMi40LjMuMS4yLjIuNC4xLjdhLjYuNiAw'
    b'IDAgMS0uMy40Yy0uMS4xLS40LjMtLjUgMGwtLjItMWMwLS4yLjEtLjMuMy0uM2ExIDEgMCAw'
    b'IDEgLjIgMHptMS40LS43YzAgLjEuMy4yLjIuNGwuMi43LjIuN3YuNWwuMi42YzAgLjEtLjIu'
    b'MyAwIC4zbDEuOC0uNWMuMiAwIC4yIDAgLjItLjJ2LS42Yy0uMiAwLS4yLjMtLjMuNGwtLjku'
    b'NGMtLjEgMC0uMi0uMS0uMi0uM2wtLjEtLjQtLjItLjdoLjdjLjEgMCAuMi4yLjMgMHYtLjVj'
    b'LS4xIDAtLjEtLjQtLjMtLjMgMCAuMSAwIC4zLS4yLjRhMS41IDEuNSAwIDAgMS0uNS4xbC0u'
    b'MS0uNWMwLS4yLS4xLS41LjEtLjVhLjguOCAwIDAgMSAuOCAwYy4xIDAgLjMuMy4zIDAgMC0u'
    b'MSAwLS40LS4yLS41aC0uNWwtMS41LjV6bTQuMS0xLjFoLS43bC0uOC4zYy0uMi4xLjIuMi4y'
    b'LjR2LjVsLjIuNS4xLjguMS43di40Yy4yIDAgLjUgMCAuNy0uMi4yIDAgLjItLjEgMC0uMnYt'
    b'LjVsLS4yLS42YTIgMiAwIDAgMCAxLS41LjkuOSAwIDAgMCAuNC0uNyAxLjEgMS4xIDAgMCAw'
    b'LS4yLS43IDEgMSAwIDAgMC0uNC0uMmgtLjR6bS41IDB6bS0uOC4yYS41LjUgMCAwIDEgLjUu'
    b'NGwuMS43YzAgLjEtLjEuMy0uMy4zbC0uNC4yLS4xLS40LS4yLS44YzAtLjIgMC0uMy4yLS4z'
    b'YS44LjggMCAwIDEgLjIgMHptMy4zLS45LjMuM3YuNWwuMi42di41bC4xLjdhLjYuNiAwIDAg'
    b'MS0uNy41LjQuNCAwIDAgMS0uMy0uMiAxIDEgMCAwIDEtLjItLjVsLS4xLS43YTcuOSA3Ljkg'
    b'MCAwIDAtLjEtLjdsLS4xLS41YzAtLjEuMi0uMyAwLS4zbC0uOC4xYy0uMi4yLjEuMi4xLjRs'
    b'LjEuNS4yIDF2LjVjMCAuMi4yLjMuMy41LjEuMS4zLjMuNS4zLjQgMCAuOCAwIDEuMS0uM2wu'
    b'My0uNS0uMS0uOC0uMS0uOC0uMS0uNmEuNS41IDAgMCAxIDAtLjNjMC0uMS4yLS4zIDAtLjNo'
    b'LS40YS4yLjIgMCAwIDAtLjIuMXptMi42LS41LTEgLjItLjUuMS4yLjRjMCAuNCAwIC44LjIg'
    b'MS4xdi43bC4xLjhjMCAuMS0uMi4zIDAgLjNsLjUtLjFhNC4yIDQuMiAwIDAgMSAuNiAwIDMu'
    b'OCAzLjggMCAwIDAgLjctLjNsLjMtLjNhLjYuNiAwIDAgMCAuMi0uNGMwLS4yIDAtLjUtLjMt'
    b'LjdsLS40LS4yYy0uMSAwLS4zLS4xIDAtLjJhLjguOCAwIDAgMCAuMy0uNS42LjYgMCAwIDAt'
    b'LjEtLjVjMC0uMi0uMy0uMy0uNS0uM2EyIDIgMCAwIDAtLjMgMHptLS41LjNjLjMgMCAuNSAw'
    b'IC43LjJ2LjZjMCAuMi0uMi4zLS40LjQtLjEgMC0uNC4xLS40LS4xdi0uNWE0IDQgMCAwIDEg'
    b'MC0uNXptLjMgMS41LjUuMWMuMi4xLjIuNC4yLjZsLS4xLjUtLjYuMmMtLjItLjEtLjItLjQt'
    b'LjItLjV2LS45YS41LjUgMCAwIDEgLjIgMHptMS43LTJzLjIgMCAuMS4ybC4xLjZ2LjVsLjEu'
    b'N3YxLjJjLS4xLjEuMSAwIC4yIDBoMS4ybC42LS4xdi0uOWMwIC4yLS4yLjMtLjMuNGEuNy43'
    b'IDAgMCAxLS4zLjJoLS4zbC0uNC0uMXYtLjdsLS4xLTEuMnYtLjdjMC0uMS4yLS4zIDAtLjNo'
    b'LS40bC0uNC4xYS44LjggMCAwIDAtLjEgMHptMi41LS4zLjEuMi4xLjR2LjRsLjIgMS42di40'
    b'cy0uMi4yLS4xLjNhNCA0IDAgMCAwIDEtLjFsLS4xLS4yLS4xLS40LS4xLS43di0uNmwtLjEt'
    b'Ljh2LS41cy4yLS4yIDAtLjJhNS41IDUuNSAwIDAgMC0uOS4xem00IDJjLS4yIDAtLjMuMi0u'
    b'NC4zIDAgLjItLjMuMi0uNC4zLS4zIDAtLjQtLjEtLjYtLjNhMS42IDEuNiAwIDAgMS0uMy0u'
    b'NXYtLjVhMy40IDMuNCAwIDAgMSAwLS45YzAtLjIgMC0uNC4yLS41LjItLjEuNSAwIC43LjFs'
    b'LjIuNWMuMi4yLjItLjEuMi0uMmwuMS0uNGExIDEgMCAwIDAtLjUtLjIgMS4yIDEuMiAwIDAg'
    b'MC0xLjEuMiAxIDEgMCAwIDAtLjMuMyAxIDEgMCAwIDAtLjEuNGwtLjIuNi4zIDEuMmMwIC4y'
    b'LjIuMy40LjVsLjUuMmExIDEgMCAwIDAgLjctLjJjLjIgMCAuMy0uMy40LS40YTEgMSAwIDAg'
    b'MCAuMi0uNHptMS4zLTIuNWgtLjRsLS4xLjgtLjIuNS0uMiAxLjMtLjMuN3YuMWguN2wtLjIt'
    b'LjN2LS41YzAtLjIuMyAwIC40IDBsLjUtLjEuMi42cy0uMi4zIDAgLjNoLjdjLjItLjEgMC0u'
    b'MyAwLS40bC0uMy0uOC0uMy0xLS4zLTEtLjEtLjJ6bS0uMy44LjQgMS4zLS4yLjFoLS40Yy0u'
    b'MS0uMSAwLS4zIDAtLjRsLjEtLjYuMS0uNHptNC4zLTEtMSAuMS4yLjN2Mi45YzAgLjEtLjQu'
    b'My0uMS4zaDEuNGExIDEgMCAwIDAgLjQtLjNsLjQtLjUuMS0uN2EyLjcgMi43IDAgMCAwIDAt'
    b'LjdsLS4yLS42LS4zLS40YTEuNyAxLjcgMCAwIDAtLjQtLjJsLS41LS4xem0wIC4zYy4zIDAg'
    b'LjUuMS42LjNhMSAxIDAgMCAxIC4xLjV2MS40YTEuNCAxLjQgMCAwIDEtLjIuNmwtLjMuMi0u'
    b'NS0uMXYtMi42YzAtLjIuMi0uMy40LS4zem0zLS4xYS44LjggMCAwIDAtLjUuMWwtLjUuNi0u'
    b'Mi44di44bC4yLjVhMS4xIDEuMSAwIDAgMCAxIC44Yy4zIDAgLjYtLjIuOC0uNGwuNC0uN3Yt'
    b'MS4yYTIgMiAwIDAgMC0uMi0uNmwtLjQtLjZhLjkuOSAwIDAgMC0uNS0uMXptMCAuMmMuMyAw'
    b'IC41LjMuNS41bC4xLjZ2LjlsLS4xLjZhMSAxIDAgMCAxLS4zLjVjLS4xLjEtLjMuMi0uNCAw'
    b'LS4yIDAtLjItLjMtLjMtLjR2LTEuOWMwLS4yIDAtLjQuMi0uNmEuNC40IDAgMCAxIC40LS4y'
    b'em0xLjQgMy41aC42Yy4xLS4xLS4yLS4yLS4xLS40YTIgMiAwIDAgMSAwLS42bC4xLS42LjEt'
    b'LjYuMS0uNS4xLjV2LjdsLjIuNnYuNmMuMS4yIDAgLjUuMy40LjIgMCAuMS0uMi4yLS4zbC4y'
    b'LTEgLjItLjUuMy0uOXYyLjVjMCAuMS0uMy4zIDAgLjNoLjZjLjIuMS4xIDAgMC0uMXYtMy4x'
    b'cy4yLS4yIDAtLjJoLS43bC0uMi41YTkgOSAwIDAgMS0uMi43bC0uMS43cy0uMS4yLS4xIDB2'
    b'LS42YzAtLjEtLjItLjMtLjEtLjRsLS4yLTFjMC0uMi0uMiAwLS40LS4yaC0uNHYxLjJsLS4y'
    b'IDEuMy0uMS41YzAgLjItLjEuMy0uMy40em0zLjMuMy42LjFoLjNsLS4yLS40di0uNmwuMi0u'
    b'NWEyMiAyMiAwIDAgMSAwLTEuMSAxLjMgMS4zIDAgMCAxIDAtLjVsLjItLjJjLjEtLjItLjEt'
    b'LjEtLjItLjFsLS43LS4xcy4yLjIuMS4zdjEuN2wtLjEuNWEyLjUgMi41IDAgMCAxIDAgLjVs'
    b'LS4yLjR6bTEuMS4zaC41Yy4xIDAgLjMuMS4yIDBhLjguOCAwIDAgMS0uMS0uNXYtLjlhMiAy'
    b'IDAgMCAxIC4xLS42di0uNmMuMi4xLjIuMy4zLjVsLjggMmMwIC4yIDAgLjQuMi40cy4yLS4x'
    b'LjItLjN2LS41bC4xLS41di0uNmwuMi0uNnYtLjZzLjQtLjIuMi0uM2gtLjZsLjIuNC0uMSAx'
    b'LjEtLjEuNi0uMi0uNS0uMy0uNi0uMi0uNi0uMy0uN2EzLjUgMy41IDAgMCAxLS42LS4xYy0u'
    b'MiAwIDAgLjIgMCAuNC4xLjMgMCAuNiAwIC44YTQuMiA0LjIgMCAwIDEgMCAuNmwtLjEuNi0u'
    b'MS42YzAgLjItLjIuMy0uMy40em0zLTNjLjEuMi4zLjMuMi40di41YTMuMSAzLjEgMCAwIDEt'
    b'LjEuNWwtLjEuN3YuNWwtLjEuM3YuM2wtLjIuMmMtLjEuMS4yIDAgLjMuMWwuNS4xcy4xIDAg'
    b'MC0uMXYtMWwuMS0uNXYtLjRjLjEtLjIgMC0uNC4yLS42di0uNGMwLS4xIDAtLjMuMi0uNGEx'
    b'LjIgMS4yIDAgMCAwLS40IDBsLS40LS4yYS4yLjIgMCAwIDAtLjEgMHptMS4xIDIuNGEyIDIg'
    b'MCAwIDAgLjQgMS4zYzAgLjIuMy4yLjQuM2guNmMuMSAwIC4zIDAgLjQtLjJsLjMtLjVjMC0u'
    b'Mi0uMi4xLS4zLjItLjIuMS0uNS4yLS43IDBhLjguOCAwIDAgMS0uMy0uNHYtLjVhNyA3IDAg'
    b'MCAxIDAtLjd2LS41bC4zLS41YS41LjUgMCAwIDEgLjMtLjJjLjIgMCAuMy4yLjQuM2EuOC44'
    b'IDAgMCAxIC4xLjVjMCAuMS4xLjMuMi4xbC4yLS41YzAtLjItLjItLjMtLjMtLjRsLS4zLS4y'
    b'aC0uOGExLjIgMS4yIDAgMCAwLS4zLjRjLS4yLjEtLjMuNC0uNC42YTIuNiAyLjYgMCAwIDAt'
    b'LjEuN3YuMnptMy41LTEuMy0uNiAxLjRjMCAuMSAwIC4zLS4yLjVsLS4zLjctLjMuNGMtLjEg'
    b'MC0uMS4yIDAgLjJsLjUuMWMuMiAwIDAtLjIgMC0uM3YtLjRjLjItLjIuNCAwIC41IDBoLjR2'
    b'LjhjLS4xIDAgMCAuMiAwIC4ybC41LjJjLjEgMCAuMyAwIC4yLS4xLS4xLS4zIDAtLjUgMC0u'
    b'OGwtLjEtLjZ2LTIuMWwtLjUtLjJ6bTAgLjh2MS41bC0uNi0uMWMtLjEtLjIuMS0uMy4xLS41'
    b'bC40LS43di0uMnptMS41IDMuM3YtMS40bC4yLS41di0uNmMuMi0uMi4yIDAgLjIuMWwuMyAx'
    b'IC4yLjYuMi45YzAgLjEuMS40LjMuM2wuMi0uNi4xLS42LjItMSAuMi0uOHMuNC0uMi4xLS4z'
    b'Yy0uMSAwLS4zLS4yLS41LS4xbC4xLjR2LjZhNC42IDQuNiAwIDAgMC0uMi41bC0uMS42Yy0u'
    b'Mi0uMS0uMS0uMy0uMi0uNWwtLjItLjdhNiA2IDAgMCAxLS4yLS43IDIuMSAyLjEgMCAwIDEt'
    b'LjEtLjVjLS4xLS4yLS40LS4yLS41LS4zLS4yIDAtLjMgMC0uMi4ydjFsLS4zIDEtLjEuNi0u'
    b'My40Yy0uMi4yLjIuMi4zLjNhLjcuNyAwIDAgMCAuMyAwem0zLjQtMi4zLS4zLjctLjQuNy0u'
    b'OCAxLjNzLS4yLjIgMCAuMmwuNS4ydi0uOGwuNS4xYy4xLjEuNCAwIC40LjNsLS4xLjZjLS4x'
    b'IDAtLjIuMSAwIC4ybC4zLjFjLjIgMCAuMy4yLjQuMXYtMy42bC0uNS0uMXptMCAuN3YxLjZs'
    b'LS41LS4ycy0uMyAwLS4yLS4ybC4zLS43LjMtLjV6Ii8+CiAgPGcgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoLjg5MjczIDAgMCAuODkyNzQgLTEyNS41IC0zMy4zKSI+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJNNDc0LjUgMjgxdjQwLjZjMCAzLjYgMCA1LjkgMS44IDguMWExMSAxMSAwIDAg'
    b'MCA2IDQuMmMxLjcuMyA3LjcuMiA5LjguMiA0LjYtLjMgNS4yLjggNyAzIDItMy4xIDQuMS0z'
    b'LjIgOC4yLTMgMiAwIDYuNi4xIDguNC0uM2E5LjQgOS40IDAgMCAwIDUuNC0zLjNjMi40LTIu'
    b'NyAyLjItNiAyLjItOS42di0zOC4zYzAtMS44LS4yLTEuMy43LTIuMmw1LjgtNkg0NjhsNi40'
    b'IDYuN3oiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDJkNjIiIGQ9Ik00OTMuOCAyOTl2LTI0Ljdo'
    b'LTI1LjVsNi4zIDYuN3YxOHoiLz4KICAgIDxwYXRoIGZpbGw9IiNjZTExMjYiIGQ9Ik01MDQg'
    b'Mjk5di0yNC43aDI2bC02LjcgNy4xdjE3Ljd6bS0xMC4yIDEwLjNoLTE5LjNsLS4xIDE1LjZj'
    b'LjkgNi44IDYgOS4yIDEwLjQgOS4xaDl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDAyZDYyIiBk'
    b'PSJNNTA0IDMwOS4zaDE5LjRWMzI1Yy0uNSA2LjgtNiA5LjItMTAuNSA5LjFoLTl6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjUiIGQ9'
    b'Ik00NzQuNiAyODF2NDAuNmMwIDMuNiAwIDUuOCAxLjggOC4zYTkuMiA5LjIgMCAwIDAgNiA0'
    b'YzEuNy4zIDcuNy4yIDkuOC4yIDIuNyAwIDMuOS0uMiA1LjcgMS42LjYuNi43LjggMS4xIDEu'
    b'NWE4LjEgOC4xIDAgMCAxIDMtMi44YzEuNC0uNSAzLjgtLjMgNS40LS4zIDIuMSAwIDYuNi4x'
    b'IDguNC0uM2ExMC42IDEwLjYgMCAwIDAgNS40LTMuM2MyLjQtMi43IDIuMi02IDIuMi05LjZ2'
    b'LTM4LjNjMC0xLjgtLjItMS4zLjctMi4ybDUuOC02aC02MS43bDYuNCA2Ljd6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZWFjMTAyIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9'
    b'Ik00OTggMjgwLjR2Mi44aC0zdjIuM2gyLjh2MTBoMi4zdi0xMGgyLjl2LTIuM2gtMi45di0y'
    b'Ljh6Ii8+CiAgICA8ZyBpZD0iZG8tYiI+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00'
    b'ODEuOSAyODR2NC42bC0xLjktMiAuMyAzMmMwIDQuNyAzLjQgOC42IDcuNiA4LjYgNC4yIDAg'
    b'Ny42LTMuOCA3LjctOC41bC0uMy0xNi40LTItMi4yLS4xLTEuN3oiLz4KICAgICAgPHBhdGgg'
    b'ZmlsbD0iIzAwMmQ2MiIgZD0iTTQ4MS45IDI4NC4ydjQuNmwtMS45LTIgLjIgMTguMiA4LjIg'
    b'Ny45di0xNy40bC0uMi0uNHYtM3oiLz4KICAgICAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0i'
    b'bTQ5MC44IDI5NS41IDIuNCAzdjEuMWwtMi40LTIuNXptNC41IDcgLjIgMTEuNGMtMS4yIDIu'
    b'Mi0zLjYgMS0zLjYgMWwuMS0xNS44eiIvPgogICAgICA8cGF0aCBmaWxsPSIjMDAyZDYyIiBk'
    b'PSJNNDk1LjYgMzE5LjZjLTMuMiAyLjQtNC0xLTQtMWE0LjQgNC40IDAgMCAwIDQtM3oiLz4K'
    b'ICAgICAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0iTTQ4MC4yIDMwOS43YTU0IDU0IDAgMCAw'
    b'IDggNy41YzEgNy43IDUuNSA1LjEgNy4xIDQtMSAzLjYtMy45IDYuMi03LjQgNi4yLTQuMiAw'
    b'LTcuNi0zLjktNy42LTguNnoiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNNDkzLjIgMjk5LjZ2LTEuMUw0ODEuOSAyODR2'
    b'NHpNNDgwIDI4Ni43bC4zIDMxLjljMCA0LjcgMy40IDguNiA3LjcgOC42IDQuMSAwIDcuNS0z'
    b'LjggNy42LTguNWwtLjMtMTYuNHoiLz4KICAgICAgPGcgZmlsbD0iI2VhYzEwMiIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4xIj4KICAgICAgICA8cGF0aCBkPSJNNDg2LjIgMjgx'
    b'LjJjLS44LTEuNC0uNi0yLS4xLTIuNmwtMy0zIC45IDQuMmMuOC0uMiAxLjQgMCAyLjIgMS40'
    b'em0tMy01LjYgMyA1LjYiLz4KICAgICAgICA8cGF0aCBkPSJtNDk4IDMwMC43LS43LjMtMTIt'
    b'MjAuNC44LS40eiIvPgogICAgICAgIDxwYXRoIGQ9Ik00ODUgMjgwLjZjLS4xLS4yIDAtLjUu'
    b'NS0uNy4zLS4yLjctLjIuOCAwIDAgLjItLjEuNS0uNS43LS4zLjItLjcuMi0uOCAwem0tNCAx'
    b'LjZjLTEtMS4zLS45LTItLjQtMi42bC0zLjMtMi42IDEuNCA0Yy44LS4zIDEuNC0uMSAyLjMg'
    b'MS4yem0tMy43LTUuMiAzLjcgNS4yIi8+CiAgICAgICAgPHBhdGggZD0ibTQ5NS4zIDMwMC0u'
    b'Ny40LTE0LjQtMTguNy42LS41eiIvPgogICAgICAgIDxwYXRoIGQ9Ik00NzkuOCAyODEuOGMt'
    b'LjItLjIgMC0uNi4zLS44LjQtLjMuNy0uMy45LS4xIDAgLjEgMCAuNS0uNC43cy0uNy4zLS44'
    b'LjF6bS40IDQuNmMtMS4xLTEuMy0xLjEtMi0uNy0yLjZsLTMuNi0yLjIgMS44IDMuOWMuOC0u'
    b'NCAxLjQtLjQgMi41Ljl6bS00LjMtNC44IDQuMyA0LjciLz4KICAgICAgICA8cGF0aCBkPSJt'
    b'NDk1LjcgMzAyLjktMTYuNC0xNyAuNi0uNSAxNi40IDE3eiIvPgogICAgICAgIDxwYXRoIGQ9'
    b'Ik00NzguOSAyODZjLS4yLS4xIDAtLjUuMy0uOC4zLS4zLjYtLjQuOC0uMi4xLjIgMCAuNS0u'
    b'My44LS4zLjMtLjcuNC0uOC4yeiIvPgogICAgICA8L2c+CiAgICA8L2c+CiAgICA8dXNlIHhs'
    b'aW5rOmhyZWY9IiNkby1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09'
    b'Im1hdHJpeCgtMSAwIDAgMSA5OTguMyAwKSIvPgogICAgPGcgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9Ii4yIj4KICAgICAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0ibTQ5Ni43IDMx'
    b'NC41LS42IDEwLjFjLS42IDAtMS45LS4xLTItMSAwLS40IDEuMy04LjcgMS4zLTkuNWwxLjMu'
    b'NHoiLz4KICAgICAgPHBhdGggZmlsbD0iIzAwMmQ2MiIgZD0ibTQ5NS44IDMxNC4xLS4zIDMu'
    b'MWMuMiAxIDEuNC44IDIgLjlsLjItNS4yYTE2LjUgMTYuNSAwIDAgMS0yIDEuMnoiLz4KICAg'
    b'ICAgPHBhdGggZmlsbD0iIzAwMmQ2MiIgZD0iTTQ5NS45IDMyN2MxLjYtMiA0LjgtLjUgNC44'
    b'LS41IDMuNC44IDIuNS0zLjEgMi41LTMuMS0uNy03LjgtMS41LTEzLjItMS41LTEzLjJsLTUg'
    b'My40eiIvPgogICAgICA8cGF0aCBmaWxsPSIjMDAyZDYyIiBkPSJNNDk1LjkgMzI3LjJjLS40'
    b'IDIuMyAyIDIgMiAyIDIuNyAwIDEuOS0zIDEuOS0zLTMtLjktNCAxLTQgMXoiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iI2NlMTEyNiIgZD0ibTQ5Ny44IDMxMi43LS4yIDljLjEgMi4xIDIuNSAx'
    b'IDIuNSAxIC42LS4zIDEuMi0uMSAxLjItLjF2LTIuOGM0LS4zIDMtMi42IDMtMi42LTEuNi03'
    b'LjYtMS44LTcuMy0xLjgtNy4zeiIvPgogICAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJNNTAx'
    b'LjMgMzE5LjhjLTIuNSAwLTMuNiAxLTMuNiAxdi4yIi8+CiAgICAgIDxwYXRoIGZpbGw9IiNm'
    b'ZmYiIGQ9Im01MDEgMzI2LjQtLjktMTUuMSAxLjgtMS4yIDEuNSAxNC4ydi4xYzAgMi43LTIu'
    b'NCAyLTIuNCAyeiIvPgogICAgPC9nPgogICAgPGcgZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAw'
    b'Ij4KICAgICAgPHBhdGggZmlsbD0iIzAwMCIgc3Ryb2tlPSJub25lIiBkPSJtNDg4LjIgMzAy'
    b'LjIgNi44IDEyLjQgMTQuNy05LjctNy43LTExLjJ6Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS13'
    b'aWR0aD0iLjMiIGQ9Im00ODguNSAzMDIuMSAxMy43LTggNy42IDEwLjgtMTQuNiA5LjR6Ii8+'
    b'CiAgICAgIDxwYXRoIGZpbGw9IiMwMDAiIHN0cm9rZT0ibm9uZSIgZD0ibTQ5NS40IDMxMy41'
    b'IDEzLjctOC44LTEtMS43LTYuOS05LjMtNSA0LTYuMyAzLjUtMS4xLS43LjIgMS41eiIvPgog'
    b'ICAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii4xIiBkPSJNNDk2LjIgMjk3LjhjLTItMS00LjQg'
    b'Mi01IDIuNi0uOC42LTIuMS4zLTIuMS4zbDYuMiAxMWMxLjguOCAzLTEuNSAzLjgtMi4zIDEu'
    b'Ni0xLjMgMy40LTEuMiAzLjQtMS4yeiIvPgogICAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii4x'
    b'IiBkPSJNNDk2LjQgMjk3LjljMC0yLjQgMy0zLjEgMy43LTMuNi44LS40IDEtMS45IDEtMS45'
    b'bDcgMTAuNmMtLjIgMi0yLjYgMi4zLTMuNiAyLjgtMS44IDEtMiAyLjUtMiAyLjV6bS0xLjQg'
    b'MTMuOWE1OTUuNiA1OTUuNiAwIDAgMC02LjEtMTF2MS4yYzQuNiA3LjUgNi41IDExLjUgNi41'
    b'IDExLjVsLS40LTEuN3oiLz4KICAgICAgPHBhdGggZmlsbD0iIzAwMCIgc3Ryb2tlPSJub25l'
    b'IiBkPSJNNDkwLjkgMzAyLjJ2LjJsLjEtLjEuMi4xaC0uMmwuMS4yLjItLjItLjMuMy0uMi0u'
    b'NGgtLjFsLjQtLjN2LjJoLS4yem0uNC0uMy4yLjR2LjJjLS4xIDAgMCAwIDAtLjFsLS4xLS4x'
    b'LS4yLS4zem0uNS0uM3YuMWgtLjJ2LjFoLjR2LjNhLjIuMiAwIDAgMS0uMiAwdi4xbC0uMS0u'
    b'MWguMmMuMSAwIC4xLS4xIDAtLjFoLS4xbC0uMi0uMXYtLjJhLjIuMiAwIDAgMSAuMSAwdi0u'
    b'MXptLjUuMnYuMWgtLjJ2LS4xbC4xLS4xdi0uMWgtLjF2LjFjLS4xIDAgMCAwIDAgMGEuMi4y'
    b'IDAgMCAxIDAtLjJsLjIuMXYuMmguMS0uMXptMCAwdi0uMWwtLjEuMXptLjEtLjQuMS0uMWgu'
    b'MWwuMi4yLS4xLjJ2LS4xbC0uMS0uMXYtLjFoLS4xdi4yaC4xbC0uMS4ydi0uMmwtLjEtLjFo'
    b'LS4xbC4xLS4xem0uMy0uNC4xLjFoLjF2LjNoLjEtLjFsLS4yLS4yYS41LjUgMCAwIDAgMC0u'
    b'MnptLjMgMGEuMi4yIDAgMCAxIC4yIDAgLjIuMiAwIDAgMSAuMS4xLjIuMiAwIDAgMSAwIC4y'
    b'LjEuMSAwIDAgMS0uMiAwIC4yLjIgMCAwIDEtLjEtLjN6bTAgMHYuMWwuMi4ydi0uM2gtLjF6'
    b'bS0xLjYgMiAuMS4ydi0uMWwuMi4yaC0uMmwuMS4xaC4xbC4xLS4xdi0uMS4ybC0uMy4ydi0u'
    b'MWwtLjItLjMuMy0uM3YuMWgtLjF6bS43LjItLjMtLjIuMS0uMXYuMWguMmMwLS4xIDAtLjIt'
    b'LjEtLjF2LS4xLjJsLjEuMnptLjMtLjN2LjJoLS4ydi0uMmwuMS0uMWMwLS4xLS4xIDAtLjEg'
    b'MGEuMi4yIDAgMCAxIC4xLS4ybC4xLjEuMS4yem0wIDB6bS4yLS40Yy4xLS4xLjIgMCAuMiAw'
    b'bC4xLjF2LjJjLS4xIDAgMCAwIDAgMGwtLjItLjJ2LS4xLjRsLS4xLS4yLS4xLS4xdi0uMXpt'
    b'LjQtLjNoLjF2LjNoLjJ2LjJhLjQuNCAwIDAgMS0uMiAwbC0uMS0uMXYtLjFhLjEuMSAwIDAg'
    b'MS0uMSAwdi0uMmEuMi4yIDAgMCAxIC4xIDB6bTAgMHYuMmMuMSAwIC4xIDAgMCAwYS4zLjMg'
    b'MCAwIDAgMC0uMXptLjIuNHMtLjEgMCAwIC4xbC4xLS4xaC0uMXptLjMtLjVoLS4ybC4xLjIu'
    b'MS0uMWEuMi4yIDAgMCAxIDAgLjFoLS4yYS4zLjMgMCAwIDEgMC0uMWMtLjEgMCAwLS4yIDAt'
    b'LjJhLjEuMSAwIDAgMSAuMSAwIC4zLjMgMCAwIDEgLjEgMHptLS4xIDBoLS4xLjF6bTAtLjQu'
    b'My40aC4xbC0uMi4xdi0uMWwtLjItLjN2LS4xem0uMi0uMWguMXYuMWwtLjEtLjF6bS4yLjEu'
    b'MS4zdi4xYy0uMSAwIDAgMCAwIDBsLS4xLS4xLS4xLS4yem0uMi0uMWEuMi4yIDAgMCAxIC4x'
    b'IDBsLjEuMmEuMi4yIDAgMCAxIDAgLjEuMS4xIDAgMCAxLS4yIDAgLjIuMiAwIDAgMSAwLS4z'
    b'em0wIDB2LjNoLjJ2LS4yaC0uMmMwLS4xIDAtLjEgMCAwem0tMiAyLjIuMS4yYzAtLjEtLjIt'
    b'LjEtLjIgMGguMmwuMi4xdi4yYS4yLjIgMCAwIDEtLjIuMWwtLjItLjFoLjN2LS4xaC0uNGEu'
    b'Mi4yIDAgMCAxIDAtLjMuMi4yIDAgMCAxIC4yIDB6bS42IDAtLjIuMmguMmEuMi4yIDAgMCAx'
    b'IDAgLjFoLS4yYS4yLjIgMCAwIDEtLjEgMHYtLjNhLjEuMSAwIDAgMSAuMiAwem0tLjEuMWgt'
    b'LjF6bS4yLS4zaC4xdi4xYS4yLjIgMCAwIDEgMCAuMXYuMWguMnYuMWEuNC40IDAgMCAxLS4y'
    b'LjFsLS4xLS4xYS4yLjIgMCAwIDEgMC0uMS4xLjEgMCAwIDEtLjEgMHYtLjNhLjIuMiAwIDAg'
    b'MSAuMSAwem0wIDB2LjJzLjEgMCAwIDBhLjMuMyAwIDAgMCAwLS4yem0uMi40cy0uMSAwIDAg'
    b'MGMwIDAgLjEgMCAwIDB6bS4yLS43LjIuMy0uMi4yLS4yLS4zLjIuMmguMXYtLjFsLS4xLS4y'
    b'em0uMy0uMXYtLjFoLjJsLjEuMi0uMS4ydi0uMmwtLjEtLjFzLS4xIDAgMCAwdi40Yy0uMSAw'
    b'IDAgMCAwIDBsLS4yLS4ydi0uMnptLjYtLjZ2LjFoLS4ydi4xaC40di4zYS4yLjIgMCAwIDEt'
    b'LjIgMHYuMWwtLjEtLjFoLjJ2LS4xaC0uM2EuMi4yIDAgMCAxIDAtLjMuMi4yIDAgMCAxIC4x'
    b'IDB2LS4xem0uNS4yLS4xLjFoLS4xYS4yLjIgMCAwIDEgMC0uMnYtLjEuMWMtLjEgMCAwIDAg'
    b'MCAwYS4yLjIgMCAwIDEgMC0uMi4xLjEgMCAwIDEgLjIgMHYuMmguMXYuMWgtLjF6bTAgMC0u'
    b'MS0uMXYuMXptLjEtLjQuMS0uMWguMWwuMi4yLS4xLjItLjEtLjJ2LS4xaC0uMXYuMmguMWwt'
    b'LjEuMnYtLjJsLS4yLS4xLjEtLjF6bS40LS41LjMtLjEuMS4zdi4yYS4yLjIgMCAwIDEtLjEu'
    b'MWgtLjF2LS4xaC4xdi0uMmwtLjItLjJ6bS43LS4yLjEuM2guMS0uMWwtLjEuMmEuMS4xIDAg'
    b'MCAxLS4xIDBsLS4yLS4zaC4xbC4xLjJoLjF2LS40aC0uMXptLjQuMXYuMWgtLjJ2LS4zLjFj'
    b'LS4xIDAgMCAwIDAtLjFoLjJ2LjFoLjF2LjFoLS4xem0wIDB2LS4xbC0uMS4xem0uMS0uNC4x'
    b'LS4xaC4xbC4yLjItLjEuMS0uMS0uMXYtLjFoLS4xdi4yaC4xbC0uMS4ydi0uM2gtLjJsLjEt'
    b'LjF6bS0yLjcgNC43LjEuMWEuMi4yIDAgMCAwLS4yIDAgLjIuMiAwIDAgMC0uMS4ybC4xLjJo'
    b'LjN2LS4yLjFhLjIuMiAwIDAgMSAwIC4yLjIuMiAwIDAgMS0uMyAwIC4zLjMgMCAwIDEtLjEt'
    b'LjQuMy4zIDAgMCAxIC4yLS4xdi0uMXptLjYgMC0uMi4ydi4xYy4xIDAgMCAwIDAgMHYuMS0u'
    b'MmwtLjEtLjQuNC4zYS4xLjEgMCAwIDAgLjEgMGwtLjIuMXYtLjF6bTAgMGgtLjN2LjJsLjIt'
    b'LjF6bS4yLS4yLjEuMmguMWwtLjIuMXYtLjFsLS4xLS4zaC0uMWwuMi0uMmguMWMuMSAwIC4x'
    b'LjEgMCAuMmEuMy4zIDAgMCAxIDAgLjF6bTAgMCAuMS0uMWEuMS4xIDAgMCAwIDAtLjJsLS4y'
    b'LjEuMS4yem0uNiAwaC0uMmwtLjEtLjRoLS4xbC4xLS4xdi4xbC4yLjNoLjF6bS4xLS44LjEu'
    b'MWgtLjJsLjIuNGguMWwtLjIuMmMuMSAwIDAtLjEgMC0uMmwtLjEtLjNoLS4xdi4ybC0uMS0u'
    b'MS4zLS4zem0uNC0uMmguMnYuM2wuMS4xYS4zLjMgMCAwIDEtLjIuMi4yLjIgMCAwIDEtLjIt'
    b'LjF2LS4yaC0uMmwuMi0uMnYuMWwuMS4yLjEuMWEuMi4yIDAgMCAwIC4yIDAgLjEuMSAwIDAg'
    b'MCAwLS4ybC0uMi0uMmMwLS4xIDAgMCAwIDB6bS43IDAgLjEuMS0uNC4yYy4xIDAgMCAwIDAg'
    b'MGwtLjEtLjRoLS4xbC4yLS4xdi4xbC4xLjNoLjFsLjEtLjF2LS4xem0uMS0uNWguM2EuMy4z'
    b'IDAgMCAxIC4xLjMuMy4zIDAgMCAxLS4zLjIuMy4zIDAgMCAxLS4yLS4xLjMuMyAwIDAgMSAw'
    b'LS4zLjMuMyAwIDAgMSAuMS0uMXptMCAwYS4xLjEgMCAwIDAgMCAuMi40LjQgMCAwIDAgMCAu'
    b'MmguMmEuMi4yIDAgMCAwIC4yLS4xLjQuNCAwIDAgMC0uMS0uMi4yLjIgMCAwIDAtLjItLjF6'
    b'bTEtLjZoLS4xdi43bC0uNC0uM2guMWwuMy4ydi0uM3MwLS4xLS4xIDBsLjEtLjJ6bS40LjMt'
    b'LjIuMnYtLjJsLS4yLS4zLjEtLjF2LjFsLjIuM2guMXptLjItLjEtLjEuMXYtLjFsLS4yLS4z'
    b'aC0uMWwuMi0uMnYuMmwuMS4zaC4xem0uMy0uMi0uMi4ydi0uMWwtLjItLjRoLS4xbC4yLS4x'
    b'di4xbC4yLjN6bS00IDQuMnYtLjJoLjJ2LjFhLjEuMSAwIDAgMSAuMi4xLjIuMiAwIDAgMSAw'
    b'IC4yLjMuMyAwIDAgMS0uMS4xYy4xLS4xLjEtLjIgMC0uMmgtLjFhLjEuMSAwIDAgMCAwLS4y'
    b'aC0uMXptLjQtLjN2LS4ybC4zLjRoLjFsLS4xLjJ2LS4ybC0uMi0uMmgtLjF6bS43LS41LjIt'
    b'LjF2LjRjMCAuMSAwIC4xLjEgMHYuMWwtLjIuMXYtLjJsLS4zLS4xLjEtLjJ2LjFsLjIuMXYt'
    b'LjJ6bS44IDB2LjFoLS4yYS4yLjIgMCAwIDEgMC0uM3YtLjJsLjMuM3YuMXptMCAwdi0uMmgt'
    b'LjJ2LjFsLjEuMWguMXptLjEtLjMuMi4xdi0uMWguMXYuMmEuMS4xIDAgMCAxLS4yIDAgLjMu'
    b'MyAwIDAgMS0uMS0uMi4yLjIgMCAwIDEgMC0uMS4xLjEgMCAwIDEgLjIgMHptMCAwaC4ybC0u'
    b'MS0uMXMtLjEgMCAwIC4xem0uNi0uMmEuMi4yIDAgMCAxIDAgLjIuMS4xIDAgMCAxLS4yIDBs'
    b'LS4xLS4xdi0uMmEuMS4xIDAgMCAxIC4yIDBoLS4xdi4xYS4yLjIgMCAwIDAgMCAuMS4xLjEg'
    b'MCAwIDAgLjIgMHYtLjF6bS0uMS0uNHptLjEuMS4yLjNjLS4xIDAgMCAwIDAgMGgtLjFsLS4x'
    b'LS4yem0uNC4xdi4xaC0uMnYtLjFhMSAxIDAgMCAxIC4xLS4xLjEuMSAwIDAgMCAwLS4xaC0u'
    b'MXYuMS0uMWguMWwuMi4yem0wIDB2LS4xbC0uMS4xYS4yLjIgMCAwIDAgLjEgMHptLjEtLjYu'
    b'Mi0uMS4xLjN2LjJzLS4xIDAgMCAwdi0uMWwtLjItLjN6bS40IDAgLjIuMi4xLS4xdi4xYS4x'
    b'LjEgMCAwIDEtLjIgMCAuMi4yIDAgMCAxIDAtLjEuMi4yIDAgMCAxIDAtLjJoLjJ6bTAgMGgu'
    b'MnMwLS4xLS4xIDB6bS40LS4zYy0uMS4xIDAgLjIgMCAuMWguMWEuMS4xIDAgMCAxIC4xLjF2'
    b'LjFoLS4yLjF2LS4xaC0uMnYtLjFhLjIuMiAwIDAgMSAwLS4xaC4xem0uNC0uMi4xLjJ2LjFj'
    b'LS4xLjEtLjIuMS0uMiAwbC0uMi0uMXYtLjFsLjIuMmguMXYtLjJoLS4xem0uMi0uMmMwIC4x'
    b'IDAgMCAwIDAtLjEuMSAwIC4yIDAgLjJoLjFhLjEuMSAwIDAgMSAuMSAwdi4yaC0uMmMwLS4x'
    b'IDAgMCAwIDBoLjJ2LS4yaC0uM3YtLjFoLjF2LS4xem0uNiAwdi4xaC0uMnYtLjFsLjEtLjFh'
    b'LjEuMSAwIDAgMCAwLS4xaC0uMXYuMS0uMWguMWMuMSAwIDAgMCAwIDBsLjIuMmgtLjF6bTAg'
    b'MHYtLjFoLS4ybC4xLjJhLjIuMiAwIDAgMCAwLS4xem0tNC41IDMuNS4yLjRoLjEtLjFsLS4y'
    b'LS4zcy0uMSAwIDAgMHYtLjJ6bS4zIDBhLjIuMiAwIDAgMSAuMiAwIC4yLjIgMCAwIDEgMCAu'
    b'MS4yLjIgMCAwIDEgMCAuMi4xLjEgMCAwIDEtLjEgMCAuMi4yIDAgMCAxLS4yLS4yLjIuMiAw'
    b'IDAgMSAuMS0uMXptMCAwYS4zLjMgMCAwIDAgLjEuM2guMXYtLjJsLS4xLS4xem0uNC0uM3Yu'
    b'MWgtLjFzMCAuMSAwIDBoLjJhLjEuMSAwIDAgMSAwIC4ydi4xaC0uMi4ydi0uMmgtLjJ2LS4y'
    b'aC4xem0uMi0uM3MuMSAwIDAgMHptLjEuMS4yLjN2LjJjLS4xIDAgMCAwIDAgMHYtLjNsLS4y'
    b'LS4xem0uNC0uMi4yLjJ2LjFsLS4yLjEtLjItLjF2LS4ybC4yLjJzLjEgMCAwIDB2LS4yem0u'
    b'NSAwLS4xLjJoLS4yYS4yLjIgMCAwIDEgMC0uM2guMXYtLjJoLS4xbC4zLjN2LjF6bTAgMGgt'
    b'LjJ2LS4xYy0uMSAwLS4xIDAgMCAuMXYuMWguMXptLS4xLS41YzAgLjEgMCAwIDAgMHptLjEu'
    b'Mi4yLjJ2LjFjLS4xIDAgMCAwIDAgMGgtLjFsLS4xLS4ydi0uMXptLjItLjJhLjIuMiAwIDAg'
    b'MSAuMiAwIC4yLjIgMCAwIDEgLjEuMi4yLjIgMCAwIDEgMCAuMS4xLjEgMCAwIDEtLjIgMCAu'
    b'Mi4yIDAgMCAxLS4xLS4yLjIuMiAwIDAgMSAwLS4xem0wIDB2LjFhLjMuMyAwIDAgMCAuMS4y'
    b'aC4ydi0uMmgtLjJ6bS40LS4ydi4xaC4ydi4yaC0uMXMwIC4xIDAgMGgtLjEuMnYtLjFoLS4z'
    b'YS4xLjEgMCAwIDEgMC0uMmguMXptLjUtLjQuMy40di4yYy0uMSAwIDAgMCAwIDB2LS4yaC0u'
    b'NGEuMi4yIDAgMCAxIDAtLjJ2LS4xaC4xem0uMS4zdi0uMWgtLjJsLjEuMmEuMS4xIDAgMCAw'
    b'IC4xIDB6bS4zLS41LjEuM3YuMWgtLjJsLS4xLS4yaC0uMS4xbC4xLjJoLjF2LS4zaC0uMXpt'
    b'LjIgMCAuMS4yLjEtLjF2LjFhLjEuMSAwIDAgMS0uMiAwIC4yLjIgMCAwIDEgMC0uMS4yLjIg'
    b'MCAwIDEgMC0uMi4xLjEgMCAwIDEgLjEgMGwtLjEuMnptMCAwaC4xbC0uMS0uMXYuMXptLjMt'
    b'LjUuMy40di4xYy0uMSAwIDAgMCAwIDBsLS4xLS4xLS4yLS4zdi0uMXptLjMuMmguMnYtLjFo'
    b'LjF2LjJhLjEuMSAwIDAgMS0uMiAwIC4yLjIgMCAwIDEtLjEtLjEuMi4yIDAgMCAxIDAtLjIu'
    b'MS4xIDAgMCAxIC4yIDB6bTAgMCAuMi0uMmgtLjFzLS4xIDAgMCAuMXptLTMuNyAzLjEuMS4z'
    b'LjEtLjJhLjEuMSAwIDAgMSAuMSAwbC4xLjJoLjFsLS4xLjJ2LS4ybC0uMS0uMWgtLjF2LjNo'
    b'LjEtLjF2LS4xbC0uMi0uM3ptLjcuMmMtLjEuMS0uMi4xLS4yIDBhMSAxIDAgMCAxIDAtLjJj'
    b'MCAuMS0uMS4xLS4xIDAgLjEgMCAuMS0uMS4yIDBsLjEuMWMuMSAwIDAgMCAwIDAgMCAuMSAw'
    b'IC4xIDAgMHptMCAwLS4xLS4ydi4yem0wLS40LjEtLjFoLjJhLjIuMiAwIDAgMSAwIC4zYy0u'
    b'MSAwLS4xLjEtLjIgMGwtLjItLjN6bTAgMCAuMi4yaC4xdi0uMmgtLjJ6bS4zLS40em0uMS4x'
    b'LjIuMy0uMS4xdi0uMWwtLjEtLjF2LS4xem0uNC4yaC0uMnYtLjFhMSAxIDAgMCAxIC4xLS4x'
    b'aC0uMWwuMS0uMS4yLjJzMCAuMSAwIDB6bTAgMHYtLjJsLS4xLjF2LjFoLjF6bS4xLS40di0u'
    b'MWguMmwuMS4ydi4xbC0uMi0uMnYuMmguMWwtLjEuMS0uMS0uMmgtLjFhLjIuMiAwIDAgMSAw'
    b'LS4xem0uOC0uM2EuMi4yIDAgMCAxIDAgLjIuMS4xIDAgMCAxLS4yIDBoLS4xdi0uM2EuMS4x'
    b'IDAgMCAxIC4yIDBoLS4xbC0uMS4xYS4yLjIgMCAwIDAgLjEuMi4xLjEgMCAwIDAgLjIgMHYt'
    b'LjJ6bTAtLjN2LjEtLjFoLjF2LjRoLjFsLS4xLjEtLjEtLjJzLS4xIDAgMCAwdi0uMnptLjIg'
    b'MCAuMi4xdi0uMWguMXYuMmEuMS4xIDAgMCAxLS4yIDAgLjIuMiAwIDAgMS0uMS0uMi4yLjIg'
    b'MCAwIDEgMC0uMS4xLjEgMCAwIDEgLjIgMHptMCAwaC4ybC0uMS0uMXMtLjEgMCAwIDBhLjEu'
    b'MSAwIDAgMCAwIC4xem0uMi0uNXYuMXptLjEuMi4yLjJ2LjJjLS4xIDAgMCAwIDAgMGwtLjEt'
    b'LjItLjEtLjF2LS4xem0uNSAwLS4xLjJoLS4yYS4yLjIgMCAwIDEgMC0uM2guMXYtLjJoLS4x'
    b'bC4zLjNzLjEgMCAwIDB2LjF6bTAgMGgtLjFsLS4xLS4xdi4yaC4yem0wLS40YS4yLjIgMCAw'
    b'IDEgLjMgMCAuMi4yIDAgMCAxIDAgLjIuMi4yIDAgMCAxIDAgLjIuMi4yIDAgMCAxLS4yIDAg'
    b'LjIuMiAwIDAgMSAwLS4zem0wIDB2LjJhLjMuMyAwIDAgMCAuMi4xaC4xdi0uMWwtLjEtLjFo'
    b'LS4xem0tMS05LjIuMi4xYS4xLjEgMCAwIDAtLjMgMHYuMWguM2EuMS4xIDAgMCAxIC4xLjJo'
    b'LS4xbC0uMS4xdi0uMWguMXYtLjFoLS4yYy0uMS0uMS0uMS0uMiAwLS4ydi0uMXptLjItLjF6'
    b'bTAgMCAuMi4zaC4xbC0uMS4xLS4xLS4ydi0uMXptLjMgMCAuMS0uMS4yLjJ2LS4zLjRsLS4y'
    b'LS4yem0uNC0uM2EuMS4xIDAgMCAxIC4yIDB2LjNhLjIuMiAwIDAgMS0uMi0uMS4xLjEgMCAw'
    b'IDEgMC0uMnptMCAwdi4yaC4ydi0uMXMtLjEtLjEtLjEgMHptLjQtLjJoLS4xdi4xaC4ydi4y'
    b'aC0uMWMuMSAwIDAtLjEgMC0uMWgtLjF2LS4yem0uMi0uMWEuMS4xIDAgMCAxIC4xIDBsLjEu'
    b'MnMtLjEuMS0uMiAwYS4yLjIgMCAwIDEtLjEgMCAuMS4xIDAgMCAxIDAtLjJ6bTAgMHYuMmgu'
    b'MnYtLjFsLS4yLS4xem0uMS0uM3YuMWguMnYuMmMuMSAwIDAgMCAwIDAgMCAuMSAwIDAgMCAw'
    b'bC0uMS0uMWMtLjEgMCAwIDAgMCAwdi0uMnptLjMgMHMuMSAwIDAgMHYuMmguMmwtLjIuMXYt'
    b'LjJoLS4xem0uMi0uMWEuMS4xIDAgMCAxIC4xIDBsLjEuMmgtLjFhLjIuMiAwIDAgMS0uMiAw'
    b'IC4xLjEgMCAwIDEgMC0uMi4xLjEgMCAwIDEgLjEgMHptMCAwdi4xbC4xLjFoLjF2LS4xbC0u'
    b'Mi0uMXptLjMtLjJ2LjFoLjFzLjEgMCAwIC4xdi4xYTQ1IDQ1IDAgMCAxLS4xIDBoLjJsLS4x'
    b'LS4xaC0uMXYtLjJ6bS0yIDIuNHYtLjFoLjFjMC0uMS4xLS4xLjEgMGwuMS4xYS4xLjEgMCAw'
    b'IDEtLjEuMXYuMWguMWwtLjEuMS0uMi0uM3ptMCAwaC4yYzAgLjEgMCAuMSAwIDB2LS4xaC0u'
    b'MXptLjMtLjJoLjJ2LjFhLjEuMSAwIDAgMS0uMSAwIC4yLjIgMCAwIDEtLjEtLjEuMS4xIDAg'
    b'MCAxIDAtLjIuMS4xIDAgMCAxIC4yIDB6bTAgMCAuMi0uMWgtLjJ6bS4zLS4zcy4xIDAgMCAw'
    b'di4yaC4ybC0uMi4xdi0uMmgtLjF6bS4yIDB2LS4yaC4yYzAtLjEuMSAwIC4xIDBsLjEuMXYu'
    b'MS0uMWwtLjEtLjFoLS4xdi4yaC4xbC0uMS4xdi0uMmgtLjJsLjEuMmE1NC44IDU0LjggMCAw'
    b'IDEgMCAuMXYtLjFsLS4yLS4xdi0uMWguMXptLjYtLjJjLS4xLjEtLjIgMC0uMSAwdi0uMWMw'
    b'LS4xIDAtLjEgMCAwaC0uMXYtLjFoLjFsLjIuMXYuMXptMCAwdi0uMWEuMy4zIDAgMCAwLS4x'
    b'IDB2LjFhLjIuMiAwIDAgMCAuMSAwem0uMS0uM3YtLjFoLjJ2LjJoLjEtLjF2LS4xaC0uMmwu'
    b'MS4yLS4xLS4yaC0uMXptLjMtLjFoLjJhLjEuMSAwIDAgMS0uMiAwIC4xLjEgMCAwIDEgMC0u'
    b'Mi4xLjEgMCAwIDEgLjEgMHptMCAwIC4xLS4xaC0uMXptLjUtLjJ2LjFhLjEuMSAwIDAgMS0u'
    b'MiAwaC0uMWEuMS4xIDAgMCAxIDAtLjJoLjItLjJhLjIuMiAwIDAgMCAwIC4yaC4ydi0uMXpt'
    b'MC0uMi4xLjFoLjF2LS4xLjJhLjEuMSAwIDAgMS0uMiAwIC4yLjIgMCAwIDEgMC0uMi4xLjEg'
    b'MCAwIDEgMC0uMS4xLjEgMCAwIDEgLjEgMHptMCAwaC4xYzAtLjEgMC0uMS0uMSAwem0uMi0u'
    b'Mi4xLS4xdi40aC4xYy0uMSAwIDAgMCAwIDBsLS4yLS4yem0uMyAwaC4yYS4xLjEgMCAwIDEt'
    b'LjIgMCAuMi4yIDAgMCAxLS4xIDAgLjEuMSAwIDAgMSAwLS4yLjEuMSAwIDAgMSAuMiAwem0w'
    b'IDB2LS4xem0wLS41Yy4xIDAgLjIgMCAuMS4xem0uMi4yLjEuMmguMS0uMWwtLjEtLjF2LS4x'
    b'em0uMi0uMmMwIC4xIDAgMCAwIDB2LjFoLjFzLjEuMSAwIC4yaC0uMS4yczAtLjEtLjEgMGgt'
    b'LjF2LS40em0tMi43IDNoLjJ2LS4xLjFhLjEuMSAwIDAgMS0uMSAwIC4yLjIgMCAwIDEtLjEg'
    b'MCAuMS4xIDAgMCAxIDAtLjIuMS4xIDAgMCAxIC4xIDB6bTAtLjFoLjFjMC0uMSAwLS4xLS4x'
    b'IDB6bS4zLS4ydi0uMWguMWwuMS4xdi4xbC0uMS0uMmgtLjF2LjJoLjF2LjFsLS4yLS4yem0u'
    b'NC0uM3YtLjFoLjJ2LS4xaC4xbC4xLjItLjEtLjJoLS4xdi40aC4xYTUxLjEgNTEuMSAwIDAg'
    b'MS0uMSAwdi0uMWgtLjJsLjEuMmgtLjF2LS4yaC0uMXptLjMtLjVzLjEgMCAwIDBjMCAuMSAw'
    b'IDAgMCAwem0uMS4xLjIuM2MtLjEgMCAwIDAgMCAwaC0uMXYtLjJoLS4xem0uMiAwIC4xLS4x'
    b'di0uMWguMnMuMS4yIDAgLjJhLjEuMSAwIDAgMSAwIC4xdi4ybC0uMi0uM3ptLjIgMGMwIC4x'
    b'LjEuMS4xIDB2LS4xaC0uMXptLjQtLjFjLS4xLjEtLjEgMC0uMSAwdi0uMi4xaC0uMXYtLjFo'
    b'LjJ2LjFoLjFzMCAuMSAwIDB6bTAgMHYtLjFoLS4xYzAgLjEgMCAuMi4xLjF6bTAtLjUuMi4z'
    b'di4xbC0uMi0uM3YtLjF6bS41LjItLjEuMWgtLjF2LS4ycy0uMSAwIDAgMHYtLjFsLjIuMnpt'
    b'MCAwLS4xLS4xdi4yYS4yLjIgMCAwIDAgMC0uMXptMC0uM3YtLjFoLjJhLjIuMiAwIDAgMSAw'
    b'IC4yLjEuMSAwIDAgMSAwIC4xaC0uMWwtLjItLjMuMS4xem0wIDAgLjEuMmguMXYtLjJoLS4x'
    b'em0uMy0uMmMuMSAwIC4xIDAgMCAwbC4xLjJ2LjFsLS4xLS4ydi0uMXptLjQgMHYuMWgtLjJs'
    b'LjEtLjJoLS4xYzAgLjEgMCAwIDAgMGguMWwuMS4xem0wIDBoLS4xczAgLjEgMCAwem0tMi42'
    b'IDIuNGMtLjEuMSAwIC4xIDAgLjFoLjF2LjJhNDUgNDUgMCAwIDEtLjEgMGguMXYtLjFoLS4y'
    b'di0uMmguMXptLjIgMGguMnYuMWEuMS4xIDAgMCAxLS4yIDAgLjIuMiAwIDAgMSAwLS4xLjEu'
    b'MSAwIDAgMSAwLS4xLjEuMSAwIDAgMSAuMSAwem0wIDB2LS4xem0uMi0uM2guMXYuMmguMWE2'
    b'Ny4zIDY3LjMgMCAwIDAtLjEuMWwtLjEtLjJ6bS4yIDAgLjEuMWguMXYtLjEuMWEuMS4xIDAg'
    b'MCAxLS4xIDAgLjIuMiAwIDAgMS0uMSAwIC4xLjEgMCAwIDEgMC0uMi4xLjEgMCAwIDEgLjIg'
    b'MHptMCAwaC4xYzAtLjEgMC0uMSAwIDB6bS4yLS40em0wIC4xLjIuMy0uMS0uMnMtLjEgMCAw'
    b'IDB6bS4zLS4xYy0uMS4xIDAgLjEgMCAuMWguMXYuMmgtLjEuMXYtLjFoLS4ydi0uMmguMXpt'
    b'LjItLjEuMS0uMS4yLjJ2LS4yaC0uMXYtLjFsLjEuMy0uMi0uMWgtLjF6bS40LS4yLjEuMWgu'
    b'MXYtLjEuMmEuMS4xIDAgMCAxLS4yIDAgLjIuMiAwIDAgMSAwLS4yLjEuMSAwIDAgMSAwLS4x'
    b'LjEuMSAwIDAgMSAuMSAwem0wIDBoLjFjMC0uMSAwLS4xLS4xIDB6bS4yLS4zdi4xbC4xLS4x'
    b'di40aC4xYy0uMSAwIDAgMCAwIDBsLS4yLS4yem0uNSAwYS4xLjEgMCAwIDEtLjEuMi4yLjIg'
    b'MCAwIDEtLjIgMCAuMi4yIDAgMCAxIDAtLjNoLjF2LS4ybC4yLjN2LjF6bTAgMGgtLjFjMC0u'
    b'MS0uMS0uMS0uMSAwdi4xaC4yem0uMiAwaC0uMXYtLjJoLS4xLjJjMCAuMS4xIDAgLjEgMHYu'
    b'MnptMCAwdi0uMmwtLjEuMXMwIC4xLjEgMHptLjMtLjNhLjEuMSAwIDAgMSAwIC4xLjIuMiAw'
    b'IDAgMS0uMiAwIC4yLjIgMCAwIDEgMC0uMnYtLjJsLjIuM2guMXptMCAwdi0uMWgtLjJsLjEu'
    b'MmguMXptMC0uMi4yLjFoLjF2LS4xLjFhLjEuMSAwIDAgMS0uMiAwIC4xLjEgMCAwIDEgMC0u'
    b'Mi4xLjEgMCAwIDEgLjEgMHptMCAwaC4yYzAtLjEgMC0uMS0uMSAwem0uMy0uM2guMXYuMmgu'
    b'MWwtLjEuMnYtLjFsLS4xLS4yem0uNCAwdi4ybC0uMS0uMXYtLjIuMWgtLjF2LS4xaC4ydi4y'
    b'aC4xem0wIDBoLS4xYzAgLjEgMCAuMi4xLjF6bS4xLS4ydi0uMWguMnYtLjFoLjFsLjEuMmMu'
    b'MSAwIDAgMCAwIDBsLS4xLS4yaC0uMXYuNGguMWMtLjEgMCAwIDAgMCAwaC0uMXYtLjFoLS4y'
    b'bC4xLjItLjEtLjJ6bS41LS4yaC4ydi4xYS4xLjEgMCAwIDEtLjIgMCAuMi4yIDAgMCAxLS4x'
    b'LS4xLjEuMSAwIDAgMSAwLS4yLjEuMSAwIDAgMSAuMiAwem0wIDB2LS4xem0uMi0uMnYtLjJo'
    b'LjJ2LjJoLjF2LjFsLS4xLS4yaC0uMXYuNGwtLjEtLjJ2LS4xem0uMi0uNHYuMWguMXYuMmgu'
    b'Mi0uMnYtLjFoLS4xYS4yLjIgMCAwIDAgMC0uMnptLjMuMXYuMWguMnYtLjEuMmEuMS4xIDAg'
    b'MCAxLS4yIDAgLjIuMiAwIDAgMSAwLS4yLjEuMSAwIDAgMSAwLS4xaC4xem0wIDBjMC0uMSAw'
    b'LS4xIDAgMHptLTQuNSAzLjh2LS4xaC4ydi0uMWguMWwuMS4yLS4xLS4xaC0uMXYuMmguMWE1'
    b'MS4xIDUxLjEgMCAwIDEtLjEgMHYtLjFoLS4ybC4xLjItLjEtLjJoLS4xem0uMy0uNXMuMSAw'
    b'IDAgLjF6bS4xLjIuMi4yYy0uMSAwIDAgMCAwIDBoLS4xdi0uMWgtLjF2LS4xem0uMy0uMmMw'
    b'IC4xIDAgMCAwIDBsLS4xLjFoLjJ2LjJoLS4xYy4xIDAgMC0uMSAwIDBoLS4xdi0uM3ptLjUg'
    b'MGEuMS4xIDAgMCAxIDAgLjEuMi4yIDAgMCAxLS4yIDAgLjIuMiAwIDAgMSAwLS4ydi0uMmwu'
    b'Mi4ycy4xIDAgMCAwdi4xem0wIDB2LS4xYy0uMSAwLS4yLS4xLS4yIDBsLjEuMi4xLS4xem0w'
    b'LS41YzAgLjEgMCAwIDAgMHptMCAuMS4yLjMtLjEtLjJoLS4xem0uMy0uMWgtLjF2LjFoLjJ2'
    b'LjJoLS4xLjF2LS4xaC0uMnYtLjJ6bS40IDB2LjFhLjEuMSAwIDAgMS0uMiAwIC4xLjEgMCAw'
    b'IDEgMC0uMmguMS0uMmEuMi4yIDAgMCAwIC4xLjJoLjF2LS4xem0tLjEtLjR6bTAgLjEuMi4z'
    b'aC4xLS4xbC0uMS0uMnptLjIgMCAuMS0uMWguMnYuMmEuMS4xIDAgMCAxIDAgLjFoLS4xdi4x'
    b'aC4xLS4xbC0uMi0uM3ptMCAwIC4yLjJjLjEgMCAwLS4xIDAtLjJoLS4xem0uMi0uNHMuMSAw'
    b'IDAgMGMwIC4xIDAgMCAwIDB6bS4xLjEuMi4zLS4yLS4yem0uMS0uMi4yLjRoLjEtLjFsLS4y'
    b'LS4zem0uMyAwYS4xLjEgMCAwIDEgLjEgMGwuMS4yLS4xLjFhLjIuMiAwIDAgMS0uMi0uMS4x'
    b'LjEgMCAwIDEgMC0uMi4xLjEgMCAwIDEgLjEgMHptMCAwdi4yaC4ydi0uMWgtLjJ6bS4zLS4y'
    b'YzAgLjEgMCAwIDAgMHYuMWguMXMuMS4xIDAgLjJhNDUgNDUgMCAwIDEtLjEgMGguMnMwLS4x'
    b'LS4xIDBoLS4xdi0uNHptLTEuNyA0LjN2LS4yYS4xLjEgMCAwIDEgLjEgMHYuMWEuMS4xIDAg'
    b'MCAxIC4yLjEuMi4yIDAgMCAxIDAgLjJoLS4xYy4xIDAgMC0uMSAwLS4yaC0uMXYtLjFoLS4x'
    b'em0uNi0uMS0uMi4ydi0uNGgtLjF2LjEtLjFhLjEuMSAwIDAgMSAuMSAwaC4xdi4zaC4xdi0u'
    b'MXptLjIgMHptLjItLjcuMi0uMXYuNi0uMWwtLjEtLjEtLjMtLjEuMS0uMnYuMWwuMi4xdi0u'
    b'MnptLjcgMGEuMS4xIDAgMCAxLS4xLjFsLS4xLS4xYS4xLjEgMCAwIDEgMC0uMmguMnMwIC4x'
    b'LS4xIDBjMCAwLS4xIDAgMCAuMWEuMi4yIDAgMCAwIDAgLjFoLjF6bS4xLS4zYS4xLjEgMCAw'
    b'IDEgLjEgMGwuMS4xLS4xLjJhLjIuMiAwIDAgMS0uMi0uMi4xLjEgMCAwIDEgMC0uMS4xLjEg'
    b'MCAwIDEgLjEgMHptMCAwdi4xbC4xLjFoLjF2LS4yaC0uMnptLjMtLjF2LS4yaC4xbC4xLjJ2'
    b'LjFsLS4xLS4yaC0uMXYuMmguMXYuMWwtLjItLjJ2LS4xem0uMy0uM2EuMS4xIDAgMCAxIC4x'
    b'IDBsLjEuMnMwIC4xLS4xIDBhLjIuMiAwIDAgMS0uMiAwIC4xLjEgMCAwIDEgMC0uMnptMCAw'
    b'di4zbC4yLS4xdi0uMWMtLjEgMC0uMi0uMS0uMiAwem0uNSAwYS4xLjEgMCAwIDEtLjIuMXYt'
    b'LjFhLjEuMSAwIDAgMSAwLS4yaC4xbC0uMi4xYS4yLjIgMCAwIDAgLjEuMWguMXptMC0uMmgu'
    b'MnYuMWEuMS4xIDAgMCAxLS4xIDAgLjIuMiAwIDAgMS0uMS0uMS4xLjEgMCAwIDEgMC0uMS4x'
    b'LjEgMCAwIDEgLjEgMHptMCAwaC4xbC0uMS0uMXptLjItLjNoLjF2LjJoLjF2LjFjLS4xIDAg'
    b'MCAwIDAgMGwtLjItLjJ6bS4zIDB2LjFoLjJ2LS4xLjFhLjEuMSAwIDAgMS0uMiAwIC4xLjEg'
    b'MCAwIDEgMC0uMmguMXptMCAwYzAtLjEgMC0uMSAwIDB6bTAtLjRoLjF6bS4yLjEuMS4yaC4x'
    b'bC0uMS4xLS4xLS4yem0uMi0uMWguMS0uMXYuMWguMXMuMS4xIDAgLjF2LjFoLS4xLjJsLS4x'
    b'LS4xaC0uMXYtLjJ6bS4yLS40LjMuNGgtLjFsLS4yLS4zem0uNS4zYy0uMS4xLS4yIDAtLjIg'
    b'MGwuMS0uMWgtLjF2LS4xaC4ydi4yem0wIDB2LS4xaC0uMXYuMXptLTQgMy4zdi0uMWwuMi4y'
    b'di0uMy40bC0uMi0uMnptLjMtLjIuMS4xaC4xdi0uMS4yYS4xLjEgMCAwIDEtLjEgMCAuMi4y'
    b'IDAgMCAxLS4xLS4yLjEuMSAwIDAgMSAwLS4xLjEuMSAwIDAgMSAuMiAwem0wIDBoLjFjMC0u'
    b'MSAwLS4xIDAgMHptLjMtLjN2LjEtLjEuNGguMi0uMnYtLjJoLS4xem0uNC4xYS4xLjEgMCAw'
    b'IDEgMCAuMS4yLjIgMCAwIDEtLjIgMCAuMi4yIDAgMCAxIDAtLjJ2LS4ybC4yLjJzLjEgMCAw'
    b'IDB2LjF6bTAgMHYtLjFjLS4xIDAtLjItLjEtLjIgMGwuMS4yLjEtLjF6bS4zLS4yLS4xLjFo'
    b'LS4xdi0uMnMtLjEgMCAwIDBoLjJjMCAuMSAwIDAgMCAwdi4yem0wIDBoLS4xczAgLjEgMCAw'
    b'em0uMy0uMWEuMS4xIDAgMCAxLS4xIDAgLjIuMiAwIDAgMS0uMiAwIC4yLjIgMCAwIDEgMC0u'
    b'MmguMXYtLjJoLS4xbC4zLjN6bTAgMC0uMS0uMmgtLjJ2LjFsLjIuMXptLjIgMHYtLjFoLS4x'
    b'Yy4xIDAgLjEgMCAwIDB2LjF6bTAtLjUuMS0uMS4yLjJ2LS4yaC0uMXYtLjFsLjEuM3YuMnMt'
    b'LjEgMCAwIDB2LS4ybC0uMi0uMWgtLjF6bS40LS41LjMuNGgtLjFsLS4yLS4zdi0uMXptLjUu'
    b'Mi0uMS4xcy0uMSAwIDAgMHYtLjJoLS4xdi0uMWguMWwuMS4yem0wIDB2LS4xbC0uMS4xczAg'
    b'LjEgMCAwem0wLS4zLjItLjEuMi4ydi0uMmgtLjF2LS4xbC4xLjMtLjItLjFoLS4xem0uNS0u'
    b'MmguMnYuMWEuMS4xIDAgMCAxLS4yIDAgLjEuMSAwIDAgMSAwLS4yLjEuMSAwIDAgMSAuMSAw'
    b'em0wIDBoLjFsLS4xLS4xYS4xLjEgMCAwIDAgMCAuMXptLjItLjNoLjF2LjJoLjFsLS4xLjJ2'
    b'LS4xbC0uMS0uMnptLjUgMGEuMS4xIDAgMCAxLS4xLjIuMi4yIDAgMCAxLS4yIDAgLjIuMiAw'
    b'IDAgMSAwLS4zaC4xdi0uMmwuMi4zdi4xem0wIDBoLS4xYzAtLjEtLjEtLjEtLjEgMHYuMWgu'
    b'MnptLjIgMGgtLjF2LS4ycy0uMSAwIDAgMGgtLjF2LS4xaC4ydi4yaC4xem0wLS4xdi0uMWgt'
    b'LjF2LjJhLjIuMiAwIDAgMCAuMS0uMXptLjMtLjJhLjEuMSAwIDAgMSAwIC4xLjIuMiAwIDAg'
    b'MS0uMiAwIC4yLjIgMCAwIDEgMC0uMnYtLjJsLjIuM2guMXptMCAwdi0uMWgtLjJsLjEuMmgu'
    b'MXptLjMtLjVjLjIgMCAuMi4xLjIuMiAwIDAtLjEuMi0uMi4xYS4yLjIgMCAwIDEtLjEtLjEu'
    b'MS4xIDAgMCAxIDAtLjF6bTAgMHYuNGguMmwtLjEtLjJoLS4xem0uMy0uMnYuMWgtLjEuMnYu'
    b'MmwtLjEuMWMwLS4xIDAgMCAwIDBsLjEtLjFoLS4ydi0uMnptLTQuNiAzLjh2LjJsLjItLjEu'
    b'Mi4yaC0uMWwtLjEtLjJoLS4xdi4xbC4xLjJoLS4xbC0uMS0uM3YtLjF6bS42LjEtLjEuMWgt'
    b'LjF2LS4yYzAgLjEgMCAwIDAgMGguMWwuMS4xem0wIDBoLS4xczAgLjEgMCAwem0wLS4zaC4x'
    b'di4yaC4xbC0uMS4xLS4xLS4ydi0uMXptLjQgMHYuMmwtLjItLjEuMS0uMnMtLjEgMCAwIDBj'
    b'LS4xLjEtLjEgMC0uMSAwaC4xbC4xLjFoLjFzMCAuMSAwIDB6bTAgMGEuMy4zIDAgMCAwLS4x'
    b'IDB2LjFhLjIuMiAwIDAgMCAuMSAwem0uMS0uNS4yLjNoLjFsLS4xLjEtLjItLjN2LS4xem0u'
    b'Mi0uMXptMCAwIC4yLjN2LjEtLjFsLS4xLS4xcy0uMSAwIDAgMHYtLjF6bS4zIDBoLjJhLjIu'
    b'MiAwIDAgMSAwIC4yLjEuMSAwIDAgMS0uMSAwbC0uMy0uMnYtLjF6bTAgMHYuMmguMnYtLjJo'
    b'LS4yem0uMi0uMmguMXYuMmguMWE2Ny4zIDY3LjMgMCAwIDAtLjEuMWwtLjEtLjJ6bS4yIDAg'
    b'LjEuMWguMnYtLjEuMWEuMS4xIDAgMCAxLS4yIDAgLjIuMiAwIDAgMS0uMSAwIC4xLjEgMCAw'
    b'IDEgMC0uMi4xLjEgMCAwIDEgLjIgMHptMCAwaC4xYzAtLjEgMC0uMSAwIDB6bS40LS4zaC0u'
    b'MXYuMWguMnYuMmgtLjF2LS4xaC0uMXYtLjJ6bS4yLjF6Ii8+CiAgICA8L2c+CiAgPC9nPgo8'
    b'L3N2Zz4K', 'DO')

DO = b64_DO
index.append("DO")
index.append("DOM")
index.append("Dominican Republic")
catalog["DO"] = DO
catalog["DOM"] = DO
catalog["Dominican Republic"] = DO
country["Dominican Republic"] = ('DO', 'DOM', 0)
lookup["DO"] = ('DO', 'DOM', 'Dominican Republic', 0)
lookup["Santo Domingo Dominican Republic"] = ('DO', 'DOM', 'Dominican Republic', 0)
lookup["DOM"] = ('DO', 'DOM', 'Dominican Republic', 0)
lookup["Dominican Republic"] = ('DO', 'DOM', 'Dominican Republic', 0)
details["DO"] = {"continent":"Americas","capital":"Santo Domingo","currency":"Dominican Peso","web":".do","lang":"es-DO","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_DZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWR6IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTMy'
    b'MCAwaDMyMHY0ODBIMzIweiIvPgogIDxwYXRoIGZpbGw9IiMwMDYyMzMiIGQ9Ik0wIDBoMzIw'
    b'djQ4MEgweiIvPgogIDxwYXRoIGZpbGw9IiNkMjEwMzQiIGQ9Ik00MjQgMTgwYTEyMCAxMjAg'
    b'MCAxIDAgMCAxMjAgOTYgOTYgMCAxIDEgMC0xMjBtNCA2MC0xMDgtMzUuMiA2Ny4yIDkyVjE4'
    b'My4ybC02Ny4yIDkyeiIvPgo8L3N2Zz4K', 'DZ')

DZ = b64_DZ
index.append("DZ")
index.append("DZA")
index.append("Algeria")
catalog["DZ"] = DZ
catalog["DZA"] = DZ
catalog["Algeria"] = DZ
country["Algeria"] = ('DZ', 'DZA', 0)
lookup["DZ"] = ('DZ', 'DZA', 'Algeria', 0)
lookup["Algiers Algeria"] = ('DZ', 'DZA', 'Algeria', 0)
lookup["DZA"] = ('DZ', 'DZA', 'Algeria', 0)
lookup["Algeria"] = ('DZ', 'DZA', 'Algeria', 0)
details["DZ"] = {"continent":"Africa","capital":"Algiers","currency":"Algerian Dinar","web":".dz","lang":"ar-DZ","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_EC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWVjIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmZlODAwIiBkPSJNMCAwaDY0'
    b'MHY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDE0OGUiIGQ9Ik0wIDI0MGg2NDB2MjQw'
    b'SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZGEwMDEwIiBkPSJNMCAzNjBoNjQwdjEyMEgweiIv'
    b'PgogIDwvZz4KICA8ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgPHBhdGggZD0iTTI2OS42'
    b'IDI5MC44IDE5NyAzNjcuM2wtMS4yLTEuNiA3Mi40LTc2LjUgMS4yIDEuNnptNTAuNCAxMi41'
    b'LTk0LjggMTAwLTEuNi0xLjYgOTQuNy0xMDAgMS43IDEuNnoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'ImdyYXkiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSI0LjEiIGQ9Ik00NzguNCA2MC4y'
    b'djg4LjZsMTcuNyA4OC42IDE3LjctODguNlY2MC4yaC0zNS40eiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoLS4wNyAtLjA3IC0uMSAuMSAyNjUgNDI5LjYpIi8+CiAgICA8cGF0aCBmaWxsPSJncmF5'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iNC4xIiBkPSJNNDc4LjQgNjAuMnY4OC42'
    b'bDE3LjcgODguNiAxNy43LTg4LjZWNjAuMmgtMzUuNHoiIHRyYW5zZm9ybT0ibWF0cml4KC0u'
    b'MDcgLS4wNyAtLjEgLjEgMjQwLjYgMzkwLjUpIi8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiNm'
    b'ZmRmMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'IjFwdCIgZD0iTTMwMS4yIDI3Mi44cy0xNy43IDMzNi42IDUzLjEgMzM2LjZTNDYwLjYgNTc0'
    b'IDQ2MC42IDU3NGwtLjgtMTg1LTE1OC42LTExNi4yeiIgdHJhbnNmb3JtPSJtYXRyaXgoLjQ1'
    b'IDAgMCAuNjQgNzIuNCAtNTkuOCkiLz4KICA8cGF0aCBmaWxsPSIjMDAwMGM0IiBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik0zNDQu'
    b'NSAzMDQuMmMwIDE3LjctNy45IDI2OS44IDI3LjUgMjY5LjhzODguNi0xNy43IDg4LjYtMTcu'
    b'N2wtLjgtMTY3LjMtMTE1LjMtODQuOHoiIHRyYW5zZm9ybT0ibWF0cml4KC40NSAwIDAgLjY0'
    b'IDcyLjQgLTU5LjgpIi8+CiAgPHBhdGggZmlsbD0iI2UxMDAwMCIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNMzY3LjUgMzIxLjJj'
    b'MCAxNy43IDQuNSAyMTcuNCA0MCAyMTcuNGg1My4xbC0uOC0xNDkuNi05Mi4zLTY3Ljh6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCguNDUgMCAwIC42NCA3Mi40IC01OS44KSIvPgogIDxwYXRoIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgZD0ibTIwNi4yIDExNiA3Mi40IDc2LjUgMS4zLTEuNi03Mi40'
    b'LTc2LjUtMS4zIDEuNnoiLz4KICA8cGF0aCBmaWxsPSIjZmZkZjAwIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik0zMDEuMiAyNzIu'
    b'OFMyNjUuOCA2MDkuNCAzNzIgNjA5LjRjODguNSAwIDg4LjUtNTMuMSAxMDYuMi01My4xbC0x'
    b'Ny43LTEyNC0xNTkuNC0xNTkuNXoiIHRyYW5zZm9ybT0ibWF0cml4KC41OCAwIDAgLjYyIDku'
    b'NiAtMTAuMikiLz4KICA8ZyBzdHJva2U9IiMwMDAiPgogICAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlLXdpZHRoPSIyLjMiIGQ9Ik0yNjkuNiAxNTUuMmMxLjEgMCAyOC4zLTk0IDExOS0x'
    b'NDcuMiIgdHJhbnNmb3JtPSJtYXRyaXgoLjQgLS4wMyAtLjA1IC4zNSAxMzUuMSAxNDcuNCki'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiMwMDViMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tl'
    b'LXdpZHRoPSIxcHQiIGQ9Ik00MjEuNC0yMC4zYzAgMTguMS00LjYgMzEuNy0xMS40IDQ1LjMt'
    b'NS42LTE4LjEtOS0yNy4yLTktNDUuM3M2LjgtMzUuMSAxMi40LTQ4LjdjMi4zIDEyLjQgOCAz'
    b'MC41IDggNDguN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4xNCAtLjIyIC4zIC4xNCAxNzUuOSAy'
    b'NTcuNCkiLz4KICAgIDxwYXRoIGZpbGw9InJlZCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJv'
    b'a2Utd2lkdGg9IjFwdCIgZD0iTTQ1NC4yLTE2OS4zYzAgNC0zLjggNy40LTguNSA3LjRzLTgu'
    b'NS0zLjMtOC41LTcuNCAzLjgtNy4zIDguNS03LjMgOC41IDMuMyA4LjUgNy4zeiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjE4IC0uMSAuMSAuMTcgMTc3LjYgMjU2LjcpIi8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjMDA1YjAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0IiBk'
    b'PSJNNDIxLjQtMjAuM2MwIDE4LjEtNC42IDMxLjctMTEuNCA0NS4zLTUuNi0xOC4xLTktMjcu'
    b'Mi05LTQ1LjNzNi44LTM1LjEgMTIuNC00OC43YzIuMyAxMi40IDggMzAuNSA4IDQ4Ljd6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCguMTggLjEyIC0uMTMgLjMzIDE4MSA5Ni40KSIvPgogICAgPHBh'
    b'dGggZmlsbD0iIzAwNWIwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFw'
    b'dCIgZD0iTTQyMS40LTIwLjNjMCAxOC4xLTQuNiAzMS43LTExLjQgNDUuMy01LjYtMTguMS05'
    b'LTI3LjItOS00NS4zczYuOC0zNS4xIDEyLjQtNDguN2MyLjMgMTIuNCA4IDMwLjUgOCA0OC43'
    b'eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjE3IC0uMDMgLS4wMyAuMzMgMTc5LjMgMTU5LjMpIi8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjMDA1YjAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS13'
    b'aWR0aD0iMXB0IiBkPSJNNDIxLjQtMjAuM2MwIDE4LjEtNC42IDMxLjctMTEuNCA0NS4zLTUu'
    b'Ni0xOC4xLTktMjcuMi05LTQ1LjNzNi44LTM1LjEgMTIuNC00OC43YzIuMyAxMi40IDggMzAu'
    b'NSA4IDQ4Ljd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMDYgLjI1IC0uMTcgLjIgMjI4IDQ1LjUp'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDA1YjAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9r'
    b'ZS13aWR0aD0iMXB0IiBkPSJNNDIxLjQtMjAuM2MwIDE4LjEtNC42IDMxLjctMTEuNCA0NS4z'
    b'LTUuNi0xOC4xLTktMjcuMi05LTQ1LjNzNi44LTM1LjEgMTIuNC00OC43YzIuMyAxMi40IDgg'
    b'MzAuNSA4IDQ4Ljd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMiAtLjIgLjIgLjI0IDE1MC4zIDI0'
    b'MSkiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDViMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlLXdpZHRoPSIxcHQiIGQ9Ik00MjEuNC0yMC4zYzAgMTguMS00LjYgMzEuNy0xMS40IDQ1'
    b'LjMtNS42LTE4LjEtOS0yNy4yLTktNDUuM3M2LjgtMzUuMSAxMi40LTQ4LjdjMi4zIDEyLjQg'
    b'OCAzMC41IDggNDguN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4yMiAtLjIyIC4yNSAuMiAxMzUu'
    b'NiAyODIuMSkiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDViMDAiIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik00MjEuNC0yMC4zYzAgMTguMS00LjYgMzEuNy0x'
    b'MS40IDQ1LjMtNS42LTE4LjEtOS0yNy4yLTktNDUuM3M2LjgtMzUuMSAxMi40LTQ4LjdjMi4z'
    b'IDEyLjQgOCAzMC41IDggNDguN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4yNiAuMSAtLjIgLjMy'
    b'IDEzMC44IDE0Ny43KSIvPgogICAgPHBhdGggZmlsbD0iIzAwNWIwMCIgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQyMS40LTIwLjNjMCAxOC4xLTQuNiAz'
    b'MS43LTExLjQgNDUuMy01LjYtMTguMS05LTI3LjItOS00NS4zczYuOC0zNS4xIDEyLjQtNDgu'
    b'N2MyLjMgMTIuNCA4IDMwLjUgOCA0OC43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjE1IC4yIC0u'
    b'MzIgLjIyIDE3OC41IDEwMy4zKSIvPgogICAgPHBhdGggZmlsbD0iIzAwNWIwMCIgZmlsbC1y'
    b'dWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQyMS40LTIwLjNjMCAxOC4x'
    b'LTQuNiAzMS43LTExLjQgNDUuMy01LjYtMTguMS05LTI3LjItOS00NS4zczYuOC0zNS4xIDEy'
    b'LjQtNDguN2MyLjMgMTIuNCA4IDMwLjUgOCA0OC43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjA4'
    b'IC4xIC0uMTQgLjE2IDI1MC43IDEwMi42KSIvPgogICAgPHBhdGggZmlsbD0iIzAwNWIwMCIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQyMS40LTIwLjNj'
    b'MCAxOC4xLTQuNiAzMS43LTExLjQgNDUuMy01LjYtMTguMS05LTI3LjItOS00NS4zczYuOC0z'
    b'NS4xIDEyLjQtNDguN2MyLjMgMTIuNCA4IDMwLjUgOCA0OC43eiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoLjEgMCAtLjA4IC4xNyAyMzggMTM2LjQpIi8+CiAgICA8cGF0aCBmaWxsPSIjMDA1YjAw'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNDIxLjQtMjAu'
    b'M2MwIDE4LjEtNC42IDMxLjctMTEuNCA0NS4zLTUuNi0xOC4xLTktMjcuMi05LTQ1LjNzNi44'
    b'LTM1LjEgMTIuNC00OC43YzIuMyAxMi40IDggMzAuNSA4IDQ4Ljd6IiB0cmFuc2Zvcm09Im1h'
    b'dHJpeCgwIC4xNCAtLjE0IC4wOCAyODcuNCA4MS4xKSIvPgogICAgPHBhdGggZmlsbD0iIzAw'
    b'NWIwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQyMS40'
    b'LTIwLjNjMCAxOC4xLTQuNiAzMS43LTExLjQgNDUuMy01LjYtMTguMS05LTI3LjItOS00NS4z'
    b'czYuOC0zNS4xIDEyLjQtNDguN2MyLjMgMTIuNCA4IDMwLjUgOCA0OC43eiIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoLjA3IC4xIC0uMjUgLjE1IDIyMC43IDExNS42KSIvPgogICAgPHBhdGggZmls'
    b'bD0iIzAwNWIwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0i'
    b'TTQyMS40LTIwLjNjMCAxOC4xLTQuNiAzMS43LTExLjQgNDUuMy01LjYtMTguMS05LTI3LjIt'
    b'OS00NS4zczYuOC0zNS4xIDEyLjQtNDguN2MyLjMgMTIuNCA4IDMwLjUgOCA0OC43eiIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoLjEzIC4yMiAtLjMzIC4yIDIwNyA3MC4xKSIvPgogICAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIyLjQiIGQ9Ik0yNjkuNiAxNTUuMmMxLjEgMCAy'
    b'OC4zLTk0IDExOS0xNDcuMiIgdHJhbnNmb3JtPSJtYXRyaXgoLjM1IC0uMiAuMTQgLjI4IDEx'
    b'MS44IDIyNy44KSIvPgogICAgPHBhdGggZmlsbD0icmVkIiBmaWxsLXJ1bGU9ImV2ZW5vZGQi'
    b'IHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNDU0LjItMTY5LjNjMCA0LTMuOCA3LjQtOC41IDcu'
    b'NHMtOC41LTMuMy04LjUtNy40IDMuOC03LjMgOC41LTcuMyA4LjUgMy4zIDguNSA3LjN6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCguMTggLS4xIC4xIC4xNyAyMDAuMyAyMjQuNikiLz4KICAgIDxw'
    b'YXRoIGZpbGw9InJlZCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIg'
    b'ZD0iTTQ1NC4yLTE2OS4zYzAgNC0zLjggNy40LTguNSA3LjRzLTguNS0zLjMtOC41LTcuNCAz'
    b'LjgtNy4zIDguNS03LjMgOC41IDMuMyA4LjUgNy4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoLjE4'
    b'IC0uMSAuMSAuMTcgMjExLjEgMjE4LjMpIi8+CiAgICA8cGF0aCBmaWxsPSJyZWQiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik00NTQuMi0xNjkuM2MwIDQt'
    b'My44IDcuNC04LjUgNy40cy04LjUtMy4zLTguNS03LjQgMy44LTcuMyA4LjUtNy4zIDguNSAz'
    b'LjMgOC41IDcuM3oiIHRyYW5zZm9ybT0ibWF0cml4KC4yIC0uMSAuMDcgLjEzIDE2Ni44IDIz'
    b'Mi43KSIvPgogICAgPHBhdGggZmlsbD0icmVkIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9r'
    b'ZS13aWR0aD0iMXB0IiBkPSJNNDU0LjItMTY5LjNjMCA0LTMuOCA3LjQtOC41IDcuNHMtOC41'
    b'LTMuMy04LjUtNy40IDMuOC03LjMgOC41LTcuMyA4LjUgMy4zIDguNSA3LjN6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCguMiAtLjEgLjA3IC4xMyAxNzAgMjMxLjMpIi8+CiAgICA8cGF0aCBmaWxs'
    b'PSJyZWQiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik00NTQu'
    b'Mi0xNjkuM2MwIDQtMy44IDcuNC04LjUgNy40cy04LjUtMy4zLTguNS03LjQgMy44LTcuMyA4'
    b'LjUtNy4zIDguNSAzLjMgOC41IDcuM3oiIHRyYW5zZm9ybT0ibWF0cml4KC4yIC0uMSAuMDcg'
    b'LjEzIDE2OC4xIDIzNC4zKSIvPgogICAgPHBhdGggZmlsbD0icmVkIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0yNTIuNyAxNjcuM2MuNC44IDAgMS44LTEg'
    b'Mi4zcy0yIC4yLTIuNC0uNyAwLTEuOCAxLTIuMyAyLS4yIDIuMy43eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0icmVkIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0y'
    b'NTUgMTY0LjljLjMuOCAwIDEuOC0xIDIuM3MtMiAuMi0yLjUtLjYgMC0xLjkgMS0yLjQgMi0u'
    b'MSAyLjQuN3oiLz4KICAgIDxwYXRoIGZpbGw9InJlZCIgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9Ii4zIiBkPSJNMjU1LjUgMTY2Yy40LjggMCAxLjktMSAyLjNzLTIgLjIt'
    b'Mi40LS42IDAtMS44IDEtMi4zIDItLjIgMi40LjZ6Ii8+CiAgPC9nPgogIDxwYXRoIGZpbGw9'
    b'IiMwMDAwYzQiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lk'
    b'dGg9IjFwdCIgZD0iTTMzNi42IDMwOC4zYzAgMTcuNy0zNS40IDIxMi42IDUzLjIgMjY1Ljcg'
    b'MzUuNCAxNy43IDg4LjUtMTcuNyA4OC41IDBsLTE3LjctMTQxLjctMTI0LTEyNHoiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KC41OCAwIDAgLjYyIDkuNiAtMTAuMikiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZTEwMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIxcHQiIGQ9Ik0zNzIgMzQzLjdjMCAxNy43LTE3LjcgMTU5LjQgMzUuNSAxOTQuOSAzNS40'
    b'IDM1LjQgMTI0IDI1LjggMTI0IDI1LjhsLTcwLjktMTMyLjEtODguNi04OC42eiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjU4IDAgMCAuNjIgOS42IC0xMC4yKSIvPgogIDxwYXRoIGZpbGwtcnVs'
    b'ZT0iZXZlbm9kZCIgZD0ibTE4My44IDE1OCA5NC44IDEwMCAxLjctMS42LTk0LjgtOTkuOS0x'
    b'LjYgMS42eiIvPgogIDxwYXRoIGZpbGw9IiNjZWNlY2MiIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0ibTQ2MC42IDE4NC4zIDE3Ljcg'
    b'MzUuNHYxNy43Yy0uOC0xLjMgMCAxNy43LTE3LjcgMTcuN1M0NDMgMjE5LjcgNDQzIDIxOS43'
    b'cy0xNy43IDM1LjQtMTcuNyA3MC45IDE3LjcgNTMuMSAxNy43IDUzLjEtMi42LTM2LjcgMTcu'
    b'Ny0zNS40YzIwLjQgMS4yIDE3LjcgMTcuNyAxNy43IDE3Ljd2MzUuNGgxNy44VjIxOS43bDE3'
    b'LjctMzUuNC0yNy4yLTUzLjItMjYgNTMuMXoiIHRyYW5zZm9ybT0ibWF0cml4KC4xNCAtLjE0'
    b'IC4xIC4xIDg2LjMgMTkyLjIpIi8+CiAgPHBhdGggZmlsbD0iI2NlY2VjYyIgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJtNTU3Ljgg'
    b'OTUuNy0yNi4zIDcwLjggMTcuNyA1My4yLTM1LjQtMTcuNyAzNS40IDUzLjF2MzUuNUg1NjdW'
    b'MjU1bDM1LjUtNTMuMS0zNS41IDE3LjcgMTcuOC01My4yLTI2LjktNzAuOHoiIHRyYW5zZm9y'
    b'bT0ibWF0cml4KC4xIC0uMTYgLjE0IC4xIDExNCAxODMuOCkiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZTEwMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIxcHQiIGQ9Ik00MjIuNSAxMzdjMCAyLTIgMy43LTQuMyAzLjdzLTQuNC0xLjctNC40LTMu'
    b'NyAyLTMuOCA0LjQtMy44IDQuMyAxLjcgNC4zIDMuOHptLTYuMiA3LjljMCAzNS44IDIwLjkg'
    b'MTg3LjggMjIuNiAxOTEuNS4xIDQuNS00LjggNi40LTcuMS45LTYuNi0xNy40LTIwLjgtMTYw'
    b'LTIxLjMtMTkzLjMtLjMtMTMuNyAzLjctMTQuOCA4LjMtMTQuNSAzLjcuMiA4LjMgMy43IDgu'
    b'MyA3LjkgMCA1LTUuOCA4LjctMTAuOCA3LjV6IiB0cmFuc2Zvcm09Im1hdHJpeCguNCAwIDAg'
    b'LjMgNDMuOCA2OS44KSIvPgogIDxwYXRoIGZpbGw9IiMwMDAwYzQiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQyMi41IDEzN2Mw'
    b'IDItMiAzLjctNC4zIDMuN3MtNC40LTEuNy00LjQtMy43IDItMy44IDQuNC0zLjggNC4zIDEu'
    b'NyA0LjMgMy44em0tNi4yIDcuOWMzMS41IDYxLjQgNDguNyAxNjYuNyA1MC40IDE3MC41LjEg'
    b'NC40LTQuOCA2LjQtNy4xLjgtMi41LTMuMy0xMi43LTEwMC4yLTQ5LjEtMTcyLjItLjMtMTMu'
    b'NyAzLjctMTQuOCA4LjMtMTQuNSAzLjcuMiA4LjMgMy43IDguMyA3LjkgMCA1LTUuOCA4Ljct'
    b'MTAuOCA3LjV6IiB0cmFuc2Zvcm09Im1hdHJpeCguMzggLjEgLS4xNSAuMyA3NiAzOC4yKSIv'
    b'PgogIDxwYXRoIGZpbGw9IiNlMTAwMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNMTg2LjcgMTUxLjVjMCAxLTEgMi0yLjIgMi0x'
    b'LjIgMC0yLjItMS0yLjItMnMxLTEuOCAyLjItMS44YzEuMiAwIDIuMS44IDIuMSAxLjh6bS0z'
    b'LjIgNGMwIDE3LjkgMTAuNSA5My45IDExLjMgOTUuOCAwIDIuMi0yLjMgMy4yLTMuNS40LTMu'
    b'My04LjctMTAuNC04MC0xMC43LTk2LjYtLjEtNi45IDEuOS03LjQgNC4yLTcuMyAxLjkuMSA0'
    b'LjEgMS45IDQuMSA0IDAgMi40LTIuOSA0LjMtNS40IDMuN3oiLz4KICA8cGF0aCBmaWxsPSIj'
    b'MDAwMGM0IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIxcHQiIGQ9Ik00MjIuNSAxMzdjMCAyLTIgMy43LTQuMyAzLjdzLTQuNC0xLjctNC40LTMu'
    b'NyAyLTMuOCA0LjQtMy44IDQuMyAxLjcgNC4zIDMuOHptLTYuMiA3LjljMzEuNSA2MS40IDQ4'
    b'LjcgMTY2LjcgNTAuNCAxNzAuNS4xIDQuNC00LjggNi40LTcuMS44LTIuNS0zLjMtMTIuNy0x'
    b'MDAuMi00OS4xLTE3Mi4yLS4zLTEzLjcgMy43LTE0LjggOC4zLTE0LjUgMy43LjIgOC4zIDMu'
    b'NyA4LjMgNy45IDAgNS01LjggOC43LTEwLjggNy41eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjQ4'
    b'IC4xNSAtLjIgLjQ4IDE2LjcgMzEuNikiLz4KICA8ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgog'
    b'ICAgPHBhdGggZD0ibTM3MC40IDI5MC44IDcyLjUgNzYuNSAxLjMtMS42LTcyLjUtNzYuNS0x'
    b'LjMgMS42ek0zMjAgMzAzLjNsOTQuOCAxMDAgMS42LTEuNi05NC43LTEwMC0xLjcgMS42eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iZ3JheSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjQu'
    b'MSIgZD0iTTQ3OC40IDYwLjJ2ODguNmwxNy43IDg4LjYgMTcuNy04OC42VjYwLjJoLTM1LjR6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCguMDcgLS4wNyAuMSAuMSAzNzUgNDI5LjYpIi8+CiAgICA8'
    b'cGF0aCBmaWxsPSJncmF5IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iNC4xIiBkPSJN'
    b'NDc4LjQgNjAuMnY4OC42bDE3LjcgODguNiAxNy43LTg4LjZWNjAuMmgtMzUuNHoiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KC4wNyAtLjA3IC4xIC4xIDM5OS40IDM5MC41KSIvPgogIDwvZz4KICA8'
    b'ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmRmMDAiIHN0cm9rZT0iIzAwMCIgZD0iTTMwMS4yIDI3Mi44cy0xNy43IDMzNi42'
    b'IDUzLjEgMzM2LjZTNDYwLjYgNTc0IDQ2MC42IDU3NGwtLjgtMTg1LTE1OC42LTExNi4yeiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLS40NSAwIDAgLjY0IDU2Ny42IC01OS44KSIvPgogICAgPHBh'
    b'dGggZmlsbD0iIzAwMDBjNCIgc3Ryb2tlPSIjMDAwIiBkPSJNMzQ0LjUgMzA0LjJjMCAxNy43'
    b'LTcuOSAyNjkuOCAyNy41IDI2OS44czg4LjYtMTcuNyA4OC42LTE3LjdsLS44LTE2Ny4zLTEx'
    b'NS4zLTg0Ljh6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjQ1IDAgMCAuNjQgNTY3LjYgLTU5Ljgp'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZTEwMDAwIiBzdHJva2U9IiMwMDAiIGQ9Ik0zNjcuNSAz'
    b'MjEuMmMwIDE3LjcgNC41IDIxNy40IDQwIDIxNy40aDUzLjFsLS44LTE0OS42LTkyLjMtNjcu'
    b'OHoiIHRyYW5zZm9ybT0ibWF0cml4KC0uNDUgMCAwIC42NCA1NjcuNiAtNTkuOCkiLz4KICAg'
    b'IDxwYXRoIGQ9Im00MzMuOCAxMTYtNzIuNCA3Ni41LTEuMy0xLjYgNzIuNC03Ni41IDEuMyAx'
    b'LjZ6Ii8+CiAgICA8ZyBmaWxsPSIjMDA1YjAwIiBzdHJva2U9IiMwMDAiPgogICAgICA8cGF0'
    b'aCBkPSJNNDI4LjItMTdzODEuNSA5MC43IDExMSAxNTQuMWMyOS40IDYzLjUgNTQuNCAxNTYu'
    b'MyA1NC40IDE1Ni4zczIuMi04Ni0zNi4zLTE2M0M1MDUuMiAzMi44IDQyNS45LTEyLjUgNDI4'
    b'LjItMTd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMTYgLS4wNyAuMDggLjM1IDMwOS41IDIxMSki'
    b'Lz4KICAgICAgPHBhdGggZD0iTTQyOC4yLTE3czgxLjUgOTAuNyAxMTEgMTU0LjFjMjkuNCA2'
    b'My41IDU0LjQgMTU2LjMgNTQuNCAxNTYuM3MyLjItODYtMzYuMy0xNjNDNTA1LjIgMzIuOCA0'
    b'MjUuOS0xMi41IDQyOC4yLTE3eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjIgLS4wNSAuMDcgLjQg'
    b'MjkxLjUgMTgyLjYpIi8+CiAgICAgIDxwYXRoIGQ9Ik00MjguMi0xN3M4MS41IDkwLjcgMTEx'
    b'IDE1NC4xYzI5LjQgNjMuNSA1NC40IDE1Ni4zIDU0LjQgMTU2LjNzMi4yLTg2LTM2LjMtMTYz'
    b'QzUwNS4yIDMyLjggNDI1LjktMTIuNSA0MjguMi0xN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4y'
    b'MyAuMTQgLS4wMyAuNCAyOTYuNSA2OS40KSIvPgogICAgICA8cGF0aCBkPSJNNDI4LjItMTdz'
    b'ODEuNSA5MC43IDExMSAxNTQuMWMyOS40IDYzLjUgNTQuNCAxNTYuMyA1NC40IDE1Ni4zczIu'
    b'Mi04Ni0zNi4zLTE2M0M1MDUuMiAzMi44IDQyNS45LTEyLjUgNDI4LjItMTd6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCguMjUgLjAzIC4wMiAuNDQgMjc0LjQgMTE1KSIvPgogICAgICA8cGF0aCBk'
    b'PSJNNDI4LjItMTdzODEuNSA5MC43IDExMSAxNTQuMWMyOS40IDYzLjUgNTQuNCAxNTYuMyA1'
    b'NC40IDE1Ni4zczIuMi04Ni0zNi4zLTE2M0M1MDUuMiAzMi44IDQyNS45LTEyLjUgNDI4LjIt'
    b'MTd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMTggLjE3IC0uMDQgLjM1IDMzMCA2NykiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTQyOC4yLTE3czgxLjUgOTAuNyAxMTEgMTU0LjFjMjkuNCA2My41IDU0'
    b'LjQgMTU2LjMgNTQuNCAxNTYuM3MyLjItODYtMzYuMy0xNjNDNTA1LjIgMzIuOCA0MjUuOS0x'
    b'Mi41IDQyOC4yLTE3eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjIzIDAgLjAzIC40IDI4MC42IDE0'
    b'MS45KSIvPgogICAgICA8cGF0aCBkPSJNNDI4LjItMTdzODEuNSA5MC43IDExMSAxNTQuMWMy'
    b'OS40IDYzLjUgNTQuNCAxNTYuMyA1NC40IDE1Ni4zczIuMi04Ni0zNi4zLTE2M0M1MDUuMiAz'
    b'Mi44IDQyNS45LTEyLjUgNDI4LjItMTd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMiAtLjA3IC4w'
    b'NyAuMzggMjkwLjEgMTk2LjgpIi8+CiAgICAgIDxwYXRoIGQ9Ik00MjguMi0xN3M4MS41IDkw'
    b'LjcgMTExIDE1NC4xYzI5LjQgNjMuNSA1NC40IDE1Ni4zIDU0LjQgMTU2LjNzMi4yLTg2LTM2'
    b'LjMtMTYzQzUwNS4yIDMyLjggNDI1LjktMTIuNSA0MjguMi0xN3oiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC4yIC0uMDMgLjA1IC40IDI5Mi43IDE2Ni44KSIvPgogICAgICA8cGF0aCBkPSJNNDI4'
    b'LjItMTdzODEuNSA5MC43IDExMSAxNTQuMWMyOS40IDYzLjUgNTQuNCAxNTYuMyA1NC40IDE1'
    b'Ni4zczIuMi04Ni0zNi4zLTE2M0M1MDUuMiAzMi44IDQyNS45LTEyLjUgNDI4LjItMTd6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCguMjIgLjE1IC0uMDUgLjM4IDMwNSA2NS41KSIvPgogICAgICA8'
    b'cGF0aCBkPSJNNDI4LjItMTdzODEuNSA5MC43IDExMSAxNTQuMWMyOS40IDYzLjUgNTQuNCAx'
    b'NTYuMyA1NC40IDE1Ni4zczIuMi04Ni0zNi4zLTE2M0M1MDUuMiAzMi44IDQyNS45LTEyLjUg'
    b'NDI4LjItMTd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMjQgLjA1IDAgLjQ0IDI3OC45IDk3Ljcp'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik00MjguMi0xN3M4MS41IDkwLjcgMTExIDE1NC4xYzI5LjQg'
    b'NjMuNSA1NC40IDE1Ni4zIDU0LjQgMTU2LjNzMi4yLTg2LTM2LjMtMTYzQzUwNS4yIDMyLjgg'
    b'NDI1LjktMTIuNSA0MjguMi0xN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4xNyAuMTcgLS4wNiAu'
    b'MzMgMzM5IDcwKSIvPgogICAgICA8cGF0aCBkPSJNNDI4LjItMTdzODEuNSA5MC43IDExMSAx'
    b'NTQuMWMyOS40IDYzLjUgNTQuNCAxNTYuMyA1NC40IDE1Ni4zczIuMi04Ni0zNi4zLTE2M0M1'
    b'MDUuMiAzMi44IDQyNS45LTEyLjUgNDI4LjItMTd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMjQg'
    b'LjAyIDAgLjQgMjc2LjQgMTI4KSIvPgogICAgPC9nPgogICAgPHBhdGggZmlsbD0iI2ZmZGYw'
    b'MCIgc3Ryb2tlPSIjMDAwIiBkPSJNMzAxLjIgMjcyLjhTMjY1LjggNjA5LjQgMzcyIDYwOS40'
    b'Yzg4LjUgMCA4OC41LTUzLjEgMTA2LjItNTMuMWwtMTcuNy0xMjQtMTU5LjQtMTU5LjV6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgtLjU4IDAgMCAuNjIgNjMwLjQgLTEwLjIpIi8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjMDAwMGM0IiBzdHJva2U9IiMwMDAiIGQ9Ik0zMzYuNiAzMDguM2MwIDE3Ljct'
    b'MzUuNCAyMTIuNiA1My4yIDI2NS43IDM1LjQgMTcuNyA4OC41LTE3LjcgODguNSAwbC0xNy43'
    b'LTE0MS43LTEyNC0xMjR6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjU4IDAgMCAuNjIgNjMwLjQg'
    b'LTEwLjIpIi8+CiAgICA8cGF0aCBmaWxsPSIjZTEwMDAwIiBzdHJva2U9IiMwMDAiIGQ9Ik0z'
    b'NzIgMzQzLjdjMCAxNy43LTE3LjcgMTU5LjQgMzUuNSAxOTQuOSAzNS40IDM1LjQgMTI0IDI1'
    b'LjggMTI0IDI1LjhsLTcwLjktMTMyLjEtODguNi04OC42eiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'LS41OCAwIDAgLjYyIDYzMC40IC0xMC4yKSIvPgogICAgPHBhdGggZD0ibTQ1Ni4yIDE1OC05'
    b'NC44IDEwMC0xLjctMS42IDk0LjgtOTkuOSAxLjcgMS42eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2NlY2VjYyIgc3Ryb2tlPSIjMDAwIiBkPSJtNDYwLjYgMTg0LjMgMTcuNyAzNS40djE3Ljdj'
    b'LS44LTEuMyAwIDE3LjctMTcuNyAxNy43UzQ0MyAyMTkuNyA0NDMgMjE5LjdzLTE3LjcgMzUu'
    b'NC0xNy43IDcwLjkgMTcuNyA1My4xIDE3LjcgNTMuMS0yLjYtMzYuNyAxNy43LTM1LjRjMjAu'
    b'NCAxLjIgMTcuNyAxNy43IDE3LjcgMTcuN3YzNS40aDE3LjhWMjE5LjdsMTcuNy0zNS40LTI3'
    b'LjItNTMuMi0yNiA1My4xeiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4xNCAtLjE0IC0uMSAuMSA1'
    b'NTMuNyAxOTIuMikiLz4KICAgIDxwYXRoIGZpbGw9IiNjZWNlY2MiIHN0cm9rZT0iIzAwMCIg'
    b'ZD0ibTU1Ny44IDk1LjctMjYuMyA3MC44IDE3LjcgNTMuMi0zNS40LTE3LjcgMzUuNCA1My4x'
    b'djM1LjVINTY3VjI1NWwzNS41LTUzLjEtMzUuNSAxNy43IDE3LjgtNTMuMi0yNi45LTcwLjh6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjEgLS4xNiAtLjE0IC4xIDUyNiAxODMuOCkiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNlMTAwMDAiIHN0cm9rZT0iIzAwMCIgZD0iTTQyMi41IDEzN2MwIDIt'
    b'MiAzLjctNC4zIDMuN3MtNC40LTEuNy00LjQtMy43IDItMy44IDQuNC0zLjggNC4zIDEuNyA0'
    b'LjMgMy44em0tNi4yIDcuOWMwIDM1LjggMjAuOSAxODcuOCAyMi42IDE5MS41LjEgNC41LTQu'
    b'OCA2LjQtNy4xLjktNi42LTE3LjQtMjAuOC0xNjAtMjEuMy0xOTMuMy0uMy0xMy43IDMuNy0x'
    b'NC44IDguMy0xNC41IDMuNy4yIDguMyAzLjcgOC4zIDcuOSAwIDUtNS44IDguNy0xMC44IDcu'
    b'NXoiIHRyYW5zZm9ybT0ibWF0cml4KC0uNCAwIDAgLjMgNTk2LjMgNjkuOCkiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiMwMDAwYzQiIHN0cm9rZT0iIzAwMCIgZD0iTTQyMi41IDEzN2MwIDItMiAz'
    b'LjctNC4zIDMuN3MtNC40LTEuNy00LjQtMy43IDItMy44IDQuNC0zLjggNC4zIDEuNyA0LjMg'
    b'My44em0tNi4yIDcuOWMzMS41IDYxLjQgNDguNyAxNjYuNyA1MC40IDE3MC41LjEgNC40LTQu'
    b'OCA2LjQtNy4xLjgtMi41LTMuMy0xMi43LTEwMC4yLTQ5LjEtMTcyLjItLjMtMTMuNyAzLjct'
    b'MTQuOCA4LjMtMTQuNSAzLjcuMiA4LjMgMy43IDguMyA3LjkgMCA1LTUuOCA4LjctMTAuOCA3'
    b'LjV6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjM4IC4xIC4xNSAuMyA1NjQgMzguMikiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNlMTAwMDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNyIg'
    b'ZD0iTTQ1My40IDE1MS41YzAgMSAxIDIgMi4xIDIgMS4yIDAgMi4yLTEgMi4yLTJzLTEtMS44'
    b'LTIuMi0xLjhjLTEuMiAwLTIuMS44LTIuMSAxLjh6bTMgNGExMTUyIDExNTIgMCAwIDEtMTEu'
    b'MiA5NS44YzAgMi4yIDIuMyAzLjIgMy41LjQgMy4zLTguNyAxMC40LTgwIDEwLjctOTYuNi4x'
    b'LTYuOS0xLjktNy40LTQuMi03LjMtMS45LjEtNC4xIDEuOS00LjEgNCAwIDIuNCAyLjkgNC4z'
    b'IDUuNCAzLjd6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDAwMGM0IiBzdHJva2U9IiMwMDAiIGQ9'
    b'Ik00MjIuNSAxMzdjMCAyLTIgMy43LTQuMyAzLjdzLTQuNC0xLjctNC40LTMuNyAyLTMuOCA0'
    b'LjQtMy44IDQuMyAxLjcgNC4zIDMuOHptLTYuMiA3LjljMzEuNSA2MS40IDQ4LjcgMTY2Ljcg'
    b'NTAuNCAxNzAuNS4xIDQuNC00LjggNi40LTcuMS44LTIuNS0zLjMtMTIuNy0xMDAuMi00OS4x'
    b'LTE3Mi4yLS4zLTEzLjcgMy43LTE0LjggOC4zLTE0LjUgMy43LjIgOC4zIDMuNyA4LjMgNy45'
    b'IDAgNS01LjggOC43LTEwLjggNy41eiIgdHJhbnNmb3JtPSJtYXRyaXgoLS40OCAuMTUgLjIg'
    b'LjQ4IDYyMy4zIDMxLjYpIi8+CiAgPC9nPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZTEwMDAw'
    b'IiBkPSJNNDc4LjQgNjk4YTUzLjMgNTMuMyAwIDAgMCA1My4xIDBWNTU2LjNoLTM1LjRjMTcu'
    b'NyA1My4xIDE3LjcgMTA2LjMtMTcuOCAxNDEuN3oiIHRyYW5zZm9ybT0ibWF0cml4KC41OCAw'
    b'IDAgLjYyIDkuNiAtMTAuMikiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDAwYzQiIGQ9Ik01MTMu'
    b'OCA2MDkuNWMwIDg4LjUtNDIuNSAxMDguMi00Mi41IDEyNiAxNy43IDAgMjkuNS04LjMgNDIu'
    b'NS0xOS43IDE3LjctMTcuOCAxOS40LTEwNy43IDE3LjctMTA2LjNoLTE3Ljd6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCguMzUgMCAwIC43IDEyMy41IC05MCkiLz4KICAgIDxwYXRoIGZpbGw9IiMw'
    b'MDAwYzQiIGQ9Ik00NzguNCA2MDkuNWMtLjkgNTEuNy00NC44IDk5LjYtMzYuNSAxMTAuMiA5'
    b'LjQgOS41IDM2LjUtMjEuNyA3MS45LTQgMTcuNy0xNy43IDE5LjQtMTA3LjYgMTcuNy0xMDYu'
    b'M2gtNTMuMXoiIHRyYW5zZm9ybT0ibWF0cml4KC4zNSAwIDAgLjcgMTIzLjUgLTkwKSIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZmZGYwMCIgZD0iTTUxMy44IDYwOS41YzAgODguNS00MC43IDk0'
    b'LjQtNDAuNyAxMTggMTcuNyAwIDQwLjYtMTIuOSA0MC43LTExLjcgMTcuNy0xNy44IDE5LjQt'
    b'MTA3LjcgMTcuNy0xMDYuM2gtMTcuN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4zNSAwIDAgLjQ2'
    b'IDExMi41IDUxKSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZGYwMCIgZD0iTTQ3OC40IDYwOS41'
    b'Yy0uOSA1MS43LTQzLjggOTUuNy0zNS41IDEwNi4zIDkuNSA5LjQgMzUuNS0xNy44IDcwLjkg'
    b'MCAxNy43LTE3LjggMTkuNC0xMDcuNyAxNy43LTEwNi4zaC01My4xeiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoLjM1IDAgMCAuNDYgMTEyLjUgNTEpIi8+CiAgICA8cGF0aCBmaWxsPSIjZTEwMDAw'
    b'IiBkPSJNNDc4LjQgNjk4YTUzLjMgNTMuMyAwIDAgMCA1My4xIDBWNTU2LjNoLTM1LjRjMTcu'
    b'NyA1My4xIDE3LjcgMTA2LjMtMTcuOCAxNDEuN3oiIHRyYW5zZm9ybT0ibWF0cml4KC0uNTgg'
    b'MCAwIC42MiA2MzAuNCAtMTAuMikiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDAwYzQiIGQ9Ik01'
    b'MTMuOCA2MDkuNWMwIDg4LjUtNDIuNSAxMDguMi00Mi41IDEyNiAxNy43IDAgMjkuNS04LjMg'
    b'NDIuNS0xOS43IDE3LjctMTcuOCAxOS40LTEwNy43IDE3LjctMTA2LjNoLTE3Ljd6IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCgtLjM1IDAgMCAuNyA1MTYuNSAtOTApIi8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjMDAwMGM0IiBkPSJNNDc4LjQgNjA5LjVjLS45IDUxLjctNDQuOCA5OS42LTM2LjUgMTEw'
    b'LjIgOS40IDkuNSAzNi41LTIxLjcgNzEuOS00IDE3LjctMTcuNyAxOS40LTEwNy42IDE3Ljct'
    b'MTA2LjNoLTUzLjF6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjM1IDAgMCAuNyA1MTYuNSAtOTAp'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZkZjAwIiBkPSJNNTEzLjggNjA5LjVjMCA4OC41LTQw'
    b'LjcgOTQuNC00MC43IDExOCAxNy43IDAgNDAuNi0xMi45IDQwLjctMTEuNyAxNy43LTE3Ljgg'
    b'MTkuNC0xMDcuNyAxNy43LTEwNi4zaC0xNy43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4zNSAw'
    b'IDAgLjQ2IDUyNy41IDUxKSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZGYwMCIgZD0iTTQ3OC40'
    b'IDYwOS41Yy0uOSA1MS43LTQzLjggOTUuNy0zNS41IDEwNi4zIDkuNSA5LjQgMzUuNS0xNy44'
    b'IDcwLjkgMCAxNy43LTE3LjggMTkuNC0xMDcuNyAxNy43LTEwNi4zaC01My4xeiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLS4zNSAwIDAgLjQ2IDUyNy41IDUxKSIvPgogIDwvZz4KICA8ZyBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCI+CiAgICA8cGF0aCBmaWxsPSIjOTA4Zjhh'
    b'IiBzdHJva2Utd2lkdGg9IjQuNSIgZD0ibTE5OC42IDc4LTg5LjcgMzUuNCA4OS43IDM1LjQg'
    b'NDQuOC0xNy43IDIyLjQgMTcuNyAyMi40IDM1LjQgMjIuNS0zNS40IDIyLjQtMTcuN0gxNTM1'
    b'Vjk1LjdIMzMzbC0yMi40LTE3LjhjMC0xNy43IDQuNy0zNS40IDIyLjUtMzUuNGg4OS42YzAt'
    b'MTcuNy00NC44LTUzLjEtMTM0LjUtNTMuMS04OS42IDAtMTM0LjUgMzUuNC0xMzQuNSA1My4x'
    b'aDg5LjdjMTcuNyAwIDIyLjQgMTcuNyAyMi40IDM1LjVsLTIyLjQgMTcuNy00NC45LTE3Ljh6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCguMTIgMCAwIC4yMiAyMTcuOCAzMjQuNCkiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNiNzRkMDAiIHN0cm9rZS13aWR0aD0iMS44IiBkPSJNMjA0LjMgOTUuN0g1'
    b'NDF2MTcuN0gyMDQuNHptMC0xNy44SDU0MXYxNy44SDIwNC40em0wLTE3LjdINTQxVjc4SDIw'
    b'NC40em0wLTE3LjdINTQxdjE3LjdIMjA0LjR6bTAtMTcuN0g1NDF2MTcuN0gyMDQuNHptMC0x'
    b'Ny44SDU0MXYxNy44SDIwNC40em0wLTE3LjZINTQxVjdIMjA0LjR6IiB0cmFuc2Zvcm09Im1h'
    b'dHJpeCguMjggMCAwIC4yNyAyMTYgMzM0LjYpIi8+CiAgICA8cGF0aCBmaWxsPSIjOTA4Zjhh'
    b'IiBzdHJva2Utd2lkdGg9IjMuMyIgZD0ibTQyMy4yIDYwLjIgMTM3LjggMTI0aDE5LjdMNDQz'
    b'IDYwLjNoLTE5Ljd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMjUgMCAwIC4yNyAxNzEuOSAzMTUu'
    b'MikiLz4KICAgIDxwYXRoIGZpbGw9IiM5MDhmOGEiIHN0cm9rZS13aWR0aD0iMy4zIiBkPSJt'
    b'NDIzLjIgNjAuMiAxMzcuOCAxMjRoMTkuN0w0NDMgNjAuM2gtMTkuN3oiIHRyYW5zZm9ybT0i'
    b'bWF0cml4KC4yNSAwIDAgLS4yNyAxNzEuOSAzODIuMikiLz4KICAgIDxwYXRoIGZpbGw9IiM5'
    b'MDhmOGEiIHN0cm9rZS13aWR0aD0iMy4xIiBkPSJNNDI1LjIgNjAuMnYxMjRoMTcuN3YtMTI0'
    b'aC0xNy43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjI4IDAgMCAuMjcgMTU5LjYgMzE1LjIpIi8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjOTA4ZjhhIiBzdHJva2Utd2lkdGg9IjMuMyIgZD0ibTQyMy4y'
    b'IDYwLjIgMTM3LjggMTI0aDE5LjdMNDQzIDYwLjNoLTE5Ljd6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCguMjUgMCAwIC4yNyAyMTYuMiAzMTUuMikiLz4KICAgIDxwYXRoIGZpbGw9IiM5MDhmOGEi'
    b'IHN0cm9rZS13aWR0aD0iMy4zIiBkPSJtNDIzLjIgNjAuMiAxMzcuOCAxMjRoMTkuN0w0NDMg'
    b'NjAuM2gtMTkuN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4yNSAwIDAgLS4yNyAyMTYuMiAzODIu'
    b'MikiLz4KICAgIDxwYXRoIGZpbGw9IiM5MDhmOGEiIHN0cm9rZS13aWR0aD0iMy4xIiBkPSJN'
    b'NDI1LjIgNjAuMnYxMjRoMTcuN3YtMTI0aC0xNy43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjI4'
    b'IDAgMCAuMjcgMjM4LjQgMzE1LjIpIi8+CiAgICA8cGF0aCBmaWxsPSIjOTA4ZjhhIiBzdHJv'
    b'a2Utd2lkdGg9IjMuMSIgZD0iTTQyNS4yIDYwLjJ2MTI0aDE3Ljd2LTEyNGgtMTcuN3oiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC4yOCAwIDAgLjI3IDIwNCAzMTUuMikiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiM5MDhmOGEiIHN0cm9rZS13aWR0aD0iMy4xIiBkPSJNNDI1LjIgNjAuMnYxMjRoMTcu'
    b'N3YtMTI0aC0xNy43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjI4IDAgMCAuMjcgMTk0IDMxNS4y'
    b'KSIvPgogIDwvZz4KICA8ZyBmaWxsPSIjZmZkZjAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAgPHBhdGggZD0iTTY1NS41IDM5'
    b'Ni45YzAgODgtNTUuNiAxNTkuNC0xMjQgMTU5LjRzLTEyNC03MS40LTEyNC0xNTkuNCA1NS41'
    b'LTE1OS41IDEyNC0xNTkuNSAxMjQgNzEuNCAxMjQgMTU5LjR6bS0xNy43IDBjMCA3OC4yLTQ3'
    b'LjYgMTQxLjctMTA2LjMgMTQxLjctNTguNyAwLTEwNi4zLTYzLjUtMTA2LjMtMTQxLjcgMC03'
    b'OC4zIDQ3LjYtMTQxLjggMTA2LjMtMTQxLjggNTguNyAwIDEwNi4zIDYzLjUgMTA2LjMgMTQx'
    b'Ljh6IiB0cmFuc2Zvcm09Im1hdHJpeCguNTggMCAwIC42MiA5LjYgLTEwLjIpIi8+CiAgICA8'
    b'cGF0aCBkPSJNNTc5LjggMjUwYy0xNC45LTguMS0zMS4yLTEyLjYtNDguMy0xMi42cy0zMy40'
    b'IDQuNS00OC4zIDEyLjVsNyAxNi40YTgyLjggODIuOCAwIDAgMSA4Mi43IDBsNi45LTE2LjR6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCguNTggMCAwIC42MiA5LjYgLTEwLjIpIi8+CiAgICA8cGF0'
    b'aCBkPSJNNTc5LjggMjUwYy0xNC45LTguMS0zMS4yLTEyLjYtNDguMy0xMi42cy0zMy40IDQu'
    b'NS00OC4zIDEyLjVsNyAxNi40YTgyLjggODIuOCAwIDAgMSA4Mi43IDBsNi45LTE2LjR6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCguNTggMCAwIC0uNjIgOS44IDQ3OS4zKSIvPgogIDwvZz4KICA8'
    b'cGF0aCBmaWxsPSIjYTdjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zNzkuNiAyMzUu'
    b'OWMwIDQ4LjUtMjcuNyA4Ny44LTYxLjcgODcuOHMtNjEuNi0zOS4zLTYxLjYtODcuOCAyNy42'
    b'LTg4IDYxLjYtODggNjEuNyAzOS40IDYxLjcgODh6Ii8+CiAgPHBhdGggZmlsbD0iI2FmZmY3'
    b'YiIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0'
    b'IiBkPSJNNjM3LjggMzk2LjljMS4xIDI2LjYtNC42IDM5LjYtMTEuOSA2Ny4zLTEuOSAzLTEx'
    b'LTYuNS0xNi40LTExLjJzLTcuOCA0LjItMTQuNi0zYy02LjctNy40LTExIDItMTYtNC4ycy01'
    b'MS4zLTctNTEuMy03LjZjNC42LTIuMiAyOC4yLjIgMjQuNC0xMS4xLTQuMy0xMS44LTMxLS40'
    b'LTM0LjYtMTUuNC0yLjUtMTUtNTMuNi0xNS42LTU3LjMtMTkuMiAxLjUgNS42IDM5LjggOCAz'
    b'OC45IDIyLjUtLjkgNi0zNy43IDcuNy00MS4zIDEyLjctMyA2LjMgMjktMS43IDMwLjEgNiAw'
    b'IDMuMi00LjcgMC0yMS4zIDUtOC40IDIuNSAxNS40IDEwLjMgNi40IDE0LjYtOSA0LjMtMjgu'
    b'MyA2LjItMjcuNSA4IDMgOSA0NC43IDE5LjYgNDAuNiAyMS4xLTE0LjggNi42LTIyLjYgMTAu'
    b'OS0yOS43IDE0LjdhMTY3LjkgMTY3LjkgMCAwIDEtMzEuMS0xMDAuMmMzMS43LTExLjQgMjUt'
    b'MTMuOCA4My42LTEzLjhzNzggMi4zIDEyOSAxMy44eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjU4'
    b'IDAgMCAuNjIgOS42IC0xMC4yKSIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTYzNy44IDM5'
    b'Ni45Yy04IDAtMTYuNCAzLjQtMjUgMy40LTguNyAwLTE3LjUtMy41LTI2LjUtMy41cy0xOS4z'
    b'IDQuNi0yOC41IDQuNmMtOS4zIDAtMTcuNC00LjUtMjYuNy00LjVzLTE4LjYgMy40LTI3Ljgg'
    b'My40LTE4LjMtMy41LTI3LjItMy41LTE3LjcgMy41LTI2LjIgMy41LTE2LjgtMy41LTI0Ljct'
    b'My41YzAtMTkuNSAzLTM4LjEgOC40LTU1LjEgMjcgMiAxMS0xNS43IDI3LTE1LjdhMzMgMzMg'
    b'MCAwIDEgMjUuMyA5LjhjMi40IDAgMTQuNC0xMS40IDI3LjktOS44IDEzLjQgMS42IDguNSAy'
    b'Ny4zIDI2LjQgMjguNiA5IDYuOCAxNC4zIDExLjEgMjYuNyAxMy45IDE3LjcgMS42IDY4LjQt'
    b'Mi41IDY4LjctLjJhMTg4LjIgMTg4LjIgMCAwIDEgMi4yIDI4LjZ6IiB0cmFuc2Zvcm09Im1h'
    b'dHJpeCguNTggMCAwIC42MiA5LjYgLTEwLjIpIi8+CiAgPHBhdGggZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNTQ5LjkgNDc0YzAt'
    b'NS43IDEzLjUtOS41IDEzLjUtMTguNnMtMTItOS4zLTEyLjQtMTcuOGMtLjItMy41IDEwLjMt'
    b'NyAxNC45LTcuNHM4LjUgNy40IDguNSA5LjEtNC43LTQuMi04LjYtNC4zLTEyLjMuNi0xMi4z'
    b'IDIuM2MwIDMuNCAxNC44IDcuNiAxMy43IDE5LTEuMSAxMS4yLTEyLjcgMTQuNi0xMi43IDE4'
    b'czUgMTIuOCA1IDEyLjgtOS43LTcuNS05LjctMTMuMnoiIHRyYW5zZm9ybT0ibWF0cml4KC4y'
    b'IDAgMCAuNDggMjE3LjIgNTkuNSkiLz4KICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik01NDkuOSA0NzRjMC01LjcgMTMu'
    b'NS05LjUgMTMuNS0xOC42cy0xMi05LjMtMTIuNC0xNy44Yy0xLTQgMTEuOC02LjYgMTYuNC02'
    b'LjlzMTAgOCAxMCA5LjYtNS40LTUuMi05LjMtNS4zLTE0LjYuNi0xNC42IDIuM2MwIDMuNCAx'
    b'NC44IDcuNiAxMy43IDE5LTEuMSAxMS4yLTEyLjcgMTQuNi0xMi43IDE4czUgMTIuOCA1IDEy'
    b'LjgtOS43LTcuNS05LjctMTMuMnoiIHRyYW5zZm9ybT0ibWF0cml4KC0uMiAwIDAgLjQ4IDQ0'
    b'NS44IDU5LjEpIi8+CiAgPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzMzIDI2NC45'
    b'YzAgMS4zLS43IDIuNC0xLjUgMi40cy0xLjQtMS4xLTEuNC0yLjUuNi0yLjQgMS40LTIuNGMu'
    b'OCAwIDEuNSAxLjEgMS41IDIuNXptMTcgOWguNHYxOS41aC0uNXptNC4xLTEuNmguNVYyOTJo'
    b'LS41eiIvPgogIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTM1Mi42IDI4MS4ydi0u'
    b'NWw0IC43di41eiIvPgogIDxwYXRoIGZpbGw9IiNiNzRkMDAiIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQ5Ny4zIDQ3OHMyNiAx'
    b'MS40IDMxLjcgMTguMmM1LjYgNi44IDMuNCA2LjggMy40IDYuOGw1Ny43IDIuM2MwLTMuNCAx'
    b'MC4yLTMuNCAxMi41LTExLjQgMi4zLTcuOSAyLjMtMTAuMiAyLjMtMTAuMmwtMTguMSA1Ljcg'
    b'MS0xMC4ySDU3MmwtMi4zIDEwLjItMzQtMS4xTDUzOCA0NjFsLTYuOCAxLjEtMSAyNmMtMS4y'
    b'IDAtMzEuOC03LjktMzMtMTAuMXoiIHRyYW5zZm9ybT0ibWF0cml4KC41OCAwIDAgLjYyIDcg'
    b'LTkuNSkiLz4KICA8cGF0aCBmaWxsPSIjZmVkZTAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0'
    b'cm9rZT0iI2ZlZGUwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik00NDAuNSAzMTYuM3MzNy43'
    b'LTExLjIgOTIuMS0xMC40IDkyLjEgMTIuOCA5MS4zIDEyLjgtMTAuNC0xOC40LTEwLjQtMTgu'
    b'NC0zOC40LTEwLjUtODEuNy0xMS4zYy00My4yLS44LTgwLjkgOC04MCA4LjhsLTExLjMgMTgu'
    b'NXoiIHRyYW5zZm9ybT0ibWF0cml4KC41OCAwIDAgLjYyIDkuNiAtMTAuMikiLz4KICA8cGF0'
    b'aCBmaWxsPSIjMzhhOWY5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Im0zMDYgMTY5LjggMTMu'
    b'Ni0uMi4yIDcuOS0xMy42LjN6bS0zMS4yIDQuM0wyNzAgMTgybDE2LjItMi0xLjMtNy43LTEw'
    b'LjEgMnptMTMuNy0zIDEzLjYtMS4xLjYgNy44LTEzLjUgMS4yem00OC45LS43LTEzLjUtMS0u'
    b'NSA4IDEzLjUuOHptMjkuMiA1IDQuOSA5LjYtMTQuNi0zLjYgMS42LTcuNyA4IDEuNnptLTEx'
    b'LjgtMy0xMy40LTEuNy0xIDcuOCAxMy41IDEuOHoiLz4KICA8cGF0aCBmaWxsPSIjZmZkZjAw'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQi'
    b'IGQ9Im01MzIuNiAzMjMuNS0yLjUtMTMuNS03LjYgMTEuNSAyLjgtMTMuNS0xMS4zIDcuNyA3'
    b'LjYtMTEuMy0xMy40IDIuOCAxMS41LTcuNi0xMy41LTIuNSAxMy41LTIuNi0xMS41LTcuNiAx'
    b'My40IDIuOC03LjctMTEuMyAxMS40IDcuNy0yLjgtMTMuNSA3LjYgMTEuNSAyLjUtMTMuNSAy'
    b'LjYgMTMuNSA3LjUtMTEuNS0yLjcgMTMuNSAxMS4zLTcuNy03LjcgMTEuMyAxMy41LTIuOC0x'
    b'MS41IDcuNiAxMy41IDIuNi0xMy41IDIuNSAxMS41IDcuNi0xMy41LTIuOCA3LjcgMTEuM0w1'
    b'NDAgMzA4bDIuOCAxMy41LTcuNi0xMS41eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjU4IDAgMCAu'
    b'NjIgOS42IC0xMC4yKSIvPgogIDxwYXRoIGZpbGw9IiNmZmRmMDAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTU0NyAyOTMuOWMw'
    b'IDkuMy02LjYgMTYuOC0xNC44IDE2LjhzLTE0LjgtNy41LTE0LjgtMTYuOFM1MjQgMjc3IDUz'
    b'Mi4yIDI3N3MxNC44IDcuNiAxNC44IDE3eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjU3IDAgMCAu'
    b'NSAxOC4zIDIxLjgpIi8+CiAgPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzIwLjcg'
    b'MTcwLjZjMCAuNS0xLjMgMS0yLjggMXMtMi44LS41LTIuOC0xIDEuMi0xIDIuOC0xIDIuOC40'
    b'IDIuOCAxem02IDBjMCAuNS0uOSAxLTIgMXMtMi4yLS41LTIuMi0xYzAtLjYgMS0xIDIuMS0x'
    b'czIuMS40IDIuMSAxeiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIxcHQiIGQ9Im01MjkuNCAyOTcuOS44LjhjLTEuOS0yLTEtMS4yIDEuNiAz'
    b'LjIgMi40LS41IDMuMS0xLjQgNC44LTIuNCIgdHJhbnNmb3JtPSJtYXRyaXgoLjU2IC0uMTgg'
    b'LjE3IC42IC0yNi43IDkwLjYpIi8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9IjFwdCIgZD0ibTUyNy44IDMwNC4zLjguOGMtMS45LTItMS0xIDMu'
    b'MiAxLjYgNCAuNSA4LjEtMS4yIDEwLjUtNCIgdHJhbnNmb3JtPSJtYXRyaXgoLjU4IDAgMCAu'
    b'NjIgOC43IC0xMC4yKSIvPgogIDxwYXRoIGZpbGw9IiNiN2UxZmYiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgZD0iTTI4MS40IDE5NC44czEgOC01LjEgMThjLTYgOS45LTUuMSA2LjQtNS4xIDYu'
    b'NHMyLjggNS41IDIuMyA1LjUtNC43LTUtNC43LTVsLTUgNS41czQuNi04LjUgNC4xLTguNS0x'
    b'LjQtMy0xLjQtM2wzLjctMS41czUuNi0xMC40IDUuNi05LjktMTYuNyAxMS40LTE2LjcgMTEu'
    b'NGwyMi4zLTE4Ljh6bTMuNyAzYy0uNSAwIDIuMyA4IDQuNyAxMiAyLjMgNCAyLjMgOC45IDIu'
    b'MyA4LjlsNy45IDQtMTAuMi0xNS40IDYuNSAyLjQtMTEuMi0xMS45em0wIDIwLjlzNS42IDYg'
    b'NiA4IC41IDYuNC41IDYuNGwtMi4zLTUtMy4zIDQuNXMyLjQtNyAxLjktNy41LTMuNyAyLjUt'
    b'My43IDIuNSAxLjQtNCAxLjQtNC40IDAtMy0uNS00LjV6bS0yNy45IDEzLjljMS45LTEuNSA1'
    b'LjYtMi41IDUuNi0yLjVzLTIuMyA0LTIuOCA0LTEuOCAwLTIuOC0xLjV6bTY0LjEtMjEuOHMx'
    b'Mi4xIDcuNCAxMi4xIDcuOS03LjktMy41LTcuOS0zLjVsLTQuMi00LjR6bS0yMS44LTE1LjVj'
    b'MSAuNSAxNy43IDE0LjQgMTcuMiAxNC40cy03LjQtNC03LjQtMy40djMuNGwtMy44LTcuOS0u'
    b'OSAzLTUtOS41em00LjIgMjIuNCA0LjYgOS40IDQuNy0xcy04LjgtOC40LTkuMy04LjR6bTE0'
    b'LjQtNiAuNSA5czIuNyAyLjUgMi43IDItMi43LTEwLjUtMy4yLTExeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiM5ODQwMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTE4Mi42IDg5LjVzMjEtMTEu'
    b'NiA0NC45LTIwLjJhMzAzLjggMzAzLjggMCAwIDEgNTQuMi0xNC40YzcgMCAxOS4yIDE3Ljgg'
    b'MjEuMiAxNy44czEwLjEtNSAyMC4zLTUgMTYuMSA4IDE4LjIgOGgxOC4yYzIgMC02LjEtMTku'
    b'OCAwLTE4LjggMyAuNSAyOC44IDQuNSA1Mi44IDEyLjIgMjQgNy44IDU4IDIxLjYgNTggMjEu'
    b'NlM0MTQuOSA5OCA0MDAgOTUuOWMtMiAxIDAgMTMtMyA3LjctNC42LTEtMjEuNy0zLjctMjQu'
    b'Ny0zLjdzLTguNyAzLjQtMTYuOCA1LjRjLTggMi0xOC4yIDUtMTguMiA1bDEzLjIgMjAuNy0x'
    b'Ni4yIDhzLTEwLjEtMjMuOC0xNC4yLTIzLjgtNiAxNi44LTExLjEgMTUuOGMtNS0xLTctMTUu'
    b'OC0xMS4xLTE5LjgtNC0zLjktMjUuNC01LjQtMzMuNS03LjMtOC0yLTIxLjEtMy41LTI4LjIt'
    b'NS41LTctMi0xNC4yIDUtMTcuMiA1czQtNiAxLTctNSAzLTcgMy0yMy4zLTQtMjUuMy01IDUt'
    b'NC45IDMtNC45aC04LjF6Ii8+CiAgPHBhdGggZmlsbD0iZ3JheSIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2U9IiM3NzI2MDAiIHN0cm9rZS13aWR0aD0iMy43IiBkPSJNNDYzLTY1YzAg'
    b'MjEuMi0yMC42IDM4LjQtNDUuOSAzOC40UzM3MS4zLTQzLjggMzcxLjMtNjVzMjAuNS0zOC4z'
    b'IDQ1LjgtMzguM1M0NjMtODYuMSA0NjMtNjV6IiB0cmFuc2Zvcm09Im1hdHJpeCguMjIgMCAw'
    b'IC4yNiAyMzEuNiA5Ni41KSIvPgogIDxwYXRoIGZpbGw9IiM5ODQwMDAiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgc3Ryb2tlPSIjNzcyNjAwIiBzdHJva2Utd2lkdGg9IjUuMyIgZD0iTTI4NC43'
    b'LTYwYzYuNy02LjYgMTUtMTYuNiAzNi43LTE2LjYgNS0xLjcgNS0xMS43IDE2LjYtMTEuNyAx'
    b'MS43IDAgOC4zIDEwIDE2LjcgMTMuNCA4LjMgMy4zIDc2LjYtMy40IDc2LjYtMy40czYuNiA1'
    b'IDYuNiAxMS43LTUgMTEuNi02LjYgMTEuNi02OC4zLTUtNzMuMy0zLjNjLTUgMS43LTguMyAz'
    b'LjMtMjAgMy4zLTExLjYgMC0xNS0xMS42LTIzLjMtMTEuNnMtMTYuNi0xLjctMzAgNi43eiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLjI3IDAgMCAuMzIgMjA1LjQgMTAwLjcpIi8+CiAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNzcyNjAwIiBzdHJva2Utd2lkdGg9IjMuNSIgZD0iTTQ4'
    b'Ny45LTc2LjZoMjYuNmM5LjYuMSAxMi45IDMgMjEuNyAzLjNoMjMuM2M4LjUtLjMgMTMtMi4z'
    b'IDIxLjYtMy4zIDE0LjUtLjIgOS42LTEuMyA2LjctMTAtMi42LTYuNS0zLTkuNi02LjctMTMu'
    b'My0xLjQtOC00LjYtMTAuOC01LTIwLTEuNS03LTQuMy0xMS43LTEuNi0yMCAzLjggNS43IDUu'
    b'MyA4IDE1IDguNCAxMCAwIDEzLjktLjMgMjAgMy4zIDQuNiA0LjkgMTAuOCAzLjMgMjAgMy4z'
    b'IDcuNiAxLjQgOC45IDUuMyAxNC45IDguMyA3LjEgNCAxMS43IDUgMjEuNiA1IDggMS41IDE1'
    b'IDIuNiAyMCA1IDQuMyA1LjEgMTEgNi40IDIwIDYuNyA1IDAgOS0uNSAxMy4zLTEuNyA3Ljcu'
    b'NCAxNS41IDAgMjUgMCA2LjIgNy4yIDcuNiA5LjkgMTguMyAxMCA3LjQgNS4yIDEzLjYgNiAy'
    b'MCA4LjNoMjVjOSAuNyAxMS44IDQuNCAyMCA2LjdhMjAwLjkgMjAwLjkgMCAwIDAgMjEuNiA4'
    b'LjMgMTA4IDEwOCAwIDAgMCAyMS43IDEuN2M2LjEgMy4yIDEzLjYgMy40IDE4LjMgNi42IDYu'
    b'OSAxLjUgMTYuMyAzLjMgMjEuNiA1IDguOCAxLjIgMTIuMiA0IDIwIDUgNi43IDItMi4yIDMu'
    b'Ni02LjcgNS05LjgtLjMtMTAuNS00LTIwLTUtNS0yLjktMTIuNi0yLjUtMjAtNWgtMS42YzYu'
    b'NiA0IDEzIDYuNSAxMCAxMy40LTguNSAwLTE1LjQtMS4xLTIzLjMtMS43LTguNC0xLjYtMTIu'
    b'Mi0zLjMtMjEuNi0zLjMgOS40LTIuMyAxMS44LjIgMTguMyAzLjMgMi40IDgtMi44IDUtMTEu'
    b'NyA1LTcuNi0yLjctMTIuMi02LTIxLjYtNi43aC0yMGM5LjkuNCAxMiA0LjEgMTguMyA4LjQu'
    b'NSAyLjYtLjEgMi40LTUgMy4zLTUuMi00LjUtMTEuOS02LTIwLTguMy03LjktLjMtMTYuMi0x'
    b'LTIzLjMtMy40LTQuOS0uMy00LjEtNi4xIDYuNyAzLjQgNi41IDMuOCA4LjggNyA4LjMgMTAt'
    b'OC42LTIuMi0xMi44LTUuNi0xOC4zLTguNGE2MS4zIDYxLjMgMCAwIDAtMjMuMy0zLjNjLTgu'
    b'Ni0yLjMuOS0zLjYgNi42IDUgMTIuNCA4LjgtMS42IDUtNi42IDMuMy03LjUtMi4xLTE1LjMt'
    b'NS4yLTIxLjctNi42LTUtMS41LTkuNC0yLjktMTUtMy40IDguNy44IDExLjYgMy45IDE1IDEw'
    b'IDguOCA2LS40IDMuMS04LjMgMS43LTUtNC40LTExLjUtNi43LTE1LTExLjctOC4zLTQuMS04'
    b'LjYtOS0zLjMgMS43IDEuMyAzLjQgMSAxMC44IDEuNiAxMS43LTYuMS02LjctNC44LTguNC0x'
    b'MS42LTguNC00LjctMy4yLTExLjUtNS43LTE1LTEwLTYuNC0uNi02LjgtMi45LTEzLjMtNSA1'
    b'LjMgNi4zIDEyLjQgMTIuNSAxNi42IDE4LjQgNy42IDQuMiA5LjcgOCAxNSAxMS42IDIuMSAz'
    b'LjcgOCA2LjcgMS43IDEuNy03LjItNy0xMi41LTguNy0yMy4zLTEzLjMtNi4yLTUtOC40LTct'
    b'MTUtMTEuNy05LTIuOS01LjUtNC41IDAgNSA2LjMgNS44IDExLjEgMTIuMiAxNi42IDE2Ljdh'
    b'NjcuOCA2Ny44IDAgMCAwIDE1IDEzLjNjMS41IDIuMiA2IDIuNiAwIDMuMy01LTQuNi0xMi40'
    b'LTcuNS0xOC4zLTExLjctOC4zLTIuMy0xMi4yLTYuNi0xOC4zLTExLjYtNC01LjktMTAuNC0x'
    b'MC40LTE1LTE1LTkuNi0zLjggMS45IDMuNiA1IDguMyAyLjEgNi4xIDQuOCAxMSA2LjYgMTYu'
    b'NyAyLjggNS41LTguNC0xLjMtMTEuNi0zLjNhNTcgNTcgMCAwIDAtMjEuNy04LjQgMjk4IDI5'
    b'OCAwIDAgMC0yMC0zLjNjLTcuNS0yIDQuMSA0LjggOC40IDExLjcgOC40IDcuOS04LjMgMS40'
    b'LTEzLjMgMGExMjUgMTI1IDAgMCAwLTI1LTEuN2MtMTAuNy42LTMgMiAwIDYuNiAzLjMgMi42'
    b'IDUuNiA4IDUgMTAtNy0xLTEzLTMtMjEuNy0zLjMtNyAyLjMtMTUuMyAxLjctMjMuMyAxLjct'
    b'LjMgNC4yIDEuNS42IDUgNSA1LjggMi4zIDkuNiA1LjEgOC40IDguM2gtNDguM2MtNS4zIDEu'
    b'NCAxLjEuNyA1IDYuNy0yLjIgNS40LTUgMy4zLTExLjcgMy4zLTQuNS0xLjgtMTMuNi0yLjYt'
    b'MTguMy01LTQuNyAwLTQuMy0xLjItOC4zLTEuNyAxNCAxMCA3IDcuNSAxNSAxNSAxLjMuNSA0'
    b'LjUgMS43IDEuNiAxLjdNMzcxLjMgNzMuM2MtMSAwLTMuMi01LjQtNi42LTEwLTIuNC02LTUu'
    b'NC0yLjYtOC40LTExLjcuNC05LjQuNy0xMSAwLTIwLTYuOC00LjgtOS43LTYuMi0xNS0xNS04'
    b'LjQtNyAxLjMtMTkgMi45LTI3LjgtNy40LTEuNi0xMSAxMS41LTIyLjMgMTYuMi04LjIgNS41'
    b'LTEtMTEuNC01LTIxLjItMi43LTEzLjktMTAuOCA3LTEzLjggMTIuOS01LjUgMy43LTcuMiA4'
    b'LjUtMTUgMS42IDAtNS4xIDQuOS0xOS41IDIuOC0yMi4zLTcuOCAzLjktMTggMTUuNS0yNi4x'
    b'IDE3LjMtOC4yLTEuNyAxLjctMTQuOCAxLjctMjQuNS0zLTEtMTQuNyAyNS44LTE5LjUgMjZz'
    b'LTIuNy0yNi01LTI1LjRjLTMuNSA1LTEwLjYgMTUuNC0xNS41IDE5LTkuNS0xLjMgMS40LTE3'
    b'LjUgMi44LTIzLjUgMS42LTcuMi04LjkgMTMuOC0xNC41IDE1LjEtNC4xIDMuNi0xMi4yIDYt'
    b'MTUgNi43IDMuMi02LjIgMTktMTguNyAxOC0yMi4zLTkuMy4zLTIzLjQgMTIuNS0zMS4zIDE0'
    b'LTUuMiAwLTEyLjQgMS43LTEzLjMgMS42LjQtOCAxOS40LTE0LjYgMjIuNC0xOS41LTkuMyAx'
    b'LjUtMjcuMiA5LjctMzIuNCAxNi4yLTYuMiAxLjMtMTQgMy0yMCAwIC45LTcuNSAxNC45LTIy'
    b'IDE4LTI2LjgtOC41IDMuNy0xMi43IDYuNi0yMS43IDguMy0xLjcgMS43LTYuNSA1LjMtNSAx'
    b'LjcgMi43LTcgNi43LTEwIDEwLTE1LTcuNSAxLjQtMTAuMyA1LjctMTguMyAxMC01LjEuMi0x'
    b'OS43IDE0LjktMjQuNiAxNS4xYTY5LjEgNjkuMSAwIDAgMS0yOC4zIDEzLjNjLTcuNiAxLjQt'
    b'MTEuMyAzLTE1IDYuNyAzLjgtNi43IDkuNi0xMyAxNS0xNi42YTI5LjggMjkuOCAwIDAgMSAx'
    b'NS0xMy40YzEuOS0yLjMgNy4xLTIuOSAxLjYtMy4zLTQuNyA0LjItMTIuNyA5LTE2LjYgMTEu'
    b'Ny01LjEgMy4yLTExIDYuNC0xMy40IDUgMi43LTcuMiA3LjUtOSAxMS43LTE1IDguOC01LjYg'
    b'MC0yLTYuNyAwLTQuMyAzLjgtMTIgNi43LTE4LjMgMTAtNyAxLjgtMTEuNyA2LTIwIDguMyAw'
    b'IDIuNCAyLjQtNC4zIDMuNC02LjcgNi44LTcuNCA4LjYtOS41IDE2LjYtMTEuNiAyLTIuOSA0'
    b'LjQtMS43LTEuNi0xLjctNC42IDQtMTAuOCA2LjItMTYuNyAxMC01LjkgMS4zLTEzLjYgMS43'
    b'LTIxLjYgMS43LTEwLjQgMS4yLTkuNSAyIDAtMy40IDUuMy01IDkuNy0zLjcgMTAtMTAtNi4z'
    b'IDQuNi0xNCA4LTIxLjcgMTEuNy02LjQuMi04LjEgMS43LTE1IDEuNyAzLjMtMy40IDUuMy03'
    b'LjcgMTAtMTAgNy03LjctNC40LTEuNS02LjcgMGgtMjVjLTQuNCA1LjYtLjIgMCAzLjQtMy40'
    b'IDQuMy0yLjIgOC44LTUuMSA4LjMtNi42LTUgNC4zLTEwLjcgNi4zLTE1IDEwLTQuNiAxLjQt'
    b'MTAgMi0xMCAzLjMgMy43LTUuMyA5LjYtOC42IDEzLjQtMTMuMyA1LjYtMS4yIDEwLjQtMyAx'
    b'MS42LTVoLTIzLjMgMTYuNmM4LjUgMCAxNS43LS44IDIzLjQtMS43IDEzLjItMi4yLTEuMi0z'
    b'LjMtOC40LTMuMy0xLjMtMi42IDQuMi00IDEwLTVDLTYuNy02OS0uNC03MS4xIDUtNzMuM2E0'
    b'NS4yIDQ1LjIgMCAwIDAgMTMuMy02LjZjLTUgLjItNSAxLjQtMTAgMS42IDcuNS0uNSAxMi44'
    b'LTEuNiAyMS43LTEuNmEyMzkgMjM5IDAgMCAwIDIxLjYtOC4zYzMtMy42IDQuMi0zLjQtMy4z'
    b'LTMuNCA2LjctMi4xIDE2LjItMy4yIDIxLjYtNWE5NCA5NCAwIDAgMCAyMC02LjZjNC45LTMu'
    b'MyA3LjctNy4yIDEzLjMtMTAgNi41IDQuNCA2LjYgNSAxOC4zIDUgOS40LS4xIDE1LjItMi40'
    b'IDIwLTYuNyA3LjItMiA4LjUtNS40IDE2LjctNi42YTEzNCAxMzQgMCAwIDAgMjMuMyAxLjZj'
    b'OC0yLjEgMTUuNy02IDIxLjYtMTAgNS4xLTIuNSAxMS4yLTYuMSAxNi43LTguMyA2IDMuMSAx'
    b'MC44IDUuNiAxOC4zIDYuNyA3LjctMS4yIDExLjgtNSAxOC4zLTYuN2EyOCAyOCAwIDAgMSAx'
    b'NS04LjNjOS43LTQuOCA5IDEuNSAxMy4zIDYuNiA1IDUuMiAxMS40IDIuNyAxOC4zIDUgMy45'
    b'IDYgNi43IDEwIDExLjcgMTMuMyAzLjkgNC44IDguNSA2IDE2LjcgNi43IDMgNCAuNiA2Ljgg'
    b'Ni42IDguMyAyLjQgMi42IDYuNSAzLjYgMTAgNSIgdHJhbnNmb3JtPSJtYXRyaXgoLjI3IDAg'
    b'MCAuMzIgMjA1LjQgMTA0LjkpIi8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNzgy'
    b'NjAwIiBzdHJva2Utd2lkdGg9IjMuMSIgZD0iTTQ2OC43IDMwLjh2LjhjMC0yLjMgMC0xIDEu'
    b'NyAzLjQuNiAzLjYtLjggMy4yLTIuNSA1LjgtLjMgMy43LS44IDYuNC0uOCAxMC44LS42IDMu'
    b'Ni0yLjYgNy00LjIgMTAtMS42IDMuMS04LjUgNC45LTguMyA5LjItNCAxLjEtNC4xLTEuNS00'
    b'LjItNS45LTIuNC0yLjctMy4yLTYuNC01LTEwLTEtMy40LTMuNC02LTUtMTAtMi40LTMuNy00'
    b'LjUtNC44LTYuNi05LjEtLjktMi0uNy00LjYtMi41LTUuOC0yLjctMy41LTQuNS00LTkuMi00'
    b'LjItMy42LjgtNSAyLjQtOC4zIDMuMy0yLjYuOS03LjYuNi0xMC44IDEuNy0uOCAxLjMgMS42'
    b'IDIgMi41IDUtMi4yIDEuOC0zIDQuOS00LjIgNy41LTIgMi41LTMuMyAzLjctNC4yIDcuNSAx'
    b'LjQgMi4zLjIgNS40LTEuNiA3LjUtLjYgMy44LTIuNSA1LjktMy40IDkuMS0yLjYgMS45LTMu'
    b'NiAzLjYtNS44IDYuNy0xLjkgMi43LTMuNiAyLjUtOC4zIDIuNS0zLjctMS00LjItMy03LjUt'
    b'NC4yLS4zLTEtLjYtMS4zLTEuNy0xLjYiIHRyYW5zZm9ybT0ibWF0cml4KC4yNyAwIDAgLjMy'
    b'IDIwNS40IDEwNC45KSIvPgogIDxwYXRoIGZpbGw9IiM4MTJlMDAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgZD0iTTMwNy42IDEyNS41cy0uNCA1LTMuNiA4LjMtOS44IDcuMS05LjggNy4xIDgu'
    b'OS00LjIgOS44LTMuM2MxIDEtNS43IDguMy01LjcgOC4zczguNy03LjcgOS44LTcuNyAzLjYg'
    b'Ny41IDQuNiA3LjNjLjktLjItMi05LjUtMS42LTExIC40LTEuNCAwLTkuMyAwLTkuM2wtMy40'
    b'LjN6bTIwLjUtLjZzLS40IDUuMy0zLjYgOC44LTkuOCA3LjYtOS44IDcuNiA4LjktNC41IDku'
    b'OC0zLjVjMSAxLTUuNyA4LjgtNS43IDguOHM4LjctOC4yIDkuOC04LjIgMy42IDggNC42IDcu'
    b'OGMuOS0uMi0yLTEwLjItMS42LTExLjcuNC0xLjYgMC0xMCAwLTEwbC0zLjUuNHptLTI4Ljct'
    b'NDhjMCAuOS0xIDEuNy0yLjEgMS43cy0yLjItLjgtMi4yLTEuOCAxLTEuOCAyLjItMS44IDIu'
    b'MS44IDIuMSAxLjh6Ii8+Cjwvc3ZnPgo=', 'EC')

EC = b64_EC
index.append("EC")
index.append("ECU")
index.append("Ecuador")
catalog["EC"] = EC
catalog["ECU"] = EC
catalog["Ecuador"] = EC
country["Ecuador"] = ('EC', 'ECU', 0)
lookup["EC"] = ('EC', 'ECU', 'Ecuador', 0)
lookup["Quito Ecuador"] = ('EC', 'ECU', 'Ecuador', 0)
lookup["ECU"] = ('EC', 'ECU', 'Ecuador', 0)
lookup["Ecuador"] = ('EC', 'ECU', 'Ecuador', 0)
details["EC"] = {"continent":"Americas","capital":"Quito","currency":"US Dollar","web":".ec","lang":"es-EC","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_EE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWVlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cmVjdCB3aWR0aD0iNjQwIiBoZWlnaHQ9IjQ3Ny45'
    b'IiByeD0iMCIgcnk9IjAiLz4KICAgIDxyZWN0IHdpZHRoPSI2NDAiIGhlaWdodD0iMTU5LjMi'
    b'IHk9IjMyMC43IiBmaWxsPSIjZmZmIiByeD0iMCIgcnk9IjAiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiMxNzkxZmYiIGQ9Ik0wIDBoNjQwdjE1OS4zSDB6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'EE')

EE = b64_EE
index.append("EE")
index.append("EST")
index.append("Estonia")
catalog["EE"] = EE
catalog["EST"] = EE
catalog["Estonia"] = EE
country["Estonia"] = ('EE', 'EST', 0)
lookup["EE"] = ('EE', 'EST', 'Estonia', 0)
lookup["Tallinn Estonia"] = ('EE', 'EST', 'Estonia', 0)
lookup["EST"] = ('EE', 'EST', 'Estonia', 0)
lookup["Estonia"] = ('EE', 'EST', 'Estonia', 0)
details["EE"] = {"continent":"Europe","capital":"Tallinn","currency":"Euro","web":".ee","lang":"et | ru","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_EG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1lZyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGQ9Ik0wIDMyMGg2NDB2MTYwSDB6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0iTTAgMTYwaDY0MHYxNjBIMHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'Y2UxMTI2IiBkPSJNMCAwaDY0MHYxNjBIMHoiLz4KICA8ZyBmaWxsPSIjZmZmIiBzdHJva2U9'
    b'IiNjMDkzMDAiIHRyYW5zZm9ybT0ibWF0cml4KC44IDAgMCAuOCAtNDAgMCkiPgogICAgPHBh'
    b'dGggc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjMiIGQ9Im00NTAu'
    b'OCAzMDIuNCA2OC41IDYzLjYtNC45LTExNS41Yy0uNy0xNy41LTE1LjktMTMuNS0yNy03LjIt'
    b'MTEuMSA3LjItMjQgNy4yLTM3LjQgMi41LTEzLjUgNC43LTI2LjMgNC43LTM3LjQtMi41LTEx'
    b'LTYuMy0yNi4zLTEwLjMtMjcgNy4yTDM4MC43IDM2Nmw3MC4xLTYzLjZ6Ii8+CiAgICA8cGF0'
    b'aCBpZD0iZWctYSIgZmlsbD0iI2MwOTMwMCIgc3Ryb2tlPSJub25lIiBkPSJtMzkzLjUgMjQ2'
    b'LjUtNC44IDExMi4zLTggNy4yIDQuOS0xMTUuNWEyNCAyNCAwIDAgMSA3LjktNHptOS42IDgt'
    b'NCA5NC04IDguMiA0LjgtMTA4LjVjMS42IDEuNiA2LjMgNS41IDcuMiA2LjN6bTguNyA3LjIt'
    b'My4xIDc4LjQtNi41IDYuMyA0LTg5LjRjMS42IDEuNSA0LjggMy44IDUuNiA0Ljd6bTkuNSA0'
    b'LTMuMSA2Ni44LTYuMyA1LjEgMy4xLTc0LjNjMS42LjcgNC43IDIuNCA2LjMgMi40em04Ljgg'
    b'MC0yLjMgNTUuNy02LjUgNi4zIDIuNS02MS4zYzEuNSAwIDUuNiAwIDYuMy0uN3oiLz4KICAg'
    b'IDx1c2UgeGxpbms6aHJlZj0iI2VnLWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC0xIDAgMCAxIDkwMCAwKSIvPgogICAgPHBhdGggZmlsbD0iI2Mw'
    b'OTMwMCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Im00NTMuMiAzMTUgOS42IDQzLjgtMy4yIDMu'
    b'Mi0zLjMtMi41LTUuNC0zOSAyLjMgMzktMy4yIDQtMy4xLTQgMi4zLTM5LTUuNSAzOS0zLjMg'
    b'Mi41LTMuMi0zLjIgOS42LTQzLjdoNi40eiIvPgogICAgPGcgaWQ9ImVnLWIiIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4zIj4KICAgICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Im00MjguNSAyOTUuOC0x'
    b'OS4xIDY3LjcgMjYuMyA0IDExLjEtNTAuOS0xOC4zLTIwLjh6Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Im00MjIuMiAzMTkgMi4zIDUuNSAxMi40LTExLjgiLz4KICAgICAgPHBhdGggZD0ibTQzMC44'
    b'IDMwNSAyLjYgMjQuMyA3LjktMTAuNG0tMy4yIDQgNC4zIDE1bTEuNy01LjUtOC43IDEzLjJt'
    b'Mi43IDEzLjItMi44LTEzLjItMi40LTEzLjQtNS45IDcuOS0yLjUtOS4xLTguMiA4LjQgNC4x'
    b'IDE1LjIgNS44LTkuNCAzLjEgOS42IDYtOS4yIi8+CiAgICAgIDxwYXRoIGQ9Im00MTUgMzYy'
    b'IDUuMy03LjUgMy40IDExLjUgNC44LTggMy4xIDkuNiIvPgogICAgPC9nPgogICAgPHVzZSB4'
    b'bGluazpocmVmPSIjZWctYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoLTEgMCAwIDEgOTAwIDApIi8+CiAgICA8ZyBzdHJva2UtbGluZWNhcD0icm91'
    b'bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4zIj4KICAgICAg'
    b'PHBhdGggc3Ryb2tlLXdpZHRoPSIyLjQiIGQ9Ik00NTAgMzkzLjhjMjAgMCAzOS0xLjYgNTAu'
    b'Mi00LjcgNC43LS45IDQuNy0zLjMgNC43LTYuNSA0LjgtMS42IDIuNC03LjIgNS43LTcuMi0z'
    b'LjQgMS00LTUuNS04LTQuNyAwLTUuNi01LjctNi4zLTEwLjQtNC43LTkuNSAzLjEtMjYuMyAz'
    b'LjktNDIuMiAzLjktMTYtLjgtMzIuNi0uOC00Mi4yLTQtNC43LTEuNS0xMC4zLS44LTEwLjMg'
    b'NC44LTQtLjgtNC43IDUuNi04IDQuNyAzLjMgMCAuOCA1LjcgNS42IDcuMiAwIDMuMiAwIDUu'
    b'NiA0LjggNi41IDExIDMuMSAzMC4yIDQuNyA1MC4xIDQuN3oiLz4KICAgICAgPHBhdGggZD0i'
    b'TTQyMi45IDM2My41YzYuNC45IDEzLjYgMS42IDE5LjIuOSAzLjIgMCA1LjUgNS41LS45IDYu'
    b'My01LjUuNy0xNC4zIDAtMTktLjhhMjMxIDIzMSAwIDAgMS0xOC40LTRjLTUuNi0yLjQtMS42'
    b'LTcgMS42LTYuNGExMDUuMyAxMDUuMyAwIDAgMCAxNy41IDR6bTU0LjIgMGMtNi40LjktMTMu'
    b'NiAxLjYtMTkgLjktMy40IDAtNS43IDUuNS43IDYuMyA1LjYuNyAxNC4zIDAgMTktLjggNC0u'
    b'OCAxMi44LTIuMyAxOC40LTQgNS42LTIuNCAxLjYtNy0xLjYtNi40YTEwNS4yIDEwNS4yIDAg'
    b'MCAxLTE3LjUgNHoiLz4KICAgICAgPHBhdGggZD0iTTQwMyAzNjAuNGMtNC44LS45LTcgNC43'
    b'LTUuNSA3LjkuNy0xLjYgNC0xLjYgNC43LTMuMi45LTIuNC0uNy0yLjQuOS00Ljd6bTE5LjIg'
    b'MTQuN2MwLTMuMiAzLjEtMi44IDMuMS02IDAtMS41LS44LTQtMi40LTRhMy40IDMuNCAwIDAg'
    b'MC0zLjIgMy4yYy0uNyAzLjEgMi41IDMuNiAyLjUgNi44em0yMi43LTkuMWM0LjcgMCA0LjIg'
    b'Ni4zIDIgOS41IDAtMi4zLTQtMy4yLTQtNC44IDAtMi40IDMuNi0yLjQgMi00Ljd6bTUyLTUu'
    b'NmM0LjktLjkgNy4yIDQuNyA1LjYgNy45LS43LTEuNi00LTEuNi00LjctMy4yLS45LTIuNC43'
    b'LTIuNC0uOS00Ljd6TTQ3OCAzNzVjMC0zLjItMy4yLTIuOC0zLjItNiAwLTEuNS44LTQgMi40'
    b'LTRhMy40IDMuNCAwIDAgMSAzLjIgMy4yYy43IDMuMS0yLjUgMy42LTIuNSA2Ljh6bS0yMy05'
    b'Yy00LjcgMC00LjIgNi4zLTIgOS41IDAtMi4zIDQtMy4yIDQtNC44IDAtMi40LTMuNi0yLjQt'
    b'Mi00Ljd6Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjkiIGQ9Ik00MDQuNyAzNjJj'
    b'MS42IDAgNCAuNyA0LjcgMS42bC00LjctMS42em03LjkgMi40Yy44IDAgNCAuNyA1LjUgMS42'
    b'bC01LjUtMS42em0yOC42IDMuMmMtMS41IDAtNC43IDAtNS41LjdsNS41LS44em0tOC43IDBj'
    b'LS45LS45LTQtLjktNS42IDBoNS42em02Mi44LTUuNmE4IDggMCAwIDAtNC43IDEuNmw0Ljct'
    b'MS42em0tNy44IDIuNGMtMSAwLTQgLjctNS42IDEuNmw1LjYtMS42em0tMjguNyAzLjJjMS41'
    b'IDAgNC43IDAgNS42LjdsLTUuNi0uOHptOC43IDBjLjktLjkgNC0uOSA1LjYgMGgtNS42eiIv'
    b'PgogICAgICA8ZyBmaWxsPSIjYzA5MzAwIiBzdHJva2U9Im5vbmUiPgogICAgICAgIDxwYXRo'
    b'IGQ9Ik00MDMuMyAzNzQuNmMtLjUtLjEtLjgtLjYtLjYtMSAuMS0uNy42LTEgMS0uOC40IDAg'
    b'LjkuNi45LjhsLS40LjctLjIuMWMwIC4yLS40LjItLjcuMnptNTUgMy45Yy0uMiAwLS42LS41'
    b'LS42LS43IDAtLjQuNi0xIDEtMWwuOC40Yy4zLjMuMy45LS4xIDEuMi0uMi4yLS44LjItMS4x'
    b'IDB6bS4zIDIuNWMtLjQtLjItLjUtLjQtLjYtLjggMC0uNSAwLS42LjUtLjlsLjQtLjIuNC4y'
    b'Yy40LjIuNy40LjcuOCAwIC4zLS4zLjYtLjcuOC0uMy4yLS40LjItLjcgMHoiLz4KICAgICAg'
    b'ICA8cGF0aCBkPSJNNDA3LjggMzcwYy0uNCAwLS45LjQtMS4yLjYtLjYuMS0xLjQuNS0yIDAt'
    b'LjYtLjEtMS40IDAtMS41LjguMS43IDEgMSAxLjYuNi40LS41IDEuNS0uOSAxLjcgMC0uNS44'
    b'LS40IDEuNy0uOCAyLjQgMCAuNS0uMy45LS41IDEuMy0uNSAwLTEgMC0xLjQuM2EyIDIgMCAw'
    b'IDAtMS42LjhjLS40LjYtLjggMS4yLS45IDIgLjEuNiAxIC44IDEuNi45bDIgLjYgMy4yLjlj'
    b'MS42LjUgMy4yLjcgNC44IDEuMWwuNS4xYy43LjIgMS0uNSAxLTFsMS0zLjZjLjItLjUuNS0x'
    b'LjUtLjQtMS4zLS41LjMtMSAuOC0xLjYuOC0uOSAwLS40IDEgMCAxLjMgMCAuNi0uMiAxLjMt'
    b'LjUgMS44LS42LjMtMS4yIDAtMS44LS4yLS41IDAtMS43LS4zLTEuMi0xbC41LTEuOGMuMy0u'
    b'Ni4zLTEuMy41LTItLjQtLjctMSAuMy0xLjUuNC0uNC4yLTEuNi4zLTEgMSAuNi40LjIgMS4x'
    b'IDAgMS43IDAgLjctLjggMS0xLjQuNy0uNiAwLTEuNS0uNS0xLTEuMWwuNS0xLjguNy0yYzAt'
    b'LjcuMy0xLjIuNi0xLjggMC0uNy41LTEuMy41LTIgMC0uMy0uMi0uNC0uNC0uNHptLTMuNyA3'
    b'LjNhLjMuMyAwIDAgMSAuMyAwYy4yLjIuMi40IDAgLjZsLS4zLjJjLS41IDAtLjYtLjEtLjYt'
    b'LjMgMC0uMSAwLS4yLjMtLjNhMS40IDEuNCAwIDAgMSAuNC0uMnptLTEgNWMtLjUtLjQtLjQt'
    b'LjcuMy0xLjMuNC0uMi41LS4yLjkuMS42LjUuNi44IDAgMS4zLS4yLjItLjMuMi0uNS4yLS4z'
    b'IDAtLjQgMC0uNy0uMnptMyAxYS45LjkgMCAwIDEtLjYtMS4xYy4yLS40LjMtLjUuOS0uNS43'
    b'IDAgLjguMS45LjcgMCAuNCAwIC41LS4zLjdhMSAxIDAgMCAxLS44LjJ6bTg5LjIgMGMtLjIt'
    b'LjEtLjMtLjItLjMtLjUgMC0uNC4yLS43LjgtLjkuNi0uMyAxLS4zIDEuMi4yLjMuNi4zLjgt'
    b'LjEgMS4yLS4yLjMtLjMuMy0uOC4zcy0uNiAwLS44LS4yem0tODUgMS4yYy0uNCAwLS42LS40'
    b'LS42LS44IDAtLjMgMC0uNC4yLS42bC42LS4yLjYuMWMuNS40LjYuOC4zIDEuMi0uMy40LS42'
    b'LjQtMS4yLjN6bTIxLjggMS0uMi0uM2MwLS42IDAtMS4xLjItMS43LjEtLjUgMC0xIC4yLTEu'
    b'NWwuNC0yLjhjMC0uNSAwLTEgLjItMS40LjEtLjggMC0xLjUuMi0yLjIgMC0uMy4zLTEgLjYt'
    b'LjYuNC42LjkgMSAxLjQgMS41LjQuMyAwIC43LS4zLjgtLjQuMS0uNS42LS41IDFsLS4yIDEu'
    b'MmMwIC43IDAgMS4zLS4yIDJsLS4xIDEuOC0uMiAxLjJjMCAuNCAwIC45LS40IDEuMS0uMy4y'
    b'LS44LjItMS0uMXptMjkuNy05LjgtMS4zIDEuMmMtLjYuNS41LjcuNiAxLjEuMi42LjIgMS4y'
    b'LjIgMS44LjIuNi4zIDEuMS4yIDEuNyAwIC43LS44LjUtMS4yLjktLjUuMi0uNy43LTEgMWE0'
    b'LjIgNC4yIDAgMCAwLS40IDEuNmMwIC41LS4zIDEgMCAxLjRsLjEuMmguNWwxLjUtLjFjMS4y'
    b'LS4yIDIuNS0uMiAzLjctLjNsMi4yLS4yYy42LjEuOS0uNS45LTEtLjQtLjctLjEtMS40LS40'
    b'LTItLjItLjgtLjEtMS41LS4yLTIuMiAwLS42LS43LS44LTEtLjQtLjQuNC0xIC41LTEuMi45'
    b'LS4zLjYuNi42LjggMWwuMSAxLjVjLjEuNi0uNS42LTEgLjctLjUuMi0xLjIuMy0xLjUtLjMt'
    b'LjItLjUtLjItMS0uMi0xLjUgMC0xLS4zLTEuOC0uMy0yLjcgMC0xLS4zLTIuMS0uMy0zLjIg'
    b'MC0uNS0uMS0xLjItLjgtMS4xem0tLjYgOC4yaC4zdi44bC0uMy4xYTMuMyAzLjMgMCAwIDEt'
    b'LjQuMSAyLjUgMi41IDAgMCAxLS4yIDBjLS4yLS4yLS4yLS41LjEtLjhsLjUtLjJ6bS0zMC05'
    b'LjJjLS4zIDAtLjguNy0xLjIuNi0uOS4xLS44IDEtLjEgMS4zdi44Yy4xLjgtLjQgMS41LS4z'
    b'IDIuMyAwIC44LS4zIDEuNy0uMyAyLjYtLjMuOS0uMyAxLjgtLjQgMi43LS4xLjgtLjcuNS0x'
    b'LjIuM3YtMWMuMS0uOS0uNS0xLjEtMS4yLTEuMi0uNyAwLTEtLjUtLjgtMS4xLjMtLjQgMS0u'
    b'MyAxLjUtLjMgMSAuMi45LTEuMS40LTEuNi0uNC0uNi0xLjItMS0xLjQtMS42IDAtLjgtLjUt'
    b'MS43LTEuMi0yLjEtMS4xLS4xLTIgLjgtMi4zIDEuOC0uNSAwLTEgLjItMS40LjQtLjcuMi0x'
    b'LjcgMS40LS43IDEuOS41LjEgMi4yLjUgMS40IDEuMi0uNC44LTEuMi44LTEuOS42LS43IDAt'
    b'MS41LS40LTEuNS0xLjItLjEtLjgtLjEtMS42LS40LTIuMy0uMi0uOC0xLjEtLjYtMS4yLjIt'
    b'LjcuNS0uNiAxLjQtLjEgMiAuMy43IDAgMS42LS4zIDIuMi0uMiAxLTEuMiAxLTEuOSAxLjIt'
    b'LjMuMi0xLjYgMC0xLjEuN2E0IDQgMCAwIDAgMi40LjNjLjggMCAxLjUtLjcgMi0xLjQuNS0u'
    b'NSAxLjQtLjIgMi4yLS4yLjcgMCAxLjUuNSAyLjMuMS4yLS41IDEuMi0xLjUgMS41LS41IDAg'
    b'LjkuNyAxLjMgMS41IDEuMi45IDAgLjUuNi41IDEuMiAwIC45LjcgMS40IDEuNSAxLjhoLjhj'
    b'LjctLjMgMS41LS42IDEuOC0xLjQuMy0uNy4zLTEuNS41LTIuMi4yLTEuMS40LTIuMy40LTMu'
    b'NC4zLTEgLjItMi4xLjQtMy4ybC4zLTIuM2MwLS41LS4yLS41LS41LS40em0tNi43IDQuMWMu'
    b'MSAwIC4yLjIuMi41IDAgLjQuMi43LjUuOHYuM2wtLjguMmMtLjUgMC0uOS0uMi0xLjItLjVs'
    b'LS4yLS4yLjMtLjIuNS0uNWMuMy0uMy41LS40LjctLjR6bTY2LTcuOWE4LjQgOC40IDAgMCAw'
    b'LTEuNy4zYy0xIDAtMS41IDEtLjUgMS42LjYgMS41IDEuNS0uNCAyLjUtLjIgMS40LjIgMS41'
    b'IDEuOCAxLjggMyAwIDEuMS40IDIuMi43IDMuMyAxIDEuMS0uNyAxLjgtMS40IDEtLjYtLjct'
    b'Mi0xLjUtMi43LS42LS45LjQtMSAxLjYtMS43IDItMS4yLjMtMS4zLTEuMi0yLTEuOC0uNi0u'
    b'OS0xLjctMS0yLjYtMS4yLS40LS45LS4yLTIuNC0xLTMtLjguMy0yLjIgMS43LTEgMi40IDEg'
    b'MS0uNSAxLjQtMSAyLS44LjktMSAyLTEgMy0xLjMuNy0xLjUtLjgtMS43LTEuNyAwLTEuMS0x'
    b'LS44LTEuNy0uNC0xIC40LTEuNCAxLjMtMiAydjJjLjIuOSAxLjIuNSAxLjguNCAxLS40IDEu'
    b'NC43LjYgMS4zLS42LjYtMi4yLjMtMiAxLjRoMS42YzEtLjMgMi4yLTEuMSAyLjMtMi4zLjIt'
    b'MSAxLjctLjkgMi41LTEuMSAxLS4zIDIuMy0uNCAyLjYgMSAuNy43IDIuMiAxLjUgMyAuNWEy'
    b'LjQgMi40IDAgMCAwIDEuMS0yLjNjLS4xLS44IDEuMy0uOCAxLjctLjMuNS44IDIuMS42IDIu'
    b'OSAwIC44LS41IDEtMS42IDIuMi0xLjZsNS40LTEuNWMxLjQtLjMtLjItMS4yLS42LTEuOC0x'
    b'LS41LTIgMS43LTMuMi42LTEtLjctLjktMi0xLjItMy4xLS4zLTEuNC0uMi0zLTEuMi00LS42'
    b'LS43LTEuNi0uOS0yLjUtLjl6bS02LjggOS41Yy4xIDAgLjMgMCAuNS4yLjQuMi43LjYuNyAx'
    b'IDAgLjIgMCAuMi0uMy4zbC0uNS4yYy0uMiAwLS43LS4zLS43LS41di0uNGMtLjItLjQtLjIt'
    b'LjQgMC0uNmwuMy0uMnptNi41LjRjLjQgMCAuNiAwIC44LjMuMS40IDAgLjYtLjQuOGwtLjUu'
    b'Mi0uNC0uM2MtLjItLjEtLjMtLjItLjMtLjQgMC0uMy40LS42LjgtLjd6bS05IDBjLjIgMCAu'
    b'MyAwIC40LjIuMi4yLjMuMy4zLjZ2LjZjMCAuMyAwIC4yLS42LjJzLS43IDAtLjctLjZjMC0u'
    b'NCAwLS41LjMtLjcuMS0uMi4zLS4yLjQtLjJ6bS01LjQgMS41YS42LjYgMCAwIDEgLjQuNGMw'
    b'IC4zIDAgLjUtLjIuNi0uMy4xLS44LjItMSAwYS42LjYgMCAwIDEgMC0uMWMtLjItLjEtLjIt'
    b'LjIgMC0uM3YtLjFsLjItLjNhLjUuNSAwIDAgMSAuNi0uMnptOS4yIDEuMi41LjF2LjZoLTEu'
    b'MmwtLjEtLjJjMC0uMiAwLS4zLjItLjRsLjYtLjF6bS0xNy4xIDQuOGMtLjEgMC0uMy0uMS0u'
    b'MS0uMi4xLS4zLjUtLjQuOC0uNmEzLjQgMy40IDAgMCAwIDEuNC0xYzAtLjQuNC0uNi40LTFs'
    b'LS4xLTEuNGExLjggMS44IDAgMCAwLS44LTFjLS4zLS4xLS43LS4yLS44LS42IDAtLjMuMy0u'
    b'Ni40LS45bC42LTEuMmMuMy0uMy43IDAgLjguMmwuNSAxYy4zLjMuNS42LjYgMSAuMi40LjQu'
    b'Ny40IDFsLjIgMS4zYzAgLjUgMCAxLjEtLjIgMS42bC0uNi44Yy0uMy4zLS42LjYtMSAuNy0u'
    b'My4xLS41LjQtLjkuNEg0NjhsLS4xLS4xem0tNi45LjRjLS4yLS4yLS4zLS4zLS4zLS42czAt'
    b'LjMuMy0uNmMuNC0uNC42LS40IDEuNCAwIC43LjQgMSAuNCAxIC4xLjEtLjIuNS0uNSAxLS41'
    b'YS44LjggMCAwIDEgLjUuMmMuMi4yLjMuMy4zLjcgMCAuNSAwIC41LS4zLjgtLjMuMi0uMy4y'
    b'LS43LjJhLjkuOSAwIDAgMS0uOC0uNmMwLS4yIDAtLjMtLjItLjFsLS4yLjFjLS4yIDAtLjYu'
    b'My0uOC41bC0uNS4xYy0uNCAwLS40IDAtLjctLjN6bS0xOS44LTguOWMtLjcgMC0xLjQuNi0x'
    b'LjUgMS4zLjIuNy44IDEuNS40IDIuMi4zIDEtLjggMS40LTEuNS45LS40LTEtLjYtMi0xLjMt'
    b'My0uOC0uMi0xLjEgMS4xLTEuNyAxLjYuMy43IDEuMSAxLjQgMS4yIDIuMy4yIDEtLjQgMi0x'
    b'LjEgMi40LS43LjctMS43LjUtMi41LjYtMSAuNi43LjggMS4yLjggMSAuMSAyLjEgMCAzLS44'
    b'LjctLjMuNi0xLjcgMS41LTEuOGw0LjguM2MuOC4yIDIuMS0uMSAyLjcuNSAwIDEgMSAxLjgg'
    b'MS45IDIuMi41LjIgMS0uNSAxLjUtLjYgMS0uMy43LTEuNSAxLjMtMmg1Yy4yIDAgLjMtLjUu'
    b'Ni0uN2wtLjItMS45Yy0uMy0uOCAwLTEuOC0uNS0yLjUtLjktLjItMS42LjUtMi40LjYtMSAu'
    b'NC0xLjcgMS4zLTEuOCAyLjMtLjUuOS0xLjQtLjItMS0xbC0uMS0xYy0uNS0uNS0xLjQtLjMt'
    b'Mi4xLS40bC0zLS4yYy0xIDAtMS45LjEtMi43LS4xLTEgMC0xLTEtMS0xLjhhMSAxIDAgMCAw'
    b'LS43LS4yem0yIDMuNyAxIC4xaDEuM2MxIC4yIDIgLjIgMyAuMi4yIDAgLjQuMi42LjR2MmMw'
    b'IC4zIDAgLjctLjIuOGEuNy43IDAgMCAxLS4yLjIgMSAxIDAgMCAxLS43LS41di0xLjRhMS4z'
    b'IDEuMyAwIDAgMC0uNy0uM2wtMi42LS4xLTItLjFjLS4zLS4xLS43IDAtLjktLjQtLjItLjIu'
    b'MS0uNi40LS43YTIuMyAyLjMgMCAwIDEgMS0uMnptMTEuMy4zYy4xIDAgLjIgMCAuMi4zbC4y'
    b'LjVjMCAuMSAwIC4yLS4yLjItLjUuMi0xIC4yLTEuMiAwIDAtLjEgMC0uNS4yLS42bC44LS40'
    b'eiIvPgogICAgICA8L2c+CiAgICA8L2c+CiAgICA8cGF0aCBzdHJva2Utd2lkdGg9IjEuMSIg'
    b'ZD0iTTQ1MCAzMjcuMmMzMi42LTI1IDI5LjgtNjEuOCAyOS44LTYxLjhsLTIuNS4yYy02Ljkg'
    b'MC0yMy4yLTQtMjctOC45LTQgNC41LTIwLjggOS0yNy42IDlsLTIuNS0uM3MtMi45IDM2Ljcg'
    b'MjkuOCA2MS44eiIvPgogICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuOSIgZD0iTTQ3Ny4yIDI2'
    b'OGgtLjhjLTYuMiAwLTIwLjYtMy4xLTI2LjItNy45LTUuOCA0LjQtMjAuNSA4LTI2LjYgOGE0'
    b'LjcgNC43IDAgMCAxLS44LS4xIDczLjEgNzMuMSAwIDAgMCAyLjYgMTguNyA3MSA3MSAwIDAg'
    b'MCAyNC42IDM3LjEgNzEuMiA3MS4yIDAgMCAwIDI0LjYtMzcuMiA3My4xIDczLjEgMCAwIDAg'
    b'Mi42LTE4LjZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjYzA5MzAwIiBzdHJva2U9Im5vbmUiIGQ9'
    b'Ik00MzkuNCAyNjVhNjIuMiA2Mi4yIDAgMCAxLTE2LjYgM2wuMSA0LjFhNzIuOCA3Mi44IDAg'
    b'MCAwIDIuNSAxNC41IDcxIDcxIDAgMCAwIDE0IDI2LjhWMjY1em0yMC42IDB2NDkuMmE3MS4x'
    b'IDcxLjEgMCAwIDAgMTQuNi0yNy42IDczIDczIDAgMCAwIDIuNS0xNC41bC4xLTRoLS44Yy0z'
    b'LjggMC0xMC40LTEuMi0xNi40LTMuMnoiLz4KICAgIDxnIHN0cm9rZS13aWR0aD0iMS4zIj4K'
    b'ICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00NjIuMyAyNTNjLjcuMS0uOS0z'
    b'LjUtLjktMy41IDEuOCAxLjggOC40IDIuMyA4LjQgMi4zLTQtMS44LTgtMTUuMS03LjUtMjUu'
    b'OC40LTEwLjYtMS41LTE0LjgtMy0xNi40LTItMi04LjUtMy44LTEyLjctNC0yLjUtLjEtMiAx'
    b'LjgtMiAxLjgtNC41LTEuMS05LTEuNi0xMS0uMi0xLjggMS4yLTIuMiA3LjUtLjggNi40IDMu'
    b'My0yLjcgNi4yLS4yIDguMiAyLjcgMS44IDIuNSAxLjcgOS43LS45IDE4LjJhNjAgNjAgMCAw'
    b'IDEtMTAgMTcuN2M0IDAgOS42LTMuNSA5LjYtMy41bC0xLjMgNS41YzQuMi0yIDcuNS01LjEg'
    b'Ny41LTUuMWw0IDQuMmMxLjMtMS44IDQtNC4yIDQtNC4yczMuMyAzLjUgOC40IDR6Ii8+CiAg'
    b'ICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik00NDYuMSAyMjcuNnMtMi4yIDE2LjQtNi40IDIx'
    b'bTEwLTIxLjVzLTEgMTYuNy0zLjggMjJtNi45LTIxLjNzMCAxOC4yIDEgMjEuM20zLTIwLjRz'
    b'LjggMTUuMyA0LjYgMjAuOCIvPgogICAgICA8cGF0aCBmaWxsPSIjYzA5MzAwIiBzdHJva2Ut'
    b'd2lkdGg9Ii4zIiBkPSJNNDQyIDIxOS42YTggOCAwIDAgMC0xLTMuM2MtMi0zLTQuOS01LjQt'
    b'OC4yLTIuNyAwIDAgMS4xLTMuNSAzLjYtMy42IDEuOC0uMSA2LjEgMS40IDkuOSA3LjggMCAw'
    b'LTIuOC0uNi0zLjUgMC0xLjIgMS0uNyAxLjgtLjcgMS44eiIvPgogICAgICA8cGF0aCBmaWxs'
    b'PSIjYzA5MzAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNNDMyLjQgMjA5LjNjLjMtMSAuNy0x'
    b'LjggMS4zLTIuMSAyLTEuNCA2LjQtMSAxMC45LjIgMCAwLS40LTEuOSAyLTEuOCA0LjIuMiAx'
    b'MC42IDIgMTIuNiA0YTcuOSA3LjkgMCAwIDEgMS41IDIuNGMtMS0xLjQtMy44LTEuMy00LjUt'
    b'MS4yLTEgLjEtMS43IDAtMy4xLjQtLjcuMi0xLjcuNC0yLjMuOC0uNC40LS44IDEuNi0xLjQg'
    b'MS42LTEgMC0xLS4yLTEuMy0uNS0uMy0uNS0uNS0xLjEtLjktMS0xIC4xLTIuOC0uNy01LTIu'
    b'NS0yLjMtMS44LTMuMi0yLjItNi0yLTMgLjItMy44IDEuOS0zLjggMS45di0uMnoiLz4KICAg'
    b'ICAgPGNpcmNsZSBjeD0iNDQ4LjgiIGN5PSIyMTAuNyIgcj0iMS4yIiBzdHJva2U9Im5vbmUi'
    b'Lz4KICAgIDwvZz4KICA8L2c+Cjwvc3ZnPgo=', 'EG')

EG = b64_EG
index.append("EG")
index.append("EGY")
index.append("Egypt")
catalog["EG"] = EG
catalog["EGY"] = EG
catalog["Egypt"] = EG
country["Egypt"] = ('EG', 'EGY', 0)
lookup["EG"] = ('EG', 'EGY', 'Egypt', 0)
lookup["Cairo Egypt"] = ('EG', 'EGY', 'Egypt', 0)
lookup["EGY"] = ('EG', 'EGY', 'Egypt', 0)
lookup["Egypt"] = ('EG', 'EGY', 'Egypt', 0)
details["EG"] = {"continent":"Africa","capital":"Cairo","currency":"Egyptian Pound","web":".eg","lang":"ar-EG | en | fr","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_EH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWVoIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImVoLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTE1OC43IDBINTI0'
    b'djUxMmgtNjgyLjd6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNlaC1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoMTQ4LjgpIHNjYWxlKC45NCkiPgogICAgPHBhdGggZD0iTS0xNTguMyAwaDY4MC45djI1'
    b'NS4zaC02ODAuOXoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDdhM2QiIGQ9Ik0tMTU4LjMgMjU1'
    b'LjNoNjgwLjl2MjU1LjNoLTY4MC45eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTS0x'
    b'NTguMyAxNDguOWg2ODAuOXYyMTIuOGgtNjgwLjl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjYzQx'
    b'MTFiIiBkPSJtLTE1OC4zIDAgMzQwLjQgMjU1LjMtMzQwLjQgMjU1LjNaIi8+CiAgICA8Y2ly'
    b'Y2xlIGN4PSIzNTIuMyIgY3k9IjI1NS4zIiByPSI2OC4xIiBmaWxsPSIjYzQxMTFiIi8+CiAg'
    b'ICA8Y2lyY2xlIGN4PSIzNzcuOSIgY3k9IjI1NS4zIiByPSI2OC4xIiBmaWxsPSIjZmZmIi8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjYzQxMTFiIiBkPSJtMzM0IDI5Ni41IDI5LjEtMjAuNyAyOC44'
    b'IDIxLTEwLjgtMzQgMjktMjAuOS0zNS43LS4yLTExLTM0LTExLjIgMzMuOS0zNS43LS4yIDI4'
    b'LjcgMjEuMi0xMS4xIDM0eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'EH')

EH = b64_EH
index.append("EH")
index.append("ESH")
index.append("Western Sahara")
catalog["EH"] = EH
catalog["ESH"] = EH
catalog["Western Sahara"] = EH
country["Western Sahara"] = ('EH', 'ESH', 0)
lookup["EH"] = ('EH', 'ESH', 'Western Sahara', 0)
lookup["El-Aaiun Western Sahara"] = ('EH', 'ESH', 'Western Sahara', 0)
lookup["ESH"] = ('EH', 'ESH', 'Western Sahara', 0)
lookup["Western Sahara"] = ('EH', 'ESH', 'Western Sahara', 0)
details["EH"] = {"continent":"Africa","capital":"El-Aaiun","currency":"Moroccan Dirham","web":".eh","lang":"ar | mey","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_ER = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWVyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNiZTAwMjciIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2I0ZDdmNCIgZD0ibTAgNDgwIDY0MC0uM1YyNDBMMCA0ODB6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjMjM5ZTQ2IiBkPSJtMCAwIDY0MCAuM1YyNDBMMCAweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2YzZTI5NSIgZD0iTTE4Ni4yIDM2MC40Yy0xMC43IDMtMTYuOCAxMS4zLTE2'
    b'LjcgMTkuMWw1Mi44LS4yYy40LTguNC02LjUtMTYuMi0xNy0xOS4zIDUxLjYtMSA5Ni40LTIw'
    b'LjQgMTA0LjYtMzIuOC04LTMuNS0xNy40IDIuMS0yNCAuOCAxNS43LTcuMyA2My0zNy45IDU1'
    b'LjMtNzAuNy02IDE4LjItMjQgMzMuMy0zMS44IDM3LjQgMTcuNy0yNi44IDQxLjgtNTQuOCAy'
    b'MC45LTc2LjQgMSAxMi41LTggMjYuMy0xMiAyNy40IDEwLjMtMjguNCAyMC02NC0yLjEtODcu'
    b'NCAyLjkgOC41IDEuNyAzMi40LTIuMyAzMy41LTEuMi0xOS4zLTQuNS01OS44LTI0LjgtNTku'
    b'MyA2LjQgNS44IDkuMiAyMS40IDkuNCAzNy4yYTU3LjUgNTcuNSAwIDAgMC0yMS4xLTI3IDEx'
    b'OC4zIDExOC4zIDAgMCAwLTQxLjUtNDIuMmMxLjggMTIuNyAzLjMgMjIuNyAyMSAzNS45LTku'
    b'Mi0uNi0xOC40LTE4LjEtMjguMy0xOC42LTcuOS0uNC0xNCA3LjEtMjYuOSAyLjggMS40IDQu'
    b'MiA3LjQgNi4xIDguNyA5LjItMi44IDItOS4zLS4zLTE0LjctMyA3LjUgMTAgMTkgMTYgMjgu'
    b'OCAxNCAxMS43LTIuMiAyNC4yLTEgMzYuMiA1LjhhNjMgNjMgMCAwIDEtMjIuNS42YzYuOSA3'
    b'IDExLjUgMTEuNyAyMy42IDExLjYgMTAuNyAwIDE2LjQtNS44IDE5LjEtMi4yIDYuOCA4IDEx'
    b'LjMgMTYgMTcgMjUuNC0xMi41IDEuMy04LjctMTQuMS0yMi42LTIyLTcuOSAxNiA5IDM1LjIg'
    b'MjAuMyA0My4yYTY1IDY1IDAgMCAwIDcuMSAzMS41YzMuNSA2LjUgOCAxMy4yIDYuMyAyNy45'
    b'LTYuOS01LTEzLjUtMjEuOC0xMS0zNS4xLTguNiAyLjMtMTIgMTcuNC04IDI1IDMgNS43IDUg'
    b'MTYuOCAxLjYgMjEuNy0zLjQgNC42LTMuNyA0LTMuNyAxNCAuMSA1LjgtMy4yIDEyLjgtOC41'
    b'IDE3LjdhMzUuNSAzNS41IDAgMCAwIDEuMS0xNS44Yy00LjIgNy4yLTE0LjkgMTQuNi0xOC4y'
    b'IDIyLjQtMy4zIDcuNy00LjEgMjEuMi0yMCAyNC4zLTIwLjYgNC0yNy43IDcuNi00MC44IDEz'
    b'LTEuNS0xMCAyLjktMzEgMTEuMy0yOS43IDguMSAxLjQgMzMtOC42IDI0LTI5LjUtMS43IDYu'
    b'Ni03LjUgMTMtMTMuOSAxMy4zIDYuOS04LjggMTktMTggMTMuMS0zMi44YTQyLjYgNDIuNiAw'
    b'IDAgMS0xNi4zIDE4YzguNC0xNiAxLTIxLTktNy42LTMuOCA1LjEtNi4xIDE1LjQtOC41IDI4'
    b'LjUtNC0xMC42LTMuNy0yNC42LTguNC0zNi00LjgtMTIuMyA2LjUtMTUuNSAxMS44LTE0LjUg'
    b'MTMgMy41IDM0LjkgMy41IDMzLjMtMTguMS01LjcgNy4zLTE1LjUgOS41LTI2LjIgNyAxMi04'
    b'LjggMjEuNC0yNS4zIDgtMzRhMzEgMzEgMCAwIDEtMTYuOSAyNC4xIDUwLjggNTAuOCAwIDAg'
    b'MS0uMy0yNC44Yy01LjIgNS42LTkgMTctMTIuMSAzMC4yLS4zLTEzIDIuMi0yMi4zIDQtMjku'
    b'MyAyLjgtMTAuMSA5LjYtMy41IDIwLTIuOCAxMC4yLjYgMjQtNSAyMS40LTE4LjctMy40IDUu'
    b'NS0xMC41IDcuNi0xNy43IDcgOC43LTUuMyAyMy44LTE0LjYgMTUuNS0yOS0zLjUgNS40LTQu'
    b'NiAxMC0xNC43IDExLjcgMi42LTYgMy0xNC43IDExLTE4LTE0LTIuOS0yMiA2LjMtMjYuMiAy'
    b'MC43LTEuNi0xMC0zLjYtMTMuNi00LTIxIDcuNi04LjMgOC40LTI0LjgtOC0yOC40YTM1IDM1'
    b'IDAgMCAwIDEuMiAxNy40Yy03LjctNC42LTE4LjUtNy4xLTI1LjgtLjcgNSA1LjMgMTIuNSAx'
    b'MCAyNC4yIDQuMi0yLjggOS0xMCA3LjUtMTkuOCA0IDYgMTEuMyAxMy42IDEzLjMgMjIgMTIg'
    b'NC40IDExLjYgNC42IDIwLjQtOC4zIDM3LjIuNi0xMC40LS4xLTE4LjItOC40LTI2LjctNy4y'
    b'LTctMTMgLjMtMS44IDE1LjgtNi44LTUtMTQuNC0xNS0xNi43LTI1LjEtMi4yIDEyLjQtLjIg'
    b'MjcuMSA2LjcgMzUuNC0zLjMgMy41LTctLjQtMTIuNS05IDIgMjcuNCAxMy43IDMyLjcgMjku'
    b'NCAyNi42LjQgMTUgLjQgMjguOSAxLjMgNDctOS4xLTEzLjItMjAuNy0yMy0yNy4xLTI1LjQt'
    b'MiA3LjMgNS41IDE3IDkuOCAyMi4zLTYuNS0xLjQtMjAuNS0xMi0yMC41LTEyLTEuNCAxMi4x'
    b'IDE0LjMgMjMuNCAyNC41IDI4LjQtMTItLjUtMTcuMy01LTI1LTEyLjQuMiAzMy44IDM2LjYg'
    b'MjcuOSA0My41IDIyLjdsMyA1Mi41Yy0xMC4zLTEuOC05LjUtNS0xOC4zLTUuNy0yNC41LTEt'
    b'NDMuOS0yOS40LTUwLjMtNTAuMy0xLjkgMy40LS40IDctMi4xIDExLjMtNC0xMC4zLTktMjMu'
    b'Ni0xNS45LTI5LjggMS44IDYgMiAxMi4xIDEuNCAyMy4zLTIuNC03LjItNC41LTkuNS00Ljct'
    b'MTggLjEtNi41IDYuMy0xMS4zIDYtMjAuNS0uMy02LjctNi40LTIxLjMtNy4zLTMyLjUtMyAx'
    b'MS42LTQuOCAyMy44LTkuNCAzMSAyLjMtMTIuNCAxLjYtMjEgNS40LTI5LjMgNC40LTguNyA4'
    b'LjEtMTYuNiA1LjItMjUuNC0yLjggMy40LTEuOSA2LjUtOSAxNC44LTEuNS05IDkuMi0yMy41'
    b'IDE5LjYtMjkuMyA3LjMtMy44IDE2LjUtMTcuNiAxMC41LTI3LTYuOSA1LTEwIDExLjYtMTku'
    b'NyAyMyA3LTI3IDI1LTM0LjIgNDYuNS0zNC4zIDQuNyAwIDE0LjMtMS43IDE3LTgtNiAyLjMt'
    b'MTMuMiAyLjYtMTkuNiAxLjQgNC43LTYuOSAxNC40LTYgMjMuNi02IDcuMSAwIDE4LjMtMSAy'
    b'Mi44LTExLjJhNTAuOCA1MC44IDAgMCAxLTMxIDEuOWMxMy43LTcgMzUtNy44IDQ2LTE3LjEt'
    b'MTIuNS05LjMtNDMuNyAyLjItNjMuNCAxNS43IDUuNS01IDE0LjItMTQgMTktMjEuMi0xMC44'
    b'LTUuMi0zOCAyNS00Ny40IDQzLTkgNS0xMi41IDEzLTE2IDE4LjUgNC43LTE2LjEgNS4yLTI3'
    b'LjggOS4yLTQxQzgwIDEzOCA5Mi42IDE5NC42IDg2IDIwOC4yYy44LTE1IC4xLTM0LjEtNi00'
    b'NC05LjQgNy4yLTEwLjIgNDkuNS0xLjQgODQuNy0zLjItOS40LTkuMi0xOC4yLTExLjEtMjku'
    b'Ny0xNCAyNS40IDguMiA1NS41IDI2LjcgNzkuMi0xNC03LjMtMjcuNy0yMi45LTM2LjgtMzYg'
    b'Mi41IDQ1LjYgNTAgNTUgNTcuNCA2Ni4yLTEwLTQuNy0yOS4xLTEzLjktMzcuMy00LjJhOTkg'
    b'OTkgMCAwIDEgMzIuMyAxMi4xYzEyLjQgMTUuNCAzNS43IDIyLjIgNzYuNCAyMy45eiIvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'ER')

ER = b64_ER
index.append("ER")
index.append("ERI")
index.append("Eritrea")
catalog["ER"] = ER
catalog["ERI"] = ER
catalog["Eritrea"] = ER
country["Eritrea"] = ('ER', 'ERI', 0)
lookup["ER"] = ('ER', 'ERI', 'Eritrea', 0)
lookup["Asmara Eritrea"] = ('ER', 'ERI', 'Eritrea', 0)
lookup["ERI"] = ('ER', 'ERI', 'Eritrea', 0)
lookup["Eritrea"] = ('ER', 'ERI', 'Eritrea', 0)
details["ER"] = {"continent":"Africa","capital":"Asmara","currency":"Nakfa","web":".er","lang":"aa-ER | ar | tig | kun | ti-ER","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_ES = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI5MDAiIGhlaWdodD0iNjAwIj4KPHJl'
    b'Y3Qgd2lkdGg9IjkwMCIgaGVpZ2h0PSI2MDAiIGZpbGw9IiNjNjBiMWUiLz4KPHJlY3Qgd2lk'
    b'dGg9IjkwMCIgaGVpZ2h0PSIzMDAiIHk9IjE1MCIgZmlsbD0iI2ZmYzQwMCIvPgo8L3N2Zz4=', 'ES')

ES = b64_ES
index.append("ES")
index.append("ESP")
index.append("Spain")
catalog["ES"] = ES
catalog["ESP"] = ES
catalog["Spain"] = ES
country["Spain"] = ('ES', 'ESP', 0)
lookup["ES"] = ('ES', 'ESP', 'Spain', 0)
lookup["Madrid Spain"] = ('ES', 'ESP', 'Spain', 0)
lookup["ESP"] = ('ES', 'ESP', 'Spain', 0)
lookup["Spain"] = ('ES', 'ESP', 'Spain', 0)
details["ES"] = {"continent":"Europe","capital":"Madrid","currency":"Euro","web":".es","lang":"es-ES | ca | gl | eu | oc","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_ES_AN = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI3NTAiIGhlaWdodD0iNTAwIiB2aWV3'
    b'Qm94PSIwIDAgOSA2Ij4KPHBhdGggZmlsbD0iIzA2MyIgZD0ibTAsMGg5djZIMCIvPgo8cGF0'
    b'aCBmaWxsPSIjRkZGIiBkPSJtMCwyaDl2MkgwIi8+Cjwvc3ZnPg==', 'ES_AN')

ES_AN = b64_ES_AN
index.append("ES_AN")
index.append("Spain Andalucia")
catalog["ES_AN"] = ES_AN
catalog["Spain Andalucia"] = ES_AN
country["Spain Andalucia"] = ('ES_AN', '', 1)
lookup["ES_AN"] = ('ES_AN', '', 'Spain Andalucia', 1)
lookup["Seville Spain Andalucia"] = ('ES_AN', '', 'Spain Andalucia', 1)
lookup["Spain Andalucia"] = ('ES_AN', '', 'Spain Andalucia', 1)
details["ES_AN"] = {"continent":"Europe","capital":"Seville","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_AN"] = ('ES_AN', 'Spain Andalucia', 1)
regional["Spain Andalucia"] = ('ES_AN', 'Spain Andalucia', 1)
#----------------------------------------------------------------------
b64_ES_AR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcyIiB3aWR0aD0iMzIwIiBoZWlnaHQ9'
    b'IjIxMyIgdmlld0JveD0iMCAwIDMyMCAyMTMiIHNvZGlwb2RpOmRvY25hbWU9IkJhbmRlcmFf'
    b'ZGVfQXJhZ8Ozbi5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2Fw'
    b'ZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2Rp'
    b'cG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4bGluaz0i'
    b'aHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8'
    b'ZGVmcyBpZD0iZGVmczYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFtZWR2aWV3'
    b'NCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIgYm9yZGVyb3Bh'
    b'Y2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpwYWdlb3BhY2l0'
    b'eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnIGlua3NjYXBl'
    b'Omdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9Imc4Ij4KICAg'
    b'IDxpbWFnZSB3aWR0aD0iMzIwIiBoZWlnaHQ9IjIxMyIgcHJlc2VydmVBc3BlY3RSYXRpbz0i'
    b'bm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiIHhsaW5rOmhy'
    b'ZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBVUFB'
    b'QUFEVkNBWUFBQUFtVENudUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZK'
    b'Z0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBR'
    b'QS93RC9BUCtndmFlVEFBQXUKRjBsRVFWUjQydTNkZVp3a1paM244YzhUUjk2WmxYWGYzZFgz'
    b'QVhJMXB5MjJLSUlISGd6ZXMrUG9ycnM3THM2c284N3NxdU40aks3aQplT0NvbzZPT3FPQU1w'
    b'OG9oSUswQ0NqUlgwL1I5ZDFWWGRkMUhadVdkR2NlemYyUlQzUVhWVUlVMERWMi85K3ZGcTZu'
    b'TWpNak1pS2h2Ci9aNG5JcDVIdWZ2REdpR0VtSWNNMlFSQ0NBbEFJWVNRQUJSQ0NBbEFJWVNR'
    b'QUJSQ0NBbEFJWVNRQUJSQ0NBbEFJWVNRQUJSQ0NBbEEKSVlTUUFCUkNDQWxBSVlTUUFCUkND'
    b'QWxBSVlTUUFCUkNDQWxBSVlTUUFCUkNDQWxBSVlTUUFCUkNDQWxBSVlTUUFCUkNDQWxBSVlU'
    b'NApFMWk1ZXdLeUZZUVE4NUxhVTljbTh3SUxJYVFKTElRUUVvQkNDQ0VCS0lRUUVvQkNDQ0VC'
    b'S0lRUUVvQkNDQ0VCS0lRUUVvQkNDQ0VCCktJUVFFb0JDQ0NFQktJUVFFb0JDQ0NFQktJUVFF'
    b'b0JDQ0NFQktJUVFFb0JDQ0NFQktJUVFFb0JDQ0NFQktJUVFFb0JDQ0NFQktJUVEKRW9CQ0NE'
    b'RkhLbk5OUXFiRmZJbnhOZHpUNTdPMjJTQWVsTzBoeEhFTFFIZC9XQUx3SmViQkp3eGNMNGpu'
    b'T2x4MHZvdFNzazJFa0NidwpQSEJvQ0NBQVFFMGl3TFk5a241Q1NBRE9FOTE5TnVGUWRiY29C'
    b'Y1BqTmxwcWRDRWtBRjhNV3NQbnJ0Yjg4aDZEU3VYRmZlL3hOUGphCm5QWllzc1ppVC9lTFd3'
    b'WDZQdHp6Z01GbnZnNjV2QndUNHVRbGZZQXp5QmZnMXZVQmxLbnBhSEc0OE93WDUzMjM3bFk0'
    b'WGhpQWJGNFQKajFhRHovUEtuUE1LNzBYNURFL3NVT3crWUtHMTRyWG5sV2xwa2lhNGtBcHdY'
    b'b2xHWVBsaWw1WkdpMUlseEMxM21TOUtOVmh4Wnc0Ygp4em4rSWFRMTNIbWZ3ZkJva05aR2kw'
    b'VWRub1Nma0FDY3I5cWFQRHhYVXhNemFHNEs4TXYxRnQ1eExzSjhYODNwOFJmU3JmZVloRU5C'
    b'Cm1oc05VRkNiOE9RZ0VCS0E4ellBbXhYSzhDbVdOSkd3b3JuQjVzNzd6UlBVVVhGOGV5bCt2'
    b'MEVSaWRyVUpCVFp2TWF0K0N6cmttTkEKU0FET2E1R1FQL1gvaWJqQ2RTeDZCMmEvL01HQnVi'
    b'MmZiY3djZEpZNXR3Q2N5L3VPcDJCaU1rQkQzZUZEUVVNZzZHT2FzditGQk9EOApEc0RnOUda'
    b'Z2E0dkJwaDJ6UzRac0hqWnREM0Q5N1RhRG83TUxzRkRRbi9ueHdPeVd6K1FVLzNtN3hkWTlJ'
    b'UWFHWjdmTUV6c01tdXFuCkh3YmhZM3dPSVNRQTUxTUFSalErVEYySEY3QVY1YktKTzR2dXNm'
    b'MEhEZXFTSnNzVzJ6endtRDJyOTF2WURwT1o2ZUdqTlVTanN3dXoKZXg4MldOb1ZJQjVWSEJx'
    b'MlpyVk1LbTBTaTZwalZyNUNuTXlzK2ZBbHMza1lIZE1zWGppM2t3bUxPcUduenllbmpLbExV'
    b'c0lSZy8yOQppaFdMamgxS0ZRY2NEMkxSYXA5YXhUVjQ0QW1Uam1hZnJ2YnFjcjRQbTNZbzhr'
    b'VUwzNjlXZnlzWGU2RDhhWCtYSnRJZUt4ZHBIdDFpClVDeVphSzJJaEYxT1hlNFRDVlZmTXpn'
    b'Q2g0Wk1KaVlOV3ByQXRzRDNGT1VLQkFQSC9uN0RZeEFJSEhrdng0V0s0OVBjT1BjK3g3RUoK'
    b'S0pjMTdhMXk1bGhJQmZpU0VvL0NQUS9BZDM2bTJOY3orMTlReTRSd2FIcTVaeWh3bkdkZmJ2'
    b'MkRGb1ZpTlhrVXNHcXBSU1FVSkpNOQo4cHJIdGhxVUtpRzB0bERLUWhQZzhXMEJUT1ZPL3d5'
    b'V3o0WW5iWHcvQ0Znb1plSzRRUjdmZk9SdjEyUldZVnBCVGw5bFk1cmdlVkJ4CkxYNTkzN05Y'
    b'bnFsSnNPMGoyNk5VMXBpbVQwUHQ3TGZ0MENoY2M1UGlKemRyNnBJU2ZrSXF3SmVrdi9wenhl'
    b'UGI0TUdORnYyakhxOCsKMjU4MnlNRE92ZkQ0Tm9OMTUva3NhRHU2R2V5VGZkcmRFSjZuMkww'
    b'ZnhpZE5IRmNSc24yNk9qMmFHNnJQSjZJSzIxWVVpdFV6eUo0SApucSt4Z2tlSGowRWlEdkZZ'
    b'OVVPVUt4cmJOaGthOFZnYU8vSzZkRWJUVUd2aitVZGVXNmxveHJJR1dsZHZsME5YbThybGlp'
    b'WVVWUGdhCmdyYWlKbjdrQzA1TXd0NXVrNHBqb0pRbUVmTXdEWmhXNjJtSVBxMzVPemdNRHp4'
    b'aDBOcm84YXF6cHdmY3puMEdqMnd4YUc3MCtlQTcKSmZ5RVZJQXZhV2VmcW1sdjhSa2VzOW13'
    b'YWZwWFg3VU03SURKQXh1RERJNVVZMkY0SFBvR2ZmS2w2YUZ3c0I5R0owTTRyZzNLd2lQQQpy'
    b'djBCeHRQVjU1WFNGTXZnK1dBWWtDOW9BcmFpNTVCRmJ6LzBEMm5LbGVweit3OTY5QTU0b0tv'
    b'Vlp5SnBrVDZxSDdCWVVtZ05vYUNpCmI4QmpYNCtMNjJrY1J6RThwaGtaaCszN0RaUmkyc1hh'
    b'cFhMMWMxVFhBWnQyQk5BRThMV0ZwMjJ5eFJEN2VxZHZBOStIZ1VHZm5rUFYKNWJJRnVPK1JB'
    b'STVyUGlQOHR1OVZiTjVsMFpBMGVNT3JwYzlRU0FYNHNuRDZLcGV0ZXdMMEQxdDA5emtzNmp4'
    b'U0EwVkNQcTVyY004RApKcWN1OXpnMEZLQ3gzbUwvUVkrNmhDWVFVRlFxbW9CdDQzdlRLeklN'
    b'ays1REJvOXU4Z2lHTEJKeHhlaUVUenlxVUtvNnh0L2dLR2hzCm11bzFoYUxtd0VHSE43M0dK'
    b'Wm1BTGJzVXFXeUlrR1dReTN2RTR5YXBTWS9hR3BOQVVKRktsM2pyNjN4Y0QzNzVHNU5DeWVE'
    b'UXNNVkUKMm1Kd3hLV2pGU3diWExmYUY1ZUlLVHpQNHJiZk9yUTFLd0syT2EyS0xKUTA0WWhG'
    b'S25YaysvY091Q3pxRExGcGg0Zmpsbmw0azBrNApyUEM5NlFFM25vYmRCMnphV2t5YWEwc1lj'
    b'aXBOU0FYNDh0QllwL0RkQ28wTkpqdjJUZi82RTJsRlhkSmdRWHVRVE5hZ1hGRTRUclZTCkt4'
    b'K3Vycko1VFN4cUVJc3FKck9hN2o2WHdSR0hiTllsbHplWXpBZlp0YjlDc2FReFRSaFArZGcy'
    b'Yk54U1pzbENSVk85UlNUa1lac2UKYTgrdWhoOUFRNjFtY01SbE1xY3BsaFRackdZeUM0Nmo2'
    b'ZWwxV2RpdVVhcDZndU95MTNsbzN5RWU4WWxGREZZdHNkbTB0WXp2UWJHawpxVGpnYTgyMlBX'
    b'VmNQMEN1YUpESit3eU91UFQwT1l4TitFUkNpcUJsNExpSHE3MmN4akFVdmwrOTlhNVlVaVJy'
    b'Yk9wcURJcVY2dU5QCjJYUEFKQmd3eUV5NnJGZ2l0NUlMcVFCZlZqcmJQTElGUlNwdE1UVG0w'
    b'WEs0NzY2dXRsb2REWTE0bkxKTU01clNPSjZtUG1sd2FOQmoKMVRJTHd3UVVUS1I5U2dXSHQx'
    b'L3NZWnJWTTZvYm5vQ3VkZ1BidHRtNnl5R1pqRklvUllqWVl5eHNON0JNazFUR3BWQzBxS2xS'
    b'RkFvTwpUL1hDSFJveVdiNm9PdlJWTGwrdEVPdGpCcEd3d2pUaDBMQm1XVmYxN012Z2lLSzkx'
    b'YVozRUNvVmgxak1wbXVCUlcrL2k2ZVRPSjdQCndOQWs5YlUyOGFoTHVlU3pla21GUlIzVjk3'
    b'cjdmcGZSOFNDaGtNSTBuZ3AvVFNKdVVDcHJOQnJicmpiaGl5Vk5NcTZtcWp6Zmg1NEIKZ3hX'
    b'TERiUmZrZDhnOGJKbS91UC90ajgzMzc1MFF5MDh1Vk5oS0FQVDhIaDBzOEhFSktUU0J1RndO'
    b'WFMyN05KVUtqNlc0ZEpRNjdLdgpyOW9YbDhsckZJcUp0TS9LSlI0dGpkVjF4aUpRS0Jta3No'
    b'YTJZV0JhQm92UC9BR25uZnRSZXZhdnA3RTJCMERBTmpDTTZ2czhzYzFuCjFWS05iVUZkVXJQ'
    b'aENZK3hGS1FuTlEzMUJybTh6ODY5UHFsSmg5ZWM1eEk2ZkJMbEYzY2JkTFFGUUZXYnRnREJv'
    b'Q0tWcStIOFMyNm0KZmZIbGpQYjlpc2FraCs4ckVqR2ZWNnc0VXFsWnBtTEhQb1h2SzNJRmpl'
    b'ZkJ2bDZIdGlZWDIzUTVOS1E1T0tCWTFHbFRLRmFieTViaApjOS9ESnI2Q1FySGFCYkJxaVVN'
    b'NEpMOUVRaXJBbDUzNkdwZWlFMkQ3WG9ObGk0TDBEWHA0bms4dXIybXFOM0JkOEJ4RnRFUFQy'
    b'Z1NMCk9remFXMHdXdHB0VHZRZkQ0d1lybkJLQncxZWJwRE1RQ1ptVUs1cnloQ0lVcmlNU3Jj'
    b'RUtMcUJRN0NNU1VoVEttckZ4RDh2U3ZQc3kKai9EaFVNc1dOTUdnUmYrUXo3bW5CeWlVTksz'
    b'TkprT2pGUklKaTVGeGI2cTUvTUYzK1B6aU54VThGQUZMMFZSdlVpaHFmSnFwcmU4ZwpuMHRS'
    b'Y1FKb1ZTWWVONWxJZThDUnkzbjI5OW1jdXFLNjZ4ZTJWMHM3MjdKcGJ5a1REQ2orOEpqUGdq'
    b'WnI2Z0x3U2xtemVZL05zaTZMCjd0NFNDbzNqdWRRbDVSZElTQVg0c2hRSStFeWtiWVpITmVH'
    b'd0lobzJ1SGREaFVUVXdIVTE0WkFtRk5GRVE0cUFEY1BqQmdjSGZCd0gKTm05M0dCbjNxSTA3'
    b'TEY5MFpKMWRIWnBOV3oxR3hqVXRUUWJkKy81SVg4OGpoSG1BUS8wTzhiaEJMS0l3REkvTFgr'
    b'OU9CZWZBc09iNgpPMHg4VjlQVmFSQ0xtbFFjQ0FZVXdhQm1Zc0psODA1Rk9BZ3RqZFUreVZP'
    b'VytReVBHdFFsTFlvbDZPNXphYWhKczJ2WGsvVHV2WTdtCjJpRkd4MTNLRllkTDFsYjdJWjh5'
    b'TnVIenlCYm9IL1RKRjMzNmh6U2dTY1o4aHNmQk1neVNOU2FaTEJTS21zRVJqOFVMTENvT0RB'
    b'NXIKT2pzc1d1c2NHdXJrRjBpOHZNM2I4M2ROZFlwTXpzUHpEYlRXREk5Nk5OU2FEQXo3VkZ5'
    b'b3E3V0pobXlpMFNBSEIweHFZaFVDSnRRbApGUzFOSnJHSTRtQy94Y09iampRdGxZSkwxMms2'
    b'V2kxMjdYTlkyRGhJUi9JKzRsSE42dVUyeFVLWjBWR0hVa2xQRGEzbGVYRDc3eFN2CmU2Vm04'
    b'VUpvcUp0KzhYSmRqVVY3cThsYlh1dnowQk9hMU9TUjUvSkZ6ZkNvU3o1ZlltbVhUU3dLSzlv'
    b'ZXByUGhBTHNPT0N4YkhPQ3MKVXpUaDhKRmx0dStGSjdZWk5DUVY4YWlpcThNaVlJTmx1Z3lO'
    b'R1lSREllSXhtMlRDSkJpRUE0YzhiRnN4T2xiOXdOa2lwRkkreXhiSgp5US94OHFlY0haRjVl'
    b'eVR2T2dCL2VOSWlFVGM0YlhHRkg5eGs4STYvdkphaG51dEptT3V4YllpRUZUaGx0dXpSMU5a'
    b'YU5OYVpKT0tLCi9RYzl0T013bWRNWXl1Y2RseWdTc1dvLzRVM3JGZkdZUlRSbVloclZPMGVV'
    b'Z2t6RzU1THpLZ1JubU9veWxZRzl2UVpLS1FiR0RHcHIKVFRJNW41YWtpNjhWN1kwZTdVMHpm'
    b'NDliNzdlcHFURXhWUFdDYUdWQVB1K1R6enRjY3I0bUVhdWV4ZjdsYjMzU09ZUG1laWc2QVZZ'
    b'dQpOY25rTk9sSmowT0RMcTg2UStPb01MbTh4akNoZitJc1ZwMzlhYjcvemN2NTlIOHY4K1Mr'
    b'SUFkNlBjNVo3YlAyVEFsQWNSTDBBWGEvCmF2NTI1QVNCMkY4VkdTNjVQUEw3QUt1ellSb2FP'
    b'OUh1V25wMzNFMTlqV0xQM1E3bjNCbG5lR1dCNVIrd1VFcWpOU3haYURJNm9SamQKNlBQYU95'
    b'T01mME14Zm5pOTV3QmIzbGRFbmVFelBPeGo5aHRVd3BxYWVzV1BQMkh6aGszUkdUOVBJekFa'
    b'OEhIK3JnUzE0SlNnK0prdwpIY00yRmFCN2htWHVYMXdnOG1lYW50MCswU1Jrc2o1TlN3MzhJ'
    b'Y1dhYjljd0RsT2Y2MXpncmd2ekJDOHo2T282UFBFUzBKUzA2TGtKCnhuOFFaT2M1WlJhOENY'
    b'SWxhRjE2QVEyTkhheXdHbm40cytNTVgrUVExSXJhajhicDl1VGlQM0VTOUFIK2RUait1Zm04'
    b'QWZxekhqVVgKd01yWFdLZ05Qazg2OStOV0Jva0YreGsrNExQd1RJdnlCamdqSFNEcisxVHFO'
    b'RG9BQnc1NlpIZG9Gdjh4UUVQaG1VTms5UlU4bkg1RgpiWTFpd1MrQ1JOK3UwWGNZbkxFNWlL'
    b'MlBmZHRZOTVzcjZCSU1IOUFZZXhScXJTYSswY1JpNW1VYTB5YkdJWVBrMnlEeVU0dG93cUE4'
    b'CkRMbEhGQXZHcHAvalVrQXNiZEFmOGhueVBCSnhSUzZ0OFg2bldMWXRRRzNlSlA5ZkhNcHBS'
    b'YnpXWUd5OHlPNnR2NlJqZlMrZG4xUUUKUTVEZkNpdDJ5Mnp0UXZvQVR3cUx4MjN5R2ZqVmIw'
    b'cmtDajZ4SGQya1J4NGlGbEcwTGpYWmQ0ZFB3akdwS1pncy9VMlF5UWVxeTdrWgpSZnVwSm9G'
    b'am5FZC9SWGVRbXJWZzdqQnB5SnJ3STVQRUJ6VGQ1enA0TTJTWnAyRGJoU1hDNTJ2YWJ3MXcx'
    b'bzFoVHYxZEVETUVCOTVSCnBtak4zT1FjV082aS90WWpmNk9pcTlmRzJtNVFmNkZpVmQvTUF5'
    b'RUVQWU8ycFlyS0JMZ2U1SFpxbHQ0WnBERmxZZ01UdjFXRUdqU3gKbUNLZmZoSzdmenROa3ph'
    b'M3J5L1IxKyt6Wks4dHZ6VkNLc0NUUmJSZ1lHOHpHVHJkWVgvUXdSMVNsR09hRmNzdERBTjBn'
    b'eWI1a0VYRQpyZjZ0eU1VMEIyb2NFbythcU8wSzN1OHpPdVJSTzNxa1J2TVU3SGw5bWNpcGly'
    b'cnJiRUtlSXBreW1kaXRDZjZGWm1TeFM3YWd5ZVkwCmt3SE54QXFYMGNzcnhNNVJXTit4YUJt'
    b'M0NLQ3FsZUoyaFhPSlQrWlZIcW1pWDcxRFJQbWtPbjJHTHEwUXUwS1R1OVpnMVdQVnFpeVIK'
    b'TWhsYTRWQlk2aFBkWm1JZk5aOUlUNGREOFgrNTVEZER6V2FUbmpxWFJJOUo4LzVxaWxjTVNM'
    b'M1hvYU96ZWdKa2FOQmo0SEY0YkVtSgoraWFEOXZ0dFR0a2wxWjg0aWZvQVpSTkFlOWFrUFdY'
    b'VGVycFBiNTlQMjVqQjFwMHVRVS9obFJUNzZ5bzBERlJQcGFwT2pSNkJOUnVxClZ3QjNqemtF'
    b'UHVTeXA3K0V2Y1BBOEtHODJxZnVWQ2g5MnlCWlBsSmtkM1hiakgvQnAvZzZCejdna21neHlP'
    b'WTA1U3prSHdiN1AweHEKTWdianRrL085QWtxQ0djTWdsKzNHRjduRVh5clMwMkRnV21DN3ln'
    b'cUd4VEdGMHhXSHRYVU5ZR2E2MjNjajduMGY3eU1la3loeWdwbgpxVS80ZENoZXF6aDFVeEFG'
    b'REhaNUJCY2MyUTc3WXc2bEVVV2Y4c2xySDJ2U0lEa096YSt4Q2VUaDdCMXkxYk00dWFnOWRX'
    b'MXlPZy9JClc1cERYeTV4Y01DajVXYzJxZmM2MUQ1dVkzVkJhS21QOFVzTE42Y0ovYTFQOFJh'
    b'RFpYOE00QU5qbHNkNHMwdm1kQjhXYVl3UUdBVkYKWUFKQ3BrSkh3YkRCTXpWR1VPRWFQa2JJ'
    b'd0RNMGdTZ0VJODlzRDhjT0Q2QUExVEg2bmo3K29OYVFIZFBZZ0ZmUVdOckFMMmxNVjZFZApv'
    b'RkM5aDdoWUMzNU00N3ZBZ0NLODBTQTViTkZZTUFpak9MREVJZkVwbitGdlFUeHJVSDZ6aDY4'
    b'Z2Q3Y2k5RDk4eHI4TDZVdGN6anpECmhuK3c2WnlRaVVLRUJPQko2dzl2THBCWjRGTTdwbWlv'
    b'TXpEU2lpVTNoTmgzdXNQbzJSV2lpeFRsZzRxYWpJSUdvRUZUdjhEQWZwblYKMGFrSlRhVlBv'
    b'NFlOSm0wUGE3R2lOS0twMjJ5eDhFR2JnVmRXNERLZjBmVlFYT09SN1llMy9Ed21CNGlRSnZE'
    b'SnJPdjNBUjY1dEVqNwpXUVptV0RHNjNZZTNsUEZXK0t4Y2JWVm5TdXVjOXZjRHFBNkhOVEdw'
    b'cDI0ZGV6cXRxM2R2ZUo3R05OVzBmNCtXeXppRVE5VWh0NTU2CkpoaFVGSXVhY05TZU5sUGIw'
    b'OWZ6MUwrR01mUFpZcVdxTTl0RlFvcmFPZ1YxMWRjMVVWMnB2d0JHRWo2OURXVlNhT3BzME9m'
    b'NVpQZEIKM1ZZNVRJUlVnUE5DUVdrZStWQ0J4aVVHSGExSCt1OWNGMFluL0ttUVU2bzZXbk13'
    b'QUltWW9xN1dZS2JzMmR2ZFFsdlg1UlN6M1JRbQpibVZCMTh3bkVRN3RMdEx4cXdUbXdEUFBz'
    b'dW9hajk0M3ArazRMenpqc3NOREpWenpWZFEybnNkdzMyOVowTGI3R2ROYWFnM3BqRSsrClVC'
    b'M0pabW9hek1NYTZoU0JvNGJISHhuM0dUamtjZHIzd3lRS3B2eWxGRklCemdlVHpTNHJ6akNK'
    b'eEtyai9XVnovdUZ4K0JRdGpjWlUKMzF4cTB1ZjNZM0ZxdlRKdFJwR3pUN09mTWJ0YTc0REw2'
    b'dk8vUmt2bkdRQnMrbDJPYk80UHhHUFB2UG9vdE05a1NjOHhtcG1qVU54VApwSHltSmhoNFpz'
    b'cVdLb3U1NEcwL3dqUXRPbGU5bHdkdXZaUlZ5NmVQNCs5NmNMRGZaOStvUVYra25uZlZwMmx2'
    b'T3JLdTBRbWZTcVU2CjZGOG9xR2lxTjJoSUdvd3Y5cWpiSm4xL1FnSndmbFNBS3pTMUVVWFBJ'
    b'US9QRDVQS0x5RWUzTWFLeFVkQ2Eyak01enQ3RzduSDZNQUkKS2M3UDlUUDVjRCtuTFRkWjFI'
    b'a2tMTElaZzNqdDRpTWhGMjJuTk9uUEdJQmFQWHNocm5WMUdLNlptdGZoV0F1bVdkMlZrV2dT'
    b'eTBvQwpSd0l3bS9OWi84Y0t1MnFhdVR1NmtKSmhzYnQ3aEU5VStsamFVVjFuWTUzQndYNlA0'
    b'ZlFpRXVFcytjSVlEZlVHbktKaG14d1g0dVEwCjc2OERmRG8vQTN0YlhKcGFEWFRzZi9McVMv'
    b'K0pIVnQramZZenhHT0swWEdmbjI2SmNYdWdDNklCUW5pOEtUREV1UXVjYWVFSGtFeEEKVC9j'
    b'WURXMFhNTnIvSkQzYnZrbGJ1emR0TXFhcHl0TjBLYWQ5c2hWTk91Uk8vNit0ek1CNWVlbzZu'
    b'em5IcFZMUTMzc1FaUzhrbGx6TQo3azNYWUxxL0lYcFVOUm9NVkUvcWpBNjU3SXZXa1RjRERG'
    b'cFJoZzZXV1JuTWtVd1laTEthL2lHYnRXLzhLU3F3aXRyQWJ6bHd3Q1A1CmU1dWtuUDBWSnlu'
    b'cEE1ekJJNDBWQ205MzZMcnd5NXkyNW5JMjNIYzFSdjRIdERWWEs3ZmhNWjk3RG9UNVhiNk9T'
    b'Mk5qWE5SVnBxWHgKbVZXZHIyRnd5S1Bub0k5bHVYUzBCMEJ4ekJNaHBaS1BhV2djZDNwQ2hz'
    b'TUdLS2JxdjVsT2ZQUWZLbE1xV2JTMFFsZW5qVFZEYlovTgphZTUrUW5HUDJjNXBSb3FMNmpP'
    b'c1hscTk0SHRnMkNmbnZaYlh2ZlU3N04rN21UMFB2QnY5RzR0WGJRMGk4NzBKYVFMUEV4bDhM'
    b'c2pHCldaOUpVWmg4RUxpY1NLeVRZdTVJVURVM0dMdzNXV2Ixamw1cWFreTBoc0VSLzhnMGxZ'
    b'Y1pCdFRYR2JTM21zQnNiaUY3L3BWV2ExUDEKQkVtcHJFbE5WaWRQT3JxWnJBNlBGUFBLWlpy'
    b'T3dSNU9YV2tSaTFqVG10aVIrRUlBMHFNUFVoNVZ2S0c3aG9NNlQ1dVNDbEJJQU00ZgpXdEUy'
    b'RktDWXZwTS8zaE1rbjY5Z3Uzb3E1S3BWR0p6NUNodGpsdVZSTnEvSjVmVlVNUG0reGo4cXBB'
    b'eFRZU2lvT004c3lFMURZZG5nClZLclBlVDZFZ3dyWHJ3YWJvYUFtcm9oRkZhRmc5YjluMDk1'
    b'cU1KN3l5V1NxODM4QU9LNGlOYnlOaCs3OUdtYnhQNGdYVEJLK2pQZ2kKcEFrODd4eFNrS3kz'
    b'MkhoNWxyWlZVS3Bva25GamFrckpvMVVjemVDUWYzZzJ0K3FNYkk2cmNSeU40K3FwK1hycmF3'
    b'MmFHMHhpVWFoTgpHbWkvT2hocUlqNzNCbVltcTZlbTNheFVOS1V5OUE5NXBDZDlNQlFHMWRu'
    b'alRBc0N0aUljVkFTRGltalVvTFdwZWkzZzAwMW1OZm1DClJtdE5JUTJOdDBjSTd6Um85SHda'
    b'TVVOSUJUaWZ0R3NZR1hPWW1QQllFYk5vREZZandQT2c1NURIMklUSDRJaG1JdVdUTDBGOXN0'
    b'cSsKckVsVVE5SXlJUnF1TGhNOFhJMEZiV2JzbDN1aE5OWVpKT0xWOXl5WHEzL1R5b2NyeG1K'
    b'Wk16anFVeXk1aktkOERBTWE2Z3lhRzZxaAp2TEREb0NhdXFJbFhCM1I5ZUo5RC9VNlBXazlq'
    b'U0ErZ2tBQ2NaMlV4MEl4aWFadEpLRmdOaFYvK3Fzek9ndzQxdFFaQnUzcXRYRGlzCkNBUmZY'
    b'Z1YwVGJ3NkYzQytvTm15MDBYamtrbjdkRGFZdlBPS0VLR1FZdWt5a3piWElLQWsvSVEwZ2Vl'
    b'bHI5aVRqQy8yc0pMVm56WFYKUGpqUEFjY0R4OU5ZbGtMejFQVjUxYk94VDgyZisxUjJxTU0v'
    b'RzRlVDFUQTRjcnVhWm1wZTNxY2JuUXd6bU8rYzhUbmZQM0pybmRaTQpUVnJ1SDk2VFQvVlQ2'
    b'cU1tTS9mODZ1UFY1NnB6a2xnR0JFeUZZVUlnZE9RMHM1T0RqcEVVUDdZOU9SQ0VWSUR6VVNi'
    b'dTgrbFBSWi9YCnNzUDNhYXpkQnNVNm40NTNQcjhxNm85YjZ2akNIejUvWEwrakM1U084Vnc0'
    b'KzAvZ0RzbUJJRTVxMHI5OUhOaTlpaVVQQllodmYvNlgKajVUenNoMkZrQXJ3WldMaU5vZ1Zx'
    b'bjlQSWozVmYyTnBnOHIxVDdWMk5jNmJOTEhFN05ZWGpNbzJGVUlDOEFTWmEvKy85WkJKMCtE'
    b'MAp6Vm1mTXVHdWFoWG9BZnN2TEJKTHpLN29kaWRuZnJ3OVBNUVZyK2xFSGZVQnkrVXkvM25m'
    b'T0pOZWcrdzRJZWJ5ZXh1L3JDeGJZUWJtCkxuOXVGV0NUaTNkNHBLdElXdEdjTnBrTWVVeTA2'
    b'S2tLMEE3TWZuM1BtSzNaZDhHdzZDODJvL0Q1OEx2T3FUN3MrMXo1bFh1cjRYZjQKTlMvSUg0'
    b'QzRKcjVXamcxeGtnZGc0MmNMc2hWbTJqQ2ZtTnZKOGE2UHFjTjFIa3o4RFBpZFNiclZwL1p6'
    b'UndmcDdMdGN6UllmdGh6NQplVWw5bGdWTkFlN2RIZVZINjNPODVjSXhPdG9hK1Btdk4zUHZu'
    b'aWhCbzh4bHA2VzVaVXZ6QzNSZ2FPVFlFQ2M3T1FueU1tSGJBYjcxCjhWZnpvWXZBd09YMkIv'
    b'b0ErTTFqS1ZZMVpmaVhEM2R3eWF0V3lZWVNZaTUvNkdVVHZId0VBamFmK012eithdDNGT2dk'
    b'R0FmZzc5K3oKaU5OV0x3TGcva2YzeUVZU1FpckFFeU5iaGtMbG1XZFBlc2NWRHc4RUtEZ3Z6'
    b'SjBWbm5la1dhMTE5ZjVkSVlSVWdDK2FEU01SYXBURAp0ZnVTZUFHYmhkRXkyMUpCOW1TQzFB'
    b'WExPRzhLTWhGVzFLNzNDT09RVmtIaWZwbS9YalZCRG92bWlNZWErdUtjM2pOZktQR3ZOMjdt'
    b'CmxnMDUzbjFoa3RYTE92bkN0ZnZ4OVFHdWZGc250aVczcmdraEFYZ2MzZGFYUUpjZC91VlFP'
    b'NFY4dGZxcXpXYllYaDhqRWZBSXAvTmsKSWpHV2J4Nmp0Q1JCd1RUNFA2Y004OFJBaEc1QzdN'
    b'cUYrZGxnTTYrcFMzRkdzdmlNeVl1T0dYN0ZNdi8xaXcreWVTQUtSRm5lRVFGZwoxWUlZTnor'
    b'cStOOC9IT0hDaGNOQWgrd2tJYVFKZkh4MDV3UDhTMTg3RWFlQ1VhamdsejBtakRCaktSK2x3'
    b'YTBMNHlrSXh3SVVMSU11CnU4eldpUWczRjF0NEpGUEROZnRxTWJKbGRvOVlYSEhmQW03ZU43'
    b'djVkdnV5ZFlmREQ1VHZjTXFTV2dET1dSR3ZOb3UxelgwOUVuNUMKU0FYNEFpdFY0Ri8yTkJJ'
    b'TmF2NHdISU5jaFhpZ1FqbGdrcStKRWlybUNZWUNuQkZQc2YyUVNUWm5jREJxa3dCMjVzUHNM'
    b'WVJ3blRLdQpyZzZKVlE0SDZDMEVJR2p5clMzMVhMWWdSMmdPMXdoMjFSZnA2bXdCNE5WckZo'
    b'RDlqMGZKZXpKeHVSQlNBUjRIdm9idEUwRit0OHNpClFSblBnOTVTbUtLeXFadElFVmFnY2hW'
    b'MmVBbkd6U0M1dWloOXErcXdZaDZuaEJ4cUFvcXVtTU1yNGtXYUd3elcyR2xXaEFvWW1USm0K'
    b'Mk9EcnU1b296ZUVFeVN0WDEwejlmMjB5d2F0V0IyVW5DU0VCZUh4RWdsQVQ5SmtvbWV3dHhW'
    b'aFM1L0t1cFZrU3ltR3NKa2x0cm9KZApxREF5N0pJSStweGZ5TkJTbU9UVVlKbVJra0ZYT1VO'
    b'ZDNJZXdTY1lLTVdCRTZZM1ZzcUsxT3FMelhZTUpmdE1kbWRWblVYaThkczMwClc5N2VlRjdE'
    b'OUxHdmhCQVNnQytrUyt0U2xDTWgzSFNadmYyS1gvZEVhVTlDdzFpS1RDSk1McG5BY2oxd1lV'
    b'MUhuanJiNWZGaWhJaXIKU01YQ3JIUXpESllzeUpRWWNZS0VpaFc4bkV1dDdSRkxaZm0zbmdi'
    b'Rzg4KzlPeFpFUnpuUW4rUHg3YjBBM0hEWEprWlRGWnBEbzdLVApoSmdqNlFPY3BRVkpqN2h5'
    b'eVNRQytFV0hoWVZ4OXFoR2dqRUxYSmV6L1FtRzh5RU9oU0xjTWx4TFBGNmhYV3RjMDJKVVc5'
    b'eFphTUMwCkRYS2VCWVVLS3VTekoxSlBPRjFnUmJ0SnIyTXlYRFNvano1N0pYY3czOEtYYmls'
    b'eXhUa0ZUbDNTekpkdkhLV2tFMEN6N0NRaEpBQmYKR0UvdmtTdjZCa0ZURTlJK3J1ZXhMMWlQ'
    b'NldxQ2VBUURtaTFPSEwvZW9pVlZaQ0FjSUpDRHRvVEZvWXhKSUY4aEhGV01aejBhaTNrbQo3'
    b'REE1UjRIbEV2TXFiQit6OFFJR2s0NUZkWmpTNTlZN1VtTDdua09VZEZ4MmxoRFNCRDYrem0w'
    b'dThjOW45aFBGNFlyR1NUQnN5c29nClV6WVlHdFBFS1ZQQ0lCalhKSjBLeEVPY1Q1b094OEVI'
    b'M0xETndqck5SQ2lHRXcyaVhCK1ZjNWpVTnBGaWlhYXd5L2t0cFZsL25vTWoKSlhwSFNqTkV0'
    b'UkJDS3NBLzBVdzNsMzFpWXhzbGJYSElqbEJNRlZDeElDVWZkRU9NdEZzaFhLNlFDbG9NQklP'
    b'Y1ZwaGt1eHRtTEdRVApzRDEwMldQWG1JR1JzRW5tQ3VpNkFDMldTejdyRUc0T3NxVFptOU1Z'
    b'aEtQNUtFL3NQQVRVeU00U1FpckE0ODlWaWhwVnhxOTQwQlRGCnlCYXhveWExaFR4TjZTd29r'
    b'OWQxRmJuTUgrZTlCWjgrQXJSa3M1UzF5ZGlvaHhVMGFjNW5NQ01HcDBTTHZMbytTOGtNRUFv'
    b'cC9tYkIKNE53QzJnancyUFp4MlNsQ1NBWDQ0cmp6MGw3KzF5UHQ5QThxMEE3eHNFOHhZR0ts'
    b'UzZ4WjVQS0hNV2plNFhMWm1Ua0dOOVR5bm5LZQpCVFVPK1hHZnZaWkpueTZ3dnpaS1dMdnN5'
    b'dG9NRkJSR1FORnVGbW1QdTNQK1BEM0ZUbWtCQ3lFQitDS1Z5d28rc0NURjl0b1FTeU5ECk5N'
    b'ZDlQQy9ONnJvS1NzRi9TMmZvZmlUR3hPUDFGQnlYVm0zaXBXMFNZWi8vZnNVRVNzSElXSnBQ'
    b'Ym11aFhEWlkyT2p6ZnpxSE9MUDUKZVk2OHJHelpLVUpJQUw1NHptOHNjSDdqekNNbHg1T2E1'
    b'ZXV5YkwwbFFGVFp4RUltUmNOaDRhdlNVLzE3VFEyYXExODV4S0dzUlZ2VQpwU1lrUTFrSmNj'
    b'S0tHdGtFTDZ4UUNCS25UQkt5bjVvUjNhT2haZnExZmZHQVpsVzlJK0VuaEZTQUo1OW9YT01a'
    b'MVpJdlZPL0lCaEZDCktzRDVvNUkvTXNpZk1xVEtFMElDY0I1eGpnckFTc0dVRFNMRVM3VUpQ'
    b'UGdSR1VkdXhpcHVJUHU4bHRNYWlwTVdUdzN2NTJRc25JckMKRHN5dEVuVDdUMnh3dW9NR2Nt'
    b'eUlrejRBaTQvSXBSUXo4V3ZuZG9GZHFhSVozbStUMmhjaGtJdE9QUjdWUWJiL3VwYmswaHlO'
    b'aTh0RQpvN05icjU4L3NkOWZGMEdPRFhIU0I2QnNnai9OU0ovSmdZMGhmRmVoQ2dGcTdDQysx'
    b'aGhIM2RkbUZRT01QWm1rYjJjZTA0VE9VeXQwCnJwQ1RJMEtjYU5JSCtDZndQSmhJYVU1N2ZZ'
    b'NTRnMGUwMGNGWlBFTFpjQ25VWkNqR2NsUUNGVXJ0NDRRNjhvUWljTmFiOGpqYUo1T1YKa3lO'
    b'Q1NBWDRNbWFhc1BJMG4zeGVFV21xc0dSMWtWMmJUTnJYalZNdUdKVHpKbzFkT1E1c056bjFn'
    b'anlEdlNhVGs3QjRwWWZjd3lhRQpCT0JKSVJxRkphczlBTHBPY1FrRkZMN25VU2g0eE9Ld1lv'
    b'MERLRm9YZUxLeGhKQUFmQmswYjFVanZUc3ZuZk55MmNFaEFqdDI0UlVLCjJNVVNlOUEwdlBP'
    b'S09SZDgyWElmLzZQeFMxTS9OMjRhcGFOUXZhTmtJS2dZUHJ0cDZybW1UV08wRjZyaE9oaFFE'
    b'SjF6NUxtNnJlTzAKRktvRExVd0VESWJPYkp4NnJuYjdCSzI1YWwva21LVVlXWE5rdWNkanZa'
    b'QU95SUVnSkFEbm8yQ3doclYvOFlWblBLNjE1dENoUStUegplVG83TzRsR285T2U3N256YnVw'
    b'Lyt1bW4xc0loN2JIeUx6NlBVbk5Md1BnTjM2RjJ5ZmVuZms3dk5lZ2FySjZWUGRqcFVQUHU3'
    b'cW5uCkp2Y1pMRHo4WEcrYnk0VkhQWmZ1TnVqcU8veGNTMm42Yy8rczZEcFlEYm5lQnBmRVVj'
    b'LzE3eWhJQUlxVG5wd0VtWU83N3JxTHl5NjcKakhQUFBaZUxMcnFJTld2VzhLMXZmUXZQbTMz'
    b'VHRyZTNsODk5N25POC92V3ZaL1hxMWZ6NW4vODVkOTU1cDJ4Y0lTUUFYN29lZWVRUgpsaXha'
    b'd29JRkM3RHRha1UxT1RuSlY3N3lGVzY1NVpaWnJXUC8vdjFzM3J5Wmh4NTZpRzNidHBGS3Bm'
    b'ajk3My9QaHo3MEllNjU1eDdaCnlFSklBTDVFNk9tWHFZeVBqOVBTMHNMM3Z2YzlicjMxVmk2'
    b'OTlOS3BJSnh0ZU8zYnQ0OVh2dktWM0hiYmJWeDExVlYwZFhWTk5hdHYKdXVrbTJlWkNTQUMr'
    b'Tk9YeWVhNi8vbm8yYk5oQUlwSGdneC84SU4vKzlyZTUrT0tMcDRMd3VaUktKVFp1M0lobFdi'
    b'ei8vZS9uK3V1dgo1d3RmK0FLTEZpMWlZbUpDTnJJUUx6STVDVEpMcVlrSkh0KzRrYzkrOXJN'
    b'QUxGdTJqSlVyVjNMZWVlZVJUQ2JadEdrVGl4Y3ZmdFoxCnVLN0wvZmZmejBjLytsRnFhMnVw'
    b'cmExbDZkS2xmT3BUbnlLVlN0SGIyMHRyYSt1c0ExVUlJUUY0M0tYVGFYN3dneDh3TURBdzlW'
    b'aTUKWE9hM3YvMHRnNE9EckZ1M2pzN09UaVltSmtpWFM5VFBzSTU4UHM5WHYvcFZlbnQ3cTRH'
    b'YVNyRmd3UUs2dTd0NThNRUh1ZkxLS3lrVQpDdXpmdjU4VksxYWM4TzhzbDJrTGFRSUxBSkxK'
    b'SktlZmZ2cTB4M3A3ZXlrV2kzUjBkUEQydDcrZGNEaE1KQkxCTjJjZXhTVWFqYkptCnpacHBq'
    b'NDJOalRFeE1jRlpaNTNGR1dlY1FWdGJHNjdyenZtU21lT1RnQktCUWdKdy9ucmFTWkQzdmU5'
    b'OU03NXNlSGlZWGJ0MmtVNm4KYVc1dXhuTXF4MXpsRzkvNHhtay9Gd29GTE12aU5hOTVEYTJ0'
    b'cmVUemVSb2FHbDRTWDEvSmtTR2tDU3llc203ZE9tNjc3VGIyN2R2SApvNDgraWxLS2Rldldz'
    b'WHo1Y2txbEVzUER3OXg1NTUxMHFXT1A0N2R3NFVLKzlLVXYwZHZieXcwMzNJQnQyMXgrK2VW'
    b'MGRYWGh1aTZGClFvR3hzVEVzNjhUdkZ0K1R3UnFFQk9EOExRQ1pIZ0MyYmRQYzNFeC9meitm'
    b'K2N4bjJMOS9QOEZna0dnMFNsZFhGeXRYcnFTN3U1dEkKVCs4eDE1blA1K25vNkdEdDJyVTgr'
    b'ZVNUZk94akg4TzJiWHpmeC9NOHVycTYyTGh4SThsazhzUUhvSXpXSmFRSlBIOTV4ZEl6SG92'
    b'SAo0eXhjdUpEZHUzZmp1aTZUazVNRUFnSEd4c1lZR2hwaTJiSmx6N3JPQ3k2NGdOV3JWeE9K'
    b'UlBqSVJ6NUNQcC9uckxQTzRweHp6c0UwClRZYUhoMW0yYkJsTGx5NlZBQlJDS3NBVCtKZWhV'
    b'S1JVS2hFS2hhWWVlK3JTRmFoZTA5ZmYzMDhnRUtDbHBXWFc2KzNvNkFDZ3M3TnoKMnVQdDdl'
    b'M1Ruai9Sbkx3Y0EwSUNjTjVxTFJiNTVTZitua1YxZGMvNnV0R24vVnpxSDV4MkdVeEF3OFAv'
    b'K1BrNW4xUk5GUTVTdTJTVwpMMzZCVDlqbThwcHdVUm9IUWdKdzNycllDTER4N25zNEpSajlr'
    b'OWJUWkpnMC9lTDJPUyszcTc0Qzd6a3gzMzNuYnBmVEhSdGtRanR4CnNyZjBaQlBNYklWcDBl'
    b'L1B6d0ZNdDJ4MGVhTVpsb05BblB3Vm9KR1F5eDJPSlYveVQ5aDduOGpyOFBJVG1rZ0NRSTRO'
    b'Y1pJSFlOZnYKMHJJVmp1VXZmYm9IZmF3NTlMR1pycVl0YzZUdDZCaWFvZVRjZzJSeUNUU2Zv'
    b'Sy90SkYyNmZpckhoWmdIQVNpYjROZ3VmNTlCbi9VcAozdnlXZDA1N2ZHeHNqRnR2dlpWTm16'
    b'Ymh1aTRyVjY3a1BlOTVEeTB0TGZUY2VUZjgzYWVuWGp0aWU2eThmeE9HTWJlU3p0ajBMZkIr'
    b'CitLSi81MTM3WFU1YkpmdGVTQUJLQUY0S0gvN2lIZE1Dc0tlbmg1dHZ2cG52ZnZlN2xFclZh'
    b'd1Z2dmZWV2JyamhCbTY5OWRibnJxNGMKaC92dnY1L0hIbnVNZkQ3UDBxVkxlZHZiM2paMWVj'
    b'MnNITWVXNlI4ZUxuUDFaK1d3RUJLQUFpaG05MUNwVkFnRXF2TmpQUFRRUTN6OAo0eC9ub29z'
    b'dTRvYy8vQ0YzM0hFSG51ZlIwOVBEOWRkZnoxdVhMai9tdXRMcE5ELzV5VS80eGplK2dlTWN1'
    b'ZEw0eHovK01UZmVlT1BUCnJpYzhNZjF2azFtUFVFQU9DekUveUZuZzUvRHBEdy95NHg5OWJl'
    b'cG4yN1laSHg5bnpabzFmUC83MytmbW0yL21YZTk2RjZacDB0M2QKL2F6cit1TWYvOGhIUHZJ'
    b'UnJyMzJXaTY2NktLcHgvZnUzY3MxMTF4endyL3JRNDlYdVBSQ0dRVkdTQVVvRGx2V1piQjcr'
    b'NzFvL1VtVQpVbFFjaDA5LytoOUlwMVBVMXRZeU1USEJGVmRjd2RxMWE1OXpHQ3ZmOThubGNx'
    b'eGJ0NDUxNjlaeDExMTNjY01OTjNEUFBmZXdmZnYyCnB6VnpYL3dLOEtFbnl2ekgxWEx4bjVB'
    b'QUZFZDUvMXNQOFBQcnZzZHJYL2QyL3ZtclgyVjRlQmdBMHpScGJHemtxcXV1NGhXdmVBV3YK'
    b'Zi8zclNWbjJqQU9pUXJYLzcrcXJyMlppWW9Ka01ra21rK0hpaXkvbWtrc3VJWlBKUE8vUHA1'
    b'OHRkMmRaMFBWVVhGWXRsc3RlaEFTZwplSnBMTHRUODVCTTNjdGxiM2pmdDN1Q25SbkVaSFIz'
    b'bDhzc3ZaL1hxMVJRUDlNeTRqa0tod005KzlqT2VlT0tKcVdrMG01dWIyYkpsCkMwMU5UYnp6'
    b'bmU5a3c0WU50TGUzMDl6Y1BLZGI1OVN6NWRZc00rMjNab0hyL2tZT0J6Ry9TQi9nTEgzMnlo'
    b'NSs5SU92OElZM3ZPR28KVnFwbWRMUjZOL0NlUFhzQWlOVE5mRFpYYTAyNVhKNDJoN0JwbXV6'
    b'Y3VaUDYrbnJPUC85OGJOdkdjUndlZXVpaEYvVzcvZG91Y3VGNwpmTm5KUWlwQU1iTVZpd3pj'
    b'N04yY2RzYi81ZDN2ZmpjSER4NmtycTZPODg0N2o5SFJVVjc5NmxlVHpXWXhCb2RtWEQ0YWpY'
    b'TFJSUmV4ClpjdVdxY2VlbW1Qa3dJRURORGMzbzdWbTI3WnRyRml4Z2twNjA0dlNCQzVvelFO'
    b'TmVXNzRyOUwzSnlRQXhiUDQraWN6dk90dmY4cTMKdm5zN2ZYMTk3Tml4QTh1eThEeVBUQ2JE'
    b'R1dlY2daTXZIblA1Tjc3eGpXemR1cFgrL240R0J3ZkpaRExZdHMzNzN2YysxcTlmejZtbgpu'
    b'a28wR2lXZnovTml6UXYzei9GSnZ2UHZFbjVDQWxETXdoZi9aaGYvOU5rcitmeVgvZzNETU1q'
    b'bGNxeGF0WW9GQ3hZQTBMTjU2ekdYClBmMzAwL241ejM4K05aTmNZMk1qWC92YTE2aXZyMmRz'
    b'Ykl6eDhYRzZ1cnJJNS9ObzUvaWZrTGdqVStUQ0QzbzAxa3RQaUpBQUZMT3cKZkpIaTNKWDNj'
    b'ZTFQcnVZdlB2RFI1N1dPMXRaV3Jybm1Ham82T2pBTUE4TXdTQ1FTNVBONXhzZkhXYjU4T2Iy'
    b'N2orLzMyTExMSWJlMAp3b2ZlTDRlQW1ML2tULy96OElFckhMTEQxM0RuSGYvNXZOZXhkdTFh'
    b'MnR2YktaZkxhSzBaR3h1alVxbE1UYTk1UEs4RDdCdHcrYzE5ClJYNXdsWVNma0FBVXo4Tm4v'
    b'enJMbGtldVl2MzZYODR0ZlByNk9IandJUDM5L1d6WXNJRmdNRWdxbGVLQ0N5NmdwcWJtdUUr'
    b'S2ZtalkKNDlwZkZQajUxUkorUWtnQS9nbSsvc2tNbXgvOEluZmNkdDJzWHA5T3ArbnA2Y0V3'
    b'RE1iSHgybHJheU9aVE5MUTBFQnZieTlkWFYyegpXcytjYmxZNzZzV0h5aDdYM3BUbnh1OVlH'
    b'TExuaFpBQS9GTmQ5ZmNwK25kZnhRLy83YXJuZk8zQXdBQjFkWFYwZG5aeTJtbW5zV1RKCkVy'
    b'WnQyMGFoVUNDWlRCSU1CbWYxbm5OcUhCOSs4Ui9NRXI5dnpuUFR2MHI0Q1NFQitBTDZoeXZ6'
    b'ckd6OEVYLzNzZmRTY1NySGZOMjkKOTk3TEthZWNNdTB4eDNFb0ZvdGtzMW42Ky91Wm5KeDh6'
    b'cGliU3dXb0ZmeHJPTU8rUzNMOCtGclozVUpJQUI0SGYvWUdqeTkrNUJHKwplZDFYZVB3WVEw'
    b'aGZlZVdWejNqc3JMUE9vbGdzMHRUVVJDcVY0c0NCQXkvWVo5cTkzK1diNlF4WGZOUGhpMStR'
    b'YS8yRWtBQThqanBhCjRPYWZEdkhrSlFXK0hDNlIxczk5ZTFrc0Z1T2NjODVoWkdTRVRDWXpO'
    b'Vit3ZnBhendNL1ZCQzRVTmQrL0xzZkdyWG51K0pYQkJXdGsKTndzeEV6a1ZlQno4djgrWHlQ'
    b'd2QvUFdIYzNEQTVqUFpMRFUxTmMrNlRIdDcrOVRrNk0vbFdFM2duTmJjbU0yVHZhN0NOejlq'
    b'MFZBbgp3U2VFQk9BSmtJakJUNjgxR1J6MitZZC92SmhnN0ZUZTltZi9rN1BXbkQvTE5jeitW'
    b'TWVtZklVYmtubnlMUzVmL1pwSlc3UHNWaUVrCkFGOENXcHZoMzc4OGp1L2Z6emQrL0RBM1hM'
    b'ZUllSEl4NTV4M01hKzcrRElzYSs2N3dOSFYwWnUzN0txUUwvaWM4UWI0M29jc0RFUDYKK1lT'
    b'WUN6WCtsYVNNZ25rQzNMYmRZMzFmSFhhc2tWQzhnV2l5bWRyR0Zob2Fta2syTk5HejVYYWlv'
    b'VHVaVEdzbVVwcjBneEFvSzhxMgpUOTcyZU5ONUptOWRIWkFOS2NTZkVvQjc2dG9rQUY4aUJu'
    b'MlBQdCtqMzNjcCs1cVlZZEJrbUhRWkZrMXk4WjRRMGdRK3Fadkxoa21yCllRSlMyUW54WXBD'
    b'eVFnZ2hBU2lFRUJLQVFnZ2hBU2lFRUJLQVFnZ2hBU2lFRUJLQVFnZ2hBU2lFRUJLQVFnZ2hB'
    b'U2lFRUJLQVFnZ2gKQVNpRUVCS0FRZ2doQVNpRUVCS0FRZ2doQVNpRUVCS0FRZ2doQVNpRUVC'
    b'S0FRZ2doQVNpRUVCS0FRZ2p4Z2xDNW0rTXlMYVlRWW40RwpvTHMvTEFFb2hKQW1zQkJDU0FB'
    b'S0lZUUVvQkJDU0FBS0lZUUVvQkJDU0FBS0lZUUVvQkJDU0FBS0lZUUVvQkJDU0FBS0lZUUVv'
    b'QkJDClNBQUtJWVFFb0JCQ1NBQUtJWVFFb0JCQ1NBQUtJWVFFb0JCQ1NBQUtJWVFFb0JCQ1NB'
    b'QUtJWVFFb0JCQ1BGOFdtZ0haREVLSStlai8KQStMZFdybmNJR1FJQUFBQUpYUkZXSFJrWVhS'
    b'bE9tTnlaV0YwWlFBeU1ESXpMVEEyTFRFNVZEQXpPalEyT2pNeUt6QXdPakF3Ni9oOAovUUFB'
    b'QUNWMFJWaDBaR0YwWlRwdGIyUnBabmtBTWpBeU15MHdOaTB4T1ZRd016bzBOam96TWlzd01E'
    b'b3dNSnFseEVFQUFBQUFTVVZPClJLNUNZSUk9CiIgaWQ9ImltYWdlMTAiIC8+CiAgPC9nPgo8'
    b'L3N2Zz4K', 'ES_AR')

ES_AR = b64_ES_AR
index.append("ES_AR")
index.append("Spain Aragon")
catalog["ES_AR"] = ES_AR
catalog["Spain Aragon"] = ES_AR
country["Spain Aragon"] = ('ES_AR', '', 1)
lookup["ES_AR"] = ('ES_AR', '', 'Spain Aragon', 1)
lookup["Zaragoza Spain Aragon"] = ('ES_AR', '', 'Spain Aragon', 1)
lookup["Spain Aragon"] = ('ES_AR', '', 'Spain Aragon', 1)
details["ES_AR"] = {"continent":"Europe","capital":"Zaragoza","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_AR"] = ('ES_AR', 'Spain Aragon', 1)
regional["Spain Aragon"] = ('ES_AR', 'Spain Aragon', 1)
#----------------------------------------------------------------------
b64_ES_AS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NDQo8c3ZnIHhtbG5zPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgd2lkdGg9IjkwMCIgaGVpZ2h0PSI2MDAiPg0N'
    b'CjxyZWN0IHdpZHRoPSI5MDAiIGhlaWdodD0iNjAwIiBmaWxsPSIjMDZmIi8+DQ0KPGcgZmls'
    b'bD0iI2Y3ZDQxNyI+DQ0KPHBhdGggZD0ibTIxNC41NiwzMTEuMjQsMi4xMTc5LDQuNzYyNi0x'
    b'NC45MTQsMjYuODEyLTQuNTAwNiw1LjExNTIsMTQuNjQ5LDAtMi4zODI4LTUuNzMyNywyLjgy'
    b'NC01LjExNTIsMTAuMTQ4LDguOTk1OCwxMC4wNi04Ljk5NTgsMi44MjQsNS4xMTUyLTIuMzgy'
    b'OCw1LjczMjcsMTQuNjQ5LDAtNC40MTIzLTUuMTE1Mi0xNS4wMDItMjYuODEyLDIuMjA2Mi00'
    b'Ljc2MjYtMTUuODg1LDB6bTcuOTQyNCw3Ljc2MTEsNi4zNTM4LDExLjQ2NS02LjM1MzgsNS43'
    b'MzI3LTYuNDQyLTUuNzMyNyw2LjQ0Mi0xMS40NjV6Ii8+DQ0KPHBhdGggZD0ibTI3Mi41OCwy'
    b'OTcuMDdjMi41NjM3LDQuNjg1OSw2LjE3NTgsOC42NDIsMTAuNDg3LDExLjUwM2wtMS42OSwx'
    b'NTguNzljLTEuOTQ4MSwwLjM2MTExLTE0LjkzOSwxMy42MDktMTUuNDk4LDE1LjgyNS0wLjIz'
    b'MzEyLDEuMDk1MS0wLjQwODM0LDIuMjUyLTAuNDA4MzQsMy4zNDcxLDAsNy40MjU5LDUuNzY4'
    b'NiwxMy40NTEsMTIuOTM2LDEzLjQ1MSwzLjcyODIsMCw3LjM0MTQtMS43MDM5LDkuNzg4OC00'
    b'LjY4NTksMy4yNjMsMy4wNDMsNy40NTc0LDQuNjg1OSwxMS43NjksNC42ODU5LDQuMzcwNyww'
    b'LDguNTY1MS0xLjY0MywxMS43Ny00LjY4NTksMi40NDc0LDIuOTgyLDYuMDU5Niw0LjY4NTks'
    b'OS43ODg4LDQuNjg1OSw3LjE2NjQsMCwxMi45MzUtNi4wMjUsMTIuOTM1LTEzLjQ1MSwwLTEu'
    b'MDk1MS0wLjExNTM2LTIuMjUyLTAuNDA3MjUtMy4yODYxLTAuMzIzMjMtMS4zNjg5LTEzLjk4'
    b'Mi0xNS42MDUtMTUuNDk5LTE1Ljg4NmwtMS42OS0xNTguNzljNC4zNzA3LTIuOTIxMSw3Ljk4'
    b'MjktNi44NzgxLDEwLjU0Ni0xMS41MDNsODguNDQ4LTAuNzMwOTJjMC42NDE0Niw1LjQ0Njks'
    b'MTEuNjM4LDIwLjA4NiwxNy4wNzIsMjAuMDg2LDUuNzY3NSwwLDEwLjQyOS00LjkzLDEwLjQy'
    b'OS0xMC44OTUsMC0zLjUzMDEtMS41NzI4LTYuNzU2LTQuMzExNS04LjgyNTEtMi4zODk1LTEu'
    b'ODI2LTEuMTY1OC01Ljc4MywxLjgwNjItNS43ODMsMS4wNDg3LDAsMi4wMzkzLDAuNTQ4MDgs'
    b'Mi42MjE2LDEuNTIxOSwwLjkzMjQ3LDAuMjQzMTMsMS44NjUyLDAuMzY1MDMsMi43OTc2LDAu'
    b'MzY1MDMsNC4xOTQ0LDAsNy45MjM2LTIuNTU2MSw5LjYxMzgtNi41MTIsMC42OTg0OS0xLjc2'
    b'NTEsMS4xMDY2LTMuNjUyLDEuMTA2Ni01LjUzOXMtMC40MDgxMi0zLjcxMy0xLjEwNjYtNS40'
    b'NzhjLTEuNjg5OS0zLjk1NjEtNS40MTkyLTYuNTczMS05LjYxMzgtNi41NzMxLTAuOTMyNDgs'
    b'MC0xLjg2NTIsMC4xODI4NC0yLjc5NzYsMC40MjU5OC0xLjYzMSwyLjczOTEtNS42NTE0LDEu'
    b'NTIxOS01LjY1MTQtMS43MDM5LDAtMC45NzQwNywwLjQ2NjI0LTEuOTQ3OSwxLjIyMzctMi41'
    b'NTY5LDIuNzM4Ny0yLjA2ODksNC4zMTE1LTUuMzU1OSw0LjMxMTUtOC44MjUxLDAtNi4wMjUt'
    b'NC42NjE3LTEwLjg5NS0xMC40MjktMTAuODk1LTUuNDI2MiwwLTE2LjQzMywxNC42NTUtMTcu'
    b'MDcyLDIwLjA4NmwtODguNDM3LTAuNzYxODRjLTIuNzg2MS01LjExNTItNi44MTI5LTkuMzU5'
    b'Ny0xMS43MS0xMi4yNzZsLTAuODI3MTMtMTA5LjMyYzQuOTQ0OS0wLjYzNDk4LDE5LjE3LTEy'
    b'LjY3LDE5LjE3LTE3LjgzMywwLTUuOTY1LTQuNjYxNy0xMC44OTUtMTAuNDMtMTAuODk1LTMu'
    b'MzIwOSwwLTYuNDY2OCwxLjcwNS04LjM5MDEsNC41MDQtMS43NDgxLDIuNDk2LTUuNTM1Miwx'
    b'LjIxOC01LjUzNTItMS44ODYsMC0xLjA5NiwwLjUyNDM1LTIuMTMxLDEuMzk4OS0yLjY3OCww'
    b'LjI5MTI0LTAuOTc0LDAuNDA3MjUtMi4wMDksMC40MDcyNS0yLjk4MjksMC00LjMyMTEtMi40'
    b'NDc0LTguMjc3LTYuMjM0OC05Ljk4Mi0xLjY4OTEtMC43OTEtMy40OTYxLTEuMTU2LTUuMzAy'
    b'My0xLjE1Ni0xLjgwNiwwLTMuNjEyMSwwLjM2NTAzLTUuMjQ0MiwxLjE1Ni0zLjg0NTMsMS43'
    b'MDUtNi4yOTI3LDUuNjYxMS02LjI5MjcsOS45ODIsMCwxLjAzNSwwLjExNzU0LDIuMDA5LDAu'
    b'NDA4MzQsMi45ODI5LDAuODc0NTgsMC41NDY5NywxLjQ1NjgsMS41ODIsMS40NTY4LDIuNjc4'
    b'LDAsMS43NjUtMS4zOTg5LDMuMjI1LTMuMDg3OCwzLjIyNS0wLjk5MDU5LDAtMS44NjUyLTAu'
    b'NDg1OTctMi40NDc0LTEuMzM5LTEuOTgxMi0yLjc5OS01LjEyNzEtNC41MDQtOC40NDkxLTQu'
    b'NTA0LTUuNzY4NiwwLTEwLjQyOSw0LjkzLTEwLjQyOSwxMC44OTUsMCw1LjY2MzEsMTQuMDI5'
    b'LDE3LjI0OSwxOS4yMjgsMTcuODMzbC0wLjg3MzQ5LDEwOS4zMWMtNC44MzU5LDIuOTIxMS04'
    b'Ljg1NjMsNy4xMjEtMTEuNjUzLDEyLjIzM2wtODguNTA3LDAuNzkyMDljLTAuNjAzMzItNS4x'
    b'MjYxLTEyLjE3LTIwLjA4Ni0xNy4wNzItMjAuMDg2LTUuNzY4NiwwLTEwLjQyOSw0Ljg3MDEt'
    b'MTAuNDI5LDEwLjg5NSwwLDMuNDY5LDEuNjMxLDYuNzU2LDQuMzExNSw4LjgyNTEsMC43NTc0'
    b'NiwwLjYwOTAzLDEuMjIzNywxLjU4MzEsMS4yMjM3LDIuNTU2OSwwLDEuNzY1MS0xLjM0MDgs'
    b'My4yMjYtMy4wMjk5LDMuMjI2LTEuMDQ5NiwwLTIuMDM5Mi0wLjU0ODA5LTIuNTY0NS0xLjUy'
    b'MTktMC45MzE1Ni0wLjI0MzE0LTEuOTIyMi0wLjQyNTk4LTIuODU0Ny0wLjQyNTk4LTQuMTM2'
    b'NSwwLTcuOTIzNiwyLjYxNy05LjU1NTcsNi41NzMxLTAuNzU3NDUsMS43MDM5LTEuMTA2Niwz'
    b'LjU5MTEtMS4xMDY2LDUuNDc4LDAsMS45NDgxLDAuMzQ5MiwzLjc3MzksMS4xMDY2LDUuNTM5'
    b'LDEuNjMyLDMuOTU2MSw1LjQxOTIsNi41MTIsOS41NTU3LDYuNTEyLDAuOTMyNTYsMCwxLjky'
    b'MzItMC4xMjE5LDIuODU0Ny0wLjQyNTk4LDEuNjMyLTIuNjc4LDUuNTk0NC0xLjQ2MSw1LjU5'
    b'NDQsMS43MDM5LDAsMS4wMzUtMC40NjYyOCwyLjAwOTEtMS4yMjM3LDIuNjE4MS0yLjY4MDUs'
    b'Mi4wMDgtNC4zMTE1LDUuMjk1LTQuMzExNSw4LjgyNTEsMCw1Ljk2NSw0LjY2MDksMTAuODk1'
    b'LDEwLjQyOSwxMC44OTUsNC44Nzk4LDAsMTYuNDcyLTE0Ljk4NywxNy4wNzItMjAuMDg2bDg4'
    b'LjUwNywwLjczMDkyLTAuMDAwMDQsMC4wMDAwMnoiLz4NDQo8cGF0aCBkPSJtMjE5LjYzLDI5'
    b'Ni42Niw1LjcwNjMsMC4wNjUzLDAsMTQuNDc1LTUuNzA2MywwLDAsMHoiLz4NDQo8cGF0aCBk'
    b'PSJtMzcxLjE2LDMxMy44OGMxLjU3MzEsMS4yMTgxLDIuNTYzNiwzLjA0MywyLjczODYsNS4x'
    b'MTMsMC4xMTUzNywwLjc5MSwwLjE3NDE0LDEuNTgyLDAuMTc0MTQsMi40MzQsMCwzLjgzNTEt'
    b'MC45MzI0OCw3LjYwNzktMi42ODA2LDEwLjk1Ni0yLjY4MDUsNS4yOTUtOS45NjQsNC45My0x'
    b'Mi4xNzctMC41NDgwOS0wLjkzMjQ3LTIuMzczLTEuMzk4OS00LjkyOTktMS4zNDA4LTcuNDg2'
    b'LDAuMjMzMTItNS41OTk5LDMuMzIyLTEwLjcxMiw4LjE1NzgtMTMuMTQ3aC0xMy4wNTJjMC42'
    b'OTkzNSwwLjY2OTk4LDEuMDQ4NywxLjUyMTksMS4wNDg3LDIuNDk2LDAsMC4zMDQwOCwwLDAu'
    b'NjA3OTUtMC4xMTUzNiwwLjkxMzEyLTEuMDQ5NiwzLjg5NDktMS41NzM5LDcuOTcyOS0xLjU3'
    b'MzksMTIuMDUxLDAsMi4wMDgsMC4xMTc1NCwzLjk1NjEsMC40MDgxMiw1Ljk2NDEsMC44MTU1'
    b'OSw2LjY5NjEsNi4zNTA4LDExLjc0NywxMi44NzcsMTEuNzQ3LDUuMTI4MiwwLDkuNzg4OC0z'
    b'LjE2NTEsMTEuODI4LTguMDM0MSwyLjA5NzIsNC45Myw2Ljc1OTEsOC4wMzQxLDExLjg4Niw4'
    b'LjAzNDEsNi41MjYsMCwxMi4wNjEtNS4wNTEsMTIuODc4LTExLjgwNywwLjIzMjAzLTIuMDA5'
    b'MSwwLjQwNzI1LTMuOTU3LDAuNDA3MjUtNS45MDQsMC00LjA3OC0wLjU4MjI2LTguMDk1LTEu'
    b'NjMxLTEyLjA1MS0wLjI5MTIzLTEuMjE4MSwwLjA1ODgtMi41NTY5LDAuOTMxNjEtMy40MDkx'
    b'aC0xMy4wMDdjNC44MzU5LDIuNDk2LDcuOTIzNiw3LjU0Nyw4LjA5ODksMTMuMTQ3djAuNjA5'
    b'MDNjMCwyLjMxMjEtMC40MDgzNCw0LjY4NTktMS4yODE4LDYuODc3LTIuMjE0Myw1LjQ3OC05'
    b'LjQ5NzgsNS44NDMxLTEyLjE3OCwwLjYwOTA0LTIuMTU1My00LjEzOS0zLjAyOTktOC44MjUx'
    b'LTIuNTYzNC0xMy41MTIsMC4yMzMxMi0yLjAwOTEsMS4yMjM3LTMuODM0LDIuNzk2Ni01LjA1'
    b'MjFoLTEyLjY0NHYwLjAwMDAyeiIvPg0NCjxwYXRoIGQ9Im0zNzQuNjEsMjk2LjcyLDUuNzcx'
    b'Ni0wLjA2NTMsMCwxNy4yMTctNS43NzE2LDAsMCwweiIvPg0NCjwvZz4NDQo8L3N2Zz4NDQo=', 'ES_AS')

ES_AS = b64_ES_AS
index.append("ES_AS")
index.append("Spain Asturias")
catalog["ES_AS"] = ES_AS
catalog["Spain Asturias"] = ES_AS
country["Spain Asturias"] = ('ES_AS', '', 1)
lookup["ES_AS"] = ('ES_AS', '', 'Spain Asturias', 1)
lookup["Oviedo Spain Asturias"] = ('ES_AS', '', 'Spain Asturias', 1)
lookup["Spain Asturias"] = ('ES_AS', '', 'Spain Asturias', 1)
details["ES_AS"] = {"continent":"Europe","capital":"Oviedo","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_AS"] = ('ES_AS', 'Spain Asturias', 1)
regional["Spain Asturias"] = ('ES_AS', 'Spain Asturias', 1)
#----------------------------------------------------------------------
b64_ES_CB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgo8c3ZnCiAgIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4x'
    b'LyIKICAgeG1sbnM6Y2M9Imh0dHA6Ly9jcmVhdGl2ZWNvbW1vbnMub3JnL25zIyIKICAgeG1s'
    b'bnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29k'
    b'aXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6aW5r'
    b'c2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAg'
    b'IHdpZHRoPSI3NTAiCiAgIGhlaWdodD0iNTAwIgogICBpZD0ic3ZnMzYwMyIKICAgc29kaXBv'
    b'ZGk6dmVyc2lvbj0iMC4zMiIKICAgaW5rc2NhcGU6dmVyc2lvbj0iMC40NiIKICAgdmVyc2lv'
    b'bj0iMS4wIgogICBzb2RpcG9kaTpkb2NuYW1lPSJCYW5kZXJhIGRlIENhbnRhYnJpYSAoc2lu'
    b'IGVzY3Vkbykuc3ZnIgogICBpbmtzY2FwZTpvdXRwdXRfZXh0ZW5zaW9uPSJvcmcuaW5rc2Nh'
    b'cGUub3V0cHV0LnN2Zy5pbmtzY2FwZSI+CiAgPGRlZnMKICAgICBpZD0iZGVmczM2MDUiPgog'
    b'ICAgPGlua3NjYXBlOnBlcnNwZWN0aXZlCiAgICAgICBzb2RpcG9kaTp0eXBlPSJpbmtzY2Fw'
    b'ZTpwZXJzcDNkIgogICAgICAgaW5rc2NhcGU6dnBfeD0iMCA6IDUyNi4xODEwOSA6IDEiCiAg'
    b'ICAgICBpbmtzY2FwZTp2cF95PSIwIDogMTAwMCA6IDAiCiAgICAgICBpbmtzY2FwZTp2cF96'
    b'PSI3NDQuMDk0NDggOiA1MjYuMTgxMDkgOiAxIgogICAgICAgaW5rc2NhcGU6cGVyc3AzZC1v'
    b'cmlnaW49IjM3Mi4wNDcyNCA6IDM1MC43ODczOSA6IDEiCiAgICAgICBpZD0icGVyc3BlY3Rp'
    b'dmUzNjExIiAvPgogICAgPGlua3NjYXBlOnBlcnNwZWN0aXZlCiAgICAgICBzb2RpcG9kaTp0'
    b'eXBlPSJpbmtzY2FwZTpwZXJzcDNkIgogICAgICAgaW5rc2NhcGU6dnBfeD0iMCA6IDUyNi4x'
    b'ODEwOSA6IDEiCiAgICAgICBpbmtzY2FwZTp2cF95PSIwIDogMTAwMCA6IDAiCiAgICAgICBp'
    b'bmtzY2FwZTp2cF96PSI3NDQuMDk0NDggOiA1MjYuMTgxMDkgOiAxIgogICAgICAgaW5rc2Nh'
    b'cGU6cGVyc3AzZC1vcmlnaW49IjM3Mi4wNDcyNCA6IDM1MC43ODczOSA6IDEiCiAgICAgICBp'
    b'ZD0icGVyc3BlY3RpdmU0MzMxIiAvPgogICAgPGlua3NjYXBlOnBlcnNwZWN0aXZlCiAgICAg'
    b'ICBzb2RpcG9kaTp0eXBlPSJpbmtzY2FwZTpwZXJzcDNkIgogICAgICAgaW5rc2NhcGU6dnBf'
    b'eD0iMCA6IDUyNi4xODEwOSA6IDEiCiAgICAgICBpbmtzY2FwZTp2cF95PSIwIDogMTAwMCA6'
    b'IDAiCiAgICAgICBpbmtzY2FwZTp2cF96PSI3NDQuMDk0NDggOiA1MjYuMTgxMDkgOiAxIgog'
    b'ICAgICAgaW5rc2NhcGU6cGVyc3AzZC1vcmlnaW49IjM3Mi4wNDcyNCA6IDM1MC43ODczOSA6'
    b'IDEiCiAgICAgICBpZD0icGVyc3BlY3RpdmUzMzI0IiAvPgogICAgPGlua3NjYXBlOnBlcnNw'
    b'ZWN0aXZlCiAgICAgICBpZD0icGVyc3BlY3RpdmUxMCIKICAgICAgIGlua3NjYXBlOnBlcnNw'
    b'M2Qtb3JpZ2luPSIzNzIuMDQ3MjQgOiAzNTAuNzg3MzkgOiAxIgogICAgICAgaW5rc2NhcGU6'
    b'dnBfej0iNzQ0LjA5NDQ4IDogNTI2LjE4MTA5IDogMSIKICAgICAgIGlua3NjYXBlOnZwX3k9'
    b'IjAgOiAxMDAwIDogMCIKICAgICAgIGlua3NjYXBlOnZwX3g9IjAgOiA1MjYuMTgxMDkgOiAx'
    b'IgogICAgICAgc29kaXBvZGk6dHlwZT0iaW5rc2NhcGU6cGVyc3AzZCIgLz4KICA8L2RlZnM+'
    b'CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJiYXNlIgogICAgIHBhZ2Vjb2xvcj0i'
    b'I2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5'
    b'PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlc2hhZG93PSIyIgogICAgIGlua3NjYXBlOnpvb209IjAuNyIKICAgICBpbmtzY2FwZTpj'
    b'eD0iNDM4LjMyMTQ4IgogICAgIGlua3NjYXBlOmN5PSIyMjMuODIzMTMiCiAgICAgaW5rc2Nh'
    b'cGU6ZG9jdW1lbnQtdW5pdHM9InB4IgogICAgIGlua3NjYXBlOmN1cnJlbnQtbGF5ZXI9Imxh'
    b'eWVyMSIKICAgICBzaG93Z3JpZD0iZmFsc2UiCiAgICAgYm9yZGVybGF5ZXI9InRydWUiCiAg'
    b'ICAgaW5rc2NhcGU6d2luZG93LXdpZHRoPSIxMjgwIgogICAgIGlua3NjYXBlOndpbmRvdy1o'
    b'ZWlnaHQ9Ijc0NCIKICAgICBpbmtzY2FwZTp3aW5kb3cteD0iLTQiCiAgICAgaW5rc2NhcGU6'
    b'd2luZG93LXk9Ii00IiAvPgogIDxtZXRhZGF0YQogICAgIGlkPSJtZXRhZGF0YTM2MDgiPgog'
    b'ICAgPHJkZjpSREY+CiAgICAgIDxjYzpXb3JrCiAgICAgICAgIHJkZjphYm91dD0iIj4KICAg'
    b'ICAgICA8ZGM6Zm9ybWF0PmltYWdlL3N2Zyt4bWw8L2RjOmZvcm1hdD4KICAgICAgICA8ZGM6'
    b'dHlwZQogICAgICAgICAgIHJkZjpyZXNvdXJjZT0iaHR0cDovL3B1cmwub3JnL2RjL2RjbWl0'
    b'eXBlL1N0aWxsSW1hZ2UiIC8+CiAgICAgIDwvY2M6V29yaz4KICAgIDwvcmRmOlJERj4KICA8'
    b'L21ldGFkYXRhPgogIDxnCiAgICAgaW5rc2NhcGU6bGFiZWw9IkNhcGEgMSIKICAgICBpbmtz'
    b'Y2FwZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlkPSJsYXllcjEiPgogICAgPHJlY3QKICAg'
    b'ICAgIHN0eWxlPSJvcGFjaXR5OjE7ZmlsbDojZGExMjFhO2ZpbGwtb3BhY2l0eToxO2ZpbGwt'
    b'cnVsZTpub256ZXJvO3N0cm9rZTpub25lO3N0cm9rZS13aWR0aDoxMC41Mjg0Nzk1ODAwMDAw'
    b'MDEwMDtzdHJva2UtbGluZWNhcDpidXR0O3N0cm9rZS1saW5lam9pbjptaXRlcjttYXJrZXI6'
    b'bm9uZTttYXJrZXItc3RhcnQ6bm9uZTttYXJrZXItbWlkOm5vbmU7bWFya2VyLWVuZDpub25l'
    b'O3N0cm9rZS1taXRlcmxpbWl0OjQ7c3Ryb2tlLWRhc2hhcnJheTpub25lO3N0cm9rZS1kYXNo'
    b'b2Zmc2V0OjA7c3Ryb2tlLW9wYWNpdHk6MTt2aXNpYmlsaXR5OnZpc2libGU7ZGlzcGxheTpp'
    b'bmxpbmU7b3ZlcmZsb3c6dmlzaWJsZTtlbmFibGUtYmFja2dyb3VuZDphY2N1bXVsYXRlIgog'
    b'ICAgICAgaWQ9InJlY3QzNjEzIgogICAgICAgd2lkdGg9Ijc1MCIKICAgICAgIGhlaWdodD0i'
    b'MjUwIgogICAgICAgeD0iMCIKICAgICAgIHk9IjI1MCIgLz4KICAgIDxyZWN0CiAgICAgICB5'
    b'PSIwIgogICAgICAgeD0iMCIKICAgICAgIGhlaWdodD0iMjUwIgogICAgICAgd2lkdGg9Ijc1'
    b'MCIKICAgICAgIGlkPSJyZWN0MzYxNSIKICAgICAgIHN0eWxlPSJvcGFjaXR5OjE7ZmlsbDoj'
    b'ZmZmZmZmO2ZpbGwtb3BhY2l0eToxO2ZpbGwtcnVsZTpub256ZXJvO3N0cm9rZTpub25lO3N0'
    b'cm9rZS13aWR0aDoxMC41Mjg0Nzk1ODAwMDAwMDEwMDtzdHJva2UtbGluZWNhcDpidXR0O3N0'
    b'cm9rZS1saW5lam9pbjptaXRlcjttYXJrZXI6bm9uZTttYXJrZXItc3RhcnQ6bm9uZTttYXJr'
    b'ZXItbWlkOm5vbmU7bWFya2VyLWVuZDpub25lO3N0cm9rZS1taXRlcmxpbWl0OjQ7c3Ryb2tl'
    b'LWRhc2hhcnJheTpub25lO3N0cm9rZS1kYXNob2Zmc2V0OjA7c3Ryb2tlLW9wYWNpdHk6MTt2'
    b'aXNpYmlsaXR5OnZpc2libGU7ZGlzcGxheTppbmxpbmU7b3ZlcmZsb3c6dmlzaWJsZTtlbmFi'
    b'bGUtYmFja2dyb3VuZDphY2N1bXVsYXRlIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'ES_CB')

ES_CB = b64_ES_CB
index.append("ES_CB")
index.append("Spain Cantabria")
catalog["ES_CB"] = ES_CB
catalog["Spain Cantabria"] = ES_CB
country["Spain Cantabria"] = ('ES_CB', '', 1)
lookup["ES_CB"] = ('ES_CB', '', 'Spain Cantabria', 1)
lookup["Santander Spain Cantabria"] = ('ES_CB', '', 'Spain Cantabria', 1)
lookup["Spain Cantabria"] = ('ES_CB', '', 'Spain Cantabria', 1)
details["ES_CB"] = {"continent":"Europe","capital":"Santander","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_CB"] = ('ES_CB', 'Spain Cantabria', 1)
regional["Spain Cantabria"] = ('ES_CB', 'Spain Cantabria', 1)
#----------------------------------------------------------------------
b64_ES_CE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMjAwcHgi'
    b'IGhlaWdodD0iODAwcHgiIHZpZXdCb3g9IjAgMCA2IDQiPg0KPHJlY3QgZmlsbD0iI2ZmZiIg'
    b'd2lkdGg9IjYiIGhlaWdodD0iNCIvPg0KPHBhdGggZmlsbD0iIzAwMCIgZD0iTTAsMCBoMyB2'
    b'NCBoM3pNNiwwIHYyIEgwIHYyeiIvPg0KPC9zdmc+', 'ES_CE')

ES_CE = b64_ES_CE
index.append("ES_CE")
index.append("Spain Ceuta")
catalog["ES_CE"] = ES_CE
catalog["Spain Ceuta"] = ES_CE
country["Spain Ceuta"] = ('ES_CE', '', 1)
lookup["ES_CE"] = ('ES_CE', '', 'Spain Ceuta', 1)
lookup["Spain Ceuta"] = ('ES_CE', '', 'Spain Ceuta', 1)
details["ES_CE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_CE"] = ('ES_CE', 'Spain Ceuta', 1)
regional["Spain Ceuta"] = ('ES_CE', 'Spain Ceuta', 1)
#----------------------------------------------------------------------
b64_ES_CL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjxzdmcgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0i'
    b'aHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgdmVyc2lvbj0iMS4wIiB3aWR0aD0iNjUw'
    b'IiBoZWlnaHQ9IjUwMCI+CjxyZWN0IHdpZHRoPSI2NTAiIGhlaWdodD0iNTAwIiBmaWxsPSIj'
    b'ZGExMjFhIi8+CjxyZWN0IHdpZHRoPSIzMjUiIGhlaWdodD0iMjUwIiB5PSIyNTAiIGZpbGw9'
    b'IiNmZmZmZmYiLz4KPHJlY3Qgd2lkdGg9IjMyNSIgaGVpZ2h0PSIyNTAiIHg9IjMyNSIgZmls'
    b'bD0iI2ZmZmZmZiIvPgo8ZyB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtODk1LjYyOTkxLC0xNDk0'
    b'LjY3NjYpIj4KCTxnIGlkPSJsaW9uIiB0cmFuc2Zvcm09Im1hdHJpeCgwLjk0MzkwNzksMCww'
    b'LDAuOTQzOTA3OSw1OC42MzYyNTksMTExLjI3MDA4KSI+CgkJPHBhdGgKCQkJZD0ibSAxMDI3'
    b'LjMwODYsMTgyMi44Mjc4IGMgLTQuNTI2NywtNi4yOTc0IC0xNC4wODE2LC0xMC41ODIxIC0x'
    b'MS40MzA3LC0xOS43NTIzIC0xLjI0NTIsMCAtMC43NTE0LC04LjkzNTUgLTEuMDYwNiwtOS43'
    b'NTg2IGwgLTUuNTM4NSwtMy4yOTE5IDAuMzUzNSw1Ljg3ODYgLTguNzI2MSwtMS44ODQ1IC0w'
    b'LjExMiw4LjcwMzcgLTIuMzU2ODYsMi45MzkzIDIuOTQ1OTYsNi4wNTUgYyAwLjExNzksLTAu'
    b'MDU5IDAuMTE3OSwxLjgyMjQgNC4wMDY3LDEuNzA0OCAwLDAgLTAuNzA3LDEuOTA1NiAxLjg4'
    b'NTUsNS40MzI5IC0wLjg0ODMsNi43NTEzIDQuMzY2NSw5LjcxODIgNy4xODgzLDE0LjU1NDYg'
    b'My4xMTA0LC0zLjgxNTcgNS4yNDA1LC03Ljk2MDcgMTIuODQ0OCwtMTAuNTgxNiB6IgoJCQlz'
    b'dHlsZT0iZmlsbDojNzQyYzY0O3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0g'
    b'MTA2NC42MDU2LDE3NzIuNzcwOSBjIC0zLjgyODgsLTMuMTU3OSAtMTIuMzUzMiwyLjE0OTQg'
    b'LTYuNDk5NSwzLjk5MDcgLTEuMjMwMywxLjE2MzggLTAuNjY0OSwyLjMyNzcgMCwzLjQ5MTYg'
    b'bCA4LjgzMjYsNC44MjIgYyAtMS4yNzI2LDEuOTUzNyAtMC45MjMyLDQuMDQyNiAxLjY2NjYs'
    b'Ni4zMTgzIC0xLjA4OTEsMy4xNTI5IC0zLjMwMjQsMi4zNzkzIC02LjE2NjIsLTAuNjY1MSBs'
    b'IC01LjE2NjIsMCBjIC0zLjc2MzUsMS43NzM2IC0yLjYyMzIsMy41NDcyIC0xLDUuMzIwOCAt'
    b'My42NDY5LDMuODE4MyAtMC42MTY4LDcuNTI0IDQuMTY2MywyLjQ5NDEgbCAzLjE2NjUsMi45'
    b'OTI5IGMgLTAuNTg2LDYuNTM4NyAtMTYuODc2LDkuNDYxOSAtMTAuNjY1OSwwLjgzMTQgLTku'
    b'NTcxLC0zLjMzNTkgLTguNTE5OSw0LjA3OTcgLTQuNjM3Miw5Ljk0NjQgLTUuMDgwNSwwLjYw'
    b'MTYgLTE1LjQ2MSwzLjAxNjEgLTguNjk1LC01LjEyNDUgLTExLjMyMzUsMS4xNTczIC0xMC43'
    b'MjksOS42MTEyIC0yLjY2NjUsMTMuODAwNyAtNy44NDcyLDEuNTQ3MSAtMTUuOTI1OSwxLjI0'
    b'NjggLTIyLjQ5ODMsMTIuOTY5MyAtNi43NDc1LDUuOTY0MyAtOS43NDkyLC0wLjA1NCAtOC42'
    b'MTgsMS43NjM4IDEuODgxNywzLjAyNDcgNS44ODE0LDEwLjA0NTMgMTEuMzQwOSwxLjc3ODgg'
    b'LTEuODAwOCwyMC4wNzEyIC04LjE3MzQsMjAuMzA2MSAtOC44MjYyLDE4LjkyMTIgLTAuNjc5'
    b'MSwtMS40NDA4IDIuNDA1NCwxMS4wNjY2IDkuMzUxMSwtMS43ODEzIDQuNzE3MywxMy40NTI3'
    b'IC0xLjA2NzcsMTEuNDYwMyAtMi40MjE4LDEyLjAyNjMgLTEuNDUxOSwwLjYwNjggMi42MTA2'
    b'LDcuMTYzOSAxMC4xNzMyLC0xLjYxNTcgbCA1LjY2NjIsLTcuNDgyMyBjIC03LjQ5ODcsNy4x'
    b'ODE5IC0xMS4zNDcxLDI0Ljg5OTIgLTIzLjM0ODIsMjAuNjQ2NyBsIC0zLjQ5OTcsMS42NjI3'
    b'IDEuMzQ5OCw0LjQ2MDYgNS45OTk2LDIuMzI3NyBjIC01LjU1MDYsLTEuMDM4MyAtOC40NDIx'
    b'LDAuMDQ2IC03LjMzMjgsNC4zMjMyIDIuNjI3Myw0Ljg3NDIgNy4xNjQzLDEwLjcwOTcgNi45'
    b'OTk1LDEuMTYzOSAtMC4wOTgsNi4xOTU1IDIuOTAxOSw3LjUzMyA1LjgzMjksOC45Nzg3IDMu'
    b'OTkzMywwLjg3NjYgMy43MDA3LC01Ljg3OTYgMC45OTk5LC01Ljk4NTcgLTAuMTA1MiwtMy42'
    b'NjQxIDEuMDI4MywtNi4xNzE1IDQuMzMyOSwtNi42NTEgMy4zMDYxLDMuODA0MiA0LjA1NzYs'
    b'LTAuNTk1MiA1LjMzMywtMy4xNTkyIDQuNTIzMSwwLjQ3NzEgNC4xNjcsLTEuMDIyNyA0Ljk5'
    b'OTcsLTUuMzIwNyBsIDguODMyNiwtMi44MjY2IGMgNi40NjY1LDEwLjMyMjQgMTguNDAwNywx'
    b'MC41MTM5IDMwLjk5NzYsOS40Nzc0IDMuNDcxNywxLjU1MiA0LjI3MDYsMy4xMDM4IDMuOTk5'
    b'Nyw0LjY1NTggLTIwLjk0MTYsOC4zNTczIC0xNC4wNDcyLC0xMS4zMjYyIC00Mi4zMzAxLDYu'
    b'MzE4NCAtMC45NDQ0LDAuMjcxIC0xLjg4ODcsMC42NjM5IC0yLjgzMzEsLTAuODMxNSAtMS4x'
    b'NTg1LDIuMTg4MSAtMi4zMjMsNC4wNjk4IDEuNDk5OSw2LjY1MSAxLjM3NTUsNC4yMTQ1IDAu'
    b'NDk2Myw3LjcwMTEgLTUuMTY2Myw5LjY0MzggMy44MzA5LDcuMTQzNiA3LjA1NDMsNC44OTQ1'
    b'IDkuOTk5MywtMS42NjI3IDAuODY5MSw0Ljg1NSA0LjczLDEwLjQwODYgLTAuNjY2NiwxMy44'
    b'MDA3IDIuNTMyMiwyLjAxMTIgNS4wNjcyLDMuNTEwMiA3LjE2NiwwLjMzMjUgbCAtMC4wOTQs'
    b'NC44ODg5IGMgLTEzLjkyMDcsMTAuODUwNSAtMTQuMDM4NSwtNi4yMTUxIC0xNi44MzIsLTIu'
    b'ODI2NyAtMC44MywxLjg2MTcgLTEuMDI5OCw0LjYyNTUgLTMuNTcyNywzLjkyMzcgLTUuNzk4'
    b'MywzLjM3MTMgMi43NDkzLDUuMjM2MiA0LjQ5OTYsNy44MTQ4IGwgLTYuODMyNywtNC40ODk0'
    b'IC0zLjY2NjQsMC4xNjYzIGMgMC41MjExLDEuNTI5NSAxLjA0NjgsMy4wNiAtMC4xNjY3LDQu'
    b'MTU2NyAwLjIyNjEsMy4wNDY1IC0wLjIyNTcsNi40MzExIDUuOTk5Niw2LjQ4NDggMi4yNDI0'
    b'LDEuNTg4MSA0LjQzMTIsMy4xOTc2IDQuNDk5Niw1LjY1MzMgOS4zNjI2LC0wLjcxMzEgOC4z'
    b'NjUxLC00LjAxMDIgMTEuMzMyNSwtNi4zMTg0IDEuNDM4OCw3LjU4ODQgNC43MDYsLTMuNjk2'
    b'NSA3LjA4NDksLTUuOTMyNyAxLjQ2MjcsMC42MTg1IDEuNzk4NiwzLjI5ODEgMS4wODU3LDUu'
    b'MjIyOSA0LjE2NjcsLTUuODEwOSA5LjgzNjYsLTEyLjg4MTkgMTEuNzg0MywtMTkuNTkwMSAt'
    b'MS44NDksLTEuNDA5NCAtMi42NjI0LC0yLjk1NSAtMy42MjI4LC02LjEzNzYgLTMuOTk3Niwt'
    b'MTIuMzY0NyA3LjI2MDYsLTE0Ljc0MzkgMjEuMzMxNiwtMTcuNzkxMyAtNi43NDQ3LDUuMzkw'
    b'NCAtMTYuNzQ1OCwxNi43ODggLTEwLjQ5OTIsMjUuNzcyNSAwLjQ4NzEsMy4xMzAzIDEuMzM1'
    b'Nyw2LjQ2NTMgLTEuNzUzNSw3LjU3MzEgMy41NTUzLDIuNDUyNSA1LjIyMDEsLTEuODc4NSA2'
    b'LjA3NDQsLTQuNTE4IDIuMDk5LDMuNTExIDkuMzg5NCw5LjE1MzQgOC42MzIyLDEzLjUxMTMg'
    b'MC45MDk1LDAuOTA2NSA2LjY2NjMsLTIuMDc0OSA0LjQ5OTgsLTcuMzE2IDQuNDU1OSwtMC44'
    b'NjM0IDYuNDE5MywtMS45NDk5IDEzLjA0OTUsLTQuMjYyMiA1LjkxODMsMS4wMTg0IDEzLjc1'
    b'MiwxOC40OTQxIC0wLjE3MTQsMTIuNDcwNCAtMS44NzksLTEuNTU5MSAtNC4xMjY2LC0yLjEz'
    b'NzggLTcuMzMyOCwtMC4xNjYyIDAuNjE3LDEuMjQ0IDAuNjM0OSwzLjA2ODkgLTAuMTY2Niw0'
    b'Ljk4ODIgLTAuMTMxLDUuMTUzNSA3LjUyOTYsLTAuNzUxNSA5LjE2NiwtMC40OTg5IC0xMi4z'
    b'NTg5LDQuMDI5MyAtNS4yODkxLDEuNjcxNCAtMy44MzMxLDguNjQ2MiAzLjE3MzMsNC42MDkz'
    b'IDUuMjg4NSwtMS45MzQgMTIuODMyMywtNi4zMTgzIGwgLTIuMzMzMSwyLjE2MTUgMC4zMzMz'
    b'LDguMzEzNyBjIDEwLjQyMywwLjY2MTMgOC45ODE2LC0xMC4wOCAxMi41NDc3LC0xNS4xOTgy'
    b'IDAuODA5LC0xLjE2MSAyLjY0ODQsLTEuOTAzMyAzLjYwODMsLTIuNzI3NiAtNS4zNjQ4LC0w'
    b'LjM2MDEgLTEwLjE2MzQsLTguMjg1NyAtNS42ODU4LC0xMi4wMzQzIC0zLjMxNzgsLTIuOTc3'
    b'OSAtMTAuMTk5MSwtNS41NjUgLTYuMzU0LC0xMC4xMzA5IC01LjQyMTcsLTQuNjY0NiAtNC40'
    b'NzUxLC02LjUyODggLTEzLjY2NTYsLTAuNjY1IC0zLjQyNDksLTIuMjYxMSAtOC4wMzk0LC00'
    b'Ljc2MjggLTUuMjgyOCwtOC4xMjg0IDcuNzgyNywtNS41ODcxIDguMjQ1MSwtMTEuNzg0NyAx'
    b'MC45OTkxLC0xNy43OTExIDQ3LjQzNjYsLTE3LjE5MDEgLTI0Ljg0MjksLTY5LjIzMjUgNi45'
    b'MjQ2LC03Mi41Mzk3IDAuNjMyOCw1LjM1MDggLTAuNTYwNCwxMC44MjIzIDEuNTc0OSwxNi4x'
    b'NzMgMy43Nzk5LDEuNDU3NSA2LjM0MDEsMi4xNTU0IDcuNjY2LDUuNjUzMyBsIDIuNjQ5Niw2'
    b'LjgxODEgYyAtMC4xNDU3LC0zLjg5NTUgMi4xMjksLTguNjUzMiAtMC4zMzQsLTExLjY4NjQg'
    b'LTIuNzczLC0zLjQxNDcgLTIuMTg0NiwtNi4wMjkzIC0yLjE3MzQsLTguNDA4OCAxLjc2NTUs'
    b'LTQuMjUzOSAtMC4yNzMyLC02LjA4MDggLTAuNjg4NCwtOC4wNTk3IC03LjE0NCwtOC4wOTI3'
    b'IC0xMC4yMjkyLC02LjM2MjEgLTEzLjIwMTQsLTUuMTMxOCAtMTAuNTA5Niw0LjM1IC0xMC44'
    b'NjY0LDE3LjYwMTggLTMuNjY1OCwyOC4wODA4IDE1LjE0MzYsMjIuMDM4NyAyMS45NDMzLDQw'
    b'Ljk5MjQgMC4xMDIxLDQyLjYzMDMgLTYuMTYwNywtNy45ODc1IC0yMi4yNDY0LC04LjA0NDYg'
    b'LTI2LjE4NTMsLTM4LjU4OTIgMC40MDA0LC0zLjcwNzEgMi45MTY0LC0zLjcyMDUgNC45OTk1'
    b'LC00LjQ4OTQgbCAyLjk5OTksLTIuMzI3OSBjIC04LjMyNTgsLTUuMTE2MiAyLjA1ODUsLTIw'
    b'Ljc5MDggOS4zMzI2LC0xMS45NzE2IC0wLjM1NjgsLTYuMjA4NCAtMC44NDMyLC0xNi40NjI3'
    b'IDIuNDgxNiwtMjEuNzYwOCAwLjcxNSwtMS40MjI5IDIuNjY1NiwwLjg2MzEgNC4xMjksMS42'
    b'ODcgLTIuMDYyNiwtMi4yNTcgLTIuOTU4NiwtMTYuMzA0MyA0LjcyMTgsLTExLjM1MTggMi42'
    b'OTksLTAuNzQ0IDIuMzkxLC0zLjUwMTMgMS44ODk0LC0yLjYxOTcgLTEuMjc3OCwyLjI0NTQg'
    b'LTUuMzIyNSwtMC42MzgzIC01LjYyNywtOC4zOTI4IC0zLjAwNDQsLTYuMjE2MiAtOC42NTgy'
    b'LC0xMy4xMDg5IC0xMi45Mjc3LC0xNi40MjI2IC0zLjY5NjgsLTAuNTEzNiAtNy4xMzM5LC0y'
    b'LjMyMjQgLTExLjY2NTgsMS4zMzAyIGwgLTMuNjY2NCwwIC0xLjQ5OTgsMS4xNjQgYyAtMC4y'
    b'Nzk3LC0xLjYwNTkgLTIuNTMyNCwtMS42MzY5IC00Ljk5OTcsLTEuNDk2NiB6IgoJCQlzdHls'
    b'ZT0iZmlsbDojNzQyYzY0O3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAw'
    b'MC45MDM1LDE4MDIuNTA3OCBjIDMuOTE4MiwxLjQ1MTUgNi43NzMzLDMuODA5MiA4LjYxMDks'
    b'Ny4wMzQzIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRo'
    b'CgkJCWQ9Im0gMTAwOS4zOTY2LDE3OTUuOTAzNiBjIC0wLjE0NTQsMi42NjQ5IC0xLjc0MjUs'
    b'NS4zMjk5IDEuMTc4NCw3Ljk5NDkiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMxOTJl'
    b'MmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDc2LjM3MjIsMTc3NC4xMTU4IGMgMCwwIDMuMzY1'
    b'NCwzLjQ5MTggMy42NjY1LDkuMTQ1MSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzE5'
    b'MmUyZTsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNzYuODY3OSwxNzc1LjUxOTUgYyAwLDAgLTcu'
    b'NTE5Nyw2LjA1OTMgMi42NDYxLDYuMjI1NSAxLjI2MDksLTIuMzc3MiAtMi42NDYxLC02LjIy'
    b'NTUgLTIuNjQ2MSwtNi4yMjU1IHoiCgkJCXN0eWxlPSJmaWxsOiNlN2U3ZTc7c3Ryb2tlOiMx'
    b'OTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDU5LjIwNywxNzc0Ljk0NzIgYyAwLjQyNjgs'
    b'Mi42NjA0IDIuNzA3NCwzLjMyNTUgMi44MzMsMy4zMjU1IgoJCQlzdHlsZT0iZmlsbDpub25l'
    b'O3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA4OS4yMDQ3LDE3ODkuNTc5'
    b'MyBjIDAsMCA0LjUyODUsMy4yMTgyIDEuODYyMSw3LjU0MTIiCgkJCXN0eWxlPSJmaWxsOm5v'
    b'bmU7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDcxLjI2ODgsMTc4NS45'
    b'MjAzIGMgMC4yMDM1LDIuMDU2OSAzLjQyMDMsNS43NzA2IDYuMTAzNCw2LjgxODIiCgkJCXN0'
    b'eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDY4'
    b'LjM3MjksMTgxOS44NDA5IGMgLTMuMjA2MSw2LjMzNyAxLjE1MjQsNS4zNjE3IDMuNDM4Niw0'
    b'LjU0MzEgMS41NzAyLC0wLjU2MjQgMS4zMzkxLDcuNTY5NyAtOC4xMDQ5LDQuNjAxOSAtNC4x'
    b'MjYzLC0yLjk0MjUgLTIuNjE1MywtOC4xNjg0IC0wLjI1LC0xMC44OTA5IgoJCQlzdHlsZT0i'
    b'ZmlsbDpub25lO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA2My4zNzMz'
    b'LDE4MjguNjUzNSBjIC0wLjcyNjUsOS4wNjggLTQuOTMwNiwyMC42NzIgLTE0LjMzMjIsMTEu'
    b'ODA1MyA4LjkxNzMsMS4wNjcxIDQuNTAyNSwtMTAuNzIzNCA1LjU4ODksLTE3LjMyMTkgMCww'
    b'IC0zLjYzNjcsMTEuNzk2MSAtMTIuMjU1MiwxMC42NzEgLTcuMTczNywtMC45MzY2IC00LjA4'
    b'NjUsLTguMTYxOSAtNC4xNjYzLC04LjE0NzQgLTZlLTQsLTAgNi4zNDYyLDQuMDQyMiA3Ljk5'
    b'OTQsLTAuNjY1MSAxLjgzMTgsLTUuMjE1NiA1LjMzMywtOS44MTAxIDUuMzMzLC05LjgxMDEi'
    b'CgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0i'
    b'bSAxMDc3Ljc4MjgsMTgyMS4xNDEyIGMgMS4wMTk5LDMuMzA3NyAwLjgyODUsNi4wMjMgLTEu'
    b'OTEwNSw3Ljg0NDciCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJ'
    b'PHBhdGgKCQkJZD0ibSAxMDI5LjU0MjUsMTgzNi4zMDIgYyAwLDAgLTUuNDA1OSw5LjYyMDcg'
    b'LTAuNTcyOCwxMS43ODIzIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMTkyZTJlOyIv'
    b'PgoJCTxwYXRoCgkJCWQ9Im0gMTA0My44NzQ4LDE4NDQuMjgzMSBjIDAsMCAtMC44MzMzLDgu'
    b'NjQ2MiAxLjY2NjUsOC45Nzg3IDIuNDk5OCwwLjMzMjYgLTYuOTk5NCwyLjgyNjcgLTcuMTY2'
    b'LC05Ljk3NjMiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBh'
    b'dGgKCQkJZD0ibSAxMTE0LjM2OTMsMTgzNS44MDMyIGMgMC45MjIxLDEuMjc0NyAwLjQ5MzEs'
    b'My41MTUgMCwzLjgyNDMiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMxOTJlMmU7Ii8+'
    b'CgkJPHBhdGgKCQkJZD0ibSAxMDc2LjY2MDIsMTg5MS4yNTUyIGMgMy4wMzE0LDIuODY2NSAw'
    b'LjAxMyw0Ljg0NjMgLTAuODI2OSw1LjUxNDUiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tl'
    b'OiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDczLjIwNTksMTg0MC43OTE0IGMgMC4w'
    b'NjQsMi4wMjA4IC0wLjA5OCw0LjEyNjcgMy40OTk2LDQuODIxOSIKCQkJc3R5bGU9ImZpbGw6'
    b'bm9uZTtzdHJva2U6IzE5MmUyZTsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNjEuODczNCwxNzg5'
    b'Ljc0NTUgYyAwLDAgLTIuOTk5NywtNC44MjIgLTExLjQ5OTIsLTAuNjY1MSAtOC40OTkzLDQu'
    b'MTU2OCAtMTEuMDA3NSwtMS45OTUyIC0xMS4wMDc1LC00LjgyMiAwLC0yLjgyNjUgNC4zNDE0'
    b'LC0zLjQ5MTYgNC4zNDE0LC0zLjQ5MTYgMCwwIC0xLjgzMzIsNy4xNDk3IDYuODMyOCw0Ljk4'
    b'ODIgOC42NjYxLC0yLjE2MTYgMTEuOTk5MSwxLjMzMDIgMTEuOTk5MSwxLjMzMDIgbCAyLjUw'
    b'OCw1LjM5MjIgLTMuMTc0NiwtMi43MzE5IHoiCgkJCXN0eWxlPSJmaWxsOiNkYTEyMWE7c3Ry'
    b'b2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDc4LjM5NzMsMTc3Ni45ODAyIGMg'
    b'LTAuMTgyNSwwLjA5OSAtMy42MjA0LDMuMDc1MyAxLjE2NDEsMi42ODQxIgoJCQlzdHlsZT0i'
    b'ZmlsbDojMTkyZTJlO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA0MC4y'
    b'MDQ2LDE4NzcuMTcgYyA3Ljk5NDQsLTMuMjYzMSA5LjUwODMsLTguNjczNyA3LjUxNzYsLTE0'
    b'Ljg5MTEiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgK'
    b'CQkJZD0ibSAxMDEzLjA0OTcsMTg5OS4xMzI2IDQuNzEzNiwxLjg4MTEiCgkJCXN0eWxlPSJm'
    b'aWxsOm5vbmU7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDIzLjg5MTIs'
    b'MTkzMS41NTQxIGMgMi4yNTAzLDAuMzAyOCAzLjMwMzQsLTEuMzg1MyA0LjI0MjMsLTMuMjYz'
    b'NSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzE5MmUyZTsiLz4KCQk8cGF0aAoJCQlk'
    b'PSJtIDEwMTcuMjkyLDE5MzUuMzQ1MSBjIDAuNzI5MSwxLjEyNTQgMi4yNDYzLDEuODU3OCAw'
    b'LjQ3MTMsNC4yMzI2IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMTkyZTJlOyIvPgoJ'
    b'CTxwYXRoCgkJCWQ9Im0gMTA4OC45Mzk5LDE5NDMuODEwMyBjIDEuODczNCwxLjI3OTkgMi4x'
    b'ODAzLDMuMDA2NSAwLjk0MjcsNS4xNzMxIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZToj'
    b'MTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA5MS44MjU0LDE5NTIuMDgwNyBjIDMuODU0'
    b'MiwxLjc4OTQgMi44ODg0LDMuNTc4NyAyLjk2NjIsNS4zNjgxIgoJCQlzdHlsZT0iZmlsbDpu'
    b'b25lO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEwNi40NjE0LDE5NTYu'
    b'NDc5NSBjIDIuNzU1MiwtMC4xMTI1IDMuNTkwMiwxLjIxMTQgNC42MzI4LDIuMzgwMSIKCQkJ'
    b'c3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzE5MmUyZTsiLz4KCQk8cGF0aAoJCQlkPSJtIDEx'
    b'MDIuMDM3LDE3NzYuOTc0IC0yLjc2NDEsMC4yMTU1IGMgMCwwIC0yLjcxNCwxLjkxOTkgLTEu'
    b'MzMzMiwzLjk5MDUgMS4zNzA4LDIuMDU1NyAyLjMxMDYsMS4zNDcxIDMuMTM5NCwwLjE4MzIg'
    b'MC42NzU3LC0wLjk0ODggMC44MDMxLC0yLjQ2MjMgMC44MDMxLC0yLjQ2MjMgbCA1LjcyMzQs'
    b'MS4xMTUyIC0yLjQ5OTgsNC40ODk0IGMgLTEuMzI1NiwtMC4yMDU4IC0yLjMzNjIsLTAuOTU2'
    b'NiAtMi44NTc2LC0wLjY0NDkgMC4xNDIzLDAuMDIgLTMuODA4NiwwLjQyOTkgLTIuMzA4Nywx'
    b'LjkyNjQgMS40OTk5LDEuNDk2NCA2Ljc1NTQsMC40NTg0IDYuNzU1NCwwLjQ1ODQgbCAyLjE5'
    b'NTEsNC43NzY3IGMgMCwtMC42NjYgLTcuNjQyNSwtMi45Mjg5IC05LjI3MjcsLTEuNzMxMiAt'
    b'MC4xNzA3LC0yLjM3NjMgLTExLjEwNzQsLTE2LjM2NzcgLTEzLjE1OTgsLTE3LjI5NTUgbCAx'
    b'LjU1MTksLTguOTM5MiAzLjQzOTQsMy43NDg5IGMgMCwwLjAyNSAtMS4xMTU1LDEuMzAxIC0x'
    b'Ljk5NDksMi4wMDY2IC0wLjkyNjgsMC43NDM2IC0xLjE3ODMsMi4zOTQ3IDAuMDYsMi43NTc5'
    b'IDEuMDU4OSwwLjMxMDggMi4zMjYyLDAuMzg3IDIuODA4NCwtMC4xOTMgMC44MDc4LC0wLjk3'
    b'MTYgMC42NTg3LC0yLjkyODkgMC42NTg3LC0yLjkyODkgbCAzLjg2MTUsLTEuMDY4NCAwLjMz'
    b'MzMsNC40ODk0IC0yLjk5OTgsMC44MzE0IGMgMCwwIC0wLjg3ODgsMS4xNjMxIDAuMzMzMywy'
    b'LjgyNjYgMS4zMjcxLDEuODIxMyAyLjg2MjksMS40NzI3IDMuMzA3MSwwLjQ3NSAwLjQxMTMs'
    b'LTAuOTIzOSAwLjUyNiwtMi4zMDQgMC41MjYsLTIuMzA0IDAsMCAzLjQ5NzMsLTAuNzcxNCA0'
    b'LjE2NCwtMS4yNzAyIC0wLjAyNiwwLjg1OTIgLTAuNjg4Niw0Ljc2NjIgLTAuNDY5LDQuNTQ2'
    b'NSB6IgoJCQlzdHlsZT0iZmlsbDojZmNkZDA5O3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRo'
    b'CgkJCWQ9Im0gMTAwNS4wMDExLDE4ODAuMTk2NiBjIC0wLjI2NDgsLTAuMjM1NSAtMi43NTAx'
    b'LDAuNTY2OSAtMy42Njg2LDEuODUzNyAtMC40MTgxLDAuNTg1OCAxLjMxOTMsMS4xNTY2IDQs'
    b'Mi4xOTEzIDEuMjI5OSwtMi4wOTQ3IDEuNDQ5MywtMi41NDI3IC0wLjMzMTQsLTQuMDQ1IHoi'
    b'CgkJCXN0eWxlPSJmaWxsOiNkYTEyMWE7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJ'
    b'ZD0ibSAxMDA0LjUwMTUsMTg5MC4yOTU2IC0xLjkyMDEsNC44NTIgYyAwLDAgNC4zMDU5LDAu'
    b'Mzg2MyA0Ljk3MDYsMC4zNzkzIDEuMzU3OSwtMC4wMTQgLTEuMjAzNiwtNi4zMjE1IC0zLjA1'
    b'MDUsLTUuMjMxMyB6IgoJCQlzdHlsZT0iZmlsbDojZGExMjFhO3N0cm9rZTojMTkyZTJlOyIv'
    b'PgoJCTxwYXRoCgkJCWQ9Im0gMTAxMy4yNzYzLDE4OTkuMTM4NiAwLjAyLDQuODIxOCAzLjgx'
    b'MjksLTIuOTkyOCBjIC0wLjYxNTcsLTIuNTk2OSAtMi4yMTU1LC0yLjIzOTcgLTMuODMzLC0x'
    b'LjgyOSB6IgoJCQlzdHlsZT0iZmlsbDojZGExMjFhO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxw'
    b'YXRoCgkJCWQ9Im0gMTAyNC4xMDg3LDE5MzEuNTYxOSBjIDAsMCAzLjk3OCwtMS4wNzA5IDMu'
    b'OTk5NywtMy40OTE4IDAuMDMzLC0zLjcyNDQgMC43MDE5LDEuMzU1NSAtMy4zNzE2LC0wLjg0'
    b'OTkgLTMuNjQ1LC0xLjk3MzMgLTAuNzk2LDQuNjg2NSAtMC42MjgxLDQuMzQxNyB6IgoJCQlz'
    b'dHlsZT0iZmlsbDojZGExMjFhO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9Im0g'
    b'MTAxNy4xNTMzLDE5MzkuNzU1NCBjIDEuOTY0OSwtMS4yMTQ3IDAuOTA4OCwtMi43NjU0IDEu'
    b'MDM1NiwtNC4xODQ2IC0yLjIxMjYsMC43NTAxIC00LjQxOTksMS41MDQxIC00Ljg1MzgsMy41'
    b'ODkgMS4zMzA4LDAuNDMwOCAyLjcwNDcsMS4wMzQ0IDMuODE4MiwwLjU5NTYgeiIKCQkJc3R5'
    b'bGU9ImZpbGw6I2RhMTIxYTtzdHJva2U6IzE5MmUyZTsiLz4KCQk8cGF0aAoJCQlkPSJtIDEw'
    b'MjQuNjMyMSwxOTQ2Ljc0NTcgYyAyLjM3ODIsMS4yMzg5IDIuNjM3NywyLjc0MjggMy4yODMy'
    b'LDQuMTk4NSBsIC00LjQ5OTYsMC44MzEzIDEuMjE2NCwtNS4wMjk4IHoiCgkJCXN0eWxlPSJm'
    b'aWxsOiNkYTEyMWE7c3Ryb2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDg5LjY0'
    b'NywxOTQ0LjA0NTUgYyAxLjI0NzgsMC40ODAxIDIuMDQwNSw1LjQxNDIgMCw1LjE3MzEgLTEu'
    b'NDA0MywtMC4xNjU4IC0zLjI5OTYsLTAuNzA1NCAtMy4yOTk2LC0wLjcwNTQgMCwwIDIuNTky'
    b'NSwtNS44Nzg2IDMuMjk5NiwtNC40Njc3IHoiCgkJCXN0eWxlPSJmaWxsOiNkYTEyMWE7c3Ry'
    b'b2tlOiMxOTJlMmU7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDkyLjQ0ODMsMTk1Mi4yNzU1IGMg'
    b'LTAuMDc0LC0xLjMzOTIgNC41MjgyLDMuMjg1MyAyLjk1MTgsNS4zMTExIC0xLjEwMjQsMS40'
    b'MTY0IC03LjE2NzIsLTEuNzgzOSAtNy4xNjcyLC0xLjc4MzkgbCA0LjIxNTQsLTMuNTI3MiB6'
    b'IgoJCQlzdHlsZT0iZmlsbDojZGExMjFhO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJ'
    b'CWQ9Im0gMTEwNS41MjE2LDE5NTYuMDM3OSBjIDAsLTAuNjQyMyA2LjUxNTQsMS4xNTczIDYu'
    b'Mjc5NywzLjI5MTkgLTAuMTU3LDEuNDIxOSAtNi4xNjksMi4xNTgzIC02LjE2OSwyLjE1ODMg'
    b'bCAtMC4xMTA3LC01LjQ1MDIgeiIKCQkJc3R5bGU9ImZpbGw6I2RhMTIxYTtzdHJva2U6IzE5'
    b'MmUyZTsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMTAuMTcxMywxNzk1LjY1ODYgYyAwLDAgMi4z'
    b'MzA0LDAuODI2MyA0LjA5OCwtMi41ODMzIGwgLTQuODg0NiwtMi41Njk4IDAuNzg2Niw1LjE1'
    b'MzEgeiIKCQkJc3R5bGU9ImZpbGw6I2RhMTIxYTtzdHJva2U6IzE5MmUyZTsiLz4KCQk8cGF0'
    b'aAoJCQlkPSJtIDEwMDEuMjAxLDE3OTguNjcyOSBjIDMuOTI2OSwwLjI5NjggMy44ODI5LC0x'
    b'LjU5NSA0LjMyMTcsLTMuNTY3MyBsIC00LjgzNDQsLTAuOTk3NyAwLjUxMjcsNC41NjUgeiIK'
    b'CQkJc3R5bGU9ImZpbGw6I2RhMTIxYTtzdHJva2U6IzE5MmUyZTsiLz4KCQk8cGF0aAoJCQlk'
    b'PSJtIDk5OC4zNDg4OCwxODA1LjU0NzggLTMuMDYwOTgsNC42OTk3IDUuODkyMiwwLjgyMjkg'
    b'YyAtMC4zNTIxLC0xLjY5NzcgMC4xNTUxLC0yLjk0ODggLTIuODMxMjIsLTUuNTIyNiB6IgoJ'
    b'CQlzdHlsZT0iZmlsbDojZGExMjFhO3N0cm9rZTojMTkyZTJlOyIvPgoJCTxwYXRoCgkJCWQ9'
    b'Im0gMTA4NS4xMzEzLDE3OTkuMDMxMiBjIDEuNDY0MywyLjE2NDcgMS4wMjQsNC4zMjk0IDAs'
    b'Ni40OTQxIDAsMCAtNi40OTAzLDUuODEwNSAwLjE3MDgsNy43NzU4IDAsMCAtNi42NjExLDMu'
    b'MjQ3MSAtOC4wMjc1LC02LjU3OTUgMCwwIC02LjQ5MDMsOS45MTIxIC0xMi41NTM2LDIuMTM2'
    b'MiAwLDAgNS43MjE3LC0wLjM0MTggNi4wNjMzLC01LjQ2ODgiCgkJCXN0eWxlPSJmaWxsOm5v'
    b'bmU7c3Ryb2tlOiMxMjFmMWY7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDI1LjE2NjYsMTg2NS4z'
    b'MDIyIGMgMCwwIC0xLjM1MTYsLTEwLjEzMSAyLjU3NjcsLTEwLjQ3MjciCgkJCXN0eWxlPSJm'
    b'aWxsOm5vbmU7c3Ryb2tlOiMxMjFmMWY7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDI0LjA3MDEs'
    b'MTk0NS44MjI4IGMgMCwwIDEuMTEwMSwtMS4zNjcyIDEuNzkzNCwtMS4zNjcyIgoJCQlzdHls'
    b'ZT0iZmlsbDojZGExMjFhO3N0cm9rZTojMDAwMDAwOyIvPgoJPC9nPgoJPGcgaWQ9ImNhc3Rs'
    b'ZSIKCQkgdHJhbnNmb3JtPSJtYXRyaXgoMC45NDM5MDc5LDAsMCwwLjk0MzkwNzksNTkuNTEx'
    b'MzY0LDg5LjYzMjM2KSI+CgkJPHBhdGgKCQkJZD0ibSAxMDQxLjg0MzYsMTUyMS4yOTUzIDMx'
    b'LjI2ODEsMC4xMDY2IDYuMTY4NSw1LjU0NTcgMCwxNC45MzA0IC0zLjQwMzIsMi41NTk0IC0w'
    b'LjEwNjQsMzQuMzM5OSA4LjE4OTMsMCAwLjMxOSwtMTcuNzAzMiAtMi4yMzM0LC0zLjMwNiAt'
    b'MC4xMDY0LC0xMC43NzEyIDQuMzYwNiwtNS4zMzIzIDE4LjI5MjksMC4xMDY2IDQuNjc5NSw1'
    b'LjQzOSAwLjEwNjQsMTAuNDUxMiAtMi43NjUyLDQuMzcyNSAtMC4xMDY0LDIxLjY0OTEgMTEu'
    b'OTExNyw2LjI5MjEgLTAuMjEyNywxNi4yMTAyIC0zLjgyODgsNS45NzIxIDAsNjQuNDE0MSAx'
    b'MC4xMDM4LDguNjM4MiAwLjEwNjMsMjAuNzk2IC0yMC4zMTM3LDEzLjQzNzQgLTkzLjI3Mjcs'
    b'MCAtMjAuMzEzNjcsLTEzLjMzMDggMCwtMjAuOTAyNyA5LjQ2NTU3LC03LjU3MTcgMC40MjU0'
    b'LC02NS4yNjcyIC0zLjYxNjA3LC01LjkzNTYgMCwtMTYuMjQ2NyAxMS4yNzM1NywtNi44MjU0'
    b'IDAuMTA2MywtMjEuNzU1NiAtMy42MTYsLTMuNzMyNyAtMC4yMTI3LC0xMC4yMzc5IDQuOTk4'
    b'NiwtNS44NjU1IDE4LjkzMTEsMCA0Ljc4NTksNS4zMzIyIDAsMTAuOTg0NSAtMi44NzE2LDMu'
    b'NTE5NCAwLjEwNjQsMTcuNTk2NSA5LjE0NjUsLTAuMTA2NiAtMC4yMTI2LC0zNC4xMjY3IC0z'
    b'LjYxNjIsLTMuNDEyNiAtMC4zMTksLTEzLjg2MzkgNi4zODEzLC02LjM5ODggeiIKCQkJc3R5'
    b'bGU9ImZpbGw6I2ZjZGQwOTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEw'
    b'NDIuMjY4OSwxNzE4LjkwOTcgMC4yMTI3LC0zNC41NTMxIGMgMCwwIDE0LjAzODgsLTIyLjgy'
    b'MjIgMzAuMjA0NywwLjIxMzIgbCAwLjQ3NDksMzQuNzY2NSIKCQkJc3R5bGU9ImZpbGw6bm9u'
    b'ZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDk5MC44OTk4MywxNjg1LjQy'
    b'MjkgMjAuMTAwOTcsOC4yMTE4IDMxLjM3NDUsMC4xMDY2IgoJCQlzdHlsZT0iZmlsbDpub25l'
    b'O3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEyMy45NTEzLDE2ODUuNTAz'
    b'OCAtMjAuMDcyLDguMDU1NiAtMzEuMDU1NSwwLjIxMzIiCgkJCXN0eWxlPSJmaWxsOm5vbmU7'
    b'c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSA5OTAuNzkzNDgsMTY5Mi40NjE3'
    b'IDE5Ljk5NDYyLDkuMjk2MyAzMS4yOTE3LDAuMDE5IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0'
    b'cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gOTkwLjYyOTY4LDE2OTkuMjEyNyAy'
    b'MC4wMDQyMiwxMS4zMTE2IDMxLjEzNDQsMC4xNTA4IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0'
    b'cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAwMS4wMDc4LDE2ODkuNTYwNCAt'
    b'MC4zMDA4LDcuMzkwMSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4K'
    b'CQk8cGF0aAoJCQlkPSJtIDk5NS44OTM5NiwxNjk0LjgzOSAtMC4xNTA0Miw3LjM5MDMiCgkJ'
    b'CXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAx'
    b'MDA1LjgyMDksMTY5OS4wNjE5IDAsOC40NDYiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tl'
    b'OiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDAxLjAwNzgsMTcwNC43OTMgLTAuMTUw'
    b'NCw3Ljg0MjgiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBh'
    b'dGgKCQkJZD0ibSA5OTcuMDk3MjEsMTYwNi43NjAyIDE4LjM0OTc5LC03LjIzOTMgODMuNDc2'
    b'MiwtMC4xNTA4IDE5LjEwMTgsNi43ODY5IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZToj'
    b'MDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAwMC43MDcsMTYxMi4zNDA2IDE4LjY1MDYs'
    b'LTUuNzMxMiA3Ni43MDc5LDAuMTUwOCAxOC4zNDk3LDUuNDI5NSIKCQkJc3R5bGU9ImZpbGw6'
    b'bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDAuNDA2MiwxNjIy'
    b'Ljg5OCAxOC42NTA1LC0zLjkyMTMgNzcuMTU5MiwwLjE1MDggMTguMDQ4OSwzLjkyMTMiCgkJ'
    b'CXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAx'
    b'MDAwLjU1NjYsMTYzNC41MTExIDE4Ljk1MTQsLTIuNDEzMiA3NS44MDU0LDAgMTguOTUxNCwy'
    b'LjI2MjQiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgK'
    b'CQkJZD0ibSA5OTkuOTkxNDUsMTY0NC4xNjM1IDE5LjMyMjA1LDEuNTYzMyA3Ni4xMjQ1LDAu'
    b'MDMzIDE5LjQyODQsLTEuNTk2NyIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAw'
    b'MDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDAuNTc4MSwxNjU1LjM0ODkgMTguODI0NywzLjA5'
    b'MjggNzYuNDY4OCwwLjEwNjYgMTguNTA1NSwtMi43NzI4IgoJCQlzdHlsZT0iZmlsbDpub25l'
    b'O3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAwMC4zNjU0LDE2NjYuNjUz'
    b'NSAxOS41NjkyLDQuMjY1OCA3NS41MTE1LDAgMTguOTMxLC00LjY5MjQiCgkJCXN0eWxlPSJm'
    b'aWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDAwLjM2NTQs'
    b'MTY3Ny4zMTggMTguOTMxLDUuNzU4OCAyMy43MTcxLDAuMDUzIgoJCQlzdHlsZT0iZmlsbDpu'
    b'b25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA3MS43MjE1LDE2ODIu'
    b'ODYzNSAyMy43OTk4LDAuMDg4IDE5LjQ5NCwtNi43MDAzIgoJCQlzdHlsZT0iZmlsbDpub25l'
    b'O3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAwOC43Njc0LDE1ODMuMDQz'
    b'MSA2Ljk2NjIsLTQuMjEyNSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsi'
    b'Lz4KCQk8cGF0aAoJCQlkPSJtIDEwMDUuMTUxMywxNTU3LjQ0ODEgMy45MzUxLC0zLjczMjYg'
    b'MTguNzE4MywtMC4xMDY2IDUuMjExNCw0LjI2NTgiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ry'
    b'b2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDA4LjM0MTksMTU2OC42NDU5IDQu'
    b'MTQ3OSwtMy4xOTkzIDEzLjE4NzksMCA0Ljc4NTksMy4zMDYiCgkJCXN0eWxlPSJmaWxsOm5v'
    b'bmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDA4LjU1NDcsMTU3NS44'
    b'OTc5IDUuMjExMywtNC4wNTI2IDExLjgwNTMsMC4xMDY3IDUuMjExNCw0LjI2NTgiCgkJCXN0'
    b'eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMTA1'
    b'Ljk3NTIsMTU4My4yMDMxIC02LjcwMDMsLTQuMDUyNiIKCQkJc3R5bGU9ImZpbGw6bm9uZTtz'
    b'dHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNDEuODQzNiwxNTIxLjYxNTIg'
    b'MC4yMTI3LDE1Ljk5NjkgMi43NjUxLDQuMjY1OSAwLDM2Ljg5OTIiCgkJCXN0eWxlPSJmaWxs'
    b'Om5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDczLjExMTcsMTUy'
    b'MS41MDg2IC0wLjIxMjcsMTUuOTk2OSAtMi43NjUyLDQuMjY1OCAwLDM2Ljg5OTMiCgkJCXN0'
    b'eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDM1'
    b'Ljk5NCwxNTQxLjU1OCA1LjYzNjksLTQuMTU5MiAzMS4xNjE3LDAuMzIgNi4yNzQ5LDQuMjY1'
    b'OCIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlk'
    b'PSJtIDEwMzkuNjEwMSwxNTQ0Ljg2NCA0Ljc4NiwtMi43NzI3IDI1Ljc5MDksMC4xNTk5IDUu'
    b'NTgzNiwyLjgyNjIiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJ'
    b'PHBhdGgKCQkJZD0ibSAxMDM5LjYxMDEsMTU1NC41Njg3IDQuODkyMywtMy4wOTI3IDI1LjQx'
    b'ODYsMC4zMiA1Ljc0MzIsMi45ODYxIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAw'
    b'MDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAzOS4yOTExLDE1NjMuNDIwMyA1LjQyNCwtMi44'
    b'Nzk0IDI1LjMxMjMsMC4yMTMzIDUuNjM2OCwyLjk4NjEiCgkJCXN0eWxlPSJmaWxsOm5vbmU7'
    b'c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDM5LjcxNjQsMTU3Mi44MDUx'
    b'IDQuMzYwNiwtMi41NTk0IDI2LjE2MzEsMC4yMTMzIDUuMTA1LDIuOTg2IgoJCQlzdHlsZT0i'
    b'ZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEwNi4yMjA3'
    b'LDE1NjEuOTgwNyAtNC44OTIzLC0zLjMwNjEgLTEyLjY1NjMsMCAtNC4yNTQyLDMuNzMyNyIK'
    b'CQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJt'
    b'IDExMDYuMzI3LDE1NjkuMjMyNSAtNC4xNDc4LC0zLjE5OTQgLTEzLjE4OCwwIC00Ljc4NTks'
    b'My4zMDYxIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRo'
    b'CgkJCWQ9Im0gMTEwNi4xMTQzLDE1NzYuNDg0NCAtNS4yMTE0LC00LjA1MjUgLTExLjgwNTMs'
    b'MC4xMDY3IC00Ljg5MjMsMy4zMDU5IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAw'
    b'MDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEyNC4zNzQ1LDE2OTEuODIxOCAtMjAuNDIwMSwx'
    b'MC4wMjQ3IC0zMC40MTcyLDAiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7'
    b'Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDczLjMyNDUsMTcxMC4zNzgyIDMwLjUyMzYsMCAyMC42'
    b'MzI4LC0xMS41MTc4IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJ'
    b'CTxwYXRoCgkJCWQ9Im0gMTExNC4zNzcxLDE2ODkuNTgyMSAwLjEwNjQsNi44MjU0IgoJCQlz'
    b'dHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEw'
    b'OS40ODQ5LDE2OTkuMzkzNiAwLjEwNjMsNy43ODUxIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0'
    b'cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTExOS4zNzU5LDE2OTQuMDYxMyAw'
    b'LjEwNjMsNy40NjUyIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJ'
    b'CTxwYXRoCgkJCWQ9Im0gMTExNC4yNzA4LDE3MDQuNjE5MiAwLjIzOTMsNy44Mzg2IgoJCQlz'
    b'dHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA4'
    b'OC4yMTQsMTY5My41MjggLTAuMTA2NCw4LjEwNTIiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ry'
    b'b2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDgwLjY2MjksMTcwMS43Mzk4IDAs'
    b'OC42Mzg0IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRo'
    b'CgkJCWQ9Im0gMTA5NS42NTg5LDE3MDEuNzM5OCAwLDguNjM4NCIKCQkJc3R5bGU9ImZpbGw6'
    b'bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwODguMTA3NiwxNzEw'
    b'LjU5MTUgMC4xMDY0LDguODUxNiIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAw'
    b'MDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMjUuNjc3NywxNjkzLjYzNDcgMCw3Ljg5MTgiCgkJ'
    b'CXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAx'
    b'MDE4LjMzOTIsMTcwMS42MzMyIDAsOC44NTE3IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9r'
    b'ZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAzNC41MDUxLDE3MDEuNzM5OCAwLjEw'
    b'NjMsOC45NTgyIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxw'
    b'YXRoCgkJCWQ9Im0gMTAyNS44OTA0LDE3MTAuNTkxNSAwLDguNTMxNSIKCQkJc3R5bGU9ImZp'
    b'bGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDAuNzkwOCwx'
    b'Njg5LjI2MjIgOC41MDgzLC05LjE3MTUiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMw'
    b'MDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0iTSAxMDA0LjQwNjgsMTY3OC4zODQ1IDEwMDQuMzAw'
    b'NSwxNjY3LjQiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBh'
    b'dGgKCQkJZD0ibSAxMDE0LjE5MTQsMTY2OS40MjYxIDAsMTEuNzMxMiIKCQkJc3R5bGU9ImZp'
    b'bGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDkuNzI0NSwx'
    b'NjY4Ljg5MjkgMCwtMTIuNDc3NCIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAw'
    b'MDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDQuNjE5NSwxNjU1Ljk4ODggMC4yMTI4LC0xMS43'
    b'MzEiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJ'
    b'ZD0ibSAxMDE0LjUxMDUsMTY0NS40MzA5IC0wLjEwNjQsMTEuODM3NiIKCQkJc3R5bGU9ImZp'
    b'bGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDkuODMwOSwx'
    b'NjMzLjA2IC0wLjEwNjQsMTEuNjI0NCIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAw'
    b'MDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDQuOTM4NiwxNjIxLjY0ODggLTAuMTA2Mywx'
    b'Mi4zNzEiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgK'
    b'CQkJZD0ibSAxMDE0LjUxMDUsMTYyMC4xNTU5IDAuMTA2NCwxMi4zNzA5IgoJCQlzdHlsZT0i'
    b'ZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAwOS41MTE4'
    b'LDE2MDkuNzA0NiAwLDExLjA5MTIiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAw'
    b'MDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMTA5Ljk4MjIsMTY3OC4xNzI4IC0wLjEwNjMsLTEx'
    b'LjA5MTEiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgK'
    b'CQkJZD0ibSAxMTAwLjUxNjcsMTY2OS4yMTQ1IDAsMTEuNzMxMSIKCQkJc3R5bGU9ImZpbGw6'
    b'bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDExMDUuMTk2MywxNjY4'
    b'LjU3NDYgMC4wMTMsLTExLjc2NzYiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAw'
    b'MDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMTEwLjAzNTQsMTY1Ni4yNTcxIDAsLTExLjg5MTEi'
    b'CgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0i'
    b'bSAxMTAwLjM3MDEsMTY0NS4xMTI2IC0wLjA2NiwxMi43OTc0IgoJCQlzdHlsZT0iZmlsbDpu'
    b'b25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEwNS4xOTYzLDE2MzIu'
    b'OTU1IDAuMDEzLDExLjcwNzMiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7'
    b'Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMTA5Ljc5MTYsMTYyMi4xODM3IDAuMDg0LDExLjYyNDUi'
    b'CgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0i'
    b'bSAxMTAwLjE5NzcsMTYxOS45NDQyIC0wLjAzMSwxMi42NzI1IgoJCQlzdHlsZT0iZmlsbDpu'
    b'b25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEwNS4xOTYzLDE2MDku'
    b'NTQ2MiAwLDExLjAzNzkiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+'
    b'CgkJPHBhdGgKCQkJZD0ibSAxMDI1LjUyNDMsMTY5My40ODE2IDYuNzY4MywtMTAuNDA2NiIK'
    b'CQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJt'
    b'IDEwODIuNTI4NywxNjgyLjkyNDIgNS44NjYsMTAuNzA4MiIKCQkJc3R5bGU9ImZpbGw6bm9u'
    b'ZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDExMDQuOTM5NSwxNjc5LjYw'
    b'NjIgOS4xNzUsOS44MDMzIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIv'
    b'PgoJCTxwYXRoCgkJCWQ9Im0gMTAzOC4zMDksMTY3MC40MDYyIDAuMDQ0LDEyLjUxOCIKCQkJ'
    b'c3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEw'
    b'NTcuNDk4OSwxNjcwLjUxMjggMC4wNjIsMy4zNjIyIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0'
    b'cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA3Ny4xMTQxLDE2NzAuNTU3IDAs'
    b'MTIuMjE2NCIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0'
    b'aAoJCQlkPSJtIDEwNjkuODk0NiwxNjU4LjM0MDYgMC4xNTAzLDExLjkxNDkiCgkJCXN0eWxl'
    b'PSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDQ0Ljc3'
    b'NjUsMTY1OC4wMzkgLTAuMTUwNSwxMi41MTgiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tl'
    b'OiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDU2LjgwOSwxNjQ1LjIxOTIgLTAuMTI0'
    b'NiwxMi44MTk4IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxw'
    b'YXRoCgkJCWQ9Im0gMTAzMS45OTE4LDE2NDUuMjE5MiAwLDEyLjUxODIiCgkJCXN0eWxlPSJm'
    b'aWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDcwLjMxOTks'
    b'MTYzMi4zOTk3IC0wLjEyNDYsMTIuODE5NSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6'
    b'IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNjkuODk0NiwxNjA2LjYwOTQgLTAuMDE4'
    b'LDEyLjIxNjUiCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBh'
    b'dGgKCQkJZD0ibSAxMDQ0LjQ3NTYsMTYwNi4xNTcgLTAuMDE4LDEyLjgxOTciCgkJCXN0eWxl'
    b'PSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDU3LjIx'
    b'NjIsMTYxOS4zNDA4IDAuMDQ0LDEyLjMwNDciCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tl'
    b'OiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDQ0LjYyNiwxNjMyLjI0ODkgMCwxMi44'
    b'MTk2IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJ'
    b'CWQ9Im0gMTAzMi4xNDIyLDE2NDUuMzcwMSAwLDEyLjgxOTciCgkJCXN0eWxlPSJmaWxsOm5v'
    b'bmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDgzLjI4MDgsMTY0NS41'
    b'MjA5IDAsMTMuMTIxNSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4K'
    b'CQk8cGF0aAoJCQlkPSJtIDEwMDMuMjM2OSwxNTg2LjM0OTEgMCw3Ljk5ODUiCgkJCXN0eWxl'
    b'PSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDA5LjUx'
    b'MTgsMTU4Mi41MDk5IDAsOS4xNzE2IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAw'
    b'MDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAxNC41MTA1LDE1NDEuNzE3OSAwLjA1Myw0Ljkw'
    b'NTciCgkJCXN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJ'
    b'ZD0ibSAxMDE5LjI5NjQsMTU0MS43NzEzIDAsNC45MDU2IgoJCQlzdHlsZT0iZmlsbDpub25l'
    b'O3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAyNC4wODI0LDE1NDEuODc4'
    b'IDAsNC42OTIzIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxw'
    b'YXRoCgkJCWQ9Im0gMTA5MC41NTM5LDE1NDEuODc4IDAsNC45MDU2IgoJCQlzdHlsZT0iZmls'
    b'bDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTA5NS42NTg5LDE1'
    b'NDEuOTg0NiAwLDQuOTA1NiIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsi'
    b'Lz4KCQk8cGF0aAoJCQlkPSJtIDExMDAuNTUxMSwxNTQyLjA5MTMgMCw0Ljc5MjUiCgkJCXN0'
    b'eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDEw'
    b'Ljc4ODEsMTcxOS4xMjMgMC40MjU0LC0yNS4zODE3IDguNTA4MywtMTAuODc3OCAtMC40MjU0'
    b'LC03Ni4zNTgzIC0zLjQwMzMsLTYuNjEyMSAtMC4wMTMsLTIxLjIxNyAxMC44NTczLC0wLjAy'
    b'MiAtMC4wMzEsMTAuMzYxMyAzLjkxNTMsMC4wNzUgLTAuMDg0LC0xMC4zNTEyIDEwLjI1Miww'
    b'LjA2MiAwLjA0NCwxMC4zNzMyIDMuNzc1NywwIC0wLjEwNjQsLTEwLjM0ODMgMTEuMTY3Miww'
    b'LjA1MyAwLDEwLjM0ODUgMy43NzU2LDAgMC4wNTMsLTEwLjQzMyAxMC4zNTkzLC0wLjAxIC0w'
    b'LjA0NCwxMC40Mzk0IDMuNzc2NiwwIC0wLjA0NywtMTAuNTI0MSAxMS4wMDEyLDAuMTIyNCAw'
    b'LjA1MywxMC4zNDgzIDMuNjQyNiwtMC4wNTMgLTAuMDg4LC0xMC4zOTMzIDExLjI4MTgsMC4w'
    b'NzYgLTAuMDUzLDIwLjEyODcgLTMuNjE2LDcuNjc4NSAtMC4xMDYzLDc2LjMwNDkgOC4wODI5'
    b'LDEwLjQ1MTMgMC4zMTksMjUuOTY4MiIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAw'
    b'MDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwMDkuNjE4MiwxNTQxLjU1OCAwLDEyLjE1NzUg'
    b'My42MTYsNC40NzkyIDAuMTA2NCwyMS4zMjkyIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9r'
    b'ZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTAyOC4zMzY2LDE1NDEuNDUxNCAwLjEw'
    b'NjMsMTIuMzcwNyAtMi40NDYxLDQuNTg1OSAtMC4yMTI4LDIwLjY4OTMiCgkJCXN0eWxlPSJm'
    b'aWxsOm5vbmU7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDA4LjQ0ODMs'
    b'MTU2MS4zOTQxIDQuODkyMywtMy4zMDYxIDEyLjY1NjIsMCA0LjI1NDIsMy43MzI2IgoJCQlz'
    b'dHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEw'
    b'NS4wNTA4LDE1NDIuMTQ0NSAwLDEyLjE1NzYgLTMuNjE2Miw0LjQ3OTIgLTAuMTA2MiwyMS4z'
    b'MjkxIgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJ'
    b'CWQ9Im0gMTA4Ni4zMzI0LDE1NDIuMDM3OSAtMC4xMDY0LDEyLjM3MDkgMi40NDYxLDQuNTg1'
    b'OCAwLjIxMjgsMjAuNjg5MiIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsi'
    b'Lz4KCQk8cGF0aAoJCQlkPSJtIDEwODIuMzAxOCwxNTU3LjU1OTUgMy42MTYsLTMuMTk5MyAx'
    b'OC43MTg0LC0wLjEwNjYgNC43ODU5LDMuNjI1OSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJv'
    b'a2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNDkuNjA3NCwxNTIxLjUwODYgLTAu'
    b'MDY5LDYuNjEyMSIKCQkJc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8'
    b'cGF0aAoJCQlkPSJtIDEwNTYuOTQ1OCwxNTIxLjQyMTMgLTAuMDQ0LDYuNTkyNyIKCQkJc3R5'
    b'bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNjUu'
    b'MTM1MSwxNTIxLjYwOTkgMCw2Ljc1IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAw'
    b'MDAwOyIvPgoJCTxwYXRoCgkJCWQ9Im0gMTEwNS42NTYxLDE1ODMuMTQ5NyAwLjEwNjQsOC45'
    b'NTg0IgoJCQlzdHlsZT0iZmlsbDpub25lO3N0cm9rZTojMDAwMDAwOyIvPgoJCTxwYXRoCgkJ'
    b'CWQ9Im0gMTExMi4xNDM3LDE1ODYuNTYyNCAtMC4xMDYzLDcuOTk4NSIKCQkJc3R5bGU9ImZp'
    b'bGw6bm9uZTtzdHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNTQuMjMyLDE1'
    b'NzAuNjQ3MSAtMC4wOTcsLTE1LjE5NDggYyAwLDAgMi42NzQxLC02LjkyNzMgNi4yNjUzLDAg'
    b'bCAwLjAyNCwxNS4yMDYxIC02LjE5MjIsLTAuMDExIHoiCgkJCXN0eWxlPSJmaWxsOiMwZjQ3'
    b'YWY7c3Ryb2tlOiMwMDAwMDA7Ii8+CgkJPHBhdGgKCQkJZD0ibSAxMDMyLjg2OTgsMTY0NS41'
    b'NjA5IC0wLjEzMzQsLTIxLjg0MTYgYyAwLDAgMy42NjksLTkuOTU3NCA4LjU5NjEsMCBsIDAu'
    b'MDMzLDIxLjg1NzggLTguNDk1OCwtMC4wMTYgeiIKCQkJc3R5bGU9ImZpbGw6IzBmNDdhZjtz'
    b'dHJva2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNzMuODM1OCwxNjQ1LjQ1NDIg'
    b'LTAuMTMxOCwtMjEuODQxNyBjIDAsMCAzLjYyMzcsLTkuOTU3MyA4LjQ5MDIsMCBsIDAuMDMz'
    b'LDIxLjg1NzggLTguMzkxMSwtMC4wMTYgeiIKCQkJc3R5bGU9ImZpbGw6IzBmNDdhZjtzdHJv'
    b'a2U6IzAwMDAwMDsiLz4KCQk8cGF0aAoJCQlkPSJtIDEwNDguMTI3MywxNjg2Ljc3MDkgYyAw'
    b'LDAgMy4zMjI3LC03LjE3MDkgOS43MjA0LC03LjMyNzMgMCwwIDUuNDE1NywtMC4xODMzIDku'
    b'MTYwNyw3LjAxNDMgbCAwLDMyLjc4MDMgLTE5LjAzNzEsLTAuMDc4IDAuMTU2LC0zMi4zODkx'
    b'IHoiCgkJCXN0eWxlPSJmaWxsOiMwZjQ3YWY7c3Ryb2tlOiMwMDAwMDA7Ii8+Cgk8L2c+Cgk8'
    b'dXNlIHhsaW5rOmhyZWY9IiNsaW9uIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgzMjUsLTI1MCki'
    b'Lz4KCTx1c2UgeGxpbms6aHJlZj0iI2Nhc3RsZSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMzI1'
    b'LDI1MCkiLz4KPC9nPgo8L3N2Zz4K', 'ES_CL')

ES_CL = b64_ES_CL
index.append("ES_CL")
index.append("Spain Castilla y Leon")
catalog["ES_CL"] = ES_CL
catalog["Spain Castilla y Leon"] = ES_CL
country["Spain Castilla y Leon"] = ('ES_CL', '', 1)
lookup["ES_CL"] = ('ES_CL', '', 'Spain Castilla y Leon', 1)
lookup["Valladolid Spain Castilla y Leon"] = ('ES_CL', '', 'Spain Castilla y Leon', 1)
lookup["Spain Castilla y Leon"] = ('ES_CL', '', 'Spain Castilla y Leon', 1)
details["ES_CL"] = {"continent":"Europe","capital":"Valladolid","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_CL"] = ('ES_CL', 'Spain Castilla y Leon', 1)
regional["Spain Castilla y Leon"] = ('ES_CL', 'Spain Castilla y Leon', 1)
#----------------------------------------------------------------------
b64_ES_CM = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgo8c3ZnCiAgIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4x'
    b'LyIKICAgeG1sbnM6Y2M9Imh0dHA6Ly93ZWIucmVzb3VyY2Uub3JnL2NjLyIKICAgeG1sbnM6'
    b'cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxucz0iaHR0cDov'
    b'L3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vaW5rc2Nh'
    b'cGUuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHdp'
    b'ZHRoPSIxMDAwLjAwMDAiCiAgIGhlaWdodD0iNTAwLjAwMDAwIgogICBpZD0ic3ZnMiIKICAg'
    b'c29kaXBvZGk6dmVyc2lvbj0iMC4zMiIKICAgaW5rc2NhcGU6dmVyc2lvbj0iMC40MiIKICAg'
    b'dmVyc2lvbj0iMS4wIgogICB4PSIwLjAwMDAwMDAwIgogICB5PSIwLjAwMDAwMDAwIgogICBz'
    b'b2RpcG9kaTpkb2NiYXNlPSJIOlwiCiAgIHNvZGlwb2RpOmRvY25hbWU9IkJBTkRFUn4xLlNW'
    b'RyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczQiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwog'
    b'ICAgIGlkPSJiYXNlIgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAgIGlua3Nj'
    b'YXBlOnpvb209IjAuOTMzMDAwMDAiCiAgICAgaW5rc2NhcGU6Y3g9IjUwMC4wMDAwMCIKICAg'
    b'ICBpbmtzY2FwZTpjeT0iMjUwLjAwMDAwIgogICAgIGlua3NjYXBlOmRvY3VtZW50LXVuaXRz'
    b'PSJweCIKICAgICBpbmtzY2FwZTpjdXJyZW50LWxheWVyPSJsYXllcjEiCiAgICAgaW5rc2Nh'
    b'cGU6d2luZG93LXdpZHRoPSIxMDI0IgogICAgIGlua3NjYXBlOndpbmRvdy1oZWlnaHQ9Ijcx'
    b'MiIKICAgICBpbmtzY2FwZTp3aW5kb3cteD0iLTQiCiAgICAgaW5rc2NhcGU6d2luZG93LXk9'
    b'Ii00IgogICAgIHNob3dndWlkZXM9InRydWUiCiAgICAgaW5rc2NhcGU6Z3VpZGUtYmJveD0i'
    b'dHJ1ZSIgLz4KICA8bWV0YWRhdGEKICAgICBpZD0ibWV0YWRhdGE3Ij4KICAgIDxyZGY6UkRG'
    b'PgogICAgICA8Y2M6V29yawogICAgICAgICByZGY6YWJvdXQ9IiI+CiAgICAgICAgPGRjOmZv'
    b'cm1hdD5pbWFnZS9zdmcreG1sPC9kYzpmb3JtYXQ+CiAgICAgICAgPGRjOnR5cGUKICAgICAg'
    b'ICAgICByZGY6cmVzb3VyY2U9Imh0dHA6Ly9wdXJsLm9yZy9kYy9kY21pdHlwZS9TdGlsbElt'
    b'YWdlIiAvPgogICAgICAgIDxkYzp0aXRsZT5CYW5kZXJhIGRlIENhc3RpbGxhLUxhIE1hbmNo'
    b'YTwvZGM6dGl0bGU+CiAgICAgICAgPGRjOmRhdGU+MTAgZGUgZmVicmVybyBkZSAyMDA2PC9k'
    b'YzpkYXRlPgogICAgICAgIDxkYzpjcmVhdG9yPgogICAgICAgICAgPGNjOkFnZW50PgogICAg'
    b'ICAgICAgICA8ZGM6dGl0bGU+VmFsYWRyZW08L2RjOnRpdGxlPgogICAgICAgICAgPC9jYzpB'
    b'Z2VudD4KICAgICAgICA8L2RjOmNyZWF0b3I+CiAgICAgICAgPGRjOnJpZ2h0cz4KICAgICAg'
    b'ICAgIDxjYzpBZ2VudD4KICAgICAgICAgICAgPGRjOnRpdGxlPkRvbWluaW8gcMO6YmxpY288'
    b'L2RjOnRpdGxlPgogICAgICAgICAgPC9jYzpBZ2VudD4KICAgICAgICA8L2RjOnJpZ2h0cz4K'
    b'ICAgICAgICA8Y2M6bGljZW5zZQogICAgICAgICAgIHJkZjpyZXNvdXJjZT0iaHR0cDovL3dl'
    b'Yi5yZXNvdXJjZS5vcmcvY2MvUHVibGljRG9tYWluIiAvPgogICAgICAgIDxkYzpsYW5ndWFn'
    b'ZT5Fc3Bhw7FvbDwvZGM6bGFuZ3VhZ2U+CiAgICAgIDwvY2M6V29yaz4KICAgICAgPGNjOkxp'
    b'Y2Vuc2UKICAgICAgICAgcmRmOmFib3V0PSJodHRwOi8vd2ViLnJlc291cmNlLm9yZy9jYy9Q'
    b'dWJsaWNEb21haW4iPgogICAgICAgIDxjYzpwZXJtaXRzCiAgICAgICAgICAgcmRmOnJlc291'
    b'cmNlPSJodHRwOi8vd2ViLnJlc291cmNlLm9yZy9jYy9SZXByb2R1Y3Rpb24iIC8+CiAgICAg'
    b'ICAgPGNjOnBlcm1pdHMKICAgICAgICAgICByZGY6cmVzb3VyY2U9Imh0dHA6Ly93ZWIucmVz'
    b'b3VyY2Uub3JnL2NjL0Rpc3RyaWJ1dGlvbiIgLz4KICAgICAgICA8Y2M6cGVybWl0cwogICAg'
    b'ICAgICAgIHJkZjpyZXNvdXJjZT0iaHR0cDovL3dlYi5yZXNvdXJjZS5vcmcvY2MvRGVyaXZh'
    b'dGl2ZVdvcmtzIiAvPgogICAgICA8L2NjOkxpY2Vuc2U+CiAgICA8L3JkZjpSREY+CiAgPC9t'
    b'ZXRhZGF0YT4KICA8ZwogICAgIGlua3NjYXBlOmxhYmVsPSJMYXllciAxIgogICAgIGlua3Nj'
    b'YXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAgaWQ9ImxheWVyMSI+CiAgICA8ZwogICAgICAg'
    b'aWQ9Imc2OTI2Ij4KICAgICAgPGcKICAgICAgICAgaWQ9ImczOTUxIj4KICAgICAgICA8cmVj'
    b'dAogICAgICAgICAgIHN0eWxlPSJvcGFjaXR5OjEuMDAwMDAwMDtmaWxsOiNhMjFjMWM7Zmls'
    b'bC1vcGFjaXR5OjEuMDAwMDAwMDtmaWxsLXJ1bGU6bm9uemVybztzdHJva2U6bm9uZTtzdHJv'
    b'a2Utd2lkdGg6MC4zODgwMDAwMTtzdHJva2UtbGluZWpvaW46bWl0ZXI7c3Ryb2tlLW1pdGVy'
    b'bGltaXQ6NC4wMDAwMDAwO3N0cm9rZS1kYXNoYXJyYXk6bm9uZTtzdHJva2UtZGFzaG9mZnNl'
    b'dDowLjAwMDAwMDAwO3N0cm9rZS1vcGFjaXR5OjEuMDAwMDAwMCIKICAgICAgICAgICBpZD0i'
    b'cmVjdDEzMTYiCiAgICAgICAgICAgd2lkdGg9IjUwMC4wMDAwMCIKICAgICAgICAgICBoZWln'
    b'aHQ9IjQ5OS45OTk4MiIKICAgICAgICAgICB4PSIwLjAwMDAwMDAwIgogICAgICAgICAgIHk9'
    b'IjAuMDAwMTc5NDk3MjkiIC8+CiAgICAgICAgPHJlY3QKICAgICAgICAgICB5PSIwLjAwMDE3'
    b'OTQ5NzI5IgogICAgICAgICAgIHg9IjUwMC4wMDAwMCIKICAgICAgICAgICBoZWlnaHQ9IjQ5'
    b'OS45OTk4MiIKICAgICAgICAgICB3aWR0aD0iNTAwLjAwMDAwIgogICAgICAgICAgIGlkPSJy'
    b'ZWN0MjA0NCIKICAgICAgICAgICBzdHlsZT0ib3BhY2l0eToxLjAwMDAwMDA7ZmlsbDojZmZm'
    b'ZmZmO2ZpbGwtb3BhY2l0eToxLjAwMDAwMDA7ZmlsbC1ydWxlOm5vbnplcm87c3Ryb2tlOm5v'
    b'bmU7c3Ryb2tlLXdpZHRoOjAuMzg4MDAwMDE7c3Ryb2tlLWxpbmVqb2luOm1pdGVyO3N0cm9r'
    b'ZS1taXRlcmxpbWl0OjQuMDAwMDAwMDtzdHJva2UtZGFzaGFycmF5Om5vbmU7c3Ryb2tlLWRh'
    b'c2hvZmZzZXQ6MC4wMDAwMDAwMDtzdHJva2Utb3BhY2l0eToxLjAwMDAwMDAiIC8+CiAgICAg'
    b'IDwvZz4KICAgICAgPGcKICAgICAgICAgaWQ9Imc2OTA5Ij4KICAgICAgICA8ZwogICAgICAg'
    b'ICAgIGlkPSJnNjg5MiI+CiAgICAgICAgICA8cGF0aAogICAgICAgICAgICAgZD0iTSAxNDUu'
    b'MzI4ODAsMTI4LjM0NDA4IEwgMTU4LjE4NTkzLDEyOC4zNDQwOCBMIDE1OC4xODU5MywxNDAu'
    b'MTI5NzkgTCAxNzIuNjE0NTAsMTQwLjEyOTc5IEwgMTcyLjYxNDUwLDEyOC4zNDQwOCBMIDE4'
    b'NS44MDQ5OCwxMjguMzQ0MDggTCAxODUuODA0OTgsMTQwLjEyOTc5IEwgMTk5LjkwMDIxLDE0'
    b'MC4xMjk3OSBMIDE5OS45MDAyMSwxMjguMzQ0MDggTCAyMTMuMTg1OTQsMTI4LjM0NDA4IEwg'
    b'MjEzLjE4NTk0LDE1NC4wNTgzNyBMIDE0NS4zMjg4MCwxNTQuMDU4MzcgTCAxNDUuMzI4ODAs'
    b'MTI4LjM0NDA4IHogTSAxNTQuMDc4ODAsMTU0LjA1ODM3IEwgMTU0LjA3ODgwLDI2Ni4yMDEy'
    b'MiBMIDIwNC40MzU5NSwyNjYuMjAxMjIgTCAyMDQuNDM1OTUsMTU0LjA1ODM3IE0gMTc4Ljkw'
    b'MDIyLDIzMS41MTA0NiBMIDE3OC45MDAyMiwxNTMuNTg4MzcgTSAxNTMuOTAwMjIsMTgwLjMw'
    b'ODM2IEwgMjA0LjA3ODc5LDE4MC4zMDgzNiBNIDE1My45MDAyMiwyMDUuMjAxMjIgTCAyMDQu'
    b'MDc4NzksMjA1LjIwMTIyIE0gMTUzLjkwMDIyLDIzMS4yMDEyMiBMIDIwNC4wNzg3OSwyMzEu'
    b'MjAxMjIiCiAgICAgICAgICAgICBzdHlsZT0iZmlsbDojZmZjYzAwO2ZpbGwtb3BhY2l0eTox'
    b'LjAwMDAwMDA7ZmlsbC1ydWxlOmV2ZW5vZGQ7c3Ryb2tlOiMwMDAwMDA7c3Ryb2tlLXdpZHRo'
    b'OjEuMDAwMDAwMHB4O3N0cm9rZS1saW5lY2FwOmJ1dHQ7c3Ryb2tlLWxpbmVqb2luOm1pdGVy'
    b'O3N0cm9rZS1vcGFjaXR5OjEuMDAwMDAwMCIKICAgICAgICAgICAgIGlkPSJwYXRoMzQ1MiIg'
    b'Lz4KICAgICAgICAgIDxwYXRoCiAgICAgICAgICAgICBkPSJNIDIxMi4wMTQ1Nyw2Mi43NDA3'
    b'OTAgTCAyMjYuNDc0OTUsNjIuNzQwNzkwIEwgMjI2LjQ3NDk1LDc1Ljk5NjE1MCBMIDI0Mi43'
    b'MDI3Miw3NS45OTYxNTAgTCAyNDIuNzAyNzIsNjIuNzQwNzkwIEwgMjU3LjUzODAxLDYyLjc0'
    b'MDc5MCBMIDI1Ny41MzgwMSw3NS45OTYxNTAgTCAyNzMuMzkwODcsNzUuOTk2MTUwIEwgMjcz'
    b'LjM5MDg3LDYyLjc0MDc5MCBMIDI4OC4zMzMzMCw2Mi43NDA3OTAgTCAyODguMzMzMzAsOTEu'
    b'NjYxNTgwIEwgMjEyLjAxNDU3LDkxLjY2MTU4MCBMIDIxMi4wMTQ1Nyw2Mi43NDA3OTAgeiBN'
    b'IDIyNC45OTU0Myw5Mi4zMjY0MjAgTCAyMjQuOTk1NDMsMjY0LjYwMzE4IEwgMjc1LjM1MjU4'
    b'LDI2NC42MDMxOCBMIDI3NS4zNTI1OCw5Mi4zMjY0MjAgTSAyNDkuODE2ODUsMTkzLjE3NTIw'
    b'IEwgMjQ5LjgxNjg1LDExNy44MDg2NCBNIDIyNC44MTY4NSwxMTguMzA4MzYgTCAyNzQuOTk1'
    b'NDIsMTE4LjMwODM2IE0gMjI0LjgxNjg1LDE0My4yMDEyMiBMIDI3NC45OTU0MiwxNDMuMjAx'
    b'MjIgTSAyMjQuODE2ODUsMTY5LjIwMTIyIEwgMjc0Ljk5NTQyLDE2OS4yMDEyMiBNIDIyNC44'
    b'MTY4NSwxOTMuMjAxMjIgTCAyNzQuOTk1NDIsMTkzLjIwMTIyIE0gMjI0LjgxNjg1LDIxOS4y'
    b'MDEyMiBMIDI3NC45OTU0MiwyMTkuMjAxMjIgTSAyNDkuODE2ODUsMjY1LjI1MjQwIEwgMjQ5'
    b'LjgxNjg1LDIxOS4xMTEwNCBNIDI0MS44MTY4NSwyMTkuMzg4NDQgTCAyNDEuODE2ODUsMTky'
    b'Ljg5Nzk5IE0gMjYwLjMyMTkzLDIxOS4zODg0NCBMIDI2MC4zMjE5MywxOTIuODk3OTkgTSAy'
    b'NDEuODE2ODUsMTE4LjM5ODU5IEwgMjQxLjgxNjg1LDkxLjkwODE0MCBNIDI1OS45NjQ3OSwx'
    b'MTguMzk4NTkgTCAyNjAuMzIxOTMsOTEuOTA4MTQwIgogICAgICAgICAgICAgc3R5bGU9ImZp'
    b'bGw6I2ZmY2MwMDtmaWxsLW9wYWNpdHk6MS4wMDAwMDAwO2ZpbGwtcnVsZTpldmVub2RkO3N0'
    b'cm9rZTojMDAwMDAwO3N0cm9rZS13aWR0aDowLjk5OTk5OTc2cHg7c3Ryb2tlLWxpbmVjYXA6'
    b'YnV0dDtzdHJva2UtbGluZWpvaW46bWl0ZXI7c3Ryb2tlLW9wYWNpdHk6MS4wMDAwMDAwIgog'
    b'ICAgICAgICAgICAgaWQ9InBhdGgzNDgyIiAvPgogICAgICAgICAgPHBhdGgKICAgICAgICAg'
    b'ICAgIGQ9Ik0gMjg3LjExODA3LDEyOC4zNDQwOCBMIDI5OS45NzUyMCwxMjguMzQ0MDggTCAy'
    b'OTkuOTc1MjAsMTQwLjEyOTc5IEwgMzE0LjQwMzc3LDE0MC4xMjk3OSBMIDMxNC40MDM3Nywx'
    b'MjguMzQ0MDggTCAzMjcuNTk0MjUsMTI4LjM0NDA4IEwgMzI3LjU5NDI1LDE0MC4xMjk3OSBM'
    b'IDM0MS42ODk0OCwxNDAuMTI5NzkgTCAzNDEuNjg5NDgsMTI4LjM0NDA4IEwgMzU0Ljk3NTIx'
    b'LDEyOC4zNDQwOCBMIDM1NC45NzUyMSwxNTQuMDU4MzcgTCAyODcuMTE4MDcsMTU0LjA1ODM3'
    b'IEwgMjg3LjExODA3LDEyOC4zNDQwOCB6IE0gMjk1Ljg2ODA3LDE1NC4wNTgzNyBMIDI5NS44'
    b'NjgwNywyNjYuMjAxMjIgTCAzNDYuMjI1MjIsMjY2LjIwMTIyIEwgMzQ2LjIyNTIyLDE1NC4w'
    b'NTgzNyBNIDMyMC42ODk0OSwyMzEuNTEwNDYgTCAzMjAuNjg5NDksMTUzLjU4ODM3IE0gMjk1'
    b'LjY4OTQ5LDE4MC4zMDgzNiBMIDM0NS44NjgwNiwxODAuMzA4MzYgTSAyOTUuNjg5NDksMjA1'
    b'LjIwMTIyIEwgMzQ1Ljg2ODA2LDIwNS4yMDEyMiBNIDI5NS42ODk0OSwyMzEuMjAxMjIgTCAz'
    b'NDUuODY4MDYsMjMxLjIwMTIyIgogICAgICAgICAgICAgc3R5bGU9ImZpbGw6I2ZmY2MwMDtm'
    b'aWxsLW9wYWNpdHk6MS4wMDAwMDAwO2ZpbGwtcnVsZTpldmVub2RkO3N0cm9rZTojMDAwMDAw'
    b'O3N0cm9rZS13aWR0aDoxLjAwMDAwMDBweDtzdHJva2UtbGluZWNhcDpidXR0O3N0cm9rZS1s'
    b'aW5lam9pbjptaXRlcjtzdHJva2Utb3BhY2l0eToxLjAwMDAwMDAiCiAgICAgICAgICAgICBp'
    b'ZD0icGF0aDM0NzAiIC8+CiAgICAgICAgICA8cGF0aAogICAgICAgICAgICAgZD0iTSAxNDYu'
    b'MjE5NTgsMjQ3LjgyNTUwIEwgMTQ2LjIxOTU4LDI4My4xODA4NCBMIDE5My42OTY3NSwyNjgu'
    b'MDI4NTUgTCAxOTMuNjk2NzUsMjMxLjkxNTYwIEwgMTc5LjU1NDYyLDIzNi45NjYzNiBMIDE3'
    b'OS41NTQ2MiwyNTMuODg2NDIgTCAxNTkuMDk5MDMsMjYwLjk1NzQ4IEwgMTU5LjA5OTAzLDI0'
    b'My4wMjcyOCBMIDE0Ni4yMTk1OCwyNDcuODI1NTAgeiBNIDE3MC41ODk1MSwyNTcuMDQzMTQg'
    b'TCAxNzAuNTg5NTEsMjY1Ljc1NTcxIE0gMTQ2LjIxOTU4LDI3My45Mzg0NSBMIDE5My42OTY3'
    b'NSwyNTguNzg2MTYgTCAxNDYuMjE5NTgsMjczLjkzODQ1IHogTSAxNTguNjUyNjQsMjcwLjIy'
    b'MjM5IEwgMTU4LjY1MjY0LDI3OC45MzQ5NiBNIDE3OS41NTAxNywyNjMuNTkzMjYgTCAxNzku'
    b'NTUwMTcsMjcyLjMwNTgzIE0gMTU3LjA3ODcyLDI3OS44OTc4NCBMIDE1My4wMzgxMSwzNzcu'
    b'ODgyNjQgTCAxMjIuNDgxMDAsMzkyLjc4MjM5IEwgMTY3LjQzMjc4LDQzNi45NzY1NyBMIDE4'
    b'NS4xMTA0NSw0MDkuNzAyNDUgTCAxOTMuODIzMDIsMjY4LjE1NDgyIE0gMTUzLjA4NTYwLDM3'
    b'OC4zMjg5OCBMIDE4NC41Nzk4NSw0MTAuMjM0NjggTSAxNTMuODEzNTQsMzYyLjA3NzMyIEwg'
    b'MTg2LjEyNTA3LDM4Ny4yMjUyOSBNIDE1NC4zOTk5OSwzNDQuOTYzMzMgTCAxODcuODc0NDUs'
    b'MzYzLjYxNzI4IE0gMTU1LjE2NjY1LDMyNy43ODU5NyBMIDE4OS4yNTQzNCwzMzkuMDYyNzMg'
    b'TSAxNTUuOTM1OTAsMzExLjc3MzYxIEwgMTkwLjgyMDkzLDMxNS4wNDc0OCBNIDE1Ni4yNjQ3'
    b'MSwyOTQuNTM5NTcgTCAxOTIuMDcwMzYsMjkxLjc0OTMzIE0gMTczLjYxOTk3LDI5My4yODIz'
    b'NyBMIDE3My42MTk5NywzMTMuMTA2NjEgTSAxNzEuNDczMzksMzMzLjU2MjIwIEwgMTcxLjQ3'
    b'MzM5LDM1NC4yNzAzMyBNIDE2OS4yMDU1MywzNzQuMDA4NjMgTCAxNjkuMjA1NTMsMzk0Ljcx'
    b'Njc2IE0gMTYyLjYyMTczLDM4OC4wODcxOSBMIDEzOC4wMjA1Niw0MDcuNDIyMDkgTSAxNzQu'
    b'Njc3NTQsNDAwLjE2NDE4IEwgMTUyLjgyMTkxLDQyMi40NzA0MSIKICAgICAgICAgICAgIHN0'
    b'eWxlPSJmaWxsOiNmZmNjMDA7ZmlsbC1vcGFjaXR5OjEuMDAwMDAwMDtmaWxsLXJ1bGU6ZXZl'
    b'bm9kZDtzdHJva2U6IzAwMDAwMDtzdHJva2Utd2lkdGg6MS4wMDAwMDAwcHg7c3Ryb2tlLWxp'
    b'bmVjYXA6YnV0dDtzdHJva2UtbGluZWpvaW46bWl0ZXI7c3Ryb2tlLW9wYWNpdHk6MS4wMDAw'
    b'MDAwIgogICAgICAgICAgICAgaWQ9InBhdGgzNTA4IiAvPgogICAgICAgICAgPHBhdGgKICAg'
    b'ICAgICAgICAgIGlkPSJwYXRoNDE0MiIKICAgICAgICAgICAgIHN0eWxlPSJmaWxsOiNmZmNj'
    b'MDA7ZmlsbC1vcGFjaXR5OjEuMDAwMDAwMDtmaWxsLXJ1bGU6ZXZlbm9kZDtzdHJva2U6IzAw'
    b'MDAwMDtzdHJva2Utd2lkdGg6MS4wMDAwMDAwcHg7c3Ryb2tlLWxpbmVjYXA6YnV0dDtzdHJv'
    b'a2UtbGluZWpvaW46bWl0ZXI7c3Ryb2tlLW9wYWNpdHk6MS4wMDAwMDAwIgogICAgICAgICAg'
    b'ICAgZD0iTSAzNTQuMDg0NDQsMjQ3LjgyNTUwIEwgMzU0LjA4NDQ0LDI4My4xODA4NCBMIDMw'
    b'Ni42MDcyNywyNjguMDI4NTUgTCAzMDYuNjA3MjcsMjMxLjkxNTYwIEwgMzIwLjc0OTQwLDIz'
    b'Ni45NjYzNiBMIDMyMC43NDk0MCwyNTMuODg2NDIgTCAzNDEuMjA0OTksMjYwLjk1NzQ4IEwg'
    b'MzQxLjIwNDk5LDI0My4wMjcyOCBMIDM1NC4wODQ0NCwyNDcuODI1NTAgeiBNIDMyOS43MTQ1'
    b'MSwyNTcuMDQzMTQgTCAzMjkuNzE0NTEsMjY1Ljc1NTcxIE0gMzU0LjA4NDQ0LDI3My45Mzg0'
    b'NSBMIDMwNi42MDcyNywyNTguNzg2MTYgTCAzNTQuMDg0NDQsMjczLjkzODQ1IHogTSAzNDEu'
    b'NjUxMzgsMjcwLjIyMjM5IEwgMzQxLjY1MTM4LDI3OC45MzQ5NiBNIDMyMC43NTM4NSwyNjMu'
    b'NTkzMjYgTCAzMjAuNzUzODUsMjcyLjMwNTgzIE0gMzQzLjIyNTMwLDI3OS44OTc4NCBMIDM0'
    b'Ny4yNjU5MSwzNzcuODgyNjQgTCAzNzcuODIzMDIsMzkyLjc4MjM5IEwgMzMyLjg3MTI0LDQz'
    b'Ni45NzY1NyBMIDMxNS4xOTM1Nyw0MDkuNzAyNDUgTCAzMDYuNDgxMDAsMjY4LjE1NDgyIE0g'
    b'MzQ3LjIxODQyLDM3OC4zMjg5OCBMIDMxNS43MjQxNyw0MTAuMjM0NjggTSAzNDYuNDkwNDgs'
    b'MzYyLjA3NzMyIEwgMzE0LjE3ODk1LDM4Ny4yMjUyOSBNIDM0NS45MDQwMywzNDQuOTYzMzMg'
    b'TCAzMTIuNDI5NTcsMzYzLjYxNzI4IE0gMzQ1LjEzNzM3LDMyNy43ODU5NyBMIDMxMS4wNDk2'
    b'OCwzMzkuMDYyNzMgTSAzNDQuMzY4MTIsMzExLjc3MzYxIEwgMzA5LjQ4MzA5LDMxNS4wNDc0'
    b'OCBNIDM0NC4wMzkzMSwyOTQuNTM5NTcgTCAzMDguMjMzNjYsMjkxLjc0OTMzIE0gMzI2LjY4'
    b'NDA1LDI5My4yODIzNyBMIDMyNi42ODQwNSwzMTMuMTA2NjEgTSAzMjguODMwNjMsMzMzLjU2'
    b'MjIwIEwgMzI4LjgzMDYzLDM1NC4yNzAzMyBNIDMzMS4wOTg0OSwzNzQuMDA4NjMgTCAzMzEu'
    b'MDk4NDksMzk0LjcxNjc2IE0gMzM3LjY4MjI5LDM4OC4wODcxOSBMIDM2Mi4yODM0Niw0MDcu'
    b'NDIyMDkgTSAzMjUuNjI2NDgsNDAwLjE2NDE4IEwgMzQ3LjQ4MjExLDQyMi40NzA0MSIgLz4K'
    b'ICAgICAgICAgIDxwYXRoCiAgICAgICAgICAgICBkPSJNIDIyMy41MzY1MywyNTAuNTM4MDYg'
    b'TCAyMjMuNTM2NTMsMjU5LjI1MDYzIE0gMjc2Ljc3ODkyLDI1MC41MzgwNiBMIDI3Ni43Nzg5'
    b'MiwyNTkuMjUwNjMgTSAxOTMuMTI4NTQsMjU4LjkzNzE4IEwgMzA2LjU3NTA3LDI1OC45Mzcx'
    b'OCBNIDE5My4xMjg1NCwyNjcuODg0MjAgTCAzMDYuNTc1MDcsMjY3Ljg4NDIwIE0gMjM3LjUz'
    b'NjUzLDI1OS40NTA1OCBMIDIzNy41MzY1MywyNjcuNTM3NjggTSAyMDkuNTM2NTMsMjU5LjQ1'
    b'MDU4IEwgMjA5LjUzNjUzLDI2Ny41Mzc2OCBNIDI2Mi44OTM5MiwyNTkuNDUwNTggTCAyNjIu'
    b'ODkzOTIsMjY3LjUzNzY4IE0gMjkwLjg5MzkyLDI1OS40NTA1OCBMIDI5MC44OTM5MiwyNjcu'
    b'NTM3NjggTSAxOTIuMzI4ODAsMjkxLjc5NDkxIEwgMzA3Ljg2NjIzLDI5MS43OTQ5MSBNIDE5'
    b'MC43MzU1MywzMTUuMTY5OTEgTCAzMDkuNDU5NzEsMzE1LjE2OTkxIE0gMTg5LjY3MzAwLDMz'
    b'OS4xNjk5MSBMIDMxMC41MjIxMCwzMzkuMTY5OTEgTSAxODguMjU2MTEsMzYzLjYxNjM0IEwg'
    b'MzExLjkzODg4LDM2My42MTYzNCBNIDE4Ni44Mzg5NCwzODcuNjE2MzQgTCAzMTMuMzU1OTAs'
    b'Mzg3LjYxNjM0IE0gMTg0LjM1ODQxLDQxMC4zNjYzNCBMIDMxNS44MzY1Myw0MTAuMzY2MzQg'
    b'TSAyMjMuNzUwMDAsMjY3LjgwODM3IEwgMjIzLjc1MDAwLDI5MS41NTgzNyBNIDI3Ni43MzIx'
    b'NCwyNjcuODA4MzcgTCAyNzYuNzMyMTQsMjkxLjU1ODM3IE0gMjIzLjc1MDAwLDMxNS42Mjk4'
    b'MCBMIDIyMy43NTAwMCwzMzkuMzc5ODAgTSAyNzYuNzMyMTQsMzE1LjYyOTgwIEwgMjc2Ljcz'
    b'MjE0LDMzOS4zNzk4MCBNIDIwNC4wMTc4NSwyOTEuNjExOTQgTCAyMDQuMDE3ODUsMzE1LjM2'
    b'MTk0IE0gMjk2LjU1MzU2LDI5MS42MTE5NCBMIDI5Ni41NTM1NiwzMTUuMzYxOTQgTSAyNTAu'
    b'Mjg1NzAsMjkxLjYxMTk0IEwgMjUwLjI4NTcwLDMxNS4zNjE5NCBNIDIwNC4wMTc4NSwzMzku'
    b'NjExOTQgTCAyMDQuMDE3ODUsMzYzLjM2MTk0IE0gMjk2LjU1MzU2LDMzOS42MTE5NCBMIDI5'
    b'Ni41NTM1NiwzNjMuMzYxOTQgTSAyMDQuMDE3ODUsMzg3LjU5MDMxIEwgMjA0LjAxNzg1LDQx'
    b'MC4zMTIxNyBNIDI5Ni41NTM1NiwzODcuNTkwMzEgTCAyOTYuNTUzNTYsNDEwLjMxMjE3IE0g'
    b'Mjg4LjU5MDc1LDQxMC4yNjM4MCBMIDI5OS41MTc4NSw0MzcuMDEzNjcgTSAyNjMuMTgyMzcs'
    b'NDEwLjYxNzc0IEwgMjY2Ljc0NzQ5LDQzNy4xOTU0NyBNIDIxMS45MzA5MCw0MTAuMjYzODAg'
    b'TCAyMDEuMDAzODAsNDM3LjAxMzY3IE0gMjM3LjMzOTI4LDQxMC42MTc3NCBMIDIzMy43NzQx'
    b'Niw0MzcuMTk1NDcgTSAzMzIuODcxMjQsNDM2Ljk3NjU3IEwgMTY3LjUyMDQ4LDQzNy4yNTky'
    b'MCBMIDE2Ny40NzY2Myw0MzcuMTE3ODkgTCAxODUuMTEwNDUsNDA5LjcwMjQ1IEwgMTkzLjc1'
    b'OTg5LDI2OC4wOTE2OCBMIDE5My42OTY3NSwyMzEuOTE1NjAgTCAyMTMuODk5ODAsMjMxLjkx'
    b'NTYwIEwgMjEzLjg5OTgwLDI1MC4zNTA4OCBMIDIzNC44NjA0NywyNTAuMzUwODggTCAyMzQu'
    b'ODYwNDcsMjMxLjkxNTYwIEwgMjY0LjkxMjUxLDIzMS45MTU2MCBMIDI2NC45MTI1MSwyNTAu'
    b'MzUwODggTCAyODYuMTI1NzEsMjUwLjM1MDg4IEwgMjg2LjEyNTcxLDIzMS45MTU2MCBMIDMw'
    b'Ni43NDE5MiwyMzEuOTE1NjAgTCAzMDYuNDgxMDAsMjY4LjE1NDgyIEwgMzE1LjE5MzU3LDQw'
    b'OS43MDI0NSBMIDMzMi44NzEyNCw0MzYuOTc2NTcgeiAiCiAgICAgICAgICAgICBzdHlsZT0i'
    b'ZmlsbDojZmZjYzAwO2ZpbGwtb3BhY2l0eToxLjAwMDAwMDA7ZmlsbC1ydWxlOmV2ZW5vZGQ7'
    b'c3Ryb2tlOiMwMDAwMDA7c3Ryb2tlLXdpZHRoOjEuMDAwMDAwMHB4O3N0cm9rZS1saW5lY2Fw'
    b'OmJ1dHQ7c3Ryb2tlLWxpbmVqb2luOm1pdGVyO3N0cm9rZS1vcGFjaXR5OjEuMDAwMDAwMCIK'
    b'ICAgICAgICAgICAgIGlkPSJwYXRoNjc2NSIKICAgICAgICAgICAgIHNvZGlwb2RpOm5vZGV0'
    b'eXBlcz0iY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2Nj'
    b'Y2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjY2NjYyIgLz4KICAgICAgICAgIDxwYXRoCiAgICAg'
    b'ICAgICAgICBkPSJNIDIyMi40MTY1Myw0MTAuMjcyOTYgQyAyMjIuNDE2NTMsNDEwLjI3Mjk2'
    b'IDIyMi4wMzczNywzODQuMTY0NjkgMjIyLjQxNjUzLDM2My45MTE0MiBDIDIyMi43OTUzOCwz'
    b'NDMuNjY3NTggMjM1Ljk4MzE5LDMzNy40NTc4NCAyNTAuMTAxNjYsMzM3Ljc1MTMzIEMgMjY0'
    b'LjIyMDEzLDMzOC4wNDQ4NCAyNzcuMjA5NzgsMzQyLjk1MTQ5IDI3Ny44MjYwMywzNjQuNDA0'
    b'ODkgQyAyNzguNDQyMTQsMzg1Ljg1MDc4IDI3Ny44MjYwMyw0MTAuMjk0NDQgMjc3LjgyNjAz'
    b'LDQxMC4yOTQ0NCBMIDIyMi40MTY1Myw0MTAuMjcyOTYgeiBNIDIyMi42OTYzNCwzOTAuNTcx'
    b'NDMgTCAyNzcuMzAzMzUsMzkwLjU3MTQzIE0gMjIyLjY5NjM0LDM2Ni41NzE0MyBMIDI3Ny4z'
    b'MDMzNSwzNjYuNTcxNDMgTSAyMjkuMzAyODYsMzQ0LjQ4NjQ5IEwgMjUwLjE3Mzk0LDM2OC43'
    b'Mjc5NyBMIDI3MS4wNDUwMiwzNDQuNDg2NDkiCiAgICAgICAgICAgICBzdHlsZT0iZmlsbDoj'
    b'ZmZjYzAwO2ZpbGwtb3BhY2l0eToxLjAwMDAwMDA7ZmlsbC1ydWxlOmV2ZW5vZGQ7c3Ryb2tl'
    b'OiMwMDAwMDA7c3Ryb2tlLXdpZHRoOjEuMDAwMDAwNDtzdHJva2UtbGluZWNhcDpidXR0O3N0'
    b'cm9rZS1saW5lam9pbjpyb3VuZDtzdHJva2UtbWl0ZXJsaW1pdDo0LjAwMDAwMDA7c3Ryb2tl'
    b'LW9wYWNpdHk6MS4wMDAwMDAwIgogICAgICAgICAgICAgaWQ9InBhdGg2MDkxIiAvPgogICAg'
    b'ICAgIDwvZz4KICAgICAgICA8ZwogICAgICAgICAgIGlkPSJnNjkwMSIKICAgICAgICAgICBz'
    b'dHlsZT0iZmlsbDojMWQ0YmJhO2ZpbGwtb3BhY2l0eToxLjAwMDAwMDAiPgogICAgICAgICAg'
    b'PHBhdGgKICAgICAgICAgICAgIHN0eWxlPSJmaWxsOiMxZDRiYmE7ZmlsbC1vcGFjaXR5OjEu'
    b'MDAwMDAwMDtmaWxsLXJ1bGU6ZXZlbm9kZDtzdHJva2U6IzAwMDAwMDtzdHJva2Utd2lkdGg6'
    b'MC45OTk5OTk4ODtzdHJva2UtbGluZWNhcDpidXR0O3N0cm9rZS1saW5lam9pbjpyb3VuZDtz'
    b'dHJva2UtbWl0ZXJsaW1pdDo0LjAwMDAwMDA7c3Ryb2tlLWRhc2hhcnJheTpub25lO3N0cm9r'
    b'ZS1vcGFjaXR5OjEuMDAwMDAwMCIKICAgICAgICAgICAgIGQ9Ik0gMjEzLjg4NDQyLDMyNC4x'
    b'MDgyNyBDIDIxMy44ODQ0MiwzMjQuMTA4MjcgMjEzLjU1MTgyLDMwNy42NDcyOCAyMTMuNjg1'
    b'NjUsMjk0Ljg3NzgxIEMgMjEzLjgxOTM3LDI4Mi4xMTQyOSAyMTguNjczMDcsMjc4LjE5OTEy'
    b'IDIyMy42NTY1MCwyNzguMzg0MTYgQyAyMjguNjM5OTIsMjc4LjU2OTIyIDIzMy4yODYzNiwy'
    b'ODEuNjYyODAgMjMzLjUwMzg5LDI5NS4xODg5MyBDIDIzMy43MjEzNSwzMDguNzEwMzQgMjMz'
    b'LjQ0MjQ0LDMyNC4xMjE4MSAyMzMuNDQyNDQsMzI0LjEyMTgxIEwgMjEzLjg4NDQyLDMyNC4x'
    b'MDgyNyB6ICIKICAgICAgICAgICAgIGlkPSJwYXRoMTA3NTMiCiAgICAgICAgICAgICBzb2Rp'
    b'cG9kaTpub2RldHlwZXM9ImN6c3pjYyIgLz4KICAgICAgICAgIDxwYXRoCiAgICAgICAgICAg'
    b'ICBzb2RpcG9kaTpub2RldHlwZXM9ImN6c3pjYyIKICAgICAgICAgICAgIGlkPSJwYXRoNjA3'
    b'NSIKICAgICAgICAgICAgIGQ9Ik0gMjY2Ljk5MTU2LDMyNC4xMDgyNyBDIDI2Ni45OTE1Niwz'
    b'MjQuMTA4MjcgMjY2LjY1ODk2LDMwNy42NDcyOCAyNjYuNzkyNzksMjk0Ljg3NzgxIEMgMjY2'
    b'LjkyNjUxLDI4Mi4xMTQyOSAyNzEuNzgwMjEsMjc4LjE5OTEyIDI3Ni43NjM2NCwyNzguMzg0'
    b'MTYgQyAyODEuNzQ3MDYsMjc4LjU2OTIyIDI4Ni4zOTM1MCwyODEuNjYyODAgMjg2LjYxMTAz'
    b'LDI5NS4xODg5MyBDIDI4Ni44Mjg0OSwzMDguNzEwMzQgMjg2LjU0OTU4LDMyNC4xMjE4MSAy'
    b'ODYuNTQ5NTgsMzI0LjEyMTgxIEwgMjY2Ljk5MTU2LDMyNC4xMDgyNyB6ICIKICAgICAgICAg'
    b'ICAgIHN0eWxlPSJmaWxsOiMxZDRiYmE7ZmlsbC1vcGFjaXR5OjEuMDAwMDAwMDtmaWxsLXJ1'
    b'bGU6ZXZlbm9kZDtzdHJva2U6IzAwMDAwMDtzdHJva2Utd2lkdGg6MC45OTk5OTk4ODtzdHJv'
    b'a2UtbGluZWNhcDpidXR0O3N0cm9rZS1saW5lam9pbjpyb3VuZDtzdHJva2UtbWl0ZXJsaW1p'
    b'dDo0LjAwMDAwMDA7c3Ryb2tlLWRhc2hhcnJheTpub25lO3N0cm9rZS1vcGFjaXR5OjEuMDAw'
    b'MDAwMCIgLz4KICAgICAgICAgIDxwYXRoCiAgICAgICAgICAgICBzb2RpcG9kaTpub2RldHlw'
    b'ZXM9ImN6c3pjYyIKICAgICAgICAgICAgIGlkPSJwYXRoNjA3NyIKICAgICAgICAgICAgIGQ9'
    b'Ik0gMTcyLjg0MzU5LDIxMS4yNjQ5NiBDIDE3Mi44NDM1OSwyMTEuMjY0OTYgMTcyLjYyNDQ4'
    b'LDE5NS4yNDQxNiAxNzIuNzEyNjQsMTgyLjgxNjE2IEMgMTcyLjgwMDc0LDE3MC4zOTM5NSAx'
    b'NzUuOTk4MjMsMTY2LjU4MzQ3IDE3OS4yODExOCwxNjYuNzYzNTYgQyAxODIuNTY0MTMsMTY2'
    b'Ljk0MzY3IDE4NS42MjUwOCwxNjkuOTU0NTMgMTg1Ljc2ODM4LDE4My4xMTg5NiBDIDE4NS45'
    b'MTE2NCwxOTYuMjc4NzkgMTg1LjcyNzkwLDIxMS4yNzgxNCAxODUuNzI3OTAsMjExLjI3ODE0'
    b'IEwgMTcyLjg0MzU5LDIxMS4yNjQ5NiB6ICIKICAgICAgICAgICAgIHN0eWxlPSJmaWxsOiMx'
    b'ZDRiYmE7ZmlsbC1vcGFjaXR5OjEuMDAwMDAwMDtmaWxsLXJ1bGU6ZXZlbm9kZDtzdHJva2U6'
    b'IzAwMDAwMDtzdHJva2Utd2lkdGg6MS4wMDAwMDAxO3N0cm9rZS1saW5lY2FwOmJ1dHQ7c3Ry'
    b'b2tlLWxpbmVqb2luOnJvdW5kO3N0cm9rZS1taXRlcmxpbWl0OjQuMDAwMDAwMDtzdHJva2Ut'
    b'ZGFzaGFycmF5Om5vbmU7c3Ryb2tlLW9wYWNpdHk6MS4wMDAwMDAwIiAvPgogICAgICAgICAg'
    b'PHBhdGgKICAgICAgICAgICAgIHN0eWxlPSJmaWxsOiMxZDRiYmE7ZmlsbC1vcGFjaXR5OjEu'
    b'MDAwMDAwMDtmaWxsLXJ1bGU6ZXZlbm9kZDtzdHJva2U6IzAwMDAwMDtzdHJva2Utd2lkdGg6'
    b'MS4wMDAwMDAxO3N0cm9rZS1saW5lY2FwOmJ1dHQ7c3Ryb2tlLWxpbmVqb2luOnJvdW5kO3N0'
    b'cm9rZS1taXRlcmxpbWl0OjQuMDAwMDAwMDtzdHJva2UtZGFzaGFycmF5Om5vbmU7c3Ryb2tl'
    b'LW9wYWNpdHk6MS4wMDAwMDAwIgogICAgICAgICAgICAgZD0iTSAyNDIuMzAxMjgsMTgzLjY1'
    b'NjI2IEMgMjQyLjMwMTI4LDE4My42NTYyNiAyNDIuMDMyMzMsMTY0LjI0MTcwIDI0Mi4xNDA1'
    b'NSwxNDkuMTgxMDEgQyAyNDIuMjQ4NjgsMTM0LjEyNzM0IDI0Ni4xNzM0NywxMjkuNTA5Njcg'
    b'MjUwLjIwMzE2LDEyOS43Mjc5MSBDIDI1NC4yMzI4NSwxMjkuOTQ2MTcgMjU3Ljk5MDA0LDEz'
    b'My41OTQ4NCAyNTguMTY1OTMsMTQ5LjU0Nzk2IEMgMjU4LjM0MTc4LDE2NS40OTU1MCAyNTgu'
    b'MTE2MjQsMTgzLjY3MjIzIDI1OC4xMTYyNCwxODMuNjcyMjMgTCAyNDIuMzAxMjgsMTgzLjY1'
    b'NjI2IHogIgogICAgICAgICAgICAgaWQ9InBhdGg2MDc5IgogICAgICAgICAgICAgc29kaXBv'
    b'ZGk6bm9kZXR5cGVzPSJjenN6Y2MiIC8+CiAgICAgICAgICA8cGF0aAogICAgICAgICAgICAg'
    b'c3R5bGU9ImZpbGw6IzFkNGJiYTtmaWxsLW9wYWNpdHk6MS4wMDAwMDAwO2ZpbGwtcnVsZTpl'
    b'dmVub2RkO3N0cm9rZTojMDAwMDAwO3N0cm9rZS13aWR0aDoxLjAwMDAwMDE7c3Ryb2tlLWxp'
    b'bmVjYXA6YnV0dDtzdHJva2UtbGluZWpvaW46cm91bmQ7c3Ryb2tlLW1pdGVybGltaXQ6NC4w'
    b'MDAwMDAwO3N0cm9rZS1kYXNoYXJyYXk6bm9uZTtzdHJva2Utb3BhY2l0eToxLjAwMDAwMDAi'
    b'CiAgICAgICAgICAgICBkPSJNIDMxNC42MzI4NiwyMTEuMjY0OTYgQyAzMTQuNjMyODYsMjEx'
    b'LjI2NDk2IDMxNC40MTM3NSwxOTUuMjQ0MTYgMzE0LjUwMTkxLDE4Mi44MTYxNiBDIDMxNC41'
    b'OTAwMSwxNzAuMzkzOTUgMzE3Ljc4NzUwLDE2Ni41ODM0NyAzMjEuMDcwNDUsMTY2Ljc2MzU2'
    b'IEMgMzI0LjM1MzQwLDE2Ni45NDM2NyAzMjcuNDE0MzUsMTY5Ljk1NDUzIDMyNy41NTc2NSwx'
    b'ODMuMTE4OTYgQyAzMjcuNzAwOTEsMTk2LjI3ODc5IDMyNy41MTcxNywyMTEuMjc4MTQgMzI3'
    b'LjUxNzE3LDIxMS4yNzgxNCBMIDMxNC42MzI4NiwyMTEuMjY0OTYgeiAiCiAgICAgICAgICAg'
    b'ICBpZD0icGF0aDYwODEiCiAgICAgICAgICAgICBzb2RpcG9kaTpub2RldHlwZXM9ImN6c3pj'
    b'YyIgLz4KICAgICAgICAgIDxwYXRoCiAgICAgICAgICAgICBzb2RpcG9kaTpub2RldHlwZXM9'
    b'ImN6c3pjYyIKICAgICAgICAgICAgIGlkPSJwYXRoNjA4OSIKICAgICAgICAgICAgIGQ9Ik0g'
    b'MjM4LjM1OTI2LDQxMC4yODEyNiBDIDIzOC4zNTkyNiw0MTAuMjgxMjYgMjM3Ljk1NTY0LDM5'
    b'MC44NjY3MCAyMzguMTE4MDUsMzc1LjgwNjAxIEMgMjM4LjI4MDMyLDM2MC43NTIzNCAyNDQu'
    b'MTcwMzQsMzU2LjEzNDY3IDI1MC4yMTc3OSwzNTYuMzUyOTEgQyAyNTYuMjY1MjQsMzU2LjU3'
    b'MTE3IDI2MS45MDM3NCwzNjAuMjE5ODQgMjYyLjE2NzcwLDM3Ni4xNzI5NiBDIDI2Mi40MzE2'
    b'MCwzOTIuMTIwNTAgMjYyLjA5MzEzLDQxMC4yOTcyMyAyNjIuMDkzMTMsNDEwLjI5NzIzIEwg'
    b'MjM4LjM1OTI2LDQxMC4yODEyNiB6ICIKICAgICAgICAgICAgIHN0eWxlPSJmaWxsOiMxZDRi'
    b'YmE7ZmlsbC1vcGFjaXR5OjEuMDAwMDAwMDtmaWxsLXJ1bGU6ZXZlbm9kZDtzdHJva2U6IzAw'
    b'MDAwMDtzdHJva2Utd2lkdGg6MS4wMDAwMDAyO3N0cm9rZS1saW5lY2FwOmJ1dHQ7c3Ryb2tl'
    b'LWxpbmVqb2luOnJvdW5kO3N0cm9rZS1taXRlcmxpbWl0OjQuMDAwMDAwMDtzdHJva2UtZGFz'
    b'aGFycmF5Om5vbmU7c3Ryb2tlLW9wYWNpdHk6MS4wMDAwMDAwIiAvPgogICAgICAgIDwvZz4K'
    b'ICAgICAgPC9nPgogICAgPC9nPgogIDwvZz4KPC9zdmc+Cg==', 'ES_CM')

ES_CM = b64_ES_CM
index.append("ES_CM")
index.append("Spain Castilla La Mancha")
catalog["ES_CM"] = ES_CM
catalog["Spain Castilla La Mancha"] = ES_CM
country["Spain Castilla La Mancha"] = ('ES_CM', '', 1)
lookup["ES_CM"] = ('ES_CM', '', 'Spain Castilla La Mancha', 1)
lookup["Toledo Spain Castilla La Mancha"] = ('ES_CM', '', 'Spain Castilla La Mancha', 1)
lookup["Spain Castilla La Mancha"] = ('ES_CM', '', 'Spain Castilla La Mancha', 1)
details["ES_CM"] = {"continent":"Europe","capital":"Toledo","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_CM"] = ('ES_CM', 'Spain Castilla La Mancha', 1)
regional["Spain Castilla La Mancha"] = ('ES_CM', 'Spain Castilla La Mancha', 1)
#----------------------------------------------------------------------
b64_ES_CN = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI2MDAiIGhlaWdodD0iNDAwIj4KPHJl'
    b'Y3Qgd2lkdGg9IjYwMCIgaGVpZ2h0PSI0MDAiIGZpbGw9IiNmYzAiLz4KPHJlY3Qgd2lkdGg9'
    b'IjQwMCIgaGVpZ2h0PSI0MDAiIGZpbGw9IiMwNzY4YTkiLz4KPHJlY3Qgd2lkdGg9IjIwMCIg'
    b'aGVpZ2h0PSI0MDAiIGZpbGw9IiNmZmYiLz4KPC9zdmc+', 'ES_CN')

ES_CN = b64_ES_CN
index.append("ES_CN")
index.append("Spain Canarias")
catalog["ES_CN"] = ES_CN
catalog["Spain Canarias"] = ES_CN
country["Spain Canarias"] = ('ES_CN', '', 1)
lookup["ES_CN"] = ('ES_CN', '', 'Spain Canarias', 1)
lookup["Las Palmas Spain Canarias"] = ('ES_CN', '', 'Spain Canarias', 1)
lookup["Spain Canarias"] = ('ES_CN', '', 'Spain Canarias', 1)
details["ES_CN"] = {"continent":"Europe","capital":"Las Palmas","currency":"","web":"","lang":"","tz":"±00:00","altname":""}
regional["ES_CN"] = ('ES_CN', 'Spain Canarias', 1)
regional["Spain Canarias"] = ('ES_CN', 'Spain Canarias', 1)
#----------------------------------------------------------------------
b64_ES_CT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWVzLWN0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZjZGQwOSIg'
    b'ZD0iTTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggc3Ryb2tlPSIjZGExMjFhIiBzdHJva2Ut'
    b'd2lkdGg9IjYwIiBkPSJNMCA5MGg4MTBtMCAxMjBIMG0wIDEyMGg4MTBtMCAxMjBIMCIgdHJh'
    b'bnNmb3JtPSJzY2FsZSguNzkwMTIgLjg4ODg5KSIvPgo8L3N2Zz4K', 'ES_CT')

ES_CT = b64_ES_CT
index.append("ES_CT")
index.append("Spain Catalunya")
catalog["ES_CT"] = ES_CT
catalog["Spain Catalunya"] = ES_CT
country["Spain Catalunya"] = ('ES_CT', '', 1)
lookup["ES_CT"] = ('ES_CT', '', 'Spain Catalunya', 1)
lookup["Barcelona Spain Catalunya"] = ('ES_CT', '', 'Spain Catalunya', 1)
lookup["Spain Catalunya"] = ('ES_CT', '', 'Spain Catalunya', 1)
details["ES_CT"] = {"continent":"Europe","capital":"Barcelona","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_CT"] = ('ES_CT', 'Spain Catalunya', 1)
regional["Spain Catalunya"] = ('ES_CT', 'Spain Catalunya', 1)
#----------------------------------------------------------------------
b64_ES_EX = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIj8+Cjxzdmcgd2lkdGg9IjkwMCIgaGVpZ2h0PSI2MDAiIHht'
    b'bG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CjxwYXRoIGQ9Im0wLDBoOTAwdjYw'
    b'MEgwIi8+CjxwYXRoIGQ9Im0wLDBoOTAwdjQwMEgwIiBmaWxsPSIjRkZGIi8+CjxwYXRoIGQ9'
    b'Im0wLDBoOTAwdjIwMEgwIiBmaWxsPSIjMDBBQjM5Ii8+Cjwvc3ZnPg==', 'ES_EX')

ES_EX = b64_ES_EX
index.append("ES_EX")
index.append("Spain Extremadura")
catalog["ES_EX"] = ES_EX
catalog["Spain Extremadura"] = ES_EX
country["Spain Extremadura"] = ('ES_EX', '', 1)
lookup["ES_EX"] = ('ES_EX', '', 'Spain Extremadura', 1)
lookup["Merida Spain Extremadura"] = ('ES_EX', '', 'Spain Extremadura', 1)
lookup["Spain Extremadura"] = ('ES_EX', '', 'Spain Extremadura', 1)
details["ES_EX"] = {"continent":"Europe","capital":"Merida","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_EX"] = ('ES_EX', 'Spain Extremadura', 1)
regional["Spain Extremadura"] = ('ES_EX', 'Spain Extremadura', 1)
#----------------------------------------------------------------------
b64_ES_GA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWVzLWdhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZm9udC1zaXplPSIxMiI+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogICAgPHBhdGggZmlsbD0iIzA5YyIgZD0iTTY0MCA0MTAuMSA5MS43LS4xSDB2'
    b'NjguNEw1NTAuNCA0ODBINjQwdi02OS44Ii8+CiAgPC9nPgogIDxnIGZvbnQtc2l6ZT0iMTIi'
    b'PgogICAgPHBhdGggZmlsbD0iIzAwNWJiZiIgZD0iTTMxNi40IDM1Mi4zYy02NCAwLTYyLTYw'
    b'LjMtNjItNjAuM3YtOTIuOGgxMjRWMjkyczIuMiA2MC4zLTYyIDYwLjMiLz4KICAgIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI5Ni42IDQwMS4yYy02MCAwLTU4LjEt'
    b'NTYuNS01OC4xLTU2LjV2LTg2LjloMTE2LjN2ODYuOXMyIDU2LjUtNTguMiA1Ni41eiIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNkODExMjYiIGQ9Ik0zMTUuOCAxNDFzLTEzLjItNi41LTI1LjcgM2MwIDAtMjIu'
    b'NS0zLjMtMjQuMiAxOC4zIDAgLjgtLjIgMi40LjIgMyAuNS40LjkgMS4zLjkgMS45IDAgLjYu'
    b'MyAxIC41IDEuMiAwIC4zLjQuNy42IDEuOCAwIDEuMi0uMyAxLjcgMSAyLjkgMSAxIDEgNC4z'
    b'IDEgNS4zcy42IDMuNSAxIDRjLjYuNiAxLjQgMiAxLjQgMy4yIDAgMSAuNSA0LjIuMiA1LS4y'
    b'LjggMS4zIDEuOCAyLjYgMi4yIDEuMy40IDE3IDUuNiA0MC4xIDUuMSAyMy0uMyAzMS40LTEu'
    b'NiA0MS01YTIuMyAyLjMgMCAwIDAgMS42LTIuNCA3IDcgMCAwIDEgLjMtMy4zYy40LS42IDMu'
    b'Mi01IDIuNi01LjctLjYtLjktLjYtMi42IDAtMy4yLjUtLjcgMi4yLTQgMi41LTUuMy4zLTEu'
    b'My40LTMgMS0zLjMuNi0uNS44LTIgMS0yLjRhNC4zIDQuMyAwIDAgMSAxLjItMS43czEtNS41'
    b'LjQtOC4xYy0uNy0yLjctNC44LTE0LjItMjEtMTEuOCAwIDAtMTIuMi05LjMtMzAuMi00Ljgi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjUiIGQ9Ik0yOTYuMSAyMDMuMnMtMTIuNC02LTI0LjEgMi44YzAgMC0yMS4xLTMtMjIuNyAx'
    b'Ny4yIDAgLjgtLjIgMi4zLjIgMi44LjQuNC44IDEuMi44IDEuOCAwIC42LjMuOS41IDEuMSAw'
    b'IC4zLjQuNy41IDEuNyAwIDEuMS0uMiAxLjYuOSAyLjcgMSAxIDEgNC4xIDEgNSAwIC45LjYg'
    b'My4zIDEgMy44LjUuNSAxLjMgMS44IDEuMyAyLjkgMCAxIC40IDQgLjIgNC43LS4yLjggMS4y'
    b'IDEuNyAyLjQgMi4xIDEuMi40IDE2IDUuMiAzNy42IDQuOCAyMS42LS4zIDI5LjQtMS41IDM4'
    b'LjQtNC43YTIuMiAyLjIgMCAwIDAgMS41LTIuM2MtLjItLjYgMC0yLjYuMy0zLjEuNC0uNSAz'
    b'LTQuNiAyLjQtNS4zLS41LS44LS41LTIuNCAwLTMgLjUtLjcgMi4xLTMuNyAyLjQtNSAuMy0x'
    b'LjIuNC0yLjcgMS0zLjEuNS0uNC43LTEuOS44LTIuMmE0IDQgMCAwIDEgMS4yLTEuNnMxLTUu'
    b'MS40LTcuNmMtLjctMi41LTQuNS0xMy4zLTE5LjgtMTEgMCAwLTExLjQtOC43LTI4LjItNC41'
    b'eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNiY2FjMGIiIGQ9Ik0zNjAuMSAxODFjLTUwLjEtMTUuOC04OS0uNy04'
    b'OS0uN3MuNSAxLjcuOSAyLjMgMSAxLjggMSAyLjd2M2MwIC44LS40IDQgMi40IDMuOSAwIDAg'
    b'MzUtMTMuNyA4MC40LjcgMCAwIDEuMy0xIDEuMy0yLjZhOC41IDguNSAwIDAgMSAxLTQuM2Mu'
    b'Ni0uOSAyLTMuNiAyLTUiLz4KICAgIDxwYXRoIGZpbGw9IiNjOGIxMDAiIGZpbGwtb3BhY2l0'
    b'eT0iLjkiIGQ9Ik0zMTMuNiAyNjQuOWgtMjEuOXMtMi4xIDE5LjUgMTQuOCAyNS41djEuN2gz'
    b'LjV2Mi40cy02LjIgNS41LS44IDEydjEuOGguOXYzLjJoMXY1cy0uOCAxOC4yLTE4LjcgMjd2'
    b'MUgzNDB2LTFjLTE3LjktOC43LTE4LjctMjctMTguNy0yN3YtNWgxdi0zLjJoMXYtMS45YzUu'
    b'Mi02LjQtMS0xMi0xLTEydi0yLjNoMy43di0xLjdjMTYuNy02IDE0LjYtMjUuNSAxNC42LTI1'
    b'LjVoLTI3LjEiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI5'
    b'NCAzMTkuM2gtMjAuNXMtMiAxOC4zIDEzLjggMjMuOXYxLjZoMy4zdjIuMnMtNS44IDUuMi0u'
    b'NyAxMS4ydjEuOGguOHYzaDF2NC43cy0uOCAxNy0xNy42IDI1LjJ2MWg0NC43di0xYy0xNi43'
    b'LTguMS0xNy41LTI1LjItMTcuNS0yNS4yVjM2M2gxdi0zaC44di0xLjhjNS02LS44LTExLjIt'
    b'LjgtMTEuMnYtMi4yaDMuNHYtMS42YzE1LjctNS42IDEzLjctMjMuOSAxMy43LTIzLjlIMjk0'
    b'eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAg'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0i'
    b'TTI4Ni42IDM0Mi45aDE5LjdtLTE5IDEuNWgxOC40bS0xNSAyLjVoMTEuNW0tMTIuMyAxMS41'
    b'SDMwM20tMTIuNCAxLjRoMTEuNm0tMTEuNiAyLjhoMTEuNW0tMTguNSAyMy4yaDI1LjVtLTMy'
    b'LjcgNS45aDQwbS00MS41LjloNDMiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEu'
    b'MDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjY2NjIiBkPSJNMzE2LjQgMjYzLjhh'
    b'MTQgMTQgMCAxIDAgMC0yNy45IDEzLjkgMTMuOSAwIDAgMCAwIDI3LjgiLz4KICAgIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI5Ni42IDMxOC4zYTEzIDEzIDAgMSAw'
    b'IDAtMjYuMSAxMyAxMyAwIDAgMCAwIDI2eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAw'
    b'IDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNjY2MiIGQ9Ik0yODQgMjIz'
    b'aC04LjZ2LTguOGgtNy43djguN0gyNTl2Ny43aDguN3Y4LjVoNy43di04LjVoOC41VjIyMyIv'
    b'PgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMjY2LjMgMjgwaC04'
    b'LjF2LTguMkgyNTF2OC4yaC04LjJ2Ny4yaDguMnY4aDcuMnYtOGg4VjI4MCIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNjY2MiIGQ9Ik0zNzQuMiAyMjNoLTguN3YtOC44SDM1OHY4LjdoLTl2Ny43aDguOHY4LjVo'
    b'Ny42di04LjVoOC43VjIyMyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAw'
    b'IiBkPSJNMzUwLjggMjgwaC04LjF2LTguMmgtNy4ydjguMmgtOC4ydjcuMmg4LjJ2OGg3LjJ2'
    b'LThoOC4xVjI4MCIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03'
    b'NikiLz4KICAgIDxwYXRoIGZpbGw9IiNjY2MiIGQ9Ik0zMjguNSAyMTJoLTguN3YtOC42SDMx'
    b'MnY4LjVoLTguNXY3LjdoOC41djguOGg3Ljd2LTguOGg4LjdWMjEyIi8+CiAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0zMDggMjY5LjdoLTguMnYtOGgtNy4ydjho'
    b'LTh2Ny4yaDh2OC4yaDcuMnYtOC4yaDguMnYtNy4yIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2'
    b'NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2NjYyIgZD0iTTI4'
    b'NCAyNjAuNWgtOC42di04LjhoLTcuN3Y4LjhIMjU5djcuN2g4Ljd2OC41aDcuN3YtOC41aDgu'
    b'NXYtNy43Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0yNjYu'
    b'MyAzMTUuMmgtOC4xVjMwN0gyNTF2OC4yaC04LjJ2Ny4yaDguMnY4aDcuMnYtOGg4di03LjIi'
    b'IHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjY2NjIiBkPSJNMzc0LjIgMjYwLjVoLTguN3YtOC44SDM1OHY4LjhoLTl2'
    b'Ny43aDguOHY4LjVoNy42di04LjVoOC43di03LjciLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iIzAwMCIgZD0iTTM1MC44IDMxNS4yaC04LjFWMzA3aC03LjJ2OC4yaC04LjJ2'
    b'Ny4yaDguMnY4aDcuMnYtOGg4LjF2LTcuMiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAw'
    b'IDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNjY2MiIGQ9Ik0yODQgMjk4'
    b'LjRoLTguNnYtOC42aC03Ljd2OC42SDI1OXY3LjdoOC43djguNmg3Ljd2LTguNWg4LjV2LTcu'
    b'OCIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMjY2LjMgMzUw'
    b'LjdoLTguMXYtOC4xSDI1MXY4LjFoLTguMnY3LjJoOC4ydjguMWg3LjJ2LThoOHYtNy4zIiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2NjYyIgZD0iTTM3NC4yIDI5OC40aC04Ljd2LTguNkgzNTh2OC42aC05djcu'
    b'N2g4Ljh2OC42aDcuNnYtOC41aDguN3YtNy44Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIGQ9Ik0zNTAuOCAzNTAuN2gtOC4xdi04LjFoLTcuMnY4LjFoLTguMnY3'
    b'LjJoOC4ydjguMWg3LjJ2LThoOC4xdi03LjMiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2Njcg'
    b'MCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjMDA1YmJmIiBkPSJNMzE2'
    b'LjMgMTIyLjRhOC40IDguNCAwIDEgMCAwLTE2LjggOC40IDguNCAwIDAgMCAwIDE2LjgiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI5Ni41IDE4NS44YTcu'
    b'OCA3LjggMCAxIDAgMC0xNS43IDcuOCA3LjggMCAwIDAgMCAxNS43eiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNm'
    b'YzAiIGQ9Ik0zMjQgMTEyLjVoLTYuOHYtMTFoMi43di0yLjJoLTIuN3YtMi43aC0yLjF2Mi42'
    b'aC0yLjd2Mi4yaDIuNnYxMS4xaC02LjR2MS41SDMyNHYtMS41Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYmNhYzBiIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik0zMDMuOCAx'
    b'NzYuNmgtNi40di0xMC40aDIuNXYtMmgtMi41di0yLjVoLTJ2Mi40aC0yLjV2Mi4xaDIuNHYx'
    b'MC40aC02djEuNGgxNC41di0xLjQiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEu'
    b'MDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmMwIiBkPSJNMjgyLjkgMTMyLjNz'
    b'Ni4yLS43IDkuNy43YzAgMC00IDQuNy0zLjIgMTAuOGExNSAxNSAwIDAgMCAyIDYuNCAxMSAx'
    b'MSAwIDAgMSAxLjMgN2gxLjJzMS4xLTUtLjgtNy44YTEwLjcgMTAuNyAwIDAgMS0xLTExYzIt'
    b'NCA0LjktNS43IDQuOS01LjdhMTggMTggMCAwIDAgMTIuMS0xLjRjMi0xLjQgMy0zLjQtLjYt'
    b'My41LTMuOC0uMi0xMC0uMS0xNC4yIDMuMSAwIDAtMi4yLTIuNi0xMy40LTEuNC0xMS4yIDEu'
    b'My0xOS4yIDYtMjEuOCAxNi4xLTEuMyA1LjIgMy41IDE2IDcuOSAxOC41IDAgMC0uMS0xLjcu'
    b'My0zIDAgMC03LjUtOC40LTUuMy0xNi4yIDIuMy03LjcgMTEuMy0xMi44IDIwLjktMTIuNiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2JjYWMwYiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'Ii43IiBkPSJNMjY1LjIgMTk1LjFzNS44LS42IDkuMS43YzAgMC0zLjggNC40LTMgMTAuMS40'
    b'IDMgMSA0LjUgMS45IDYgLjggMS4zIDEuNyA0LjMgMS4yIDYuNmgxLjFzMS4xLTQuOC0uNy03'
    b'LjRhMTAgMTAgMCAwIDEtMS0xMC4zYzEuOS0zLjggNC42LTUuMyA0LjYtNS4zIDMgMS4yIDku'
    b'NiAwIDExLjQtMS4zIDEuOS0xLjMgMi44LTMuMi0uNi0zLjMtMy41LS4yLTkuMy0uMS0xMy4z'
    b'IDIuOSAwIDAtMi4xLTIuNC0xMi42LTEuMy0xMC41IDEuMi0xOCA1LjctMjAuNCAxNS4xLTEu'
    b'MiA0LjggMy4zIDE0LjkgNy40IDE3LjMgMCAwLS4xLTEuNi4zLTIuOCAwIDAtNy03LjktNS0x'
    b'NS4yIDIuMi03LjIgMTAuNi0xMiAxOS42LTExLjh6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2'
    b'NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTMw'
    b'My45IDEzMC44YzItLjIgMy41LS41IDMuNC0uOCAwLS4zLTEuNi0uMy0zLjUtLjItMiAuMS0z'
    b'LjQuNi0zLjQuOCAwIC4zIDEuNi4zIDMuNS4yIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0yNzguMyAxOTUuNHMtMiAyIDAg'
    b'MCA2LjQtMy4yIDguOS0yLjdjMi40LjYtLjUuOS0xLjMgMS0uOCAwLTIuNC4zLTQuOCAwIiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZjMCIgZD0iTTM0OS41IDEzM3MtNi0uNy05LjcuN2ExNS42IDE1LjYgMCAw'
    b'IDEgMS4zIDE3Yy0xIDEuNy0xLjkgNC44LTEuNCA3LjJoLTFzLTEuMy01IC43LTcuOWExMC43'
    b'IDEwLjcgMCAwIDAgMS0xMC45IDEzLjQgMTMuNSAwIDAgMC00LjgtNS43Yy0zLjMgMS4zLTEw'
    b'LjQgMC0xMi4zLTEuNC0yLTEuNC0zLTMuMy44LTMuNiAzLjYtLjIgOS45IDAgMTQuMSAzLjIg'
    b'MCAwIDIuMi0yLjYgMTMuNS0xLjMgMTEgMS4xIDE5LjIgNiAyMS42IDE2IDEuMyA1LTMuNCAx'
    b'NS45LTcuOCAxOC40IDAgMCAwLTEuNy0uMy0zIDAgMCA3LjUtOC4zIDUuMy0xNi0yLjMtNy45'
    b'LTExLjItMTIuOS0yMS0xMi43Ii8+CiAgICA8cGF0aCBmaWxsPSIjYmNhYzBiIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0zMjcuNyAxOTUuOHMtNS43LS43LTkuMS42'
    b'YTE0LjYgMTQuNiAwIDAgMSAxLjIgMTZjLS45IDEuNS0xLjggNC40LTEuMyA2LjdoLTFzLTEu'
    b'Mi00LjcuNy03LjRhMTAgMTAgMCAwIDAgLjktMTAuMiAxMi42IDEyLjYgMCAwIDAtNC41LTUu'
    b'NGMtMy4xIDEuMy05LjcgMC0xMS41LTEuMy0xLjgtMS4zLTIuOC0zLjEuNy0zLjMgMy40LS4y'
    b'IDkuMy0uMSAxMy4zIDMgMCAwIDItMi41IDEyLjYtMS4zIDEwLjQgMS4xIDE4IDUuNiAyMC4z'
    b'IDE1IDEuMiA0LjgtMy4yIDE0LjktNy4zIDE3LjMgMCAwIDAtMS42LS4zLTIuOCAwIDAgNy03'
    b'LjggNC45LTE1LjEtMi4xLTcuMy0xMC41LTEyLTE5LjYtMTEuOHoiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZm'
    b'IiBkPSJNMzI4LjUgMTMxLjRjLTEuOSAwLTMuNC0uNC0zLjQtLjcgMC0uMiAxLjYtLjMgMy41'
    b'LS4yIDIgLjIgMy42LjUgMy42LjcgMCAuMy0xLjYuNC0zLjcuMiIvPgogICAgPHBhdGggZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNMzE0LjYgMTk2'
    b'czIuMSAyIDAgMGMtMi0xLjktNi40LTMuMi04LjgtMi42LTIuNS41LjQuOCAxLjIuOS45IDAg'
    b'Mi41LjQgNC45IDAiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAt'
    b'NzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmMwIiBkPSJNMzEwLjUgMTI2djI0Yy0uMiAyLjMg'
    b'Mi45IDUuNyA1LjEgNi42IDAgMCA1LjQtMS43IDUuNy02LjZ2LTI1aC0xLjh2MjEuN2MwIDIu'
    b'MS0xLjUgNi4yLTMuNiA2LjggMCAwLTMuOC0uNi00LTYuOHYtMjEuMWwtMS40LjYiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNiY2FjMGIiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNyIg'
    b'ZD0iTTI5MS4xIDE4OS4zdjIyLjNjLS4yIDIuMiAyLjcgNS4zIDQuOCA2LjIgMCAwIDUtMS42'
    b'IDUuMy02LjJ2LTIzLjVoLTEuN3YyMC40YzAgMi0xLjQgNS44LTMuMyA2LjQgMCAwLTMuNi0u'
    b'Ni0zLjgtNi40di0xOS44bC0xLjMuNiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAg'
    b'MS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0yNTggMTU4Ljdh'
    b'Mi45IDIuOSAwIDEgMCAwLTUuNyAyLjkgMi45IDAgMCAwIDAgNS43Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0yNDEuOCAyMTkuOGEyLjcgMi43IDAgMSAw'
    b'IDAtNS4zIDIuNyAyLjcgMCAwIDAgMCA1LjN6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3'
    b'IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI1Ni4x'
    b'IDE1Mi4xYTIuOSAyLjkgMCAxIDAgMC01LjYgMi45IDIuOSAwIDAgMCAwIDUuNiIvPgogICAg'
    b'PHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMjQwLjEgMjEzLjdhMi43IDIu'
    b'NyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'MS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9'
    b'Ik0yNTcgMTQ0LjJhMi45IDIuOSAwIDEgMCAwLTUuNiAyLjkgMi45IDAgMCAwIDAgNS42Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0yNDEgMjA2LjNhMi43'
    b'IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik0yNjEuNCAxMzcuNmEyLjkgMi45IDAgMSAwIDAtNS42IDIuOSAyLjkgMCAwIDAgMCA1'
    b'LjYiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI0NS4xIDIw'
    b'MC4xYTIuNyAyLjcgMCAxIDAgMC01LjMgMi43IDIuNyAwIDAgMCAwIDUuM3oiIHRyYW5zZm9y'
    b'bT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNMjY2LjcgMTMyLjhhMi45IDIuOSAwIDEgMCAwLTUuNiAyLjkgMi45IDAg'
    b'MCAwIDAgNS42Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0y'
    b'NTAgMTk1LjZhMi43IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNmZmYiIGQ9Ik0yNzMuNSAxMzAuMWEyLjkgMi45IDAgMSAwIDAtNS42IDIuOSAy'
    b'LjkgMCAwIDAgMCA1LjYiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIg'
    b'ZD0iTTI1Ni40IDE5My4xYTIuNyAyLjcgMCAxIDAgMC01LjMgMi43IDIuNyAwIDAgMCAwIDUu'
    b'M3oiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjgwLjUgMTI5YTIuOSAyLjkgMCAxIDAgMC01Ljgg'
    b'Mi45IDIuOSAwIDAgMCAwIDUuNyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIj'
    b'MDAwIiBkPSJNMjYzIDE5MmEyLjcgMi43IDAgMSAwIDAtNS40IDIuNyAyLjcgMCAwIDAgMCA1'
    b'LjN6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI4Ny4zIDEyOC41YTIuOSAyLjkgMCAxIDAgMC01'
    b'LjcgMi45IDIuOSAwIDAgMCAwIDUuNyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDAwIiBkPSJNMjY5LjMgMTkxLjZhMi43IDIuNyAwIDEgMCAwLTUuNCAyLjcgMi43IDAg'
    b'MCAwIDAgNS40eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03'
    b'NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0yOTMuMyAxMjlhMi45IDIuOSAwIDEg'
    b'MCAwLTUuNyAyLjkgMi45IDAgMCAwIDAgNS44Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIGQ9Ik0yNzUgMTkyYTIuNyAyLjcgMCAxIDAgMC01LjMgMi43IDIuNyAw'
    b'IDAgMCAwIDUuNHoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAt'
    b'NzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzEwLjQgMTI2LjhhMi45IDIuOSAw'
    b'IDEgMCAwLTUuNiAyLjkgMi45IDAgMCAwIDAgNS42Ii8+CiAgICA8cGF0aCBmaWxsPSJub25l'
    b'IiBzdHJva2U9IiMwMDAiIGQ9Ik0yOTEgMTkwYTIuNyAyLjcgMCAxIDAgMC01LjMgMi43IDIu'
    b'NyAwIDAgMCAwIDUuM3oiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTgg'
    b'MCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzE2IDEyOC4zYTIuOSAyLjkg'
    b'MCAxIDAgMC01LjYgMi45IDIuOSAwIDAgMCAwIDUuNiIvPgogICAgPHBhdGggZmlsbD0ibm9u'
    b'ZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMjk2LjIgMTkxLjRhMi43IDIuNyAwIDEgMCAwLTUuMyAy'
    b'LjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4w'
    b'Njc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMTYgMTQ5LjVhMi45'
    b'IDIuOSAwIDEgMCAwLTUuOCAyLjkgMi45IDAgMCAwIDAgNS44Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0yOTYuMiAyMTEuMmEyLjcgMi43IDAgMSAwIDAt'
    b'NS40IDIuNyAyLjcgMCAwIDAgMCA1LjR6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAg'
    b'MCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTM3NC43IDE2'
    b'MC41YTIuOSAyLjkgMCAxIDAgMC01LjcgMi45IDIuOSAwIDAgMCAwIDUuNyIvPgogICAgPHBh'
    b'dGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMzUxLjMgMjIxLjVhMi43IDIuNyAw'
    b'IDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4w'
    b'NjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0z'
    b'NzYuMiAxNTMuNWEyLjkgMi45IDAgMSAwIDAtNS43IDIuOSAyLjkgMCAwIDAgMCA1LjYiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTM1Mi43IDIxNWEyLjcg'
    b'Mi43IDAgMSAwIDAtNS40IDIuNyAyLjcgMCAwIDAgMCA1LjN6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZD0iTTM3NSAxNDZhMi45IDIuOSAwIDEgMCAwLTUuNiAyLjkgMi45IDAgMCAwIDAgNS43Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0zNTEuNiAyMDhhMi43'
    b'IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik0zNzIgMTM5LjFhMi45IDIuOSAwIDEgMCAwLTUuNyAyLjkgMi45IDAgMCAwIDAgNS43'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0zNDguNyAyMDEu'
    b'NWEyLjcgMi43IDAgMSAwIDAtNS40IDIuNyAyLjcgMCAwIDAgMCA1LjR6IiB0cmFuc2Zvcm09'
    b'Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZD0iTTM2Ni43IDEzNC4zYTIuOSAyLjkgMCAxIDAgMC01LjggMi45IDIuOSAwIDAg'
    b'MCAwIDUuNyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMzQz'
    b'LjggMTk3YTIuNyAyLjcgMCAxIDAgMC01LjQgMi43IDIuNyAwIDAgMCAwIDUuM3oiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJNMzYwLjQgMTMxLjFhMi45IDIuOSAwIDEgMCAwLTUuNiAyLjkgMi45'
    b'IDAgMCAwIDAgNS42Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9'
    b'Ik0zMzcuOSAxOTRhMi43IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Ik0zNTMuMiAxMjkuNWEyLjkgMi45IDAgMSAwIDAtNS42IDIu'
    b'OSAyLjkgMCAwIDAgMCA1LjYiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgZD0iTTMzMS4xIDE5Mi41YTIuNyAyLjcgMCAxIDAgMC01LjMgMi43IDIuNyAwIDAgMCAw'
    b'IDUuM3oiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzQ2LjcgMTI5YTIuOSAyLjkgMCAxIDAgMC01'
    b'LjcgMi45IDIuOSAwIDAgMCAwIDUuNyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDAwIiBkPSJNMzI1IDE5MmEyLjcgMi43IDAgMSAwIDAtNS4zIDIuNyAyLjcgMCAwIDAg'
    b'MCA1LjN6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTM0MC43IDEyOC4yYTIuOSAyLjkgMCAxIDAg'
    b'MC01LjcgMi45IDIuOSAwIDAgMCAwIDUuNyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjMDAwIiBkPSJNMzE5LjQgMTkxLjNhMi43IDIuNyAwIDEgMCAwLTUuNCAyLjcgMi43'
    b'IDAgMCAwIDAgNS40eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAw'
    b'IC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zNDQuNSAxNTEuNGEyLjkgMi45'
    b'IDAgMSAwIDAtNS43IDIuOSAyLjkgMCAwIDAgMCA1LjgiLz4KICAgIDxwYXRoIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZT0iIzAwMCIgZD0iTTMyMyAyMTNhMi43IDIuNyAwIDEgMCAwLTUuMyAyLjcg'
    b'Mi43IDAgMCAwIDAgNS40eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1'
    b'OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zNDYgMTQ2YTIuOSAyLjkg'
    b'MCAxIDAgMC01LjcgMi45IDIuOSAwIDAgMCAwIDUuNiIvPgogICAgPHBhdGggZmlsbD0ibm9u'
    b'ZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMzI0LjQgMjA4YTIuNyAyLjcgMCAxIDAgMC01LjQgMi43'
    b'IDIuNyAwIDAgMCAwIDUuM3oiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3'
    b'NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzIyLjEgMTI3LjhhMi45'
    b'IDIuOSAwIDEgMCAwLTUuOCAyLjkgMi45IDAgMCAwIDAgNS44Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0zMDIgMTkwLjlhMi43IDIuNyAwIDEgMCAwLTUu'
    b'NCAyLjcgMi43IDAgMCAwIDAgNS40eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAg'
    b'MS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMDguMyAxMjdh'
    b'Mi45IDIuOSAwIDEgMCAwLTUuNyAyLjkgMi45IDAgMCAwIDAgNS42Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0yODkgMTkwLjFhMi43IDIuNyAwIDEgMCAw'
    b'LTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAw'
    b'IDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMDQuOSAx'
    b'MjYuOGEyLjkgMi45IDAgMSAwIDAtNS42IDIuOSAyLjkgMCAwIDAgMCA1LjYiLz4KICAgIDxw'
    b'YXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI4NS44IDE5MGEyLjcgMi43IDAg'
    b'MSAwIDAtNS4zIDIuNyAyLjcgMCAwIDAgMCA1LjN6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2'
    b'NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI4'
    b'Ni43IDE1MS41YTIuOSAyLjkgMCAxIDAgMC01LjcgMi45IDIuOSAwIDAgMCAwIDUuNyIvPgog'
    b'ICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMjY4LjggMjEzLjFhMi43'
    b'IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik0yODUuOSAxNDQuOGEyLjkgMi45IDAgMSAwIDAtNS44IDIuOSAyLjkgMCAwIDAgMCA1'
    b'LjgiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI2OCAyMDYu'
    b'OGEyLjcgMi43IDAgMSAwIDAtNS40IDIuNyAyLjcgMCAwIDAgMCA1LjR6IiB0cmFuc2Zvcm09'
    b'Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZD0iTTI4OCAxMzguMmEyLjkgMi45IDAgMSAwIDAtNS43IDIuOSAyLjkgMCAwIDAg'
    b'MCA1LjciLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTI3MCAy'
    b'MDAuNmEyLjcgMi43IDAgMSAwIDAtNS4zIDIuNyAyLjcgMCAwIDAgMCA1LjN6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTMwMC41IDEyNy41YTIuOSAyLjkgMCAxIDAgMC01LjcgMi45IDIuOSAw'
    b'IDAgMCAwIDUuNyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJN'
    b'MjgxLjcgMTkwLjZhMi43IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Ik0yOTUuNyAxMjkuNGEyLjkgMi45IDAgMSAwIDAtNS43IDIu'
    b'OSAyLjkgMCAwIDAgMCA1LjciLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgZD0iTTI3Ny4yIDE5Mi40YTIuNyAyLjcgMCAxIDAgMC01LjMgMi43IDIuNyAwIDAgMCAw'
    b'IDUuM3oiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjkxLjIgMTMzLjJhMi45IDIuOSAwIDEgMCAw'
    b'LTUuNiAyLjkgMi45IDAgMCAwIDAgNS42Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiMwMDAiIGQ9Ik0yNzMgMTk2YTIuNyAyLjcgMCAxIDAgMC01LjMgMi43IDIuNyAwIDAg'
    b'MCAwIDUuM3oiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYp'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzE2IDEzMS41YTIuOSAyLjkgMCAxIDAg'
    b'MC01LjYgMi45IDIuOSAwIDAgMCAwIDUuNiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjMDAwIiBkPSJNMjk2LjIgMTk0LjRhMi43IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43'
    b'IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAw'
    b'IC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMTYgMTM3YTIuOSAyLjkgMCAx'
    b'IDAgMC01LjggMi45IDIuOSAwIDAgMCAwIDUuOCIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlPSIjMDAwIiBkPSJNMjk2LjIgMTk5LjVhMi43IDIuNyAwIDEgMCAwLTUuNCAyLjcg'
    b'Mi43IDAgMCAwIDAgNS40eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1'
    b'OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMTYgMTQyLjdhMi45IDIu'
    b'OSAwIDEgMCAwLTUuNyAyLjkgMi45IDAgMCAwIDAgNS43Ii8+CiAgICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0yOTYuMiAyMDQuOWEyLjcgMi43IDAgMSAwIDAtNS40'
    b'IDIuNyAyLjcgMCAwIDAgMCA1LjR6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAx'
    b'LjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTMyNS44IDEyN2Ey'
    b'LjkgMi45IDAgMSAwIDAtNS43IDIuOSAyLjkgMCAwIDAgMCA1LjgiLz4KICAgIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTMwNS40IDE5MC4yYTIuNyAyLjcgMCAxIDAg'
    b'MC01LjQgMi43IDIuNyAwIDAgMCAwIDUuNHoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2Njcg'
    b'MCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzI5LjYg'
    b'MTI2LjJhMi45IDIuOSAwIDEgMCAwLTUuNyAyLjkgMi45IDAgMCAwIDAgNS43Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0zMDkgMTg5LjRhMi43IDIuNyAw'
    b'IDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4w'
    b'NjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0z'
    b'MzQgMTI2LjhhMi45IDIuOSAwIDEgMCAwLTUuNiAyLjkgMi45IDAgMCAwIDAgNS43Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0zMTMuMiAxOTBhMi43IDIu'
    b'NyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS40eiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'MS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9'
    b'Ik0zNDUgMTM5YTIuOSAyLjkgMCAxIDAgMC01LjYgMi45IDIuOSAwIDAgMCAwIDUuNiIvPgog'
    b'ICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNMzIzLjUgMjAxLjRhMi43'
    b'IDIuNyAwIDEgMCAwLTUuMyAyLjcgMi43IDAgMCAwIDAgNS4zeiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik0zMzguNSAxMjkuNWEyLjkgMi45IDAgMSAwIDAtNS44IDIuOSAyLjkgMCAwIDAgMCA1'
    b'LjgiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTMxNy4zIDE5'
    b'Mi41YTIuNyAyLjcgMCAxIDAgMC01LjQgMi43IDIuNyAwIDAgMCAwIDUuNHoiIHRyYW5zZm9y'
    b'bT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNMzQyLjUgMTMzLjRhMi45IDIuOSAwIDEgMCAwLTUuNyAyLjkgMi45IDAg'
    b'MCAwIDAgNS43Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik0z'
    b'MjEuMSAxOTYuMWEyLjcgMi43IDAgMSAwIDAtNS4zIDIuNyAyLjcgMCAwIDAgMCA1LjN6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0ibTMxNS43IDE3Ni03LjQgMy44IDYuNyA0LjMgOC00LTcuMy00'
    b'LjIiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIuNSIgZD0ibTI5NiAyMzYtNyAzLjYgNi4zIDQgNy41LTMuOC02LjgtMy44IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0ibTI5OS4zIDE3Ni44LTExLjIgMS43cy0uMiA2LjEuMyA3LjVsMTEuNy0x'
    b'LjVzLjUtNS43LS44LTcuNyIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJtMjgwLjYgMjM2LjgtMTAuNSAxLjZzLS4yIDUuNy4z'
    b'IDdsMTAuOS0xLjRzLjUtNS4zLS43LTcuMnoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2Njcg'
    b'MCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjMDU4ZTZlIiBmaWxsLW9w'
    b'YWNpdHk9Ii45IiBkPSJNMjk4LjEgMTc5cy02LjguNi04LjUgMS4ydjRzNC42LS43IDguNi0x'
    b'VjE3OSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lk'
    b'dGg9Ii41IiBkPSJNMjc5LjUgMjM4LjhzLTYuNC42LTggMS4ydjMuOHM0LjMtLjcgOC4xLTFs'
    b'LS4xLTQiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMzMxLjQgMTc3IDExLjMgMS44cy4xIDYuMS0u'
    b'NCA3LjVsLTExLjUtMS41cy0uNi01LjYuNi03LjciLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0ibTMxMC43IDIzNyAxMC42IDEu'
    b'N3MuMSA1LjctLjQgN2wtMTAuOC0xLjRzLS41LTUuMy42LTcuMnoiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjMDU4'
    b'ZTZlIiBmaWxsLW9wYWNpdHk9Ii45IiBkPSJNMzMyLjggMTc5LjNzNi43LjYgOC40IDEuMnY0'
    b'LjFzLTQuNi0uOC04LjYtMXYtNC4zIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik0zMTIgMjM5LjFzNi4zLjYgNy45IDEuMmwt'
    b'LjEgMy44cy00LjItLjctOC0xbC4xLTQiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAw'
    b'IDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik0yNTQuMiAyNDEuOHMzNy0xMy43IDg0LjIgMS4ybS04'
    b'Mi43IDYuN3MzNS45LTEzLjQgODAgLjZtLTc5LjgtOSA3LjIgMi4xLTUgNS40IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmls'
    b'bD0icmVkIiBkPSJtMjczIDE4OC41IDQuNS0zLjctNS0xcy43LjguNiAxLjV2My4yIi8+CiAg'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjUiIGQ9'
    b'Im0yNTYgMjQ3LjggNC4yLTMuNS00LjctLjlzLjYuNy41IDEuNHYzem04MS42LTUuMS03Ljcg'
    b'MS40IDUuMiA2IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2'
    b'KSIvPgogICAgPHBhdGggZmlsbD0icmVkIiBkPSJtMzU3LjcgMTg4LjgtMy4xLTMuMiA0LjQt'
    b'LjVzLTEuMi44LTEuMiAxLjUuMiAxLjYgMCAyLjIiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0ibTMzNS4zIDI0OC0yLjktMyA0'
    b'LjItLjRzLTEuMi43LTEuMiAxLjRjMCAuNi4yIDEuNSAwIDJ6bS03MC02LjJjLjYgMCAxLjIt'
    b'LjQgMS4yLTEgMC0uNC0uNi0uOS0xLjItLjktLjcgMC0xLjIuNS0xLjIgMXMuNSAxIDEuMiAx'
    b'em0yMC42LTIuM2MuNyAwIDEuMi0uNCAxLjItMSAwLS41LS41LS45LTEuMi0uOXMtMS4yLjQt'
    b'MS4yIDFjMCAuNS41LjkgMS4yLjl6bTAgMy4zYy43IDAgMS4yLS40IDEuMi0uOXMtLjUtMS0x'
    b'LjItMS0xLjIuNS0xLjIgMSAuNSAxIDEuMiAxem0yMC4zLTMuMWMuNiAwIDEuMi0uNSAxLjIt'
    b'MXMtLjYtMS0xLjItMWMtLjcgMC0xLjIuNS0xLjIgMXMuNSAxIDEuMiAxem0yMC4xIDMuN2Mu'
    b'NyAwIDEuMi0uNSAxLjItMXMtLjUtMS0xLjItMS0xLjIuNS0xLjIgMSAuNSAxIDEuMiAxem0t'
    b'LjMgMi42Yy42IDAgMS4yLS40IDEuMi0xIDAtLjQtLjYtLjktMS4yLS45LS43IDAtMS4yLjUt'
    b'MS4yIDFzLjUgMSAxLjIgMXptLTE5LjgtM2MuNiAwIDEuMi0uNCAxLjItMSAwLS41LS42LS45'
    b'LTEuMi0uOS0uNyAwLTEuMi40LTEuMiAxIDAgLjUuNSAxIDEuMiAxem0tNDAgM2MuNyAwIDEu'
    b'My0uNCAxLjMtMSAwLS40LS42LS45LTEuMi0uOS0uNyAwLTEuMi41LTEuMiAxcy41IDEgMS4y'
    b'IDF6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZjMCIgZD0iTTI3MC41IDE3MC42cy4xIDcuNyA1LjEgNi42IDQu'
    b'NS03LjMgNC44LTcuN2MuNS0uMyAxLS4zIDEtLjNzLjYgNi4xIDUuMyA1LjRjNC43LS44IDQu'
    b'NS04LjMgNC05LjVsMS0uNHMxLjggOC44IDcuMiA3LjVjNS4zLTEuMyA0LjgtNi44IDQuOC02'
    b'LjhoLjRzMS4yIDYgNS42IDUuNWM0LjItLjMgNS0xLjcgNC41LTcuN2wzLS41cy0xLjEgOC42'
    b'IDQgOC42YzUuMi0uNCA1LjQtNC40IDUuNy01LjJoLjlzLjIgNi4xIDQuNiA2LjFjNC4yIDAg'
    b'NS01LjEgNS03LjFsNC40LjJzLTQuNSA4IDIgOWM2LjQgMS4xIDYuNi01IDYuNi01aDEuM3Mt'
    b'LjIgOCAzLjMgOC4xYzMuNi4yIDUuNy0xIDYtN2wyIC43cy0xLjYgOS43LTguMyA4Yy0zLjYt'
    b'MS00LjctNS00LjUtNi4xIDAgMC0yLjUgNC40LTcuNCAzLTQuOC0xLjQtNC4yLTQuOS00LjIt'
    b'NiAwIDAtMyA1LjQtNyA0LjItMy42LTEtNS0yLjMtNS00LjkgMCAwLTEuOCA0LjItNS4zIDQt'
    b'My42LS4xLTUuNC0yLjQtNS42LTQuMyAwIDAtLjcgMy45LTUuNSA0LjItMy4yIDAtNS0xLjUt'
    b'NS44LTMuNyAwIDAtMSAzLjktNS41IDQuNS0yLjkuMy01LjgtMS4zLTYuNC00IDAgMC0uOCA1'
    b'LjMtNS40IDYtNC42LjctNS43LTIuNS01LjctMi41cy0xIDQtNC43IDVjLTMuNy45LTYuMi0u'
    b'Ny03LjItNC41LS44LTMuNy0uNS01LjMtLjUtNS4zbDEuNSAyIi8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYmNhYzBiIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0yNTMuNiAy'
    b'MzFzLjEgNy4yIDQuOCA2LjIgNC4yLTYuOSA0LjUtNy4yYy40LS4zLjktLjMuOS0uM3MuNiA1'
    b'LjcgNSA1YzQuNC0uNyA0LjItNy43IDMuNy04LjlsMS0uM3MxLjcgOC4yIDYuNyA3YzUtMS4y'
    b'IDQuNS02LjQgNC41LTYuNGguNHMxLjEgNS42IDUuMiA1LjJjNC0uMyA0LjgtMS42IDQuMy03'
    b'LjJsMi43LS41cy0xIDggMy45IDhjNC44LS4zIDUtNC4xIDUuMy00LjhoLjhzLjIgNS43IDQu'
    b'MyA1LjdjNCAwIDQuOC00LjggNC44LTYuN2w0IC4ycy00LjIgNy41IDEuOSA4LjVjNiAxIDYu'
    b'Mi00LjggNi4yLTQuOGgxLjJzLS4yIDcuNSAzLjEgNy43YzMuNC4xIDUuNC0xIDUuNy02LjZs'
    b'MS45LjdzLTEuNiA5LTcuOSA3LjRjLTMuMy0uOS00LjQtNC43LTQuMi01LjcgMCAwLTIuMyA0'
    b'LjItNi45IDIuOC00LjUtMS4zLTQtNC41LTQtNS41IDAgMC0yLjcgNS02LjUgMy45LTMuNC0x'
    b'LTQuNy0yLjItNC43LTQuNiAwIDAtMS43IDMuOS01IDMuNy0zLjQtLjEtNS0yLjItNS4yLTQg'
    b'MCAwLS43IDMuNi01LjIgMy45LTMgLjEtNC43LTEuNC01LjQtMy40IDAgMC0uOSAzLjYtNS4y'
    b'IDQuMi0yLjcuMy01LjQtMS4yLTYtMy43IDAgMC0uNyA0LjktNSA1LjUtNC40LjctNS40LTIu'
    b'My01LjQtMi4zcy0uOSAzLjgtNC40IDQuN2MtMy41LjgtNS44LS43LTYuNy00LjItLjgtMy41'
    b'LS41LTUtLjUtNWwxLjQgMS44eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4w'
    b'Njc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmYzAiIGQ9Ik0yODAuOSAxNzFhMS44'
    b'IDEuOCAwIDEgMCAwLTMuNiAxLjggMS44IDAgMCAwIDAgMy41Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYmNhYzBiIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0yNjMuMyAy'
    b'MzEuM2ExLjcgMS43IDAgMSAwIDAtMy4zIDEuNyAxLjcgMCAwIDAgMCAzLjN6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZjMCIgZD0iTTMwNC4xIDE2Ny4yYTEuOCAxLjggMCAxIDAgMC0zLjUgMS44IDEuOCAw'
    b'IDAgMCAwIDMuNSIvPgogICAgPHBhdGggZmlsbD0iI2JjYWMwYiIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9Ii43IiBkPSJNMjg1LjEgMjI3LjhhMS43IDEuNyAwIDEgMCAwLTMuMyAx'
    b'LjcgMS43IDAgMCAwIDAgMy4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4w'
    b'Njc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmYzAiIGQ9Ik0zMjcuOCAxNjhhMS44'
    b'IDEuOCAwIDEgMCAwLTMuNiAxLjggMS44IDAgMCAwIDAgMy41Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYmNhYzBiIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0zMDcuMyAy'
    b'MjguNWExLjcgMS43IDAgMSAwIDAtMy4zIDEuNyAxLjcgMCAwIDAgMCAzLjN6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZjMCIgZD0iTTM1MS4xIDE3MS43YTEuOCAxLjggMCAxIDAgMC0zLjUgMS44IDEuOCAw'
    b'IDAgMCAwIDMuNSIvPgogICAgPHBhdGggZmlsbD0iI2JjYWMwYiIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9Ii43IiBkPSJNMzI5LjIgMjMyYTEuNyAxLjcgMCAxIDAgMC0zLjMgMS43'
    b'IDEuNyAwIDAgMCAwIDMuM3oiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3'
    b'NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmMwIiBkPSJNMzE0LjkgMTY1LjNoLTEu'
    b'NmMtLjQgMS42LTMuOSAyLjUtMy45IDIuNS0uNC0xLjIuNi0zIC42LTMtNC0xLjEtNC0yLjQt'
    b'NC0yLjQuNi0xLjQgNC4zLTEuNiA0LjMtMS42LTEtMS4yLS45LTMuMi0uOS0zLjIgMi41LjIg'
    b'NC41IDIuNyA0LjUgMi43cy0yLjQtMS4zLTIuMS01LjZjMCAwIDEuMyAwIDIuMS45IDAgMCAw'
    b'LTQuNyAyLTUuM2guMmMxLjkuNiAxLjkgNS4zIDEuOSA1LjMuOC0xIDIuMS0uOSAyLjEtLjku'
    b'MyA0LjMtMi4xIDUuNi0yLjEgNS42czItMi41IDQuNS0yLjZjMCAwIDAgMi0uOCAzLjIgMCAw'
    b'IDMuNi4xIDQuMyAxLjUgMCAwIDAgMS40LTQgMi4zIDAgMCAuOCAxLjkuNSAzLjIgMCAwLTMu'
    b'Ni0xLTMuOS0yLjZIMzE1Ii8+CiAgICA8cGF0aCBmaWxsPSIjYmNhYzBiIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik0yOTUuMiAyMjZoLTEuNWMtLjQgMS41LTMuNiAy'
    b'LjQtMy42IDIuNC0uNC0xLjIuNS0yLjkuNS0yLjktMy43LTEtMy43LTIuMi0zLjctMi4yLjUt'
    b'MS4zIDQtMS41IDQtMS41LTEtMS4xLS44LTMtLjgtMyAyLjMuMiA0LjIgMi41IDQuMiAyLjVz'
    b'LTIuMy0xLjItMi01LjJjMCAwIDEuMiAwIDIgLjggMCAwIDAtNC40IDEuOC00LjloLjJjMS44'
    b'LjUgMS44IDQuOSAxLjggNC45LjgtLjkgMi0uOCAyLS44LjMgNC0yIDUuMi0yIDUuMnMxLjkt'
    b'Mi4zIDQuMi0yLjRjMCAwIC4xIDEuOC0uNyAzIDAgMCAzLjQuMSA0IDEuNCAwIDAgMCAxLjMt'
    b'My44IDIuMiAwIDAgLjggMS43LjUgMyAwIDAtMy4zLTEtMy42LTIuNWgtMy41eiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIGQ9Ik0zMTUuNyAxNjYuMWEzLjIgMy4yIDAgMSAwIDAtNi40IDMuMiAzLjIg'
    b'MCAwIDAgMCA2LjQiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIuNCIgZD0iTTI5NiAyMjYuOGEzIDMgMCAxIDAgMC02IDMgMyAwIDAgMCAw'
    b'IDZ6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTMxNS43IDE2NC43YTEuOCAxLjggMCAxIDAgMC0z'
    b'LjYgMS44IDEuOCAwIDAgMCAwIDMuNiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNMjk2IDIyNS41YTEuNyAxLjcgMCAxIDAg'
    b'MC0zLjQgMS43IDEuNyAwIDAgMCAwIDMuNHoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2Njcg'
    b'MCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmMwIiBkPSJtMzQwLjQg'
    b'MTY3LjQgMS42LjNjMCAxLjYgMy4yIDMuMyAzLjIgMy4zLjYtMSAwLTMgMC0zIDQuMi0uMiA0'
    b'LjUtMS42IDQuNS0xLjYtLjMtMS40LTMuOC0yLjQtMy44LTIuNCAxLTEgMS40LTIuOSAxLjQt'
    b'Mi45LTIuNC0uNC00LjkgMS41LTQuOSAxLjVzMi43LS42IDMuMi01YzAgMC0xLjItLjItMi4x'
    b'LjQgMCAwIDEtNC41LS45LTUuM2wtLjItLjFjLTIgMC0zIDQuNi0zIDQuNi0uNi0xLjEtMi0x'
    b'LjItMi0xLjItMSA0IDEgNS44IDEgNS44cy0xLjQtMi44LTMuOC0zLjVjMCAwLS41IDIgMCAz'
    b'LjIgMCAwLTMuNS0uNS00LjQuNyAwIDAtLjMgMS40IDMuMyAzLjIgMCAwLTEuMSAxLjYtMSAz'
    b'IDAgMCAzLjUtLjQgNC4yLTEuOGwxLjYuMyAyLjIuNCIvPgogICAgPHBhdGggZmlsbD0iI2Jj'
    b'YWMwYiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJtMzE5LjEgMjI4IDEu'
    b'NS4zYzAgMS41IDMgMy4xIDMgMy4xLjYtMSAuMS0yLjkuMS0yLjkgMy45LS4xIDQuMS0xLjQg'
    b'NC4xLTEuNC0uMi0xLjQtMy41LTIuMy0zLjUtMi4zIDEtLjkgMS4zLTIuNyAxLjMtMi43LTIu'
    b'My0uNC00LjYgMS40LTQuNiAxLjRzMi41LS42IDMtNC42YzAgMC0xLjEtLjMtMiAuMyAwIDAg'
    b'LjktNC4yLS44LTVsLS4yLS4xYy0xLjkgMC0yLjggNC4zLTIuOCA0LjMtLjYtMS0xLjgtMS4x'
    b'LTEuOC0xLjEtMS4xIDMuOC45IDUuNC45IDUuNHMtMS40LTIuNi0zLjYtMy4yYzAgMC0uNSAx'
    b'LjggMCAzIDAgMC0zLjMtLjUtNC4xLjYgMCAwLS4zIDEuMyAzLjEgMyAwIDAtMS4xIDEuNS0x'
    b'IDIuOCAwIDAgMy4zLS4zIDQtMS43bDEuNS4zIDIgLjQiIHRyYW5zZm9ybT0ibWF0cml4KDEu'
    b'MDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJN'
    b'MzM5LjIgMTY4YTMuMyAzLjMgMCAxIDEgMS41LTYuNCAzLjMgMy4zIDAgMCAxLTEuNCA2LjQi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIu'
    b'NCIgZD0iTTMxOCAyMjguNmEzIDMgMCAxIDEgMS40LTYgMyAzIDAgMCAxLTEuMyA2eiIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNmZmYiIGQ9Ik0zMzkuNiAxNjYuN2ExLjggMS44IDAgMSAxIC44LTMuNiAxLjgg'
    b'MS44IDAgMCAxLS44IDMuNiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNMzE4LjQgMjI3LjNhMS43IDEuNyAwIDEgMSAuNy0z'
    b'LjMgMS43IDEuNyAwIDAgMS0uNyAzLjN6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAg'
    b'MCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZjMCIgZD0ibTI5MC41IDE2'
    b'Ny0xLjYuMmMtLjMgMS43LTMuNiAzLjItMy42IDMuMi0uNS0xLjMgMC0zLjIgMC0zLjItNC0u'
    b'NC00LjEtMS44LTQuMS0xLjguNC0xLjQgNC0yLjIgNC0yLjItMS0xLTEuMS0zLTEuMS0zIDIu'
    b'My0uMiA0LjYgMiA0LjYgMnMtMi41LS45LTIuOC01LjFjMCAwIDEuNC0uNCAyLjIuNCAwIDAt'
    b'LjUtNC42IDEuMy01LjRoLjJjMiAuMyAyLjYgNC44IDIuNiA0LjguNy0xIDItMSAyLTEgLjgg'
    b'NC4yLTEuNCA1LjctMS40IDUuN3MxLjctMi42IDQtMy4yYzAgMCAuNSAyLS4zIDMuNCAwIDAg'
    b'My43LS40IDQuNCAxIDAgMCAuMiAxLjMtMy42IDIuOCAwIDAgMSAxLjcgMSAzIDAgMC0zLjYt'
    b'LjYtNC4zLTIuMmwtMS41LjQtMi4yLjIiLz4KICAgIDxwYXRoIGZpbGw9IiNiY2FjMGIiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNyIgZD0ibTI3Mi4zIDIyNy42LTEuNS4yYy0u'
    b'MiAxLjYtMy4zIDMtMy4zIDMtLjUtMS4yIDAtMyAwLTMtMy43LS40LTMuOS0xLjctMy45LTEu'
    b'Ny40LTEuMyAzLjgtMiAzLjgtMi0xLTEtMS4xLTIuOC0xLjEtMi44IDIuMi0uMiA0LjQgMS44'
    b'IDQuNCAxLjhzLTIuNC0uOC0yLjctNC44YzAgMCAxLjMtLjMgMi4xLjQgMCAwLS41LTQuMyAx'
    b'LjItNWguMmMxLjkuMiAyLjQgNC41IDIuNCA0LjUuNy0uOSAyLTEgMi0xIC43IDQtMS40IDUu'
    b'NC0xLjQgNS40czEuNi0yLjUgMy44LTNjMCAwIC40IDEuOS0uMyAzLjEgMCAwIDMuNC0uMyA0'
    b'LjEgMSAwIDAgLjIgMS4yLTMuNCAyLjYgMCAwIDEgMS42LjkgMi44IDAgMC0zLjMtLjUtNC0y'
    b'bC0xLjQuMy0yIC4yIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAg'
    b'LTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI5MS40IDE2Ny44YTMuMiAzLjIg'
    b'MCAxIDAtLjgtNi40IDMuMiAzLjIgMCAwIDAgLjggNi40Ii8+CiAgICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik0yNzMuMiAyMjguNGEz'
    b'IDMgMCAxIDAtLjgtNiAzIDMgMCAwIDAgLjggNnoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2'
    b'NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjkx'
    b'LjIgMTY2LjNhMS44IDEuOCAwIDEgMC0uNC0zLjUgMS44IDEuOCAwIDAgMCAuNCAzLjUiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIg'
    b'ZD0iTTI3MyAyMjdhMS43IDEuNyAwIDEgMC0uNC0zLjMgMS43IDEuNyAwIDAgMCAuNCAzLjN6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZjMCIgZD0iTTM2Mi45IDE3NHMtLjktMi4yLTIuNy0xLjUtMS42IDEu'
    b'MS0zLjIgMS4xYzAgMC0uNi0yIC4yLTIuOSAwIDAtMi41LTEtMy4yLTMuMiAwIDAgMS40LTEu'
    b'NiA0LjctMSAwIDAgMC0xLjUuMy0yLjMgMCAwIDMuNiAxIDMuNiAzLjEgMCAwLTEuMS0zLjgu'
    b'OC02LjYgMCAwIDEuNi42IDEuNSAyLjQgMCAwIC44LTMuNiA1LjYtMi42IDAgMC0yLjYgMi4z'
    b'LTIuNyAzLjQtLjIgMS0yLjQgMi45LTIuNSAzLjVhNCA0IDAgMCAxLS44IDIuM2MtLjcuNi0u'
    b'OCAxLjctLjggMiAwIC4zIDAgMS44LS44IDIuMiIvPgogICAgPHBhdGggZmlsbD0iI2JjYWMw'
    b'YiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNMzQwLjIgMjM0LjFzLS44'
    b'LTItMi41LTEuMy0xLjUgMS0zIDFjMCAwLS42LTEuOS4yLTIuNyAwIDAtMi40LS45LTMtMyAw'
    b'IDAgMS4zLTEuNSA0LjQtLjkgMCAwLS4xLTEuNS4zLTIuMiAwIDAgMy4zIDEgMy4zIDIuOSAw'
    b'IDAtMS0zLjYuOC02LjIgMCAwIDEuNS42IDEuNCAyLjMgMCAwIC43LTMuNCA1LjItMi41IDAg'
    b'MC0yLjQgMi4yLTIuNSAzLjItLjIgMS0yLjIgMi43LTIuMyAzLjMgMCAuNS0uMiAxLjUtLjgg'
    b'Mi4xLS42LjYtLjcgMS42LS43IDIgMCAuMiAwIDEuNi0uOCAyeiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik0zNjAuMiAxNjkuN2EzLjIgMy4yIDAgMCAxIDUuMS0yYzAgLjYtLjMgMS40LS44IDIt'
    b'LjcuNi0uOCAxLjctLjggMmEzLjIgMy4yIDAgMCAxLS40IDEuOGgtLjVhMy4yIDMuMiAwIDAg'
    b'MS0yLjYtMy44Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iLjQiIGQ9Ik0zMzcuNyAyMzAuMWEzIDMgMCAwIDEgNC44LTEuOGMwIC41LS4z'
    b'IDEuMy0uOCAxLjgtLjYuNi0uNyAxLjYtLjcgMmEzIDMgMCAwIDEtLjQgMS42aC0uNWEzIDMg'
    b'MCAwIDEtMi40LTMuNnoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTgg'
    b'MCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzYxLjYgMTcwYTEuOCAxLjgg'
    b'MCAwIDEgMy4yLS44bC0uMy41Yy0uNy42LS44IDEuNy0uOCAydi4zaC0uNmMtMS0uMS0xLjYt'
    b'MS0xLjQtMi4xIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iLjMiIGQ9Ik0zMzkgMjMwLjRhMS43IDEuNyAwIDAgMSAzLS43bC0uMy40Yy0u'
    b'Ni42LS43IDEuNi0uNyAydi4yaC0uNmMtMS0uMS0xLjUtMS0xLjMtMnoiIHRyYW5zZm9ybT0i'
    b'bWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmMwIiBkPSJNMjY5IDE3M3MuOS0yIDIuNy0xLjJjMS43IDEgMS41IDEuMiAzLjIgMS4yIDAg'
    b'MCAuNi0yIDAtMi44IDAgMCAyLjUtLjggMy4yLTMgMCAwLTEuMy0xLjctNC42LTEuMyAwIDAg'
    b'LjItMS42LS4yLTIuMyAwIDAtMy41LjgtMy42IDIuNyAwIDAgMS4yLTMuNy0uNS02LjYgMCAw'
    b'LTEuNy43LTEuNyAyLjQgMCAwLS41LTMuNy01LjMtMyAwIDAgMi40IDIuNSAyLjQgMy42czIu'
    b'MiAzIDIuMiAzLjZjMCAuNi4yIDEuNy44IDIuNC43LjYuNyAxLjcuNiAyLjEgMCAuMiAwIDEu'
    b'Ny44IDIuMiIvPgogICAgPHBhdGggZmlsbD0iI2JjYWMwYiIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9Ii43IiBkPSJNMjUyLjIgMjMzLjNzLjgtMiAyLjUtMS4yYzEuNi45IDEuNCAx'
    b'LjEgMyAxLjEgMCAwIC42LTEuOCAwLTIuNiAwIDAgMi40LS43IDMtMi44IDAgMC0xLjItMS42'
    b'LTQuMy0xLjIgMCAwIC4yLTEuNS0uMi0yLjIgMCAwLTMuMy44LTMuNCAyLjYgMCAwIDEuMi0z'
    b'LjUtLjQtNi4yIDAgMC0xLjYuNi0xLjYgMi4yIDAgMC0uNS0zLjQtNS0yLjcgMCAwIDIuMyAy'
    b'LjMgMi4zIDMuM3MyIDIuOCAyIDMuNGMwIC41LjIgMS42LjggMi4yLjYuNi42IDEuNi41IDIg'
    b'MCAuMiAwIDEuNi44IDJ6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4'
    b'IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI3MS44IDE2OC45YTMuMiAz'
    b'LjIgMCAwIDAtNS0yLjFjMCAuNS4zIDEuNC44IDEuOS43LjYuNyAxLjcuNiAyLjEgMCAuMiAw'
    b'IDEgLjQgMS44aC40YTMuMiAzLjIgMCAwIDAgMi44LTMuNyIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii40IiBkPSJNMjU0LjggMjI5LjRh'
    b'MyAzIDAgMCAwLTQuNi0yYzAgLjUuMiAxLjMuNyAxLjguNi42LjYgMS42LjUgMiAwIC4yIDAg'
    b'MSAuNCAxLjdoLjRhMyAzIDAgMCAwIDIuNi0zLjV6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2'
    b'NjY3IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI3'
    b'MC40IDE2OS4xYTEuOCAxLjggMCAwIDAtMy4yLTFsLjQuNmMuNy42LjcgMS43LjYgMi4xdi4y'
    b'aC43YzEgMCAxLjYtMSAxLjUtMS45Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0yNTMuNSAyMjkuNmExLjcgMS43IDAgMCAw'
    b'LTMtLjlsLjQuNWMuNi42LjYgMS42LjUgMnYuMmguN2MuOSAwIDEuNS0uOSAxLjQtMS44eiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoMS4wNjY2NyAwIDAgMS4wNjc1OCAwIC03NikiLz4KICAgIDxw'
    b'YXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0y'
    b'NTcuMiAyNTEuNnMzMy44LTEzLjIgNzYuNC4zIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3'
    b'IDAgMCAxLjA2NzU4IDAgLTc2KSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNMzM4LjQgMjQxLjFjLTQ3LjEtMTUtODQuNy0u'
    b'OC04NC43LS44IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2NjY3IDAgMCAxLjA2NzU4IDAgLTc2'
    b'KSIvPgogICAgPHBhdGggZmlsbD0icmVkIiBkPSJtMzE1LjcgMTc3LjktNCAyIDMuNiAyLjIg'
    b'NC4zLTItMy45LTIuMiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9Ii41IiBkPSJtMjk2IDIzNy44LTMuOCAxLjkgMy40IDIuMSA0LTItMy42'
    b'LTIiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDY2NjcgMCAwIDEuMDY3NTggMCAtNzYpIi8+CiAg'
    b'PC9nPgo8L3N2Zz4K', 'ES_GA')

ES_GA = b64_ES_GA
index.append("ES_GA")
index.append("Spain Galicia")
catalog["ES_GA"] = ES_GA
catalog["Spain Galicia"] = ES_GA
country["Spain Galicia"] = ('ES_GA', '', 1)
lookup["ES_GA"] = ('ES_GA', '', 'Spain Galicia', 1)
lookup["Santiago de Compostela Spain Galicia"] = ('ES_GA', '', 'Spain Galicia', 1)
lookup["Spain Galicia"] = ('ES_GA', '', 'Spain Galicia', 1)
details["ES_GA"] = {"continent":"Europe","capital":"Santiago de Compostela","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_GA"] = ('ES_GA', 'Spain Galicia', 1)
regional["Spain Galicia"] = ('ES_GA', 'Spain Galicia', 1)
#----------------------------------------------------------------------
b64_ES_IB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NDQo8c3ZnIHhtbG5zPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiIHdpZHRoPSIxMDgwIiBoZWlnaHQ9IjcyMCI+DQ0KPHJlY3QgaGVp'
    b'Z2h0PSI3MjAiIHdpZHRoPSIxMDgwIiBmaWxsPSIjZmNkZDA5Ii8+DQo8ZyBmaWxsPSIjZGEx'
    b'MjFhIj4NDQo8cmVjdCB3aWR0aD0iMTA4MCIgaGVpZ2h0PSI4MCIgeT0iODAiLz4NDQo8cmVj'
    b'dCB3aWR0aD0iMTA4MCIgaGVpZ2h0PSI4MCIgeT0iMjQwIi8+DQ0KPHJlY3Qgd2lkdGg9IjEw'
    b'ODAiIGhlaWdodD0iODAiIHk9IjQwMCIvPg0NCjxyZWN0IHdpZHRoPSIxMDgwIiBoZWlnaHQ9'
    b'IjgwIiB5PSI1NjAiLz4NDQo8L2c+DQo8cmVjdCBoZWlnaHQ9IjM2MCIgd2lkdGg9IjU0MCIg'
    b'ZmlsbD0iIzQwMTA0YyIvPg0NCjxnIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzQwMTA0YyIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjQ0Ij4NDQo8cmVjdCBoZWlnaHQ9IjE3Mi4zMyIgd2lkdGg9IjQwLjIz'
    b'NiIgeT0iODguNDA0IiB4PSIyNDkuODgiLz4NDQo8cGF0aCBkPSJtMjQ3LjI5LDgzLjI3NSw0'
    b'NS40MzcsMC0yLjk2NSw0Ljc5NjUtMzkuNjY4LDAtMi44MDMtNC43OTY1eiIvPg0NCjxwYXRo'
    b'IGQ9Im0yNTMuMzQsNzUuMDM2LTYuNTU2MSwwLDAsOC42NjU3LDQ2LjQ3OCwwLDAtOC42NjU3'
    b'LTYuNTU2MSwwLDAsMy43MDAzLTYuMTI2OCwwLDAtMy43MDAzLTcuNDkyNywwLDAsMy43MDAz'
    b'LTYuMTI2OCwwLDAtMy43MDAzLTcuNDkyNywwLDAsMy43MDAzLTYuMTI2OCwwLDAtMy43MDAz'
    b'eiIvPg0NCjxnIGlkPSJoYWxmIj4NDQo8Zz4NDQo8cmVjdCBoZWlnaHQ9IjEwMyIgd2lkdGg9'
    b'IjQwLjI4NSIgeT0iMTU3Ljc2IiB4PSI0OC4yMTciLz4NDQo8cmVjdCBoZWlnaHQ9IjE0Ny4y'
    b'MiIgd2lkdGg9IjQwLjIzNiIgeT0iMTEzLjUyIiB4PSI4OC42MDgiLz4NDQo8cmVjdCBoZWln'
    b'aHQ9IjEwMyIgd2lkdGg9IjQwLjI4NSIgeT0iMTU3Ljc2IiB4PSIyMDkuNTkiLz4NDQo8cmVj'
    b'dCBoZWlnaHQ9IjEwMyIgd2lkdGg9IjQwLjI4NSIgeT0iMTU3Ljc2IiB4PSIxMjguOTUiLz4N'
    b'DQo8cmVjdCBoZWlnaHQ9IjE0Ny4yMiIgd2lkdGg9IjQwLjIzNiIgeT0iMTEzLjUyIiB4PSIx'
    b'NjkuMjgiLz4NDQo8cGF0aCBkPSJtNDMuNTUyLDE1My40OCw0NS4wMDMsMCwwLDQuMDY0Ni00'
    b'MC42NjQsMC00LjMzOTMtNC4wNjQ2eiIvPg0NCjxwYXRoIGQ9Im00OC42MzMsMTQ0Ljk0LTYu'
    b'NTU2MSwwLDAsOC42NjU3LDQ2LjQ3OCwwLDAtOC42NjU3LTYuNTU2MSwwLDAsMy43MDAzLTYu'
    b'MTI2OCwwLDAtMy43MDAzLTcuNDkyNywwLDAsMy43MDAzLTYuMTI2OCwwLDAtMy43MDAzLTcu'
    b'NDkyNywwLDAsMy43MDAzLTYuMTI2OCwwLDAtMy43MDAzeiIvPg0NCjxwYXRoIGQ9Im04Ni4w'
    b'MTgsMTA4LjY5LDQ1LjQzNywwLTIuOTY1LDQuNzk2NS0zOS42NjgsMC0yLjgwMzEtNC43OTY1'
    b'eiIvPg0NCjxwYXRoIGQ9Im05Mi4wNjQsMTAwLjQ1LTYuNTU2MSwwLDAsOC42NjU4LDQ2LjQ3'
    b'OCwwLDAtOC42NjU4LTYuNTU2MSwwLDAsMy43MDAzLTYuMTI2OCwwLDAtMy43MDAzLTcuNDky'
    b'NywwLDAsMy43MDAzLTYuMTI2OCwwLDAtMy43MDAzLTcuNDkyNywwLDAsMy43MDAzLTYuMTI2'
    b'OCwwLDAtMy43MDAzeiIvPg0NCjxwYXRoIGQ9Im0yMDkuNTQsMTUxLjQ5LDAsNi44OTA1LDQw'
    b'LjM5LDAsMC02Ljg5MDUtNDAuMzksMHoiLz4NDQo8cGF0aCBkPSJtMjE1LjI0LDE0NC45NC01'
    b'LjY5NzQsMCwwLDguNjY1Nyw0MC4zOSwwLDAtOC42NjU3LTUuNjk3NCwwLDAsMy43MDAzLTUu'
    b'MzI0MywwLDAtMy43MDAzLTYuNTExMywwLDAsMy43MDAzLTUuMzI0NCwwLDAtMy43MDAzLTYu'
    b'NTExMywwLDAsMy43MDAzLTUuMzI0MywwLDAtMy43MDAzeiIvPg0NCjxwYXRoIGQ9Im0xMjgu'
    b'OSwxNTEuNDksMCw2Ljg5MDUsNDAuMzksMCwwLTYuODkwNS00MC4zOSwweiIvPg0NCjxwYXRo'
    b'IGQ9Im0xMzQuNTksMTQ0Ljk0LTUuNjk3NCwwLDAsOC42NjU3LDQwLjM5LDAsMC04LjY2NTct'
    b'NS42OTc0LDAsMCwzLjcwMDMtNS4zMjQzLDAsMC0zLjcwMDMtNi41MTEzLDAsMCwzLjcwMDMt'
    b'NS4zMjQ0LDAsMC0zLjcwMDMtNi41MTEzLDAsMCwzLjcwMDMtNS4zMjQzLDAsMC0zLjcwMDN6'
    b'Ii8+DQ0KPHBhdGggZD0ibTE2Ni42OSwxMDguNjksNDUuNDM3LDAtMi45NjUsNC43OTY1LTM5'
    b'LjY2OCwwLTIuODAzLTQuNzk2NXoiLz4NDQo8cGF0aCBkPSJtMTcyLjczLDEwMC40NS02LjU1'
    b'NjEsMCwwLDguNjY1OCw0Ni40NzgsMCwwLTguNjY1OC02LjU1NjEsMCwwLDMuNzAwMy02LjEy'
    b'NjgsMCwwLTMuNzAwMy03LjQ5MjYsMCwwLDMuNzAwMy02LjEyNjgsMCwwLTMuNzAwMy03LjQ5'
    b'MjcsMCwwLDMuNzAwMy02LjEyNjgsMCwwLTMuNzAwM3oiLz4NDQo8L2c+DQ0KPGcgZmlsbD0i'
    b'bm9uZSI+DQ0KPHBhdGggZD0ibTQ4LjM5NCwyMTYuNiwyMjEuNjEsMCwwLDE0LjcyNC0yMjEu'
    b'NjEsMCIvPg0NCjxwYXRoIGQ9Im00OC4zOTQsMjAxLjg4LDIyMS42MS0wLjEzMzQ2LDAtMTQu'
    b'MzYxLTIyMS42MS0wLjIyOTYiLz4NDQo8cGF0aCBkPSJtNjguMzYsMTcyLjg2LDAsMTMuOTk4'
    b'bTAuMDAwMDAxLDE1LjIzMywwLDE0LjMyNW0wLDE1LjA0NCwwLDE0LjQwNyIvPg0NCjxwYXRo'
    b'IGQ9Im00OC4zOTQsMjQ2LjEyLDIyMS42MSwwIi8+DQ0KPHBhdGggZD0ibTEwOC43MywxMTMu'
    b'MzksMCwxMy45OThtMCwxMTkuMTYsMCwxMy45OThtMC00My44NCwwLDEzLjk5OG0wLTg3LjQ3'
    b'NSwwLDU4LjM4NSIvPg0NCjxwYXRoIGQ9Im0yMjkuNzQsMTU4Ljg4LDAsNDMuMDY3bTAsMTUu'
    b'MTk0LDAsMTQuMzI1Ii8+DQ0KPHBhdGggZD0ibTE0OS4wOSwxNTguODgsMCw0My4wNjdtMCwx'
    b'NS4xOTQsMCwxNC4zMjUiLz4NDQo8cGF0aCBkPSJtMTU1LjgyLDE3Mi42MiwwLDEzLjk5OG0t'
    b'MTMuNDYzLTEzLjk5OCwwLDEzLjk5OG05NC4xMDgtMTMuOTk4LDAsMTMuOTk4bS0xMy40NjMt'
    b'MTMuOTk4LDAsMTMuOTk4Ii8+DQ0KPHBhdGggZD0ibTE2OS40MywxNTcuNTksMzkuOTMyLDBt'
    b'LTEyMC42LDAsMzkuOTMyLDAiLz4NDQo8cGF0aCBkPSJtMTg5LjM5LDExMy4zOSwwLDEzLjk5'
    b'OG0wLDExOS4xNiwwLDEzLjk5OG0wLTQzLjg0LDAsMTMuOTk4bTAtODcuNDc1LDAsNTguMzg1'
    b'Ii8+DQ0KPHBhdGggZD0ibTE2OS40MywxNDIuNjIsMzkuOTMyLDBtLTEyMC42LDAsMzkuOTMy'
    b'LDAiLz4NDQo8cGF0aCBkPSJtMTY5LjQzLDEyNy43NCwzOS45MzIsMG0tMTIwLjYsMCwzOS45'
    b'MzIsMCIvPg0NCjxwYXRoIGQ9Im0yNTAuMDMsMTU3LjU5LDE5Ljk2Ni0wLjAxMDUsMCwxNC44'
    b'NjctMjIxLjYxLTAuMDEwNiIvPg0NCjxwYXRoIGQ9Im0yNTAuMDMsMTI3Ljc0LDE5Ljk2Ni0w'
    b'LjA3NDksMCwxNS4xMDYtMTkuOTY2LTAuMTUxNTciLz4NDQo8cGF0aCBkPSJtMjUwLjAzLDk1'
    b'LjUzMSwxOS45NjYsMC4zMjE2MSwwLDE1LjUwMy0xOS45NjYtMC4xNTE1NiIvPg0NCjwvZz4N'
    b'DQo8ZyBzdHJva2UtbGluZWpvaW49InJvdW5kIj4NDQo8cGF0aCBkPSJtMTAzLjIzLDE2NS40'
    b'My00LjkwODEtMi4wNzNjMS43MzI1LTUuMTY2NSw0LjUyNDItOS42MjM4LDEwLjQwNS0xMS41'
    b'MDV2Ni40MjYyIi8+DQ0KPHBhdGggZD0ibTEwMy44MiwxNjEuMzktMy40MzU3LTIuMzgzOSIv'
    b'Pg0NCjxwYXRoIGQ9Im0xMDYuMDgsMTU4LjE3LTIuMDYxNC0zLjMxNjciLz4NDQo8cGF0aCBk'
    b'PSJtMTE0LjIyLDE2NS40Myw0LjkwODEtMi4wNzNjLTEuNzMyNS01LjE2NjUtNC41MjQyLTku'
    b'NjIzOC0xMC40MDUtMTEuNTA1djYuNDI2MiIvPg0NCjxwYXRoIGQ9Im0xMTMuNjMsMTYxLjM5'
    b'LDMuNDM1Ny0yLjM4MzkiLz4NDQo8cGF0aCBkPSJtMTExLjM4LDE1OC4xNywyLjA2MTQtMy4z'
    b'MTY3Ii8+DQ0KPHBhdGggZD0ibTIyMi44LDIzOC45My02LjE5NjMtMi42MTdjMi4xODcyLTYu'
    b'NTIyNSw1LjcxMTYtMTIuMTUsMTMuMTM2LTE0LjUyNXY4LjExMjkiLz4NDQo8cGF0aCBkPSJt'
    b'MjIzLjU0LDIzMy44My00LjMzNzQtMy4wMDk2Ii8+DQ0KPHBhdGggZD0ibTIyNi4zOSwyMjku'
    b'NzctMi42MDI0LTQuMTg3MyIvPg0NCjxwYXRoIGQ9Im0yMzYuNjgsMjM4LjkzLDYuMTk2My0y'
    b'LjYxN2MtMi4xODcyLTYuNTIyNS01LjcxMTYtMTIuMTUtMTMuMTM2LTE0LjUyNXY4LjExMjki'
    b'Lz4NDQo8cGF0aCBkPSJtMjM1LjkzLDIzMy44Myw0LjMzNzQtMy4wMDk2Ii8+DQ0KPHBhdGgg'
    b'ZD0ibTIzMy4wOCwyMjkuNzcsMi42MDI0LTQuMTg3MyIvPg0NCjxwYXRoIGQ9Im0xNDIuMTUs'
    b'MjM4LjkzLTYuMTk2My0yLjYxN2MyLjE4NzItNi41MjI1LDUuNzExNi0xMi4xNSwxMy4xMzYt'
    b'MTQuNTI1djguMTEyOSIvPg0NCjxwYXRoIGQ9Im0xNDIuOSwyMzMuODMtNC4zMzc0LTMuMDA5'
    b'NiIvPg0NCjxwYXRoIGQ9Im0xNDUuNzUsMjI5Ljc3LTIuNjAyNC00LjE4NzMiLz4NDQo8cGF0'
    b'aCBkPSJtMTU2LjAzLDIzOC45Myw2LjE5NjMtMi42MTdjLTIuMTg3Mi02LjUyMjUtNS43MTE2'
    b'LTEyLjE1LTEzLjEzNi0xNC41MjV2OC4xMTI5Ii8+DQ0KPHBhdGggZD0ibTE1NS4yOSwyMzMu'
    b'ODMsNC4zMzc0LTMuMDA5NiIvPg0NCjxwYXRoIGQ9Im0xNTIuNDQsMjI5Ljc3LDIuNjAyNC00'
    b'LjE4NzMiLz4NDQo8cGF0aCBkPSJtMTgzLjksMTY1LjQzLTQuOTA4MS0yLjA3M2MxLjczMjUt'
    b'NS4xNjY1LDQuNTI0Mi05LjYyMzgsMTAuNDA1LTExLjUwNXY2LjQyNjIiLz4NDQo8cGF0aCBk'
    b'PSJtMTg0LjQ5LDE2MS4zOS0zLjQzNTctMi4zODM5Ii8+DQ0KPHBhdGggZD0ibTE4Ni43NCwx'
    b'NTguMTctMi4wNjE0LTMuMzE2NyIvPg0NCjxwYXRoIGQ9Im0xOTQuODksMTY1LjQzLDQuOTA4'
    b'MS0yLjA3M2MtMS43MzI1LTUuMTY2NS00LjUyNDItOS42MjM4LTEwLjQwNS0xMS41MDV2Ni40'
    b'MjYyIi8+DQ0KPHBhdGggZD0ibTE5NC4zLDE2MS4zOSwzLjQzNTctMi4zODM5Ii8+DQ0KPHBh'
    b'dGggZD0ibTE5Mi4wNCwxNTguMTcsMi4wNjE0LTMuMzE2NyIvPg0NCjxwYXRoIGQ9Im0yNTYu'
    b'MDQsMTM0LjA0LTQuMDA1NS0yLjAzNThjMS40MTM5LTUuMDczOCwzLjY5MjItOS40NTEyLDgu'
    b'NDkxNy0xMS4yOTl2Ni4zMTA5Ii8+DQ0KPHBhdGggZD0ibTI1Ni41MiwxMzAuMDctMi44MDM5'
    b'LTIuMzQxMiIvPg0NCjxwYXRoIGQ9Im0yNTguMzcsMTI2LjkxLTEuNjgyMy0zLjI1NzMiLz4N'
    b'DQo8cGF0aCBkPSJtMjY1LjAyLDEzNC4wNCw0LjAwNTUtMi4wMzU4Yy0xLjQxMzktNS4wNzM4'
    b'LTMuNjkyMi05LjQ1MTItOC40OTE3LTExLjI5OXY2LjMxMDkiLz4NDQo8cGF0aCBkPSJtMjY0'
    b'LjUzLDEzMC4wNywyLjgwMzktMi4zNDEyIi8+DQ0KPHBhdGggZD0ibTI2Mi42OSwxMjYuOTEs'
    b'MS42ODIzLTMuMjU3MyIvPg0NCjxwYXRoIGQ9Im0yNjIuMDksMjIwLjI3LTcuMDYyNS0zLjIw'
    b'MTljMi40OTMtNy45ODAxLDYuNTEwMS0xNC44NjUsMTQuOTcyLTE3Ljc3MXY5LjkyNTkiLz4N'
    b'DQo8cGF0aCBkPSJNMjYyLjk0LDIxNC4wMiwyNTcuOTksMjEwLjM0Ii8+DQ0KPHBhdGggZD0i'
    b'bTI2Ni4xOSwyMDkuMDYtMi45NjYyLTUuMTIzIi8+DQ0KPC9nPg0NCjxnIGZpbGw9IiM0MDEw'
    b'NGMiPg0NCjxwYXRoIGQ9Im0xMDguNjksMTU3LjAzYy0zLjMwMTEsMC4zMjM2Mi01LjI0MzEs'
    b'My4yNjIxLTYuMTg3OCw4LjA3NTR2MjAuNjQ2aDEyLjM3NnYtMjAuNjQ2Yy0wLjk0NDc1LTQu'
    b'ODEzMy0yLjg4NjctNy43NTE4LTYuMTg3OC04LjA3NTR6Ii8+DQ0KPHBhdGggZD0ibTIyOS42'
    b'OSwyMjguMzRjLTQuMTY3NSwwLjQwODU0LTYuNjE5Miw0LjExODMtNy44MTIsMTAuMTk1djIy'
    b'LjI4aDE1LjYyNHYtMjIuMjhjLTEuMTkyNy02LjA3NjctMy42NDQ0LTkuNzg2NS03LjgxMi0x'
    b'MC4xOTV6Ii8+DQ0KPHBhdGggZD0ibTE0OS4wNCwyMjguMzRjLTQuMTY3NSwwLjQwODU0LTYu'
    b'NjE5Miw0LjExODMtNy44MTIsMTAuMTk1djIyLjI4aDE1LjYyNHYtMjIuMjhjLTEuMTkyNy02'
    b'LjA3NjctMy42NDQ0LTkuNzg2NS03LjgxMi0xMC4xOTV6Ii8+DQ0KPHBhdGggZD0ibTE4OS4z'
    b'NSwxNTcuMDNjLTMuMzAxMSwwLjMyMzYyLTUuMjQzMSwzLjI2MjEtNi4xODc4LDguMDc1NHYy'
    b'MC42NDZoMTIuMzc2di0yMC42NDZjLTAuOTQ0NzUtNC44MTMzLTIuODg2Ny03Ljc1MTgtNi4x'
    b'ODc4LTguMDc1NHoiLz4NDQo8cGF0aCBkPSJtMjYwLjUsMTI1Ljc5Yy0yLjY5NCwwLjMxNzgt'
    b'NC4yNzg5LDMuMjAzNi01LjA0OTksNy45MzA2djExLjQ3aDEwLjF2LTExLjQ3Yy0wLjc3MTAx'
    b'LTQuNzI3LTIuMzU1OS03LjYxMjgtNS4wNDk5LTcuOTMwNnoiLz4NDQo8cGF0aCBkPSJtMjY5'
    b'Ljk0LDIwNy4zYy00Ljc1MDEsMC40OTk4NS03LjU0NDYsNS4wMzg2LTguOTA0LDEyLjQ3M3Y0'
    b'MS4wMTNoMTcuODA4eiIvPg0NCjwvZz4NDQo8L2c+DQo8dXNlIHhsaW5rOmhyZWY9IiNoYWxm'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCgtMSwwLDAsMSw1NDAsMCkiLz4NCjwvZz4NDQo8L3N2Zz4=', 'ES_IB')

ES_IB = b64_ES_IB
index.append("ES_IB")
index.append("Spain Islas Baleares")
catalog["ES_IB"] = ES_IB
catalog["Spain Islas Baleares"] = ES_IB
country["Spain Islas Baleares"] = ('ES_IB', '', 1)
lookup["ES_IB"] = ('ES_IB', '', 'Spain Islas Baleares', 1)
lookup["Palma Spain Islas Baleares"] = ('ES_IB', '', 'Spain Islas Baleares', 1)
lookup["Spain Islas Baleares"] = ('ES_IB', '', 'Spain Islas Baleares', 1)
details["ES_IB"] = {"continent":"Europe","capital":"Palma","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_IB"] = ('ES_IB', 'Spain Islas Baleares', 1)
regional["Spain Islas Baleares"] = ('ES_IB', 'Spain Islas Baleares', 1)
#----------------------------------------------------------------------
b64_ES_MC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NDQo8c3ZnIHhtbG5zPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiIHdpZHRoPSI3NTAiIGhlaWdodD0iNTAwIj4NCjxyZWN0IHdpZHRo'
    b'PSI3NTAiIGhlaWdodD0iNTAwIiBmaWxsPSIjOWMxZjJkIi8+DQo8ZyBpZD0iY2FzdGxlIiBm'
    b'aWxsPSIjZmNiNzE0IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMC42OTA0Ij4NCjxw'
    b'YXRoIGQ9Ik0zNy4zOTEsMTEzLjM1LDUyLjYsNjIuNjE2aDMxLjE3OGwxNS4yMDksNTAuNzMz'
    b'aC0yMC4zMTV2LTIxLjgzN2wtMC4xMDktMS4wODctMC4xMDktMS4wODYtMC4yMTgtMC45Nzgt'
    b'MC40MzUtMC45NzgtMC40MzUtMC44NjktMC41NDMtMC44NjktMC41NDMtMC43Ni0wLjY1Mi0w'
    b'Ljc2MS0wLjc2MS0wLjc2MS0wLjg2OS0wLjU0My0wLjg2OS0wLjU0My0wLjg2OS0wLjQzNS0w'
    b'Ljk3OC0wLjQzNC0wLjk3OC0wLjIxOC0xLjA4Ny0wLjEwOS0wLjk3OC0wLjEwOWgtMC42NTJs'
    b'LTAuNDM1LDAuMTA5aC0wLjU0NGwtMC41NDMsMC4xMDktMC45NzgsMC4yMTgtMC45NzgsMC40'
    b'MzQtMC44NjksMC40MzUtMC44NjksMC41NDMtMC44NjksMC41NDMtMC42NTIsMC43NjEtMC43'
    b'NjEsMC43NjEtMC41NDMsMC43Ni0wLjU0MywwLjg2OS0wLjQzNSwwLjg2OS0wLjQzNSwwLjk3'
    b'OC0wLjIxOCwwLjk3OC0wLjEwOSwwLjU0M3YwLjU0M2wtMC4xMDksMC41NDR2MjIuMzc5aC0y'
    b'MC4zMDYiLz4NCjxwYXRoIGQ9Im01NS4yMDcsNDIuNTE4djkuNjY4aDQuMDE5di0xOC4yNWgt'
    b'MTAuMzJ2OC41ODJoNi4zMDEiLz4NCjxwYXRoIGQ9Im02My44OTgsNTIuMTg3di05LjY2OGg4'
    b'LjU4MnY5LjY2OGgwLjg2OXYtMjQuNDQzaC0xMC4zMnYyNC40NDNoMC44NjkiLz4NCjxwYXRo'
    b'IGQ9Im04MS4yNzksNTIuMTg3di05LjY2OGg2LjE5MnYtOC41ODJoLTEwLjMydjE4LjI1MWg0'
    b'LjEyOCIvPg0KPHBhdGggZD0ibTU1LjIwNyw0Mi41MTh2OS42NjhoOC42OTF2LTkuNjY4aDgu'
    b'NTgydjkuNjY4aDguNzk5di05LjY2OGg4LjU4MnYxNi43M2gtNDMuMjM2di0xNi43M2g4LjU4'
    b'MiIvPg0KPHBhdGggZD0iTTQ2LjQwOCwzMi45NzVoMTUuMzE3di01Ljc1OGgtMTUuMzE3djUu'
    b'NzU4eiIgc3Ryb2tlLXdpZHRoPSIwLjc1Ii8+DQo8cGF0aCBkPSJNNjAuNTMsMjYuNzgzaDE1'
    b'LjMxN3YtNS45NzVoLTE1LjMxN3Y1Ljk3NXoiIHN0cm9rZS13aWR0aD0iMC43NSIvPg0KPHBh'
    b'dGggZD0iTTc0LjY1MywzMi45NzVoMTUuNDI2di01Ljc1OGgtMTUuNDI2djUuNzU4eiIgc3Ry'
    b'b2tlLXdpZHRoPSIwLjc1Ii8+DQo8L2c+DQo8dXNlIHhsaW5rOmhyZWY9IiNjYXN0bGUiIHg9'
    b'IjcyLjU5NyIvPg0KPHVzZSB4bGluazpocmVmPSIjY2FzdGxlIiB5PSIxMDYuMjEzNDQiLz4N'
    b'Cjx1c2UgeGxpbms6aHJlZj0iI2Nhc3RsZSIgeD0iNzIuNTk3IiB5PSIxMDYuMjEzNDQiLz4N'
    b'CjxwYXRoIGlkPSJjcm93biIgZmlsbD0iI2ZjYjcxNCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'd2lkdGg9IjAuNjk4MyIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0ibTYwOS4zMywzNjku'
    b'MjljLTAuMDEyLTEuNzgzMi0wLjY3MTg0LTMuNDc5My0xLjMxMDMtNS4xMjg0LTEuMTQ0My0y'
    b'LjUxMjctMi42MjA0LTQuODcyMS00LjI1NjUtNy4wOTI5LDEuNTgyLDAuNTU5MjksMy4yMzc3'
    b'LDAuOTYzMjUsNC43OTk2LDEuNTg5NSwxLjMzOTYsMC43MTUzNSwyLjc2MDMsMS4zMTIzLDMu'
    b'OTEyMywyLjMyNzYsMC42MjM5OSwwLjQ5NjM0LDEuMjYwNSwxLjExMDIsMS41NDU4LDEuODY2'
    b'NSwwLjA3MDgsMC43NzgxNCwwLjAyNTksMS42Nzg5LTAuNzY0MDEsMi4wNzU0LTAuNDg5OTQs'
    b'MC41NDkxLTEuMTgxNSwwLjc4NjI2LTEuODU2NiwwLjk4MTczLDAuMDg4NSwwLjg5NzM0LDAu'
    b'NTA3MzMsMS43Mzk4LDAuOTc4MTQsMi40NzA2LDAuODc0NDcsMC43NTQ0LDEuOTk5NSwxLjA0'
    b'ODYsMy4xMzczLDAuOTEzMSwxLjYyODUtMC4yMDAyOSwzLjA4NzgtMS4yMDk2LDMuOTMyNy0y'
    b'LjYwNzYsMC41MDYzNy0wLjc2MjcyLDAuNzAxNDQtMS4yOTQ2LDEuMDcxMy0wLjExNzA5LDAu'
    b'NDkyODcsMC43MTIyOSwxLjA5NSwxLjQwMjYsMS43Njg0LDEuOTY0MiwxLjE0MjYsMC44Mjcy'
    b'NywyLjU5MiwxLjA2MjYsMy45NzQyLDAuOTc4MTksMC44MzA0NS0wLjAxNDcsMS43NzA3LTAu'
    b'MjM2ODksMi40NDM1LTAuNjU4MSwwLjc4NzQ2LTAuNzM0MjIsMC43MDY0NS0yLjAxNzMsMC4z'
    b'ODE3OS0yLjk2MTQtMC40MDc1Ni0wLjU0NTE4LTEuMjkyMi0wLjc4NjI1LTEuOTgwNi0wLjUz'
    b'MjE4LTAuNjQwMS0wLjEzNzY0LTEuODQ3MywwLjc5MDA5LTEuMTY1LTAuMzQwMDIsMC4xMDg0'
    b'NS0wLjgyNzUzLDAuNzE4MTctMS41NDgyLDEuMjgzMi0yLjEyOTcsMC40NTcyMy0wLjQzMDMy'
    b'LDEuMjA5OC0wLjY2ODI5LDEuNjQzNi0wLjgwNDAzLDAuNjc1ODItMS4yMTA0LDEuMjg1Mi0y'
    b'LjY5NzksMi42MjA2LTMuMjc0OCwxLjA1NDQtMC4wNTQsMS43NjU3LDAuOTkyNjQsMi4zNDg1'
    b'LDEuNzQ4OCwwLjQxNjE5LDAuNTA5NTIsMC41MzczMiwxLjYyMTYsMS4xOTA0LDEuNjM1OSww'
    b'Ljk1NDc3LDAuMzA3MDMsMS44NDQ1LDEuMDEyLDIuMjM3NCwxLjk0NjMsMC4xOTM1NCwwLjQw'
    b'NzI1LDEuMTE3LDEuODY4NywwLjE5NjE0LDEuMzg5LTAuNzM0NjgtMC4xMzg5Ni0xLjUyODUt'
    b'MC4zODk1NS0yLjI1ODItMC4xNzEzMy0wLjc5MTU5LDAuMjA5OTItMS4wMzQzLDAuOTMxMjQt'
    b'MC45ODM3NSwxLjY4MzMtMC4xMjAxNywwLjk3MTc3LDAuMzk1NDgsMi4wMDA4LDEuNDI5LDIu'
    b'MTc5LDEuMTE4MiwwLjM2ODM5LDIuMzcyLDAuMzk3MTksMy41MDk5LDAuMTcxNTUsMS4wNzgx'
    b'LTAuMTc4MSwyLjA3MzMtMC42NTEwNSwyLjc5LTEuNDk4OCwwLjY4NjIzLTAuNjAxMzIsMS4x'
    b'NTA0LTEuNDMxLDEuNTUwMi0yLjIwMzQsMC42MjUwNCwxLjEyMjIsMS4zNzksMi4zNTM2LDIu'
    b'NTkxLDIuOTUyNSwxLjM2NzYsMC43OTg1OSwzLjIzMzEsMC45NzQyMyw0LjYxMjgsMC4xMDQ1'
    b'NSwwLjkxNDQ0LTAuNjI4ODYsMS4yNzI2LTEuNzc1NywxLjQyMDItMi44Mzg0LTAuNzUwMDMt'
    b'MC4xNzU5My0xLjM3MzgtMC41NjA4MS0xLjk1OTctMS4wNTA2LTEuMTc3Mi0wLjc2NTktMC42'
    b'MTg1Ny0yLjQ1OTksMC4yMzMxOS0zLjI3NDEsMC45OTI2My0wLjk4MTQ5LDIuMjAyNi0xLjc5'
    b'MjcsMy40OTI5LTIuMzU0NiwxLjEzNzItMC41MTQ4OSwyLjIzMzgtMS4xMzYzLDMuNDgzMi0x'
    b'LjM2OTUsMC44MTYxMS0wLjMxOTYsMS42NTYxLTAuNTU2NiwyLjQ5ODQtMC43OTE4Ny0xLjA3'
    b'MjgsMS4zMjU0LTEuOTIyMSwyLjg0NjItMi44OTc2LDQuMjU0LTAuOTcxNTYsMS44ODA2LTIu'
    b'MDYzNiwzLjc0ODItMi40MjA0LDUuODY4Mi0wLjQ4MjA2LDEuODk1OS0wLjE1MTk2LDMuODgt'
    b'MC4yNDg5MSw1LjgxODR2OC4xNzQzaC00NC45NTR2LTExLjg5NCIvPg0KPHVzZSB4bGluazpo'
    b'cmVmPSIjY3Jvd24iIHg9Ii02MS44NjkiIHk9IjMxLjUzMiIvPg0KPHVzZSB4bGluazpocmVm'
    b'PSIjY3Jvd24iIHk9IjMxLjUzMiIvPg0KPHVzZSB4bGluazpocmVmPSIjY3Jvd24iIHg9IjYx'
    b'Ljg2NSIgeT0iMzEuNTMyIi8+DQo8dXNlIHhsaW5rOmhyZWY9IiNjcm93biIgeD0iLTMzLjk1'
    b'MiIgeT0iNjMuMzk0Ii8+DQo8dXNlIHhsaW5rOmhyZWY9IiNjcm93biIgeD0iMzMuOTM0IiB5'
    b'PSI2My4zOTQiLz4NCjx1c2UgeGxpbms6aHJlZj0iI2Nyb3duIiB5PSI5NC45MjciLz4NCjwv'
    b'c3ZnPg0NCg==', 'ES_MC')

ES_MC = b64_ES_MC
index.append("ES_MC")
index.append("Spain Murcia")
catalog["ES_MC"] = ES_MC
catalog["Spain Murcia"] = ES_MC
country["Spain Murcia"] = ('ES_MC', '', 1)
lookup["ES_MC"] = ('ES_MC', '', 'Spain Murcia', 1)
lookup["Murcia Spain Murcia"] = ('ES_MC', '', 'Spain Murcia', 1)
lookup["Spain Murcia"] = ('ES_MC', '', 'Spain Murcia', 1)
details["ES_MC"] = {"continent":"Europe","capital":"Murcia","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_MC"] = ('ES_MC', 'Spain Murcia', 1)
regional["Spain Murcia"] = ('ES_MC', 'Spain Murcia', 1)
#----------------------------------------------------------------------
b64_ES_MD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iMTEwMCIgaGVpZ2h0PSI3MDAi'
    b'IHZpZXdCb3g9IjAgMCA4OCA1NiIgZmlsbD0iI2ZmZiI+DQo8cGF0aCBkPSJNMCAwSDg4VjU2'
    b'SDB6IiBmaWxsPSIjYzYwYjFlIi8+DQo8ZyBpZD0icyIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUo'
    b'MjAgMjMpIiBmaWxsPSIjZmZmIj4NCjxnIGlkPSJjIj4NCjxwYXRoIGlkPSJ0IiBkPSJNMC03'
    b'VjBIMy41eiIgdHJhbnNmb3JtPSJyb3RhdGUoMTggMC03KSIvPg0KPHVzZSB4bGluazpocmVm'
    b'PSIjdCIgdHJhbnNmb3JtPSJzY2FsZSgtMSAxKSIvPg0KPC9nPg0KPGcgaWQ9ImQiPg0KPHVz'
    b'ZSB4bGluazpocmVmPSIjYyIgdHJhbnNmb3JtPSJyb3RhdGUoNzIpIi8+DQo8dXNlIHhsaW5r'
    b'OmhyZWY9IiNjIiB0cmFuc2Zvcm09InJvdGF0ZSgyMTYpIi8+DQo8L2c+DQo8dXNlIHhsaW5r'
    b'OmhyZWY9IiNkIiB0cmFuc2Zvcm09InJvdGF0ZSg3MikiLz4NCjwvZz4NCjxnIGlkPSJzMyI+'
    b'DQo8dXNlIHg9IjE2IiB4bGluazpocmVmPSIjcyIvPg0KPHVzZSB4PSIzMiIgeGxpbms6aHJl'
    b'Zj0iI3MiLz4NCjx1c2UgeD0iNDgiIHhsaW5rOmhyZWY9IiNzIi8+DQo8L2c+DQo8dXNlIHg9'
    b'Ii04IiB5PSIxMS4zMzY4ODEiIHhsaW5rOmhyZWY9IiNzMyIvPg0KPC9zdmc+', 'ES_MD')

ES_MD = b64_ES_MD
index.append("ES_MD")
index.append("Spain Madrid")
catalog["ES_MD"] = ES_MD
catalog["Spain Madrid"] = ES_MD
country["Spain Madrid"] = ('ES_MD', '', 1)
lookup["ES_MD"] = ('ES_MD', '', 'Spain Madrid', 1)
lookup["Madrid Spain Madrid"] = ('ES_MD', '', 'Spain Madrid', 1)
lookup["Spain Madrid"] = ('ES_MD', '', 'Spain Madrid', 1)
details["ES_MD"] = {"continent":"Europe","capital":"Madrid","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_MD"] = ('ES_MD', 'Spain Madrid', 1)
regional["Spain Madrid"] = ('ES_MD', 'Spain Madrid', 1)
#----------------------------------------------------------------------
b64_ES_ML = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmczMiIgd2lkdGg9IjMyMCIgaGVpZ2h0'
    b'PSIyMTMiIHZpZXdCb3g9IjAgMCAzMjAgMjEzIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X01lbGlsbGEuc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUu'
    b'b3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBv'
    b'ZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxpbms9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8y'
    b'MDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRl'
    b'ZnMgaWQ9ImRlZnMzNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJuYW1lZHZpZXcz'
    b'NCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIgYm9yZGVyb3Bh'
    b'Y2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpwYWdlb3BhY2l0'
    b'eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnIGlua3NjYXBl'
    b'Omdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9ImczOCI+CiAg'
    b'ICA8aW1hZ2Ugd2lkdGg9IjMyMCIgaGVpZ2h0PSIyMTMiIHByZXNlcnZlQXNwZWN0UmF0aW89'
    b'Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IiB4bGluazpo'
    b'cmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQVVB'
    b'QUFBRFZDQUlBQUFDcExyNjVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2'
    b'SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIw'
    b'UUEvd0QvQVArZ3ZhZVRBQUJQCnlrbEVRVlI0MnUyZGQzaGN4Ym4vdjNQYTlyNHFxOTRseTFY'
    b'dXhqWXVnRTB6N1dLSFRpZ2huWVFrTjRXRVhGb0tOOGxOUWtKb0lSQksKS0NGMDQ0NHg3cjFi'
    b'bHF5NnFydmFYYTIyNzU0eXZ6OGsyN0l0MjVCZnVOZStkejRQangrMDU1eVpjODdNOTh6TU8r'
    b'KzhRM0RmYWpBWQpqUE1UanIwQ0JvTUptTUZnTUFFekdBd21ZQWFEQ1pqQllEQUJNeGdNSm1B'
    b'R2c4RUV6R0F3QVRNWURDWmdCb1BCQk14Z01BRXpHQXdtCllBYUR3UVRNWURDWWdCa01KbUFH'
    b'ZzhFRXpHQXdtSUFaREFZVE1JUEJCTXhnTUppQUdRd0dFekNEd1FUTVlEQ1lnQmtNQmhNd2c4'
    b'RmcKQW1Zd21JQVpEQVlUTUlQQllBSm1NQmhNd0F3R0V6Q0R3V0FDWmpBWVRNQU1CaE13ZzhG'
    b'Z0FtWXdHRXpBREFhRENaakJZQUptTUJqbgpFQUo3QmVjeFZLdldSU2Q0RE5WdVhiNkZkeHNG'
    b'aTA3UU5KVlNTZ2lKUnFPeXFnRWdtbXEyV0RSVjFlbjFITWRIMDBvZ29YUkgxY045CnFUMjlx'
    b'WWEwQllSOXg4OVhlTXk0amIyRjgrKzdTNVdyOGxJUHo3WitmMkhOWldQemFySU1ML3p4MXdW'
    b'WnpuREE5OGlERHdSODNVRi8KejRKNWN4ZGRldkhkWDd4MS9kbzFseSs4NVBwckZ0VlVscjMx'
    b'K3F1MzNYQjlYMHQ5NzhHdDl5MjU2UGJwaGRPdE1UVVphNG9TamNtWQpkYUVaL3cxSVd1WTNz'
    b'M1NMODJOL2VPUkhQTThETUpsTThWaU1FRkphVm1vd0dHYlBudTF0OStvTkJvN2p3dUh3WFhm'
    b'ZEpVa1NJZVNTClN4YTB0RFEzTnpjUFJDSU5EUTA2bmU1SFAvcGgwdGQ2VlZib3YyYnJKQzNE'
    b'M2kwVE1PTnpaMUd4ZXQzMHFvbVRKdTNmdjU4UU12aWoKMCtYcUQ0WDBlcjNmNTF1NVlrVmxW'
    b'U1dsVk5PMER6NzR3R3l4QUlqSDQ3LzV6YStMaW9zckt5djlmbDl1Ym00eWtkaXdZVU5kWFoz'
    b'Ygo3YjUyV3RWVnhTcDd0MHpBak04ZGgwRUVZRGFiM1ZsWjdlM3RBSUxCb01QaENJVkNlcjFC'
    b'cDlNLytORER2L2o1enpWTmt5VHBHOS80ClprdEx5eHR2dkRFd01QRFNpeSsydHJieVBPLzMr'
    b'Yk56c25WNi9jVVhYL3pWcjN4bDNMaHhBSndHa2IxYk5nWm0vT3V4cXRGaWZhYmMKckk1MVly'
    b'eGR5ZUZUTTJvS0FPemV0Y3RrTkpaWFZIeTRkQ25WYUZOelUyNXVibmRYcDYvWGYrR2NPVTZu'
    b'Yzl1MnJjWEZ4Yzg5OStlMQp5OTk0NGlkWHpKdGMvTmFLM1pPblR0dXdmdjI0c2VPOFh1OGRk'
    b'OTc1OTcrL01XN2MrS3lzck4ySDIvS01LRFJxVGk1dG9zbTByTWhFCllpLy9YTGVHc0Zkd2pu'
    b'NVpxVGJOa1pwWFpocm40bXNLS3ZmdDJ6TjM3cnkrUHIrbTBXMWJ0d3llVTFsVnVYcjFhbzdu'
    b'SjlSTkFEQisKNHNUR2hzTVh6Snl0NXRTb2V1dXlsdVNDYi8rbWtlZGJBNGxyNTlWVUZqZ0RG'
    b'a1BkbUdKZVoxeThlTEhGYW0xcGFWNzcwVWZWMWRWRgpSVVVBcW9UQXY4MFltNVdkL2NMenox'
    b'K3orTnFXMWxaWWRMdDk4dXJteUk2SWtWbXFXUXZNK0ZSazhhbWJLcmtiWE40NlEvREF4eDkw'
    b'CnRqWk1tRERocmJmZW1qVnI5a3N2dmpSdS9QaVhYM25sa2tzdUlZVGs1UmZvU3V2MnhjeC9Q'
    b'eHgvZVdkbmFQOVRBclVYbG85YTBTTTgKMjhodjlITk45ZTN1ajFkbGQ3ZHhYR0pyVSsrY2lT'
    b'V1B2dFg2Vi82UzlkM3EvaENCTmRmaGRIM3BobXVNUmlPbDlPTzFhOXU5N1pNbgpUOTYrZlZz'
    b'd0dOcTdkNDhTRHhjYmxUbjUvRlZWUmpPbmVNUHBGRmczbTQyQkdhZkJoTXc5MWVyeTI4b1g1'
    b'YWYzYnZwNDNManhUcWR6Ci9ManhvVkNJNDdpZTd1N09yazVLS1NqdDdQQkdJcEhEYlQzZlhL'
    b'OCszU2lzN3pjanVLdW44Y0RXZmg4MXVSZFhDQUJzVWQrekczNS8KdzhDT0w3aEZYME4zSWkw'
    b'Ly9JdVZFeGJlQkY3czR4emJJdWJuamdqZjJxanQzSHNvRW9sMGRIanREb2NpS3o2Zkx4NlA2'
    b'M1E2VGRWbQp6cHhWWDE4dnk1bVAzM24xUWtQbjYxYzVieXZQNkNDemttSUNacHlNUjBxOXNN'
    b'ajl3SlZqRHUzYldWTlRNMmJzV0VxcHdXajQ4TU9sClZWVlZBS0t4V0g4b1JDbk56YzF0YjJz'
    b'ZkNJY0xQVG5ITGwvb1hIMnc1cWViYkhjYzhQYU9yeXErd3RIM0kydWIrVDkrTVA3ZHQzSisK'
    b'OE4ydnlvYTZuZjVyeDE1NHc4SlpPalY1UEZkS2l3bzhrWUdCdHRiV0pVdVdLSXJTMXRiNjRk'
    b'S2xFeWRPYkR6U2FES1pORTBiTmFxMgpwTFFrRm90L3ZITHA5K1lVUGJYUTd1SlRyTHhZRjVv'
    b'eHZPMU5QMzlsVG9sZE5KbE1ELzdIZnl4ZXNxUzd1NHNRRWdxRk1wbE1YbDUrCmZYMTlWV1Zs'
    b'cUQva2RMcU1SbU4vZjcvYjdlSUY2WVg2b2NuYkhmeVZLVjBPZ0oxaDNSWFo4UnRtMWpqem5W'
    b'R0JGM2crdDZxcXRhYksKT1gzRytOdHVHVnVhdTZoVVdIcW9MMDRsQUNEa25yRjZXWkczYjk4'
    b'K2ZzSUVpOVY2NE1BQnZWNG5pcExkN2lnb0tHaHVhUjR6WnN5UgpJNDJTS0U2WVVIZWtzVEhm'
    b'YnJpd3pQNytrYmhHZUZad1RNRC9WNURTWVNlWFVETkpsUk5QTlFqZFdVVXlUWnYrK3NJTGwx'
    b'OXh4VWNmCmZWUlpVVUZBK2tPaFpESlpYVk85YTljdWs5Rmt0ZG5LeThwOGZuOVpXYm5INC9G'
    b'NnZiMlIxQWM5K3BPU29vUy9iWXloMEpNVFM4VDEKaE12S3pkMjNiNjhqS3pzbDhLSW9kdmY2'
    b'TEFacFUvdEFWMnJJd2p6VDFGdFRYaWFJb3RGb2xHVTVGb3RWMTlTME5EZjcvRDVLYVdGaApV'
    b'WDUrL3VIRGg5T1p0RjZ2NTNsZVVSUmY2Mkc3dzcwL2ZJcUFWY1VnRHppNGxDTExLcTlqaGY3'
    b'ZkFMTkNmNDRZdE9UTUhHMWVtYlV1ClY5KzByOTd0ZGsrZk1lTkloMjliWjN4TmMzUkRRRks0'
    b'SVpzUVQ3Qi8zNzdKVTZiRVlyRkpreWE5K05LTFM1WjhZU0FTdWZ5S0s1eE8KWjBhV2Q3ZjR2'
    b'UU9abm9GTXYycFpYNjhtRlRtV2RIUW1SczUzM2VHZVNIdW43ZSt2Ri96eUVWRVVzN096OC9N'
    b'TE9qdWx2THg4QUR0Mwo3ZllHaytETmd5Zi83cUR3YXN0aGkwRXllTHNOSXJIcXlndE0wc1Q1'
    b'bFJOS2MzeStIcFBKckdtYW5KRjVnUjg3WnV6aGhvYjI5clpvCkpDcmtIRmV2cUtibjVhcnp5'
    b'ODFUQ3QwT2ZRN0g4MnZXckFrbjFiaTFZSHZZc0syUFMvTUdWaG1ZZ004L3JpamhMclg0MzMv'
    b'dGVjOVYKVjIvWnNxV3VydTdBZ1FOMWRYVnRoNWN1RUVKZnZXVHk4amI1dmVaMEVPYVdBYVVt'
    b'TjZlNnVtWWdIRjY4Wk1uS2xTdkdqaDFyemM1Nwo4MEJnWTd0M1Q1OGFKdWFqcVJLQUFOd1p5'
    b'dTZYalk2L3JQeFp0ZFp2Y3ppT1hnS080d0NvcXRyU0UrcmxjNCtkdkRkbVJ1eWtCREpBCnhv'
    b'V2V1bXhwZG5INjh0cnN4VXVXdlBubW16dDM3clE3N0QwOVBlVmw1V3RDYWNDUXkwV3ZxVFFz'
    b'R2UveDJJMnIxNnhldXJYVjdyQlAKbXpiZDZYVDY2ZzlOTGl1NDc5ckpkNzYwYzVXZjFRVW00'
    b'UE9RbnFqc0xISFYxdGJXMTlmelBDZEtJcVVVUUtBdm9HbGFwTGR0VWI3NwoyM09ybCs3dldk'
    b'OFVxeGxWbThsa05Fcmo4WGpOMklsM3ZManJFeCtYNFhTQUFlU01veUExcVpPREFKSzZIQXJC'
    b'bU80Q2tKWG84NVY0CmZBZDNxWExHN3N5U1piay81T3Z6dGF1cW1wQWNSRk1NR1QrQWxKU2pj'
    b'U1BQREFWaFdlM0hhci82MkxiV2VSNThmK0dsRXNHaFE0Zk0KSnJQT2JMV0YwNytlWVZwVU44'
    b'N3Y2LzFvMVFmSlpMSzJ0dFppdFZ4d3dRWFYxVFdCdmo2VHlUUmp4Z3dBM1ZGbXRmNGNZVmJv'
    b'ejVHVQpRdTEyKzk0OWU2KzYrdXFNTEwvOTF0dDFkWFdIRHg4T0JvT2RYWjJ6WjEvNDl6ZmVX'
    b'TGxzYVRrZmZQSzJHZVdsSlorc1crZHdPRlJaCmR0bE0yL3RvaHZ0VXc4alpwblhOUys1c1hu'
    b'S25SMjNVcFgwTjE5M1p2T1JPZm1LUVptVTdFeit1TXkyV1FvK0lvdWdrNzA0eUw4bE4KM1ox'
    b'bDRzZUxXd2N2cWVKMm56WDlCTkh2OUNzT3E0WG51TWxUSmh0Tnh2d3MxNk9YbC9QZCszZnQz'
    b'UEhLS3kvZmNzdXR0OS8rUlpmTAp0V3JseW9Id0FJQjBKaU9La2lBSUFGSXlZVFdCQ2ZpOHhH'
    b'MFVIWFo3ZFUxMVNVbUpLQWpqeG84N2NxUlJ6bVJNSnBNa1NpYVRTVkhrCmVmUG5yMXl4NHJr'
    b'Ly8vbklrU00zMzN3VHBkU1RuNStkbFhWUERmMzBHZkVjK0tNbFNRaDREa2xSY3NSam1xYnlI'
    b'RlJON2UzdGpjZmoKUEFkQ2FGK1NVa3FIWDNKV3ZqVmVkTmp0bnZ4OFFqRmgvSVJnTVBqdGI5'
    b'MDdiZXJVc3JLeXhvWUdTWkxNWnJQVDZTb3RMWE5uWmZYMgo5c3B5UmhLSEduYTNtZFV4SnVE'
    b'emsycVh6bUsxZXR1OWxGS0QwYmhnd2NMbHk1YW4wdWw0UEg3VjFWY1BEQXlFUXFFTkc5WURX'
    b'TEJ3CllYOS8yR0syMkd5MndXdS9lR0dObThRL1UzWnZ6cnAvOWV3dlN5SUExQzdwRW05Y21t'
    b'ZHJCSkNyM3lDMnp5N1F2d21nTUR0eG1mN2EKRjJZOTl1bVRMUkZqaTJlT0d2eC9oOHRsdFZt'
    b'WExmdXdadFNvVjE5NzFlUHhBUEQ1ZkpxbUdReUdqczZPelpzM3hlUHhhQ1FxSzBNOQo1Mm9u'
    b'TTBkL2pyQnBwTStSTDFSTEhpUEp6YzBoSUJmTXVFQnZNSXdlTTZhcXFpb1FDTFMydGxDcWVk'
    b'dTlpeFpkdFc3ZE9rS0lLRWxHCms2bXJxNnUrdmo2VlN1a2tNUkVKN3d5ZmZUbEJpZEMwdUdJ'
    b'ekFLZFpjVnVWd1IrTlJtcTFVWUduQUVSQnN4Z1Z2YVFCNEFoc1pzMWkKMEFaUGUvN3cvQUR5'
    b'ejV6KzEwWnBaVTVwWUdDZ3Z6L2s5L3Q3ZW5wYldsbzBTZ045Z1lxS0NrblM3ZGl4UTVabHU4'
    b'UGhkcnRIamFxMQpXQ3lWRlJVRkJRV1JhTlJnTkxZRkl1dTZLYXNNekloMS90SGYyYXlWVEpn'
    b'NWM5YXhYMVJWN2VycXFxdXJjN25kUHArdlpsUk5XVmtaCkwvRFRaOHpZdFd2bkF6LzU4WDg4'
    b'K05DNzc3eHo1MTEzQWtSU0U0RDVyTGxFVXNMSERSNEFHZ2dBZzVLMHkwbTlwb0lpNDNTa1ZN'
    b'NWkKMFN1S0lnaUNvbVNJUm5sL2dBQTlCa3VhbHhLcUhtZHp4OURTVVp2TnB0UHBBS3hmdi81'
    b'd2ZiM05idGRKT3F2VjJ0RFllTjIvL2R0SApIMzNrOFhnVVdaNHdZWUxINHhrMGR3L1MyZG1W'
    b'OXJjRGhhd3lNQUdmZitRWGwrWGs1SnpRNGVINWdvSUNBSUZBSUJSTExicHVjVEtaClRDWVNY'
    b'cTgzRUFndVdMaHcvNzU5b2lTNm5LNit2cjY0enZscGN0bXZUdHZaOUo1SEh3TFZkRXBLbHRN'
    b'cERMVjRpZjVJY2JIUzFPd1MKZVFKQ2xXaWNaREo4aHNZNWNVRFB0YWF5dkdUMFdkUFBHRnlE'
    b'NmdVZ0NJS3Fxb0crd0kwMzNmVDQ0NytmTUg1Q2Z6eFZXbDdsY3JzZApRMU5XSjFCUWtPL3lS'
    b'T0ZsTGZEbkJjRjlxOWxiK0p3d0lUMHJoNVk2eEdJVExYZnBjaXc2dTlYaWRBN0pVcGFWK2I5'
    b'ZmYxR1Y2K3BhCjUwRG5rVkFvVkpCZjhNNDdiK2ZrNU5iVzF1cHlTNys2TWhJaHhrK1ZFOVVl'
    b'S2Z6cGx5ZHZPNkg5andDQVVZK2VBRXJ5VHI3aTJWMVQKZjl6K0NNalpUY1RaZk9MRmF3cEds'
    b'K1FBMkxCaHc2YU5HeWRNbURCejFxeURuY0YzRHZidmFPOWZlZC9jWXljSGc4RndOTm9UVHJm'
    b'MgpaOXJpcERtWTJ0UW5KQWtiQmpNQm41K01OMFh2cm5Nc21sdzJHTHdxbVV5R1FpRk5WVzEy'
    b'dTlWcXZlcXBiYnZqRms1VEo5b1NvOXk2ClFwdVlheFl6R3JaMUpqN3dhZ25vUDMxR3VWclQr'
    b'c3Z1dFJtVTQ5MVhId3B5RUkxREVoR0pJMnRZQTlrWk1zeGQrM1JrbUR2SG1iRWcKZVUwcFg1'
    b'ZG41QW50anNvZEVmbWdQN012WnFTRW4rZEt2UGpGU2YzOTRYZ3NDa0t5czdNbFNRS1F6bVRl'
    b'M3RINjNPN3c0WlNWVlFObQp4RHIvME5QMGZXTzAzeTZwRzFYb1BqWXNGRVhSYXJYYWJMWllM'
    b'TlliSE5qblN4eUppWlJ3M1JuZHZqQy9zU05SRWZwcE9QREpXNzdSCk1XTC9UTm5GaUxOVzJG'
    b'bWI1UTlIRVFnam1rQkdoc09LakF5akFVZThBTkRYRDRjVkFQNXljTmJxMkdXZlB2RU14SDFo'
    b'dnE5cmRWbjYKRHg4ZjZsMGFuZXlUZFlNZTNUTnphYUV1WXpicXNuTnlyRmJyNEhjS2dNRHpZ'
    b'd3JkTjlibHBvUGRld0tVclh6NG5HRFRTSjhMb3BwKwpkSWJ1M2t2SEQ3Zm9ETWZsY2lXaWtW'
    b'VHFoSFY1bW1qaXpMYjdMdGo0NTZwdlNHcjBzMllhN3N1MGQ2Q3hGUVU1eU05R1djSHhReE9x'
    b'CmtldEdPb09HWmpRMEl6UFl2ZjRzekJiZWYzYnFZemVOMjM4UXM0Zi9IbytFUlI1Mis4aWZH'
    b'MUVVZm54MTNhTVg2QVNxc0ZyQkJIemUKOEwwSi9CZG1qdHJXMFBHRGYreDU5TldQUmhpMFV0'
    b'b2NKVnNESnhzUjQ2cVJhcWdyalZ4ait0dG56YlNsaHovVXduVjBjNGtVTWlmNgpMeW9xS0VV'
    b'MFNsbzZ1WlpPTGpqd0dkdERxbjJuL0lWc0orVUkwaWQyN05mMTZWdjZNeU0rNEk5ZlhQMlR0'
    b'L2Z1YisyNWVXYjFsNnBZCnlNdlBCV2FGL3Rjenh4RmRVRnZ5bFplM3IralJlU1Q1bmRzbUh6'
    b'dlU3USs5ZjhDL3ZUdHh3SmZxZ2gyODVhUmFYeVB1QjJBMTRhN3kKRDc2c1cyNlIwcy9zdnVE'
    b'UDZaOThtbnpiSEJmL2JFNjlvcUs5RzBVZXhCSXdIeldCUmVOd1dHR3owU25qS0lBMzEwekVw'
    b'MmpncFhUdworYXA3cXZKVFhmMm1pcXlvb3NLZ1F5MDJic2VTNDZZeXpuckg2blRKeDV0SFor'
    b'dW01aHNYamN2TGNsZ0JFRUx1WGxCMzdkL2EvbmJFCnQ2aW8rMXV6QzdmMHRPMk9XVmoxWUFJ'
    b'K3A1RzBUTGt1Y2QzckhmMHdnOE5YNnZoc2h4WEE1c1BlWjdmM3JlOGxLYzRBRFA1M01ubnEK'
    b'b1J1bXRLWFNBRkJYbVFiU3ZpQlVZemJTbnlwclE3cW50UnVKSkVhWEEwQWlCUUNFSUJxSHpR'
    b'd0FIamNPdDBKUndhdUpUelgwMVRrdApScVU0V3k3T0RnT2dGUEVrdmxLN2NudnpraFBPSTF5'
    b'YmFtL3J3ZEllK3AvYmo4ejE0Q3NYNUU4b3pTM05kZDA1cHZ0WCs0VzN1ckRoCkRlOWw3dWpl'
    b'aUZIajJHQ1lkYUhQNWRHdkVuKyt4OTBQSTRCYVEvVEdHZFVEc2NUOWIrNzYrcnY3dFo2L2wv'
    b'TTdRVTg3S2FybjA4TTcKdmRFNFpBVUhZeFdmTXV2TEMzWTRMR2pwRnRjM1pnT3dtVEVRQXdD'
    b'Tmd1TVFUWkFQOTN0aUNZd3FnNVVHUGwyU3BDMlNReW5DMGFGdgpBYVdReVpsczQ1UW1JLzZW'
    b'ajc3K3dxUHY3a3FtMG5mT3Fpd1VvZ0Q4bXVsbFg3Wk9qYk1hd2dSOFRoT1hIUFNveGZYRzBk'
    b'WndQSG5YCjZ3ZGZhdFBQVVA3KzNVbkwvanpsRjY5VTNseEdEbzU0cmFyeGlhTldyVWdNRmhN'
    b'a0VmY1ZQMXRIVitjbWR1V3BoODZjZFUvQ2JqRmgKd1RUWlB5QTh2OFlUVHdKQVJvWmVRbk1Y'
    b'L3JLK2RFcVJmMUl0ZWdPUWRHZnBlWTFPcjlBbGZkK3dQVHpXM1NVck1Ca1FqUU1BQlJLWgow'
    b'MTFMbDVqKzh2YVkyLzh3NitrYml6OWN1V1BkWGEvdWsxVnRjYzFRUDE0bFFsSmtVMHIvWXRn'
    b'MDB1ZUZrOFMrT2QzOXBiZmI5c2JNCklLUkJtUFY2OTVWVitvYUZGUzNqdUExS09KREZkYmZU'
    b'bXVHWFRERnVXMVM4alFDcERPd1dFSUpraXV4djFTMnUyZm5RckEvQ2ZaRXQKcWJtbnkrNExo'
    b'cWZtdXJhMXRjc0Z1U2h4UmZPdHNXQS9CaEltWDZTWWF1RjRuTTZzNnRlTDFCczB0bm5sQ212'
    b'WGx1QzRDTWs2WFdwdgpUTDczL2tsdlJjSVpxT25DTEZVU2taWWhDZ2dPd0dhUVgvUmVCZTY0'
    b'ak0xYTMzV21sOFpnNHoyVkg5UVVLM2Q5Y3Q4ejRXK0g5UlhlCnBMU2xzZXV1aWE1M0RrZGt3'
    b'dUxSTWdHZlZ5ek1pcjE2T0gwNGNkeVZTaVBDOW1EdHpjWExITWIwb3VyNmNBVHI0aGNOdjJS'
    b'QjlOZmoKUzFLcXFvb0NxSWJOamZaZjdyanl1M04zRjJlbFdydTVuelY5UFV4eU1kTHEvdXRN'
    b'TC81Ky9oc3VTOFpzaE5rSVFZQWdvRC9wY28xLwpxMlQ4ZC9zR2JIcjFZN01SRGlzSVZiS2RL'
    b'TXVWTDh6YXViSmpRb3lNNksxSmM5TDEwd3E3YXZOanJjbmlKelpQSG1WcnpYRU96UzBmCjd0'
    b'SjM5WkZ1Y2N6eFlYOG05TXkweHk2dFBPSnhhVS90bS9OSy94M0hEdlZtcEFQZXZocGpxaVZ0'
    b'WWxXQ2RhSFBKeloxSkE3RlQ3WlUKaFRuUDI4MlRQUzYxTjRBWTd6N3BxTXRqZTMrZnh4ZEVR'
    b'eXRhdXhCS0czKy84RzFGbzIzZDVLRnQxejVZKyt5cVNWKzQwZllDUjArWQpJNUl5NGRHMkZv'
    b'R25Oak9zRnFSa0pOUFFOS2g4aVNPckNvREpmU0VIVUlwSUhLSkFMVVlZOUxCTDhRcis1SjY4'
    b'aDdiOFY5a1AxMDI5ClRwYWNmL3FrTnBuRzFOeVd1K3UyN08rd3QzUmg1eUZrWkJJYTRNSzZ5'
    b'aE5HRGJ3N251SjBJaVFSNzNiTk95bk5mVW43UG4rYTFRZlcKQXA5dmcyRmg1UEdlV1EzT3k5'
    b'bWhhUWpIaENhZndTSW1CekRVbFhYMDc3aStkay9hOGcxbjZaZjcrdzVPTGZXQ1Vwc1ovUkZ5'
    b'N2FoRApKZlpRdmpOMVVlRUI2dDJ6UmIzMCtNaVoxMzhTbmVPSmJuWHlvV0FZOXFNek5lbEVY'
    b'emhtVEtTMGlQZEpzOUNvRTZHWDBCdEFLbzFJCkhFL3RtLzlPK283aE4rWklOejh6NnJ0WGp2'
    b'VmFKSGxTVm5PVkt5RHlNT2hoRURJV1hXcUF2eW03NXZ0ZWI2dFY2bDdWTnlzc0ZBQUEKMVdv'
    b'eWE4dE1YVk5OVzEwMjFSZlIvYUwxWG5wS2pKN1R2UW9HRS9ENVJ6UkI3cWhZNXJZajNOTjNV'
    b'K1VHRGVMVzJMVEJRNzhZOTBRbQpLdGZNK2FzcnAwYk9rRXovUndZOU1qTGNkc2dxckNZa1Uv'
    b'akw5ckcvR1hoVUkrS1hYRTkwSnJManhBN0FyQVVlblBnM2wxa21IQXc2CktCbzZlMUdTcHlW'
    b'Q24zQURyN3NOamVrTW9uRllUYkNhRVUyZzJBTUo2Yi8zWGc3Q0E3alc4cnFreGR1NXNidUNW'
    b'WFhpK3NKc1ZhTXcKRzBFNHlBcDREczNkanRxNXJ6cmNGZWxrc05yMVNWTWtaMytxYnJDei9i'
    b'Y0ozL3kzNGs5VVdYVmFzYTI3NkozK2Exa1JzeTcwLzJaNgorR3F2WDl4NUNIVTF4S0NETDBR'
    b'WGNpL2J0VzRBdTZPangxWXAzYzN2QWtqRWZDWURPQUlBcVRTOFBYaDJWZlpQMWx6MFVPQTNN'
    b'bWNFCk1ObDlaSnAxNTJDYXQrVzhXdVNNaDZQd3VLR29hUGFpMkFOQlFJNFRKZm5nZVJSNXdQ'
    b'Tm82b0FrUUJRQVlIWlo1eHpEeXNITHJ5LzYKeUNXRkFCd2hFMi9jKzlUank0dFg3Ykw2Z3BD'
    b'Vm9YV0pxcEtPUjN0bE9aM29XNjhSL2xDOEJrQzV1blUrZmFVOTR2UzRLWUJJSEVmQwp1YXg4'
    b'LzV0aGpoei83UkRTTTJCeTY4S0VvSzJYLzlHMDVYcEJPZFQyeW85YUgzN00rMTBsbmJrODcv'
    b'NHRUYytiaFNPdWF0UzNJSlpFCmVRSEdWcUNxeUwrN2RjdHJCNUlxYndBUXlsaXZLVmo3L3FI'
    b'cnlybTk5MDVZQlNETGdmNElLSVVuQ3hZVCtpTkRTeGVNZXNRU0tNMkgKdHdlQk1FeEhCK1kv'
    b'SFB2YTFxMHpTL2lHaThwYmYzVjRLSEpBblhuWG9qSHRwZmxRTlRTMklaWkFjUjdxcWhKYlYx'
    b'OHI2WFE1TnQvdAo2LzU5anp6alh0TURWNVZzSFYyT2RRY3RuVDdrdXRIVGg4TWhEeXRlSnVE'
    b'LzdWQjZ4RjlXV3J2YnFLZWp5MVJKUkRpS3lrSXQyT1RLCjhNWW51ci82eGJGM1JCUDFZeXNR'
    b'VGFBa0gwWTlHdHZ3em5hWGFzMExwbXc4VlFhOWlzMWlhbXBPeThMbTE3OVN1OHBwU2dPUVJF'
    b'Z2kKQm1Ld0dKRk13V0ZGUncvOElWU1hRSktnYXVBNFpBK3pPay9NOTMzVDgwUzUzZDhYRVV4'
    b'Q0Npb0E5TVhOYTdyR0pZK29aZEtSQzhaawpiR1pFNGhCNFRLM3BxMi9CdmxEbGxzdzhBQ0pS'
    b'OHR5SXhqQ3hKRW9BU2NUdUpyZk1sYlBpWldQZy8rVVk1SUZmM1hiai9qMnJuYWF3CjNZSzJM'
    b'c1RUUWhvR0k2S2JZalBUdkNYZTIxdGdEdVZZVXpZekNFRXNpU3duaXQzSmwxb1cvalYycjNv'
    b'MDF1eFhDbDc2K2NhTEhwcjYKOTBKcjJERE1PYW8vZ21RR3dSQWFtb2tnRUg4ZktPRHJJOGsw'
    b'WW9rVEJBd2doN1FuVW1TamY1d0MzZjdVT0FCK1V2cFJaTjVkZWE5YwpOam1xVVdSazJNd1FC'
    b'S1JsdkxPdjlLbkFWd2RJamtQcit2bTBWdzU1UlQwdmF4ck1SaHhwRjVPR2hWek85ZXQ5TEln'
    b'c0d3UC9yeVlwCjJaL1o0S3VZL09ET3h1eGtHbGxPNkhYYXUwM2p2elZ4elV4cEpZRG5rLy8r'
    b'Uk12TklvL1dMdkwyWm50dmtDZ3FzcDM0VXVrL1ROcVEKQzJTaGV0QmppY1JFRDBlVmpJelF3'
    b'UEgwVFFhRUFnajBrYkppZWloWStHSDhtdDZrdzJxbWlTanA2VDFCWFMyZE1CdWdRZHdYcVpu'
    b'bQoybnZzOTB1bE4rc0srZ2hCSkVGMk5ScysyZ1pOdzVGZTB5L1RUN2FUY1J5VmYxTHhPRWUw'
    b'dHBoSEVLakZoSGdLYmVIcWduRS9mTHN4CnljcVh0Y0QvKzluUkx5NDlySFlIVTlaNFF6eXVP'
    b'cXpJQkgyUzJYeE4yZGFWM3JGaG11MUZUWjN5NGY1ZWQ5aGM4L3VtMnlxNXZiL2IKT0hsYmFG'
    b'eHYwaEVYYzNndC9SOVZ2OXZrSCsxVFBGK3EyK3dMUWljaUVBYkhRU2NobFVGZkFNWEZXTkZR'
    b'ZGwvM0UzdlY2UjhFRjE3cwpXRzNYSjNtQUYyQXlvaWVBWUJnbUEwUUJmV25Icjl1L2ZIL3RY'
    b'dy8zMmpxMENvQzY0M3UzKzhxYnZVcEF6ZjNXZ1FkK05uZnA5aU9tClp4dXViTVFrQUhjNy8z'
    b'VGZ0SFh2N3ZiVTJscW9SdHU3c2I3QithZlFmVThlNEhzVTVxM0JCUHgvZ3dUUnR3bDF2cVR6'
    b'cGxGYkNZVlIKcCs0TmxXWHBvNWZsYnQzVVc5NVBjei9xbTM1RnllNldlTUVIMGV0MmhHcS9Q'
    b'WDZweGFBcHhGZ2wxZitnOGxtWFB2N2drZnNLZFozWApsMjkxMmhDS2dCRG9KQ1RURUFWb2xF'
    b'UWk0ajB0ajJkVUFpV3RRSHkzNzRwRjlxV1ZKVEtBVkFhaUFGbUd5UWlIRmQ1K3k5LzZianpp'
    b'CnQvMWh4cCtNR2IrWkJrcWNrZHRyUG01STFqemkvVkZLY3YrYjY1M2ZIRnE4VEwwVndNMjJa'
    b'Mit2V08yMlpPcTdMYVhPaU10T3ZCSFgKRHdMUCtMaEM1aXo1UHdLTGlmVS96RlIrOWZPemZ0'
    b'VVhvbDFobzhOdCtsUERvdStNZWV2eCt1c2lLZDJmNXZ6NXFvOGVhZFFtR3RLOQpaVkxUaGRi'
    b'MVU5eUh6V0k2Sk52NzFCeVRrTWtWdThkazlhUXowRWxJWnlDSXlHUUd6V1NRQktJejhDSTNG'
    b'QWNqbzRuSnBLb3FHZ1U0CkFwMEVUUU1BamtNb0poMklqNG9vWmtHSjV4dDZkU1RkblhDdjZK'
    b'bFNMMC9vbFhOVHV0ejc4Mzg1eXRINTY0T0xyOHRmTzhyVi9kS2gKNmZlTi95QVRqWlhtWVcr'
    b'SDVZdU56eVU0T3l0SEp1RC91MHhRVno0MitqY05yWFRKUXRUOC9lbHMzbmRId2Q5cTdEMmRx'
    b'Vnhla2txTQozV1B6UWpycG40bk1PcmdNVUM5Qi8wK0ZoY3pJMk5mbDhzYXpiVnlRVUdXWmQv'
    b'cXJpWHZ1OUx4d3JXdHBYNStjRWgxZjYzdyt3eGxaCkNUSUIvMS9ueTdaZjMxS3lVaEt4cTcv'
    b'Nnd1TFdMR3RtdUFoakp5Mi9wd0FCSWVqb1JTS05ZZzlNZW1nVXNneU9nMEdIY0FUQlRoNjkK'
    b'QXVpUTFZcnlWRmVWZHJ0ZzBHRndtYUhaaUhnU2ZTRkVrM0RiNGJDQzBxRWdzOGNXTEhNY3No'
    b'eERqaDhBMGhueWNWdUpsb3lQeWZYNwpRdHl0OWM4R09SYXgvWDhZTmc5OFRyQTBkTVh0bFIr'
    b'VkZpaWxCUTE5L2VqeUQ4bUpVbkFjdkQwb0swRHVpV3NmdGpSV2VxYjhWdFBVCnp0M2ZuVFc2'
    b'YVhpQVozODNWL044bmpONXdxQzBjV3JJZkVmWVlZWDdhSHpaZUJLYzY0N0txaThIMnBlSzZx'
    b'UFo3dU9OUEtYWTJ3aE4KQlVjd09POU1DQUI2WVZHclFROUZ4YXJtaWlCWHdBcU9HYkVZQUhC'
    b'djhiT1hWTFowK25DZ0JRSkJTVDZzWmxoTlNHZncyQzdQbitUUgpBLzJhMWhQanVPTnJGY0w4'
    b'RjR0cnJySFlQTWxFVUl0dE1RL3J5WFlmRk1xMm5ieFBRb0xYTXBQajFtRmJ0VFMway95Sno3'
    b'cmNIbmZlCnBIM2IzeXpPR1pxTTJyd0gyMXJGOTVTUzMzYVY1bVNpTXlveWRndXNKZ0JvOWlJ'
    b'UUJzOWpabVh3L1laUndiUHRxOFQ0dkdIendPY0UKN2RIc0xoOHNWbnYyaEhkOHFicE9Id0Qw'
    b'aFhEditxSlhyT082Rk1QbWxMc3J4SHVHTmNLeDRDNUZrUlZGamdWM09XMG5wS2JQVjdxeQpU'
    b'cGlTbFVFakZRbnJpUnN0bVExMG9QY1RBSUdlM1M2TDc5anZCYms0a2pLK00rRHB0VG9mREkz'
    b'N3l4YkxZSXpMM2o0bzdoK256VitYClJMVDBTQkhxWkFYSHhzQU1BQ0JVK1dYODFwa0x5b3Bu'
    b'dkhWazN4dlc2SGVMY2hHTlkyT3I0Wm11QWs3aTc5UTNYRGFkRHU4bkoxTFkKMWxDbWFKcFQz'
    b'K2JKZ2l4REVwSE9ESTJSUTJGWU5ENmVCS1dRUkhBU0pVYk5vQU1BU1VJbU0vUnZXNitvaWFO'
    b'c3V0YUpWU2RFcWZTSAo4TnBlODB1SnNnVzJ3SkxjbmpGbE5KN0Vqc2I4YWRkODB0bTZyV2Y5'
    b'YmM4ZHVINUYvaDJzNE5nWW1BRUFkZDVkOHp2RTlxb1dXM1dYCndWYlIxNDZpWEZoTXVIUk1j'
    b'bHpPa1paT2xPU2h5My9jdGpRNENUU21xTVZvZ0hHa0lITWxlUURPSG9yWmt5WEhrL3ZpU1F5'
    b'MitZT2oKN3NGdndLS3EySGpmdmtrMVE3RnBJekdZSFdXQ0lLWEQyMlA5K3J2Mk5xOWczV2Nt'
    b'WU1ZZ0draEpqM0cvenhjOWZIdHZmSUtCSEZlVQpVWTlaZFNOYzBoOUJKSTVqV3l4UVFGYVE1'
    b'VUFnUFBTTDA0SlFCSlRDYUFDQVpCb0E5Qkk0N3VqL2k5QW9DQWVSUTQ0YjBpbU9HS1g1CkNJ'
    b'YUg1cUl5R2FRR212WnZlTUNxdk9ieFd5S0UrVHd6QVRPT3NxZG84bjkxN0JnVFdrdmtobUpq'
    b'UTI3UjhjbWJXQUtOYlJpSVVWOFEKeVRRUkJVVGkxQi9FK0dyaXNrTXZRU2RCSjBFdlFSUmhN'
    b'NSt3WENGM3BLaDFBekdZNWFHNGVhMWRTR2N3RUtPYjloR09ReXhCVlpVVQo1a0Nub3hZRHlY'
    b'S2lNUGY0Qm9aV2MwOHkvVUp6aTJqYWEvck5xQ3RZcVRFQk00NE5nc2t2Wm4xMVd0citxdk41'
    b'c3hIUk9IWWZKcDArCkhHalNWSlZVbDFCSlFEQUNoNVU2YlREb1FBaHMvN3BORGtSaGFQL1JU'
    b'aC84SVVvSUFpSHM2S2FLQ2xFZ05ndnh1RkZlaU9vU1NnaWEKL05JVjg1OEF6eHdubVlEL1Y1'
    b'TW54UFAxOGhsT0dKRDV4dlJ4RllxOTllRmc3eHZMOUFBYXVreDlZY2lwbEp4UzlIcjA5MFBS'
    b'cEVTYQo2Q1NZRFpBVkpOUFkxMEQwRWlTUjhEeDRIZ0lQam9OQlVpVkJQdk9OK2NLU3BoSkZo'
    b'VTdFUUJ5YUNrV2xlb2x3SElra2FDS0psazVrCk1naEhWRkRaYkVBcVErS0thTGZyS3p4SnAx'
    b'bHBDeHFOdmN0U2xYTTB3NUR0V3dkMW5Qa3NPN1hzanBvVndpb2JFL0Q1UXc0WHYzUFUKbWR3'
    b'TTE3VEVoZ3Q0VlAzcXRZRUdIQnErRmZmeDJhSG1YejdpbVh2aFdUUDFQZmRDNmJQUG4vbWM1'
    b'ai85MWpOeDRsbVQ4di91RHlXdgp2WG44N3c1Zy85RGQzaVMvYzQzUkVhb1kycVl3UTNGbFRp'
    b'TGJlZHJJZFoyQnlQYW9qVlVKSnVEenlpNGxHcTY4Y01vWlR0Z2MySWZnCnlJZW9UYVhqRXFS'
    b'REpHMUhUY3luYk1qQ3FaMUU3bEIxVTNINnJYZXBKMDByTXFSQlQvekRlcnluZUZWem1VT2FV'
    b'SUxUZXpYVDBoUXQKbExrOVJrUkd5SXNTZnZ5b2lrblZ4YWU3Zk4zK1ZyU21XSlZnQWo2ZlVH'
    b'UzVvZFY3aGhQaWlSamdHRUg1aS9xSnBPMHRMeHhmN3FWeQpuSHZWQmUyNGdJbWlrSjI3dGNr'
    b'VHlWOWVGV0lmME5zZjRwZjF5amZmTUVJNlh3Z1NnajNsK1hXNVhacEt1TGVjUno4RlJ4VWNq'
    b'UkpGCmdkbk12Zmc3ZnBTaWpua1EzcWcyZHZTSjQyTktydy9DU1BjNlNzWm5keURCY1IvYVQ4'
    b'MnJvN3ZYTEozV0x0M1Q2d2RZWkZrbTRQT0sKd3dsRGxzUHV0SisyNGpZczZ4MjV3K2x3SlNE'
    b'bHUzcUlySzdwbjNTeDFqbThCYWF4bVA2SnA5SmYraEtYTVBHdlF5M29QMkV2NEdFaQoybTZv'
    b'cXBIYUM5eStYcjh0bUxhTlFmeWtKbGhZdTQ3ZnV6OXp6WFg4TGlQNTBJZnJObWxGcDdnM3ky'
    b'U05jY0k4NjQ0Q1ovZkJ2cUlzCi9jQ0lnU2REdkwyNnRPaDBUN3E4aWUxcDlubkJYQ2svTDFU'
    b'QjhNejZsdE1kWGJhejZWRENlR0pIbEFDQVFjc2YyMTQxc2RHVkZhSUYKNlhtVE5xRTREUUJV'
    b'R3pyUGJzOTg3UjdwMlQrTHI3NE9TU0xSQ00zM2pOUjV6a3l1MjJPcDZuYzVndGsxM2FQRzE4'
    b'TjIxSzlER3hLdwpjdFdWWkdCQS84Z2ovSjY5S1BCd0xTMjBJTy9rZE1yVDh5WnRKSVVaWjA1'
    b'bzlLU0QyV042TU5MQ3hyOGZISWduUjk1K29UOFNmNnVCCkNaaTF3T2NoTCswYlNMYzhrMjB6'
    b'bjZ4dFRYMnRUYWZaeG81d2pjd1JQZFYwbE9pb1pnRXhLWWh4QU1qUlpwTnJheGRmZmcyS3Fw'
    b'V1gKRVVxMTJocHU2dzdNbWpua3JuR3NKUTRKY01sYWdpY2lxQVdFMDVEZ1Rob0RjMXUzMDBT'
    b'S3hHSmFZWUdXNjlHbVRPUzI3ZFRLeWs1SQpKOEhCcG1vQ1QvUlVVd25KQU1vSVhlVURDY3Qz'
    b'L3VzdkUvSkhzRlJ0NjRpMkdDOWtsWUVKK1B3anJuTVZsbFJOcjh3KzZmZmVRTDgvCmVKcGRk'
    b'aFhRRlBmeC9tbno1cXovZU1lTWVYUFdJOFVQVjUzbWNtYStlcmRXWFMwOS9XZHV6MzdkL2Y4'
    b'aDM3QjRoQVg3YVE0VUgrKzQKWU42YzlSOXZuekYvMGliSTVDUjdHRWxubEc5L1hUUG94UmRm'
    b'RlQ3Wm9JRFNtdXFUMDBrUjRHZzZPMmJNTDk0R2JlUWI1N01xNTB6TgpPL1gzRGNsdUpGaGRZ'
    b'QUkrRHluZ3duSW11ZjVBNjhrSENEZmRrbG9iUDQzVmw5QjVjOVlER1B3WDVNUXVxOFZDS3l2'
    b'NURadUVOOTVTCkw1Nm42U1JseWZYZ3VKUEh3QVRIVXBnM2R6MWkvTEJoOGxDQzZvVXpBVWhQ'
    b'L1puNCsyZzhUajBlWmNIeDNSTHBxZW5NV1kvMjA0YjIKS0pRU0l6d3BVR1dnbnpBQk13R2Zq'
    b'N1JyenFrMXpyS2lFYnorWDMzKzFEMitDUUNVcCtDUkFmeDQyYmQrZHRudkFkQlpNYkxjUnJW'
    b'aApNbTVxRlpZdVMvL25veEFFNmNHZklUd0ErOGw5VjNwQmJOQys4ZVBsMy9yWnBiK25acFZP'
    b'U0pJOWhoT0cwNEQ0NUxPa3BWVysrUWErCnRwcGY5WkY4eDYwbnBhUE5pZ0ZRRmU3QlZkOTQ1'
    b'TExIYVZHYUZtWFFQTUxENnJNS2I1aFZkdXJ2Zi9pNCtYU3paUXdtNEhQY2tDWG4KNXVUWmJD'
    b'T01ERVdCRzNteFVJZU9lOUVGcDFydDdTT3JyU1RNazgzbTRmMWVBTFMyT3Yyclh3QVFubnN4'
    b'L2VoLzBKSVJ6TDlrcjRGNwp3d203VXQzU3gzMW9vMkdCTk9oT0dnTURrTysrQTZJQWY1LzAx'
    b'NWZTanoxeWFqcmNlak1WcUdiVGFscjgzUHQyQkFWMGk4QUl6bDVHCnZYN0VKOVhyZEt3aU1B'
    b'R2ZseEF0WXphTVBOWVZ1TlBNbW1ZSVdXRURjQWUyWU9PdzlmdDBCTnV2Y3RmcG82bkVlUEt1'
    b'L1dnNnJoTXkKRzU3VTRKcUo3S3pVRTc4Yk9aMStnYnpsRUlIYnNBMmJ6clNDWHhSR2ZpS0pa'
    b'K3VXbUlEUFQwU3E2UFVqQzFqa1RwN0FNNXY1STFmZgpmdHdtcEk5UVJkS1VvY3VYYmoyZzFQ'
    b'ZWROY2VnUHhhb3Vmek01K1N2M20vZTJuTFdwTExqR2VYdTI0OE55d1ZqVUUwNEtPVUJlSDI5'
    b'CnVzNlRKNDBFZnVRcFNZbGpBbVlDUGorUm9BakN5RzlZUE1VbDBXVFM1ZDk5SnpRTnNSaXNW'
    b'dkdEUjRucG9ETHpZVFNwV20zTmtVZGUKZVkyZTNZRVpXVURXcDdpelR4R2o5cmU1Qi9Mdlhv'
    b'eElCQ1lUN2VuVmIvaW1ObmU2WXJzVGlocnBEd2wvV0hHS1VFL3pFZ1R5cWZKagovRk13UjQ3'
    b'UEVSMVB5R2tXdm91bjhWOG1lL2ZwZi9BVHRQZHdHMlhocHo2eXRvM2Z2UFdmN01Dcm1XeTFM'
    b'VmR0RnBWLzNvOUMrdm12CitLM2J1WU5IdUZjSVdXcVVmdnVIb2VEeEkzU1ZUOU1ONFZrZFl5'
    b'M3dlZG9DbnpMOEM0VkN5V1NTNS9sY0xsckVxNHBLZzJtYTFoMzMKaUtaMUU3U2FLdDNQZnNZ'
    b'ZmJxQm1DM2VvUWIzMG90T01sdmRDMDBOZkRia2IzUHZnSGRDdUFTZVphUGk2ckE5cmRRY0pS'
    b'NUtDUTFZNQpLK21Ia3ZGcUZXOTBYeDRnZVFBZzd3Qy9EZW9ZaUJkQ0RnR3RJT1VRN0NOazh2'
    b'M3Y2TDk0RDBtblNDUktCUkZ1TjNXN0VZOE5IVlpsCko0bnJvUmoxRWtseW5SMGRITSs3M1c1'
    b'SmtzNHFiQVlUOERuL2NubVN5V1Q2K3ZvRzIyRktxY3ZsY2pxZEFINzN4U0dmNGt3bTAranQK'
    b'N1lqSUh4NEJBSzYxalVRU25MZUQydTFhWmJrNit3TCtnK1hhcUZFbko1M2FoOXhsTU9uUnZo'
    b'dWRHVmdER0oxQ3g4NUxyZjJYWjMzOApyditTVi8wUEtKeCtXRWRMbVNSdC9YN3hFL3RqbzE3'
    b'Mi94dDFiMFFramZidHNFUlExUUkramI1RHdLMGpQTUtXcmRUdElsNnZWbFJJCnE2cXdhemZY'
    b'M0FLQnV5U2ZXM0Nwb2RqbEtzZzkyVTBsRUFpazAybENDS1ZVa2tTUk5jQ2ZKeXd1OU9kRkFS'
    b'ZTVmWlN1ekNubDVucDYKZTNwS1NrcmVmZWVkM2J0M2hVTDlmL3pENC9NdnV1aitILzJvdHJa'
    b'Mjc5NDk2VmdFOFZCSGkvZmlTeS9pMnIzVTdWUnV1UUdnM0o3OQpYSnRYR3pkR0d6MXExU2Y3'
    b'RG9qRC9KeENUZkJHSU0rRUVJZVR3dmhWUkZMVmxpMFhXQ09QZXIvWHBGUnJKNjZlcCtDNjFh'
    b'SlY0Zm1qCkRZZnF4SGYzYVE0a3Z3NkxGYTVEQ014Q1Z4bytCZmJ4R05iaHYxVG5yNTAwbXQr'
    b'NlE3bHBpVFpqS3VmdEVGNTVYYm4rV3FKcGZxTkIKaklkM2J0dVFpRVZ6Y25JK2VQLzlkOTk3'
    b'ZCszYXRiTm5YN2g4K1RKZmIrK0JBd2NBMU5iVzZuUTZwQ0xoU0t3OW9xbHNRVDhiQTU4WApl'
    b'SVQ0dzVQbzJxOU4rTXFsRTE5NStaWDYrdnBBTUFnZ0dvdGFMZGI5Ky9hbDBtbFJGTXZLeXJ4'
    b'ZXI4dnBldi85OTR1S2h1WnkxUW5qCmxJdm1FbThIdjNvdFJBRU91M2JCOUpNemtBUEk2VVpG'
    b'QVlnWjVHcEljYVQzMUltTktxZjl0dmViTXFjLy9iQ1l2TnAvWTJNaVB3OWgKQUxCdlJIZzJo'
    b'REs0Y2xHcGc3cnoxQ3ZrVzI3UXlzdWtKNStGeTAwNERnNjdPbVVTQUo3bjVzNmI5K3FyZi9Q'
    b'Ny9Rc1dMblRZSGZuNQorUnpIelpoeGdhd29odzRlaU1XaUg3ei8vaU1QUDV5SlJaNjZlZEt5'
    b'R3ozWDVpVjRxckRxd1FSOExrTXZ6NDU4ZUh2VjRrbUYyN1pzCmVleVh2eHc3YnR6M3Z2dmRj'
    b'TGdmZ012cDZ1L3Z2K2ZMWCtZNUhzQ2t5Wk5mL09zTE5hTkdTVHBwK2ZKbHgzdXR5MWFKTDc2'
    b'aTNIS1QKY3NldC9OcDExSGlLeHlWcGd0b0V5UWZUT3BEWG9jaWlibStIME4yYzBDRzk1U3cz'
    b'S0FlMnFFS3ZuSEhHbjRNekJkb0EvVXNRZmVBNwp3STFrTGN0azlQLytJODNqa1c5YXJKVVc4'
    b'MXUyNCtqRTJJd1pNd3dHdzhvVksreDJPeUZFRWlVQVBNOTcyOXVycXFzdnZmU3lwdWFtCmdv'
    b'S0M1Y3VYclZtenBxb2c1L0ViSi8xNWdTVlBZQ3VUbUlEUFZXNHVpRDExeTlRZWI5dXJyNzAy'
    b'ZXN5WWdjaEFKREx3eTEvKzhsZS8KK2hVQXE4M3F6bkx6UEI4TUJWOTY4Y1hpNHFLS3lzcERo'
    b'dzdlZSsrM1pQbTRiNU42OGR6VU0wOG8xMXpKdjc4MC9kaWoxSEdLYlVtdQpSRnNPZlBPZzNJ'
    b'MllCSE8vSmpjSHpTWnF6Q0N5RVprbzBydWdiWUE2TUV5SHU2QnNSTWFQNkNjZ1B0VnVISEQ1'
    b'MFJHSHF4M0ptNUM2CkFoMTE4STYwMTVFa1pSNTlNUDN6aDBoTE84M0p6dHo3dGVFSGYvQ0RI'
    b'MWh0VmdDUmFLU25wK2ZwcDU1cWEyMDlkT2hRUlhrRmdFMGIKTjlYWEgvSzJ0MWRYVlFIWXNX'
    b'UEgxQkxueTljWDV6TU4vK3RnT3pQOHk2alJSOTYvYTRLaXlIdjM3dDI1WThlNDhlT1N5U1Fo'
    b'eEdndwptc3ptY2VQRytYdytqdU95czdONW5oODBhNlhUNlZRcTFkcmFtcGVYOTRzSEh2dmVs'
    b'Qk9qWVZBS1Fxd0dBMGZJOXc0a1AzQWQ3VXZMCisrQmFCcU9BUGlQU2hYQWQxSVdpTWpkT2t5'
    b'OURjaDhjZTJCUlFGTUkxNEpiQkFESmRtUzlDcjBPTVlLK1hIQXp3Q2ROMXRmak9oMzgKRHBp'
    b'dE1IVENJYUxaRE9udVk1bi9zSC8xTlNXbVUrOEhRSk92TjFsVmVlbml4UUJVVmVYNTQ0Wm1S'
    b'VkVPSFRwb01CZ05ldjJ0dDk3eQp4Uy9lUVFpNTdmYmI2K3Zydi9hMXJ5NWZ2a0tuMHkzZGNl'
    b'UXI2K1FUZ2c4dy9tbERLWHNGL3lxbTV4dlhyRm45OEVNUExsNnlwS3lzCjdKV1hYN254cHB0'
    b'cWEyc05Cb05PcCt2cjYrTTRUdE8wdnI0K1N1a1RIelhzakJqc09qN2J4SmU3REJWS1JFNXBs'
    b'WC8rS3dCcVYxQ1UKb1hOaVpJMEYzU0lKQ3dDQ2syNkY2MmhPbWhFdEJNWTZrREhnOTBMUk1y'
    b'eEFFemtRdTVDN0YrRkx1S1NiODc4dGlRbW5wNVZRSmFabQpJcnNGbW5leHBpdUJiUVhrN2VD'
    b'dlQvRThBakdZelloTlFXUTJtbDZCNjRTbENNRzJZT1hxTjRmdXB6U05DK0owaFlYelNZanlH'
    b'VG16CjlldGZlMmxEWTJ0L3BuMGdIWWlyNGFUNjAybTZtcUljQUM2WG0rTTRqdU9XTFYvUjJk'
    b'bTU5SU1QVnExYUJVcEZRZERwZEFBV1RpZzEKcnRxV2tCeXN6akFCbjBNY0NhWWV1ZXNLbDh2'
    b'WjNOeThZL3YyWC96eWw0U1FaRElaalVabFdjN0xPMkd0ckdyc08raVRrQVRDUUJjQQplV3ov'
    b'a0hOaStJYTBSVXQrckI4N2ExWjloaXJXWjA4SkFLMnJ3TURGTUU0RWNJVWh2aStaN0JRbGsz'
    b'R2oyYVNONS9xbkZHeHVJWVp3CmtTNVBpWDVyMUhNQU5uV2IzeTNOSStxVHBYemFsQ1QvYWEy'
    b'dGFQMTFrMXNpR3JrNlRkOHhWQUFBYmtKR3drakJuc00zWnl4cWZLMSsKN096NWh4VTFiWDdP'
    b'RHVBWFcyT2hmaFhnZ2FFaHV0MWh6TS9QSDk0VTkvYjI2dlg2RzI2Nk9STHV0OXBzeHhycWZT'
    b'M2RTWkdGeUdKago0SE9NYlVHeHJUZmc4ZVROdVhET2d3ODl2S0c1LzZIMzloVVVGQlFVRkxq'
    b'ZDdwTk81c25KYjE0N1doWWh5WnpTU2ZOcXRpUjFVa2d5Cmo1eFo5cEJiNWNiVXJHdnEyem1C'
    b'S0U0a2s4a3RHZE02MmNscjZ0WUIyNHVwaXZvTzNoZkN5NzY4ZGZHc3BNYjNxUHhmdFZ5RWs2'
    b'MjIKQkJkSTNOYmR1bDI1ZUNoQlV5Rk1PU05tMWNkYk1wSTRmL1NXbUtRUDY0NEtqenZaUDRN'
    b'NzBlZFpFSVRCWnovU0ZmalQ3bGdnbXI1Kwo4ZUxCUXl1YUJpaGg3aDJzQlQ3SGtIbmQ4b1Ar'
    b'ZStiVjdOaTFaL1dCamdIZWxtMDY3ZllGd2lrVmVNaGR1REJUVXVnakFFMXk5dUorCm14WkdW'
    b'Zzc2eE5PTkY4UFVQVHR0dlc3VmtWY25ZRTFCWVc3WS83dTZGbEZBM1pIUTltNTlTYTNLRVh5'
    b'bHNPT05YY0VITGdyeGxHNXMKOGYwcU9XNGlGMWdZak5ic0ZQKzZZTlJabnFvc1hWSHNCd1ZO'
    b'Y283U0FKRUpuTG53alhEaTZXN1JaRExrV05RTnpmNlNzVE1BVUVyWApOTWNBTzZzd1RNRG5I'
    b'S3RhWXJkZWtPbU9hMSs4N0FJQTc2N2ZmYm96YlNTdFZ6TXAvcFFwb2c0SjJVcGZZN1k3eitj'
    b'NzVNNHE3a1BmCldUWXhPV2pOL1dhRGJMK3M1OUc1M2JFa2YvQTV0NnRKTjhWQWk2MUtYMTBX'
    b'QlVTVmZuVy9rTjdwRVZOazlOeUJIWXUzQXVqNnE4M24KK2hTN3M3VHBhSzRjUEpUajh2Z0M5'
    b'VzYzSjRpUUFKenNEdTFCbU9kTUl5WWdFdkxEeThjQWlNYml5N1ljY05nc0RXa3JNMkF4QVor'
    b'TAo3T3JYdmJKODB6M1h6aC84OHd3NytOVm02emJPTEhwblQrZVRlMUlCZXJLTUtUL1lLZjFV'
    b'aTNpZUxibHhZZFYzd3YyYUt3bXpRUzBVCjFjSStIUUJyVGlLdnJCZEFQQW5WVyt3QUQ4QXJV'
    b'Z0NxaGw1VmZydHkvS2Q4TG8wZmZKd1I3bWVtTGZMVmFWbXphcWUyZG5hUGVPMngKdFF3V3N5'
    b'blBhZmo3cms0UXRqTTRFL0E1aWNKTGJiSGp0Wnc3dllJSlFiYlRkczk4VzdCMytaOTZqdTlw'
    b'UU4weU9KcFY3V3ZyS2l5cAo2VUNHd0tHZy8wekYxSTJ5VlhuVHIvbGdmMnFwUGx5VTdqRmtN'
    b'R0dBOXZOK1JaTzNTUUJTR1VwdHFhaWRjbmJOMThSelA4OFMyblJjCm5mYVMvZWF6UDFLMkRD'
    b'Q3IydGZlblY5YzA0VWtCNnQ2TEVST2RyejVUM2ZPY2pyc2lxSkkvTWpEMnVHaEM2cUtDdGE4'
    b'VVE4REV6QXoKWXAyckxBODZ0alYyRGFuMDlLY05HckdhdlYyRnpoUDdzUVVLS0FId25jM2ZH'
    b'U29majRKaGtlaEc1SS90dDhWbDBaVVI4NXZNbmh5YQo5Ky9CL0ovN3M2NktsdjIrb096M0Ji'
    b'VlBGcHEvMDVmL2M3L24rNEhjaks3Z29NV1dFdjRpWEpMa3p0NkZwZ1V5VkFMZ3ZrM2ZBMEJF'
    b'ClNuT1ArNXhVNU9lczNOVUFRRlZWU1JxNXF5K0pncXFxQUJSRmZlekRBNTJHY2xaSldBdDg3'
    b'dEtuR201K3IyOXVUdStNWWpNZlQ1NmgKQlc1cTd3akdsUXZIVldDZkg3ekFjVnFyeTRrT2NB'
    b'L2s4Q2JsZ2RUYlBmVmoxTGlnSlFTNHdCSDFUSm5TdkFjTHJuL0krTHF4bThqYQptYVFlMTdT'
    b'TzNPU3J4V05lenpwTDgwc0YydXB5b3RYSi9UU0hONm9QcE43dXJoOUxFN3dhRjdyc0NZNnFB'
    b'TEtNd3BKNTQxOWR1ZkdxCm1SUEUwNFF1ME91a2YyeXViNHVTbGMyeGhqU2JQV0lDUHVkSkVk'
    b'MXlQNWI3dGVzS0RMZWY1cHpvd01DQTFUS3R0bFJWVlpQU0ZPZWQKdVZubW5HZmZQdDUxN1hs'
    b'R0UzSzByS3NILzh4LzZNVXpaN295NjhyRE9hTisvWVhmdXBjbXV1N041VzIwVjhpUXl3T1NX'
    b'VXNxTlBDSwpIV21CN3hmNlpxVi9PUFdPOVltNVozMkswVFBINUh6cG9XTnl6dlkrb2VUT2gx'
    b'UUxJRlJmYi9qRENnQXVrOEJ4M0EyWFhQRGhsbjNUCkt2Sk8xd0ovZDMwYWtwRnRqOFFFZko0'
    b'eFlpd0tTcW5YNjUwN1pZemRhZ1hBODd4ZGQzemJJbjcvQWFUU2FrRSs5KzFWL0Z4Qm1XYm4K'
    b'RHZYSXQ5endhYkx6YXVVMzdmNnZMMGwvdmxIY1ZkTWlhRGtrNytaZUFCa1p4bmRkU1FQOXBE'
    b'VDNGN2lqTzFIeEdlckhzcFhxckJsMAo1eDd4dVgrUU8vcHBzSjVXbEIrTEkyL1RjUUFJSVZm'
    b'TUdOL1oyUlVLaFFaWE93OUg1UGtSSS9JeG1JRFBkY2dwbytCZ01KaUl4NHVLCmlvYUgyckVi'
    b'K0s2amZXMnFhdEtUejVCNTh6bWREYXZqZkhTSHZQaDZmR3EvWVlWSVQyWjk3Y2tzMUFRMlRG'
    b'VVBxUnR0UEpSUTJocWMKaFMydXl5ai9tWXViK0gzaXIzNUhpNHFKMzBLMkdVajhZR2JSRldn'
    b'ZEN1QnUxeDgzWEJVVTVNZWlVYSszM2VQSkUwVngrR2lCRUtaZwpKdUR6bkhRNjdmUDFPcDB1'
    b'bDhzMS9QZnU0RUIzVWp4bTg5SW1qRlBIanBIKzhqeVNTZVdxSzZoT1R6VDFuNmo5aDkyekRt'
    b'TVdqc1d4CnpQNG5iMXUrNVNiZHZkOFZWcTRHb0k0WnplOC9pR0ZqN0liQUNYc3VtQzBXczhY'
    b'UzA5TUR3T1B4RE5NdmkycjNlY0dzMEo5bkMwd0EKUUZFVXI3ZDlZR0NncUtqWWJEN0JOVEtS'
    b'eXR6N2JsTS9qczhEaTg4K3p6ZTNxcFBxdExKU2ZzY3ViZW9rZnRPVy84RkgwTjMzZmNMeAo2'
    b'clNwc0ZpRUxWdlZDMmZ4VzdjZE8vcHFxL2owNm4wblhlTHhlTEt5c3J6ZWRyL2ZQeVJnNXJi'
    b'Qld1RHpFa283T3pwNFFTZ3FHbUgzCit1QkE5TDYzR3JiMm4rREFwTnh3dlh6M0Y3bWR1NlVu'
    b'bmlLaGZuN3BDblh1V2JmMm8wanZCYkZBR3BxaE1XalJTZVpkZFk3R0xGMlkKbzBwSXNSOFlL'
    b'Tjh5VUJjaFIwUE9LZ1BRR3NHVlF6akxsR3o2cC9mRDdSTC85am80d3EvOWhCWVVLQmZPT3Vi'
    b'M1NZbndxOTBaazNUbwpsZ3RyVDZoVmdsQlVWSnhLcFRxOFhrRVVXQSthQ2ZqOFk3d3A4bTgx'
    b'am9MQ3doR1BkdmI2NzNpcjdYRFNNa3lGQUVBdEZ2NXdnL0RpCksxcDFKWW5HSUFqcXhmTnc2'
    b'anl3N0lQd0prUWJFak9RYUlGeko3SU02TGphS0RwdnpYMnpTdGV3SzFtM3NtZGFJT09RcVpp'
    b'dEM0MjMKTmZ5bytQR2c3UDVMenhkQ3lJWDBMa3c5Nk53TzNTMlExa05xUTd3V3Vua2ozS2pi'
    b'eGUzWUpiNzhxbnpiemR5T1hXcGxoVlpiZy9yNgo0d3JucEI5dlUxdjltKzYvZGhwL29pK0hY'
    b'cTh2TENxS3hXSmZHY08vZkNRUmhwSFZDaWJnODRBOFB2YWRxZGJGMDZkdzNNZ2pGSyszCmZk'
    b'bkJ3SEQxbm5pNFM3bitHanB1TFA3d0ZDeW1rZTFoaWcrWktHd20yRDdFUUQ2aVV5RDBXblhi'
    b'ZjE2MjllMmVCVS8zM2pIVWZSY0EKSUtMbE52WFgvcVAvMmduUzlrZktmL1dueGtzUE9rUG9u'
    b'WUtNQnR2ZklCb1JqeUhUaVJQM01PSUc5MERMWlBnREI5T1AvSlJhN1h4VgpCU1J4c0ZjODNM'
    b'Q3NFZjZGUm5LejErdDBPT3gyKzBsUFl6YWJmM0RWcE5zQzRkK3NhWDZ6UTZleWRVaE13T2N5'
    b'Qzl6Um55MnF5WFdPClBPY1pqVWFEd1dCUlVSR2FrcWZicjBCZE1COEFTU1RVNlZQVXVYT090'
    b'czhubmp6Z2grNHlLT09SNkVUQk80ak9zc2ZWVXZmNlg3UisKbzBzck9aM05lazlteWcrYks3'
    b'N2cvRVZickN3dXpVZldtNUJMZ1lXUXV4SGJDVjBVa21XWWdDa0FTSkw4eFZzQmtPWVcrYzdi'
    b'MUprWApBT0E1anFNbmJCTk1RSXNLQzJPeFdIdDcrMGsyOXFHQnNkdis2eTlNdW5oWDg0L1do'
    b'UU1hYTRxWmdNOUpMcytPL2ZHR2lhSTR3bHNkCnRFS2JUT2FTa2hLTXRNNmgyeGZ6ejczazVP'
    b'TDUyV01tamdmUVgza0ZxbzZsdFFQVnUyQVM0ZCtQOUhTb0xvaDd4cGpXN2VyUFQyaFoKWnk3'
    b'U0tCeC82NXd2NW15WFFvY3k1WjFvdWd6OFNoVFV3NlNodlFlNDU5aVpUUjl0OTcvNjNFbVhT'
    b'NFF6RUU3SnBGT2pyajFSd0FCZwp0OXR0Tmx0SGgxZVNkTG01dWFmbWZ1bkU4bHhINzgzLzZJ'
    b'b1FwbUVtNEhPUEM4dHNwNnBYbHVYZW5oNUpweHZSbERVTXZpU1ZBUUJKCm94S2xsdzdBcUpH'
    b'M0hVUWxTSEM1eWZDdzNxMExCelM0TGdDbmgyVTEwRytnN1JzMUE4Mk9JL0EzNE80elRSdW50'
    b'eVFLOXhCQkx4bmYKUkZJSHgxS2t4cUh6Y2d3c2c5V05ZVGJ5c3ZqQTBQM1lWRzFzRWwwQzF6'
    b'b1VqMUtTMDdKb09FbkFnNjB1SWFTb3FEaVR5WFI0dlRxOQpQanY3NVBtckNhVzVGWmFPWFRG'
    b'V1daaUF6ejA2QjA3WXN5K2VTUFlIQTRJa0ZSYWR2SVh2cVMyd2RuUzhUQXN6NFp2U1NzRFVs'
    b'Y29xCitscVhmUnZsMWxvOWlXRUNWa1RrbFVMb1JjYUR2cWtvWDYxNXc1dzlXKzBzZzdjSDdu'
    b'ZmdDVUFMSXo0YjBuUUFrQWNndkFBalFhSUkKSFRHRXNqaVBaTlEzcDlNeTBpN0krVEExdzFL'
    b'QTBBbXRZbG5VRDRCZUZvWlIyMU5hT0NIVVJtZEd5ZXR1eUNTaWFVbUQvYVF1OVBCdQpzeVJK'
    b'aFVWRjZYUzZzNk9ERS9nOHp3bGVscDJSTkRnenF5My9FdGc4OEwrU2pvR2h3T1VaV1g1bTdh'
    b'SGZMTjFiVUZpWW01UHphYTVOCmNrZU5TREcrVzJkelNlRnhub1p1YVhBWkw2cWlQY08rdWwz'
    b'UXRVSU1RZ3pBc1FrSldURkxhbWdxeEl0UmJVWldHdkV5QkZSby9VY0YKSDBVOGc2Z2RNS0Yy'
    b'QUs2WnFySTRSbmlrRlFoaG1BOUJUc0xRQW12cnNSeDA4ZERZOUFDQXZpenpJV05ob2FzYkRt'
    b'MmxPQWt5QWRDcQphU2xuNFVrQ1B2V0pkRHBkUVdHaDArRzg4OWwxMjQrdTBPcnM5ZmRScGw3'
    b'V0FwK1RlQWNVQVBYdFBROStVTDhwNWJtdHpIUzZNMC90CjQ4YUZvKzZIODJLajdCSG9PY3Fo'
    b'Vm16QmFCMVdXK2NQZERuQ1hmMzJmQUFnNDlGNEVJVlhRWFJucFE0SGRlK292SXB3azhuV3JC'
    b'ZGkKRjV0ejlPcUJBREtJcjV4Y3ZKSG50R0NVMjk2aEZEaXBZREhzQzdqcXM1ZlQ3cXVWTEFs'
    b'cTJoWXVHREQvRzBTZzRTMVlTNDR0TjVqYQpjOEFDUUVkZFkzcmR1bTVxMXFqRVgxeTJnYTdQ'
    b'SmszNlRrRlA5ZFpUK2hTbjJZZFJGRGYwaVd2ZkRkeGIxZkgxeXljMTk4VXByMk5WCmhiWEE1'
    b'MllMbk43VDFCR1B4eThkbllNek9qQ2ZXdHNIN0FXdGcwNlQzWUpDaFRRVnFWbUxSMHpFSndJ'
    b'd2djN3FQdXJ6Sk9oUmNpdEUKTjRCSjJXMVhSVnM1VUtIU3A3YzA1ZEhEQitWTjcyVUNTMHN0'
    b'bXozbWl3cDJYRnV4bzBQd2J4cVY5YTVKMlJEYjdqUitvdkdaYlBQVApOS01VQ1psTHM0NDZZ'
    b'UmRjRGN1RVl6ZXpzSGMvQUdRSUNEUUowR3VhRWJBcmlQSUFnaU9GMmp1ZGdBa2hCRFJMek53'
    b'eGYreWJhM2UwCjlyR283a3pBNXlwQnp0clUwajY1dG1MSjFES2JGajJEQytHcFI1UzhNU3VP'
    b'TmsxVUpWVGpvQktxSGoveHFxN2R4MmVldUtIbWV2bkEKcFF2M2FiZDdlNjNkb1hBVVBRYjdq'
    b'L0lhM3FuZU91WFFnZHprUUxDZmR2aGdRN3FvdnZrUDlxMHZqdHJyRkdTcWF2MXBmcnJmOTlO'
    b'MQpiYS9IYnpsbVFzUFJRSm02Vk9RS2Z3TUFVQkNaYk5rN0VjRGd2eVJEQVBRWWJDZmYvZWw5'
    b'clFZRmZIbVozbTR4M2JSZ3hvNkdWbFpQCldCZjZISVZ5NHVhUTdqcE5NeGtOQlVaNmhwM3BS'
    b'OUMySld1UFpFSW1RN01WSVN1VmlSdUNLYXU3UEVRRHBzRnpydzE3bjJ6YnRxdGsKMnNsOVZJ'
    b'dnoxeHNIYmxqU1dEL2V6QVVWOVpEQkY5ZmRid29lR1FpNnpKd0dYT3NLVEd5UDJ2Y0t2UW5I'
    b'a3BMNHpMd0RrNnFqanBWUwpLbVU3OWlFWXpoVk5ueFNwUjhQV2NYVEc3RzBBTHBpOWRmRERv'
    b'd0xkSnZmWkgrZkVscm5JTGdFNDNPSGZuc2xqOVlTMXdPY3ViM1NaCkgzMXZMNEM0VE0vZ3hV'
    b'L29DSWVhemRrQVVKQUJzS2x4MHQ5M1g0YkJvRGFEZzJTZXYwTTlmT3BINFIzUHRJNkNlTFpa'
    b'dWFtazU0WkoKZmVPQzVLS1Y3Z3Zmemwyd3gxcFRwdGFXcVdNcjVNdFd1aTVha1hYSmV2dW9W'
    b'UEwyVWY0eG5pU0FYUjczcWZkZ1RnUnVpZTRmK2g0VgpwMmxoQnNEOXk3NnRhaHdBT2p1Mk81'
    b'UHVMSnAwMWc3RlNlMXpQSzMwaENKM3Y5M2VyYkFaWU5ZQ245dThlSVRVYmR6VExwdk9kTkpJ'
    b'ClZiN0pXZElmUE94NFBJZTY1QXRKNzNRYTRKWVdrcERnYzloakMrWkxWeTI2cXJUa3dNUFBQ'
    b'VzJaTmZ5cTVhWXJ2djdOZC9HV1NIcEUKV3BxT24zR0tOWjVFMTNZZGFaTTZGZlgzMVRlZDJr'
    b'VjQyTlUrNFpWbmp5eGZJU3hkVVZCL1FQaUxHMW5LMkk1ZXNzYktoUWxaYTNtZgo1NE5sTXo3'
    b'bEFIaW9sU0RZM0pHSXllM3RNck0vTXdHZjg2UTUzYTgyZUtsUUJDaWZvUXNOUkVZdi9HM0wr'
    b'b2UxQk9rVERkQjB5SFNWClZpU3VYK0MrN2hyUDBYV0kzN2pyc20wdjdOcHRyRHcrZU9aMHZ6'
    b'NTB5MjhHWGlqY2FnRndhR2F3NHdHdjFzLzMxUXZxQTFrQU5DQ3kKcUM5U3JISjJsYjV1TC9y'
    b'QUNtRGpWRnVqYTl4Sk4zQk5lTnVWWDdwVzFPbnlyNzRLVjEvVnRXZXZzblNaL2YyUGI0bHZ3'
    b'OGFoZFV2MQoxcnhQK1RqSDBDZzJoZ3dkQVQ5NEQ2c2VUTURuQWExQ0VRRDZXWmZSU2NiTnRq'
    b'ejBOOFVFd1Q5OVN1Ykt5d3ZuekhZU0FrRHNlcEdtCm8wckpiZmFDL045ZTBuUHRxcjUrWTlh'
    b'eDY5WWtMdDVDVnVZaHlnTVdBL0pxRkVDQml1STFRNzdON2JjSEN5bzBBTjBTQVhBNFgvMXgK'
    b'M25kUHlydzYwdlRBRFpNTmc0RitJdTlCS01xZU1BRVR4a2UvZEZmVGUrOUx5MWNWZFhidnpx'
    b'UVBqWi85NmZvVEoraGJJM3diVXk4VAo4SGxtMDZMa3pLYWRVOWxmT2VjMVE4NmNlNytlbTU4'
    b'UGdEdlN6QjA0cU15Y2hRYzJpL1lXZXM5RS9xME41ZmYvK3d1ZDc5MXltSThlCkQ3Qk12amI2'
    b'NS9WamYzTzdmb3UvaGRmZU4zSjJyYmVkbzFMYUxKQ1lxUG9hQkxSeEpDTDBPRko3RnRudngv'
    b'ZkM0Z2xPamtXUjlxZm0KT3p5U1RtdHNJaFlMLytPbmNIazJyZndLMXhPeFhMckFjdmVkNmgy'
    b'M042NWMvZktUei9WVXpmdE1MVEJsaTRHWmdNOVhBWCsySVRBQQp5TVZUMWpYdXZ1cm9Obi9V'
    b'YWhFK1dFWkNZWjZBYk1ud0ZmdVVheFlCbUhqOVZhKzg4K0dkKzlJQjAxQ3pwaEh4OS9TSGU4'
    b'amErNUl2CkZiOG1BVUJPSXUvNUxnQTJEYm83Q3p5eUZERElhMmZXL0ZiM2JZV2NZSHdlTTNE'
    b'azZZVlpSVE5uWU0zSHVuZmZreTlaU0xRQzhwNHEKak5zeW1CMEFudWVsU1hWdE9SV2Y2WEVH'
    b'QlV6WlRpcE13T2RwRS94UFhMU0NyN3B4N2RySjgrWUJvQzZuY3RrQzhlbm5TRFNxVHBtawp1'
    b'VndrTk9RZ1dYZk41Vy9ZMW4zcnZlMzdDNlljdTNaZFl0NkcwcGszR2w2K1BIaEF6TWlCN2l3'
    b'QnFqOXB5UlJKTDduSy81eDlmZEJ3CmtsYzIvVUxmK3Z1L3ZOQlpXZ0pBdldndXQyR3o5THZI'
    b'U1R5bVhITVZTU1poUEc0MGZ2bnhQMzVjZGRObmZ3ZE13RXpBNTZsK3p6UTcKZWxwdEQ1VFBm'
    b'ZWFGUHc0S1dGaTZqTit3U2IxZ092SDd1UVAxeXFVTHVNTU42cXdaQUZSRk1Tejk4TjB0VzM5'
    b'VzJ2UzNVWmNsamZiQgp5MVVpdmV5NTgrWEJodmxZK0txSkkyU1UxZC81N2IzL3VEbmFFcnlp'
    b'RnFVbEFNUy8vSlZ2YktLVnBRaUZpYmREdWZVR2J1Tm1iZkYxCkFPb1BIdGpVSjhMQi8xTUNa'
    b'bnhlOEpoeEczc0xueFBqN05yRm8wWmV5YkMvSTdpNjg3UVZ1MDNNc2U5NWY4SUZNN1NLQ3ZY'
    b'U1MyaFIKZ2ZqaGNtcXpjTjA5MnFRNnJhSWNnUGZSWDlTc1dhY0hMdWx2WDlTMk1abUtOMWx5'
    b'RmNud2FXNHNQOUQwalQxL2YyTC9QMmJIL1RwRgpwVnUyQld1cXpmbDVOQ2RIdmZGNnJiU1Vh'
    b'MnJtNmcrVFJJSldWMnZsWlpUUzN6LzgyTktLVzArWG9GRkxmbVZXMFlpSE5FMzc0OFl1ClZU'
    b'Q3crc0JhNFBNSnZaWndhckhYMTJ3YnVabU5Kdk41WTVjNjhyeW80aXgrWmQrRytVMU5SUlVW'
    b'cEw1QmZPRmxMU2NYSmdQWDNaT2UKZXlHQTlqOCtPZXJEbFFDMHNVa2kwTXJkZVB6SXFnZWEx'
    b'cTV3bG42VU8rcWdJNmZGUFZvVDljUFQxTVg4WXlNdDR3TWRjN3NQelkvMgpEQjZqZFhGa09N'
    b'ZEJxQS8vclArLy90TlJWVW02dXNVWFhxWkZoVGgwV0NzclV4WmNCT0RscDU1ZWFwMXpob2Vk'
    b'WkV1ZTdrbEJ0U20yCitJYVVnMVdKendPQysxYXp0L0I1OE9OUnNTcXJjb1lUVXB6eDI1dTBK'
    b'TkdmN29RNU8zLzczUE4vTUJ4cDRzSUR5dlNwMGhOUEl4eVcKZi9MRDl0ZGVML3ZqTTJKNWlr'
    b'NkpoU3ltRkJFOUEySHVrSUhzTXdKb0w4aHp2UFpTYjMxOTBoOUt5WEltbnRLYjlEcWR6cFRy'
    b'enFtdQpEbjd0M3VJOSt3SFE4WEd0TnQxcGNkbTRtRFdTd2haemI3cUUvTzdYcms4MndxaFhK'
    b'MDhXWDNpUjZuVHk5Nyt6ZTl1MlgveGx4ZWJLCjYwOTNueGRueGUrbzVoUTVmZHB1bnFqNzR3'
    b'RnRTOWpFYWdWcmdjK1RrUWxWakRSZVVWUjZobk82QW1HakVrdUtweFh3dXJIM1BIVGYKRDMv'
    b'K3A5OE9ocDlTSnRWcE0yZjByVmxiL09SeklxVlFzYmF3ZGxya0NFKzBqL05xNXpjZFhTU1E3'
    b'eEVFb1dEczJLRS9WVC80WVRORwpubHpzMlE4QUp2cHhUbTFkdWtXaXlzZEZOZk0vN3Nycjd1'
    b'bjk0VThpai8rWDBlVkVmMWdySzFPdXZjcm44ejM3OU44MjEzNzVEQTlpClN2Y1g1bFR5M0ds'
    b'SC9MS2lXVEpOQUJNd0UvQjVRb0VRdmUyS3VXYytwNmlvZUdiRDd2ZTZUMytHWkhyTmVhbnov'
    b'cDkrNytjUEE5Qm0KWGRDM2FiUGpaNDlCbGc4cmN2WEU1TnphTGVnVGpEeWRhL2ZSc0lYc01B'
    b'SkFYdDZnN1FqSkpDU2Q5UDZqS09QbG1nY1FWbWhPdHBwNwpkRXcrTGpsMzdCWkVPS0tRT1Zu'
    b'YmFKMkRkRXU1emExdFAzcEErTjJ2SklkZHVma0xrVWprc1I4LzhuN3QxODc4SU5kTkt5OHRL'
    b'VG56Ck9WZFBWbGQ5SXJPS3dRVDhmd3ZaVWZSMGI1eDgvOGZxNWFOZTJyOEduUEsyVVhUR1lq'
    b'YU9JeGxRQ21RcGxBTVVndVRRdWhUVmt3dEEKZk8wTm1wR1ZNUk80ZjhSZzVJWEpiOVBpSW1Y'
    b'aEpmUm9yRG1hNEFEQXJWQ0ZnQnkzbUdmdjMvKzdSKzdiUDZ0S1U3WDRxdm90VmQ4Qwptd1Jp'
    b'QXY0L3hXakJmMk1GZldQWjJyT2VPY09HS2RhelRjelV1RDlvRUxlMmZnUXpYZFJsU280clRx'
    b'LzZ5TVB6U0hQaE5oY2hWS2RQCmgvb2RCYW1oUlF6VWt3dEF1WHFSN2l2MzhwdTJrSjVlYmZ4'
    b'WTBoZVFyNzhPZ0hZc1dHU0tlT3VMY3oyK1dOZ3Npckl0eVFGSUV0dzYKUCt2akNVQ2lFUUNa'
    b'S1Z5YjNsem5yajN6RGZvNzFUZTYyczk4amtyeDlhellFMzBWckhvd0FaL3JIRlN5ZjNMNFg1'
    b'Ulc1Z0FoWGxyUwpEVjdNYjFhV0pOM0N1blZlUFRsaWx5bzF2cVRLTjNoV1htRU1qUTRNK243'
    b'bDV3RWdiVjR0SzB2WXVJbG11V2hWQlRVYStjMWIxU3N1Ck5aV1Z4QWd4VXdxZ3FLNFZnRE0z'
    b'QVFCcnN3QzhVYVQvZUlJYmdLa3BIZmVZcVVsK0s5YjhWdUFVK3pQVmpxMytaL3pQd29yaEhF'
    b'YloKZ05MVkMwc3lldkRTZ0g2Vy9kS3QyK29mbWwvMDFTc0xObktLdmk0S1lQUEJpY3QzelFH'
    b'Z1hSQUgwS3VUM0pXVkFMakREZW9WQzlPUAovMXFkTkluLys5dlVZQ0NxQXNDZWxkWHZ0QVBB'
    b'ekRpQXBkdm43V3dZQzRET2pBSFlsNlVEd0lXVk9QOWQrS1lDZ0MyQ1RQZ0U2WWJmCmdQMjMw'
    b'RDhMWlNQWXJvT3NCV2FNVFBRd3luWWFNNWloNVI3UUIvaUV2YnMxMmxKbDNDY1h6VjIyNjFz'
    b'SnpiWE1Sb09DdlYvVHlTa1MKdHBEZEpnQ3lKM2R3YjE3bHVxc0JpRTg4UlFJaGtraVFWRnFk'
    b'T2JTSWwrYm1JdGhQWG5aaVhNTG1VM1dTUURxdDNCYnoreGw1RmN3QQpORW1BbG9SbUF3QWRv'
    b'QTBBOXFHN0loVG1BcWgrWk1lUnRSMnRFUWlYc2JKaUFtWU10MXo1WUY0T2ZTZjBwZ1RvRzdT'
    b'cGs0c1JOUjNUCkhRcG5UVkxKckJXWEw3NTR4MnVYSGRoNS8zN2RHQklCQUF3dExhUjV4NWZz'
    b'aWMvOGhkdDdRTGxoTWJKYy9JY3I1RnR2UEM3Z2cvVmsKdTRsc044MUJKNERWR2N2ekZzK1cy'
    b'WXZET1Zhbzc4TUk4SjlBSkFBUTRTQWVXd0NzZ3I2TC9BNEVESUFDQXBRZVJxc053Z1dzMEpp'
    b'QQpHWVBxYllWN0diUUJwRFhJS2lUK0lBa0FvTm5wb00yQzNnNW9MMEdkM1RIOTltY20zN0I4'
    b'MjkrbTl4NjRJelV3OWVoMkVKcm51T2VtCnN1UTZldWZ0cEt1TCsrdExxVWQvZXV4M0xYZG9X'
    b'amlxYVg5VnRMV093ajNUcmdnWFRSNDYzSk9IZ200VU5hSTNBWmdROTRBWGdjR0YKR2U4aHV3'
    b'c2RWNExiamRacVpNb2grS0EyczByRUJNd1lWTzkrV05jZ0dZT09SNVlKc25iQzRMTS9BYUVF'
    b'aVhFd0ZBS0FvUE5PbWViTgpUbnpZR2hxMU4xN2RuN3dnRWF0MU9ZOHBtTnJ0QUdoUllmSzVw'
    b'eUVNMmJvMVRXdm04THFpTmxnOGgxeWxMWFdMTmYxUmQwNDFEUzBCClpSYkNyOE5Pa0tWSDV3'
    b'QmlZMkFFTWo0WTF5SzdGKzJ6SUJRaGxvUjFEQXdBQ2lCT1l1WDJQd2h6cFR4bkdHaUEwQSt0'
    b'QWJsQnhFVGsKeXRBZE5USEtLdG9KdE11Z0gzWDgvTXd5bERSQ09HNUc0dnZTNWZ2bE1zMlla'
    b'N1JaVFVaSjREbWU1emlPQXNsWVBLMnFrWFNpS3gxcApjcVk3OWZNaGxJTnZoRndKWG9hcWdV'
    b'OUJwckFjZ2hKRlRnQVpGVFk5VkEwQk96UTc3QjBRQU84TWlGTlpRVEVCTTBac2Z1TklMSVBO'
    b'CmdVZ2UxRTh3L21qSWRRclVWOE13RC93d3AwdGxHNG8yUXBXZys2ZmNtMUlhUktEWGpQUVk1'
    b'T3hFUnlFS094QVRrWjBDQVNnUVRjR1gKaHNNQmx3WU5DRGdRblFXcG5KVVM2MEl6VG9Ob2d1'
    b'MTZBTEJTMENDd1k5Z2gvUW5xbFp0UXNCa0NnU0JENWlCcW56a3ZQUWNBK1ltaApGY00xYlFC'
    b'Z1VvOTkxYUhUZzUrSHhGVDB0WU1Yb2MrSHhFcUlDWmp4S2J0RmZHVDRYeWpZaTg0a1VBSXVC'
    b'OUpXd1ZxdjZJNzZiNGthCktEMUxWTWl6a2xFaERYTUk4eW5vWHdSak5RQ1lTbGg1TUFFelBx'
    b'dUVLZExhOFRHd0FTaHBnTkNJUGhuWklra3F3REM5bmFwZWxZSUEKM0dkUmRYOFNEZ1BpR1FS'
    b'eW9TeUFNWmNWd25rQjg4UTZKOG5rb1AxRXQyR1JnQUFXQUpBTlo5dmRqeWNJSjRlVVBFZ3NE'
    b'UUFhaFVhUgpQR1hZTFBHdzZ1RlBvSzhLNnRVUW1YcVpnQm4vUC9DVEljeEQ5SlRTTVJ5Tkpq'
    b'bTQ3MUxpcUJTVE1wUVRSOEptSFdMcElkMGVVM0kwCkRZNUEwWTVmT0Z6ejJVYklZeUhZMk90'
    b'bkFtYjgvdzl1TE9nYmYycGNTM3VTNS9xVGlLUVFUU09hUmtKRGR3NEd5dUZYVG01VUZRMHEK'
    b'aGFJaG1rWXNBNVhDSkExSk41WkdiL1RrSE5NRWhHMTl3Z1RNK0plMXd6UFI0VUhuOFZBMWhi'
    b'RDhySFpKYmtTRVJRZXJEamxtK0xPUgpMa2VxRlAyTEVEeHgwMjI3QVg2TDBLWENva08rRlRF'
    b'WkFRMWVGUVlSMldia1dnQWdvcUxQZ3Q1OGRJNUIxMFdRY3RoYlA4K3NKV3dlCitKeEdreEhi'
    b'REJPRi9TQWNHYlBYRk9mS0Y5aDBlNVRkUGlrQjA3QzVIWTNDenlIbmhCak16cDZLU1JiTG1z'
    b'QUJyZVRFUG5OWWowZ1YKa2lXUWlzQXpRK2I1M0ZGanIrRGM3aUdKc0Y0SUFKR1o2UFBHdExB'
    b'ZzFsQWFDL3BIZmFPODQ2bjJEa1VhQUplR2xJUkRSdTZKL2UwRQpqd0hQNnN5RTZibWhyWUYy'
    b'emFwQjRwQUJlc1pBblFuQkFCYnBsUW1ZOGQvVlZSS2dMd09nQUN2RFJoaXdvU2Vxa1BGSXEr'
    b'QjRwQlFFCkdxRnZoNkVUWWdveUR6a0w4YWtoWTNFcEFsYTZRUE4xemJFMzEvZEYvQU1USUZX'
    b'elltZGRhTVo1VXNDYVFqa0J3QUtEZDJXaThQL1gKNVlOeHJuWFIyQ3Y0MzgyZ2VnR3NUREwx'
    b'TWdFenp1dmVGb01KbU1GZ01BRXpHQXdtWUFhRENaakJZREFCTXhnTUptQUdnOEVFekdBdwpB'
    b'VE1ZRENaZ0JvUEJCTXhnTUppQUdRd21ZQWFEd1FUTVlEQ1lnQmtNSm1BR2c4RUV6R0F3bUlB'
    b'WkRBWVRNSVBCQk14Z01KaUFHUXdHCkV6Q0R3V0FDWmpDWWdCa01CaE13ZzhGZ0FtWXdtSUFa'
    b'REFZVE1JUEJZQUptTUJoTXdBd0dFekNEd1dBQ1pqQVlUTUFNQm9NSm1NRmcKQW1Zd0dFekFE'
    b'QWFEQ1pqQllBSm1NQmpuUHY4UFJna1ZrNTNYN04wQUFBQWxkRVZZZEdSaGRHVTZZM0psWVhS'
    b'bEFESXdNakl0TURZdApNVFZVTURNNk1qTTZOVGtyTURBNk1EQ1JCcGVQQUFBQUpYUkZXSFJr'
    b'WVhSbE9tMXZaR2xtZVFBeU1ESXlMVEEyTFRFMVZEQXpPakl6Ck9qVTVLekF3T2pBdzRGc3ZN'
    b'd0FBQUFCSlJVNUVya0pnZ2c9PQoiIGlkPSJpbWFnZTQwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'ES_ML')

ES_ML = b64_ES_ML
index.append("ES_ML")
index.append("Spain Melilla")
catalog["ES_ML"] = ES_ML
catalog["Spain Melilla"] = ES_ML
country["Spain Melilla"] = ('ES_ML', '', 1)
lookup["ES_ML"] = ('ES_ML', '', 'Spain Melilla', 1)
lookup["Spain Melilla"] = ('ES_ML', '', 'Spain Melilla', 1)
details["ES_ML"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_ML"] = ('ES_ML', 'Spain Melilla', 1)
regional["Spain Melilla"] = ('ES_ML', 'Spain Melilla', 1)
#----------------------------------------------------------------------
b64_ES_NC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc0NyIgd2lkdGg9IjMyMCIgaGVpZ2h0'
    b'PSIyMTMiIHZpZXdCb3g9IjAgMCAzMjAgMjEzIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X05hdmFycmUuc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUu'
    b'b3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBv'
    b'ZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxpbms9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8y'
    b'MDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRl'
    b'ZnMgaWQ9ImRlZnM1MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJuYW1lZHZpZXc0'
    b'OSIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIgYm9yZGVyb3Bh'
    b'Y2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpwYWdlb3BhY2l0'
    b'eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnIGlua3NjYXBl'
    b'Omdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9Imc1MyI+CiAg'
    b'ICA8aW1hZ2Ugd2lkdGg9IjMyMCIgaGVpZ2h0PSIyMTMiIHByZXNlcnZlQXNwZWN0UmF0aW89'
    b'Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IiB4bGluazpo'
    b'cmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQVVB'
    b'QUFBRFZDQUlBQUFDcExyNjVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2'
    b'SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIw'
    b'UUEvd0QvQVArZ3ZhZVRBQUFuCmYwbEVRVlI0MnUzZGVad2RWWmszOE9lY1UzdmQvZmJ0N3R0'
    b'ckZoS1NFSGFSVlJNZ2dDQ2JqSTdiT0NyenFxaWd5SXdidUNHK0tvSzQKajRvb0tvZ0xvNmhz'
    b'b2l3aG9Ld0NBZ2xKT2x1bmw5dkw3YjVyN1hYT2VmOUlTRHFkN3REeGRjWXdQdC8va3RTdFc1'
    b'OTc4cXZubkZOVgpwOGpHWEFjZ2hGNmVLUDRFQ0dHQUVVSVlZSVFRQmhnaEREQkNDQU9NRU1J'
    b'QUk0UXd3QWhoZ0JGQ0dHQ0VFQVlZSVF3d1FnZ0RqQkRDCkFDT0VNTUFJWVlBUlFoaGdoQkFH'
    b'R0NHRUFVWUlBNHdRd2dBamhEREFDR0dBRVVJWVlJUVFCaGdoaEFGR0NBT01FTUlBSTRRd3dB'
    b'Z2gKRERCQ0dHQ0VFQVlZSVlRQlJnZ0RqQkRDQUNPRU1NQUlJUXd3UWhoZ2hCQUdHQ0dFQVVZ'
    b'SUE0d1F3Z0FqaEREQUNDRU1NRUlZWUlRUQpCaGdoaEFGR0NHR0FFY0lBSTRRd3dBZ2hEREJD'
    b'LzZnVS9Bbit0NG9XS09ZcFNjbWx2OVpWSHcveEI4RUtqRjQyeEdrV2E0cjhtOW82Ci9rOFhx'
    b'VXV4d3NUZjVIOGxzakhYZ2IvQy96NlptK2JiODAwcFFWVVUzd3ZkZFU3ajRnSDhXYkFMalY0'
    b'ZUdtc2JVWDlnTHJWQ0kzTHUKcjRVYXg5OEVLekI2MmVDS1pESEozVFNmMnF4OHdTYk9KT01F'
    b'ZnhZY0E2T1hCeFlUOC9wT0p5V3FOSXcva3NYMFloY2F2WnlrZmptLwpkWDY2M3ZBQklQWG0z'
    b'TWFpUmo4MGlqOExWbUQwTWhrYXBWaWpHY1N4NEVMVzZuNzJrR1NzNHErQ0ZSZ2RxQ1NsSUlU'
    b'SVptUVFjbE1SClhFb3BGWldCbElRQVl6VE1teVRRSVl5bzU0RVEyS1hHQUtQL0ljRWxGNUho'
    b'RWRaV0lDdGZMYSs1RHM1K3JmejJkd1ZWdE9HU05Jem8KODUrSk5qeGh2ZVA5a1YvWHpSVEky'
    b'TklUNGNnNzI5Tm1yZVlCUUNwbDl2YzM3Vi9menBqR3VTOGs1V0VZLy9KbnRIMkJkdmxuQUNE'
    b'cwpLQW9HOE9FUDhOdnYxQys3TEY3OUlOM2NMNHZ0K2plK2d6LytnZDdWd2xub0ExWjR5VVgw'
    b'ek5POHNlZTZqajB2aWlMUHFXVHp4WW14CnJmblcrWlhKa2dROXFJeUZzZGQ3OEpHVEUyVlYw'
    b'NExBcGJKR2lhVGdCZVAzSjVRMVlSQkxJalZWYVpEWEdPbWxuQzFrc2t6VWhhN2IKVENUVGht'
    b'RU1iM21HU2NOcTdRUVpabk50NWJIK2x0YmVpWExKVG1SVlZSMTg1azR6czFUYzlRY05rNHdC'
    b'Um5QdERCdTZkKzBYZUdYVQpQbmxGUzJ2WDhQQ0FZWmljY3lPNmwrc242dDR0a1htdUV2NnhE'
    b'cTl0TDNaeHpvZUd0cHVhbitkZmlTbzF1cjRlRFFSeEpWWmVrOG90Ck8yaDcrSEVoWkkvMnBj'
    b'cjJQbU9UMEZLTTVCVFptU2MwSEpaWGhqSHA3T3doaEF3UGJVN0pOYUYrSWxSL0k3TnZGczZm'
    b'd0ZyQm1PSjcKYmtkbmQzbHMwRjJ6aHFaYXpjcytTc0lJR3dnRGpQYkYvZUpWbmE4N1YwbzVN'
    b'clJlTTF0bDBOY2l2a2FaVUJtSjNOamQ0aldIWS8vbwpkNFhxb3ZrTEQzTWNoNDk4MHU3cnE5'
    b'NHlSdjdzVTA0QVFBTFlQKytOVzg5MmxQT2xsQlk4bm5CdUxMOXVrK0lUQU9BNjJHL0o1OTlZ'
    b'CkdDWXJ6ZUtGQURCYVdxK0pVbWJvRzBaQlY5SXFwU1FXVWtveURwY1NmVkhnam5WMEx3V0F3'
    b'ZHQrWTMvc1U5aEFPQVpHczlSZWdNWmIKLzVubkZDbWxsRklYejdaSHY1SVVRSUx6eDNyNW5v'
    b'cDQwZ01Kd1UrdjZWNTJocFJ5MitZbjh1ejM4aWQvYnR4U1l3QUFPMmVtdUNIMQpsT0xLRHNZ'
    b'WUlTVHdNMWxORVZrQ0pRQUFGb0IvNDhUZ1RST0Y2NE1Kd3B2MHpONzVSM0IrNkVqb0d1ZGZ5'
    b'VzFRampGemIycFREamJhCjRUcEZzQ0Y1dmhBSEUwTENUbE4rNEwzMjE3K05FMkFZWURRRDV5'
    b'TWY2cm53N1ZFWWpnNDhxc0p3MGJpTlVWWi9wRmI3N2lqcml3Z0EKQTFBdXlzZUpOQUFRUWd5'
    b'bENyKytWOTVTbTdhZldDT0txbmk4a0U4a0NDSGp6U3hRSWpVS0lIWjN2V0lZdjNCcng2OGUz'
    b'Slk3Q3dBWQpZNHFwS205TWs1L1Y0QUZ2OG9GdGZLbWF2NnlUSG14MkdiOGVIRlJDNk8wOGZJ'
    b'VjJ6R2xEUGQzMmYxeU9qWFdBd092QUI5SjRwcjJWClVxcnBPbzJlYjlkK29SSmF1bjZvOGVG'
    b'QjFyZHo1QmxuaUhadXJ5VEd0cTBiaDdZOW5xLytKTHh4Y3RmSG0xSnU1TkhqY2ZoVUpRamkK'
    b'V0ZXazR6aU5Sa05WTlVubHMyWC8rVGpxNTdFdjVjNnZBeWg5ZEd1QjNqdzh0TG0vZjR0a3Jh'
    b'bC9iWmN2bGxmMlFsUjV6N2J4NzVRSQpvUjNHclV6MDY3cE9LU1VxWGxER0NvejJGQjI2akgv'
    b'MUdoQzhOUEFzNFlPZDluMGFVd2V1MkVRZTlLYjJWNVdqekVudGtvN3VJNlNVCm93TVBqOTIv'
    b'N2ZaSkp4VEFBQ1FGbTVBdXBsaUVwQWlGVURyQ2FNMFlsTkpTWlpBcjNHeVFFT1IyTHA2SXdr'
    b'QklrQUFBOGkvd3dlcnoKWUFlOXZjdWtuRC9XLzA1eTBCVkszODRuSDRnQWNVdDFhQ3pxL3V5'
    b'OEx1dVgyd2U2Z2JiQThpWCtmWGV5RDM1WWZYNGROaHdHR0FFQQpCS2VlM05QZERRRGxrZlh0'
    b'eWc4MWpRMThiZ3Q1MEp1ZTh5TXNDc0dPL3JPVTBQOW83VHpETXNnTVkxSWpab3FkdDIwYkFG'
    b'UWpyN2hzCk9WVm43RzgxSHF1VFUzZnVnZEpRbnBDRXZ1b2VXOXpyYkRmNnV5N3Y3VFd1R3hK'
    b'WEZ0c1hBa0QvcVNzeHdCaGd0Sk9Rc0hYenBtUTYKclVVUFN3WEc3eXlUTzUycGsxdDNoOTZ3'
    b'NE85c0wzb3hIUm9hQ2dLdlM3bVI5a3VWekR5anhMZEgvc0thWDc0TlJCeUdoOEhJckpkLwp4'
    b'Tk5OODZSZmJOdjJyNXFtSzFLTEZobzMrczNEbUhxc3F1L3UyOS9SckI0ellhMUk2L3poY2ps'
    b'ZnI5VndIZ3NEakY2Y3UvcS9uKzYrCjRIek9lV1Awaml6OUhkU2srNTlqN01WLzNjTGp1MEx2'
    b'Yk0wOFN6T0puVXBrRnVkeU9RQVkySGlCWFhseXRuMk9iYWgwSDN4bHEycEoKSVNpNWRhU3Z3'
    b'bWJaMG4ycUtkUno1dlhNQjREaFlkNmVWdDlsSko2S3cyOTdqYk4xcTV2dS9Gemp1ckhVU2Rr'
    b'TS9mMklVK2pxUHBOZAo5SzVTYThHNjRrcHNQcHpFK29kdmcweUdNYVpwV2d6ZGhOTGFYUlUy'
    b'dVhPZWFVM2dQeDJGRjV2SmVVd0JBQVp1RUxoU3lpaUtsSEJvCjFoSDFZZ1grcTVFMG1WTU5u'
    b'R3FZU2lqeFQ2cngwcGtubjJoWnlLaTg0OEtWaUQzRlZBRGdLRVc3eUV3K0hnUy9DM1oyNDJs'
    b'TlZINDUKUmlrSTJxbHBHbU9NcE5QWWRsaUJFWkFmM3JTeG82aVp0Rk85aVJEd24yenNPSzNl'
    b'SFhocFF2OUp0M2FQYkxtTTNadkQ3VnViUVZzYQpubTVZVW5WbjZNd3FpL1FGVnl3WXFTK3Ft'
    b'dThCa0tubWpmTnY0a05mSDRRWFp1aElFd25wNEp0akd4N1BHQU41bXBQQnprdE5CT0NmClRH'
    b'dDlIUDNBYWI3VFRoQUE1NCtOOUpzS2ViaHA2NVpVRk1UMkQyL0N0c01LakNENnhFY1hMVnVh'
    b'U09XRUpBQ0VUMFFBc0Ryd0UwQlAKMFBTcFc5WkhQRE44cERYanptL2Rrc3dZWUJOK2hqVnRi'
    b'M0dPNVA2NURUUTZFYjJpV0N3V2l4MVZjcHBxS3kxdktNU3QwNXVicjdKRQpuaVZUMmtGdDYx'
    b'dHpyaGF0cjQ0N1V6ZFlvcWhubU9ZTlRsTUN4S1VRZ0FoSms2bk1vaVZMNDA5OEROc09BL3lQ'
    b'VGhLaXA5T0VrSmFXCjFscDBwSlNTMTBWZkhEZWtmSld1VDkvNGhvb1ZzckVSL3N6QUJlUHVZ'
    b'UjNmWFpROFBSUG5DQUM0MTM4dHZPOU85OE9Ya0NRMTJuVXAKUkZyZVh5b05qNVJLaWZndUtj'
    b'Qm9OMmlLdWxkY0Z0NS9sM3ZkNXdHQVp5Q3hLdDE1dzhKR2ZQZ0xvK2VVUjZVV3N1ajZ5V2xm'
    b'MmtuWgo2WWJ4RzgrRkdFQkNMVHFpcGFXVkVLSm4wcExnWkJZRytCKzgveXlsLyt4em82T2pt'
    b'L3JXRi9UVmhCQ2VvMzhJdkhPTTZRdkJodTBrCmRXbTdyUEV4NDhvRmgxNGc4Kytya2xUN3F3'
    b'dkZIeDRVVzlSWWZtaDdkN2QyN3Jtc253OThyWjhRYXBmN2xEKzhoVDN3Wm52Z3oweWgKMjcv'
    b'ZVR6ZkYraG12YWUvcXNrODhNYlRVd3ZjV0ZsZTFlY3p3RSsvdFd2TEdjZU5LVXVVdGwzV0cz'
    b'ZE5qMmNzVWhaRFJGQUNCZ3JHNgpyMi85Nk9pby8reHo1TVY3UWhBRytCKzREVzY3WFFoZWFD'
    b'ME9lZWZHTVg4dVI5NXMyWHR2cG8xSXJzajBZU2tpQlFEb3V1NUhtcEN5CitsaE5jWVZUbWZR'
    b'OHp5K1BBUUNaNEgzdldGdTVzSjgxUVBOWi9hTCt2cmV0bGVNeEFIakRBNTduTmFwVnpZM3Fq'
    b'OWFFRUg3QVZGVUIKQUtwbzVoTGIwN2c2TUVNc3p6Yk1nVjRtSlF3RzcyaHRMVW9wMkdOUFlO'
    b'djkzYkZMekNUK0NuOWZ3VWMrMUhYNFlZWmgxQnNpSHI4egphSWk4SXBWaHNhdVA3WHprQTJI'
    b'U0FqcXc4S01MQkpmTjh2cHF0S0JSZXFKdDhzR0k4SmpMK1BjTjdaYi9Dazk1THZqcDlmcTZt'
    b'QTV4Ck9pNElBTGt3RFFVbWY5dWtaVUVIT0FERTIrOFd2VS9wYi9nS2dGUmZuNUlhWWVQTnNt'
    b'TzZYTFVhMzAzWjllekMxTmdmeStHcnp2Sk8KVzZrOThmU3VHaHU4UWpHT3pXaXRNakRPYjIz'
    b'clRpU1NOUUxhN1hkaDgyR0EvOUU1Qi9VWUM2clV2VnNMN3U1c0owUVR2Vy9wYk1xSQpIR0hJ'
    b'WjMzdnUxL3JldDBGK3NrcjY4OXY4UjU2VGx0aXBjeUdjOVdOcWVOZXFIeHpKTHEySE56Zm9F'
    b'SkdPYW1kUzZ6REVvNGZxQnRpCkFJZytraTI4TW1mbDlIcTNwR3M4QUFpT1ZaT1h0bEtsR2Q5'
    b'WG95R0VEemFEbXlhYnp6VlNxN2FLcTI5cFB3Vmludzk5ZmJzYkhKeTcKK3VyQ2lTZE9IbnVV'
    b'K3F2YjRhMHBlcFRaOWVGZXZRREZqZ3dFYTJtME9mQ3F0VFViekVlZXhPYjcrOExMU0g5L21h'
    b'OWYzK2grWmNlSwpRT1pnYkZ4WE93L1RyT0VGSDV3SEFPdCsrNHlnaEJDaXFpcGtzdUpIamRG'
    b'RjQveVhkVDRaUjF5a1A5NWV2Yk5pZnEvUmZLV2EvdmUyCnR2YTBxdEwrdDhxeFZUVWRGQ3Vq'
    b'ajVVY0FKQkxqZXJYc3pLV3lSYTlZMkdPYzFHNlJqamZHak9laW9OenJlUmI4eEVJOGJ3M2RO'
    b'RW0KOXVZMDNGcVBUMCtxcWtvSVlZbEVaTXRGbC9ReWpRa2h1YitnWEJsdGI2a0NmWHpUMHh2'
    b'VFgzMFEyKzd2UDRlQ0QvUWZJT1RaTnZ6TApjdG56aFZRcU5iRGhqa01LdDZvS0hicDV5UHNW'
    b'ajYrN1RpVEgyUmMrYmZ3cGtBU0lCSGxEZS9IZ3JHbXFXN2FVbldhVVRwb0tVMVdWCnFUb3hF'
    b'NHB0YVROK1JSakdqWG9ZK3pJS2VNeGpyeG5TQkpzM0x4dEhmT2p4c3Z6M01TS0JTQWlYS1BI'
    b'VlZ4SzNxRjc2SWVNODF2NzIKVGlsa1gvMGRoWjRWanVQUWtTL0ZQMWhEZjl2RUpzTUtqS2Fj'
    b'U3U5d0JwY3RXSDVFamxLcUpwY1JJT1AzbG9OSG1zcG9xTDdsMzZLZgp0aWMrM2g3WE9ITmxS'
    b'UWxOaTlYR3dpREpGeTRzTUViRElLN1h3OUNKbTJWUkgvVzVGQlJJRk1jZWswTHdsS0p6S1RS'
    b'RkFRbE1aYXFoCjZMYVNzdlJrTWdjQXRhcnYxa0pXTkpyZnlxY3FUQ1Jvb2xOcjFyK2h2RzJF'
    b'QVBpUGFwUEY4ZHlwTGFDMjY3cXVhZHFtMy9Ya01iMVkKZ2RIZUlvMDJiL20rbHM3Vis3OWpY'
    b'bk4zWnNPTHMxeVhwVHJPYVhlY0tIU0VsZEFLYlJhbFpMTHNlZlU0REdKbWtWUkd6Mld0Y3FQ'
    b'WAppZHA3YzQ4QndEUERsZjZCeVlHbVF5bTBwdEpwVXoxMWNUdFY2RURsZUVNWkxpVDc0MWlN'
    b'ak5RalR5b0tNeXdsbTljWm8rT2pyak1aCjZqWTEwMnJwNXBKNlEzM0hBWGc5cFBueGxZbkZs'
    b'L0ZxelhyVDIybUViMXJDQUtQWk5WK2owemVtZzIyQitFVWwrNzZpYkZWU3R0VlcKdEtKSVRJ'
    b'NTV2aGNaS2FXam1QSzgwSzhIMGJaUW5hOWxXNU9iL1dzMEk5RVdmbUJ6YVhScnpWay9YSDZr'
    b'UEJrSnNhS3RaV2xYYTVldApMK3RwNlJmZmtDSmFvRjAyTWVIN2ZjUllvQnEyc0cybFBPNDRi'
    b'cXdTbG1uUmRaMk5Eam4xcGd1Ync4cU40OVdWZHY0SWMvS1c2c0pICk1iY1lZRFEzSEdEeVA5'
    b'S1p3KzFDVzdLbHhSd1pjVHdueWhYTVRNWUFnTklUWmZjK045NFkrMXREZllHV3ZEVFplV2lo'
    b'djNaV1NKY3MKU2w2M1l3L2pGZmN2WTNVS1ltbExzcGpmZWExaFUrTjlLa3oySm44MnNNR0p2'
    b'bElXbTJ1c0t3bUxFK3JKaWE3alRBQ29OWUo2TmRRMQpWbWkxU3NPTjBhME4rYVJqLzdoSkJi'
    b'WUpCaGp0VjRZLzNiYm8zUGJTaUNPbDdPNUtWZU5qS3ZER3RMZ3RwLzF4eXgrRzZDQXhGcXZh'
    b'ClFzTk1HNmFwbHNlY2tZbW1iV3E2b2xCR1ZJMFJJcm1RakRFQ0VNWmNWVWdVaWpDTW94aWNo'
    b'cmRrYVh2TWViTkJvMDFSdU1HUGkrS2cKTTdLbCtoR2U4YTk2ZEUvUnZHZG91R1pidW1VcEd6'
    b'NjcyYnJMeGViQVNTeTBmNlNBVFUrV0R6NjJkZWNJbVJ0VU5TUFpDUUFMVHV1TQpRcmxwYXpr'
    b'amlYUmpQK0IyVWx2ZTJnWUFVb0x2UjU3UEdhV1VBVWpnVWhpYVNnaWs4cXFpRUFBUUl0MW9o'
    b'RUlJQ1NKb0QyaWJQR2hCCkhnQzhLTTBTdXU5M1VncmRYV25majBvRFRaYkdSYkN3QXFPL3l1'
    b'aFIwbjlmZG1GYmVuNTNEZ0NFcEVPbHFrcUlwaWxNb2FtVUppWFUKNmdHUGVCQ0lpSXN3akdN'
    b'ZWQ3U25kL1MwcDFuZlY1WmM2anBURmFhcFRGRVZ5NkttcWZsKzdQa3hqM2l0NmhlNzg1WUJB'
    b'REEwVk8wYgpyOGEvcVBYZWhiMW5yTURvci9LWE5tK2tGQjA1dnhVQXRtNnRKVk5hSVdmcEdx'
    b'dldBdCtMeW1VbmpNVFNKUzF6M051U1JkTzNISnQwCityZlhFclp1bWtvcVpXUnpacTN1bDBl'
    b'OVlrYzJtVFNlZkw0U0paeGVzTEVoc0FLanY1SjdZU0o3Zm1zaW9XVXlodXRHOVliZmFBWUwK'
    b'NXhlVXYvVzVkMkI3VFZKSUpmVjB5cWpVL0diZGEvNnVvdjVuRFpzQUE0eitlb203RjdXMldv'
    b'NFhUNVNkYk43TUpJMy8xcS96L1hoNApxTjVTU0NRVDZzaW8wenl6RDVzQUE0eGUyck54ZUZ2'
    b'Z0ZkbjB4ZWRvaDhvb0FRRE9KWUJVRlBiZmVoZ3hsMUpLeGdnQjRGeUswdlJWCmVFcWNYNkJi'
    b'aHlvNHM0VmpZRFQxVkFya1BOMDhRdG5yTnViSnYrdGhHZE5YQlhrNkRuRVpEZ3d3bXBXa3hE'
    b'c25aeDJibERxTjFybmsKWitPcXM5KzNRTVVhamQ1UU1BK3pBY0IvcHFuZU9zN2kvVjQ5d3ow'
    b'bG16ZzV3eE9FYi9iRno4dmFlQWdBdUFiSEFRVlg1RGh3S3ZETwpiUGp2YXRjUHQ1czNqem5m'
    b'S0FrcDRaTTlYTm0vbWljSjhBOTNzYnpTL041dzgvc2p0RjJML3IxcmY0L0hlWDNCT2pOYnUy'
    b'M2MrZkpnCk5Cb3BuK29KTStxdVEwVTRCa1o3ZUQ2T0lwQ0w1eVh0eTd2NVpWdVp2N1BxaHQ5'
    b'WnpKc3gvTm5oTGxlRWpEdDFLSVZxUnRHT3NuaEIKSXdPQmZNRURYd0FBRkRVb2hUU3ZLc2Nu'
    b'WTRXRUYvVVoxWGhITlNiZlc4eHFrYis2QnBVNExHb3dIZ09BWWhEdDJCVHAxRmlmRjY1MQpw'
    b'RUlGSmFRY0FpVXczNkFuWjZLcit1MzFPKy9CQ3QvWkJqRm9ONDMrT1E1TlFwWXhIQU5qRnhw'
    b'TnE1d0FaTDRKVzROZDZmWFRDbzJGClYrWEdFcE1sbVFSZ0pvWEZwZ3o1NkF0K2xySEt0aUM5'
    b'eUFTVEFvQ2FaSFNlSHJsaTRoa24zYWxGWGZxT0FMdHRtdG1JbmUyaGRYeEsKVDdHRXhhVExB'
    b'Y0FkRGIxYUhOdFVqUFBVeVJtbUVxSlM2WEhPWVdLYm4zZUZjckFGTHdZNFd1Y2xWbVhram9Q'
    b'RXBzSUFveG1KMFJBNgpOYm5qNVdVQXlxb3NiMUZUT1JYdXIwQnp5aDFSV2RiNWlpU2tLWXlw'
    b'ZEoxRFhod2pDeTVaa2xxdlNMSTBNN2I1Ty81U253alZnaG9uCm1Gb0svYTMrN3JiWGlkdWpG'
    b'N3Axc0lqM3JNZW5URyszRm5XUll2NDhRMk9FY0FrQXJGdVB4a01GQTR3QlJyT05nUUhBN25Q'
    b'amNoeTgKdXoxeGRFS3BjV1crUGxHS0xDckRQelh0ZFhzOFJoK1RFVWxCNXpOTkt0MDhUcjR3'
    b'enp1dkJUbzFwaEp2TUdURFFmeWxRVmtLcDNWOAprd3B4R1ZGRG9lNjVHK2Uwbk5YV1loMWlU'
    b'NXlYVjFkcVZzS0dtUENyK2pIQUJ4cWN4RHJBdXRBUzRHdURaTDZabkc5VThxeFNpZk01CkpS'
    b'aU9NeGUxUllrOXJnQVRLU21mZVVwWUNVVjg5WUJ4dEIwdU0rTmxwbmFvSlQ0L21DeUZNMnda'
    b'U3kwUVpNL2RSR2tsOC9wODViRm0KcklMK21weVNUM3BOeVVaRGZTQUFBQ2tsQmhnRGpQYXF3'
    b'Qy9HUW1sdzVjc0Q5UnJYKzN4MnkzajFxdTBkaDF0MVN1RFNUc0htbWgxdApMQXF2SHpFbllu'
    b'MHNFajhjMlhFRmFFNTllQVhvWlYzMVNMWXR0K1NuKzYyTE52SWdwRnRjL25SejExa0dhekFH'
    b'R00xY2dYZkdienpTCk5RS0xyR2d3VEt4M1MxOFliTy9SeUFJamVHZmIzUGVtYi9IaUZrMTI2'
    b'T3JtWU82ZkN0NVZWT2ZycVJSdFhETm9idmVaZ0FTTnJjTXMKUGhSTzYrMGpERENDMlZLaFVD'
    b'RGF6bXZEOXRPTmdmK2FzUEpxeTFtNTVqbHpmZmFJU0VKVW91cVVpTG5lZk9HY2s4K3N6RWli'
    b'VmI0MwphbXpmT2QwbHBhUWEzWFYyd1RId0FRVW5zUTdFQ2d3QVhBS2hCT2pPc0tSK1BEclo1'
    b'T2JyOHEzL1VtZ2NidkhyUzlwWTlEZjg2amlyCnlBdmJjc2NrdlZnNjE1ZVNEOVgyTlZESHBz'
    b'SUtqUFpkZ1FXWHpDQ2V1WHZpeXY3MWhEb2NEVDdRMEE0MjRlTzljMnBkQnB5QW1NTloKbW4r'
    b'bVZ6czBPZnA0QS83aUpPK3JUdCtQd2FKMkZRT01BVVp6cnNBQ0NGQmpZbmVaSlVJMjE5UmFW'
    b'cVY4UjhRR2NROTU2ZWZzTlVaQwpUN3prWGREdTRRbXVzZGlQY3llbTNUVXoxRjdoYzNVa3hB'
    b'QmpnTkdjS3JBa0pCYVNTRTdzUFJwSXYyZXkvbGhETTJtMHprdTh2WTFyCmRKKzlZa1pCcWdC'
    b'UlR0dFg3VFZaOHUydDBWcEhzVmp0b1pyOVdHT3YveU1FSk1nWE8vTVlZQXd3bXFVQzczb1Y0'
    b'S2taWGFWa3ZXY2MKbVppNkFZdGw0cG9COTdxaDloTVRyczNpOXhiM2NVMVdIcDl5K256Ujc5'
    b'UGpVN051UXdpL3VOalFXZkdFcEh2TllQS3JROU5lK2V2WQp4TXJiemhaZlgyUmhBMkdBMFp3'
    b'cXNQN3FGQkRnUFlZOGRJYlltSDlwVnE0ZEtuUnE3SERiZjNOaHRoMkt4WFppcVVVWEdtU0pP'
    b'ZHMyCnpwc0t5bEs3MEtGT1hETm9QdWZzdmNIRUNxTmVqeWtuK3RIVzN2MThoQUZHTTR5Qm15'
    b'OTRRa2hCUVRabWZoTFllTEpSK3VtWW1WUmEKWGw5d1ZtWm0zdDFtejlubUI2VW9lTmFaT2Iy'
    b'cmNxMXZhTkZTZE9TbWNmUHBXVjUzRk5Kc1RyZVg2TDVLWnp6WG9MOHZ2SXgwSU5aZwpkbS9W'
    b'UHltbFZtTytldGJMT1ltZmo5Y3NwcDJRS2x4U3JCNXNrcHZIcGozM0w1K3NxNmVsQmFYcTQv'
    b'VnBuNDFTRFA2bHJYQkt1ajRaClJ3L1drcjhhbisxYjJ2L2tsN2NGN3ZOTnUvTGlDOGRCRWt3'
    b'd1ZtQzBEOVo0eUV4R0ZocWtmMTgzVVprL0d0VWFmT0NlcW5WNkVxN3UKbnZhdjZuaXNGRFda'
    b'WU9wa1BQMlRYK294VGs0TTNsUFZ5ckZ4ODlnK3ZrSnp1ZTFKcTlmaW0vMWQzUVNDTlJnRGpQ'
    b'WXhCZ1lBUm9GcApaTjhqVGlLa3M3cGFPQ1hqVnpqUHF2NGgrc3liN2JrVDd4aGRwSlN3SnZL'
    b'bnBKc1BWcWZOV3UyTnhWSkpLUkRLS1FGR0dHQTAreGg0CmxqL1BRUDFkcGI3SlY2a1NiVzRZ'
    b'SDh6dHV0aXpPNzJNVE8zeUNoV3M5N1dFTDlRVmhUVTIrc2J2SzMvRlFXS0FNY0RvSlNxd2xF'
    b'QVkKalpJdnNZaXNFb3JFSjdZMmZ6VGF1alFiSmV6d2s3bTk4aWFuMXZINHN5MkJaaFFPelRW'
    b'dkdFbDhldHRzRHlSTy8xOWlVWjVUZHgwWQp3Z0NqbDZqQUJJamtRcTNHYy9tZy9XQjE0cHVs'
    b'cktYcGgrV2pkNldtbkFVSVJISlhGOXA5ZjBaZGxNM1ordVMzU3ZiRCsvSEtCZUVMClVvbXdB'
    b'bU9BMFp3cXNLUkFGQW1TU0gydVliRWVySTdjVmRHcFlwNWRERTQzQUNCYWFGQW50aFRpOVpv'
    b'QUVKeG5wMDV2dFJTMTlLdEoKNjhIcWZweFdxQVFCVTk4UGpBRStjT0JscEFPeEFqZVhKL0lB'
    b'OFdhUEhaR0FnYmsreld2ZFVLb25xSDY0bWZuZ3ZJbWpSb21XOWl0Ywp5RGc2THg4YVJ2cWtR'
    b'amdwSngrdEpuODhNdmREaWhMVTdEV2F6enJLSWdPZWJtQUZ4Z3FNWm0ySjNWM29rMUp1VFhp'
    b'VUtLOUs3Y2NlCkJDamZMT2toR1ZoVEw2enNWSmVaZHJ0cTVMVzJreFBXY2EybCsrcXN5clh2'
    b'bHZhbjlwTG1XOXFqU0JKQ3lCSEp2ZnY1Q0NzdzJ0MHYKM1pFTjc4eWNmVlFpcEtCYWF0amsw'
    b'ZnM3clc4TnpYRW5MQlRWaCtwZGIyaXBEUG1mditHNXJiRUxVaTZ3RXBlLy9aQ09WMmNuYng0'
    b'Mwo1L3grQmtraCtIaVBwb0VRb0hScHpHTGVDV256VHpXSlozME1NSnF0Q3gxa1ZmUDhmSERG'
    b'Tm4wODVKUnFSTUwzRi91TEZwS0g2bkl5CkVxMHEzZkVjdjgzZzZJVFpxWWRQTnNMbkhLa1Ew'
    b'Q210YzZEQXUvVkdRMXo3bjJ1Zm1WY3JEeWlFeWxxaCt0VnZiN2o0QTh2RERvMGYKYW9Fa3dx'
    b'YXlJVWdrOWFNVDZ2SEpZSHNvLzl3RWx3TkFuR2EwRkNyekRMa3F5MEFhbDI0T05CTHBqQlIx'
    b'OVFORi9saGRBaTVxaHdGRwpNMWRnR1M4eDlXMitQaG9DZ0NLRWwyU2t5bm1WMDJPU1dsWUJn'
    b'NEF2QWNBcmhTU1dqVmpxS1NYejNpTFZDV1ZFQkNMMnBGdm5TcE52CkVNM3lrTko5WEFnQUE0'
    b'OXJMd1MxcEpEZVFzTjZSYmRpVWFJUUtVR0UwbC9udWhwaEdRVk96V2dkS2dEb0dvRlFobU9S'
    b'SmtRamxCcUEKR2tvMWpLRVJneXVhQzAzNXZJdWpZQXd3Mm1zRVM0Z0VrSzRnTnR1OXVwMHZh'
    b'WXRxZG10eGZ3amwzY3ZLS1RieENqcFZTT3JZWkxUZApsMnpuMHU1VVNwbFJXSkpaNnU3N055'
    b'UWhoa3BpbmZBa2s1NlF3YzQxc2lRUVk2a1ZoWkphakRXNFB1WEJDYk5IRjR4RTQzdXMyc00x'
    b'ClFoc2NKN0V3d0dqV01iQ3h6aEYycTdNeXcwWWptVkRJUkVBcWNlM2JZNW05RnFtU1djVS9M'
    b'Q0ZlY0kyeFBaYU05VjZkTFZ6ZVNVTWoKdmJpNS9RbFRTcG51amRpR3BHS3d4by9IamJzbnBs'
    b'NVpkaGNZNGhCYnJHdW1OZ2RUOXhMcnJQRzZ2SFZDS21oVDQzbW10cHg2VGRWdQpjS3NVQUFi'
    b'NGdQcHZneTgzTzBBTUNiNCtqazdWakdDaEZWMWN6TTgzUW9mSHNZeStQMktzMlkrYkxzTDNk'
    b'c1NMVEwxRmVmK1hueGhLCnVVQ2d0Mko5K1lPdklLRVVmMmthK3pNTDdaMmRqODdNdFhkcmpo'
    b'ZUpVUEtQOUd1bDhNN1FPMTdWY3dSbnNyQUNvNzBxTUFEb20xMysKcGNIR2xUMytVQVFQMVZM'
    b'N2sxNzNuTHg1ZklwTlJqSVFYN3o0YUpVQlVTVmxWQWtBSXFHZG1IYUhRK3YyaVRudXpieGpR'
    b'anplckh4eApuamZlc0FaOXJiVHovY0JZZ1ErZ2tSZitCQWRPZ0hleFNvR2xFTmF0c1JkZkRq'
    b'Z1gvcW5aOUZ0YUxaTzRqelRZZXpiQkQ4ZE5WOHFZCit6Y08wMy9iNkQzYU5BMlNlSE9MZTBa'
    b'dTd2dTB4d0xMaVkyaUdUM3J6M2lvQ0FPTWRyYkVsTHNWZ1pFcFJYa3V0WGRsSnZ2ZUlqRkkK'
    b'K2M1Szh1ZGpSRWpqNlliU3B1cVdtbHp0RWdHSm40Nlc3NjRvQm10NWQ3dTNJck1mQnlZa1Zj'
    b'aXVnOE1iT2JBTGpmYlZoZDc1UjVOSwpmMDVYWE1NdVhYbHJhLzdvUk1NVnprUDFYWGRLRWdt'
    b'S1FlTlE3Rm9yei96UldGbGoxZ21KM01WRjU5aGsvSk14YldnTzkybWFUSWpkCkU5VFloY1lL'
    b'akdZTU1KRlRJaXhka2JKZXVuVUVBK1hxSHJuY0dIbTBUdFk2cWUrWGRqMTF3QmtCQW1Fa3A5'
    b'UlNrZnplRUYzdmxoNXUKaWtVNi9mUThPYmYyRjFQK24yQUZ4Z0NqbVN2d3JpNTBiREt3R0Ft'
    b'bFNMOUVGeW40dDdUdkJpS0V6UEZwNzU3cUhxOUJrdEJveHZHZQpUL3dTQWU0OTFjeXJraExB'
    b'bnd6ZDA3TXZmV1NlVU9pVU00dkVDb3dCUmpNRmVIZXYrSVJVV0k5cWZaNTI0cjRlWmdoT050'
    b'Sm50N01SCnFWQmErZFZFNHBrOTFtU1hSRVNoVkNoTVc2WWo4VlNqZHR1RXdwamlpc3piMnIx'
    b'RDk3WGdjNWhWV0ljR1ZWODd4dGk5WTJ3dEREQ2EKM2hKVEZzNEkyeFJTMExLSFdrR1BQdHYy'
    b'L2pGNjhvUGRRWVVyUHNRWDkyVitPanB0ZzhaUlNUSVFaRFFlblQxOVhlajBUMGI1SlgycQpr'
    b'SUVUcHo3VzdTNlpOY1BoY2Frd2tFd3h5UExrbERFd1JoZ0RqR2J2UXV1L3I5VUhvK2FmR3Rv'
    b'VGpabHpkWlNXK1ZSUDZGSFJIOE8xClE2b2o5dDVHT3pyUnNGbk5VK2l4aWIzL1ZYRUVYRHRF'
    b'eHVLUWs4d1ZYY0g4bVJkL2o4ZmlpSUlMUXRidzFTb1lZTFRQQU8rcXdHWTUKVEt0Z0xMZWlQ'
    b'bS9hWmp4Sm9pdXltYXZtMWNjbERJZjhLNE1zRURObmJ6QlFJd2wrSEsyZGVRUG04K0M2Zmpv'
    b'Uk51c2k4N2xlL3kydAozSnErQkZmNnFRWlV1RkdTMFIwMUREQUdHTTBwd0FDZ0VLQTJJOUgw'
    b'U2Qvdzh6M2FrWVhCUHpTVE1Zay9zMTJyekxwb1ZuSk5JNXRSCmxVaWg5ODU2TDVjeEtjSlA5'
    b'U2MxT3JpbWJweVY5UytmdnJnMGtWSjN1Ym5BRUJXT0FjWUFvMzBHZU9xS2p6YmJPeWpPa1Vr'
    b'N293Y1YKM3JVaVU3MnJvc3p5NHBVZDFNbkl5Q3N5cXlpVCsxb1pUMjN3NnQyVDNhL0orQldl'
    b'Nk5SZjhxMmxlQmtKQTR4bWJJazlGbUNYNGZSKwpiOUN1dGJ5L1dQbUxKd1VkLzdPajNUbjV0'
    b'L3BxOVk3SjhhY2MwR2h0dlp1N3BDTnNVZmM0czJRVllHVGF1UVpoZ05HK3V0QVFpcWwvCkRu'
    b'Tks0aFBkbFVDMExUUDV0VVAyNS9wWkpQYTlRODRBSklSY3ZPUlhLNkd3citvWFh4NHNMRFdy'
    b'c2JTdjdJMnl1ek1zS2pGTXVaaU0KWFdnTU1KbzV3THVpRnFZVW1sT2hFVU5lQVlBb295USsw'
    b'K3RZU2pyRmFwL3R0L3JtOUlTRHdrRVNVTmljRjZiZDZOYXZIRWluRmRlaQoxcWU2NHlRREFF'
    b'a0lUYks0eVdsRzJSMWdUREFHR08yakFudW5aR3JseUIyTHRWTXp6cEZKNjZwZU44RnlGcDM0'
    b'M3FpK2JhNnJ6RVo1CmhRcXBDaG50MlNYZUIzMnJOL0dEMFV5UytSbFYrMlNQdTh5dXJNcDZK'
    b'bXR1OTgwVjZSY0RqRGR5SEVEd1lZWURLTUE3K0s5TUpzL1AKS3hZbEptdDA2OFZYcFVwUE9X'
    b'MEZkZUx5YllrdDNuN3M4S1QwNUViZllLQ2VsSUdmamM3eFU0a0hLaFBqWWN2bmVzYTJ5ZUtY'
    b'NTQyTQp4SVFSNHlBclZFQzhJbVUrV2NjdU5BWVl6ZFFYSWlBQVlwdnA3Mmp6djdEZFZhZ3dx'
    b'WGx1ZmlUUWphSlcvczJrc1QvcEJRQi9nZEY2CmlDa2tUSlJqYlg4K2FEenZWSDVYb3djWkkw'
    b'TVIyK2p4cnczRkdvRWV3M3hmTVZyWGxBSGVpWVZkYURSekYxb0doMWgwT0RRM2VJbTEKVHVy'
    b'SkJ2L0JLUEZFR0VwMng4VCs3cEN0cnJwYmc0bm5QWEp2ZFg4L3krK2NVRnBVY0RuL3daZ1dD'
    b'S3ZCcmJVT0d3dURwUW04aklRQgpSak1HbU1nZHcrQXBiU0xUek1oUXphYmhNY245SFhxcXo3'
    b'dEtVVE82ZGVNRlozOFBSdWhVeGxKTnE3Ujc5L2haMGgwbkdheS9HR0EwClV3VVdBUHBhVjdS'
    b'cDdyS2RkMVB3K2FacTBva0hxdUsxT2ZybEJjNVp1VmliYTVOUklWV2RVSTJBMkkrcTJWaHE4'
    b'MHM2RXgvcm5ueWsKVGdqQU1UdnZvM2FXMjZKRjFkYzVXSUZ4REl4bVBwVkdFbFNIZXplT1da'
    b'ZDBpQTJ1OUlWOXVGMWI2N1YxRzBxYkZuaWNuSjIzTG15dgovR1NNM1Y4eGF2d2x1c0dNQUNP'
    b'Q2k3a1V6RmlsM25ISi9MdUxlaVNFSzdoR0M4dHNQaEhSSXhMOFBVVmlNdnRnMC8vK2lPRUpm'
    b'TFVLCkJoak56Q1JrV1BDT0ordkJGbGNjbVNBR2szZFg3SDVmQXZnYURVL0wycWRsdUpES21S'
    b'bDJRUXQxdURzUmgzZE1waDZaK1ZabndpVncKdWUrMDFRK3hsZGZta2kwcXRLaWFrSTFRcG0z'
    b'YWZMenAzelZwYnZjcGdEdlBvTXR0NlhIMm94R2pFdGVrOFBGbXlnT3E0NGJyUWg4NApCTUNQ'
    b'L09aQ3ByNWFuZlV4WVBmSWhIRjYxbHh1RC95eDFubHFKb3BrOCtmajl1MFRaSzhicm9LRWty'
    b'eDVzZXRMK2M0TnFqZkQvVmpPCnlvejk3cUtpd2NnOXRjS3hObFJqNTc2YWZsK1ZoVFBmdkxV'
    b'NjhqZnorRzJHcmVFb0dBT01ack0yamg2T2c0T1pza0kxWmd1S2YzbzIKKzk2aVpIVHdya3A2'
    b'aVdub3NubHZqZjZocXRkM1A3ZmduSjVObkpWakNxbmZXcDc2Um0rdUVIOUZKckVxdzFQS3hM'
    b'TnV4MmtwalpIeQpyZVBtTGVNemZwY0VXQjM1RzNsOGtxSWZvcWpZUUJoZzlOSTI4dmpCeUM4'
    b'UWVvWm1talBkdStoMTZkNko2WFNHS2NzczEyQzZsRXBPCkNWYlhnajlVOU8yK1RDdmt5bmtp'
    b'eWVKUXFoNkh6MnpYeGtNL3I4THBHZnVjUFBlRTd3dmRvTkRuVlJwY1gxT3puNXRocHRxVDhw'
    b'N1EKRzVkaXBXb3NZamphd2dDai9WUVc0dmVSMTVCeWhhb3ZZVE5YUDBuQU9TWnByY3A2Q3cz'
    b'VkZVWmFBWk1TSWtmdnJ5VjlMbUp3RTZ4bApSWm81WE5nc25JZ2N4akxWMExtL3BqOHdhMjk1'
    b'SzQ4ZmpnSWY1RG1hMlU0Wk5nUUdHUDEvalkwZmpZTG5lWlFqOUd6Tk5HWjVtTUR2Ck5zZ1oy'
    b'ZFRKNmY3Vjlmd3hOcjlqMHZqdEJBRDRGN1NvNStUTGY2cTNIWmZpNjVyZTcydUo1NW96N2lF'
    b'Q2VYOFk5SXU0aDdMVE5CT0QKaXdGR2YwdGpndDhmK1JVaFR0UE1nMmJwMDdySHBMUVBkQUFB'
    b'djNTelBoRUJnTitoYWRjdUFBbitEMGF0K3lvemZtcTdpTzhQQXdIeQpETTNzeEpLTEFVYi9m'
    b'V0tRRDRSQnY0aTdLRHRWTTlTOTVvVHJ4NlVUNStmSng3Y1NLUUZBVWlLdlhWRDd6VVIyeWxU'
    b'V3JwSjdYK2dQCkN0NUxsWk0xWGNIcFpRd3craDh6S3ZqcUtKZ1UvRlROWER5bElFc0M0ZVU5'
    b'cE1IRHV5YUFVdTIxT2FFUjQrcUJxWi9keHVQVlVTQkIKcnRMTWJpeTVHR0IwUUkyUVk0MUdi'
    b'eWhZaDlzU3dIKzZxZDQ2em1JNWJaUzdTak93NUdLQTBZRmlXUEQ3UWo4RytTclYySHVFM01m'
    b'agpoeU5mQVhLcVpuUmd5Y1VBb3dNVEIzZzQ4amZ4dUlXeVl4Vk5CZkpRNUU5SXNZaXBKNms2'
    b'M3NhTUFVWXZEMlVobm9yREdPUnhxcDRqCm1Gd01NRUxvQUlNblpvUXd3QWdoRERCQ0NBT01F'
    b'QVlZSVlRQlJnaGhnQkZDR0dDRU1NQUlJUXd3UWdnRGpCQUdHQ0dFQVVZSVlZQVIKUWhoZ2hE'
    b'REFDQ0VNTUVJSUE0d1F3Z0FqaEFGR0NHR0FFVUlZWUlRd3dBZ2hEREJDQ0FPTUVNSUFJNFFC'
    b'UmdoaGdCRkNHR0NFRUFZWQpJUXd3UWdnRGpCRENBQ09FQVVZSVlZQVJRaGhnaEJBR0dDRU1N'
    b'RUlJQTR3UXdnQWpoQUZHQ0dHQUVVSVlZSVFRQmhnaEREQkNDQU9NCkVNSUFJNFF3d0FoaGdC'
    b'RkNHR0NFRUFZWW9YOVkvdy9NaEJIWldPUW5nQUFBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VB'
    b'TWpBeU15MHcKT0Mwek1WUXdNam96TWpveE9Dc3dNRG93TU1PNVVhd0FBQUFsZEVWWWRHUmhk'
    b'R1U2Ylc5a2FXWjVBREl3TWpNdE1EZ3RNekZVTURJNgpNekk2TVRnck1EQTZNREN5NU9rUUFB'
    b'QUFBRWxGVGtTdVFtQ0MKIiBpZD0iaW1hZ2U1NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'ES_NC')

ES_NC = b64_ES_NC
index.append("ES_NC")
index.append("Spain Navarra")
catalog["ES_NC"] = ES_NC
catalog["Spain Navarra"] = ES_NC
country["Spain Navarra"] = ('ES_NC', '', 1)
lookup["ES_NC"] = ('ES_NC', '', 'Spain Navarra', 1)
lookup["Pamplona Spain Navarra"] = ('ES_NC', '', 'Spain Navarra', 1)
lookup["Spain Navarra"] = ('ES_NC', '', 'Spain Navarra', 1)
details["ES_NC"] = {"continent":"Europe","capital":"Pamplona","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_NC"] = ('ES_NC', 'Spain Navarra', 1)
regional["Spain Navarra"] = ('ES_NC', 'Spain Navarra', 1)
#----------------------------------------------------------------------
b64_ES_PV = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWVzLXB2IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI0Q1MkIxRSIg'
    b'ZD0iTTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwOUI0OCIgZD0iTTAgMGg1'
    b'My4xbDEzMy40IDEwMC4xIDEzMy41IDEwMEw1ODYuOSAwSDY0MHYzOS45bC0xMzMuNCAxMDBM'
    b'MzczLjIgMjQwIDY0MCA0NDAuMlY0ODBoLTUzLjFMNDUzLjUgMzgwQTY5NDExLjcgNjk0MTEu'
    b'NyAwIDAgMCAzMjAgMjc5LjlMNTMuMSA0ODBIMHYtMzkuOGwxMzMuNC0xMDAuMUwyNjYuOCAy'
    b'NDAgMCAzOS45di0yMHoiLz4KICA8cGF0aCBmaWxsPSIjRkZGIiBkPSJNMjg4LjEgMGg2My44'
    b'djIwOC4xSDY0MHY2My44SDM1MS45VjQ4MGgtNjMuOFYyNzEuOUgwdi02My44aDI4OC4xdi0x'
    b'MDR6Ii8+Cjwvc3ZnPgo=', 'ES_PV')

ES_PV = b64_ES_PV
index.append("ES_PV")
index.append("Spain Pais Vasco")
catalog["ES_PV"] = ES_PV
catalog["Spain Pais Vasco"] = ES_PV
country["Spain Pais Vasco"] = ('ES_PV', '', 1)
lookup["ES_PV"] = ('ES_PV', '', 'Spain Pais Vasco', 1)
lookup["Vitoria-Gasteiz Spain Pais Vasco"] = ('ES_PV', '', 'Spain Pais Vasco', 1)
lookup["Spain Pais Vasco"] = ('ES_PV', '', 'Spain Pais Vasco', 1)
details["ES_PV"] = {"continent":"Europe","capital":"Vitoria-Gasteiz","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_PV"] = ('ES_PV', 'Spain Pais Vasco', 1)
regional["Spain Pais Vasco"] = ('ES_PV', 'Spain Pais Vasco', 1)
#----------------------------------------------------------------------
b64_ES_RI = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNyIgd2lkdGg9IjMyMCIgaGVpZ2h0'
    b'PSIyMTMiIHZpZXdCb3g9IjAgMCAzMjAgMjEzIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X0xhX1Jpb2phXyh3aXRoX2NvYXRfb2ZfYXJtcykuc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9'
    b'Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNv'
    b'ZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0w'
    b'LmR0ZCIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5z'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMgaWQ9ImRlZnMyMSIgLz4KICA8c29kaXBvZGk6bmFt'
    b'ZWR2aWV3IGlkPSJuYW1lZHZpZXcxOSIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIgYm9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIy'
    b'IiBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJk'
    b'PSIwIiAvPgogIDxnIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVs'
    b'PSJJbWFnZSIgaWQ9ImcyMyI+CiAgICA8aW1hZ2Ugd2lkdGg9IjMyMCIgaGVpZ2h0PSIyMTMi'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3'
    b'MEtHZ29BQUFBTlNVaEVVZ0FBQVVBQUFBRFZDQUlBQUFDcExyNjVBQUFBQkdkQlRVRUFBTEdQ'
    b'Qy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZt'
    b'QUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFqCnNFbEVRVlI0MnUzZGVa'
    b'eGtWWDMzOGUrNVc5V3RxbHQ3VjNkWDc5MHowOU96ejRBak80S0M3QmdRRURSUlRGeEQ5Rkh6'
    b'dUdBMENzU1kKUkJOalhJbDVpQm9nQmdHRllaRmhHUWFZZ1ZtYTJYcW05MzJ0ZlYvdWRwNC9w'
    b'bGtHaHA0WmlOTGc3LzNpeFV1NnE2NzFPcWMvZGMrOQp0eFkyMk5VTVFzaGJrMEJEUUFnRlRB'
    b'aWhnQWtoRkRBaEZEQWhoQUltaEZEQWhCQUttQkFLbUJCQ0FSTkNLR0JDS0dCQ0NBVk1DS0dB'
    b'CkNTRVVNQ0VVTUNHRUFpYUVVTUNFRUFxWUVBcVlFRUlCRTBJb1lFSW9ZRUlJQlV3SW9ZQUpJ'
    b'UlF3SVJRd0lZUUNKb1JRd0lRUUNwZ1EKQ3BnUVFnRVRRaWhnUWloZ1FnZ0ZUQWloZ0FraEZE'
    b'QWhGREFoaEFJbWhGREFoRkRBaEJBS21CQkNBUk5DS0dCQ0tHQkNDQVZNQ0tHQQpDU0VVTUNF'
    b'VU1DR0VBaWFFVU1DRVVNRGs3U2Z0MWROZW5jYmhiWXlWbnR0T28vQzJsTXlNenFadUJYaGQ4'
    b'Qk1oZnlzTnlOc3pZTTQ1CmpjTGJVcm1VSHQ3elBZQzNyL3VjNmdyUWdMd3RTVFFFYjFlcUs2'
    b'RGJmbkJPOVZMQTVLM25SdzkzVCt4L0VzRDI0cnMrZmNFR0dwQzMKSlRxSjlmYjA4TE83LytX'
    b'aHpUWktOa3IvOHREbWg1L2RUV05DeDhEa0xlTzJuMTVvWWp4dmFRQTBNUytoK2ZwUFBFVERR'
    b'Z0dUUlcwdQpGanQwNkpERDRaaE9GcTUrMUh4L3M4bHQzRDBwL2M5NVVuM0FiUmpHOHVYTGF5'
    b'TVJHaWc2QmlhTHlPRGdZS2xjTmcyenFsZE4wMXF5CnBKbmJnMTl6Zit1Y2s3NEJZSG5pRzlI'
    b'QU41dWFXM3A3RHcwUEQwOU5Ua215NUZKZFM1WjAwTkJSd09UTmtjdmxoa2RHRGIzYTFkVTEK'
    b'TWpMcTlma0srVnpuOHE1OXoyL2Q5dmpXM05TdldpSmQ2VlRLdG5sYm5hOW55OGNuR3E3Umds'
    b'MU55N3Y2ZWc5NU5PL2M3R3h0YmFTMwp0MWRSSE8zdGJacW0wWkRTRXByOGZuSE85K3paeXho'
    b'cmFJajI5UTFJc3VqeGFLYWhGNHJGMXRhMnB4LzVGOVhKOWRUdkd2MERobUgxClpEN1J0ZjRh'
    b'enUzZVBYZXRDdnhVa29TcGJLY2NPTDlTWWFlZi83bVJrV0hObzRteVhDemtUY1BxN0Z3Nk9U'
    b'VU56dGV2WDBmalRIdGcKOHI5cFlHQ3dVQ3g0M0o1UUtKakxGeFJaNnVzZmFHMXI3ZXZkWDF0'
    b'YlZ5NVprOC9jbko5WjdqWWZWcXVGcGtneTRKTm45ZmNyWlZsVgpuWnh6aDBPV2d0ZlVPWDdy'
    b'VUFaU3BhUmdldlp2TnpPeGcrdk8rYTVUZGMvTlRDenZXdDNiMXkrSm9tNFk2WFE2a1VnVWlr'
    b'V1B4N04wCnlSSWEvRVdPTGlNdFVxbFVhdGZ1N2wyN2R3UFFkZDNqMGFhbnA0Y0dlNFBCUUZO'
    b'ejgxamZwbXExVWsxdTduM3lBMU83UHg3eERycjAKemJJc3IyMmZVYlYyWmVsRHdabzJuM1BX'
    b'NlhTcXF1cDFUb2ZybHNoTEhsQzF0ald0czdLc3VJeUhhN1doeWQwZjc5MXlqWjU2dEZvdApq'
    b'L2M5ME5UYzdQZjdoZ1o3cDZkblBCNU5yK29BZHUzZXZYdDNkeXFWb2htaEpUUTV0bmdpVWNq'
    b'bjI5cmFob2FHSEU0MWxVbzVoWGd4CjNUMFRWOVpzdkhKcW9uOTI1R0Zmc0swNmRRc1QzSnFi'
    b'VzJaRjhtNmNualZYMWoxcDVRdHpCOCtzRmM2U3B1ZFN0UTlOcWVxcTk5L0wKdVgzZzExYzJW'
    b'M1J2NGlJN1dqTnJiYW5yZWtyMGFBZm16bTZzRlkzY0RsRnk1b3ZnZHNuUjhEZlo1SEJkKzRV'
    b'TlRjdjI3YmludnFicQpDbXpRZVNRUUNGUXI1WTZPanBHUkVVM1R3dUV3VFJNRlRJN0NzcXk5'
    b'ZS9lRndtSExOQnhTY2FUdnNmamt0bHB0S0lYTFRlNzErbXZOClFuZUkzMlhZYnArYWhuYlJY'
    b'SGxkTVpmd0ZHNzNkc2ZzM1lISWxPeTI1emMxL3ZIcENXVmx5L20zQUJoNzVHK2FLajNOUDRz'
    b'ZS9sVlIKUUR4cXN2WHA5UHBJMmY5QnR6Y1VVWjluK1FlejVhQXNGSlBzYXRtelBwZU5pVHdU'
    b'WkwrZExTeUxOSnpTdnZ5OHF1a1NSQ21aVEt4Ygp1MVlRYU9GR0FaT2puYVBhdFd1MzErZWI2'
    b'L3Rubm45U043ay8zR280TDJsYTlqN0cyTmkyUzJ6YnJQRWJ6b2IvbXlpdnlLVjY3S2tmCmhw'
    b'NGI4V3p4aFVyeUVjdHYwUlIvTUhIZ2FibitKTlcyRWR0VDdqclZ3R2VhQTViNDhwdmxGRE45'
    b'ZWpaeGVvdlk4bGZlOElxdzgyQmwKNnAvaUdaa0pVdXRwbXpqbmszMzNTdFZObWNTWUxESEJj'
    b'MDVkMStleTJjdzdUajZaWm9vQ0prZm82ZW5SZFNNYWpjNE8zNUVlL3BGbAp5K0ZJVTdqemJ4'
    b'dGFUK1djUDNyL2R4ekNKSEwzK2V2ZjNYbnF2d3Fpc3VsYlZ6ZVBQZVY5MWhYS080NjZ3ZEcx'
    b'MmZJVnFTWHR2S0pqCmNwS3A5d1JiOS9xT2VzdXNhcVRmV1J4dk8vMkNMOS9CQkx0djIyZlNN'
    b'MDh3MzJWVjN2U2VTNzdBR0pzYzJaYnF2eWtSbnhDWUdWeHkKUTIzcjFkUFRNNG9pcjF5NWtp'
    b'YU9BaVlBOFB6emUyb2lrY0g5ZDlYeGY4emx1S3ZwaHBXbmZvVXhsb2pQUFhyYitvQTJoNkpu'
    b'dzhiQwo3djk2UjNUQXl5WkdHcW9MYlcyc3ZTQmZsQzJyVnZNYXM2Smpyazl5bFVUalFWL0xz'
    b'R2VCZTgwcHpHaG9udXJNbi95bnU3cWY4OWllClFqWlhlODZmUGxjYmJlS2NIOWgrUzJYeXh4'
    b'NFBteE8rdUdUMVZmRllqQzQ0TFFaME1MTW9oTU9oMFlHdFRlenJNeW0vdSs3Q1ZhZmQKeURu'
    b'dis0Ly9qRjF4WFgwcDNkd0FwaFczYjVZQzhxSEd3V1BVQzBEUzdNZ3AxZFoxSmdETzBiYldq'
    b'SnhTbFRSNzRYdlY2cnh4WkN5bwo5RzdmTEFsYXNhMEJkWVZNNWsrdTYvditEMDFkWDMzYTEx'
    b'eVI5ODZtL1kzNCt0akFVK0Z3aUdhTkFpYnpHaG9hdkxtdmVOVUN1Tzd3CnJzdE9UL2U4Lzdx'
    b'YWIveGRjSHlNZTAySERNM05BKzFXTWx4TmllWXh0NlluQk02Uks0SXhNSVpjRVp4RFR4eDdy'
    b'bE9pbVF4WC9lMlcKeDhNVkdkeHYrR2RtYS83cGV3T1hYWm5vNzNmNE5vRHJQbGRCeTkvWTJO'
    b'aElzMFlCazNuVEU0Y2kzdkZjMmFkSVpucDJadmFESDJuWQp1UnRBTEZoZXZzRUdzS1FaeTlx'
    b'NHY5bjBXUXU5OW1iQ1g5bHphcUo4Y1VZUUlEQ1lGa3dMQW9NZ29IUnhaczlwaWFsQVpZRzdl'
    b'eTB4CjBHcDJ0dkVselFEUWRaSTlGeWdEcUR2WWwvN1FSNU5qazRwazVzcStpRFk2Tlg2UVpv'
    b'MENKckJ0KzFjL3VhaDN5MlY3KzUxamNjM1gKY0lWN3ExQXpPSEw0dDV5aHFnTkFxUUxkUUNy'
    b'QkZ2NlFPdEZqcmI0aEY1ZU1nVis3RklFVlNpaVZvUWhzNE5ldXBHeXMvc3VjN1YxbwpCNTdX'
    b'OUZTQzZRWktGUUNvNm9BNGY0b2tORFBuM1dvSG1xOGJqYm4zOWp0N3QxejIzeisreUxadG1r'
    b'RUsrSTk3QWdUaGlqLy9qVDk2ClhrUEV5QmZFVExKV3VQZnVGMy9MVkc2WXNEa3NDMDRISWsx'
    b'ODEzdG5lMjRjUFZpZmYvV21pb28xMTFiYWM1ZTZkaDFuSjVjUDltQXEKcGt3bm5mdjNnNzJq'
    b'dkdZdGYvNHVOZEZjTHNoSGFiZ25tajk0NCtqdUMrWnFvdHpwZ0dYQnNtRmFnUHJTT1U3MjRL'
    b'WlVLbEFveW8yMQpoajk2d1pWLzhSdTZJRXdCRThpeXN1SGRQN0tVZFV2ckoxMzZWMnk5L09L'
    b'dm5xekxGREpDb1FSUnhQT1B5ZVU5eXRrWG14QzRXcFFxCjRoRjd2N3hrSmE2ZlczWjkzcm1t'
    b'cXJsUlc4T1pMMUN6NGVIbTA3YUl3YnJhTU5mY1VOZFVsMzRrbi94b0xDOWJMNzl2UmJUVmdz'
    b'UWwKZnZiRlpubXZZODhUc2lTaVdFWXVKVHhabDNueFpwWlpjcFcrdExSKzBwQTNiSGozdjht'
    b'eVFuUDNwcU0zTXl5Vy9iQXpmSVdjM0IxUApPNEsyQTVpUHM1MHBnK002MTFZNVpvY2FPaXVh'
    b'bDgvRVVSNlhtNzQ3azRxSjJUdDlIdUVNdm1hMTkvNEhwV0xLR3BYbDB5c2hEeko1CjZBYXFs'
    b'cXBxVVZGU1ROdFRyc0t5RWZaQWtXR095T0RJK1B5NVN5OWsrL2FWK1RPZWE3UGhHcXQvcXpM'
    b'cjFldlBxdVN6YkUrL1dtVWQKck5EVHhsK3ExR000RWlYRnIrbFN6UlcwNzZXQXlSRVUveWxX'
    b'QXFaWkhmamlwUFd3WStQeklRRHBVTlViWHJmK2d0K09IZnl2YXV4Rwp2NGlBRDRFemRFbUNw'
    b'ZHBWaCtYNC9PZnJPanJtQk5iMml6czh2NnVaMnVOSkxpczBmU2h2emtwUmJXYjRxWXZCcElo'
    b'anlKeVZuTTNtCjNIMXVjOERUTWFjQ0dMNzhvcnBQZjJKMmNMRDh2YTB1MVpZa2RKdzVmM1Jk'
    b'c1hpbzgrdk5YUi9zZnVqU1FtM3Y0Ui91MkpDVTNsc1YKTE4zbWtMMm4wbnhSd09RSVRlMW5i'
    b'SDFhTHBTTWpxWktUOXVhL2UvN2dQYkFNKzE2b2lETTVMTlRsaVc0RlFEZ0hJTWpTRThKSFUr'
    b'RQoxMDE2bnZudEwyZlhNLy9PZ2NNYjBXS0srNlo4Y3A4akcyTXJMcWtFelNFQXNvU0Q5eXRH'
    b'Um16KzA3end5ZURoVzFaM1BiWG5pVm03CjJ6NWpWMmhnenZIVU9ZbEExRjdTQnNhZ09wRzN4'
    b'SHhtVW1Xek5SWEg2TVlOK1l0UHkreTljM1YwNThBNEg1OVZ6anFmQXFhQXlTdG0KUXBLR3A3'
    b'MGJPcFBKREpvdXZiSzU2NnJCK3JxdVQzUWZqRXdmeXI5YkV2U0dEb3hObzFSQlE0alZSdXhF'
    b'WHdXVG5sVy8zankyY3NKWgpqZ0J1QUY0dWp2OWxvOXlrcjdvcGxpL0M2d2FBWEJHckxxL01m'
    b'aTJTKzZuU3hPZGZEcTJVRG1uVnJXMTNOd05pTGxwWnZzNkd4WHBICnVNdUo1bnBNRE55WTdK'
    b'ZjlrN3pqc2ZyZW4xN1JzZVpNdVZsUFR1eHNybWZkZmQ1ekpmcXpvWk5ZNUVpNVhNNFJ2aVNa'
    b'VlJycllDUnUKMzdINUswUGJQaTl6RnQ0Y0xHVktxNWFZVGdVdFVheFppblFLaFJ2clZqNFhB'
    b'bEJ5MnE2Y1pGeVFMcjF3WHFyWlZKaG1HMVZrRHlrNwp0MG83bjVTeWh4U2pDc0ZyTjVzS0F3'
    b'QVVKY3U0TU9QTVNUbW5CV0RsczZIQ1Yrc3lLYXhaaXBZb25BcFdMVEh6eVhKa2MwRG1iR2o3'
    b'CjUzYysrbFVqZm50REhSSnB4Ukc2dUZBbzBIeFJ3T1FJYnJlN2M4T25wZ3Z2TkhUSXhyN000'
    b'S2IxYmZHeDVmbUd1SHJxejV1TEJUWTkKeHlZbVVhbWljeG12dkNmblpBeUEwVnBWRHFtTzdk'
    b'clVsZkdxTUgvcWk0L0txYzlHN1l6UThuQ281WkdRblJKU240M2FvL1B2V0tvSwo5c3hWTWVm'
    b'VFhtZWZhclpVQVRnWnE1eWZYYmFNVjZxWW1HQXpNVmJJc3pOKzBSeE5xS05kK1hXdDhjelEv'
    b'Yks1WDljeGxOcXc3S1JQCnVWd3VtcTlGUXZ6R043NUJvN0FvbmtvRklSS0pPTHhybm5ucWQ4'
    b'ek9hYjVxZmtKcHVxeVE2WGJVNUJ3SGhXb3hqOUREb1ZpQkQrK1UKelFGSGZkcVpWODNLdFVs'
    b'MWs3OWgxSk5Uek5RbHFWS0pwUTFiaUpyRzVSbXgyOVBjcDNtelNrNnl6UXV6VWtwT0czYSt2'
    b'Wks0SWlIdAo4N1R0OVZYU2dubGxtdTFWQlZNWU5ZekpTYVpQeU40dC9waWc1dzg2bHZaN1p5'
    b'Smw3MS9IaDNvVVQzMnhVTUtoeWVZekx2MlBWYXZYClM3U0VYalRvM1VpTFRybVVmZkxPRlpv'
    b'eU96NmhMdEVNWGhZYzl3WEMwMnJpaTVPT0g5U0djbzZKVTlMRjFVVkZGNUlPdzlIdGFaeDEK'
    b'Nmc1dTJOejJXOFVWSmQxbGVTRHdVY1dabHQwT2NJNlNqbXJRNE0xNmtkbHFXWlQydXBTQ3FJ'
    b'b0NMN0haK25KbFhiSFdsa3FTN2Q3bgpibm91a1BCVzliK2NDLzlqWXlKYXJsNmVodE1lS3Nn'
    b'dFRlV2NYbi8ydFQycXkwY1RSQUdUWXpmODlKM0xSaVlTUyt1RjZEOUhwODlQCkZXcXI3b3dj'
    b'empsNGpjSHFERnV6UEJIYjUvbGYrUCt5YmFTU3JKSVdwSkpvWndRaExzZmRlc1ZuZUthZHRa'
    b'dURVNStkSG9yWnJVMDEKWjE0NzRGVHBvMmNwWUhLYzU3U3ljMC9kMGU1UnE1NXhoMzlOMVJ2'
    b'a3BvVllDZ0FZdzh0Zmd6eVRrSkpaYjJ0ZEt1UkhzUXhCZ09iRwp4Q1FyNzNNd2d3SGdNbGZY'
    b'VnBzYWVMNEkyNFpiUlRLRDBkbGd5SmVyRDgrL3JKSXhDQXcyQjJNSSt5RkxTTTBLMmIyTzhw'
    b'SktvZUk4Cjg3cGhyNCsrejJFeG9vT1pSY3FwK3NLUmhwYlEwSXk3a2pPUWozRlJZQjRWLzIr'
    b'M2Q2V2FPMjAxM0NvQVZIVmt0WC9vV3Y2K0EwOWMKM3huWUdnNEFBT2VZZWNSNzZvNlgzcko3'
    b'WURicCswelcvOEllZENoOTFoa2Z1RzMwMEwxaDZhOGRDZ0FVeTlpMkh3Y3J2dXMzWkZOWgpt'
    b'QllnMlBLNmNsTVlFNmtHajBZZlpMZFlUNTNRRUN4TzZjUzRSeG9ibWxSNjAxY1hLMmlJTUVG'
    b'a24zbXU3VnY2U2YrUVdISDNZNGV2CkI2RnF3T0Z1bENURjRhcDcrZDI1Zk1UQ3lwYU8rRStI'
    b'V2k5Sml0UGRXRFhtZjNMUDQrd2ZVaXYremp6cC8reG9Zd0pyaUNCWFFGLzYKbXBGcHhTMk54'
    b'dWRHYVVab0QweE9RRzEwMmZhREY0ckI0VE12K2U2MjMvUjFXSHR6UllSUlhxbkhydmNOWFhQ'
    b'cWZKQmVOL2J0L1Z6Lwp6a1lQMjUxeEk1dWZYMEpiNStXZWFDKzVHR05BMGVhaHBXWW1qMXdC'
    b'a2dTbmd0ejByNSs4ZDh3ampuZTg4TEZXMTE3QWhlMURQeXNJCklhV1NLeUxveFd4eDNSbnYr'
    b'ODZlVFFkaUUwdFhYdDVPTTBMSHdPVEU3RG5udkwzdlBOaDEyVThUdzdlMWUzOGpDQ2lXa01v'
    b'aUhEemkKTU5qcmduYmlaN000UnlxTGl2N1MwYTl0STVORHdBZVBDNXhqSVAwbm9mWVA5OS8v'
    b'eWRYUHJWejMrQ00wSGJRSEppYzROMTFkVXJ5SApqMTRqbHN5cWlvQ0dnQmVOZFNoVk1EUEg4'
    b'am1ZSlpaTmc1VUZJeS80dU1US1RDa0xsU0pUR0hPS1FzQVFaZ3NjUUoySHBXVzdZdGs2CjUw'
    b'Nk5HNnB0TzNpV21iTFhodFAyQmlHcFhQUHlhQzBhYXdHZ1VFSzJBTEc0eVJwNVNFbjRwZVZk'
    b'TkJlMEJ5WW5UQytWSC96Sng1YTIKM3hrSlluQ01qUSt6Nlg1eFM3ZTlOT0ZSRFNGdjIrc1VS'
    b'ODYyUTRMb1pFS3pKRGtZY3pJbWcvbGU0NzErV2RzMndDdWNWemtmTjgwSwp0MU8ycFFuQ0hy'
    b'M3FGWVN5YlBkSEN1OWFKelIwV3MxdHZLT0ZKelBvSGJqMm9rLzl1K0pTYVRvb1lMS1FCMys3'
    b'NlVmL2VlOHJHNjdrCm1URmcyYXhVa1BVS3R3cDIyZVkrZ1hIQTRuQXh3UUlYd1JqZ0VrUkpF'
    b'QVZBQUNRR0FQckxKdmJ3RDAwT0cvUC9WTGx0V0tZT1c0S1EKNTdiTUlBSlptNnNpazkyQzB5'
    b'VzRQSVlrMnJhOHpLSDZBWmlXOWVLZnlwOWRkK25WVjcyUHBveVcwT1FsV3pZLy9rRGJkVytK'
    b'aHhwOQo3QUVLZUpHZ3kwaUxWSURGRnNrak9kZS9kYU8yazJhRUFpYkh5OHV5OTUzNWhYUDhU'
    b'NzM1S3pSZS9lNkc3Ly85Nmg4QWRLaEZBWlBqCmM0cC9kMmR3N3NyR3g5N2NoM0dxZDJlOU5P'
    b'NXpWbnhLc2NNNWZKcjNPWm9hT2dZbUMxbm4yZnZscnA4L09MYkJzbGk4N1B2NStpOTEKcDVi'
    b'KzY5aGYvT0VmaVovUC91YWNyMmFyNnVhSjFWVlRlZUk5TjNBYkhmZmZZNHAwUnBvQ0pxOUJZ'
    b'ZFUxL3VHQWxOc3gxeEVSSjZPdQozRkR1emZuNGl3eXIrK3F1ajZRSzRzbitmZHcyUDczMTQ0'
    b'clRRZlZTd0dRaE8vSWIzL1BZOTk3aDNYV21mMmRNRDk4eWNNTXNiM216CkhzelBwcTVya1Vj'
    b'dWE5bXBjMm4zekR0bmNsR2FJRG9HSnNjd2JiZkd6ZnF6MnNhcm9uZU90L0EzZFk2S1hIc3F2'
    b'dmFKMk1ZSzZHTjAKYUE5TWpzKzJ3dWszNzBrOWtMclFadlAxMXZBSnAvU3FyeFcxYmJ0YVht'
    b'QTdsc1hFak1STy9BRVlvalFYV1FZZ1lZWnZuNzNDNHBJQgpCODBMQlV5TzEvM3BTL0d5OHI2'
    b'MjdBY2ZXUG44VVc5WnlEQzNqN09qWlRvOUlUUjh1ZlYxN01HM3VHcXV2UGptdy8rN3d0MDBI'
    b'UlF3Ck9ZYlhkNWwxcGx2UjcvVk50Rlhxenl2N20wd2FSam9HSm04WjVSTEwvVlpyR2RFYXUz'
    b'M3hSK244TUFWTTNsSlVGMS95dDhtNGFCU1gKbDVaOEpFOEQ4c2U0aE40MDhrTWFoY1ZnSW44'
    b'SW9ZdFA5RjR2SHZteUV6bFY5ZCtuVE1raTQ1ekxLZm55M3FOOFdoMWZjR3N6aFNINgpzMWtz'
    b'QWQ4L1RET3hPQUl1bEJGYUlOU1hqcEVuZnVHMVc2c3RaMVdQZXN1K24vaUNwNVpyMXVxditI'
    b'bFZ0QWRxaW01RHJNaTJ5ZEhZCmFTWnlYTWpLby82eUtDRHJORlpOZTQvem9VNFhCKzhmSHFB'
    b'cFd4UUIweEFzRXV6NHptTEZkem9jT3oyT25Wcit3Zm5QMUFsWWtyN2YKbmYveS9HV2VscGc4'
    b'azVMVWhyUW5mTVEzZ0k4SHl2dlhwMTJNRlcyT25HZzg3aTZGcTZiTDJIRkczQ1d3VkpZZmY4'
    b'Q0Vqb0hKNnlTcQozQlk1OTFnOGJQS3dhWWROenJqdHNBLy9KdytidHN4dDJSYVZWOTV4YWNJ'
    b'ZGpQRDhyS2lGN1FaTEtnTVdSMnRTaFdLTHBoQzFqN2dECnZmT0k5c0RrOXlLNFNwODhQWitQ'
    b'R2syblZ3SFlOcExYTzYxbDVib2JVZ0E0eDhCdFd2aVVpdXExWDMzZlFna2RPL3g5RFRIUjR2'
    b'SmwKV1NrbTJNODZxNE9PWlZPZTZlVkZHbHNLbVB3aE5GNzFtbTl2WUF6TFB2cWFwNk9aZ0gy'
    b'bnBRSXVxQ0tyV0pBa0xqSll6WlVERWFPbQpwTkRBVXNEa0Q4MjA1cGU4bGcxeHdlT2h4OCtj'
    b'alRUWjd6clhpaWRaeGx0WnZRcjVJdUlvWHZCT0hrdWIyV2xyYno2OWRuOWdmZ25OCkdJMHRC'
    b'VXhPd01LSG5VY05LcE5pNlcvWHRKdHk4WUI3NkNmV3NrOW5GOXFDWmsrTnM3MEh3QVFPMCs2'
    b'ZWhtRnl3VEozUFFTUnNhZ20KT0IzV2NUNVV4aGtkSmxQQTVJM3krTGdkZHdpQVZwQTFXMXo0'
    b'eG5VRGJ1ZVZsV2FHc0ErcExBLzZrTW9pRk9BQWtsbWV6VnZ0dndyUQprTDdsMEZub3QvS3py'
    b'NGhxY1A3YmpYallPTVpNVzRJb0lKWEZ6SjFlcHlFbXN3ajVrZDNoekR6alRHWEFPUncyTFpz'
    b'cFlQS0h4U0l2CmZEOW96YkhmeVdEWmFLbUhkMGhOaklsTG1sSFdvY1JrWmNiWlZBL2psZmVt'
    b'bUdrSlRVN3NJUGoxTk1OZitJSmZIRWZBTGhXelNWajEKNWFaNlBwTkF0QWI5WHROU3JFb0M5'
    b'TlVMRkRCNU00UU5BRlZ3cGU0WXA2QkVoa29Wa1NDaW44L05KbEVYd2t3Q3l5NHBBNWlZUXpK'
    b'RgpRMGtCa3ovOGJqdHNBa2g0cW5VUmUrRmI2ckt0S0ppSlFSSVJDV0JxRGtFZkNpVUFtSTFC'
    b'YzZIc3NEejZjUjFTMFFsb0NwaWM0TEV1Ck9FeUd2R2pablhCZEpaazNBK0NhZFRqZytZVjBj'
    b'aGxzaituL2N5SFZEWE1VdmwzQS9JczY1bHpWM01XcHFBL2xNdEk1NkRyRUhqWHQKc3UyMnFx'
    b'NGpGSUJIUmQ5Vk16VzNONytRNklMcmVVWUpVOERrUkZVMGZjbVRjRGk1UXpYdEQ4c0hiaFh3'
    b'OStGV0t5V2FoODlnMlhLYgpzZklIRUNRTEY2R1VjZ3hlOUdMQUpaRW55M3ptRUZycWtjMGhN'
    b'S0V1dTd2T0VQbUJEMCtwemNaTUVwVXFtSnV5Zk91aHM5Q0xhUys3Ck1Lc29QdnZQa0IwUVJL'
    b'SHZPU0g5UzNBNEhLZ0VEUjQyWVFNNWh6RGFEVkVDWTJMZlk3eXk1S1ZwWnJ3dUJGbUNVNFln'
    b'd0h2QUxYQ20KbWtMZGdDZVpnU0pERk9FUUdDMlNhUTlNZmwrTXV0L1o2NVpCWUFEc2xhZnJi'
    b'WTg1ZGw3TUd3Y1JObEZqSXVzdzEzK0xlMzBBSUlyVwpPNjdsc3h2UmUrNkxkM2VyOEtvb1Z1'
    b'QlVVRDQ5TjNOMXlxNElwVm5SN1lKdUlhQ2htRDN1WnhxNnhrUUJreE9XbitiUnpoZmI0WmJK'
    b'CjNiTUFlTVRrWVJOdWc1V3o4d0VmenF3d0N5QW5XUG5HU25sbDBhRmdlVHRDZmdBb2x2V1pF'
    b'VUZTN1k1M21ZekJNREVkZ3hDeEo5ZmsKcENGblhYSGhOemJRN3BrQ0pxOWpxdUszOHZxMTNC'
    b'c0V3S3BsWVh3N0FnVUFac0JRNmt3b1hKaDZ5SGE5SDU0QUlMRDB0QmkvbGN1Mgo5YS9qMFNB'
    b'SFlOa1luVUltajN3UkxWRXd6VzV1d0s2RHFBK2hhc0R0UWt2VXhwY1Nwb1dKZmlteHgvRkdG'
    b'dnVFQWlhdldMVnlWdiswCk5QQWgyL2tobG90QkxZcXVueDcrVlR4VVhWdHZBeEI5dHdpOVQw'
    b'Q3ZoZUNGYXh1TDlMTTQ4aVdNakRGSnhWeUdyMW1LOFZrMDFXRjAKQ2sxMTJOdUgxbnBNenFH'
    b'cERycUpIZnNSMWxpMWlQb0dLeUJYY2VDMWQ4QjBGcG9DSnErRDROOHY0RXR3SHZIRGhnMlc4'
    b'TUs1U0JaOAo1b2pXYkNTTHZLa1ZrekdzWG9hWk9GcWptSW9oV2p2L2J3NGMvdTZIUkJydGpa'
    b'aU04Y1lvMGtVY0dscG9DVTA3NEVYMEowRkQ4SmIyCjVMUjJidmZHais1Y1BwS1dqM3FEc0Ir'
    b'VGM2Z0xJWlpBSklqSk9VU0NtSWxCa1pITklaNUNYUWd6OGZsZjFZVXdPUWZOaGZyd0F2MXkK'
    b'Q0pRd0JVemVzRHVIdzlmdFdSdnpCVGFKN2UvdE8vM25mZUZYSDZ5bWM2Z05JNUZCMEk5a0Zy'
    b'VmgyRGFxSnBycUVBcUNDWmhMSWVoSApJb1BhTU1vVmVEVUFLRlFXU0pUVE1UQUZUTjZRVGFP'
    b'K0M3YXUrV3hQbHlHSmg2L3FaSnllTDVVM2ZyUm5kZFZncjJndG1ZSGZnMXdCCmZnK21ZeWhX'
    b'c0RJcXBHNE5scjVmMCtRVzNVN014T0gzSUplSEpNSGx3TmdNTEU3OVVzRGs5NEJ6ZkdqNzhv'
    b'L05uZEtkOXdFQVkyQ0EKS29OejI2MXM4bmV0SGJ2ZzRka1hQbURhWXBFUUFPUkwwRnhJWkJE'
    b'UVVNT2s2czIxYlR2OXJZYzA0NWJha0NtRi9EeVpoY2VOVEI2bQppYUNQZTdJeUZVd0JreE5L'
    b'ODFqaEFvZHlybE1lTytuUmF0UVNHRGlIQVBpZE1HeFlOalFGTGdWQVN0WCt6SHozYVlQbi9t'
    b'cTJubGtzCmQ0Yy81SWNrSWwrQ0lpTWFaTWIzdzVIWS9Mc0hhMUpPKy9zMUViY29Da2puNFBk'
    b'Z05nWEhzT3A1TUxqQUk2RVhjbERBNU1UMHA1U3YKN21zNzc1bjFJN2JIam5xaDJ3Q2d5bEJs'
    b'T0NRWUZzb0dkUFBGUTk5Qk5meFgxcGxuNWM3djJCNjA5amlyQm13THpmVklQT0NwbnpuaQpx'
    b'N29qY1RWOXIxWWJncXBnSm9sMnQrVDdSWTNUV3ZnWW1DNGpVY0RrUkh3dnYrTGZ6ZVc2Nm9S'
    b'ZmhTeUNBU0tEM3dsUmdDUkFZSEJJCktMOFE4QXVIc0htUFd3REVCd0poUC9JbGVGd1E5cmhl'
    b'dlhGNWh6dmtSeVlQdndmbFRacTNKQi9qMGRBdWVOR2c2OEJ2RVl6REJEUUYKc2dTSndiSVJk'
    b'QUZBK1lXUHdwTEYrVVc0eldGWUVFU1k4KzhRYm9pcHovU0hIMG0zNmxxc2M5WSt2RnAvWEt1'
    b'ZGRQdE9UVTB0MDR2MQpPV2QvdjJQYlROT3FsdEx5ZlFJV3Z0VExPYU5YVTFMQTVBU1BrQmtr'
    b'QmttQVI0WnV3LzJxbHl2bktuREswQzFJQWh3aWJBNVpoR2xkCmRPbVhkQzcwekVVRlMvL2hI'
    b'bWZUaGFsV016Y3V1TWNjZFFCRTIxeGx6SGdzL1VCdkpBc05QWWllbCt3c3h5ZXErc0lGRXdx'
    b'WXZISW4KdTJEQUFBQ1RvMnpDUHRxSGIxZ2NSUjJIdnlCRkZpQ0pVRVRCdHRkdTZGQUU0ZXNk'
    b'bnBQYmE4ZGptVWNHWGYzSjZza2U1ZHcyVDFQQQpjWEN1K01pZ1ZEYjVWWTN1TTlxOCtZcng1'
    b'SWpqWUR3c0ptT0RXZXFYQWlZbnNJL2x4ekZUSE5WamYzZ2REQnVHamJLaFpnclhuTzgxCk9Y'
    b'dHN1UGl6NS92clhjSzdPN1R6TzdUSnJQRS9QWmxFeFY0WlZxNWU2WGRJd29GWTlSKzNUSGlj'
    b'enJOYjNaZXZDTnkzdS9Mb3Z0ZjUKVkVNbzREL09IZkNDV1ZpdTEvT2NBSngzVnhxTUxYZFh1'
    b'a0x5UU1yKzVhR3F3U1NCMjJ2OFpzUXQzSE9vOHAxdUhVQlEwamRFNUtsQwo1WTdlY3NWaUtP'
    b'V2cxZENjVU1Ea2Y0a1JBRVpleDNQQ1BaZjduWXE0b2pGY0xwVThtamFYeXZZbnl2V2EzQlQw'
    b'Y000VlJkazlFaXNaCmZFTnpRSE01QWNRemhRTXorVnVmemorZGUrMlZBbDI3b0lESnEycGI4'
    b'SE5oelU1VXUrRTQ0Vlg1enVuS1ZONTQ2SjdKdUtFczlSaG4KdDNscTNjclBkeWUyVE9nV2NF'
    b'cWRmRnFMcDJ6WTMzazZOcEEySWk3Mm5uYk5MeG83RWpKZTYxMzl0aWxJTmwyQXBJREpFVVNu'
    b'Q1V1SAorQnJkS0xXSU42Qng2a1Qzd1BmMTVzSXU0Zk9uQmFPYXN6ZGVmbUswOEVndXZ5cmkv'
    b'T2E3UXBvaWJSdlAzN1UvNVJEWmV6bzhuM3huCnpVU204dGh3WWYvSWpLNDF2K1pHU3hsWGl3'
    b'blExNUZTd09SbFFpZUpubTE3Q3EwYlgvTVcrcm5JM3duTlBJR05jano0c1RXTXNhZjcKcGdm'
    b'VHh0S1E4aGVuZFNteW5DdFZIajBVUzFlc2ExWUh2MzNaY2dDanNjeXp3OGwydjdOekhUNFdx'
    b'MTFnazU3SjNjMVh5elJmRkRBNQpRbmkxR3J4bndZQ2xFT2JPaGZ3b25QWng3NEp4M2srZUx4'
    b'ZzhyaXNScVpLMEZQZm1lRVRsMDJXaGFNREZqRHh6dHFvVEl0aG9TWEpDCnIxYkxGaVJiOVMr'
    b'd3lackttT3lrMDlBVU1EbVNJTEVReHNZWHZwR3lBcE1jdFZ1Z0djZlhMeTVmNGRjVThjS3VV'
    b'RjFBeXhUS20zdGoKdzJtanhhKzh0ek1VOExyM2o4Y2ZIOHJydG4xMmkxc0EvdXFCcVVuVHZk'
    b'QVdMZE9uVGRCa1VjRGthS3ZvRlhQTzVHZ2wxTHBnd3lzUgppeUQ3T09xbklCNzdUTklOWjdV'
    b'SkwzemlqdCtqWG5WeXk4dC91N3E1Wm5WempXNFl0MjdwKzlFK0l3LzNNUjdoM3J0WGZicE1m'
    b'ellVCk1EbUt0ZytvVTEvKzVhR3p2bmFNMjhrMXNLK1JCdnRNMXdDYzAxQUtrRzF3QmJZSkY0'
    b'TzQwUHJXTk0xVXJ1QVFHWUJTVlI5SmxwNGIKejkvWFh4clVOZUFZWHhHT2FySEZ1ZDBWb3I4'
    b'WkNwZ2NkY1hMMEhMcTJOellqbFRMeG1QZTJGUTd3VHRSQnNvdi9NaTJNSlVDaXBBSwpVRVlS'
    b'R3VZUUdXUFRpY3h0ejA0OE8xMmR5ZWxaSFJWWmcvRHllUmNCN1hnZVh2T3VIMis0MmFUWFlW'
    b'SEE1TFVqZVorYS9PYlA4NUZsCnhvSm5rbDdqTUZxRXF3WTQvQXFxVlppSmMzVlR6M2pzbzcr'
    b'Wm5ERmRnQVRtUHRFcnlTOHRubnMyclRwdldCQkZtcU5GUlR6cHorZ1YKYzR0TDdSbW8vdGVU'
    b'eWJvenVmVEdycldLYmltdkhlZ2U2cGNiM3VCRDBzWjJyZzMvdXYxeXFuZlJvZGZUTEw0cGtk'
    b'akdtNndWMjc4bQpWdk52Y0ZPV3Aya3lFSGlERy9HTlBMT0cvYkx6US9TblFnR1Q0OXgzS216'
    b'akxjYmE1NzhZSEgzdWpXem5DeDAvKy9GSjMyYXdYdjl5CllOKzlHeU8zci93VXZZT2ZBaVlu'
    b'MUxDRG5YeXpkSEx3UDVZKy9UMmhXbjU5Rzdrb3V2MzBhRis5OEhxdTNFcjUyYzZuYnpybHZO'
    b'KzEKWFUwcjU4V0xmZnpSTGhxRnhVd3YyZjMvWnNaeXE4ZFh2Vi8zMWgzbnZXNWI4d1V1eUZW'
    b'TDJoQWMyRHkxL3F6Nm5xdTNmWHZXT3E2RApZVGs5MFhUb252ckd2cFdmRk9tVTh5SkhaNkVY'
    b'TzhVbHJQcVNZbFo3eCs2Nk1iK3JwbVNFU3ZDWVRPVDh4VSttNGhCVncrSE5oOXBMCjlWMkgz'
    b'dzdCR0p4Q0pWdldkc2M3bWp3SldiREt0bnI0K2NBOTNlUEpqSXRHV1RTTEhDOTlUUW9ESEhi'
    b'Ukl5ZjlLMlk3Ym5ZeGdYYTgKdEFjbWZ4QzJ4U3RaSzNXd1hOZ25WT0xocE5FNnV1SERyYTd4'
    b'RDBmLzJ5V1dmelZ6MmI3VWtvYTlkd1NkVTY3NlpQQWswZHZ1VU55QwpJTkh1bGZiQVpER2N5'
    b'UkNaS3lpNXp0QndCb0N5WHVxSi9Odm40czZMNVhhbHpaKzJ0bzJjVkwxOXhVMmlJTExqZk0w'
    b'R29UMHdlWk5OCjNGMFpuVHkvSmxKeU9wOXIvUk5hRDc5TkEvN09FeXRvRk42dU50MmtadzMv'
    b'QjI4dTBWQzhiUVBtejY2aFVYaTdtb29aM2IzNnBXZTUKYVNnb1lFTElva012NUNDRUFpYUVV'
    b'TUNFRUFxWUVBcVlFRUlCRTBJb1lFSUlCVXdJQlV3SW9ZQUpJUlF3SVJRd0lZUUNKb1JRd0lR'
    b'UQpDcGdRQ3BnUVFnRVRRaWhnUWdnRlRBZ0ZUQWloZ0FraEZEQWhGREFoaEFJbWhGREFoQkFL'
    b'bUJBS21CQkNBUk5DS0dCQ0NBVk1DQVZNCkNLR0FDU0VVTUNFVU1DR0VBaWFFVU1DRUVBcVlF'
    b'QXFZRUVJQkUwSW9ZRUlvWUVJSUJVd0lvWUFKSVJRd0lSUXdJWVFDSm9SUXdJUVEKQ3BnUUNw'
    b'Z1FRZ0VUUWloZ1F2NW8vWDhDbWxvS3drSDV6Z0FBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VB'
    b'TWpBeU15MHdPQzB6TVZRdwpNam94TmpvMU1pc3dNRG93TUxJRUdhTUFBQUFsZEVWWWRHUmhk'
    b'R1U2Ylc5a2FXWjVBREl3TWpNdE1EZ3RNekZVTURJNk1UWTZOVElyCk1EQTZNREREV2FFZkFB'
    b'QUFBRWxGVGtTdVFtQ0MKIiBpZD0iaW1hZ2UyNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'ES_RI')

ES_RI = b64_ES_RI
index.append("ES_RI")
index.append("Spain Rioja")
catalog["ES_RI"] = ES_RI
catalog["Spain Rioja"] = ES_RI
country["Spain Rioja"] = ('ES_RI', '', 1)
lookup["ES_RI"] = ('ES_RI', '', 'Spain Rioja', 1)
lookup["Logroño Spain Rioja"] = ('ES_RI', '', 'Spain Rioja', 1)
lookup["Spain Rioja"] = ('ES_RI', '', 'Spain Rioja', 1)
details["ES_RI"] = {"continent":"Europe","capital":"Logroño","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_RI"] = ('ES_RI', 'Spain Rioja', 1)
regional["Spain Rioja"] = ('ES_RI', 'Spain Rioja', 1)
#----------------------------------------------------------------------
b64_ES_VC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAx'
    b'Mjc2LjIgODQ3Ij48c3R5bGUgdHlwZT0idGV4dC9jc3MiPiAgDQoJLnN0MHtmaWxsOiNGQ0RE'
    b'MDk7fQ0KCS5zdDF7ZmlsbDojMDA3MkJDO30NCgkuc3Qye2ZpbGw6I0RBMTIxQTt9DQoJLnN0'
    b'M3tmaWxsOiNGQ0REMDk7c3Ryb2tlOiMwMDAwMDA7fQ0KCS5zdDR7ZmlsbDpub25lO3N0cm9r'
    b'ZTojMDAwMDAwO30NCgkuc3Q1e2ZpbGw6I0ZGRkZGRjtzdHJva2U6IzAwMDAwMDt9DQoJLnN0'
    b'NntmaWxsOiNEQTEyMUE7c3Ryb2tlOiMwMDAwMDA7fQ0KCS5zdDd7ZmlsbDojMDc4OTMwO3N0'
    b'cm9rZTojMDAwMDAwO30NCjwvc3R5bGU+PHJlY3QgY2xhc3M9InN0MCIgd2lkdGg9IjEyNzYu'
    b'MiIgaGVpZ2h0PSI4NDciLz48cmVjdCBjbGFzcz0ic3QxIiB3aWR0aD0iNDI1LjQiIGhlaWdo'
    b'dD0iODQ3Ii8+PHBvbHlnb24gY2xhc3M9InN0MiIgcG9pbnRzPSIxMjc2LjIgMTg4LjMgMTI3'
    b'Ni4yIDk0LjIgNDI2IDk0LjIgNDI2IDAgMzMxLjggMCAzMzEuOCA4NDcgNDI2IDg0NyA0MjYg'
    b'NzUyLjggMTI3Ni4yIDc1Mi44IDEyNzYuMiA2NTguNyA0MjYgNjU4LjcgNDI2IDU2NC43IDEy'
    b'NzYuMiA1NjQuNyAxMjc2LjIgNDcwLjYgNDI2IDQ3MC42IDQyNiAzNzYuNCAxMjc2LjIgMzc2'
    b'LjQgMTI3Ni4yIDI4Mi4zIDQyNiAyODIuMyA0MjYgMTg4LjMgIi8+PHBhdGggY2xhc3M9InN0'
    b'MyIgZD0iTTE5NC4yIDc3Mi4zYzAgMC0zOC42IDg1LjMtNTUuOCA0NC40IDAgMCA0LjkgMS45'
    b'IDguNy0xLjkgMy40LTMuNCAzLTYuNi0wLjktMTEuMyAtNC4yLTUuMS0xNi4zLTIuOC0xOC43'
    b'IDMuMiAtNS41IDE0IDcuNiAzMi41IDE5LjUgMzEuNiAzMS40LTIuMSAzNC44LTM1LjcgNTUu'
    b'Ni02NC4zQzIwMy44IDc3Mi4xIDE5NC4yIDc3Mi4zIDE5NC4yIDc3Mi4zTDE5NC4yIDc3Mi4z'
    b'eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0xOTQuOSA2NzQuMmMwIDAtMzguNi04NS4zLTU1'
    b'LjgtNDQuNCAwIDAgNC45LTEuOSA4LjcgMS45IDMuNCAzLjQgMyA2LjYtMC45IDExLjMgLTQu'
    b'MiA1LjEtMTYuMyAyLjgtMTguNy0zLjIgLTUuNS0xNCA3LjYtMzIuMyAxOS41LTMxLjYgMzEu'
    b'NCAyLjEgMzQuOCAzNS43IDU1LjYgNjQuM0MyMDQuNCA2NzQuMiAxOTQuOSA2NzQuMiAxOTQu'
    b'OSA2NzQuMkwxOTQuOSA2NzQuMiAxOTQuOSA2NzQuMnoiLz48cGF0aCBjbGFzcz0ic3QzIiBk'
    b'PSJNMzI0LjQgNjk0LjJjLTUuNSAxMC42LTUwLjkgMjgtNTAuOSAyOHM0NC4yIDE2LjggNTAu'
    b'MyAyOGwwLjYgMTYuNGMtMjIuNS0zMC42LTQ1LTMzLjUtNjIuNC0zNC40IC0xMi4zLTAuNi0x'
    b'MS4yIDYuNi04LjkgOS41IDIwLjIgMjUuNy01LjkgMzMuMS05LjggNTQuNCAtMC4yIDEuMS0z'
    b'LjItMy42LTQuMi05LjggLTAuNi00IDAuNi0xMCAwLjYtMTAgLTkuMSAxNC45LTIwLjQgMy0y'
    b'Ny40IDE4IDAgMC0xLjUtMi4zLTIuMy0zIC0yLjEtMS45LTguNS0wLjktOS41LTE3LjggMC0w'
    b'LjYtNy40IDEuMy03LjQgMS4zIDQuMi0xNCAzOS45LTI5LjUgMzAuNi0zOC44IC0xMC42LTEw'
    b'LjItMTEuMyAyMS45LTI3LjggMjQuMiAtMC45IDAuMiAyLjUtOS4zIDIuNS05LjMgLTcuOCAw'
    b'LjQtMTEuMiA5LjMtMTEuOSAxNC42bC0xLjktNC45Yy03LjQtNC4yIDEuOS0yNS4xLTEuNS0y'
    b'OC43IC0yLjYtMi44LTExLjUgOC43LTE1LjMgMTAuNiAtMy44IDEuOS0yNS4zIDEuOS0xNC43'
    b'IDE0LjkgMC44IDEuMS0yLjEtNS45IDIuOC02LjggNS41LTAuOSA1LjMgNS41IDUuMyA2IDAg'
    b'Mi42LTQuOSA5LjMtMTIuNyA1LjUgLTAuNC0wLjItMTQuNy0xMC42IDQtMjUuMyAwIDAtMTEu'
    b'NSA3LTIzLjQtNS41IC0yLjYtMi42LTYtNi0xMC4yLTguNyA0LjItMi42IDcuMi01LjcgOS44'
    b'LTguNSAxMi4xLTEyLjUgMjMuNC01LjcgMjMuNC01LjcgLTE4LjctMTQuNy00LjUtMjUuMS00'
    b'LTI1LjMgNy42LTMuOCAxMi41IDIuOCAxMi43IDUuNSAwIDAuNiAwLjIgNy01LjMgNiAtNC45'
    b'LTAuOS0yLjEtNy44LTIuOC02LjggLTEwLjYgMTMgMTEgMTMgMTQuOSAxNC45IDMuOCAxLjkg'
    b'MTIuNyAxMy40IDE1LjMgMTAuNiAzLjQtMy42LTUuOS0yNC42IDEuNS0yOC43bDEuNy00Ljlj'
    b'MC45IDUuMyA0LjMgMTQuMiAxMi4xIDE0LjYgMCAwLTMuNC05LjUtMi41LTkuMyAxNi40IDIu'
    b'MSAxNy40IDM0LjQgMjcuOCAyNCA5LjMtOS4xLTI2LjUtMjQuNi0zMC42LTM4LjYgMCAwIDcu'
    b'NCAxLjkgNy40IDEuMyAwLjktMTcgNy40LTE2LjEgOS4zLTE4IDAuOC0wLjggMi4xLTMgMi4x'
    b'LTMgNyAxNC45IDE4LjUgMi44IDI3LjQgMTcuOCAwIDAtMS4zLTYtMC44LTEwIDAuOS02LjIg'
    b'NC0xMC44IDQuMi05LjggNC4yIDIxLjQgMzAuMiAyOC41IDEwIDU0LjMgLTIuMyAyLjgtMy40'
    b'IDEwLjIgOS4xIDkuNSAxNy40LTAuOSAzOS45LTQgNjIuMi0zNC42TDMyNC40IDY5NC4yIDMy'
    b'NC40IDY5NC4yeiIvPjxwYXRoIGNsYXNzPSJzdDQiIGQ9Ik0xODQuNSA3NjAuNGMyLjUtMjAu'
    b'OCAyMC0yNy42IDE5LjctMzcuOCAtMC40LTEwLjItMTguMS0yMC44LTIwLjItMzguMk0yMDku'
    b'MSA3OTAuN2MtMTMuOC0yOC43IDMwLjYtMzguNCAyOS4zLTY4LjEgLTEuMy0yOC4yLTQzLjUt'
    b'NDAuNi0yOS41LTY4LjRNMjczIDcyMi4ySDExOC43Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0i'
    b'TTI1OSA1NjMuMmMtNC45LTEzLjQtMTkuMS0xNy4yLTI3LjItMTcuNCAtOS4xLTAuNC0yMy4z'
    b'IDEyLjEtMzIgMTcuNCAtNy44IDQuNy0yMS43LTEuNS0yNC03IC00LjktMTIuMSAyLjgtMTQu'
    b'NCA2LjYtMTMuOCAwIDAtNC41IDguNyAzIDcuNiA0LjctMC44IDYtNy44IDUuMy0xMC42IC0x'
    b'LjUtNS43LTkuNi01LjEtMTIuOS00LjIgLTEwLjQgMy04LjcgMTcuNi01LjEgMjMuMSA1LjEg'
    b'OC4zIDE4IDkuNSAyNi4xIDguMyAxMi41LTEuOSAyMi41LTE0LjYgMjkuOS0xNC4yIDEuOSAw'
    b'IDQgNi44IDIuMSA3LjIgLTEyLjUgMi4zLTEwLjggMTEuMi0xMC44IDExLjJ2MC4yYzAgMC0x'
    b'LjcgOC43IDEwLjggMTEuMiAxLjkgMC40LTAuNiA3LjQtMi41IDcuNCAtNy40IDAuNC0xNy0x'
    b'Mi43LTI5LjUtMTQuNCAtOC4xLTEuMS0yMSAwLTI2LjEgOC4zIC0zLjQgNS41LTUuMSAyMCA1'
    b'LjEgMjMuMSAzLjIgMC45IDExLjIgMS41IDEyLjktNC4yIDAuOC0yLjgtMC40LTEwLTUuMy0x'
    b'MC42IC03LjYtMS4xLTMgNy42LTMgNy42IC0zLjggMC44LTExLjUtMS43LTYuNi0xMy44IDIu'
    b'My01LjUgMTYuMy0xMS43IDI0LTcgOC43IDUuNSAyMi45IDE3LjggMzIgMTcuNCA4LjEtMC40'
    b'IDIyLjMtNCAyNy4yLTE3LjRWNTYzbDAgMFY1NjMuMnoiLz48cGF0aCBjbGFzcz0ic3QzIiBk'
    b'PSJNMzIxLjYgNTU0LjNjLTEuNyA4LjktMjQuMiAxNi42LTI0LjIgMTYuNnMyMi4xIDExLjUg'
    b'MjUuMSAyMC44bC0wLjYgMTAuOGMtNy4yLTI0LjQtMzQuNi0yNi4zLTM0LjYtMjYuMyA1Ljkg'
    b'OC4zIDExIDE5LjctMyAzMSAwIDAgNC4yLTEwLjYgMi4xLTEzIDAgMC0xLjkgNi42LTkuOCAx'
    b'Mi43IC0zLjIgMi41LTEyLjEgMi4xLTE2LjEgNC41bDMuNC0xMC44Yy00LjIgOC43LTE1Ljkg'
    b'OS44LTE1LjkgOS44IC0wLjgtMy0wLjQtMTAuMiAzLjItMTUuNyA2LjgtMTAuNCA1LjMtMTgg'
    b'NS4zLTE4IC01LjkgMTMtMjkuMSAxNC4yLTMzLjUgMTEgLTAuNi0wLjQgNS4xLTYgNS4xLTYg'
    b'LTIuMSAwLjQtNy45LTMuOC03LjgtNC45IDAuMi0xLjcgNC01LjMgNC43LTYuNCAwIDAtNC4z'
    b'LTMuNi00LjUtNS4zIC0wLjItMS4xIDUuNy01LjMgNy44LTQuOSAwIDAtNS45LTUuNy01LjEt'
    b'NiA0LjMtMy4yIDI3LjYtMi4xIDMzLjUgMTEgMCAwIDEuNy03LjQtNS4xLTE4IC0zLjYtNS41'
    b'LTQtMTIuOS0zLjQtMTUuNyAwIDAgMTEuOSAxLjEgMTUuOSA5LjhsLTMuNC0xMC44YzQgMi4z'
    b'IDEyLjkgMS45IDE2LjEgNC41IDcuOSA2IDkuOCAxMi43IDkuOCAxMi43IDIuMS0yLjUtMi4x'
    b'LTEzLTIuMS0xMyAxNCAxMS4zIDguOSAyMi43IDMgMzEgMCAwIDI3LjYtMS45IDM0LjYtMjYu'
    b'M0wzMjEuNiA1NTQuMyAzMjEuNiA1NTQuM3oiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMTkx'
    b'LjMgNTczLjhjLTcuNiAwLjItMTggNS41LTI3LjQgNC4yIC02LjgtMC45LTE4LjktOS4xLTE4'
    b'LjktOS4xczEyLjMtNi40IDE4LjUtNy44YzEwLTIuMyAyMCA2LjQgMjcuNiA2LjZDMTkyLjcg'
    b'NTY3LjcgMTkyLjggNTczLjggMTkxLjMgNTczLjhMMTkxLjMgNTczLjggMTkxLjMgNTczLjh6'
    b'Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTE5MS41IDU1OC43YzQuMi0wLjkgMy40IDEyLjEg'
    b'My40IDEyLjEgMCAxLjcgMC42IDExLjMtMy40IDEyLjEgLTQuNS0wLjYtMy4yLTEyLjEtMy4y'
    b'LTEyLjFTMTg3LjcgNTU4LjUgMTkxLjUgNTU4LjdMMTkxLjUgNTU4LjcgMTkxLjUgNTU4Ljd6'
    b'Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTIxOS43IDU3MC40TDI5OCA1NzFNMjYzLjYgNjAy'
    b'bDExLjItMzEuMk0yNzQuNyA1NzAuOGwtMTEtMzAuNiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9'
    b'Ik0xOTQuOSA0NjkuOGMwIDAtMzguNiA4NS4zLTU1LjggNDQuNCAwIDAgNC45IDEuOSA4Ljct'
    b'MS45IDMuNC0zLjQgMy02LjYtMC45LTExLjMgLTQuMi01LjEtMTYuMy0yLjgtMTguNyAzLjIg'
    b'LTUuNSAxNCA3LjYgMzIuNSAxOS41IDMxLjYgMzEuNC0yLjEgMzQuOC0zNS43IDU1LjYtNjQu'
    b'M0MyMDQuNCA0NjkuNiAxOTQuOSA0NjkuOCAxOTQuOSA0NjkuOEwxOTQuOSA0NjkuOCAxOTQu'
    b'OSA0NjkuOHoiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMTk1LjUgMzcxLjdjMCAwLTM4LjYt'
    b'ODUuMy01NS44LTQ0LjQgMCAwIDQuOS0xLjkgOC43IDEuOSAzLjQgMy40IDMgNi42LTAuOSAx'
    b'MS4zIC00LjIgNS4xLTE2LjMgMi44LTE4LjctMy4yIC01LjUtMTQgNy42LTMyLjMgMTkuNS0z'
    b'MS42IDMxLjQgMi4xIDM0LjggMzUuNyA1NS42IDY0LjNDMjA0LjkgMzcxLjkgMTk1LjUgMzcx'
    b'LjcgMTk1LjUgMzcxLjdMMTk1LjUgMzcxLjcgMTk1LjUgMzcxLjd6Ii8+PHBhdGggY2xhc3M9'
    b'InN0MyIgZD0iTTMyNSAzOTEuN2MtNS41IDEwLjYtNTAuOSAyOC01MC45IDI4czQ0LjIgMTYu'
    b'OCA1MC4zIDI4bDAuNiAxNi40Yy0yMi41LTMwLjYtNDUtMzMuNS02Mi40LTM0LjQgLTEyLjMt'
    b'MC42LTExLjIgNi42LTguOSA5LjUgMjAuMiAyNS43LTUuOSAzMy4xLTkuOCA1NC40IC0wLjIg'
    b'MS4xLTMuMi0zLjYtNC4yLTkuOCAtMC42LTQgMC42LTEwIDAuNi0xMCAtOS4xIDE0LjktMjAu'
    b'NCAzLTI3LjQgMTggMCAwLTEuNS0yLjMtMi4zLTMgLTIuMS0xLjktOC41LTAuOS05LjUtMTcu'
    b'OCAwLTAuNi03LjQgMS4zLTcuNCAxLjMgNC4yLTE0IDM5LjktMjkuNSAzMC42LTM4LjggLTEw'
    b'LjYtMTAuMi0xMS4zIDIxLjktMjcuOCAyNC4yIC0wLjkgMC4yIDIuNS05LjMgMi41LTkuMyAt'
    b'Ny44IDAuNC0xMS4yIDkuMy0xMS45IDE0LjZsLTEuOS00LjljLTcuNC00LjIgMS45LTI1LjEt'
    b'MS41LTI4LjcgLTIuNi0yLjgtMTEuNSA4LjctMTUuMyAxMC42IC0zLjggMS45LTI1LjMgMS45'
    b'LTE0LjcgMTQuOSAwLjggMS4xLTIuMS01LjkgMi44LTYuOCA1LjUtMC45IDUuMyA1LjUgNS4z'
    b'IDYgMCAyLjYtNC45IDkuMy0xMi43IDUuNSAtMC40LTAuMi0xNC43LTEwLjYgNC0yNS41IDAg'
    b'MC0xMS41IDctMjMuNC01LjUgLTIuNi0yLjYtNi02LTEwLjItOC43IDQuMi0yLjYgNy4yLTUu'
    b'NyA5LjgtOC41IDEyLjEtMTIuNyAyMy40LTUuNyAyMy40LTUuNyAtMTguNy0xNC43LTQuNS0y'
    b'NS4xLTQtMjUuMyA3LjYtMy44IDEyLjUgMi44IDEyLjcgNS41IDAgMC42IDAuMiA3LTUuMyA2'
    b'IC00LjktMC45LTIuMS03LjgtMi44LTYuOCAtMTAuNiAxMyAxMSAxMyAxNC45IDE0LjkgMy44'
    b'IDEuOSAxMi43IDEzLjQgMTUuMyAxMC42IDMuNC0zLjYtNi0yNC42IDEuNS0yOC43bDEuNy00'
    b'LjljMC45IDUuMyA0LjMgMTQuMiAxMi4xIDE0LjYgMCAwLTMuNC05LjUtMi41LTkuMyAxNi40'
    b'IDIuMSAxNy40IDM0LjQgMjcuOCAyNCA5LjMtOS4xLTI2LjUtMjQuNi0zMC42LTM4LjYgMCAw'
    b'IDcuNCAxLjkgNy40IDEuMyAwLjktMTcgNy40LTE2LjEgOS4zLTE4IDAuOC0wLjggMi4xLTMg'
    b'Mi4xLTMgNyAxNC45IDE4LjUgMi44IDI3LjQgMTcuOCAwIDAtMS4zLTYtMC44LTEwIDAuOS02'
    b'LjIgNC0xMC44IDQuMi05LjggNC4yIDIxLjQgMzAuMiAyOC41IDEwIDU0LjMgLTIuMyAyLjgt'
    b'My40IDEwIDkuMSA5LjUgMTcuNC0wLjkgMzkuOS00IDYyLjItMzQuNkwzMjUgMzkxLjcgMzI1'
    b'IDM5MS43eiIvPjxwYXRoIGNsYXNzPSJzdDQiIGQ9Ik0xODUuMyA0NTcuOWMyLjUtMjAuOCAy'
    b'MC0yNy42IDE5LjctMzcuOCAtMC40LTEwLjItMTguMS0yMC44LTIwLjItMzguMk0yMDkuNyA0'
    b'ODguMmMtMTMuOC0yOC43IDMwLjYtMzguNCAyOS4zLTY4LjEgLTEuMy0yOC4yLTQzLjUtNDAu'
    b'Ni0yOS41LTY4LjRNMjczLjYgNDE5LjlIMTE5LjMiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJN'
    b'MTkzLjYgMTcwLjVjMCAwLTM4LjYgODUuMy01NS44IDQ0LjQgMCAwIDQuOSAxLjkgOC43LTEu'
    b'OSAzLjQtMy40IDMtNi42LTAuOS0xMS4zIC00LjItNS4xLTE2LjMtMi44LTE4LjcgMy4yIC01'
    b'LjUgMTQgNy42IDMyLjUgMTkuNSAzMS42IDMxLjQtMi4xIDM0LjgtMzUuNyA1NS42LTY0LjND'
    b'MjAzLjEgMTcwLjMgMTkzLjYgMTcwLjUgMTkzLjYgMTcwLjVMMTkzLjYgMTcwLjUgMTkzLjYg'
    b'MTcwLjV6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTE5NC4yIDcyLjRjMCAwLTM4LjYtODUu'
    b'My01NS44LTQ0LjQgMCAwIDQuOS0xLjkgOC43IDEuOSAzLjQgMy40IDMgNi42LTAuOSAxMS4z'
    b'IC00LjIgNS4xLTE2LjMgMi44LTE4LjctMy4yIC01LjUtMTQgNy42LTMyLjUgMTkuNS0zMS42'
    b'IDMxLjIgMi4zIDM0LjggMzUuNyA1NS42IDY0LjVDMjAzLjggNzIuNiAxOTQuMiA3Mi40IDE5'
    b'NC4yIDcyLjRMMTk0LjIgNzIuNCAxOTQuMiA3Mi40eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9'
    b'Ik0zMjMuNyA5Mi41Yy01LjUgMTAuNi01MC45IDI4LTUwLjkgMjhzNDQuMiAxNi44IDUwLjMg'
    b'MjhsMC42IDE2LjRjLTIyLjUtMzAuNi00NS0zMy41LTYyLjQtMzQuNCAtMTIuNS0wLjYtMTEu'
    b'MiA2LjYtOC45IDkuNSAyMC4yIDI1LjctNS45IDMzLjEtOS44IDU0LjQgLTAuMiAxLjEtMy4y'
    b'LTMuNi00LjItOS44IC0wLjYtNCAwLjYtMTAgMC42LTEwIC05LjEgMTQuOS0yMC40IDMtMjcu'
    b'NCAxNy44IDAgMC0xLjUtMi4zLTIuMy0zIC0yLjEtMS45LTguNS0wLjktOS41LTE3LjggMC0w'
    b'LjYtNy40IDEuMy03LjQgMS4zIDQuMi0xNCAzOS45LTI5LjUgMzAuNi0zOC44IC0xMC42LTEw'
    b'LjItMTEuMyAyMS45LTI3LjggMjQuMiAtMC45IDAuMiAyLjUtOS4zIDIuNS05LjMgLTcuOCAw'
    b'LjQtMTEuMiA5LjMtMTEuOSAxNC42bC0xLjktNC45Yy03LjQtNC4yIDEuNy0yNS4xLTEuNS0y'
    b'OC43IC0yLjYtMi44LTExLjUgOC43LTE1LjMgMTAuNiAtMy44IDEuOS0yNS4zIDEuOS0xNC43'
    b'IDE0LjkgMC44IDEuMS0yLjEtNS45IDIuOC02LjggNS41LTAuOSA1LjMgNS41IDUuMyA2IDAg'
    b'Mi42LTQuOSA5LjMtMTIuNyA1LjUgLTAuNC0wLjItMTQuNy0xMC42IDQtMjUuNSAwIDAtMTEu'
    b'NSA3LTIzLjQtNS41IC0yLjYtMi42LTYtNi0xMC4yLTguNyA0LjItMi42IDcuMi01LjcgOS44'
    b'LTguNSAxMi4xLTEyLjUgMjMuNC01LjcgMjMuNC01LjcgLTE4LjctMTQuNy00LjUtMjUuMS00'
    b'LTI1LjMgNy44LTMuOCAxMi41IDIuOCAxMi43IDUuNSAwIDAuNiAwLjIgNy01LjMgNiAtNC45'
    b'LTAuOS0yLjEtNy44LTIuOC02LjggLTEwLjYgMTMgMTEgMTMgMTQuOSAxNC45IDMuOCAxLjkg'
    b'MTIuNyAxMy40IDE1LjMgMTAuNiAzLjQtMy42LTUuOS0yNC42IDEuNS0yOC43bDEuNy00Ljlj'
    b'MC45IDUuMyA0LjMgMTQuMiAxMi4xIDE0LjYgMCAwLTMuNC05LjUtMi41LTkuMyAxNi40IDIu'
    b'MSAxNy40IDM0LjQgMjcuOCAyNCA5LjMtOS4xLTI2LjUtMjQuNi0zMC42LTM4LjYgMCAwIDcu'
    b'NCAxLjkgNy40IDEuMyAwLjktMTcgNy40LTE2LjEgOS4zLTE4IDAuOC0wLjggMi4xLTMgMi4x'
    b'LTMgNyAxNC45IDE4LjUgMi44IDI3LjQgMTcuOCAwIDAtMS4zLTYtMC44LTEwIDAuOS02LjIg'
    b'NC0xMC44IDQuMi05LjggNC4yIDIxLjQgMzAuMiAyOC41IDEwIDU0LjMgLTIuMyAyLjgtMy40'
    b'IDEwLjIgOS4xIDkuNSAxNy40LTAuOSAzOS45LTQgNjIuMi0zNC42TDMyMy43IDkyLjUgMzIz'
    b'LjcgOTIuNXoiLz48cGF0aCBjbGFzcz0ic3Q0IiBkPSJNMTg0IDE1OC42YzIuNS0yMC44IDIw'
    b'LTI3LjYgMTkuNy0zNy44IC0wLjQtMTAuMi0xOC4xLTIwLjgtMjAuMi0zOC4yTTIwOC41IDE4'
    b'OC45Yy0xMy44LTI4LjcgMzAuNi0zOC40IDI5LjMtNjguMSAtMS4zLTI4LjItNDMuNS00MC42'
    b'LTI5LjUtNjguNE0yNzIuNCAxMjAuNkgxMTguMiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0y'
    b'NTguMyAyNjIuNmMtNC45LTEzLjQtMTkuMS0xNy4yLTI3LjItMTcuNCAtOS4xLTAuNC0yMy4z'
    b'IDEyLjEtMzIgMTcuNCAtNy44IDQuNy0yMS43LTEuNS0yNC03IC00LjktMTIuMSAyLjgtMTQu'
    b'NCA2LjYtMTMuOCAwIDAtNC41IDguNyAzIDcuNiA0LjctMC44IDYtNy44IDUuMS0xMC42IC0x'
    b'LjUtNS43LTkuNS01LjEtMTIuNy00LjIgLTEwLjQgMy04LjcgMTcuNi01LjEgMjMuMSA1LjEg'
    b'OC4zIDE4IDkuNSAyNi4xIDguMyAxMi4zLTEuOSAyMi41LTE0LjYgMjkuOS0xNC4yIDEuOSAw'
    b'IDQgNi44IDIuMSA3LjIgLTEyLjUgMi4zLTEwLjggMTEuMi0xMC44IDExLjJ2MC4yYzAgMC0x'
    b'LjcgOC43IDEwLjggMTEgMS45IDAuNC0wLjYgNy40LTIuNSA3LjQgLTcuNCAwLjQtMTctMTIu'
    b'Ny0yOS41LTE0LjQgLTguMS0xLjEtMjEgMC0yNi4xIDguMyAtMy40IDUuNS01LjEgMjAgNS4x'
    b'IDIzLjEgMy4yIDAuOSAxMS4yIDEuNSAxMi45LTQuMiAwLjgtMi44LTAuNC0xMC01LjEtMTAu'
    b'NiAtNy42LTEuMS0zIDcuNi0zIDcuNiAtMy44IDAuOC0xMS41LTEuNy02LjYtMTMuOCAyLjMt'
    b'NS41IDE2LjMtMTEuNyAyNC03IDguNyA1LjMgMjIuOSAxNy44IDMyIDE3LjQgOC4xLTAuNCAy'
    b'Mi4zLTQgMjcuMi0xNy40di0xNS4xSDI1OC4zeiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0z'
    b'MjEgMjUzLjdjLTEuNyA4LjktMjQuMiAxNi42LTI0LjIgMTYuNnMyMi4xIDExLjUgMjUuMSAy'
    b'MC44bC0wLjYgMTAuOGMtNy4yLTI0LjQtMzQuNi0yNi4zLTM0LjYtMjYuMyA1LjkgOC4zIDEx'
    b'IDE5LjctMyAzMSAwIDAgNC4yLTEwLjYgMi4xLTEzIDAgMC0xLjkgNi42LTkuOCAxMi43IC0z'
    b'LjIgMi42LTEyLjEgMi4xLTE2LjEgNC41bDMuNC0xMC44Yy00LjIgOC43LTE1LjkgOS44LTE1'
    b'LjkgOS44IC0wLjgtMy0wLjQtMTAuMiAzLjQtMTUuNyA2LjgtMTAuNCA1LjEtMTggNS4xLTE4'
    b'IC01LjkgMTMtMjkuMSAxNC4yLTMzLjUgMTEgLTAuNi0wLjQgNS4xLTYgNS4xLTYgLTIuMSAw'
    b'LjQtNy45LTMuOC03LjgtNC45IDAuMi0xLjcgNC01LjMgNC43LTYuNCAwIDAtNC4zLTMuNi00'
    b'LjUtNS4zIC0wLjItMS4xIDUuNy01LjMgNy44LTQuOSAwIDAtNS45LTUuNy01LjEtNiA0LjMt'
    b'My4yIDI3LjYtMi4xIDMzLjUgMTEgMCAwIDEuNy03LjQtNS4zLTE4IC0zLjYtNS41LTQtMTIu'
    b'OS0zLjItMTUuNyAwIDAgMTEuOSAxLjEgMTUuOSA5LjhsLTMuNC0xMC44YzQgMi4zIDEyLjkg'
    b'MS45IDE2LjEgNC41IDcuOSA2IDkuOCAxMi43IDkuOCAxMi43IDIuMS0yLjUtMi4xLTEzLTIu'
    b'MS0xMyAxNCAxMS4zIDguOSAyMi43IDMgMzEgMCAwIDI3LjYtMS45IDM0LjYtMjYuM0wzMjEg'
    b'MjUzLjcgMzIxIDI1My43eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0xOTAuOCAyNzMuNGMt'
    b'Ny42IDAuMi0xOCA1LjUtMjcuNCA0LjIgLTYuOC0wLjktMTguOS05LjEtMTguOS05LjFzMTIu'
    b'My02LjQgMTguNS03LjhjMTAtMi4zIDIwIDYuNCAyNy42IDYuNkMxOTEuOSAyNjcuMyAxOTIu'
    b'MyAyNzMuMiAxOTAuOCAyNzMuNEwxOTAuOCAyNzMuNCAxOTAuOCAyNzMuNHoiLz48cGF0aCBj'
    b'bGFzcz0ic3QzIiBkPSJNMTkxIDI1OC4xYzQuMi0wLjkgMy40IDExLjkgMy40IDExLjkgMCAx'
    b'LjkgMC42IDExLjMtMy40IDEyLjEgLTQuNS0wLjYtMy4yLTEyLjEtMy4yLTEyLjFTMTg3LjIg'
    b'MjU3LjkgMTkxIDI1OC4xTDE5MSAyNTguMSAxOTEgMjU4LjF6Ii8+PHBhdGggY2xhc3M9InN0'
    b'MyIgZD0iTTIxOS4xIDI3MGw3OC4zIDAuNk0yNjIuOCAzMDEuNGwxMS4yLTMxLjJNMjc0LjEg'
    b'MjcwLjJsLTExLTMwLjYiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzIzLjMgNjYxLjFjLTcu'
    b'OC0yMC44LTM1LjctMTguNS0zNS43LTE4LjVzMjggMC4yIDM1LjItMjQuMkwzMjMuMyA2NjEu'
    b'MXoiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzIzLjMgNzg1LjRjLTcuOCAyMC44LTM1Ljcg'
    b'MTguNS0zNS43IDE4LjVzMjgtMC4yIDM1LjIgMjQuMkwzMjMuMyA3ODUuNHoiLz48cGF0aCBj'
    b'bGFzcz0ic3QzIiBkPSJNMjU4LjggODA0LjVjMCAwIDExLjUgOS4zIDE5LjMgNy40IDAgMC04'
    b'LjkgOC41LTEuNSAxNS4zIDAgMCAyLjMtOC45IDEyLjktMTAuNCA4LjktMS4zIDEyLjUtOC43'
    b'IDEyLjUtMTIuM3YwLjJjMC4yLTMuNi0zLjQtMTAuOC0xMi41LTEyLjMgLTEwLjYtMS43LTEy'
    b'LjktMTAuNC0xMi45LTEwLjQgLTcuNCA2LjYgMS41IDE1LjMgMS41IDE1LjNDMjcwLjQgNzk1'
    b'LjQgMjU4LjggODA0LjUgMjU4LjggODA0LjVMMjU4LjggODA0LjUgMjU4LjggODA0LjV6Ii8+'
    b'PHBhdGggY2xhc3M9InN0MyIgZD0iTTMyMi4zIDQ4MS4zYy03LjggMjAuOC0zNS43IDE4LjUt'
    b'MzUuNyAxOC41czI4LTAuMiAzNS4yIDI0LjJMMzIyLjMgNDgxLjN6Ii8+PHBhdGggY2xhc3M9'
    b'InN0MyIgZD0iTTMyMy4zIDM2MC45Yy03LjgtMjAuOC0zNS43LTE4LjUtMzUuNy0xOC41czI4'
    b'IDAuMiAzNS4yLTI0LjJMMzIzLjMgMzYwLjl6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTMy'
    b'My4zIDE3OS4yYy03LjggMjAuOC0zNS43IDE4LjUtMzUuNyAxOC41czI4LTAuMiAzNS4yIDI0'
    b'LjJMMzIzLjMgMTc5LjJ6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTMyMy4zIDU5LjdjLTcu'
    b'OC0yMC44LTM1LjctMTguNS0zNS43LTE4LjVzMjggMC4yIDM1LjItMjQuMkwzMjMuMyA1OS43'
    b'eiIvPjxyZWN0IHg9IjMyMS40IiB5PSItMS41IiBjbGFzcz0ic3QzIiB3aWR0aD0iMTAuNCIg'
    b'aGVpZ2h0PSI4NTAuNCIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0yNTkuNCA2NDEuM2MwIDAg'
    b'MTEuNSA5LjMgMTkuMyA3LjQgMCAwLTguOSA4LjUtMS41IDE1LjMgMCAwIDIuMy04LjkgMTIu'
    b'OS0xMC40IDguOS0xLjMgMTIuNS04LjcgMTIuNS0xMi4zdjAuMmMwLjItMy42LTMuNC0xMC44'
    b'LTEyLjUtMTIuMyAtMTAuNi0xLjctMTIuOS0xMC40LTEyLjktMTAuNCAtNy40IDYuNiAxLjUg'
    b'MTUuMyAxLjUgMTUuM0MyNzAuOSA2MzIuMiAyNTkuNCA2NDEuMyAyNTkuNCA2NDEuM0wyNTku'
    b'NCA2NDEuMyAyNTkuNCA2NDEuM3oiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMjU4LjggNTAw'
    b'LjFjMCAwIDExLjUgOS4zIDE5LjMgNy40IDAgMC04LjkgOC41LTEuNSAxNS4zIDAgMCAyLjMt'
    b'OC45IDEyLjktMTAuNCA4LjktMS4zIDEyLjUtOC43IDEyLjUtMTIuM3YwLjJjMC4yLTMuNi0z'
    b'LjQtMTAuOC0xMi41LTEyLjMgLTEwLjYtMS43LTEyLjktMTAuNC0xMi45LTEwLjQgLTcuNCA2'
    b'LjYgMS41IDE1LjMgMS41IDE1LjNDMjcwLjQgNDkxIDI1OC44IDUwMC4xIDI1OC44IDUwMC4x'
    b'TDI1OC44IDUwMC4xIDI1OC44IDUwMC4xeiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0yNTku'
    b'NCAzNDIuNmMwIDAgMTEuNSA5LjMgMTkuMyA3LjQgMCAwLTguOSA4LjUtMS41IDE1LjMgMCAw'
    b'IDIuMy04LjkgMTIuOS0xMC40IDguOS0xLjMgMTIuNS04LjcgMTIuNS0xMi4zdjAuMmMwLjIt'
    b'My42LTMuNC0xMC44LTEyLjUtMTIuMyAtMTAuNi0xLjctMTIuOS0xMC40LTEyLjktMTAuNCAt'
    b'Ny40IDYuNiAxLjUgMTUuMyAxLjUgMTUuM0MyNzAuOSAzMzMuNSAyNTkuNCAzNDIuNiAyNTku'
    b'NCAzNDIuNkwyNTkuNCAzNDIuNiAyNTkuNCAzNDIuNnoiLz48cGF0aCBjbGFzcz0ic3QzIiBk'
    b'PSJNMjU5LjQgMTk3LjhjMCAwIDExLjUgOS4zIDE5LjMgNy40IDAgMC04LjkgOC41LTEuNSAx'
    b'NS4zIDAgMCAyLjMtOC45IDEyLjktMTAuNCA4LjktMS4zIDEyLjUtOC43IDEyLjUtMTIuM3Yw'
    b'LjJjMC4yLTMuNi0zLjQtMTAuOC0xMi41LTEyLjMgLTEwLjYtMS43LTEyLjktMTAuNC0xMi45'
    b'LTEwLjQgLTcuNCA2LjYgMS41IDE1LjMgMS41IDE1LjNDMjcwLjkgMTg4LjcgMjU5LjQgMTk3'
    b'LjggMjU5LjQgMTk3LjhMMjU5LjQgMTk3LjggMjU5LjQgMTk3Ljh6Ii8+PHBhdGggY2xhc3M9'
    b'InN0MyIgZD0iTTI2MC4xIDQwLjhjMCAwIDExLjUgOS4zIDE5LjMgNy40IDAgMC04LjkgOC41'
    b'LTEuNSAxNS4zIDAgMCAyLjMtOC45IDEyLjktMTAuNCA4LjktMS4zIDEyLjUtOC43IDEyLjUt'
    b'MTIuM1Y0MWMwLjItMy42LTMuNC0xMC44LTEyLjUtMTIuMyAtMTAuNi0xLjctMTIuOS0xMC40'
    b'LTEyLjktMTAuNCAtNy40IDYuNiAxLjUgMTUuMyAxLjUgMTUuM0MyNzEuNyAzMS44IDI2MC4x'
    b'IDQwLjggMjYwLjEgNDAuOEwyNjAuMSA0MC44IDI2MC4xIDQwLjh6Ii8+PHBhdGggY2xhc3M9'
    b'InN0NSIgZD0iTTM5MC4yIDgwMC4zYzAgNy44LTYuNCAxNC4yLTE0LjIgMTQuMnMtMTQuMi02'
    b'LjItMTQuMi0xNC4yYzAtNy44IDYuNC0xNC4yIDE0LjItMTQuMkMzODQgNzg2LjEgMzkwLjIg'
    b'NzkyLjUgMzkwLjIgODAwLjNMMzkwLjIgODAwLjN6Ii8+PHBhdGggY2xhc3M9InN0NSIgZD0i'
    b'TTM5MC4yIDYxMmMwIDcuOC02LjQgMTQuMi0xNC4yIDE0LjJzLTE0LjItNi4yLTE0LjItMTQu'
    b'MmMwLTcuOCA2LjQtMTQuMiAxNC4yLTE0LjJDMzg0IDU5OCAzOTAuMiA2MDQuMiAzOTAuMiA2'
    b'MTJMMzkwLjIgNjEyeiIvPjxwYXRoIGNsYXNzPSJzdDUiIGQ9Ik0zOTAuMiA0MjMuOWMwIDcu'
    b'OC02LjQgMTQuMi0xNC4yIDE0LjJzLTE0LjItNi4yLTE0LjItMTQuMmMwLTcuOCA2LjQtMTQu'
    b'MiAxNC4yLTE0LjJDMzg0IDQwOS43IDM5MC4yIDQxNS45IDM5MC4yIDQyMy45TDM5MC4yIDQy'
    b'My45eiIvPjxwYXRoIGNsYXNzPSJzdDUiIGQ9Ik0zOTAuMiAyMzUuNmMwIDcuOC02LjQgMTQu'
    b'Mi0xNC4yIDE0LjJzLTE0LjItNi4yLTE0LjItMTQuMmMwLTcuOCA2LjQtMTQuMiAxNC4yLTE0'
    b'LjJDMzg0IDIyMS40IDM5MC4yIDIyNy44IDM5MC4yIDIzNS42TDM5MC4yIDIzNS42eiIvPjxw'
    b'YXRoIGNsYXNzPSJzdDUiIGQ9Ik0zOTAuMiA0Ny41YzAgNy44LTYuNCAxNC4yLTE0LjIgMTQu'
    b'MnMtMTQuMi02LjItMTQuMi0xNC4yYzAtNy44IDYuNC0xNC4yIDE0LjItMTQuMkMzODQgMzMu'
    b'MyAzOTAuMiAzOS41IDM5MC4yIDQ3LjVMMzkwLjIgNDcuNXoiLz48cG9seWdvbiBjbGFzcz0i'
    b'c3QzIiBwb2ludHM9IjM1Mi42IDE0Mi40IDM3NiAxMTguOSAzOTkuNSAxNDIuNCAzNzYgMTY1'
    b'LjYgIi8+PHBvbHlnb24gY2xhc3M9InN0NiIgcG9pbnRzPSIzNTQuMyAxNDIuNCAzNjEuMyAx'
    b'NDkuNSAzNjguNyAxNDkuNSAzNjguNyAxNTYuOSAzNzUuOSAxNjMuOSAzNzYuMiAxNjMuOSAz'
    b'ODMuMiAxNTYuOSAzODMuMiAxNDkuNSAzOTAuNiAxNDkuNSAzOTcuOCAxNDIuNCAzOTcuOCAx'
    b'NDIuMiAzOTAuNiAxMzUgMzgzLjIgMTM1IDM4My4yIDEyNy42IDM3Ni4yIDEyMC42IDM3NS45'
    b'IDEyMC42IDM2OC43IDEyNy42IDM2OC43IDEzNSAzNjEuMyAxMzUgMzU0LjMgMTQyLjIgIi8+'
    b'PHBhdGggY2xhc3M9InN0MyIgZD0iTTM2Ni4yIDEyMy42YzEuMSAxLjEgMCA0LTIuNSA2LjIg'
    b'LTIuNSAyLjUtNS4zIDMuNi02LjIgMi41IC0xLjEtMS4xIDAtMy44IDIuNS02LjJDMzYyLjIg'
    b'MTIzLjYgMzY1LjEgMTIyLjUgMzY2LjIgMTIzLjZMMzY2LjIgMTIzLjYgMzY2LjIgMTIzLjZ6'
    b'Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM4NS45IDEyMy42Yy0xLjEgMS4xIDAgNCAyLjUg'
    b'Ni4yIDIuNSAyLjUgNS4zIDMuNiA2LjIgMi41IDEuMS0xLjEgMC0zLjgtMi41LTYuMkMzODku'
    b'OCAxMjMuNiAzODcgMTIyLjUgMzg1LjkgMTIzLjZMMzg1LjkgMTIzLjZ6Ii8+PHBhdGggY2xh'
    b'c3M9InN0MyIgZD0iTTM4NS45IDE2MC45Yy0xLjEtMS4xIDAtMy44IDIuNS02LjIgMi41LTIu'
    b'NSA1LjMtMy42IDYuMi0yLjUgMS4xIDEuMSAwIDQtMi41IDYuMkMzODkuOCAxNjAuNyAzODcg'
    b'MTYxLjggMzg1LjkgMTYwLjlMMzg1LjkgMTYwLjl6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0i'
    b'TTM2Ni4yIDE2MC45Yy0xLjEgMS4xLTQgMC02LjItMi41IC0yLjUtMi41LTMuNi01LjMtMi41'
    b'LTYuMiAxLjEtMS4xIDQgMCA2LjIgMi41QzM2NiAxNTYuOSAzNjcuMiAxNTkuOCAzNjYuMiAx'
    b'NjAuOUwzNjYuMiAxNjAuOXoiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzY4LjcgMTE1Ljdj'
    b'MC0xLjEgMi42LTIuMyA1LjktMi42IDAuNiAwIDEuNS0wLjggMS41LTAuOHMwLjkgMC44IDEu'
    b'MyAwLjhjMy40IDAuMiA2IDEuMyA2IDIuNiAwIDEuNS0zLjQgMi42LTcuNiAyLjZDMzcxLjkg'
    b'MTE4LjQgMzY4LjcgMTE3IDM2OC43IDExNS43TDM2OC43IDExNS43eiIvPjxwYXRoIGNsYXNz'
    b'PSJzdDMiIGQ9Ik0zODMuNiAxNjguOGMwIDEuMS0yLjYgMi4zLTUuOSAyLjYgLTAuNiAwLTEu'
    b'NSAwLjgtMS41IDAuOHMtMC45LTAuOC0xLjMtMC44Yy0zLjQtMC4yLTYtMS4zLTYtMi42IDAt'
    b'MS41IDMuNC0yLjYgNy42LTIuNkMzODAuMiAxNjYuMiAzODMuNiAxNjcuNSAzODMuNiAxNjgu'
    b'OEwzODMuNiAxNjguOHoiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzQ5LjIgMTQ5LjdjLTEu'
    b'MSAwLTIuMy0yLjYtMi42LTUuOSAwLTAuNi0wLjgtMS41LTAuOC0xLjVzMC44LTAuOSAwLjgt'
    b'MS4zYzAuMi0zLjQgMS4zLTYgMi42LTYgMS41IDAgMi42IDMuNCAyLjYgNy40QzM1MiAxNDYu'
    b'MyAzNTAuNyAxNDkuNyAzNDkuMiAxNDkuN0wzNDkuMiAxNDkuNyAzNDkuMiAxNDkuN3oiLz48'
    b'cGF0aCBjbGFzcz0ic3QzIiBkPSJNNDAyLjkgMTM0LjhjMS4xIDAgMi4zIDIuNiAyLjYgNS45'
    b'IDAgMC42IDAuOCAxLjUgMC44IDEuNXMtMC44IDAuOS0wLjggMS4zYy0wLjIgMy40LTEuMyA2'
    b'LTIuNiA2IC0xLjUgMC0yLjYtMy40LTIuNi03LjRDNDAwLjIgMTM4LjIgNDAxLjQgMTM0Ljgg'
    b'NDAyLjkgMTM0LjhMNDAyLjkgMTM0LjggNDAyLjkgMTM0Ljh6Ii8+PHBhdGggY2xhc3M9InN0'
    b'MyIgZD0iTTM3MS45IDM2Mi4xYzAgMi4zIDEuOSA0LjIgNC4yIDQuMiAyLjMgMCA0LjMtMS45'
    b'IDQuMy00LjIgMC0yLjMtMS45LTQuMi00LjMtNC4yQzM3My44IDM1Ny43IDM3MS45IDM1OS42'
    b'IDM3MS45IDM2Mi4xTDM3MS45IDM2Mi4xeiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0zNzEu'
    b'OSAyOTUuN2MwIDIuMyAxLjkgNC4yIDQuMiA0LjIgMi4zIDAgNC4zLTEuOSA0LjMtNC4ycy0x'
    b'LjktNC4yLTQuMy00LjJDMzczLjggMjkxLjMgMzcxLjkgMjkzLjIgMzcxLjkgMjk1LjdMMzcx'
    b'LjkgMjk1Ljd6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM5MS43IDMyOWMwIDE1LjMtNyAy'
    b'Ny44LTE1LjkgMjcuOCAtOC43IDAtMTUuOS0xMi41LTE1LjktMjcuOCAwLTE1LjMgNy0yOCAx'
    b'NS45LTI4UzM5MS43IDMxMy41IDM5MS43IDMyOUwzOTEuNyAzMjl6Ii8+PHBhdGggY2xhc3M9'
    b'InN0NyIgZD0iTTM4OS4zIDMyOC42YzAtMTMuMi01LjMtMjQtMTEuOS0yNS4zIC0wLjQgMC0x'
    b'LjMgMS43LTEuMyAxLjdzLTAuOS0xLjctMS4zLTEuN2MtNi42IDEuMy0xMS45IDEyLjEtMTEu'
    b'OSAyNS4zIDAgMCAwIDAgMCAwLjIgMCAwIDAgMCAwIDAuMiAwIDEzLjIgNS4zIDI0IDExLjkg'
    b'MjUuMyAwLjQgMCAxLjMtMS43IDEuMy0xLjdzMC45IDEuNyAxLjMgMS43YzYuNi0xLjMgMTEu'
    b'OS0xMi4xIDExLjktMjUuMyAwIDAgMCAwIDAtMC4yQzM4OS4zIDMyOC44IDM4OS4zIDMyOC44'
    b'IDM4OS4zIDMyOC42TDM4OS4zIDMyOC42IDM4OS4zIDMyOC42eiIvPjxwYXRoIGNsYXNzPSJz'
    b'dDMiIGQ9Ik0zOTYuOCAzMjljMC0xLjEtMC45LTIuMS0yLjEtMi4xIC0xLjEgMC0yLjEgMC45'
    b'LTIuMSAyLjEgMCAxLjEgMC45IDIuMSAyLjEgMi4xQzM5NS45IDMzMSAzOTYuOCAzMzAuMSAz'
    b'OTYuOCAzMjlMMzk2LjggMzI5eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0zNTkuNCAzMjlj'
    b'MC0xLjEtMC45LTIuMS0yLjEtMi4xcy0yLjEgMC45LTIuMSAyLjFjMCAxLjEgMC45IDIuMSAy'
    b'LjEgMi4xUzM1OS40IDMzMC4xIDM1OS40IDMyOUwzNTkuNCAzMjl6Ii8+PHBhdGggY2xhc3M9'
    b'InN0MyIgZD0iTTM4OS43IDM1My41YzAtMS4xLTAuOS0yLjEtMi4xLTIuMXMtMi4xIDAuOS0y'
    b'LjEgMi4xYzAgMS4xIDAuOSAyLjEgMi4xIDIuMVMzODkuNyAzNTQuNyAzODkuNyAzNTMuNUwz'
    b'ODkuNyAzNTMuNXoiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzY2LjYgMzUzLjVjMC0xLjEt'
    b'MC45LTIuMS0yLjEtMi4xIC0xLjEgMC0yLjEgMC45LTIuMSAyLjEgMCAxLjEgMC45IDIuMSAy'
    b'LjEgMi4xQzM2NS42IDM1NS42IDM2Ni42IDM1NC43IDM2Ni42IDM1My41TDM2Ni42IDM1My41'
    b'eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0zNjAuOSAzNDEuOGMwLTIuMy0xLjktNC4yLTQu'
    b'Mi00LjIgLTIuMyAwLTQuMyAxLjktNC4zIDQuMiAwIDIuMyAxLjkgNC4yIDQuMyA0LjJDMzU5'
    b'IDM0NiAzNjAuOSAzNDQuMSAzNjAuOSAzNDEuOEwzNjAuOSAzNDEuOHoiLz48cGF0aCBjbGFz'
    b'cz0ic3QzIiBkPSJNMzk5LjcgMzQxLjZjMC0yLjMtMS45LTQuMi00LjItNC4yIC0yLjMgMC00'
    b'LjIgMS45LTQuMiA0LjIgMCAyLjMgMS45IDQuMiA0LjIgNC4yQzM5Ny44IDM0NS44IDM5OS43'
    b'IDM0My45IDM5OS43IDM0MS42TDM5OS43IDM0MS42eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9'
    b'Ik0zNjIuNCAzMDQuMmMwIDEuMSAwLjkgMi4xIDIuMSAyLjEgMS4xIDAgMi4xLTAuOSAyLjEt'
    b'Mi4xcy0wLjktMi4xLTIuMS0yLjFDMzYzLjQgMzAxLjkgMzYyLjQgMzAyLjkgMzYyLjQgMzA0'
    b'LjJMMzYyLjQgMzA0LjJ6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM4NS41IDMwNC4yYzAg'
    b'MS4xIDAuOSAyLjEgMi4xIDIuMXMyLjEtMC45IDIuMS0yLjEgLTAuOS0yLjEtMi4xLTIuMUMz'
    b'ODYuNCAzMDEuOSAzODUuNSAzMDIuOSAzODUuNSAzMDQuMkwzODUuNSAzMDQuMnoiLz48cGF0'
    b'aCBjbGFzcz0ic3QzIiBkPSJNMzkxLjIgMzE1LjljMCAyLjMgMS45IDQuMiA0LjIgNC4yczQu'
    b'Mi0xLjkgNC4yLTQuMmMwLTIuMy0xLjktNC4yLTQuMi00LjJTMzkxLjIgMzEzLjUgMzkxLjIg'
    b'MzE1LjlMMzkxLjIgMzE1Ljl6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM1Mi40IDMxNS45'
    b'YzAgMi4zIDEuOSA0LjIgNC4zIDQuMiAyLjMgMCA0LjItMS45IDQuMi00LjIgMC0yLjMtMS45'
    b'LTQuMi00LjItNC4yQzM1NC4zIDMxMS44IDM1Mi40IDMxMy43IDM1Mi40IDMxNS45TDM1Mi40'
    b'IDMxNS45eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0zNzEuOSA3MzUuNGMwIDIuMyAxLjkg'
    b'NC4yIDQuMiA0LjIgMi4zIDAgNC4zLTEuOSA0LjMtNC4yIDAtMi4zLTEuOS00LjItNC4zLTQu'
    b'MkMzNzMuOCA3MzEuMyAzNzEuOSA3MzMuMiAzNzEuOSA3MzUuNEwzNzEuOSA3MzUuNHoiLz48'
    b'cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzcxLjkgNjY5LjFjMCAyLjMgMS45IDQuMiA0LjIgNC4y'
    b'IDIuMyAwIDQuMy0xLjkgNC4zLTQuMnMtMS45LTQuMi00LjMtNC4yQzM3My44IDY2NC45IDM3'
    b'MS45IDY2Ni44IDM3MS45IDY2OS4xTDM3MS45IDY2OS4xeiIvPjxwYXRoIGNsYXNzPSJzdDMi'
    b'IGQ9Ik0zOTEuNyA3MDIuNGMwIDE1LjMtNyAyOC0xNS45IDI4IC04LjcgMC0xNS45LTEyLjUt'
    b'MTUuOS0yOCAwLTE1LjMgNy0yNy44IDE1LjktMjcuOFMzOTEuNyA2ODcgMzkxLjcgNzAyLjRM'
    b'MzkxLjcgNzAyLjR6Ii8+PHBhdGggY2xhc3M9InN0NyIgZD0iTTM4OS4zIDcwMi4yYzAtMTMu'
    b'Mi01LjMtMjQtMTEuOS0yNS4zIC0wLjQgMC0xLjMgMS43LTEuMyAxLjdzLTAuOS0xLjctMS4z'
    b'LTEuN2MtNi42IDEuMy0xMS45IDEyLjEtMTEuOSAyNS4zdjAuMmMwIDAgMCAwIDAgMC4yIDAg'
    b'MTMuMiA1LjMgMjQgMTEuOSAyNS4zIDAuNCAwIDEuMy0xLjcgMS4zLTEuN3MwLjkgMS43IDEu'
    b'MyAxLjdjNi42LTEuMyAxMS45LTEyLjEgMTEuOS0yNS4zIDAgMCAwIDAgMC0wLjJDMzg5LjMg'
    b'NzAyLjIgMzg5LjMgNzAyLjIgMzg5LjMgNzAyLjJMMzg5LjMgNzAyLjIgMzg5LjMgNzAyLjJ6'
    b'Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM5Ni44IDcwMi40YzAtMS4xLTAuOS0yLjEtMi4x'
    b'LTIuMSAtMS4xIDAtMi4xIDAuOS0yLjEgMi4xIDAgMS4xIDAuOSAyLjEgMi4xIDIuMUMzOTUu'
    b'OSA3MDQuNCAzOTYuOCA3MDMuNSAzOTYuOCA3MDIuNEwzOTYuOCA3MDIuNHoiLz48cGF0aCBj'
    b'bGFzcz0ic3QzIiBkPSJNMzU5LjQgNzAyLjRjMC0xLjEtMC45LTIuMS0yLjEtMi4xcy0yLjEg'
    b'MC45LTIuMSAyLjFjMCAxLjEgMC45IDIuMSAyLjEgMi4xUzM1OS40IDcwMy41IDM1OS40IDcw'
    b'Mi40TDM1OS40IDcwMi40eiIvPjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0zODkuNyA3MjYuOWMw'
    b'LTEuMS0wLjktMi4xLTIuMS0yLjFzLTIuMSAwLjktMi4xIDIuMSAwLjkgMi4xIDIuMSAyLjFT'
    b'Mzg5LjcgNzI4LjEgMzg5LjcgNzI2LjlMMzg5LjcgNzI2Ljl6Ii8+PHBhdGggY2xhc3M9InN0'
    b'MyIgZD0iTTM2Ni42IDcyNi45YzAtMS4xLTAuOS0yLjEtMi4xLTIuMSAtMS4xIDAtMi4xIDAu'
    b'OS0yLjEgMi4xczAuOSAyLjEgMi4xIDIuMUMzNjUuNiA3MjkgMzY2LjYgNzI4LjEgMzY2LjYg'
    b'NzI2LjlMMzY2LjYgNzI2Ljl6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM2MC45IDcxNS4y'
    b'YzAtMi4zLTEuOS00LjItNC4yLTQuMiAtMi4zIDAtNC4zIDEuOS00LjMgNC4yIDAgMi4zIDEu'
    b'OSA0LjIgNC4zIDQuMkMzNTkgNzE5LjQgMzYwLjkgNzE3LjUgMzYwLjkgNzE1LjJMMzYwLjkg'
    b'NzE1LjJ6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM5OS43IDcxNWMwLTIuMy0xLjktNC4y'
    b'LTQuMi00LjIgLTIuMyAwLTQuMiAxLjktNC4yIDQuMnMxLjkgNC4yIDQuMiA0LjJDMzk3Ljgg'
    b'NzE5LjIgMzk5LjcgNzE3LjUgMzk5LjcgNzE1TDM5OS43IDcxNXoiLz48cGF0aCBjbGFzcz0i'
    b'c3QzIiBkPSJNMzYyLjQgNjc3LjZjMCAxLjEgMC45IDIuMSAyLjEgMi4xIDEuMSAwIDIuMS0w'
    b'LjkgMi4xLTIuMSAwLTEuMS0wLjktMi4xLTIuMS0yLjFDMzYzLjQgNjc1LjUgMzYyLjQgNjc2'
    b'LjUgMzYyLjQgNjc3LjZMMzYyLjQgNjc3LjZ6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM4'
    b'NS41IDY3Ny42YzAgMS4xIDAuOSAyLjEgMi4xIDIuMXMyLjEtMC45IDIuMS0yLjFjMC0xLjEt'
    b'MC45LTIuMS0yLjEtMi4xUzM4NS41IDY3Ni41IDM4NS41IDY3Ny42TDM4NS41IDY3Ny42eiIv'
    b'PjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik0zOTEuMiA2ODkuM2MwIDIuMyAxLjkgNC4yIDQuMiA0'
    b'LjJzNC4yLTEuOSA0LjItNC4yYzAtMi4zLTEuOS00LjItNC4yLTQuMlMzOTEuMiA2ODcgMzkx'
    b'LjIgNjg5LjNMMzkxLjIgNjg5LjN6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM1Mi40IDY4'
    b'OS41YzAgMi4zIDEuOSA0LjIgNC4zIDQuMiAyLjMgMCA0LjItMS45IDQuMi00LjIgMC0yLjMt'
    b'MS45LTQuMi00LjItNC4yQzM1NC4zIDY4NS4yIDM1Mi40IDY4NyAzNTIuNCA2ODkuNUwzNTIu'
    b'NCA2ODkuNXoiLz48cG9seWdvbiBjbGFzcz0ic3QzIiBwb2ludHM9IjM5OS41IDUxOC4yIDM3'
    b'NiA1NDEuNyAzNTIuNiA1MTguMiAzNzYgNDk0LjggIi8+PHBvbHlnb24gY2xhc3M9InN0NiIg'
    b'cG9pbnRzPSIzNTQuMyA1MTguNiAzNjEuMyA1MjUuNiAzNjguNyA1MjUuNiAzNjguNyA1MzMg'
    b'Mzc1LjkgNTQwIDM3Ni4yIDU0MCAzODMuMiA1MzMgMzgzLjIgNTI1LjYgMzkwLjYgNTI1LjYg'
    b'Mzk3LjggNTE4LjYgMzk3LjggNTE4LjIgMzkwLjYgNTExLjIgMzgzLjIgNTExLjIgMzgzLjIg'
    b'NTAzLjggMzc2LjIgNDk2LjcgMzc1LjkgNDk2LjcgMzY4LjcgNTAzLjggMzY4LjcgNTExLjIg'
    b'MzYxLjMgNTExLjIgMzU0LjMgNTE4LjIgIi8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTM2Ni4y'
    b'IDQ5OS45YzEuMSAxLjEgMCAzLjgtMi41IDYuMiAtMi41IDIuNS01LjMgMy42LTYuMiAyLjUg'
    b'LTEuMS0xLjEgMC0zLjggMi41LTYuMkMzNjIuMiA0OTkuOSAzNjUuMSA0OTguNyAzNjYuMiA0'
    b'OTkuOUwzNjYuMiA0OTkuOSAzNjYuMiA0OTkuOXoiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJN'
    b'Mzg1LjkgNDk5LjdjMS4xLTEuMSA0IDAgNi4yIDIuNSAyLjUgMi41IDMuNiA1LjMgMi41IDYu'
    b'MiAtMS4xIDEuMS00IDAtNi4yLTIuNUMzODUuOSA1MDMuNyAzODQuNyA1MDAuOCAzODUuOSA0'
    b'OTkuN0wzODUuOSA0OTkuNyAzODUuOSA0OTkuN3oiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJN'
    b'Mzg1LjkgNTM2LjljLTEuMS0xLjEgMC0zLjggMi41LTYuMnM1LjMtMy42IDYuMi0yLjVjMS4x'
    b'IDEuMSAwIDMuOC0yLjUgNi4yUzM4NyA1MzguMSAzODUuOSA1MzYuOUwzODUuOSA1MzYuOXoi'
    b'Lz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzY2LjIgNTM2LjljLTEuMSAxLjEtNCAwLTYuNC0y'
    b'LjUgLTIuNS0yLjUtMy42LTUuMy0yLjUtNi4yIDEuMS0xLjEgNCAwIDYuMiAyLjVDMzY2LjIg'
    b'NTMzLjIgMzY3LjIgNTM2IDM2Ni4yIDUzNi45TDM2Ni4yIDUzNi45eiIvPjxwYXRoIGNsYXNz'
    b'PSJzdDMiIGQ9Ik0zNjguNyA0OTEuN2MwLTEuMSAyLjYtMi4zIDUuOS0yLjYgMC42IDAgMS41'
    b'LTAuOCAxLjUtMC44czAuOSAwLjggMS4zIDAuOGMzLjQgMC4yIDYgMS4zIDYgMi42IDAgMS41'
    b'LTMuNCAyLjYtNy42IDIuNkMzNzEuOSA0OTQuNCAzNjguNyA0OTMuMyAzNjguNyA0OTEuN0wz'
    b'NjguNyA0OTEuN3oiLz48cGF0aCBjbGFzcz0ic3QzIiBkPSJNMzgzLjYgNTQ1LjFjMCAxLjEt'
    b'Mi42IDIuMy01LjkgMi42IC0wLjYgMC0xLjUgMC44LTEuNSAwLjhzLTAuOS0wLjgtMS4zLTAu'
    b'OGMtMy40LTAuMi02LTEuMy02LTIuNiAwLTEuNSAzLjQtMi42IDcuNi0yLjZDMzgwLjIgNTQy'
    b'LjQgMzgzLjYgNTQzLjUgMzgzLjYgNTQ1LjFMMzgzLjYgNTQ1LjF6Ii8+PHBhdGggY2xhc3M9'
    b'InN0MyIgZD0iTTM0OS4yIDUyNS44Yy0xLjEgMC0yLjMtMi42LTIuNi01LjkgMC0wLjYtMC44'
    b'LTEuNS0wLjgtMS41czAuOC0wLjkgMC44LTEuM2MwLjItMy40IDEuMy02IDIuNi02IDEuNSAw'
    b'IDIuNiAzLjQgMi42IDcuNEMzNTIgNTIyLjYgMzUwLjcgNTI1LjggMzQ5LjIgNTI1LjhMMzQ5'
    b'LjIgNTI1LjggMzQ5LjIgNTI1Ljh6Ii8+PHBhdGggY2xhc3M9InN0MyIgZD0iTTQwMi45IDUx'
    b'MWMxLjEgMCAyLjMgMi42IDIuNiA1LjkgMCAwLjYgMC44IDEuNSAwLjggMS41cy0wLjggMC45'
    b'LTAuOCAxLjNjLTAuMiAzLjQtMS4zIDYtMi42IDYgLTEuNSAwLTIuNi0zLjQtMi42LTcuNEM0'
    b'MDAuMiA1MTQuMiA0MDEuNCA1MTEgNDAyLjkgNTExTDQwMi45IDUxMSA0MDIuOSA1MTF6Ii8+'
    b'PC9zdmc+', 'ES_VC')

ES_VC = b64_ES_VC
index.append("ES_VC")
index.append("Spain Valenciana")
catalog["ES_VC"] = ES_VC
catalog["Spain Valenciana"] = ES_VC
country["Spain Valenciana"] = ('ES_VC', '', 1)
lookup["ES_VC"] = ('ES_VC', '', 'Spain Valenciana', 1)
lookup["Valencia Spain Valenciana"] = ('ES_VC', '', 'Spain Valenciana', 1)
lookup["Spain Valenciana"] = ('ES_VC', '', 'Spain Valenciana', 1)
details["ES_VC"] = {"continent":"Europe","capital":"Valencia","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["ES_VC"] = ('ES_VC', 'Spain Valenciana', 1)
regional["Spain Valenciana"] = ('ES_VC', 'Spain Valenciana', 1)
#----------------------------------------------------------------------
b64_ET = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWV0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImV0LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTYxLjMgMGg2ODIu'
    b'N3Y1MTJILTYxLjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0IiBjbGlwLXBhdGg9InVybCgjZXQtYSki'
    b'IHRyYW5zZm9ybT0idHJhbnNsYXRlKDU3LjUpIHNjYWxlKC45NCkiPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmYzYyMSIgZD0iTS0yMzggMy41SDgwMHY0OThILTIzOHoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNlZjIxMTgiIGQ9Ik0tMjQwIDM0Mi41SDc5OS4zVjUxMkgtMjQweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iIzI5OGMwOCIgZD0iTS0yMzggMEg4MDB2MTgwSC0yMzh6Ii8+CiAgICA8Y2ly'
    b'Y2xlIGN4PSI1MzQuMiIgY3k9IjM1MyIgcj0iMTk5LjciIGZpbGw9IiMwMDZiYzYiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KC41NCAwIDAgLjU0IC0yNS44IDc0KSIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmYzYyMSIgZD0ibTIxNC4zIDE4OC4yLTYuNSA0LjUgMjMuNSAzMyA2LjMtNC0yMy40LTMz'
    b'LjV6bTI5LjQgNzgtOS43LTYuOCA0LTEyLjctNDguMS43LTE0LTEwLjcgNjUuNy0uNyAxMi4y'
    b'LTM2LjkgNi42IDE1LTE2LjcgNTJ6bTc2LjUtNzAuNy02LjMtNC44LTI0LjMgMzIuNCA1LjYg'
    b'NC43IDI1LTMyLjN6TTI1NC44IDI0N2wzLjUtMTEuMmgxMy4zTDI1Ni40IDE5MGw2LTE2LjUg'
    b'MjAuNSA2Mi40IDM4LjguNS0xMi4yIDEwLjctNTQuNy0uMnptOTAuNiA1MS4yIDIuNy03LjQt'
    b'MzguMy0xMy4zLTIuOCA3IDM4LjQgMTMuN3ptLTY5LjEtNDYuNCAxMS43LS4xIDQuMSAxMi42'
    b'IDM4LjgtMjguNSAxNy42LjYtNTMuMSAzOC43IDExLjUgMzcuMi0xNC04LjQtMTYuNi01Mi4x'
    b'em0tMTkuOCAxMDIgNy45LjIuMy00MC41LTcuNC0uNS0uOCA0MC45em0yMi04MC4zIDMuOCAx'
    b'MS4xLTEwLjcgOCAzOS40IDI3LjcgNSAxNi44LTUzLjYtMzgtMzEuNSAyMi43IDMuNS0xNiA0'
    b'NC0zMi4zem0tMTAzLjMgMTMgMi4zIDcuNSAzOC43LTEyLjItMi03LjItMzkgMTEuOXptODMu'
    b'Mi00LTkuNCA3LjEtMTAuOC03LjctMTQuMiA0Ni0xNC40IDEwIDE5LjUtNjIuNy0zMS40LTIz'
    b'IDE2LjMtMS42IDQ0LjQgMzEuOXoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'ET')

ET = b64_ET
index.append("ET")
index.append("ETH")
index.append("Ethiopia")
catalog["ET"] = ET
catalog["ETH"] = ET
catalog["Ethiopia"] = ET
country["Ethiopia"] = ('ET', 'ETH', 0)
lookup["ET"] = ('ET', 'ETH', 'Ethiopia', 0)
lookup["Addis Ababa Ethiopia"] = ('ET', 'ETH', 'Ethiopia', 0)
lookup["ETH"] = ('ET', 'ETH', 'Ethiopia', 0)
lookup["Ethiopia"] = ('ET', 'ETH', 'Ethiopia', 0)
details["ET"] = {"continent":"Africa","capital":"Addis Ababa","currency":"Ethiopian Birr","web":".et","lang":"am | en-ET | om-ET | ti-ET | so-ET | sid","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_FI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWZpIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMmY2YyIgZD0iTTAgMTc0LjVoNjQw'
    b'djEzMUgweiIvPgogIDxwYXRoIGZpbGw9IiMwMDJmNmMiIGQ9Ik0xNzUuNSAwaDEzMC45djQ4'
    b'MGgtMTMxeiIvPgo8L3N2Zz4K', 'FI')

FI = b64_FI
index.append("FI")
index.append("FIN")
index.append("Finland")
catalog["FI"] = FI
catalog["FIN"] = FI
catalog["Finland"] = FI
country["Finland"] = ('FI', 'FIN', 0)
lookup["FI"] = ('FI', 'FIN', 'Finland', 0)
lookup["Helsinki Finland"] = ('FI', 'FIN', 'Finland', 0)
lookup["FIN"] = ('FI', 'FIN', 'Finland', 0)
lookup["Finland"] = ('FI', 'FIN', 'Finland', 0)
details["FI"] = {"continent":"Europe","capital":"Helsinki","currency":"Euro","web":".fi","lang":"fi-FI | sv-FI | smn","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_FJ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWZqIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzY4YmZlNSIgZD0i'
    b'TTAgMHY0ODBoNjQwVjBIMHoiLz4KICA8ZyBzdHJva2UtbWl0ZXJsaW1pdD0iNC44Ij4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00MjAuOSAxOTMuMnYxMzYuNGMwIDQ0LjYgODAuNiA3'
    b'MSA4MC42IDcxczgwLjUtMjYuNCA4MC41LTcxVjE5My4yeiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2QyMTAzNCIgZD0iTTQ5MC4zIDI0MS4ydjYxLjRoLTY5LjR2MjIuM2g2OS40djcxLjVsMTEu'
    b'MiA0LjMgMTEuMS00LjNWMzI1SDU4MnYtMjIuNGgtNjkuNHYtNjEuNHoiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNkMjEwMzQiIGQ9Ik00MjAuOSAxOTMuMkg1ODJWMjQ2SDQyMC44eiIvPgogICAg'
    b'PGcgc3Ryb2tlLW1pdGVybGltaXQ9IjMiPgogICAgICA8ZyBmaWxsPSIjZmZmIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjgiIHRyYW5zZm9ybT0idHJhbnNsYXRlKC05Ni45IDk3'
    b'LjUpIHNjYWxlKC42NjQ4NikiPgogICAgICAgIDxlbGxpcHNlIGN4PSI3OTguMiIgY3k9IjE5'
    b'Mi4yIiByeD0iMTMuNiIgcnk9IjExIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9Ijc5OC4yIiBj'
    b'eT0iMTg2LjUiIHJ4PSIxMi4xIiByeT0iNi4xIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9Ijc5'
    b'OC4yIiBjeT0iMTk4LjgiIHJ4PSIxMi4xIiByeT0iNi4xIi8+CiAgICAgICAgPGVsbGlwc2Ug'
    b'Y3g9Ijc5OC4yIiBjeT0iMTkyLjIiIHJ4PSIxMi4xIiByeT0iNi4xIi8+CiAgICAgIDwvZz4K'
    b'ICAgICAgPHBhdGggZmlsbD0iI2ZmZDEwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'Ii44IiBkPSJtNTc4IDIzNS40LTEuMy0zLjZzLTMuNi0xLjUtMy45LTMuNGMtLjYtNS4xLTIu'
    b'NC03LTUuMi03LjhhNiA2IDAgMCAwLTQuNS41Yy0uOCAxLjItNSAxLjItNy4yIDEuMy0yLjMg'
    b'MC0yLjQtMS0yLjQtMS0xLjcgMC0yLjUtMS4zLTIuNS0xLjMtMS4xLTIuMy0yLTMuMi0yLjYt'
    b'My41IDMgMCA1LjItMS4zIDguNi00LjggMy42LTMuOCA2LjItMi40IDYuMi0yLjQtMS44IDMu'
    b'Ni42IDMuMy42IDMuMyA0LjgtMi41LjYtOC43LS44LTguNC0xLjUuMy0xLjktLjctMS45LS43'
    b'IDAgMS4xLTEuNiAxLjYtMS42IDEuNiAxLjItNy4xLTMtOS0zLTktLjYuNi0xIDEuOS0xIDEu'
    b'OS0xLjIgNC4zLTUuMSAzLjYtOS41IDEuNS00LjQtMi0xNiAyLjItMTkuNyAzLjctMy43IDEu'
    b'NS0xMC40IDMuNy0xNi40LjQtNi0zLjQtNy41LTIuOC05LjktMi4xLTIuMy42LTYuNSAxLjYt'
    b'OCAuOGE4LjUgOC41IDAgMCAwLTMuNC0uOWMuNC0uMi0uMi0xLjItLjItMS4yLTEuOS0yLjUu'
    b'Mi00IC4yLTRzLTMuNCAxLTIgNi44bC42LjhzLjQgMS45IDEuNCAyLjR2LjRzLjktLjQgMS4x'
    b'LjhjLjMgMS4yIDEuNiAwIDIuMS0xIDAgMC0uOSA1LjQgNS43IDYuNyAwIDAtLjctLjktLjUt'
    b'MS40LjMtLjYtLjgtMS0uNy0xLjguMS0uOS0xLjYtMS4yLS4zLTEuOSAxLjQtLjYgMi0xLjkg'
    b'NS0uMSAyLjkgMS43IDUuMiAxLjMgNS4yIDEuM3MtMS44LTMuNi0uOC0zLjYgNS40IDUuNCA3'
    b'LjUgNS4yYzIuMi0uMyA2LjQtMi44IDguNS0xLjkgMCAwIC4yLTEgOC4yLTIuNCA4LTEuNCAx'
    b'OC01LjQgMjEuNy0xLjkgMCAwIC40IDIuOCAyIDMuNSAwIDAtLjMgNS44LTEwLjIgMi42bC0z'
    b'LjYtMXMtLjYtMS43LTE5LjUgMy4yYzAgMC0xLjEuNC0xLjkuOS0uNy41LTEuNy0uMy01LjUg'
    b'MS0zLjcgMS41LTE3LjcgNi0yNi4zIDQuNC0xLjktLjYtMy42LS4zLTMuNy0uNiAwLS4zIDEg'
    b'LjEgMSAuMS0uNi0uNy0uOS0uOC0uOS0uOC03LjItLjgtNi00LTYtNGwuNCAxYzEuMi0xLjYt'
    b'LjQtNS4yLS40LTUuMmgtLjFhMy44IDMuOCAwIDAgMCAwLS4zbC41LS40YzMuNS0zIDcuNS0z'
    b'LjUgNy41LTMuNS0yLjQtMy03LjQtMS40LTcuNC0xLjQuMS0zLjUtMS40LTcuNy0xLjQtNy43'
    b'YTEyIDEyIDAgMCAwLTcuNyA0LjdjLS4yLTMuNy00LjktNS44LTQuOS01LjggMS44IDIuMS43'
    b'IDcuMi43IDcuMmguMi0uNWwtLjEgMS4xaC0uMnMtMS43LjYtMy43IDUuMmMwIDAtLjIgMS0x'
    b'IDJ2LS40cy0yLjMgMy03LjQgMGMwIDAtNy00LjEtOS42LTQtMi40LjItNCAxLjMtMy45IDIg'
    b'MCAwLTUuNy0uNC03LjYgMi44IDAgMC00LjMgMS42LS42IDUgMCAwIC41IDEuNiAxLjUgMi40'
    b'IDAgMC0uMS0zLjIuNy0yLjNsLjUuNmMuMS40LjUgMS42IDEuMiAyLjNsLjYtLjJjMC0uOC4y'
    b'LTEuOC40LTIuMmguMmwxIDEuNiAxLS42Yy42IDAgMS4zLjUgMS4zLjVsMS4zLTEuMWMxLjMu'
    b'MiAxLjctMi40IDEuNy0yLjRhNCA0IDAgMCAwIDMuMS0uNWMuNiAyIDUuMiA0LjMgNS4yIDQu'
    b'M2guMmwtLjYuNGMyLjEgMS41IDYgMS4xIDYgMS4xLTEuNi42LTEuNCAzLjctMS40IDMuNy0x'
    b'IC40LTEgMS4zLTEgMS4zIDMuMiAxLjMgNS4zLjIgNS4zLjIuMiAxIDAgMS4yIDAgMS4yLTEu'
    b'MyAyLjctMS45IDUuNC0xLjkgNS40aC4xdi4ycy01LjcgMi04LjEgNC43YzAgMC0uMy0uOC0x'
    b'LS44cy0yLjgtMS44LTMuOC0yLjFjLTEtLjMtMi41LjMtMy0uMi0uMy0uNC0uMS0zLjYtLjgt'
    b'NGwtLjctMmMtLjQgMS0yLjQuOC0yLjQuOGwtLjguNi0uOC0uMWMtLjIgMC0uNC41LS41IDFs'
    b'LS4zLjN2LS42Yy0uMy4zLTEuMS0uMS0xLjQtLjEtLjIgMC0uNC40LS41LjlsLTEuOS4xYy0u'
    b'My4yIDAgMi42IDAgMi42LTIuMyAxLjItMS4yIDMuMS0xLjIgMy4xIDEuMiA2IDExLjUgMy4z'
    b'IDEyLjMgNC4xLjguOCAyLjYgMSAzLjUgMSAxIDAgMi4xIDIuMiAzLjQgMi40IDEuMy4yIDAt'
    b'MS44IDYuMS0zLjIgNi4xLTEuNSA4LjItNCA4LjItNCAxLjktLjQgMi40LTIuNyAyLjUtMy42'
    b'bC4yIDEuNGMuMyAyLjEtMS4yIDMtMS4yIDNsNS4zLTEuN2MyLjEtLjUgMS44LTIuNCAxLjgt'
    b'Mi40IDIgNS44IDUuNyA2LjIgNS43IDYuMi43LTIuMi42LTIuOS42LTIuOWgxLjdjMC0xLjMt'
    b'MS0yLjItMS43LTIuNmwyLjYgMS41IDEtLjFjMCAuOSAxLjMgMS43IDEuMyAxLjdsLjItMS4y'
    b'YzEuMiAxLjYgMy40IDEgMy40IDFhNy4zIDcuMyAwIDAgMC0uMi0uOGM0LjcgMi45IDEyLjIt'
    b'LjggMTIuMi0uOCAyIC40IDIuMy0uOCAyLjMtLjggMi4yLjMgMi44LTEuMyAyLjgtMS4zIDUu'
    b'My0uNCA5LjEtNC4yIDkuMS00LjIgMi43LS4yIDIuOC0yLjEgMi44LTIuMXMyLjYuNSA1LjIt'
    b'Mi43YzYtOC41IDE0LjgtNCAxNC44LTRsLTUuMS4zYy0xMy41LS4xLTcuOSA5LTcuOSA5aC44'
    b'YzEuMy4yIDUuNyAzLjcgNCA2LjJ2LjJjLTIuOCAzLjctNy44LjItOS4zLTMtMS40LTMuMi00'
    b'LjQtMi41LTQuNC0yLjVzLTcuNSAxLjMtNC40IDcuM2MuMSAxLjUgMSAzLjIgMy44IDQuOCAx'
    b'LjUgMi4yIDYuNSAyLjQgMTAuMSAxLjZDNTI0IDI0NCA1MzMgMjQwIDUzMyAyNDBjLjctMiAz'
    b'LTEuNSA1LTQuNCAyLTIuOC0yLjktMy44LTQtNS40LTEtMS41LjMtMS4yLjMtMS4yIDQuNCAy'
    b'LjMgNC44LTUuMiA0LjgtNS4yYTYuNiA2LjYgMCAwIDAgNC4zIDUuNWMyLjMtMi4zLjYtNy4y'
    b'LjYtNy4yIDUuNyAxMC4yIDkuMSA4LjUgOS4xIDguNS0zLTEuOC0xLjUtNC40LTEuNS00LjQg'
    b'Mi43IDEwLjggMTQgMS40IDE0IDEuNC0uNiAxLjYgMCAyLjUgMSAzLjVzMi4yIDEuNCAxLjYg'
    b'My4zYy0uNSAxLjgtNS44IDEuNC01LjggMS40cy01LS4yLTQuNiA0Yy4zIDEgMy42IDEuNCA1'
    b'IDEuMSAwIDAtLjYuMiAxLjMuNGgyLjJjMi4xIDAgNC41LS40IDQuNS0uNCAyLjktLjYgMi40'
    b'LTEuNiAyLjQtMS42IDQuNS0uOCA1LTMuOCA1LTMuOHoiLz4KICAgICAgPHBhdGggZD0iTTQy'
    b'OS42IDIxNi43cy4zLS41LjctLjZjLjQgMCAuOC4yIDEuMi44bC4zLS4ycy0xLjItMS44LS44'
    b'LTNjLjMtLjYuOC0xIDEuNi0xLjF2LS4zYy0xIC4yLTEuNi42LTEuOCAxLjNhMiAyIDAgMCAw'
    b'LS4yLjdjMCAuNi4yIDEuMi41IDEuN2ExLjEgMS4xIDAgMCAwLS44LS4yIDEgMSAwIDAgMC0u'
    b'OC42em0xNDEgMjRjLTMgLjUtNy41LjctNy45LS4yIDAtLjIgMC0uOCAyLjQtMi40bC0uMi0u'
    b'NWMtMi4xIDEuNC0zIDIuMy0yLjcgMyAuNyAxLjggNy4yLjggOC41LjZ6bS01OC40IDEuN2Mt'
    b'LjctMS0uMy0yLjUgMS00LjNsLS41LS4zYy0xLjQgMi0xLjcgMy42LTEgNXoiLz4KICAgICAg'
    b'PHBhdGggZD0iTTUwOC4xIDIzNy44YzAgMS45IDEuNCAzLjYgMy45IDUuMWwuMy0uNWMtMi40'
    b'LTEuNC0zLjYtMy0zLjYtNC42LS4yLTIuNSAyLjUtNC41IDIuNi00LjVsLS4zLS40Yy0uMiAw'
    b'LTMgMi4xLTIuOSA1em01MiAuN2MtLjggMS4zLS41IDIuOC0uNSAyLjhoLjVjMC0uMS0uMi0x'
    b'LjQuNS0yLjVhMyAzIDAgMCAxIDItMS4ydi0uNWMtMS4xLjItMiAuNy0yLjQgMS40ek00NDEg'
    b'MjE1LjFoLS4ydi4ycy0uMiAxLjYtMSAyYS44LjggMCAwIDEtLjYgMGwtMS4zLS43Yy0uMi0u'
    b'Mi0uNC0uMy0uOC0uMmExLjggMS44IDAgMCAxLS40LTEuNGMuMS0uNy42LTEuNCAxLjYtMmwt'
    b'LjItLjNjLTEgLjctMS42IDEuNS0xLjcgMi4zIDAgMSAuNSAxLjYuNSAxLjZ2LjFoLjJjLjMt'
    b'LjEuMyAwIC42LjJsMS40LjhoMWMuNy0uNSAxLTEuOSAxLTIuMiAzLjIuNyA1LjgtMy4zIDYt'
    b'My40bC0uMy0uMnMtMi43IDQtNS44IDMuMnoiLz4KICAgICAgPHBhdGggZD0iTTQzMy4xIDIx'
    b'NC41YTMgMyAwIDAgMCAuNCAyYy4zLjUuNy44IDEgLjkuNSAwIC44LS4zIDEuMi0uNi4yLS4y'
    b'LjQtLjQuNi0uNGwuMy4yLjItLjItLjUtLjNjLS4zIDAtLjYuMi0uOC41cy0uNi41LTEgLjVj'
    b'LS4yIDAtLjUtLjMtLjgtLjhhMi4yIDIuMiAwIDAgMS0uMy0xLjdjLjQtMS40IDIuMS0yLjUg'
    b'Mi4xLTIuNWwtLjEtLjNjLS4xIDAtMS45IDEuMi0yLjMgMi43em0tNC40IDIwLjdjLjEtLjYu'
    b'Ni0xIDEuMy0xLjQtLjIgMCAuNi42IDEuMy42bC41LS4zYy4yLjIgMS40IDEuMyAxLjQgMi43'
    b'IDAgLjMgMCAuNi0uMi45bC4zLjFjLjktMi4xLTEuNC00LTEuNC00aC0uMmwtLjQuM2MtLjYg'
    b'MC0xLjMtLjYtMS4zLS42LTEgLjQtMS40IDEtMS42IDEuNnptMTAuMy01LjRjLS43LjEtMi41'
    b'LjQtMy4xIDEuNC0uMi40LS4zLjgtLjEgMS4ybC4yLjZjLjYgMS42IDEuMiAzLjIgMS45IDMu'
    b'NmwuMS0uM2MtLjYtLjMtMS4yLTItMS43LTMuNGwtLjItLjZhMSAxIDAgMCAxIDAtMWMuNS0u'
    b'NyAyLjItMSAzLTEuMS40IDAgLjUgMS41LjYgMi40aC4zYy0uMS0xLjQtLjMtMi44LTEtMi44'
    b'eiIvPgogICAgICA8cGF0aCBkPSJNNDMzLjkgMjMxLjRjLS40LjMtLjMuOC0uMy45IDAgLjEu'
    b'MiA0IDIgNC44bC4xLS4zYy0xLjYtLjctMS44LTQuNS0xLjgtNC42IDAgMCAwLS40LjItLjYu'
    b'My0uMi44LS4zIDEuNiAwbC4xLS4zYy0uOS0uMy0xLjUtLjItMS45IDB6Ii8+CiAgICAgIDxw'
    b'YXRoIGQ9Ik00MzIuNCAyMzEuN2MtLjguNi0uNyAyLjItLjcgMi4zaC4zczAtMS42LjYtMmMu'
    b'My0uMi42LS4yIDEgMGwuMS0uNGMtLjUtLjItMS0uMi0xLjMgMHoiLz4KICAgICAgPGcgdHJh'
    b'bnNmb3JtPSJ0cmFuc2xhdGUoLTk2LjkgOTcuNSkgc2NhbGUoLjY2NDg2KSI+CiAgICAgICAg'
    b'PHBhdGggZD0iTTg2Mi4zIDE2OS41czEuMyAzIDEuMyA1LjNjMCAuNC0uMi43LS4zIDFsLS41'
    b'LTEuMy0uMyAxcy0uNiAxLjQuMyAyLjljMS4yIDIgNC4yIDMuMiA5IDMuN3YuMWEuOC44IDAg'
    b'MCAwLS40LjFsLS4yLjJ2LjRjLjIuNS43LjUgMS44LjVsLjcuMS42LjItLjEtLjFjMSAwIDIu'
    b'My4zIDMuNi44bC0xIC4yIDEuMS41Yy4xIDAgOC43IDMuNSAxMi4yIDYuMy0xIC45LTUuMyA0'
    b'LTEyLjcgMi4ybC0xLjItLjMuOCAxczQuOSA1LjYgNS45IDljLTEuNyAwLTguMiAwLTEwLjUt'
    b'MmwtLjUuNXMzIDQuNiAzLjggOC4xYy0xIC4yLTMgLjMtNC4zLTEuNGwtLjYtLjctLjMgMmMt'
    b'LjYtLjUtMS40LTEuMS0xLjQtMS45di0uNGwtMS44LjMtMy44LTIuM2E4IDggMCAwIDAtLjYt'
    b'LjRsLS40LjcuNi4zYy44LjYgMi4yIDEuNyAyLjMgMy4zSDg2M3YuNWMwIC4zIDAgMS40LS45'
    b'IDMuNy0xLjEtLjItNS4zLTEuNy03LjgtOC44bC0uOC4ydi4yYzAgLjctLjIgMi4zLTIuNCAy'
    b'LjlsLTYuNSAyYTQuNSA0LjUgMCAwIDAgLjgtMi44di0uOGEyMC4zIDIwLjMgMCAwIDEtLjIt'
    b'Mi42YzAtMS41LjMtMi40IDEuNC0zbC0uNC0uOGMtLjEgMC05LjYgMy45LTE0LjMgMi4zLjIt'
    b'MSAxLTQuMiAyLjYtNy42bC0uMi4yYy4zLS4yLjYtLjYuMy0yLjJ2LS41bC0uNS4ycy0zIDEu'
    b'NC03LjQtLjJjMC0uNC4zLTEgMS4yLTEuNGwuMy0uMXYtLjhjMC0xLjIuMS00IDEuOC00LjZs'
    b'LS4yLS44cy01LjEuNC04LjItMS4zYTExIDExIDAgMCAxIDQuNS0xLjloLjN2LS40YTYgNiAw'
    b'IDAgMC0uNS0yLjNjMS4yLjQgMi42LjcgMy4xLjNsLjItLjEtLjItMy4xaC0uOGwuMSAyLjYt'
    b'My0uNy0xLjItLjQuOCAxYTQgNCAwIDAgMSAuNyAyLjQgMTIuNyAxMi43IDAgMCAwLTUgMi4z'
    b'bC0uNS40LjUuM2MyLjQgMS42IDYuMSAxLjggOCAxLjdhOC40IDguNCAwIDAgMC0xLjMgNC41'
    b'di40YTMuMSAzLjEgMCAwIDAtMS41IDIuMnYuM2wuMi4xYTExIDExIDAgMCAwIDcuOS41di45'
    b'Yy0yIDQuMi0zIDguMy0zIDguM3YuNGguM2MzLjkgMS42IDEwLjctLjUgMTMuOC0xLjYtLjQu'
    b'Ny0uNyAxLjUtLjcgMi41YTIyLjEgMjIuMSAwIDAgMCAuMyAzLjRjMCAyLjMtMS41IDMuMi0x'
    b'LjYgMy4ybC4zLjggOC0yLjRjMS44LS41IDIuNS0xLjYgMi44LTIuNSAzLjEgNy40IDggOCA4'
    b'LjMgOC4xaC4zbC4xLS4zYTE0IDE0IDAgMCAwIDEtNCA0MzkuNiA0MzkuNiAwIDAgMCAyLjQt'
    b'LjF2LS41YzAtLjctLjEtMS4zLS40LTEuOGwxLjQuOCAxLjMtLjJjLjMgMS4zIDEuOSAyLjQg'
    b'Mi4xIDIuNWwuNS4zLjMtMS43YzIgMS43IDQuNyAxLjIgNC45IDEuMmwuMy0uMXYtLjRjLS40'
    b'LTIuNy0yLjItNS45LTMuMy03LjYgMy41IDEuNiA5LjkgMS41IDEwLjIgMS41aC40di0uNWEz'
    b'MCAzMCAwIDAgMC01LjYtOWM4LjIgMS41IDEyLjYtMi44IDEyLjgtM2wuMy0uMy0uNC0uMmE1'
    b'My44IDUzLjggMCAwIDAtMTEuNi02LjNsLjktLjItMS0uNWExMi44IDEyLjggMCAwIDAtNS44'
    b'LTEuNGMtMS0xLjItMS41LTEuMy0xLjYtMS40LTUuNi0uNi03LjYtMi4xLTguNC0zLjN2LS4z'
    b'bC4yLS4zYy41LS43LjctMS42LjctMi42IDAtMi42LTEuMy01LjUtMS4zLTUuNmwtLjguM3oi'
    b'Lz4KICAgICAgICA8cGF0aCBkPSJNODM2LjggMTY3LjlzLS42IDMtMy4yIDQuNWMtMiAxLTQu'
    b'NSAxLTcuNi0uM2wtLjQtLjF2LjRhNSA1IDAgMCAwIDIgMy4yYzEuMyAxIDMuMyAxLjQgNS45'
    b'IDEuMi0uOSAxLTMuNiA0LjQtMy42IDcuOHYuNWMuNC4yIDQuNiAxLjQgNi42LTEuMSAwIDEg'
    b'LjQgNC41IDEuNyA1LjguOC44IDEgMS44IDEgMi43IDAgLjgtLjIgMS40LS4yIDEuNGwtLjIu'
    b'Ni41LS40Yy4yLS4xIDQuMS0zIDUuMy02LjcgMCAwIC43LTEgMS45LTEuM3YuNWMwIDEuNS42'
    b'IDQuMSA0LjggNS43bC4zLjF2LS4zYTcuMSA3LjEgMCAwIDEgMC0uN2MwLTEuMSAwLTMgMS4x'
    b'LTRhMi44IDIuOCAwIDAgMCAuNi0zLjNjLjkuMiAyLjkuOSAzLjcgMi40IDEuMiAyLjIgNS4z'
    b'LjQgNS41LjRsLS4xLS41cy0xLjguNC0yLjktLjNhMi4xIDIuMSAwIDAgMS0uOC0xLjVsLS4y'
    b'LTIuNGMwLTEtLjItMS43LS43LTIuMi41IDAgMS42IDAgMiAxIC44IDEuNiAzLjMgMS43IDMu'
    b'NCAxLjdsLjkuMS0uNy0uNXMtMi4yLTEuNC0xLjgtMy4zbC4zLTEuNGMuNi0yLjUgMS42LTYu'
    b'Ni43LTkuMmwtLjQuMmMuMi42LjMgMS40LjMgMi4yIDAgMi4yLS43IDUtMSA2LjdsLS40IDEu'
    b'NGEyLjYgMi42IDAgMCAwIDAgLjVjMCAxLjMuNyAyLjIgMS4zIDIuNy0uNy0uMS0xLjctLjUt'
    b'Mi0xLjMtLjctMS40LTIuMy0xLjQtMy0xLjNsLS42LjEuNC40Yy43LjQuOCAxIC44IDIuM2wu'
    b'MiAyLjNjLjEuOC41IDEuNCAxIDEuOC42LjQgMS4yLjQgMS43LjUtMS4yLjMtMi45LjUtMy41'
    b'LS42LTEuMS0yLjItNC4zLTIuNy00LjQtMi44aC0uNWwuMi40cy40LjYuNCAxLjRjMCAuNS0u'
    b'MiAxLjItLjcgMS43LTEuMSAxLjEtMS4zIDMuMi0xLjMgNC4zdi40Yy0zLjYtMS41LTQuMi0z'
    b'LjctNC4yLTV2LTFsLjItLjNoLS40YTMuNSAzLjUgMCAwIDAtMi41IDEuOCAxNSAxNSAwIDAg'
    b'MS00LjcgNi4yIDYuOSA2LjkgMCAwIDAgLjEtMWMwLS45LS4yLTItMS0yLjktMS41LTEuNC0x'
    b'LjctNi0xLjctNnYtLjhsLS40LjdjLTEuNiAyLjgtNi4yIDEuNC02LjMgMS40LS4yLTMuNSA0'
    b'LTguMSA0LTguMmwuNC0uNGgtLjZjLTIuNy40LTQuOCAwLTYuMi0xYTQuNiA0LjYgMCAwIDEt'
    b'MS42LTIuNWMzIDEuMSA1LjYgMS4yIDcuNi4xYTcuNCA3LjQgMCAwIDAgMy40LTQuOGMzLTYu'
    b'NiA1LjUtNy43IDUuNS03LjdsLS4xLS40Yy0uMiAwLTIuOCAxLTUuOCA4eiIvPgogICAgICAg'
    b'IDxwYXRoIGQ9Ik04NDMuNSAxNThoLS4ybC0yLjQgMy4zaC43YTMxIDMxIDAgMCAxIDE5Ljcg'
    b'OS4ybC4zLjMgMi4zLTIuNS0uMi0uM2MtNi41LTEwLjItMjAuMS0xMC0yMC4zLTEwem0uMi45'
    b'YzEuNiAwIDEzLjIuMyAxOS4yIDkuM2wtMS4zIDEuNGEzMyAzMyAwIDAgMC0xOS4zLTguOSA2'
    b'MzEuMiA2MzEuMiAwIDAgMSAxLjQtMS44eiIvPgogICAgICAgIDxwYXRoIGQ9Ik04NDEuNiAx'
    b'NjQuOGExMSAxMSAwIDAgMC0yLjEgNC44bC4xLjRhNy4zIDcuMyAwIDAgMC0yIDUuNWMwIDEu'
    b'My4yIDIuNi42IDMuOGwuMy43YzEuMiAzLjQgMi4zIDYuNCA3LjggNC42IDUuMi0xLjYgNS40'
    b'LTIgNi43LTQuMmwuNC0uNWMuNy0xLjIgMS41LTEuNCAyLjMtMS43IDEtLjMgMi0uNiAzLTIu'
    b'NGwuOC0xLjNjMS0xLjMgMi4yLTMgMi4zLTVoLS40YTkuOCA5LjggMCAwIDEtMi4yIDQuN2wt'
    b'MSAxLjRhMy42IDMuNiAwIDAgMS0yLjYgMi4yIDMuOSAzLjkgMCAwIDAtMi42IDEuOGwtLjQu'
    b'NmMtMS4yIDIuMS0xLjQgMi40LTYuNSA0LTUgMS42LTYtLjktNy4yLTQuNGwtLjMtLjdjLTEu'
    b'NC0zLjgtLjMtNy42IDEuNi05bC42LS41LS45LjF2LS4xYzAtLjcuNy0yLjYgMi00LjUgMS4y'
    b'LTEuNiA0LTMuMSA0LTMuMmwtLjItLjRjLS4yLjEtMi45IDEuNy00LjEgMy4zeiIvPgogICAg'
    b'ICAgIDxwYXRoIGQ9Ik04MzkuMiAxNzguN2MuOS42IDIuMS41IDMuNyAwIDAgLjUgMCAxLjcg'
    b'MSAyLjUgMS4yIDEgMyAxLjIgNS41LjZ2LS41Yy0yLjQuNi00LjIuNC01LjItLjVhMyAzIDAg'
    b'MCAxLS45LTIuNHYtLjRsLS4zLjJjLTEuNS42LTIuNy43LTMuNiAwLTEuNS0xLTEuNC0zLjct'
    b'MS40LTMuN2gtLjRzLS4yIDMgMS42IDQuMnoiLz4KICAgICAgICA8cGF0aCBkPSJNODQyIDE3'
    b'NWMtLjYuMi0uOC43LS44IDEuMXYuM2MuMiAxLjIgMS41IDIgMi42IDIuMyAxLjIuMyAyLjYu'
    b'NCAzLjEtLjMuMi0uMy40LS44IDAtMS43YTMuNyAzLjcgMCAwIDAtNC44LTEuN3ptMiAzLjNj'
    b'LTEtLjMtMi4yLTEtMi4zLTIgMCAwLS4xLS43LjUtLjlhMy4zIDMuMyAwIDAgMSA0LjIgMS42'
    b'Yy4zLjQuMy44LjEgMS0uMy41LTEuNC42LTIuNS4zem0tMi0zLjN6bTEuNiA2Yy0uMyAyLjUg'
    b'MCAyLjYuMSAyLjZoLjJsLjItLjEgMS40LTItMS44LS44di4zem0uNS40LjcuMy0uOCAxLjF2'
    b'LTEuNHptLTQuMi0yLjQtLjEgMi4zIDItMi40LTItLjJ2LjN6bS40LjJoLjZsLS42Ljh2LS44'
    b'eiIvPgogICAgICAgIDxwYXRoIGQ9Ik04MzguNSAxNzguMnMxLjUgMi45IDEuOCA0Yy4xLjYg'
    b'MSAxLjQgMiAxLjcgMSAuNCAyIC40IDIuNy0uMWwxLjMtMS4xYy40LS41LjYtLjYgMS0uNXYt'
    b'LjVjLS42IDAtLjkuMi0xLjMuNmwtMS4zIDFjLS44LjYtMS43LjQtMi4yLjItMS0uMy0xLjct'
    b'MS0xLjgtMS41LS4zLTEtMS43LTMuOS0xLjgtNGwtLjQuMnptMi04LjZhNSA1IDAgMCAwLTIu'
    b'NCAyLjhsLjQuMXMuNy0xLjggMi4xLTIuNWEyLjkgMi45IDAgMCAxIDIuNCAwbC4xLS40Yy0x'
    b'LS40LTEuOC0uNC0yLjcgMHptMTAuOCA1LjJjLjIgMCAzLjIgMi40IDEuNSA1LjJsLjMuM2My'
    b'LTMuMy0xLjUtNS45LTEuNS02bC0uMy41em0tOS4yLjRzLS41IDEuNyAyIDIuM2MwIDAtMi4z'
    b'IDAtMi41LS42LS4xLS42IDAtMS45LjUtMS43em03LjUgMmMwIC4yLS4yLjMtLjMuM2EuMy4z'
    b'IDAgMCAxLS4zLS4yYzAtLjIuMS0uMy4zLS4zLjEgMCAuMy4xLjMuM3ptLjIgMS4yYzAgLjEg'
    b'MCAuMi0uMi4yYS4zLjMgMCAwIDEtLjMtLjIuMy4zIDAgMCAxIC4zLS4zYy4xIDAgLjIuMS4y'
    b'LjN6Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iODQ4IiBjeT0iMTc3LjgiIHI9Ii4zIi8+CiAg'
    b'ICAgICAgPHBhdGggZD0iTTg0OC44IDE3OS40YS4zLjMgMCAxIDEtLjYgMGMwLS4xLjEtLjIu'
    b'My0uMmwuMy4yem0tNy4xLTcuM2EuMy4zIDAgMCAxLS42IDAgLjMuMyAwIDAgMSAuNSAweiIv'
    b'PgogICAgICAgIDxjaXJjbGUgY3g9Ijg0MS42IiBjeT0iMTczLjIiIHI9Ii4zIi8+CiAgICAg'
    b'ICAgPGNpcmNsZSBjeD0iODQwLjEiIGN5PSIxNzIuNyIgcj0iLjMiLz4KICAgICAgICA8cGF0'
    b'aCBkPSJNODQwLjggMTc0LjNhLjMuMyAwIDAgMS0uMi4zLjMuMyAwIDAgMSAwLS42LjMuMyAw'
    b'IDAgMSAuMi4zem00LjgtOS42czMuNSAyLjIuMSA2LjNjMCAwIDEuNy0xLjMgMS44LTMuNC4y'
    b'LTIuMS0xLjItMy44LTItMi45em0xMy41IDUuOWMtMS4yLjYtMi44LS41LTMuNi0xLjUtLjgt'
    b'MS0yLjUtMS4zLTMuNi42LTEgMS44LTIuNSAyLjUtMi41IDIuNXMxLjUtLjggMy0yLjVjMS41'
    b'LTEuNiAyLjQtLjMgMy45LjUgMS40LjggMS43IDEgMi43LjV2LS4xeiIvPgogICAgICAgIDxw'
    b'YXRoIGQ9Ik04NTguOCAxNzAuOWExLjcgMS43IDAgMCAxLTIuMi0uMWMtMS0uOC0xLjctMS44'
    b'LTIuOC0xLjItMS4yLjYtMy4zIDIuMi0zLjMgMi4yczMuNS0yLjQgNC4yLTEuOGMuNi41IDIu'
    b'MiAxLjggMy4xIDEuNGwxLS41eiIvPgogICAgICAgIDxwYXRoIGQ9Ik04NTYuMSAxNzIuM2Mt'
    b'MS4xLS44LTIuMiAxLTMuMS44LTEtLjItMS43LTEuOC0xLjctMS44cy44IDEuNiAyIDEuM2Mx'
    b'LjMtLjQgMi4xLTEuMiAyLjktLjYuNy42LS4xLjMtLjEuM3oiLz4KICAgICAgICA8cGF0aCBk'
    b'PSJNODU0LjQgMTcyLjZhMiAyIDAgMCAxLTIuNC0xLjlzLjcgMS44IDIuNiAxLjVsLS4yLjR6'
    b'Ii8+CiAgICAgICAgPHBhdGggZD0iTTg1NC4zIDE3MS4yYy4xLjUuMS44LS41LjhzLTEtLjIt'
    b'MS0uOGMwLS41IDEuNC0uNCAxLjUgMHptLTcuOC0zYS43LjcgMCAwIDEtLjcuNmMtLjQgMC0u'
    b'NS0uMi0uNS0uNnMwLS43LjUtLjcuNy4zLjcuN3oiLz4KICAgICAgICA8cGF0aCBkPSJNODQ0'
    b'IDE2NS43czMuOCAwIDIgNC43YzAgMCAxLjQtMi4zLjUtNC0xLTEuNi0yLjMtMS4yLTIuMy0x'
    b'LjJzLS40LjMtLjIuNXoiLz4KICAgICAgICA8cGF0aCBkPSJNODQ0IDE2Ny42YzAgMSAuNiAx'
    b'LjkgMS44IDIuOWwuMy0uNGMtMS4xLS45LTEuNy0xLjctMS43LTIuNXMuNi0xLjMuNi0xLjNs'
    b'LS4zLS4zcy0uNy42LS44IDEuNnoiLz4KICAgICAgICA8cGF0aCBkPSJNODQ0LjggMTY4LjRj'
    b'LjEuNS42IDEgMS4yIDEuMmwuMi0uNGMtLjUtLjItLjktLjYtMS0xLS4yLS44LjQtMS43LjQt'
    b'MS43bC0uNC0uM3MtLjcgMS4yLS40IDIuMnptNS4xIDIuNnMuNyAxLjUtLjMgMy4xbC0xIDEu'
    b'NnMxLjItMi4zLjctMy4yYy0uNC0xIC42LTEuNS42LTEuNXptMTQuNiAxNS44YzMuOC43IDEy'
    b'LjUgNy41IDEyLjUgNy41bC41LS42Yy0uMy0uMy04LjktNy0xMi45LTcuN2wtLjIuOHptMy40'
    b'IDkuNWMuMiAzLjUgNCA1LjYgNCA1LjdsLjUtLjdzLTMuNS0yLTMuNy01aC0uOHptLTkuMy44'
    b'YzAgMy44IDMuNiA4LjQgMy44IDguNmwuNi0uNXMtMy42LTQuNi0zLjYtOC4xaC0uOHptLTEy'
    b'LjEuNGMuNiAxLjMuNiAxLjkuNCAyLjItLjIuNC0uNi40LS42LjRsLjEuOGMuMyAwIC45LS4y'
    b'IDEuMi0uOC40LS43LjMtMS43LS40LTNsLS43LjR6Ii8+CiAgICAgIDwvZz4KICAgICAgPGcg'
    b'ZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4yIj4KICAgICAgICA8'
    b'cGF0aCBkPSJNNDI5LjYgMjE2LjNzLjEgMS43IDEuNCAyLjdjMCAwLS4xLTEuOC4zLTIuNiAw'
    b'IDAtLjctLjgtMS43LS4xem0yLjYgMXMuMyAxLjYgMS4yIDIuM2wuNi0uMXMuMi0yIC41LTIu'
    b'MmMuMy0uMi0xLjMuNy0yLjMgMHoiLz4KICAgICAgICA8cGF0aCBkPSJtNDM0LjUgMjE3LjMg'
    b'MSAxLjYgMS4yLS43LS4yLTEuOHMtLjctLjItMiAuOXptNC43LjMtMS4zIDEuMXMtLjctLjUt'
    b'MS4yLS41bC4yLTEuN3MxLS43IDIuMyAxLjF6bS05LjMgMTZzLS4yLTIuNCAwLTIuNWMwIDAg'
    b'MSAuMyAxLjQgMCAwIDAgLjUgMS44LjQgMi42LS4yLjgtMS4xLjUtMS44IDB6bTYtMi40cy0u'
    b'MS0yIC4yLTIuM2MwIDAgMiAuMyAyLjQtLjhsLjcgMnMtMi4xLS4zLTMuNCAxeiIvPgogICAg'
    b'ICAgIDxwYXRoIGQ9Ik00MzMuOCAyMzEuNnMuMy0yLjEuNy0yLjJjMCAwIDEgLjMgMS4zLS4x'
    b'djIuNnMwLTEuMS0yLS4zem0tMi4zLjNzLjUtMS45LjgtMS45IDEgLjUgMS40LjJ2MS40cy0x'
    b'LjYtLjQtMS45IDEuOWwtLjMtMS42eiIvPgogICAgICA8L2c+CiAgICA8L2c+CiAgICA8ZyBm'
    b'aWxsPSIjMDBhNjUxIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjgiPgogICAgICA8'
    b'cGF0aCBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDYxLjcgMjcwLjRzNS4yIDQuOSAzLjkgOS4y'
    b'YzAgMCAzLjMtNy4zLS4zLTkuNS0zLjYtMi0zLjctLjUtMy42LjN6Ii8+CiAgICAgIDxwYXRo'
    b'IGZpbGw9IiM5NjRiMzYiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00NTUgMjc1LjFzLTEuMyAy'
    b'IC4yIDMuM2MwIDAtMS43IDIuNC0uNCA0LjQgMCAwLTEgMi4xLS44IDQuNCAwIDAtLjggMy41'
    b'IDEgNS4xIDAgMCAyIDEgMyAuMSAwIDAgMS43LTIuNi42LTUuMyAwIDAgMS4yLTIuMy0uMi01'
    b'LjIgMCAwIC40LTEuNi0uNy0zLjUgMCAwIC43LTEuMi4xLTIuMiAwIDAtMi41LTIuNy0yLjgt'
    b'MXoiLz4KICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTQ1Ni41IDI2OXMtNi4y'
    b'LTEyLTEwLjYtMTIuNWMtNC40LS41LTQuNi00LjgtNC42LTQuOHMuNSAyIDQgMiAxMC4yIDUg'
    b'MTEgOC43Yy43IDMuNyAxLjUgMy4yIDEuNSAzLjJsLTEuMyAzLjR6Ii8+CiAgICAgIDxwYXRo'
    b'IHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00NTYuNSAyNjguMXMyLjMtMTUuMSAxMi4yLTE1LjRj'
    b'OS45LS4yIDYuNi44IDktLjggMCAwLTYuNiAzLjQtMTAuNyA0LTQuMi40LTcuNiA4LjUtNy40'
    b'IDEwIDAgMS41LTIuMyA0LjQtMy40IDMuNC0xLjItMSAuMy0xLjIuMy0xLjJ6Ii8+CiAgICAg'
    b'IDxwYXRoIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00NTguOCAyNzMuOHMyLjMtNiA2LjEtNGMw'
    b'IDAtMy01LjgtOC40LS44IDAgMCAyLjQgMy4zIDIuMyA0Ljh6bS03LjUtNnMzLjIgMTMuNC0x'
    b'LjggMTcuNWMwIDAgLjItNi45LTIuOS0xMS0zLTQuMiAzLTguNyA0LjctNi41eiIvPgogICAg'
    b'ICA8cGF0aCBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDUxLjcgMjcwLjFzNS45IDUuNyA2LjIg'
    b'Ny42Yy40IDEuOCAxLjgtNS43LTEtNy44cy01LjctMi41LTUuNy0yLjVsLjUgMi44eiIvPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjOTY0YjM2IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDQwLjgg'
    b'Mjg1cy41IDIuMyAyIDIuOGMwIDAgMCAxLjcgMS40IDIuMiAwIDAtLjcgMS41LjQgMi40IDAg'
    b'MC0uMiAzIC44IDMuNSAwIDAgMi43LS4xIDMuNi0uOSAwIDAgLjUtMS45LTEtMy44IDAgMCAu'
    b'My0xLjgtMS4yLTIuOCAwIDAgLjUtMi41LTEuNC0zLjQgMCAwLS4zLTItMS40LTMgMCAwLTIu'
    b'MiAzLjEtMy4yIDN6Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00NDMu'
    b'NyAyODJzLTcuNy0yLjgtMTIgMS4yYzAgMCA2LjYgMSA3LjQgMi4zLjggMS4zIDQuOS0yLjIg'
    b'NC42LTMuNXoiLz4KICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuNSIgZD0ibTQ0MS4zIDI4'
    b'Ni44LTEuNC0xYy0uNy0uNi03LjItMi4zLTguMSA0IDAgMC0yLjQtNi4zIDEtNyAzLjUtMSA2'
    b'LjIgMSA4LjUgNG0tNS0xMi44czIuMyA1LjIgMy4yIDUuNGMuOS4zIDEuNS0uNiAxLjUtLjZz'
    b'LTMuMS00LjYtNC44LTQuOHptLTEuOC03LjlzLTItNi42LTQuNC00LjhjLTIuNCAxLjctMS44'
    b'IDYuNS0xLjggNi41cy00LjctNS0yLTguOGMyLjgtMy45IDguMi40IDguMiA3LjF6Ii8+CiAg'
    b'ICAgIDxwYXRoIGZpbGw9IiM5NjRiMzYiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00MzkuOSAy'
    b'NzkuOHMwIDEuMy45IDEuNmMuOC40IDIuNSAxIDIuNS4zcy0xLjMtMy43LTEuOC0zLjNjLS41'
    b'LjQtMS40LjQtMS42IDEuNHoiLz4KICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuNSIgZD0i'
    b'TTQzOC40IDI3MnMtLjMtNS43IDMuNS03LjljMCAwIC43LjIgMS4xLTEgMCAwLTMgNy4zLTIu'
    b'MSAxMWwtLjEuNCIvPgogICAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDM5LjEg'
    b'MjY1czYuOC0xNCAxNS05LjFjMCAwLTguNiAxLjctMTEuNyA3LjlsLTMuMSA0LjYtLjItMy40'
    b'eiIvPgogICAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDM1LjUgMjcwLjFzLTIt'
    b'OS40LTMuMy0xMC42Yy0xLjItMS4zLTMuMy0yLjYtNS45LS41IDAgMCA0LjQtMy45IDktLjYg'
    b'NC43IDMuMiAzLjcgOC40IDMuNyA4LjRsLS41IDYuNS0zLjEtMi45Ii8+CiAgICAgIDxwYXRo'
    b'IHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00NDIuOCAyODEuM3MtOC4zLTE1LjctMTMuNy00LjVj'
    b'MCAwLTEgMi45LjEgNCAwIDAtMy0yLjMtMS42LTcuOHMxMC41LTMgMTMuMiAxLjVjMi42IDQu'
    b'NSAzLjMgNi44IDMgNy0uNC4zLTEtLjItMS0uMnptMjMuMyA0LjVzNi0xMi40IDkuNS02Ljhj'
    b'MCAwIDEgMi44LS41IDQgMCAwLTIuNC0zLTQuNS42LTIuMiAzLjUtMS4zIDMuMi0xLjMgMy4y'
    b'cy0yLjIuNi0zLjItMXoiLz4KICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTQ3'
    b'NSAyODNzMy4zIDEuNyAyLjIgNS4yYzAgMCA0LjQtOC40LTEuNi05LjIgMCAwIDEuMSAyLjct'
    b'LjUgNHptLjUtOC42czcuOSAyLjMgOC4xIDUuN2MwIDAgMS40LTYuNi0zLjEtOC42IDAgMC01'
    b'LjQgMS01IDN6Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00NzkgMjY0'
    b'YzMuNC02LjYgNy42IDIuMSA3LjYgMi4xczEuNS02LjktMi43LTguMWMtNC4zLTEuMy03IDE0'
    b'LjctNyAxNC43bC01IDFzMS4zLTEzLjggOC44LTE1aDEiLz4KICAgICAgPHBhdGggc3Ryb2tl'
    b'LXdpZHRoPSIuNSIgZD0iTTQ3MyAyNjhzLTQuOC05LjgtOC0xMC44IDEuNy0yLjUgMy43LS42'
    b'IDUuOCA0LjMgNS40IDkuM0w0NzMgMjY4em0tNSAxMy40czEuNC02LjYgNS4yLTguNmMzLjgt'
    b'MiA3LjMtMS4zIDcuMy0xLjNzLTQuNSAxLTUuMyAzLjNjLS43IDIuMi0yIDIuNC0yIDIuNGwt'
    b'NS4xIDQuMnoiLz4KICAgICAgPHBhdGggZmlsbD0iIzk2NGIzNiIgc3Ryb2tlLXdpZHRoPSIu'
    b'NSIgZD0iTTQ2NiAyODUuOHMtMiA0LTEuNiA0LjZjMCAwLTIuMiAzLjMtMS4zIDUgMCAwIDIu'
    b'MiAxLjcgMy4yIDEgMCAwIDIuNi0zLjcgMS45LTUuNyAwIDAgMS44LTIuNCAxLjEtMy45IDAg'
    b'MC0yLjYuMS0zLjItMXoiLz4KICAgICAgPHBhdGggZmlsbD0iIzAwMCIgc3Ryb2tlPSJub25l'
    b'IiBkPSJNNDU1IDI3OC42Yy4yLjEgMS41LjcgMi4zLjRsLjYtLjUtLjUtLjJjLS4zLjYtMS43'
    b'LjEtMi4xLS4xbC0uMi40em0tLjEgNC0uMi41Yy4xIDAgMi43LjUgMy45LS42bC0uNC0uNGMt'
    b'MSAuOS0zLjMuNC0zLjQuNHptLS43IDQuNC0uMy40czMgMi4xIDQuOS0uMmwtLjUtLjNjLTEu'
    b'NSAxLjktNCAuMi00LjEgMHptLTExLjUuNi4xLjNjLjEgMCAyLjYtMSAyLjgtMi45aC0uM2Mt'
    b'LjEgMS42LTIuNSAyLjYtMi42IDIuNnptMS40IDIuM3YuM2MuMiAwIDIuNS0uMiAyLjktMS44'
    b'aC0uM2MtLjQgMS4zLTIuNSAxLjUtMi42IDEuNXptLjUgMi40di4zYy4xIDAgMi43LjEgMy42'
    b'LTEuM2wtLjMtLjJjLS44IDEuMy0zLjMgMS4yLTMuMyAxLjJ6bTE5LjctMS43czEuMSAxLjIg'
    b'Mi40IDEuMWEyLjMgMi4zIDAgMCAwIDEuNy0uOGwtLjQtLjRjLS40LjUtLjguNy0xLjMuNy0x'
    b'IDAtMi0xLTItMWwtLjQuNHoiLz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiM5NjRiMzYiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyI+CiAgICAgIDxwYXRoIGQ9Ik01NDIgMjk5'
    b'LjhhMS4xIDEuMSAwIDAgMC0uMy4zbC40LS4zem05LjMtMi4zYy0uMS0uMi0uMi0uMS0uMy0u'
    b'MmwtLjQtLjhoLS4zbC0uNy0xLjRhLjQuNCAwIDAgMCAwLS4zIDcuNiA3LjYgMCAwIDAgMC0u'
    b'NHMtLjIgMC0uMy0uMnYtMS42bC0uMS0uNWEyIDIgMCAwIDEtLjMtMS4xdi0xYy4xLS40LS4x'
    b'LS42LS4xLTFsLjEtLjl2LTUuNGwtLjEtMS0uMS0uNHYtMS42IDIuNmwtLjItNC4zLTMuNC0x'
    b'LjZzLS4zIDYuMi0uMiA3YzAgLjkuNCA2LjcuMiA3LjRsLS41IDQuM3MtMS42IDEuMi0yLjIg'
    b'Mi40Yy0uNyAxLjMtLjUgMS43LS43IDEuN2wxLjUtLjItMS4xLjhhLjcuNyAwIDAgMSAuNy4x'
    b'bC4yLjIuMi0uMmMuMyAwIC41LjQuNy4zbC40LS4yLjItLjRjLjEtLjEuMyAwIC40IDBoLjdj'
    b'LjMgMCAuNi0uNS45LS43LjItLjIuNC0uMy43LS4zLjMgMCAuNi4zIDEgLjMuMiAwIC4zIDAg'
    b'LjUtLjJsLjQtLjYuOC0uMS40LjFoLjZsLjMuMi4yLS40LS4xLS40eiIvPgogICAgICA8cGF0'
    b'aCBkPSJNNTQ0LjUgMjk5LjdoLjZ2LjJhLjIuMiAwIDAgMCAuMiAwbC4zLjJoLjNsLjQuMWMu'
    b'Mi4xLjQgMCAuNi0uMS4yLS4yLjMgMCAuNi4yLjEuMS4xLjEuMiAwbC4xLS4xLjMtLjEuMy0u'
    b'MS40LS4yLjQuMmEuOC44IDAgMCAxIC4yIDBsLjctLjVjLjMtLjIuNSAwIC43IDBoLjNjLjEt'
    b'LjEuMiAwIC40IDAgMC0uMSAwLS4yLjItLjNsLjcuNGMuMS4xLjcuMi42LS4yIDAtLjQtLjQt'
    b'LjEtLjUtLjR2LS42YS43LjcgMCAwIDAtLjMtLjRjLS4yIDAtLjIuMS0uNCAwbC0uMi0uNi0u'
    b'My4yYy0uMiAwLS4yLS4xLS4zLS4zLS4zLS4zLS40LjItLjcuMS0uMiAwLS40LS41LS41LS43'
    b'LS4xLS4xLS4zLS41LS41LS40LS4yLjEgMCAuNSAwIC43aC0uNWMtLjIgMC0uMiAwLS4zLjIt'
    b'LjIuNC0uMy43LS43LjYtLjEgMC0uMy0uMS0uNCAwbC0uNS4yYTEgMSAwIDAgMS0uNCAwbC0u'
    b'NC0uNGEuMS4xIDAgMCAwLS4yIDAgOC43IDguNyAwIDAgMC0uMS0uMmMtLjIgMC0uMiAwLS4z'
    b'LjNsLS4xLjUtLjMuNC0uNC4xYy0uMiAwLS40LjMtLjQgMC0uMi0uNC4zLTEuMS0uMi0xLS4x'
    b'IDAtLjIgMC0uMy4ydi43Yy0uMS4zLS43LjgtLjYgMSAwIC4zLjQgMCAuNCAwbC4yLjRjLjIu'
    b'My43LS40LjcgMG0tMi4xLTIuN3YtLjJsLS40LS4xYy0uMiAwLS40LjMtLjUuNC0uMi40LS4y'
    b'IDEtLjYgMWgtLjV2MXMtLjIgMC0uMi4yYy0uMS40LjIuMi40LjJoMWwuNS0uMWMuMiAwIC40'
    b'IDAgLjUtLjJhMi4yIDIuMiAwIDAgMCAuMi0uNHYtLjRjMC0uMi4zLS4xLjMtLjQuMS0uNy0u'
    b'Ni0uMi0uNS0uOSIvPgogICAgPC9nPgogICAgPGcgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lk'
    b'dGg9Ii41Ij4KICAgICAgPHBhdGggZD0iTTU1MC44IDI3Ny45YzAgLjktLjYgMS42LTEuNCAx'
    b'LjYtLjcgMC0xLjQtLjctMS40LTEuNiAwLS45LjctMS42IDEuNC0xLjYuOCAwIDEuNC43IDEu'
    b'NCAxLjZ6bS00LjUtMmMwIC45LS42IDEuNi0xLjQgMS42cy0xLjQtLjctMS40LTEuNmMwLTEg'
    b'LjctMS42IDEuNC0xLjZzMS40LjcgMS40IDEuNnoiLz4KICAgICAgPHBhdGggZD0iTTU0OC43'
    b'IDI3Ni41YzAgMS0uNiAxLjYtMS40IDEuNi0uOCAwLTEuNC0uNy0xLjQtMS42IDAtLjkuNi0x'
    b'LjYgMS40LTEuNi44IDAgMS40LjcgMS40IDEuNnoiLz4KICAgICAgPHBhdGggZD0iTTU0Ni40'
    b'IDI3OGMwIC45LS42IDEuNi0xLjQgMS42LS44IDAtMS40LS43LTEuNC0xLjYgMC0uOS42LTEu'
    b'NiAxLjQtMS42LjggMCAxLjQuNyAxLjQgMS42eiIvPgogICAgICA8cGF0aCBkPSJNNTQ4LjUg'
    b'Mjc5LjNjMCAuOC0uNiAxLjYtMS40IDEuNi0uNyAwLTEuNC0uNy0xLjQtMS42IDAtMSAuNy0x'
    b'LjcgMS40LTEuNy44IDAgMS40LjcgMS40IDEuNnoiLz4KICAgIDwvZz4KICAgIDxwYXRoIGZp'
    b'bGw9IiMwMGE2NTEiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTU0OS4y'
    b'IDI2MS41czEzLjktMTkuNCAyOC44LjdjMCAwIC4xIDItMS4zIDQuMmwtLjMtMS43LTEgLjMt'
    b'LjItMS0xLjYtLjEuNS0yLjItMS43IDEuNC4yLTEuNS0yIDIgLjMtNC4zLTIuMiAzLjcuMy0y'
    b'LjUtLjggMS4xLS40LTEuNS0uNyAxLjUtMS0uN3YxbC0xLjgtMS41LS42IDItLjktMi4yLS4y'
    b'IDEuNS0uOS0xLjctLjEgMS45LTIuOS0xLjMuNiAxLjgtMS4zLTEgLjIgMS0xLjktLjQuMiAx'
    b'LjEtMi0uNC4zIDEtMi43LS4zIDEgMS0uMy42czE1LTUgMTYgMTMuOGwtMi43IDEuMy44LTEu'
    b'NS0uOC0uNS0yLjMtMS43LjctMi40LS44LjMtLjEtMS40LS40LjItLjktMS4zLS4yLjUtLjYt'
    b'MS43LS43IDEuMi0uMy0yLjgtMSAxLjgtLjItMS0uMy42LTEuMy0xLjUtLjQgMS0uNS0uOC0u'
    b'MyAxLTEuNC0xLjR2MWwtMS0uNy0uMy41LTIuMS0xLjEtLjEgMS0xLjItMS0uMyAxczEzLjYg'
    b'Ny44IDkuNCAyMC40bC0uOCAxLjYtLjItNC4yLTEuMyAyLjIuOS00LjktLjkgMS0uMS0yLTEu'
    b'MSAyLS40LTIuMi0uNS42LS44LTMuMi0uNiAxLjMtMS0zLjYtLjggMS41LS41LTMuMS0uNSAx'
    b'LjktMS41LTIuOC0uMiAxLjEtLjktMi4yLS41LjdzLTIuNS0uMS0zLjMtLjdjLS43LS43LTIu'
    b'OCAzLjctMi44IDMuN2wuMi0yLjYtLjkgMS44di0xLjhsLTEuNiA1LjMtLjQtMy44LS44IDMu'
    b'My0uNC0xLS4zIDEuMy0uNS0uNS0uNCAxLjUtLjgtLjZ2MmwtLjgtMS0uNiAzLS40LTEuMnYx'
    b'LjNsLS42LS43LS42IDMtMS0xLjN2Mi4ybC4zIDEuNi0xLS41LjQgMi42cy0zLjktNy4yLjgt'
    b'MTQuMmM0LjYtNyAxMC45LTkgMTAuOS05bC0uNy0uNnYtLjZsLTMuOCAxLjl2LTEuMWwtMSAu'
    b'OC0uMi0xLjItLjYgMS4xLS4xLS41LTEgMS40LS40LTItLjYgMi40LS42LTEuNy0xLjMgMy41'
    b'VjI3MGwtMSAyLjgtLjQtMy0uNyAzLjR2LTNsLTEuMiAzLS43LTMtLjUgMy0uOC0yLjMtLjcg'
    b'My40LTEuMi0zLS42IDQuNS0uNy0xLjgtLjIgMy4zLS44LTIgLjggNC4yLTEtMS42LjMgMi42'
    b'LTEuNi0yLjl2My40bC0uOC0xLjEtLjQgMS4zcy0uMy0xMyA4LjYtMTUuNmM4LjktMi41IDE0'
    b'LjYuOCAxNC42LjhsLTMuNC0yLjguNC0uOWgtMS4ybC41LTEtMi43LjEuOC0xLTIgLjN2LS42'
    b'bC0xLjMgMSAuNS0xLjItMS43IDEuMi0uMS0xLjctMSAxLjQtLjQtMS41LTQgNCAxLTQuMS0u'
    b'Ny45LS4xLTEtMS4xIDEuOC0uMy0xLjItLjUgMS41LS40LTEuOC0uOCAxLjgtMS0xLjYtLjMg'
    b'Mi4xLS42LTEuMS0uOCAxLjYtMS0xdjFsLTItLjkuNCAxLjUtMS41LTEuMi0uNCAyLS44LTEt'
    b'LjcgMi41LS42LTIuNC0uNiAxLjlzNy44LTIwLjIgMjcuNi03YzAgMCAyLjIgMi4xIDIuNyAz'
    b'LjZzLjEuMi4xLjJsLS40LTEzLjkuOCA2IC41LTItLjEgMyAyLTQuM3MtMi40IDcuMi0xLjUg'
    b'OS45YzAgMCAuOS04LjQgMy45LTkuNGwtMi44IDYgLjktLjEtLjYgMS4yaC43bC0uOSAyLS41'
    b'IDEgLjUgMSAuOC0uN3oiLz4KICAgIDxwYXRoIGQ9Im01NDcuMSAyNjkuNi40LjRzMS4zLTEu'
    b'NCAzLjQuNGwuMy0uNGMtMi41LTIuMS00LS40LTQtLjR6bS0uNi02Ljh2LjVsLjktLjQtLjcg'
    b'MS4yIDEuNS0uNS0xLjggMi4zLjQuMyAyLjktMy43LTEuOC42LjgtMS4zLTEuNi42LjMtMS45'
    b'aC0uNWwtLjQgMi4zeiIvPgogICAgPHBhdGggZD0ibTU0My45IDI2MyAuNiAxLjMtMS0uNCAy'
    b'LjkgNS4yLjQtLjUtLjYgMS41LjUuMiAxLjItMy4yLS40LS4zLTEgMS4zLTEuOC0zLjEuOC4z'
    b'LS44LTEuNyAxLjEuNnYtMS45aC0uNXYxbC0xLjgtMS4xLjQuOHptLTEuOSA2LjQuMi41Yy44'
    b'LS4zIDEuNS0uNCAyLS4yLjUuMy43LjkuNyAxbC41LS4ycy0uMi0uOS0xLTEuMmMtLjYtLjMt'
    b'MS40LS4zLTIuNC4xem0yLjMgNS40LS41LTIuOGguNmwuNCAyLjd6bTMuOC0uNC0uNy0yLjIu'
    b'NS0uMS43IDJ6bTEuNCAxLjUtLjUtMi4xLjUtLjEuNiAyLjF6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjMDBhNjUxIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00NDIuNiAz'
    b'NDAuMnMtMi40LTEtMy41LS4yYy0xIC43LS45IDEuOS0xLjggMS44IDAgMCAzLjYuOCA0LjMt'
    b'LjFsMS0xLjJtLjQuN3MtMS42IDItMSAzLjNjLjUgMS4yIDEuNyAxLjMgMS40IDIuMiAwIDAg'
    b'MS41LTMuMy44LTQuM3MtMS0xLjEtMS0xLjFtLTIuOC01LjhzLTIuNS44LTIuOCAyYy0uMiAx'
    b'LjQuNiAyLjEtLjEgMi43IDAgMCAzLjItMS44IDMuMS0zdi0xLjVtMS4yLjdzMS4yLTIuMy41'
    b'LTMuNGMtLjgtMS4yLTItMS0xLjgtMiAwIDAtMSAzLjUgMCA0LjRsMS4xIDFtLTIuMi0uOXMw'
    b'LTIuNi0xLTMuMmMtMS4yLS43LTIuMi0uMS0yLjUtMSAwIDAgLjcgMy42IDEuOCA0bDEuNS4z'
    b'bTQuNCA0LjJzMi43LTEgMyAyYy4yIDMtLjIgMi0uMiAycy0xLjQtMy4yLTMtMy43bC4yLS4z'
    b'eiIvPgogICAgPHBhdGggZD0ibTQ0MyAzNDEuMy4yIDIuMmguNGwtLjMtMi4yIDEtNC45aC0u'
    b'NGwtMSA0Ljl6Ii8+CiAgICA8cGF0aCBkPSJtNDQwLjUgMzQwLjYtLjEuM2MxLjMuNSAzLTEg'
    b'My4xLTFsLS4yLS4zcy0xLjcgMS4zLTIuOCAxem0zLjQtMi45LTYtMyAuMi0uNSA2IDN6Ii8+'
    b'CiAgICA8cGF0aCBkPSJtNDM5LjUgMzM3LS40LS40IDEuMi0xLjIuNC40em0yLjEtLjYtMS4z'
    b'LTIuOC41LS4yIDEuMyAyLjh6bTEuOCAzLjR2LjZjMS43LS4xIDIgMSAyIDFsLjYtLjJjMC0u'
    b'My0uNy0xLjUtMi42LTEuNHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIuNyIgZD0iTTQ3MS4yIDM0MWMyLTEgMi40LTUgMi40LTUtLjUg'
    b'MS40LTQuMiAyLjktNC4yIDIuOSAyLjctMS43IDYtOS40IDYtOS40LS44IDIuNy04IDUtMTIu'
    b'NiA3LjYtNC42IDIuNi0yLjIgMTAtMi4yIDEwLTEuMy0uOS0zLjgtNC44LTQuMy04LjMtLjUt'
    b'My41LTEuOC00LjktNS01LjMtMy4xLS40LTUgMy4yLTUgMy4ybC00LjcgMi40IDQuOC4yczMu'
    b'NCAxLjEgMy40IDMuOGMwIDIuNi0zIDEzLjMgMiAxOS4zIDMuMyA0LjEgMTYgNi41IDE2IDYu'
    b'NSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'Ii43IiBkPSJNNDYxLjkgMzQ5LjNzMS00LjggNC4xLTQuNmMzLjEuMiA0LTMuNiA1LjktNC4x'
    b'IDEuOS0uNiAxMS41LTMuMiAxMi41LTcuOCAwIDAtLjkgNy42LTkuNyAxMS40IDAgMCA3LjEt'
    b'Mi4zIDgtMy45IDAgMC0zLjIgNi44LTEwLjkgNy45IDAgMCA3LjItLjYgOC4yLTIuNSAwIDAt'
    b'My4yIDQuMi04LjUgNC44IDAgMCA1IDIgNi4yLjMgMCAwLTIuNyAzLjItNiAzLjRsMSAuMnMt'
    b'My4yIDMuOC02LjcgMS4zLTMuNi42LTMuNi42Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Ik00NjkgMzU2LjVzNC4xIDYuOCA0'
    b'LjUgMTAuNGMwIDAgNy44IDguNSAxMC43IDkgMCAwLTEuNC42LTQtMS41IDAgMCAyLjIgMi4y'
    b'IDIuNiAyLjMuNCAwLTEuNy0uMi0yLS44YTYgNiAwIDAgMCAxLjQgMS41bC0uNS0uMnMtMS0u'
    b'MS0xLjYtLjVjLS41LS40LS4xIDEtLjEgMXMtMS4yLS4zLTEuNi0uN2MtLjQtLjQuMS45LjEu'
    b'OWwtMS0uMy0uOC41czAgLjUtLjUgMGMtLjUtLjMtMS40IDAtMS40IDBzLS42LjYtMSAuMmMt'
    b'LjMtLjQtMS41IDEuNi0xLjUgMS42bC01LTEyLjMiLz4KICAgIDxwYXRoIGQ9Im00NzMuOSAz'
    b'NzguNy02LjQtMTIuMi42LS40IDYuNCAxMi4zem01LjYtLjgtMTEtMTIuMy42LS41IDExIDEy'
    b'LjN6bTIuNS0xTDQ2OS41IDM2NWwuNS0uNSAxMi41IDExLjd6Ii8+CiAgICA8ZyB0cmFuc2Zv'
    b'cm09InRyYW5zbGF0ZSgtOTYuOSA5Ny41KSBzY2FsZSguNjY0ODYpIj4KICAgICAgPHBhdGgg'
    b'ZD0iTTgyMy40IDM2MC44cy0xLjItMi4yLTIuMy0xLjNjLTEgLjgtMS42IDEtMS44LjkgMCAw'
    b'IDEgMCAxLjctLjUuNi0uNiAxLjYtLjMgMi40IDF6bS02LjYtMSAuNyAxLjQtLjggMi4zLjYu'
    b'Mi43LTIuNS0uNy0xLjYtLjUuMnoiLz4KICAgICAgPHBhdGggZD0iTTgyMy4yIDM2MC41cy0x'
    b'IDEtMi4yLjhsLTEuMy0uM2gxLjhjLjcgMCAxLjYtLjMgMS43LS41eiIvPgogICAgICA8cGF0'
    b'aCBkPSJNODIyLjkgMzYwLjdzLTEuMi0xLjItMi0uOGMwIDAgMS40LS41IDIuMi43bC0uMi4x'
    b'eiIvPgogICAgICA8cGF0aCBkPSJNODIyLjcgMzYwLjVzLTEuMy45LTIuNyAwbC0uMS0uMmgu'
    b'MnMxLjcuNyAyLjYuMnoiLz4KICAgICAgPGNpcmNsZSBjeD0iODIxLjYiIGN5PSIzNjAuMyIg'
    b'cj0iLjQiLz4KICAgIDwvZz4KICAgIDxwYXRoIGQ9Ik00NTAgMzU5LjZzLS43IDEuMi0uMyAy'
    b'Yy4zLjcgMiAxIDIuMSAyIC4yIDEgLjggMSAxLjUgMWwuOS0uM3MtMy4xLTEuNi00LTQuM2wt'
    b'LjItLjR6Ii8+CiAgICA8ZyBmaWxsPSIjOTY0YjM2IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iLjUiPgogICAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNNTQ5LjQgMzM0'
    b'LjhzNS42LTcuNCAxMC42LTUuNWM1IDIgOC4xIDMgOC4xIDNzLjEgNC45LTIuNSA0LjktNS4y'
    b'LTUtNy42LTMuNWExMyAxMyAwIDAgMC00LjUgNC4yYy0uMS43LTYuMy44LTQuMS0zLjF6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik01MjguMiAzNzAuNHMtMS42IDEuNi0uOSAyYy43LjQgMi4xIDAg'
    b'Mi4xLS42cy0xLTEuNi0xLjItMS40eiIvPgogICAgICA8cGF0aCBkPSJNNTI3IDM3MnMtMy0x'
    b'LjctNS4yIDIuMmMtMi4zIDMuOC00LjEgMTAuMS01LjQgMTEtMS4zLjggMTIuOC02LjIgMTMt'
    b'OS4yIDAgMCAuOS0zLjgtLjYtMy43LTEuNSAwLTEuNi4yLTEuOS0uNHoiLz4KICAgICAgPHBh'
    b'dGggc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTUyNy4zIDM3Mi40cy0zIC43LTMuNiA0LjljLS42'
    b'IDQuMi00LjcgNi4zLTUgNi41bTQ5LjQtNTEuNnMtNC40IDEuNi0zLjcgNC43Ii8+CiAgICA8'
    b'L2c+CiAgICA8cGF0aCBmaWxsPSIjZmZmMjAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iLjMiIGQ9Ik01MzMuNyAzNDEuM3MuMi0xMC42IDguOS0xMC4yYzEuNi4yLjggMi4xLjgg'
    b'Mi4xczItMS4zIDIuOC44YzAgMCAyLjctMS4yIDMgMS41IDAgMCAzLS40IDIuNiAyIDAgMCAy'
    b'LS41IDIgMS4yIDAgMCAyLjMtLjkgMiAxLjUgMCAwIDIuNi0xLjcgMi4zIDEuNCAwIDAgMi42'
    b'LTEuOSAzLjUgMS4yIDEgMy4yLTIuNiA5LjgtNi4xIDExLjUiLz4KICAgIDxwYXRoIGQ9Ik01'
    b'NTcuOSAzNDJzMS4xIDguMi0zLjUgMTEuM2wuMS4yYzQuOS0zIDMuNy0xMS41IDMuNy0xMS42'
    b'aC0uM3ptLTUuNyA5IC4yLjJjMy0yLjkgMy43LTEwLjYgMy43LTExaC0uM3MtLjcgOC0zLjYg'
    b'MTAuOHptLTIuNy0xLjloLjNhMjYgMjYgMCAwIDEgNC4xLTEwLjNsLS4yLS4xcy0zLjggNS41'
    b'LTQuMiAxMC40em0tMi4yLTEuNGguM2MuNS01LjcgNC40LTEwIDQuNC0xMC4xbC0uMi0uMnMt'
    b'NCA0LjUtNC41IDEwLjN6bS0zLTJoLjNjLjMtNi43IDQuOC0xMCA0LjgtMTBsLS4yLS4zcy00'
    b'LjYgMy40LTUgMTAuNHptLTIuOC0xLjZoLjNjLS4yLTYuMiA0LjUtMTAgNC42LTEwbC0uMi0u'
    b'MnMtNSAzLjgtNC43IDEwLjJ6bS01LTIuM2guM2ExMC4yIDEwLjIgMCAwIDEgNi44LTguNHYt'
    b'LjNhMTAuNSAxMC41IDAgMCAwLTcuMSA4Ljd6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDBhNjUx'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik01MjguNiAzNTQuMnMtMS41'
    b'LTkuOSA0LjQtMTNjMCAwIDEuMS0uMiAxLjcgMS4yIDAgMCAzLjEtMS4zIDMuMiAxLjMgMCAw'
    b'IDEuNi0xLjIgMiAuNSAwIDAgMy4zLS43IDIuNyAxLjggMCAwIDIuOC0uOCAyLjUgMS42IDAg'
    b'MCAyLjgtMSAyLjQgMSAwIDAgMy0uNiAyLjIgMS44IDAgMCAzLjctLjQgMi42IDIuMSAwIDAg'
    b'Mi43LS43IDIgMS40IDAgMCAzLjYuNyAyIDNhMjQuMSAyNC4xIDAgMCAxLTkuOCA3Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjMDBhNjUxIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMi'
    b'IGQ9Ik01MjUuNCAzNjQuMXMtMi40LTguMiAyLjItMTAuM2MwIDAgLjktLjIgMSAuNiAwIDAg'
    b'MS0xLjMgMS44LS4xIDAgMCAyLjMtMS4xIDIuOS42IDAgMCAxLjUtMS4zIDIuMy42IDAgMCAx'
    b'LjUtLjYgMS41IDEgMCAwIDItMSAyIDEgMCAwIDItLjggMS41IDEuMiAwIDAgMyAuNSAyLjEg'
    b'MS45IDAgMCAyLjcuNyAxLjcgMS44IDAgMCAyLjgtLjMgMS4zIDEuNiAwIDAgMi4yLS43IDEg'
    b'MS43LTEuMyAyLjQtNS4yIDUtOCA1LjQiLz4KICAgIDxwYXRoIGZpbGw9IiMwMGE2NTEiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTUyOC4zIDM3MC42cy01LjEtNS0y'
    b'LjctNi40YzAgMCAxIC4zIDEuNSAxLjQgMCAwIDEuMi0xLjggMiAwIDAgMCAxLjgtLjYgMS44'
    b'LjdsMS40IDFzMS43LS4xIDEuNCAxYzAgMCAxLjktLjMgMS44LjcgMCAwIDEuNi4xIDEuNSAx'
    b'LjIgMCAwIDIuOC41IDEuNSAxLjkgMCAwLTQuOCAxLTguMy0uNCAwIDAtMS43LS42LTEuOS0x'
    b'LjF6Ii8+CiAgICA8cGF0aCBkPSJNNTQ1LjkgMzYyLjR2LjNhMzYgMzYgMCAwIDAgOC42LTgu'
    b'N2wtLjMtLjJjMCAuMS01LjQgNy41LTguMyA4LjZ6bS0xLjgtMS4zLjIuM2MyLjYtMS41IDcu'
    b'OS04LjUgOC04LjhsLS4xLS4yYy0uMS4xLTUuNSA3LjItOCA4Ljd6bS0xLjUtLjYuMi4yYTQ4'
    b'IDQ4IDAgMCAwIDctMTAuM2wtLjItLjFzLTQuMiA3LjktNyAxMC4yem0tMS4zLTEuOGguM2Mu'
    b'NS0zLjggNi05LjkgNi0xMGwtLjMtLjFjLS4yLjItNS41IDYuMi02IDEwLjF6bS0xMC45LTQu'
    b'N2guM2MtLjQtNS41IDQuMS0xMS41IDQuMi0xMS41bC0uMy0uMnMtNC43IDYuMi00LjIgMTEu'
    b'N3ptMi45LjVoLjNjLS44LTQuNCA0LjQtMTAuNiA0LjQtMTAuN2wtLjItLjJjLS4yLjMtNS4z'
    b'IDYuNC00LjUgMTAuOXptNC40IDEuNmguM2MtLjItNSA0LjYtMTAgNC43LTEwbC0uMi0uM2Mw'
    b'IC4xLTUgNS4yLTQuOCAxMC4zem0tMTAuNSA5aC4zYy0xLjgtNC43IDEuMi0xMC42IDEuMy0x'
    b'MC42bC0uMy0uMnMtMy4xIDYuMS0xLjMgMTAuOXptMiAuNC4zLS4xYy0xLjYtNC43IDEtMTEg'
    b'MS0xMWwtLjItLjJzLTIuNyA2LjUtMS4xIDExLjN6bTguMyA0Ljd2LjJjNS0xLjcgOC4zLTYu'
    b'MyA4LjMtNi4zbC0uMy0uMnMtMy4yIDQuNS04IDYuM3ptLTEtMS4xdi4zYzQtMS44IDcuNy02'
    b'LjggNy43LTYuOGwtLjItLjJzLTMuNyA1LTcuNSA2Ljd6bS0xLS40LjIuM2MzLTIuMyA3LTgg'
    b'Ny04bC0uMi0uMnMtNCA1LjctNyA3Ljl6bS01LTIuOWguNGEyMSAyMSAwIDAgMSAyLjUtMTAu'
    b'OWwtLjMtLjFzLTMuMiA2LTIuNSAxMXptMi4yIDEuNC4yLjJjMy4yLTIuOSA0LjMtMTAuNiA0'
    b'LjMtMTFoLS4zcy0xIDgtNC4yIDEwLjh6bTIuMi44LjIuM2ExNyAxNyAwIDAgMCA1LjctOS41'
    b'aC0uM3MtMS4yIDYtNS42IDkuM3ptLjUtMTMuNHYuOWwtMy40IDExIC4zLjEgMy40LTExYy0u'
    b'NS01LjQgNC4yLTExLjMgNC4zLTExLjNsLS4zLS4ycy00LjMgNS4zLTQuMyAxMC41eiIvPgog'
    b'ICAgPHBhdGggZD0iTTUzOSAzNTcuM2MwIC4yLTEuMSA3LjctNS4yIDEwLjVsLjIuM2M0LjIt'
    b'Mi45IDUuMi0xMC4zIDUuMi0xMC43IDEuOC0yLjEgNi05LjcgNi05LjdsLS4yLS4ycy00LjIg'
    b'Ny42LTYgOS44em0tMTIgOC4zYzAgLjEuNiA0IDEuNCA1LjJsLjMtLjFjLS44LTEuMy0xLjUt'
    b'NS4xLTEuNS01LjJsLS4zLjF6bTEuOSAwLS4xIDUuM2guM3YtNS4zaC0uMnoiLz4KICAgIDxw'
    b'YXRoIGQ9Im01MjkgMzcxIC4zLjFjMS4zLTIuOCAxLjctNC44IDEuNy00LjhoLS4zcy0uNCAx'
    b'LjktMS43IDQuN3ptLjMuMS4yLjNhNi42IDYuNiAwIDAgMCAzLTRoLS4zcy0uNiAyLjQtMi45'
    b'IDMuN3ptLjUuMnYuM2MyLjQtLjIgNC0zLjEgNC0zLjNoLS4ycy0xLjYgMi44LTMuOCAzeiIv'
    b'PgogICAgPHBhdGggZD0iTTUzMCAzNzEuNXYuM2MzLjktLjMgNS42LTIuNiA1LjYtMi43bC0u'
    b'Mi0uMXMtMS43IDIuMi01LjQgMi41eiIvPgogICAgPHBhdGggZD0iTTUzMC4zIDM3MS41di4z'
    b'Yy4xIDAgNSAxLjEgNi43LTEuNGwtLjMtLjJjLTEuNSAyLjQtNi40IDEuNC02LjQgMS4zeiIv'
    b'PgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIu'
    b'OCIgZD0iTTQyMC45IDE5My4ydjEzNi40YzAgNDQuNiA4MC42IDcxIDgwLjYgNzFzODAuNS0y'
    b'Ni40IDgwLjUtNzFWMTkzLjJ6Ii8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9'
    b'Ik0wIDBoMzIwdjI0MEgweiIvPgogIDxwYXRoIGZpbGw9IiNGRkYiIGQ9Im0zNy41IDAgMTIy'
    b'IDkwLjVMMjgxIDBoMzl2MzFsLTEyMCA4OS41IDEyMCA4OVYyNDBoLTQwbC0xMjAtODkuNUw0'
    b'MC41IDI0MEgwdi0zMGwxMTkuNS04OUwwIDMyVjB6Ii8+CiAgPHBhdGggZmlsbD0iI0M4MTAy'
    b'RSIgZD0iTTIxMiAxNDAuNSAzMjAgMjIwdjIwbC0xMzUuNS05OS41em0tOTIgMTAgMyAxNy41'
    b'LTk2IDcySDB6TTMyMCAwdjEuNWwtMTI0LjUgOTQgMS0yMkwyOTUgMHpNMCAwbDExOS41IDg4'
    b'aC0zMEwwIDIxeiIvPgogIDxwYXRoIGZpbGw9IiNGRkYiIGQ9Ik0xMjAuNSAwdjI0MGg4MFYw'
    b'ek0wIDgwdjgwaDMyMFY4MHoiLz4KICA8cGF0aCBmaWxsPSIjQzgxMDJFIiBkPSJNMCA5Ni41'
    b'djQ4aDMyMHYtNDh6TTEzNi41IDB2MjQwaDQ4VjB6Ii8+Cjwvc3ZnPgo=', 'FJ')

FJ = b64_FJ
index.append("FJ")
index.append("FJI")
index.append("Fiji")
catalog["FJ"] = FJ
catalog["FJI"] = FJ
catalog["Fiji"] = FJ
country["Fiji"] = ('FJ', 'FJI', 0)
lookup["FJ"] = ('FJ', 'FJI', 'Fiji', 0)
lookup["Suva Fiji"] = ('FJ', 'FJI', 'Fiji', 0)
lookup["FJI"] = ('FJ', 'FJI', 'Fiji', 0)
lookup["Fiji"] = ('FJ', 'FJI', 'Fiji', 0)
details["FJ"] = {"continent":"Oceania","capital":"Suva","currency":"Fiji Dollar","web":".fj","lang":"en-FJ | fj","tz":"+12:00","altname":""}
#----------------------------------------------------------------------
b64_FK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1mayIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGxpbmVhckdyYWRpZW50IHhsaW5rOmhy'
    b'ZWY9IiNmay1hIiBpZD0iZmstYyIgeDE9IjQ0NC40IiB4Mj0iNDcwLjkiIHkxPSI1OTIuMiIg'
    b'eTI9IjU3Ny4xIiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KC0xLjA4NDQ4IDAgMCAxLjI2'
    b'Njc0IDkwOS41IC00MTQuNykiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIi8+CiAg'
    b'ICA8bGluZWFyR3JhZGllbnQgeGxpbms6aHJlZj0iI2ZrLWEiIGlkPSJmay1nIiB4MT0iODUx'
    b'LjgiIHgyPSI2NDYuMiIgeTE9IjM2OS45IiB5Mj0iMzY5LjkiIGdyYWRpZW50VHJhbnNmb3Jt'
    b'PSJtYXRyaXgoLjg1NzMzIDAgMCAuOTYyNCAtMTYxLjUgLjMpIiBncmFkaWVudFVuaXRzPSJ1'
    b'c2VyU3BhY2VPblVzZSIvPgogICAgPGxpbmVhckdyYWRpZW50IHhsaW5rOmhyZWY9IiNmay1h'
    b'IiBpZD0iZmstZCIgeDE9IjQ1OC4yIiB4Mj0iNTIwLjUiIHkxPSI1NjIuNSIgeTI9IjU1Mi44'
    b'IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KC0xLjAxOTQxIDAgMCAxLjM1NTQgOTA5LjUg'
    b'LTQxNC43KSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5lYXJH'
    b'cmFkaWVudCB4bGluazpocmVmPSIjZmstYSIgaWQ9ImZrLWUiIHgxPSI0NzIuNCIgeDI9IjQ0'
    b'NS4zIiB5MT0iNTc4LjciIHkyPSI1ODAuMiIgZ3JhZGllbnRUcmFuc2Zvcm09Im1hdHJpeCgx'
    b'LjA4NDQ4IDAgMCAxLjI2Njc0IDQ5LjcgLTQxNC43KSIgZ3JhZGllbnRVbml0cz0idXNlclNw'
    b'YWNlT25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVudCB4bGluazpocmVmPSIjZmstYSIgaWQ9'
    b'ImZrLWYiIHgxPSI1MTgiIHgyPSI0NTYuNCIgeTE9IjU1My43IiB5Mj0iNTU4LjEiIGdyYWRp'
    b'ZW50VHJhbnNmb3JtPSJtYXRyaXgoMS4wMTk0MSAwIDAgMS4zNTU0IDQ5LjcgLTQxNC43KSIg'
    b'Z3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVudCBp'
    b'ZD0iZmstYSI+CiAgICAgIDxzdG9wIG9mZnNldD0iMCIgc3RvcC1jb2xvcj0iI2E0MzkwNyIv'
    b'PgogICAgICA8c3RvcCBvZmZzZXQ9IjEiIHN0b3AtY29sb3I9IiNmZmYiLz4KICAgIDwvbGlu'
    b'ZWFyR3JhZGllbnQ+CiAgICA8bGluZWFyR3JhZGllbnQgeGxpbms6aHJlZj0iI2ZrLWEiIGlk'
    b'PSJmay1oIiB4MT0iMzg4LjUiIHgyPSI2NzcuNCIgeTE9IjUwNy4yIiB5Mj0iNTA4LjgiIGdy'
    b'YWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoLjg4OTI3IDAgMCAxLjU0NTQyIDUwLjQgLTQxMy42'
    b'KSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVu'
    b'dCB4bGluazpocmVmPSIjZmstYSIgaWQ9ImZrLWkiIHgxPSI1NzkuOCIgeDI9IjU1Ni44IiB5'
    b'MT0iNTA0LjkiIHkyPSI1MDUuOSIgZ3JhZGllbnRUcmFuc2Zvcm09Im1hdHJpeCguOTEwOTYg'
    b'MCAwIDEuNTIwMDggNDkuNyAtNDE0LjcpIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVz'
    b'ZSIvPgogICAgPGxpbmVhckdyYWRpZW50IHhsaW5rOmhyZWY9IiNmay1hIiBpZD0iZmstaiIg'
    b'eDE9IjU4MS40IiB4Mj0iNTU4LjkiIHkxPSI1MTIiIHkyPSI1MTQuMyIgZ3JhZGllbnRUcmFu'
    b'c2Zvcm09Im1hdHJpeCgtLjg4OTI3IDAgMCAxLjU0NTQyIDkwOC44IC00MTMuNikiIGdyYWRp'
    b'ZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIi8+CiAgICA8bGluZWFyR3JhZGllbnQgeGxpbms6'
    b'aHJlZj0iI2ZrLWEiIGlkPSJmay1rIiB4MT0iNTUyIiB4Mj0iNTg5LjgiIHkxPSI1MTcuOSIg'
    b'eTI9IjUwMy45IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KC0uOTEwOTYgMCAwIDEuNTIw'
    b'MDggOTA5LjUgLTQxNC43KSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAg'
    b'IDxsaW5lYXJHcmFkaWVudCB4bGluazpocmVmPSIjZmstYSIgaWQ9ImZrLWIiIHgxPSI0NDQu'
    b'NCIgeDI9IjQ3MC45IiB5MT0iNTkyLjIiIHkyPSI1NzcuMSIgZ3JhZGllbnRUcmFuc2Zvcm09'
    b'Im1hdHJpeCguODU3MzMgMCAwIC45NjI0IC0xNjIuNCAtLjYpIiBncmFkaWVudFVuaXRzPSJ1'
    b'c2VyU3BhY2VPblVzZSIvPgogIDwvZGVmcz4KICA8cGF0aCBmaWxsPSIjMDEyMTY5IiBkPSJN'
    b'MCAwaDY0MHY0ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjMDEyMTY5IiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIGQ9Ik0wIDBoNDAwdjIwMEgweiIvPgogIDxwYXRoIGZpbGw9InVybCgjZmstYiki'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjZmZmIiBzdHJva2Utd2lkdGg9IjEwIiBk'
    b'PSJNNDEyLjkgMzA4LjlhMTEuMyAxMi43IDAgMCAwLTEuNyAwYy0zIC42LTcuNiAxMS4zLTEw'
    b'IDE3LjYtNC4xIDUuNC02LjIgOS42LTcuOCAxMi43LS43IDEuMi0xLjcgMi42LTEuNCA0LjIt'
    b'NiAxLjYtNi4zIDcuNC02LjMgOS42IDAgMi41LjcgMy43LjcgMy43bDMuNiA3LjV2LjFjMy44'
    b'IDkgOS40IDIwLjkgMTIuNyAyMS44IDQuNCAxLjUgMTYtMy4zIDI0LjgtMTEuN2ExNDAuNiAx'
    b'NTcuOCAwIDAgMCA1My4yIDEyLjFjMjAuNCAwIDM4LjctNS41IDUzLTEyLjEgOC44IDguNCAy'
    b'MC40IDEzLjIgMjUgMTEuNyAzLTEgOC43LTEzIDEyLjYtMjEuOGwzLjUtNy42cy43LTEuMi43'
    b'LTMuNmMwLTIuMi0uMy04LTYuMy05LjYuMy0xLjYtLjYtMy0xLjMtNC4zLTEuNy0zLjItMy44'
    b'LTcuNC03LjctMTMtMi42LTYuMi03LjItMTYuNy0xMC0xNy4yLTQuMi0uOC0xMyAxLjUtMTMg'
    b'Mi40di40bC0xNy43IDE4LjZjMCAuNS45IDE0IDQuMyAyNmExMjYgMTQxLjUgMCAwIDEtNDMu'
    b'MyA4LjJjLTE3IDAtMzEuNS0zLjQtNDMuMi04LjNhMTE2LjYgMTMwLjkgMCAwIDAgNC4zLTI2'
    b'TDQyNCAzMTEuOHYtLjRjMC0uNy02LjgtMi41LTExLjEtMi41em00LjQgMjNjMi4zIDAgNC42'
    b'IDIuMiA2LjUgNC40bC0uMSAxLjNhNjcuNSA3NS43IDAgMCAxLTIuOCAxMC4yIDczLjYgODIu'
    b'NiAwIDAgMS0xMi4yLTkuOWMxLjktMi4zIDUtNS40IDguMi01LjhoLjR6bTEyNi42IDBoLjRj'
    b'My4zLjYgNi4zIDMuNyA4LjMgNmE3My40IDgyLjQgMCAwIDEtMTIuMyAxMCA2Ny4xIDc1LjQg'
    b'MCAwIDEtMi44LTEwLjMgMTQuNiAxNi40IDAgMCAxLS4yLTEuM2MyLTIuMyA0LjMtNC4zIDYu'
    b'Ni00LjN6bS0xNDIuNCAyNi40YzIuNCAyIDUuNCA0LjQgOS4xIDYuOGExMC41IDExLjggMCAw'
    b'IDEtMy4yIDEuNmMtMS42LjQtMy4xLjMtNC43IDBhMTUgMTYuOCAwIDAgMS0xLTUuNiA2MC4z'
    b'IDY3LjcgMCAwIDEtLjItMi44em0xNTguMiAwLS4xIDIuOGExNSAxNyAwIDAgMS0xIDUuNSAx'
    b'MC4zIDExLjUgMCAwIDEtOC0xLjVjMy43LTIuNCA2LjgtNC44IDkuMS02Ljh6Ii8+CiAgPHBh'
    b'dGggZmlsbD0idXJsKCNmay1jKSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNNDI2LjIgMzM5LjZzLTYuMS0xMS4xLTExLjEtMTAu'
    b'MmMtNS4xLjctMTAgNy44LTEwLjIgOC4yYTQ0LjUgNTIgMCAwIDEtNy41LTkuNWMuMy0uNCA3'
    b'LjgtMjAuOSAxMi0yMS44IDQtLjkgMTIuNyAxLjUgMTIuNyAyLjN6Ii8+CiAgPHBhdGggZmls'
    b'bD0idXJsKCNmay1kKSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iMS4yIiBkPSJNNDM5LjggMzI3LjdjMCAuOC0yLjIgMzAuMi0xMC45IDQwLjQt'
    b'OC42IDEwLjMtMjMgMTYuNi0yOC4yIDE1LjEtNS0xLjYtMTYuNS0zMS4zLTE2LjUtMzEuM3Mx'
    b'Mi4yIDE0LjIgMjEuMyAxMS44YzkuMS0yLjMgMTQuNi0yMC4xIDE2LjMtMjguOSAxLjctOC42'
    b'LjMtMjUuNy4zLTI1LjdsMTcuOCAxOC42eiIvPgogIDxwYXRoIGZpbGw9InVybCgjZmstZSki'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIg'
    b'ZD0iTTUzMi45IDMzOS42czYuMi0xMS4xIDExLjItMTAuMmM1IC43IDkuOCA3LjggMTAuMiA4'
    b'LjJhNDQuNSA1MiAwIDAgMCA3LjUtOS41Yy0uNC0uNC03LjktMjAuOS0xMi0yMS44LTQuMS0u'
    b'OS0xMi44IDEuNS0xMi44IDIuM3oiLz4KICA8cGF0aCBmaWxsPSJ1cmwoI2ZrLWYpIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik01'
    b'MTkuMyAzMjcuN2MwIC44IDIuMiAzMC4yIDEwLjkgNDAuNCA4LjcgMTAuMyAyMyAxNi42IDI4'
    b'LjIgMTUuMSA1LTEuNiAxNi42LTMxLjMgMTYuNi0zMS4zcy0xMi4zIDE0LjItMjEuNCAxMS44'
    b'Yy05LTIuMy0xNC41LTIwLjEtMTYuMi0yOC45LTEuOC04LjYtLjQtMjUuNy0uNC0yNS43bC0x'
    b'Ny44IDE4LjZ6Ii8+CiAgPHBhdGggZmlsbD0idXJsKCNmay1nKSIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNNDAxLjIgMzI2LjJj'
    b'LTQgNS41LTYuMSA5LjgtNy45IDEzLTEuNyAzLjItLjYgNy43IDMuMiAxNCA0LjMgNi43IDM5'
    b'IDMzLjQgODQuMSAzMy40IDQ1LjIgMCA3OS44LTI2LjYgODQtMzMuNCA0LTYuNCA1LTEwLjgg'
    b'My4zLTE0LTEuNy0zLjItMy45LTcuNS03LjktMTMgMCA4LjMtMjguNyAzOC41LTc5LjQgMzgu'
    b'NXMtNzkuNC0zMC4yLTc5LjQtMzguNXoiLz4KICA8cGF0aCBmaWxsPSJ1cmwoI2ZrLWgpIiBm'
    b'aWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9'
    b'Im01NTcuNyAzNzguOCA3LjgtMTUuMS0zLjktMy4yYy0xIDMuOC01LjUgNS4xLTYuMyAxMC0u'
    b'NyA0LjcgMyA5LjQgMi40IDguM3oiLz4KICA8cGF0aCBmaWxsPSJ1cmwoI2ZrLWkpIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik01'
    b'NjQuOCAzNzQuNXMxLjQtNi44LTMtNy42Yy00LjQtLjgtNi44IDMuOC02LjEgMiAuNi0yIDMu'
    b'Mi00IDMuNy0xMC43LjMtNi43LS40LTEwLjMtLjQtMTAuM3MxLjgtOC43IDguOC03LjVjNy4y'
    b'IDEuMyA3LjUgNy42IDcuNSA5LjlhOSA5IDAgMCAxLS42IDMuNXoiLz4KICA8cGF0aCBkPSJt'
    b'NTM5LjIgMzUxLjcgMS41IDIuOCAxLS42LS43LTIgLjEtLjMgMS43LTEuMiA0LjQgOC43di41'
    b'bC0xIC43LjUuOCA0LjItMy0uNC0uOC0xIC42aC0uM2wtNC40LTguOCAxLjYtMS4yaC40bDEg'
    b'MS42IDEtLjctMS41LTIuOC04IDUuN3ptLTEwLjUgNi43LjQuOC45LS40LjMuMSAzLjkgOC45'
    b'LS4xLjQtLjguNi4zLjggNC4xLTIuNS0uMy0uOC0uOS40aC0uNGwtMS44LTQuMyA0LjMtMi40'
    b'IDEuOCA0di41bC0xIC42LjQuOSA0LjItMi41LS40LS44LS45LjQtLjMtLjItMy44LTguOHYt'
    b'LjRsLjgtLjYtLjMtLjgtNC4xIDIuNS4zLjggMS0uNS4zLjIgMS41IDMuNi00LjIgMi41LTEu'
    b'Ni0zLjcuMi0uNC44LS41LS40LS45em0tMi40IDcuNi4yLjggMS4yLS4zLjQuMS45IDMuNy0u'
    b'OC40Yy0yLjUuOC00LjQtLjUtNS4zLTMuNy0uOC0zLjIuMi01LjYgMi41LTYuNGEzLjUgNCAw'
    b'IDAgMSAxLjQtLjFsLjMuMi44IDEuNyAxLjItLjQtLjctM2MtMS4zIDAtMi41LjItMy41LjYt'
    b'My42IDEuMy01LjIgNC41LTQuMyA4LjIgMSAzLjcgMy45IDUuNCA3LjIgNC4zYTExLjMgMTIu'
    b'NyAwIDAgMCAzLjQtMkw1MzAgMzY2bC4yLS40LjktLjQtLjMtLjl6bS05LjcgMTAuMyA0Ljct'
    b'MS43LS4zLS45LTEgLjItLjMtLjEtMi42LTkuNi4xLS4zIDEtLjUtLjItLjgtNC43IDEuNi4z'
    b'LjkgMS0uMy40LjIgMi41IDkuNS0uMi40LTEgLjQuMy45em0tMjUuNSA0LjYgOC4zLS44LS4z'
    b'LTMuNC0xIC4xLS4yIDItLjIuMy0zLjUuNC0uNC00LjkgMi0uMi4zLjMuMiAxLjNoMWwtLjQt'
    b'NC40aC0xdjEuNGwtLjIuNC0yIC4xLS40LTQuNCAzLjEtLjMuMi4yLjQgMS43IDEuMS0uMS0u'
    b'Mi0zLTcuOC44di45aDFsLjMuMy43IDkuOS0uMS4zLTEgLjJ2MXptLTEyLjQtMTIuM3YxaDFs'
    b'LjIuMy4xIDkuOS0uMi4zLS45LjJ2LjhoNC40di0uOWgtMWwtLjItLjRWMzc1aDQuNHY0LjZs'
    b'LS4yLjMtLjkuMXYxaDQuNHYtMWgtMWwtLjEtLjQtLjItMTAgLjItLjNoMXYtMWgtNC41djFs'
    b'MSAuMS4yLjN2NGwtNC4zLjEtLjItNCAuMy0uM2guOXYtMXptLTkuNC0uM3YzLjNoMWwuMy0y'
    b'IC4yLS4zaDEuOXYxMC4ybC0uMy40aC0xdjFoNC42di0uOWwtMS0uMS0uMy0uNC4xLTEwaDEu'
    b'OGwuMy4yLjMgMmgxdi0zLjN6TTQ1NSAzNzguOWw4IC40LjItMy4zaC0xbC0uMyAxLjktLjIu'
    b'Mi0zLjUtLjEuMi01IDEuOS4yLjIuMy4yIDEuNGguOGwuMi00LjNoLS45bC0uMiAxLjItLjIu'
    b'M2gtMmwuMi00LjYgMyAuMi4yLjIuMSAxLjdoMS4xdi0yLjlsLTcuNS0uNHYuOWwxIC4yLjEu'
    b'My0uNCA5LjktLjIuM2gtMXYuOXptLTE4LjYtNS40IDQuNCAxLjYuMi0uOC0xLS41di0uNGwy'
    b'LjUtOS41LjMtLjIgMSAuMy4yLS44LTQuMy0xLjctLjIuOS45LjQuMi40LTIuNyA5LjQtLjIu'
    b'My0xLS4zem0tNy42LTMuM2E4LjQgOS40IDAgMCAwIDIuNiAxLjZjMi40LjggNC4zLS4yIDQu'
    b'OC0yLjJhMyAzLjUgMCAwIDAtLjUtMy4ybC0xLjgtMmMtLjYtLjktLjgtMS42LS42LTIuNS4z'
    b'LS45IDEuMS0xLjQgMi4yLTEgLjQuMi44LjQgMSAuN3YuM2wtLjIgMiAxIC4zLjgtMi44YTgg'
    b'OSAwIDAgMC0yLjUtMS43Yy0yLS44LTMuOC4zLTQuNCAyLjJhMy4yIDMuNSAwIDAgMCAuNCAy'
    b'LjhjLjQgMSAxIDEuNSAxLjUgMiAuOSAxIDEuMiAyIDEgMi45LS4zIDEtMS4yIDEuNS0yLjQg'
    b'MWE0IDQuNSAwIDAgMS0xLjItLjhsLS4xLS4zLjQtMi4yLTEuMS0uNHptLTkuOC00LjYgNy40'
    b'IDQgMS4yLTMtMS0uNS0uOSAxLjctLjMuMS0zLjEtMS44IDEuOC00LjMgMS44IDF2LjNsLS4z'
    b'IDEuMy44LjUgMS42LTQtLjgtLjQtLjcgMS4xLS4zLjItMS43LTEgMS42LTQgMi43IDEuNS4x'
    b'LjMtLjQgMS42IDEgLjUgMS0yLjYtNi44LTMuOS0uNC44LjguNi4xLjQtMy42IDloLS4zbC0u'
    b'OS0uM3ptLTEuMS0xNS0zLjctMi45LS41LjguNy43LjEuNC00LjYgOC4yLS40LjEtLjctLjUt'
    b'LjUuOCAzLjYgMi44YzEuNCAxIDIuNSAxLjUgMy42IDEuNCAxLjYtLjIgMy0xLjIgNC0zIDEu'
    b'OC0zLjQgMS4zLTYuNi0xLjYtOC44em0tMS42IDAgLjguNmMyIDEuNSAyLjIgMy43LjUgNi42'
    b'LTEuNyAzLTMuNSAzLjYtNS40IDJsLS44LS40IDUtOC43em0yOS4zIDEzLS4xLjguOS4zLjEu'
    b'NC0xLjcgOS43LS4zLjJoLTF2LjhsNC4xIDEgLjItLjgtMS0uNC0uMS0uMy43LTQuMWguM2Mx'
    b'LjUuNCAxLjggMS4zIDEuOCAzLjIuMS45LjEgMS43LjggMi43LjMuNC43LjggMS40LjlhMTAu'
    b'MSAxMS40IDAgMCAwIDEuNS4ybC4xLS44aC0uMWMtMS0uMy0xLjUtLjctMS41LTEuOC0uMi0x'
    b'IDAtMi0uNC0zYTIuNiAyLjkgMCAwIDAtMS4zLTEuNGMxLjcgMCAyLjctLjkgMy0yLjUuNC0y'
    b'LS41LTMuNS0yLjktNGwtNC40LTEuMXptMyAxLjcuNi4yYzEuNC40IDIgMS40IDEuNyAyLjkt'
    b'LjMgMS43LTEuMiAyLjMtMi44IDEuOGwtLjUtLjEuOS00Ljh6bTU0LjIgMSAuMSAxaDFsLjMu'
    b'MiAxLjQgOS44LS4yLjMtMSAuMy4yLjggNC41LS44di0xbC0xLjEuMi0uMy0uMy0uNi00aC4z'
    b'YzEuNi0uNSAyLjIuMiAzIDEuOS4zLjguNSAxLjYgMS41IDIuMi40LjMgMSAuNCAxLjguM2Ex'
    b'MiAxMy42IDAgMCAwIDEuNi0uNWwtLjEtLjloLS4yYy0xLjEuMy0xLjcgMC0yLjItLjktLjQt'
    b'LjgtLjctMS44LTEuMy0yLjUtLjQtLjUtMS0uOC0xLjgtLjggMS43LS44IDIuNS0yIDIuMy0z'
    b'LjctLjMtMi0xLjctMy00LjItMi41em0zLjUuNWguN2MxLjYtLjQgMi41LjIgMi44IDEuOC4y'
    b'IDEuNi0uNSAyLjYtMi4yIDNoLS42bC0uOC00Ljh6Ii8+CiAgPHBhdGggZmlsbD0idXJsKCNm'
    b'ay1qKSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0i'
    b'MS4yIiBkPSJtNDAxLjUgMzc4LjgtNy44LTE1LjEgMy45LTMuMmMxIDMuOCA1LjUgNS4xIDYu'
    b'MyAxMCAuNyA0LjctMyA5LjQtMi40IDguM3oiLz4KICA8cGF0aCBmaWxsPSJ1cmwoI2ZrLWsp'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIi'
    b'IGQ9Ik0zOTQuMyAzNzQuNXMtMS40LTYuOCAzLTcuNmM0LjQtLjggNi44IDMuOCA2LjIgMi0u'
    b'Ny0yLTMuMy00LTMuNy0xMC43LS40LTYuNy4zLTEwLjMuMy0xMC4zcy0xLjctOC43LTguOC03'
    b'LjVjLTcuMSAxLjMtNy41IDcuNi03LjUgOS45IDAgMi4yLjcgMy41LjcgMy41eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiMwMDcyYzQiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjZmZmIiBz'
    b'dHJva2Utd2lkdGg9IjMuOSIgZD0iTTQ4MC41IDM1Ni4xcy04Mi0yNy04MS40LTEyOS40bC42'
    b'LTEzNS42SDU2MWwuNiAxMzQuOGMuNSAxMDIuNC04MS40IDEzMC4xLTgxLjQgMTMwLjF6Ii8+'
    b'CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4KICAgIDxwYXRoIGZpbGw9IiNiY2JjYmMiIGQ9'
    b'Im00MTAuMyAxMjMuNiAyLTJjMS4zLS44IDIuNC0xLjcgMy43LTIuNCAxLS42IDMtMS4xIDMu'
    b'Ny0xLjZhOS4yIDEwLjMgMCAwIDAgMy0yLjhjLjItMS43LjUtMyAuNS01YTEyIDEyIDAgMCAx'
    b'IDMuNi0yYzEuNy0uNiAyLTEuNCAzLjgtMS43IDEtLjQgMi44LS40IDQuNC0uNCAxLjYgMCAy'
    b'LjcgMS40IDQuMiAxLjYgMS44LjggMi42IDEuNCA0LjEgMi44YTcuNSA3LjUgMCAwIDAgMi42'
    b'IDNjMS4xLjYgMi4yIDEuNiAzLjQgMiAxLjUuOSAyLjcgMS40IDMuOCAyLjggMSAuOCAxLjQg'
    b'MiAyLjMgMi43YTI2LjUgMjkuNyAwIDAgMCAzLjQgMi44YzEuNSAxLjEgMyAyIDUuMiAxLjcg'
    b'MS4zIDAgMi42LS4zIDQgMCAxLjggMCAzLjQgMCA0LjguNSAxLjggMCAzLjIuMiA0LjguNCAx'
    b'LjUuMiAzIC4zIDQuNy4zIDEuNS41IDMgLjQgNC44LjRoOS41YzEuNyAwIDMuNC4xIDQuNy40'
    b'YTM3LjQgNDIgMCAwIDAgNC43LS40YzEuOSAwIDMuMy0uMyA1LS40aDUuOGMxLjUuNSAzLjQu'
    b'OCA0LjQgMS43IDEuNC40IDIgMS4xIDMuNCAxLjVhMTEgMTEgMCAwIDEgMy40IDIuOCAxOC4x'
    b'IDIwLjMgMCAwIDEgMi43IDQuNGMxIDEuNSAxLjMgMy4zIDIgNS4yLjQgMS44LjcgMy41Ljcg'
    b'NS41LjQgMS43LjMgMy42LjMgNS42LS4zIDEuOC0uNCAzLjgtMSA1LjUgMCAyLS40IDMuNy0u'
    b'NyA1LjItLjIgMS42LS42IDIuNy0uNyA0Ljd2NS42YzAgMS44LS40IDMuMi0uNiA1LjFhNTIg'
    b'NTguNCAwIDAgMC0yLjQgNiAxMC44IDEyIDAgMCAwLTIuNyAzLjJjLS43LjUtMS4xIDEuMy0x'
    b'IDEuNiAxLjQuNSAxIDEuNiAxIDMuNWwuNyA1LjJjLjEgMiAuNSAzIDEgNC40LjYuOC43LjQt'
    b'LjcuNC0xIC44LTIgLjQtMi4zLTEuMmE4LjggOS45IDAgMCAxLTEuNC00LjRjLS4yLTEuOC0u'
    b'NS0zLjYtMS00LjgtLjItMi4yLS43LTIuMi0yLjctMi40LTEtLjktMi4yLTEuMS00LTEuMS0y'
    b'IDAtMi0uMi0yIDJ2NS42Yy0uNCAxLjYtMSAyLjgtMS41IDQuMy0xIC44LTEuNCAyLjItMi43'
    b'IDMuMi0uNSAxLjgtMS40IDItMyAyLjRsLTItMi44YzEtMS44IDEuNy0yIDIuMy00IC44LTEu'
    b'NiAxLjItMi42IDEuNy00LS43LTEuMi0xLjMtMS44LTItMy41YTE5LjMgMjEuNiAwIDAgMS0x'
    b'LjctNC40Yy0xLjEtLjQtMi45LS41LTMuNy0xLjItMS43LS40LTIuMSAxLjctNCAxLjdoLTQu'
    b'OGMtMi4xIDAtMi42IDEuMi00LjQgMS4xLS41LjItMS44IDAtMy43IDAtMS41LjYtMy4yLjQt'
    b'NC44LjQtMS43IDAtMy0uNS00LjQtLjgtMS41LS41LTMtMS00LjctMS4yLTIgMC0yLjcuMi00'
    b'IDEuMi0xIC43LTIuNiAyLjMtMy43IDMuMi0uNSAxLjMtLjggMy41LTEuNSA1LjEtLjMgMS43'
    b'LS45IDIuNi0xLjIgNGExMy41IDE1LjEgMCAwIDAtMSA0LjhjLS4yIDIuNi0uNyAyLjMtMi4x'
    b'IDEuNi0uNi0xLjItMS41LTIuMy0yLTMuNi4yLTIgLjctMyAuNy01LjEtLjQtMS43LTEuMS0x'
    b'LjUtMi0uNSAwIDIuMSAwIDMuNy0uOCA0LjhhNC40IDUgMCAwIDEtMiAzLjEgNC43IDQuNyAw'
    b'IDAgMS0yLjcgMi44Yy0uMiAwIDAtLjUgMC0xLjYtLjgtMS43IDAtMy4zIDAtNS41IDAtMi0u'
    b'Mi0zLjMuNC01LjEgMC0yLS44LTMuOC0xLTUuMi0uNy0xLjUtMS4xLTIuMi0yLjgtMi44LTEu'
    b'Mi0uNi0zLTEuMi0zLjctMi41YTcgNy45IDAgMCAwLTMuMS0yLjdjLTEuNS0uNi0yLjMtMS4y'
    b'LTMuNC0yLTEtMS4zLTEuOS0xLjgtMi4zLTMuNS0uNy0xLjItLjgtMy41LTEuMy01LjJhMTUu'
    b'OSAxNy44IDAgMCAwLTEtNC43IDE3LjggMjAgMCAwIDAtMS00LjhsLTEuMS01LjJjMC0xLjkg'
    b'MC0zLjgtLjQtNS41di01LjZjLS4yLTEuNy0uMy00LS42LTUuMiAwLTIuMS0uMy0zLjMtLjgt'
    b'NC44LS43LTEuNC0uNy0yLTItMi4zLS44IDEuMi0yLjIgMS44LTQgMi0xLjItLjMtMy0uNi00'
    b'LjQtMS4yLTEuNC0uNC0yLjItMS0zLjMtMS43YTMxLjcgMzUuNSAwIDAgMC0yLjEtM2MtLjIt'
    b'Mi4xLS42LTMuMi0uNy01LjMgMC0xLjUgMC0uNiAxLjQtMi43eiIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZlZmVmZSIgZD0ibTQzMC4zIDEzOCAuMy0uNGMtLjYuNy0uNC4zIDEtLjMuNi0uNCAy'
    b'LTEuNCAyLjUtMiAuNi0uMyAxLjctLjcgMi4yLTEuMy42LS44IDEuMy0xLjUgMi4yLTIuMi45'
    b'LTEgMS43LTEuMyAyLjgtMiAxLjMtLjIgMS45LS44IDMuMS0uMyAxLjIuMyAxLjcuMyAyLjYt'
    b'LjkgMS0uNiAyLjEtMS40IDIuNS0yLjR2LTEuOGMwIDEuOC0uNCAyLjUtMS41IDMtLjcgMS4x'
    b'LTEuOCAyLjItMi4yIDMuMi0uNyAxLjItLjkgMS45LTEuNiAyLjUtLjcuOS0xLjcgMS40LTIg'
    b'Mi44LjQuNyAwIDEgLjggMS4xLjcuNyAxLjQuNCAyLjQgMGExMC40IDExLjcgMCAwIDAgMS45'
    b'LTMuM2wxLjctMi45Yy44LS42IDEuMy0xLjEgMS42LTIuMiAxLS42IDEuOC0xLjMgMi41LTIg'
    b'LjctLjQgMS0uOSAyLTEuMWE0LjQgNSAwIDAgMS0uNyAzLjFjLS4yIDEuNi0uMSAyLjMuMyAz'
    b'LjMuNy42LjYgMSAxIDIgLjQtMSAuNi0yLjcuNy0zLjl2LS4yYzAgMS4xIDAgMi44LS4zIDMu'
    b'NiAwIDEuNi40IDIuNC44IDMuNi4zLjcuNyAxIDEuMSAxLjQgMC0xLjYuNS0yLjYuNi00LjFs'
    b'LjQgMy45YzAgMS4zLjUgMi4zIDEgMy4zLjUuNC43IDEuNS45LjYuNi0yIC42LTQgMS02LjIg'
    b'MC0xIDAtMi42LjUtMy4zbC0uNiAzLjNjLjEtMSAuMi0yLjUuNi0zLjN2LS40YTI4LjYgMzIg'
    b'MCAwIDEgLjUgNC42YzAgMS4yLS4xIDIuNC4yIDMuNi43LS40IDEuMi0xLjQgMS43LTIuNWEx'
    b'My4zIDE1IDAgMCAxIDEuOS0zLjFsLTIgM2ExMy4zIDE1IDAgMCAxIDItM3YtLjJhMjkuNSAz'
    b'My4xIDAgMCAwLS4yIDMuOGMwIDEuMyAwIDIuOC4yIDMuNy4zIDEuNS42IDEuNy43IDMuMyAw'
    b'IC44LS4xIDEuNy4yIDIgMSAuMyAxLS4zIDEuMi0yIDAtMS43LjQtMyAuNS00LjcgMC0yLjEu'
    b'Mi4zLjUgMWE5LjUgMTAuNyAwIDAgMSAuNyAzLjhjMCAuOCAwIDEuNi4yIDIgMS0uNSAxLjMt'
    b'MS43IDItMi4zLjQtMS40IDEtMiAxLjQtMi44IDEuMi0uMyAxLjItLjkgMS4yLTIuNSAwLTEu'
    b'NC0uMS0yLjguMy00YTMwIDMzLjcgMCAwIDAgLjktMy43Yy40LS4yLjkuNSAxLjIgMS4yLjUu'
    b'OS40IDIuMi40IDMuNmExNCAxNCAwIDAgMCAxLjMgMy40IDExIDEyLjMgMCAwIDAgMS42IDIu'
    b'OGMuMy45LjMgMi41LjMgMy43IDEtMS4yIDEtMyAxLjEtNC44LS4xLTEuMi0uMS0yLjgtLjQt'
    b'NCAwLTEuMi0uMy0yLjQtLjUtMy4zLS43LS40LTEtLjgtLjItMiAuNy0uNyAxLjYtLjQgMi44'
    b'LS4yLjcuNy45IDEuMSAxIDIuOCAwIDEuNSAwIDIuNi41IDMuNi40LjguOSAxLjQgMS4yIDIu'
    b'OC4zLjQuNiAxIDEuMS4zLjMtLjguNS0yLjQuOC0zLjQuMi0xIC42LTEuNiAxLjEtMiAwIDEu'
    b'NiAwIDIuNS42IDMuN2wxLjEgMy4xYy41LjQuNiAxLjMgMS4zIDEuN2wuMi00LjV2LTRjMC0x'
    b'LjIuNC0yIC43LTMgLjggMS4xLjggMS41LjggMyAuNy0uMy44LTEgMS4xLTEuOS41LS42Ljgt'
    b'LjggMSAuNi4xIDEuNS40IDIuOC43IDQuMi41LjYgMSAyLjIgMS42IDIuOGExMiAxMy41IDAg'
    b'MCAwIDEuNSAyLjNjLjQuOC40IDEuNCAxLjUgMS42IDAtMS45IDAtMy44LS4zLTUuNiAwLTEu'
    b'Ni0uMy0yLjItLjUtMy43LS40LS45LS42LTIuNC0uNS0yLjhhOCA5IDAgMCAxIDIuMiAzLjRs'
    b'MS41IDMuN2ExNC43IDE2LjUgMCAwIDEgMS44IDIuOGMuOS44IDEuMyAxLjcgMi4yIDIuNS40'
    b'LjUgMS41LjggMS43LjUgMC0xLjYtLjMtMy0uNy00LjRhNi42IDcuNCAwIDAgMC0uOC0zLjRj'
    b'LTEtLjktMS43LTEuNS0yLjItMi44LS4zLS40LS4zLS42LS40LTEuNGExOS4zIDIxLjYgMCAw'
    b'IDEgMy40IDMuOSA1LjEgNS44IDAgMCAwIDEuOSAyYy40LjYgMS44IDEuNCAyLjggMS42YTQu'
    b'MSA0LjYgMCAwIDAgMi40IDEuN2wtMi40LTEuNmE0LjEgNC42IDAgMCAwIDIuNCAxLjZ2LjRh'
    b'OS41IDEwLjcgMCAwIDAtMS40LTQuNiA2LjQgNy4yIDAgMCAwLTIuMi0zIDYuOCA3LjYgMCAw'
    b'IDAtMi40LTIuNWMtLjYtLjktMS42LTIuNC0yLjItMi44IDEuMS0uOSAyLjMuNCAzLjQgMSAx'
    b'IDEuMiAxLjggMi43IDIuNCAzLjRhMTMuMiAxNC44IDAgMCAwIDIuMiAzLjdjMSAuNyAxLjcg'
    b'MS4zIDIuNiAyLjIgMS40LjQuOS0uMS41LTEuNC0uNS0xLjYgMC0xLjYgMS0uNi42LjYgMS40'
    b'IDEuNCAyLjQgMiAuMy42IDEgMSAxLjYuNi4zLS40LjMtLjQuMy0uOC0uNS0xLjgtMS0zLjIt'
    b'Mi4yLTMuNy0uNS0uOS0xLjUtMS43LTIuMi0yLjUtLjUtLjgtMS0xLjMtMS40LTIuM2wxLjQg'
    b'Mi4yYy0uNS0uOC0xLTEuMi0xLjQtMi4yaC0uMmMxLjQgMCAyIC41IDMgMS4yYTUgNS42IDAg'
    b'MCAxIDIuMiAyYy41LjYgMS4yIDEuMyAxLjcgMi4xbDIuNCAyYy44IDEuMiAxIDIgMSAzLjYu'
    b'NC45LjUgMi41LjcgMy40LS4yIDEuNi0uNy4zLS44LS42LS4xLTEuMi0uNi0xLjEtMS40LS44'
    b'IDAgMS43LjIgMi4yLjcgMy40YTUuOSA2LjYgMCAwIDEtLjkgMi44Yy0uNi40LS43LS44LTEu'
    b'Mi0xLjQgMC0xLjctLjUtMi0xLjUtMi44djEuMWMuNiAxLjIgMS4yIDIuMyAxLjIgMy45YTgu'
    b'OCA5LjkgMCAwIDEgLjYgMy43YzAgMS40IDAgMi43LS4zIDQgMCAxLjQtLjMgMi0uMyAzLjZ2'
    b'Ny45YTE3IDE5LjIgMCAwIDAtLjIgMy42bC4yLTMuNmMtLjIgMS0uMiAyLjItLjIgMy42di4y'
    b'Yy0uNC0xLjQtMS0yLjYtMS4yLTRhNy41IDguNSAwIDAgMS0xLjYtM2MtLjMtMS4yLS4zLTIu'
    b'Ni0uNS0zLjYtLjQtMS0uOC0yLTEuNS0xLjQtLjMgMiAwIDMuMy43IDUuMy40IDEuMy40IDIu'
    b'NS44IDMuNy41IDEuNSAxIDEuNiAwIDMuMy0uNiAxLS44IDEuMi0xIDIuMy0uOS41LTEuMS44'
    b'LTEuMiAyLS4zLTEuMS0xLTIuNC0xLjQtMy43LS41LTEuNC0xLTIuOC0xLjItNC0uNi0uOS0x'
    b'LjMtMi40LTItM2wtMS44LTMuM2MtMS0xLjMtMS4yLTItMi0yLjYtLjEtLjUtLjQtMS4zLTEt'
    b'LjggMCAxLjMgMCAyLjcuMyAzLjkuMyAxLjYuNyAyLjUuOCA0LjJ2M2MtLjYtMS42LTEuMy0y'
    b'LjktMS43LTQuNC0uNi0uOS0xLjEtMi41LTEuNy0zLS40LTEuMi0uNy0yLjEtMS4yLTIuOS0u'
    b'MS0uOC0uNS0uOC0uOC0xLjQgMCAxLjYuNSAyLjIuOCAzLjMuNSAxLjIuNiAyLjkuNSAzLjUt'
    b'LjYtMi0xLjItNC4xLTItNmEyNiAyNiAwIDAgMS0xLjgtMy43Yy0uOC0uOS0xLjUtMS0yLjIt'
    b'MS42YTQuMyA0LjkgMCAwIDEtMS43LTEuNGMuMiAxLjUuNyAyLjUgMSAzLjYuMiAxLjQuNyAy'
    b'LjYuOSAzLjctLjIgMi0uNi0uNS0xLTEuNC0uMi0xLjYtLjctMi40LTEuMS0zLjMtLjctLjYt'
    b'MS4zLTEuNS0yLTItLjctLjMtLjQgMC0uNCAxIDAgMS44IDAgMyAuNSA0IC41LjguNSAxLjku'
    b'NSAzLjQtLjEgMS40LS4zIDIuNC0uMyA0djIuMWMtLjUtMS4xLTEtMS45LTEuNS0zLjMtLjct'
    b'MS4zLTEtMi4zLTEuNi0zLjctLjUtLjItMS41LS40LTIgMCAuMiAxLjQuNyAyIC44IDMuNy0x'
    b'IDEtLjggMS40LTEuNC0uMy0uNi0xLjMtMS4yLTEuMi0yLTItMS4yLS4xLS44LTEtMS4xLTIu'
    b'MyAwLTEgMC0yLS4zLTMtMS4zIDAtMiAwLTIuOS44LS4zLjgtLjIgMi41IDAgMy43djMuOWMt'
    b'LjMgMS0uNyAxLTEgMi4zLS40IDEuMS0uNSAyLjUtLjkgMy4zLS45LjktLjUgMS0xLS41di05'
    b'YzAtMS41LjMtMi4zLjMtMy43LS41LTEuMS0uNi0xLjQtMi4yLTEuNGE2IDYgMCAwIDAgMCAy'
    b'LjhjMCAxLjQuMSAyLjcuMyAzLjdsLjIgMy42YzAgMS41LS4zIDIuNy0xIDMuMy0uOC40IDAg'
    b'MS0uOSAxLjNhMTEgMTIuMyAwIDAgMS0yLjYtMmMtMS0uMy0xLjgtLjYtMy4xLS42LTEuNiAw'
    b'LTEuNi0uMi0yLjItMS42YTIzIDI1LjggMCAwIDEtMS00LjZjLS41LTEuMy0uNi0yLjItMS0z'
    b'LjdhNC41IDUuMSAwIDAgMC0xLjQtMmMtLjMgMS42LS42IDIuNy0uNiA0LjMtLjMuNy0uNCAy'
    b'LjQtLjYgMy0uNC0uNy0uNi0yLjQtMS0zLjUtLjMtMS43LS43LTIuOC0yLjMtMi4yLTEuNiAw'
    b'LTEuNiAwLTEuNiAybDEuOSAzLjJ2NGMwIDEuNiAwIDIuMS0xIDIuNC0uNC0xLjYtMS4yLTMu'
    b'My0yLjItNC43IDAtMS4xLS40LS44LTEuNC0uOC0uNiAwLTEuMy0uMS0xLjcuM3YyLjRjLS41'
    b'LjItLjcgMC0xLjEtLjUtLjUuOS0uMiAyIDAgM2ExMCAxMCAwIDAgMS0xLjIgMy4yYy0uMi0u'
    b'NC0uNC0uMiAwLS4yLTEuNy0uOC0zLTEuMi00LjQtMS43LS43IDAtMS40IDEtMS44IDEuNy0x'
    b'LjMuNC0xLjguOC0zLjIuOGwtMyAuMmMtMSAuMy0yIC40LTMuMi40LS42LS4zLTEuOC0uMy0y'
    b'LjEtLjYuNS0uOCAxLTEuMiAxLjQtMi41YTE0LjcgMTYuNSAwIDAgMCAyLTJsMS44LTIuM2Mu'
    b'NC0xLjQgMS0xLjYgMS43LTIuMiAxLjUgMCAxLjcuNiAzLjEuOCAxLjQuNiAyLjIuOSAzLS4z'
    b'IDEtLjUgMi0xLjQgMy4yLTEuNmwyLjQtMS43YzEtLjcgMS41LTEuNSAyLjQtMi4zLjMtMS4x'
    b'IDEtMiAuNy0zLjMtMS4zLS40LTIuMS0uMy0zIC41LS45IDEtMSAxLjQtMi4zIDIuMi0xIC40'
    b'LTEuNC45LTIuNiAxLjItMSAuNC0yLjIuMi0zLjMuMnMtMi41IDAtMy4xLjRjMS0uOCAyLjMt'
    b'MS43IDMuMy0yIDEtLjcgMS40LTEgMi43LTEuMi42LS44IDEuMS0uOCAxLjQtMi4yLjQtMS42'
    b'LTEtMS4xLTItLjUtLjkuMi0yIDEtMi44IDEuM2ExMC41IDExLjggMCAwIDEtMyAuNmMtLjQt'
    b'LjUuMS0uOS40LTEuNiAxLS41IDEuMy0uNyAxLjQtMi0xLjMuMi0xLjcuNy0yLjkuOGExOCAx'
    b'OCAwIDAgMS0zLjguNmgtMy4zYy0xLjIgMC0xLjgtLjMtMy4yLS4zLTEtLjYtMS0uOC0xLTIu'
    b'NS44LTEgMS41LS44IDMtLjhsMi42LTEuNWMuOS0uMiAxLjQtLjYgMS4yLTFoLTMuM2MtMS40'
    b'LS43IDAtMSAuNy0xLjUgMSAwIDIuMyAwIDMgLjUgMS41IDAgMi0uNSAzLjEtMS42IDEtLjgg'
    b'MS41LTEuNCAyLjUtMiAuNy0uOSAxLjQtMS40IDEuOS0yLjIgMS0xIDEuNy0xLjcgMi4yLTIu'
    b'Ni42LS40IDEtLjguNy0xLjQtMS41LjItMi4yLjktMy4yIDEuN2E3LjMgOC4yIDAgMCAxLTEu'
    b'OSAxLjYgNiA2LjcgMCAwIDEtMy4xIDEuM2MtMS4yIDAtMi4yLS4zLTMuMy0uNC0xLjMtLjEt'
    b'LjItLjUuMi0xLjEuNS0uMy45LTEuMi41LTItMS0uMy0yLjItLjItMy4zLS4yaC0zLjRjLTEu'
    b'MyAwLTEuOC0uNC0yLjctLjktLjItLjggMC0uNSAxLS41YTEzLjIgMTQuOCAwIDAgMCAzLjEt'
    b'LjZjMS4xLS4zIDEuMy0uOCAxLjUtMi4yLTEuMiAwLTIuNCAwLTMuMS0uM3ptLTIwLjctNi41'
    b'Yy0uMi0yLS43LTMuMS0uNy01LjIgMC0xLjUgMC0uNiAxLjQtMi43bDItMmMxLjMtLjggMi40'
    b'LTEuNyAzLjctMi40IDEtLjYgMy0xLjEgMy43LTEuNmE5LjIgMTAuMyAwIDAgMCAzLTIuOGMu'
    b'Mi0xLjcuNC0zIC40LTUgMS40LTEgMi41LTEuNiAzLjctMiAxLjctLjYgMi0xLjQgMy44LTEu'
    b'NyAxLS40IDIuOC0uNCA0LjQtLjQgMS42IDAgMi43IDEuNCA0LjIgMS42IDEuOC44IDIuNiAx'
    b'LjQgNCAyLjguOCAxLjIgMS40IDIuMiAyLjcgMyAxLjEuNiAyLjIgMS42IDMuNCAyIDAgMS40'
    b'LjMgMS4yLS42IDEuMi0uMSAxLjUtLjQgMS4zLTEuNyAxLjRhNS45IDYuNiAwIDAgMS0yLjIt'
    b'Mi4zYy42LTEuNC4zIDEuMiAwIDEuNy0uNS42LS45IDEuMi0xLjYuNi0uNC0xLjQtLjctMi4z'
    b'LS43LTQtLjItMS43LS43LS41LTEgLjMtLjMgMS41LS4yIDIgLjMgMy4xLTEuMyAwLTIuMi0u'
    b'Mi0zLjEtLjMtLjktLjMtMiAwLTMgLjYtMS4yLjktLjcuOS0uMiAyIDEuMS4zIDIgMSAzIDEu'
    b'NmwzLjMtLjhjMS4xLS41IDIuMi0uMiAzLjMgMCAuNi40IDEuNC40IDEuNy44IDAgLjkgMCAx'
    b'LjgtLjMgMi4zLS40LjQtMSAxLjQtMS43IDEuNmExMS44IDEzLjIgMCAwIDEtMy4yIDEuNWMt'
    b'MS41IDAtMi4xLjQtMy4yIDEtLjEgMS42LS41IDEuOS0xLjcgMi40YTcuNSA4LjUgMCAwIDEt'
    b'My4zLjhjLS43IDAtMS40IDAtMS43LS4zYTkuNCAxMC41IDAgMCAwIDItMy4zYy4yLS43LjYt'
    b'MSAuMi0xLjUtMS40IDAtMS44IDAtMiAxLjYtLjEgMS42LS42IDEuOS0xLjYgMi40LjMtMS40'
    b'LjMtMi41LjctMy43YTE4LjMgMjAuNiAwIDAgMS0zIC4zYy0uOC41LTEuMS43LS44IDEuNi0x'
    b'IC40LTIuMi4yLTMuNCAwLTEgMC0uNC0uNS0xLjItMS0uNS0xLjEtMS0xLjQtMi4yLTEuNC0u'
    b'NS44LTEuNCAxLTIgMS42LTEuMS40LTEuOCAwLTIuNy0uNS0xLjIgMC0xIC40LS43IDEuNC41'
    b'LjMgMCAuNy43LjguNy43IDEuMy45IDIuNi45IDEtLjQgMi4yLS4zIDMuNC0uMyAxLjIgMCAx'
    b'IC4zIDEgMS42LS44LjctMiAuNi0zLjIuNmExMi4yIDEzLjcgMCAwIDEtMi45LS44Yy0xIDAt'
    b'Mi0uMy0yLjggMC0uNC41LTEuNS43LS4yLjguNS42IDMuMy4zIDMuNCAxLjMuNy44LjUgMS45'
    b'LS42IDEuOWExLjYgMS44IDAgMCAwLTEuNyAwbC0zLjEuMWMxLjguMi0xLjMtMi4yLTItMy4y'
    b'eiIvPgogICAgPHBhdGggZmlsbD0iI2JjYmNiYyIgZD0ibTQxNy4xIDEyMi4yLTEuNCAxLTIu'
    b'OSAyLjNjLS41LjUtLjUuOC0xLjEuOCAxLS4xIDEuNi0uNSAyLjYtMSAxLjItLjIgMi40LS41'
    b'IDMtMS4yLjctLjIgMC0xLjMtLjItMnptMTEtMTMuMmMuMiAwIC41LjggMSAxLjQuNCAxIC43'
    b'IDEuOC43IDMgLjMtMS4zLjgtMi40IDEtMy45LS40LS44LS40LTEtMS41LTEuMSAwIC44LjIu'
    b'Mi0xLjIuNnoiLz4KICAgIDxwYXRoIGZpbGw9IiNjNGM0YzIiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIuOSIgZD0iTTM0OS40IDQxNy43Yy0uNSAwIC44LS41IDEuMy0uNi40LS44'
    b'LjYtMS4zIDEuMy0xLjggMS4xIDAgMS43LjQgMi4yIDEuMSAxIC4zIDEuMy43IDIuNC45LjUu'
    b'NCAxIC40IDAgLjctLjYuMy0xLjUuNC0yLjYuNGE3LjIgNy4yIDAgMCAwLTIuNi43Yy0xLjUg'
    b'MC0xLjMgMC0yLTEuNHoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDg0NDggMCAwIDEuMjY2NzQg'
    b'NDIuNiAtNDEwLjIpIi8+CiAgICA8cGF0aCBmaWxsPSIjYmNiY2JjIiBkPSJNNDMyLjUgMTA5'
    b'LjJ2LjNjMC0uOCAwLS40LjIgMS4yYTYuNiA3LjQgMCAwIDEgLjUgMy4zIDUgNS41IDAgMCAw'
    b'IDEuNS0yLjVjMC0yLjItLjQtMi4xLTIuMi0yLjN6bTguOCAzMi4zaC4zYy0uOCAwLS4zIDAg'
    b'LjktLjguOC0uNiAxLjUtMS42IDIuNi0yYTkuNSAxMC43IDAgMCAxIDMuMS0yYy42LS4zIDEu'
    b'MS0uOCAxLjctLjItLjEgMS4zLS40IDItMS41IDIuNS0uNS44LTEuMyAxLjMtMiAxLjYtLjgu'
    b'NS0xLjcuNS0yIDEuNS0xLjMuNy0xLjUuNS0zLS42em00LjYgOC4yYy4zLS40IDEuOS0yLjIg'
    b'Mi42LTIuOGExMSAxMi4zIDAgMCAxIDIuNC0yLjhjLjctMS4yIDEuNi0yIDIuMi0zLjFsMS45'
    b'LTIuOGMwIDEuMi0uMiAyLjguMiAzLjZhNS4xIDUuOCAwIDAgMS0uOCAzLjRjLS41IDEtMSAx'
    b'LjYtMi4yIDIuMy0xIC42LTEuNi44LTIuNSAxLjZhMTkgMjEuNCAwIDAgMS0yLjIgMS40Yy0u'
    b'Ny4zLS40LjMtMS42LS44em0tNy41IDYuNGguM2MtLjcgMC0uNCAwIDEtLjggMS0xLjIgMS44'
    b'LTEuNyAzLTIuMmE3LjUgOC41IDAgMCAwIDMtLjljLjUtLjEgMS0uNSAxLjMgMCAuOCAxLjIg'
    b'MSAxLjUtLjIgMi4zYTYuOSA3LjcgMCAwIDEtMi40IDEuNGMtLjYuNS0xLjguNS0zIC44LS44'
    b'IDAtMS40LjEtMS44LS42bDIgLjZjLTEgMC0xLjUuMS0zLjItLjZ6bTEwLjMgMHYtLjJjMCAu'
    b'OCAwIC40LjUtMS4yIDEtMS42IDEuMi0yLjUgMi40LTIuOC41LS44IDEuNS0xIDIuNi0xLjQu'
    b'NS44LjEgMS44IDAgMi44LS4zIDEtMS4xIDEuOC0xLjcgMi42LS43LjUtMSAxLjEtMi4yIDEu'
    b'NC0uOCAwLS4zIDAtMS42LTEuMnoiLz4KICAgIDxwYXRoIGQ9Ik00MjUuMyAxMTkuN2MwIC43'
    b'LS41IDEuNC0xLjIgMS40cy0xLjItLjctMS4yLTEuNGMwLS44LjYtMS40IDEuMi0xLjQuNyAw'
    b'IDEuMi41IDEuMiAxLjR6Ii8+CiAgPC9nPgogIDxnIGZpbGw9IiMwMDUxMjAiIGZpbGwtcnVs'
    b'ZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAyYjBkIiBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICA8'
    b'cGF0aCBkPSJNMzUxLjggNDc5LjZoLjljLTIuOCAwLTEuMS0uMiAzLjUgMy41IDItMS42IDIt'
    b'MS44IDMuNSAxIDEgMS41IDEuMi0uMiAyLjctMS44LjcgMy4yIDEuMSA2LjUgMy41IDMuNSAy'
    b'LjggMCA1LjYtLjIgNy4xLjkgMS44IDMuMyAxLjItLjYgMi42LjkgNCAuNCAzLjktMy40IDgu'
    b'MS00LjQgMi42IDMuMyAzLjguOCA3LS44IDIuNS42IDQuOCA0LjMgNS4zLjcgMi0zLjIgMi4x'
    b'LTMgMy41IDAgMiAxLjggMi44LS44IDQuNC0xLjcgMyAxLjcgNi4zIDIgMTAuNi45LjggMi45'
    b'IDIuNiAxLjYgNC41LjggMy45IDEuNyA1LjIgMi4yIDkuNyAwIDIuMi0yLjYgMSAuMSAyLjYg'
    b'MS44IDMuMy0xIDIuNC0xLjIgNi4yLS45IDMuOSAwIDQuMiAwIDUuMy0yLjYgMiAxLjkgMi42'
    b'IDMuMyA1LjMuOSA0LjIgMCAyLjkuNSA1LjMtMSAxLjkgNCAyLjMgMS4yIDQuNSAyLjdhMTQu'
    b'NSAxNC41IDAgMCAxLTYuMiA3Yy0xLjcgMy0yLjggNi02LjIgNy4yLTIuNSAyLjUtNS4yIDQt'
    b'OCA2LjItMy44IDEtOCAuOC0xMi4zLjhIMzg4Yy0yLjYgMS40LTcgMi0xMC42IDIuNy00IDAt'
    b'OC43IDAtMTEuNS0uOS0xLjktMS45LTUuMi00LTctNi4yLTItMS41LTItNC40LTMuNi02LjIt'
    b'MS40LTIuNS0yLTYuNS0zLjUtOC44eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wODQ0OCAwIDAg'
    b'MS4yNjY3NCA0Ny4zIC00MTEuNCkiLz4KICAgIDxwYXRoIGQ9Ik00MzcuNSA0ODcuNnYuOGMw'
    b'LTIuNC4xLTEuMS0xLjggMy42LS4zIDEuMS0xLjIgMS40LTIuNiAxLjhtLTMuNS0yLjdoLjlj'
    b'LTMuMyAzLTUuNSA0LjUtNi4yIDhsNi4yLThjLTMuMyAzLTUuNSA0LjUtNi4yIDhtLTcuMS0x'
    b'Mi40cy0uMSAzLjEtLjkgNC40bS0yLjYgMS44di44em0tNy4xLTUuM2guOS0xYy40IDAgLjcg'
    b'MCAwIDB6bS00OS41IDBjLjQgMCAyLjIgMi44IDQuNCA0LjQtLjUgMi42LTEuNCA1LjYgMCA4'
    b'bTIuNy03LjFjLjQgMCAyLjEgMi44IDQuNCA0LjRsLTQuNC00LjRjLjQgMCAyLjEgMi44IDQu'
    b'NCA0LjR2LjljMC0yLjgtLjItNS42LjktNy4xIDEgMS43IDIuMiA0LjMgMi42IDEuOCA1LS4y'
    b'IDcuNC0xLjYgMTAuNi0yLjcgMCAxLjMtLjIuNyAxIDEuOG02MC0zLjZoLjljLTEuNyAxLjQt'
    b'MyA0LjMtNC40IDYuMm0tMzIuNy04LjhoNyIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wODQ0OCAw'
    b'IDAgMS4yNjY3NCA0Ny4zIC00MTEuNCkiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNNDI1LjkgMjE0LjNjLTExLjUgMC0xNS40IDEzLjUt'
    b'MjYuOSAxMy41aC0uNnYuOGMwIDkuNC42IDE4LjEgMS44IDI2LjIgMTAuNi0uOCAxNC41LTEz'
    b'LjQgMjUuNy0xMy40IDExLjUgMCAxNS4zIDEzLjQgMjYuOCAxMy40IDExLjYgMCAxNS40LTEz'
    b'LjQgMjYuOS0xMy40IDExLjUgMCAxNS40IDEzLjQgMjYuOSAxMy40IDExLjUgMCAxNS4zLTEz'
    b'LjQgMjYuOC0xMy40IDExIDAgMTUgMTIuNSAyNS42IDEzLjRhMTM5IDE1Ni4xIDAgMCAwIDEu'
    b'OS0yN2gtLjdjLTExLjUgMC0xNS4zLTEzLjQtMjYuOC0xMy40cy0xNS40IDEzLjUtMjYuOCAx'
    b'My41Yy0xMS41IDAtMTUuNC0xMy41LTI3LTEzLjUtMTEuNCAwLTE1LjMgMTMuNS0yNi44IDEz'
    b'LjUtMTEuNCAwLTE1LjMtMTMuNS0yNi44LTEzLjV6bTAgNTIuN2MtOSAwLTEzLjIgOC4yLTIw'
    b'LjIgMTEuOGExMTEgMTI0LjUgMCAwIDAgOC42IDIwLjVjMy4zLTIuOCA2LjctNS4yIDExLjYt'
    b'NS4yIDExLjUgMCAxNS4zIDEzLjUgMjYuOCAxMy41IDExLjYgMCAxNS40LTEzLjUgMjYuOS0x'
    b'My41IDExLjUgMCAxNS40IDEzLjUgMjYuOCAxMy41czE1LjQtMTMuNSAyNi45LTEzLjVhMTgu'
    b'MyAyMC42IDAgMCAxIDExLjMgNSAxMTIgMTI1LjcgMCAwIDAgOC42LTIwLjRjLTYuNy0zLjct'
    b'MTEtMTEuNy0yMC0xMS43LTExLjQgMC0xNS4zIDEzLjUtMjYuOCAxMy41UzQ5MSAyNjcgNDc5'
    b'LjYgMjY3cy0xNS40IDEzLjUtMjYuOSAxMy41Yy0xMS40IDAtMTUuMy0xMy41LTI2LjgtMTMu'
    b'NXptNTMuNyA1Mi43Yy0xMS41IDAtMTUuNCAxMy41LTI2LjkgMTMuNS0xMC45IDAtMTQuOS0x'
    b'Mi0yNS0xMy40YTEzMiAxMzIgMCAwIDAgMzkuMyAzM2MzLjYtMy4yIDcuMyAzLjYgMTIuNSAz'
    b'LjYgNS4zIDAgOS02LjkgMTIuNS0zLjhhMTI5LjEgMTQ1IDAgMCAwIDM5LTMyLjdjLTkuOCAx'
    b'LjctMTQgMTMuMy0yNC42IDEzLjMtMTEuNSAwLTE1LjMtMTMuNS0yNi44LTEzLjV6Ii8+CiAg'
    b'PGcgdHJhbnNmb3JtPSJtYXRyaXgoLjg2NDY1IDAgMCAuOTcwNjIgLTE3NS40IDIuNSkiPgog'
    b'ICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNTEyMDA3IiBzdHJva2Utd2lkdGg9Ii41'
    b'IiBkPSJNMzMyLjUgNTQxLjRhMTEwIDExMCAwIDAgMSAxMC41LTNsMTYuMyAxNS43LTEzLjQg'
    b'Mi43eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4yNSAwIDAgMS4zIDI1OS40IC00MzApIi8+CiAg'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiM1MTIwMDciIHN0cm9rZS13aWR0aD0iLjYi'
    b'IGQ9Ik00MTMuNiA0NzFjLjMtNC42IDguOC0zMSA4LjgtMzFtLTUuOSAzMS4zIDYuNy0zMS4x'
    b'bS00LjQgMzEuMiA1LjYtMzEuMm0tMTAuNSAyN2MxLjUtLjggNS44LTIgNS44LTJtLTMuNy0y'
    b'LjZjMS40IDAgNC4zLTEuMiA0LjMtMS4ybS0zLjUtMi4zYTI0IDI0IDAgMCAxIDQuNC0xLjJt'
    b'LTMuOC0zLjIgNC43LS44bS0yLjYtM2MwIC4zIDMuMi4zIDMuMi4zbS0yLjQtMy43IDMuMi41'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA2IDAgMCAxLjAzIDI3Ni44IC0xNzgpIi8+CiAgICA8'
    b'cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiM1MTIwMDciIHN0cm9rZS13aWR0aD0iLjQiIGQ9'
    b'Ik00MTMuNiA0NzFjLjMtNC42IDguOC0zMSA4LjgtMzFtLTUuOSAzMC4xIDYuNy0zMG0tMy43'
    b'IDI3LjdjLjItMS43IDQuOS0yNy42IDQuOS0yNy42bS0xMC41IDI3YzEuNS0uOCA1LjgtMiA1'
    b'LjgtMm0tMy43LTIuNmMxLjQgMCA0LjMtMS4yIDQuMy0xLjJtLTMuNS0yLjNhMjQgMjQgMCAw'
    b'IDEgNC40LTEuMm0tMy44LTMuMiA0LjctLjhtLTIuNi0zYzAgLjMgMy4yLjMgMy4yLjNtLTIu'
    b'NC0zLjcgMy4yLjUiIHRyYW5zZm9ybT0ibWF0cml4KC0xLjI1IDAgMCAxLjc2IDEyOTAuNCAt'
    b'NTAyKSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNTEyMDA3IiBzdHJva2Ut'
    b'd2lkdGg9Ii41IiBkPSJNNDEzLjYgNDcxYy4zLTQuNiA4LjgtMzEgOC44LTMxbS01LjkgMzAu'
    b'MSA2LjctMzBtLTMuNyAyNy43Yy4yLTEuNyA0LjktMjcuNiA0LjktMjcuNm0tMTAuNSAyN2Mx'
    b'LjUtLjggNS44LTIgNS44LTJtLTMuNy0yLjZjMS40IDAgNC4zLTEuMiA0LjMtMS4ybS0zLjUt'
    b'Mi4zYTI0IDI0IDAgMCAxIDQuNC0xLjJtLTMuOC0zLjIgNC43LS44bS0yLjYtM2MwIC4zIDMu'
    b'Mi4zIDMuMi4zbS0yLjQtMy43IDMuMi41IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS4yNSAwIDAg'
    b'MS4zIDEzMjEuMyAtMzAyKSIvPgogICAgPHBhdGggZmlsbD0iI2RkOGI1OSIgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBzdHJva2U9IiM1MTIwMDciIHN0cm9rZS13aWR0aD0iLjUiIGQ9Im0zOTUu'
    b'MyA1NzIuMi45LTczczIuNi0uMyAyLjYgMC0uMyA3Mi43LS42IDczYy0uMy4zLTMuMi41LTIu'
    b'OSAwem0yOC41LTY5LjgtLjYgNjEuMy0yIDIuNC42LTYzLjd6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgxLjI1IDAgMCAxLjMgMjU5LjQgLTQzMCkiLz4KICAgIDxwYXRoIGZpbGw9IiNkZDhiNTki'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjNTEyMDA3IiBzdHJva2Utd2lkdGg9Ii41'
    b'IiBkPSJNMzYzIDU2MC4yczMgMzAgMzYuNCAyOS4xYzMzLjQtLjkgNDIuNy0zMC4yIDQyLjct'
    b'MzAuMmwtMTQuNS0uNmMtLjMgMC0xMS42IDE0LTI2LjIgMTMuNy0xNC42LS4zLTE5LjItMy44'
    b'LTIyLjQtNi43LTMuMi0zLTYtNy4zLTYtNy4zbC0xNy02LjcgMSA2LjR6bTkwLjMtMy0xLTR2'
    b'LTMuNGwxLjYtMy42cy0yNS4zIDMuNy0yNS4zIDRsLS4xIDYuOCAyNC44LjF6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjI1IDAgMCAxLjMgMjU5LjQgLTQzMCkiLz4KICAgIDxwYXRoIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0ibTQ0OC41IDU0'
    b'OS44LS42IDZoNC4xbC0uMy02em0tNC4zLjMtLjMgNi40IDIuNi0uMy4zLTYuMXptLTQuNCA2'
    b'LjR2LTVsMi42LS45LjMgNXptLTUtLjMuNi00LjQgMyAuMy4yIDQuN3ptLTUuNSAwIC4zLTMu'
    b'OCAzLS4zdjQuNHptLTY3LjQgMy43Yy45IDAgNy42IDEuNSA3LjYgMS41bDcgOS4zIiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCgxLjI1IDAgMCAxLjMgMjU5LjQgLTQzMCkiLz4KICAgIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTM2Ni44'
    b'IDU2MS4xYy4zLjMgNi4xIDE5LjggMzQgMTkuOHMzNC42LTIyLjEgMzQuNi0yMi4xIiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCgxLjI1IDAgMCAxLjMgMjU5LjQgLTQzMCkiLz4KICAgIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTQzOS44'
    b'IDU1OS40cy0xMy40IDI5LTM5IDI3Yy0yNS41LTItMjkuNi0xMS42LTMxLjYtMTYuNi0yLTUt'
    b'My4yLTktMy4yLTkiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjUgMCAwIDEuMyAyNTkuNCAtNDMw'
    b'KSIvPgogICAgPHBhdGggZmlsbD0iI2RkOGI1OSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJv'
    b'a2U9IiM1MTIwMDciIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik0zNzMuMiA1NTguMmMuMy0xLjcu'
    b'My01NC40LjMtNTQuNGwtMS43LS4yLS4zIDUzLjcgMS43IDF6bS00MS41LTE3LjEgMjIgMTAu'
    b'Ny0uNSAxLjVTMzMyIDU0My4zIDMzMiA1NDNjMC0uMy4yLTEuNS0uMy0yeiIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoMS4yNSAwIDAgMS4zIDI1OS40IC00MzApIi8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZGQ4YjU5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdp'
    b'ZHRoPSIuNSIgZD0iTTM0MS44IDUzNy45YzAgLjggMy4yIDE4LjYgMy4yIDE4LjZzMiAuMyAy'
    b'IDBsLTMuNC0xOC4zem0yMC40LjVjMS4xIDAgMjEtMy4yIDIxLTMuMmwtLjQgMy4yLTE5LjUg'
    b'MnoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjUgMCAwIDEuMyAyNTkuNCAtNDMwKSIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZlY2YzZSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiM1MTIw'
    b'MDciIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik0zNjUgNTE0LjNjLjcgMCA3IDMuMiA5LjcgMi40'
    b'IDIuNy0uOC45LTMgMS40LTMgLjYgMCAyLjYgMS41IDMuOC4zIDEuMi0xLjEgMi00LjYgMS41'
    b'LTQuMy0uNi4zLTE2IDUuOC0xNi4zIDQuNnoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjUgMCAw'
    b'IDEuMyAyNTkuNCAtNDMwKSIvPgogICAgPHBhdGggZmlsbD0iI2RkOGI1OSIgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBzdHJva2U9IiM1MTIwMDciIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik0zNjIu'
    b'NSA1MjEuNmMxLjEuMyAyMy44LTYuMSAyMy44LTYuMXMwIDItLjMgMmwtMjMuNSA2LjF6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgxLjI1IDAgMCAxLjMgMjU5LjQgLTQzMCkiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNmZWNmM2UiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjNTEyMDA3IiBz'
    b'dHJva2Utd2lkdGg9Ii41IiBkPSJNNDE1IDUxMi42czEuNSAzLjUgMyAyLjljMS41LS42IDIu'
    b'OS0xLjggMi45LTEuOHMxLjIgMyAzLjIgMi40YzItLjYgMy4yLTMuOCAzLjItMy44czIgLjYg'
    b'Mi45LjNjLjktLjMgMi01IDItNWwtMTcuMSA1em0tMS43IDI4LjJjLS4zLjYgMS41IDIgMyAy'
    b'czItMiAyLjMtMS40Yy4zLjUuMyAzLjIgNCAyLjMgMy43LS45IDMuOC0zLjUgMy44LTMuNXMt'
    b'MS4xLjkgMS41IDEuMmMyLjYuMyA1LjItMy44IDUtMy44LS40IDAtMTkgMy41LTE5LjYgMy4y'
    b'eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4yNSAwIDAgMS4zIDI1OS40IC00MzApIi8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZGQ4YjU5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzUxMjAw'
    b'NyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTM2My40IDUxMy4xYTUgNSAwIDAgMCAuMiAyLjds'
    b'MTktNi40cy44LTEuNSAwLTEuNS0xOS41IDUuOC0xOS4zIDUuM3ptMjUtNGMuNSAwIDE5LjQt'
    b'Ni4xIDE5LjQtNi4xcy4zIDIuNiAwIDIuNmwtMTcuNyA1LjItMS44LTEuN3oiIHRyYW5zZm9y'
    b'bT0ibWF0cml4KDEuMjUgMCAwIDEuMyAyNTkuNCAtNDMwKSIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZlY2YzZSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiM1MTIwMDciIHN0cm9rZS13'
    b'aWR0aD0iLjUiIGQ9Ik00MTMuMyA1MjEuOXMtMi45IDMuMi0yIDcuNWMuOSA0LjQgMiA4LjIg'
    b'Mi4zIDguMi4zIDAgMy41LTUuOCA3LTYuMSAzLjUtLjMgOS45IDMuMiA5LjkgMy4ycy0uOS03'
    b'LS42LTEwLjJjLjMtMy4yIDUuMi04LjcgNS4yLTguN2wtMjEuOCA2eiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoMS4yNSAwIDAgMS4zIDI1OS40IC00MzApIi8+CiAgICA8cGF0aCBmaWxsPSIjZGQ4'
    b'YjU5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRo'
    b'PSIuNSIgZD0iTTM4Ni45IDUxNi42cy0uNiAyLjctLjMgMi43bDI0LjctNi40VjUxMWwtMjQu'
    b'NCA1LjV6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjI1IDAgMCAxLjMgMjU5LjQgLTQzMCkiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNiNmI2YjQiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIj'
    b'NTEyMDA3IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNMzU1LjUgNTUxLjhzLTUuOC0uOC01LjUu'
    b'NmMuMyAxLjUgMi45IDIuOSAzLjIgMy44LjMuOS0uOSA0IC45IDMuOCAxLjctLjMgMy40LTEu'
    b'NSAzLjQtMi40bC0uMy01eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4yNSAwIDAgMS4zIDI1OS40'
    b'IC00MzApIi8+CiAgICA8cGF0aCBmaWxsPSIjZGQ4YjU5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQi'
    b'IHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTM4Ny44IDUzNy4zdjJs'
    b'MjAuOS0yLjktLjYtMS41eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4yNSAwIDAgMS4zIDI1OS40'
    b'IC00MzApIi8+CiAgICA8cGF0aCBmaWxsPSIjZmVjZjNlIiBmaWxsLXJ1bGU9ImV2ZW5vZGQi'
    b'IHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTM2MyA1NDAuOGMuNCAw'
    b'IDAgMi42IDIuNCAyIDIuMy0uNiAyLjktMiAyLjktMnMuNiAzLjIgMy44IDIuOWMzLjItLjMg'
    b'NS0zLjggNS0zLjhzLjIgMi42IDIuMiAxLjdjMi0uOSAyLjYtMi45IDIuNi0yLjlsLTE4LjMg'
    b'Mi42LS41LS41em0wLTE3LjJzLTIuNi45LTEuNyA2LjFjLjkgNS4yIDMgOC4yIDMuMiA4LjIu'
    b'MyAwIDIuNi01IDYuMS01LjggMy41LTEgOS42IDIuNiA5LjYgMi42cy0uNi00LjcuMy05YTE4'
    b'IDE4IDAgMCAxIDMuOC03LjZzLTIwLjQgNS41LTIxLjIgNS41eiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoMS4yNSAwIDAgMS4zIDI1OS40IC00MzApIi8+CiAgICA8cGF0aCBmaWxsPSIjZGQ4YjU5'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIu'
    b'NSIgZD0ibTQxMS45IDUzOC43LjMgMS44czIxLTIuNiAyMS0zYzAtLjIgMC0yLS40LTItLjMg'
    b'MC0yMC42IDMuNS0yMSAzLjJ6bS0uMy0xOC42LjMgMiAyNC43LTYuNnMuNi0xLjguMy0xLjgt'
    b'MjQuNyA3LjMtMjUuMyA2LjR6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjI1IDAgMCAxLjMgMjU5'
    b'LjQgLTQzMCkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzUxMjAwNyIgc3Ry'
    b'b2tlLXdpZHRoPSIuNSIgZD0iTTQxNC4yIDUxMC44cy0uMyAxLjggMCAxLjggMTguMy00LjQg'
    b'MTguMy00LjdjMC0uMyAxLjgtMiAuMy0xLjctMS40LjMtMTggNS41LTE4LjYgNC42em0zOC43'
    b'IDMzLjctMTgtMjguNG0tMi40IDE5LjdjLjMtLjggMS4yLTE4LjMgMS4yLTE4LjMiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDEuMjUgMCAwIDEuMyAyNTkuNCAtNDMwKSIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZlY2YzZSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiM1MTIwMDciIHN0cm9r'
    b'ZS13aWR0aD0iLjUiIGQ9Ik0zODkgNTEwYzEgLjIgMy4xIDMuMiA0LjMgMi42IDEuMi0uNiAy'
    b'LjktMi40IDIuOS0yLjRzLS4zIDMuNSAyIDNjMi40LS42IDIuNy0zIDIuNy0zczEuNyAxIDMu'
    b'MiAwYzEuNC0uOCAyLjgtNS4yIDIuMy01LjJzLTE2LjkgNS4yLTE3LjUgNXptLS42IDguNGMw'
    b'IC42LTMgNS4yLTIgOS42IDEgNC40IDIuNSA4LjQgMi44IDguNC4zIDAgNC43LTQuNiA4LjUt'
    b'NS41IDMuNy0uOSA5LjMgMi45IDkgMi45LS4zIDAtMS41LTQuNC0xLjUtNy42IDAtMy4yIDQu'
    b'NC0xMyA0LjQtMTN6bTAgMjFjMCAuMi44IDIuMiAyLjkgMi4yIDIgMCAyLjMtMiAyLjMtMnMt'
    b'LjMgMy41IDIuOSAzLjJjMy4yLS4zIDQuMy0zLjUgNC4zLTMuNXMuMyAxLjggMyAuOWMyLjYt'
    b'LjkgNi0zLjggNS44LTMuOC0uMyAwLTIxIDMuOC0yMS4zIDN6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgxLjI1IDAgMCAxLjMgMjU5LjQgLTQzMCkiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2Zr'
    b'LWwiIHdpZHRoPSI5OTIuMSIgaGVpZ2h0PSI0OTYuMSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUo'
    b'LTYuNiA3LjMpIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNmay1sIiB3aWR0aD0iOTkyLjEi'
    b'IGhlaWdodD0iNDk2LjEiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDYuNiAzLjgpIi8+CiAgICA8'
    b'dXNlIHhsaW5rOmhyZWY9IiNmay1sIiB3aWR0aD0iOTkyLjEiIGhlaWdodD0iNDk2LjEiIHRy'
    b'YW5zZm9ybT0idHJhbnNsYXRlKDAgMTEpIi8+CiAgICA8cGF0aCBpZD0iZmstbCIgZmlsbD0i'
    b'I2JlMGYxNyIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiM1MTIwMDciIHN0cm9rZS13'
    b'aWR0aD0iLjYiIGQ9Ik00MDkgNDc3YTEuOSAxLjkgMCAxIDEtMy44IDAgMS45IDEuOSAwIDAg'
    b'MSAzLjggMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4wNCAtMS4wNyAxLjAyIC4wNCAyNTEuNiA2'
    b'NjgpIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiM1MTIwMDciIHN0cm9rZS13'
    b'aWR0aD0iLjUiIGQ9Ik0zOTguMiA1MDBjMC0uMiA5IDMuOCA5IDQuMSAwIC4zIDMyIDQyLjgg'
    b'MzIuMyA0Mi44bS0xNi00Mi44IDguMiAzLjUgMi42IDYuNG0tNjEuNC0xMC40Yy0uMyAwIDkg'
    b'NyA5IDdsMS4yIDUuN00zNDEuMyA1NDZjNC0xLjcgMzIuMi0yNi40IDMyLjItMjYuNG0tMzku'
    b'OCAyMS43IDMxLjctMjYuN20yMS4yIDQgMzAgNDkuOG0tMy42LTI5LjJzMy41IDExLjcgNyAx'
    b'My41YTg2IDg2IDAgMCAxIDcuNiA0LjYiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjUgMCAwIDEu'
    b'MyAyNTkuNCAtNDMwKSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNTEyMDA3'
    b'IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDEyLjYgNTM5LjVzMi41IDEzLjggNiAxNi40YzMu'
    b'NSAyLjYgNyA1LjUgNyA1LjUiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjUgMCAwIDEuMyAyNTku'
    b'NCAtNDMwKSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNTEyMDA3IiBzdHJv'
    b'a2Utd2lkdGg9Ii41IiBkPSJNMzkxIDQzOXMzLjQgMTkuMiAxMC40IDIzLjZhOTUwIDk1MCAw'
    b'IDAgMSAxMi44IDguMSIgdHJhbnNmb3JtPSJtYXRyaXgoMS4yNSAwIDAgMS4zIDI1Ni4zIC0y'
    b'OTkuNSkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tl'
    b'LXdpZHRoPSIuNSIgZD0iTTM5MC43IDQzOC43czcuNSAxNS4yIDE0IDE5LjhjNi4zIDQuNyAx'
    b'NSA5IDE1IDlNMzY2LjMgNDQwYzIgMy41IDEuNyAxMC4yIDQgMTIuNWE2NiA2NiAwIDAgMSA1'
    b'LjggNy42bS05LjMtMTkuOWMxLjIgMS43IDQuNCAxMC40IDYuNCAxMyAxLjUgMi40IDE2LjMg'
    b'MTcuMiAxNi4zIDE3LjIiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjUgMCAwIDEuMyAyNTYuMyAt'
    b'Mjk5LjUpIi8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzUxMjAw'
    b'NyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTM4NC42IDQ3MS4xYTIuMiAyLjIgMCAxIDEtNC40'
    b'IDAgMi4yIDIuMiAwIDAgMSA0LjQgMHptMTAuNyA0LjdhMS45IDEuOSAwIDEgMS0zLjggMCAx'
    b'LjkgMS45IDAgMCAxIDMuOCAwek00MDkgNDc3YTEuOSAxLjkgMCAxIDEtMy44IDAgMS45IDEu'
    b'OSAwIDAgMSAzLjggMHptMTEuOS00LjVjMCAxLS43IDEuNy0xLjYgMS43LS45IDAtMS42LS44'
    b'LTEuNi0xLjcgMC0uOS43LTEuOCAxLjYtMS44LjkgMCAxLjYuOCAxLjYgMS44em05LjYtNS43'
    b'YzAgLjktLjkgMS42LTEuOSAxLjYtMSAwLTEuOS0uNy0xLjktMS42IDAtLjkuOS0xLjYgMS45'
    b'LTEuNiAxIDAgMS45LjcgMS45IDEuNnoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjUgMCAwIDEu'
    b'MyAyNTYuMyAtMjk5LjUpIi8+CiAgICA8cGF0aCBmaWxsPSJyZWQiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjNTEyMDA3IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNMzc0LjEgNDA0'
    b'LjRjLS45LjYtMTUuNCA0LjEtMTMuNCAzLjggMi0uMyAxMy43IDMgMTMuNCAyLS4zLTEgMC01'
    b'LjIgMC01Ljh6bTI0LjctNC4zYy0uNiAwLTkgMy4yLTguNyAzLjIuMyAwIDkuNiAyLjYgOS4z'
    b'IDItLjMtLjYtLjMtNC40LS42LTUuMnptMjUuMyAyLjljLS42LjMtMTAuNSAyLjYtOC43IDIu'
    b'OSAxLjguMyA4LjQgMi42IDguNCAyIDAtLjUgMC00LjYuMy01eiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoMS4yNSAwIDAgMS4zIDI1Ni4zIC0yOTkuNSkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTQxMy42IDQ3MWMuMy00'
    b'LjYgOC44LTMxIDguOC0zMW0tNS45IDMwLjEgNi43LTMwbS0zLjcgMjcuN2MuMi0xLjcgNC45'
    b'LTI3LjYgNC45LTI3LjZtLTEwLjUgMjdjMS41LS44IDUuOC0yIDUuOC0ybS0zLjctMi42YzEu'
    b'NCAwIDQuMy0xLjIgNC4zLTEuMm0tMy41LTIuM2EyNCAyNCAwIDAgMSA0LjQtMS4ybS0zLjgt'
    b'My4yIDQuNy0uOG0tMi42LTNjMCAuMyAzLjIuMyAzLjIuM20tMi40LTMuNyAzLjIuNSIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoMS4yNSAwIDAgMS4zIDI1Ni4zIC0yOTkuNSkiLz4KICAgIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzUxMjAwNyIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTQx'
    b'My42IDQ3MWMuMy00LjYgOC44LTMxIDguOC0zMW0tNS45IDMxLjMgNi43LTMxLjFtLTQuNCAz'
    b'MS4yIDUuNi0zMS4ybS0xMC41IDI3YzEuNS0uOCA1LjgtMiA1LjgtMm0tMy43LTIuNmMxLjQg'
    b'MCA0LjMtMS4yIDQuMy0xLjJtLTMuNS0yLjNhMjQgMjQgMCAwIDEgNC40LTEuMm0tMy44LTMu'
    b'MiA0LjctLjhtLTIuNi0zYzAgLjMgMy4yLjMgMy4yLjNtLTIuNC0zLjcgMy4yLjUiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDEuMjUgMCAwIDEuMzYgMjI1LjMgLTMyMy40KSIvPgogICAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNTEyMDA3IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDEz'
    b'LjYgNDcxYy4zLTQuNiA4LjgtMzEgOC44LTMxbS01LjkgMzAuMSA2LjctMzBtLTMuNyAyNy43'
    b'Yy4yLTEuNyA0LjktMjcuNiA0LjktMjcuNm0tMTAuNSAyN2MxLjUtLjggNS44LTIgNS44LTJt'
    b'LTMuNy0yLjZjMS40IDAgNC4zLTEuMiA0LjMtMS4ybS0zLjUtMi4zYTI0IDI0IDAgMCAxIDQu'
    b'NC0xLjJtLTMuOC0zLjIgNC43LS44bS0yLjYtM2MwIC4zIDMuMi4zIDMuMi4zbS0yLjQtMy43'
    b'IDMuMi41IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS4yNSAwIDAgMS4zMiAxMjU5LjIgLTMwNy4z'
    b'KSIvPgogICAgPHBhdGggZmlsbD0iI2RkOGI1OSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJv'
    b'a2U9IiM1MTIwMDciIHN0cm9rZS13aWR0aD0iLjUiIGQ9Im00MjYuNCA1NTguNSAyNy42LjYu'
    b'My0yLTI4LjUtLjN6bTEuMi03LjNjMy4yIDAgMjcuMy00LjYgMjcuMy00LjZzLjktMyAwLTMt'
    b'MjcuMyA1LjYtMjcuMyA1LjZ6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjI1IDAgMCAxLjMgMjU5'
    b'LjQgLTQzMCkiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2ZrLWwiIHdpZHRoPSI5OTIuMSIg'
    b'aGVpZ2h0PSI0OTYuMSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMCA1LjUpIi8+CiAgPC9nPgog'
    b'IDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9Ik0wIDBoMzIwdjI0MEgweiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNGRkYiIGQ9Im0zNy41IDAgMTIyIDkwLjVMMjgxIDBoMzl2MzFsLTEyMCA4OS41IDEy'
    b'MCA4OVYyNDBoLTQwbC0xMjAtODkuNUw0MC41IDI0MEgwdi0zMGwxMTkuNS04OUwwIDMyVjB6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI0M4MTAyRSIgZD0iTTIxMiAxNDAuNSAzMjAgMjIwdjIwbC0x'
    b'MzUuNS05OS41em0tOTIgMTAgMyAxNy41LTk2IDcySDB6TTMyMCAwdjEuNWwtMTI0LjUgOTQg'
    b'MS0yMkwyOTUgMHpNMCAwbDExOS41IDg4aC0zMEwwIDIxeiIvPgogIDxwYXRoIGZpbGw9IiNG'
    b'RkYiIGQ9Ik0xMjAuNSAwdjI0MGg4MFYwek0wIDgwdjgwaDMyMFY4MHoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjQzgxMDJFIiBkPSJNMCA5Ni41djQ4aDMyMHYtNDh6TTEzNi41IDB2MjQwaDQ4VjB6'
    b'Ii8+Cjwvc3ZnPgo=', 'FK')

FK = b64_FK
index.append("FK")
index.append("FLK")
index.append("Falkland Islands (Malvinas)")
catalog["FK"] = FK
catalog["FLK"] = FK
catalog["Falkland Islands (Malvinas)"] = FK
country["Falkland Islands (Malvinas)"] = ('FK', 'FLK', 0)
lookup["FK"] = ('FK', 'FLK', 'Falkland Islands (Malvinas)', 0)
lookup["Stanley Falkland Islands (Malvinas)"] = ('FK', 'FLK', 'Falkland Islands (Malvinas)', 0)
lookup["FLK"] = ('FK', 'FLK', 'Falkland Islands (Malvinas)', 0)
lookup["Falkland Islands (Malvinas)"] = ('FK', 'FLK', 'Falkland Islands (Malvinas)', 0)
details["FK"] = {"continent":"Americas","capital":"Stanley","currency":"","web":".fk","lang":"en-FK","tz":"-03:00","altname":""}
#----------------------------------------------------------------------
b64_FM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWZtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImZtLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTgxLjMgMGg2ODIu'
    b'NnY1MTJILTgxLjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0IiBjbGlwLXBhdGg9InVybCgjZm0tYSki'
    b'IHRyYW5zZm9ybT0idHJhbnNsYXRlKDc2LjMpIHNjYWxlKC45NCkiPgogICAgPHBhdGggZmls'
    b'bD0iIzY3OTdkNiIgZD0iTS0yNTIgMEg3NzJ2NTEySC0yNTJ6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJtMjU5LjggMTIzLTMyLjQgMjIuMiAxMi40LTM1LjktMzIuNS0yMi4yaDQw'
    b'LjFsMTIuNC0zNS45IDEyLjQgMzZoNDBsLTMyLjQgMjIuMSAxMi40IDM1LjlNMjU5LjggMzkw'
    b'bC0zMi40LTIyLjIgMTIuNCAzNi0zMi41IDIyLjFoNDAuMWwxMi40IDM1LjkgMTIuNC0zNiA0'
    b'MCAuMS0zMi40LTIyLjIgMTIuNC0zNS45bS0xODguNC05Mi40TDc5LjMgMzA2bDEuNC0zOC0z'
    b'Ny41LTExLjcgMzguNC0xMS43IDEuMy0zOCAyMi4zIDMwLjggMzguNC0xMS44LTI0LjYgMzAu'
    b'NyAyMi40IDMwLjdtMjc0LjItMTEuNyAyNC42IDMwLjctMS40LTM4IDM3LjUtMTEuNy0zOC40'
    b'LTExLjctMS4zLTM4LTIyLjMgMzAuOC0zOC40LTExLjggMjQuNiAzMC43LTIyLjQgMzAuNyIv'
    b'PgogIDwvZz4KPC9zdmc+Cg==', 'FM')

FM = b64_FM
index.append("FM")
index.append("FSM")
index.append("Micronesia")
catalog["FM"] = FM
catalog["FSM"] = FM
catalog["Micronesia"] = FM
country["Micronesia"] = ('FM', 'FSM', 0)
lookup["FM"] = ('FM', 'FSM', 'Micronesia', 0)
lookup["Palikir Micronesia"] = ('FM', 'FSM', 'Micronesia', 0)
lookup["FSM"] = ('FM', 'FSM', 'Micronesia', 0)
lookup["Micronesia"] = ('FM', 'FSM', 'Micronesia', 0)
details["FM"] = {"continent":"Oceania","capital":"Palikir","currency":"US Dollar","web":".fm","lang":"en-FM | chk | pon | yap | kos | uli | woe | nkr | kpg","tz":"","altname":""}
#----------------------------------------------------------------------
b64_FO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWZvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImZvLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTc4IDMyaDY0MHY0'
    b'ODBILTc4eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBzdHJva2Utd2lkdGg9IjAiIGNsaXAtcGF0aD0idXJsKCNmby1hKSIgdHJhbnNm'
    b'b3JtPSJ0cmFuc2xhdGUoNzggLTMyKSI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLTc4'
    b'IDMyaDY2My45djQ4MEgtNzh6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDAzODk3IiBkPSJNLTc2'
    b'IDIxOC43aDE4NS45VjMySDIxNnYxODYuN2gzNzEuOHYxMDYuNkgyMTZWNTEySDEwOS45VjMy'
    b'NS4zaC0xODZWMjE4Ljd6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDcyODI4IiBkPSJNLTc2IDI0'
    b'NS4zaDIxMi40VjMyaDUzLjF2MjEzLjNINTg4djUzLjRIMTg5LjVWNTEyaC01M1YyOTguN0gt'
    b'NzZ2LTUzLjR6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'FO')

FO = b64_FO
index.append("FO")
index.append("FRO")
index.append("Faroe Islands")
catalog["FO"] = FO
catalog["FRO"] = FO
catalog["Faroe Islands"] = FO
country["Faroe Islands"] = ('FO', 'FRO', 0)
lookup["FO"] = ('FO', 'FRO', 'Faroe Islands', 0)
lookup["Torshavn Faroe Islands"] = ('FO', 'FRO', 'Faroe Islands', 0)
lookup["FRO"] = ('FO', 'FRO', 'Faroe Islands', 0)
lookup["Faroe Islands"] = ('FO', 'FRO', 'Faroe Islands', 0)
details["FO"] = {"continent":"Europe","capital":"Torshavn","currency":"Danish Krone","web":".fo","lang":"fo | da-FO","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_FR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWZyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'FR')

FR = b64_FR
index.append("FR")
index.append("FRA")
index.append("France")
catalog["FR"] = FR
catalog["FRA"] = FR
catalog["France"] = FR
country["France"] = ('FR', 'FRA', 0)
lookup["FR"] = ('FR', 'FRA', 'France', 0)
lookup["Paris France"] = ('FR', 'FRA', 'France', 0)
lookup["FRA"] = ('FR', 'FRA', 'France', 0)
lookup["France"] = ('FR', 'FRA', 'France', 0)
details["FR"] = {"continent":"Europe","capital":"Paris","currency":"Euro","web":".fr","lang":"fr-FR | frp | br | co | ca | eu | oc","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_FR_20R = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc2Njc3IgogICB3aWR0aD0i'
    b'MTY3IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE2NyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQ29yc2ljYS5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzNjY4'
    b'MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzY2NzkiCiAg'
    b'ICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAg'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAg'
    b'IGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJi'
    b'b2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAg'
    b'aW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNjY4MyI+CiAgICA8aW1hZ2UKICAg'
    b'ICAgIHdpZHRoPSIxNjciCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZlQXNw'
    b'ZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXpl'
    b'UXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJP'
    b'UncwS0dnb0FBQUFOU1VoRVVnQUFBS2NBQUFCa0NBSUFBQUJzQ0xlaEFBQUFCR2RCVFVFQUFM'
    b'R1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFB'
    b'Nm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVcKaEVsRVFWUjQydTFk'
    b'YVZ4VFY5NitJWVNkVm1yWlFrSllaRkdJQ2xSMk5DR2hRRm1LR2xDa0tvTlZLWVd5V08xVUI2'
    b'MGRtY0ZCRk1UKwoySDVWb1E2cll0VlN0UU1xVUZuRElxQ0k3QVFDbWhCQWxrQkljdDhQZHla'
    b'dmpCRWlJZ1M5ejZkd2wzUC85enljYy8vck9RZ1FCQUVZCjd4bGs0QzZBV1ljQnN3NERaaDBH'
    b'ekRvTW1QWGxnTnpjM0thbUpwank5NGoxdExTMHlNakk5UFIwQUFEb2RIcG5aK2ZJeU1oN3l6'
    b'cmkKSGJQWGVUd2VtODFXVVZHQi9tU3hXRGs1T2ZuNStUVTFOUk1URTJ2WHJ1Vnl1U3dXQ3dS'
    b'QkpCS3BwcWFtcGFXRndXQ3NyYTAxTkRRVQpGQlE4UER3UUNBVE0rbklDQ0lJN2R1eW9yNjkz'
    b'ZG5ZZUdocnE2ZW1oMFdpRGc0TjhQbCtTMnhVVUZBZ0V3dW5UcDFldlhnMnp2bXdvCkR3NE96'
    b'c2pJbUo2ZWZwTjJQdjc0NDFXclZxbXBxVUZ0WHJ0MlRVNU9idDZ0MWRiV05qVTE5ZlgxS1Nr'
    b'cGJkeTQ4Wk5QUG9GWlh4aXcKMmV4ejU4N2w1K2MzTmphK0llVWlVRlZWUFhMa1NIaDR1SUtD'
    b'd3Z4YThQUHpVMVJVdExTMFpMUFo2ZW5waFlXRnBxYW1VakZFbGkvbwpkSHBnWUtDeHNiR016'
    b'TnRTUzVGSXBMR3hNWVZDdVhQbnpqd2twRkFvWldWbDBPOFRKMDc4L2U5L2w0WitXOGFzbDVT'
    b'VUdCa1pMZHJ3ClVGRlJzYmUzVDB4TUhCa1prVnpJclZ1M2xwYVdnaUE0UER5TVJxTVBIejRz'
    b'RFYyM0xDMjNVNmRPN2Q2OWU4K2VQVzF0Yll2MjBQSHgKOGZMeThzaklTRE16TXhzYm00Q0Fn'
    b'TUhCUVVsdUhCb2FDZzBOMWRMU1lyUFpPam82MHRDQnNzdVI5Zkx5OHF0WHJ5N0pvL2w4Zm45'
    b'LwpmMzkvUDQxR201eWNuRjNidUgzN2RtZG5KNFZDMGRYVlRVNU9ackZZVXVJa1dINWpmV3Bx'
    b'cXJ1N2UrazdUa2JtM0xsekw5dUVYVjFkCklTRWhuM3p5aVlHQlFVNU96bmZmZlRjOFBOelMw'
    b'akkxTmZYdmYvK2JTcVZldVhLRnpXWUxycWZUNlRvNk9zZU9IUk0rQ0d0em90aTIKYlp1VU9G'
    b'SmtaV1ZEUWtLRVpYdjI3QmtPaDB0TlRXMXFhdUx6K2REQjFOUlVlWG41bFN0WEVvbkVZOGVP'
    b'QlFRRXJGdTNibUppQWpyNwovUGx6YlczdDBOQlFPenU3OGZGeFdKc1RnNktpb2hVclZralB4'
    b'SVBCWUJvYkd3WGkzYnQzejh2TEt6WTJOamMzdDd5OEhBVEJmZnYyCnljcktwcWFtQ3IrRmw1'
    b'ZVhRTEh2Nitzek16TURRZkRBZ1FQSGp4OWZuRzVjWnQ5MVNJV1dIbm42K3ZxQ2dvTEt5c29n'
    b'Zzk3YTJwcEsKcGFMUmFDNlhxNk9qczNyMTZyNit2dkx5Y2dzTGk3S3lzcTZ1TGdhRDhlREJn'
    b'N2EyTmp3ZUQya0pjWEZ4K3ZyNmNYRngvL25QZjN4OQpmV0Z0VGd6NisvdVJTQ1NQeDVNZWtX'
    b'cHJhLy95bDc5a1oyY0RBS0NvcUppUWtMQnQyellaR1JsWldWa3ltVnhUVThOaXNTd3NMSEE0'
    b'Cm5KR1JrYnE2dXJ5OHZJS0NnbzJORFpQSlJDS1JDQVJpYW1xcW9hR0JUcWREamNEZjlSZVFu'
    b'cDZPeFdLcnFxcHUzYnExZi85K2JXMXQKS1NGZVFVRmgyN1p0L2YzOUlBanllRHcwR3Mxa01n'
    b'Vmk3OW16UnpERGQzZDM0M0M0TzNmdVBIbnk1T25UcDRKcmZ2dnR0MDgvL1JUMgowcndBTnB2'
    b'dDdlMXRiR3g4Ly81OXdVRU9oMU5ZV0JnUUVEQnZkK25DUWxOVGMvUG16U0FJN3R5NU15OHZU'
    b'eUJuVUZCUWNIRHcyTmpZCnpaczNEUTBOcjF5NTh1dXZ2OGJHeGtLaFB3aGtNdm5telpzdzZ5'
    b'L2d4SWtUaW9xS1ZWVlZZcy8yOXZZZVBYcDB5UjBnSDMvOGNXNXUKTGdpQzJkblpnWUdCQXZH'
    b'YW01dlhyMSt2cTZ0TEpwT3BWQ29JZ3BDaUowQlRVOVBxMWFzRk9qL00rbi9oNit2cjZlazUr'
    b'eldUazVNLwovL3l6dWJuNVVyRytkdTFheVBSaXNWZ1lERWFZeGFDZ0lNSHZscFlXRWNuMzdO'
    b'bVRrcElDKytGRkFYM0ZIeng0TU9lVlhDNDNLeXZMCjB0SnlTWWduRW9rUThZNk9qdEN3aHZE'
    b'bGwxOEtmcDg4ZVZMRXhFZWowWXRtcVM4blB6eUR3WkNSa1FrUER5OHFLaEkrenVGdzd0MjcK'
    b'ZCtQR2pkSFJVVUdJek4vZm4wcWxabVZsTFg1eXhOMjdkOGxrOHREUWtMdTcrKysvL3k3SkxT'
    b'a3BLWUdCZ2NyS3luQ2s5UVdrcGFXcApxNnQzZDNlLzZvS09qbzZUSjArR2hZWEZ4TVJVVkZU'
    b'd2VEem8rUFQwZEZKU0VocU5Yc3orUkNLUmNYRng5ZlgxdHJhMkFnbkR3c0ltCkp5ZWgzNmRQ'
    b'bjU2ZW5oWW9wRGdjcnErdkQ0NjBpc0xIeDhmQndVR1NLMXRiV3hNVEU3LzQ0b3ZkdTNlbnBL'
    b'UTBORFR3K2Z6aDRlSFEKME5CRlk5M0N3bUptWm9iUDUyT3hXQWFEQVFuMnQ3LzlqVTZuQzR5'
    b'MGhvWUc2UGZseTVkOWZYMFh2MHVYZ1pmbStmUG5qWTJOeWNuSgorL2J0UXlLUnMxeHBiR3hz'
    b'Ykd3TUFNREl5RWhwYVdsMmR2YXhZOGVnUWJabzBzckp5Y25LeWdJQTRPcnFldnYyN1lDQUFB'
    b'QUFlRHdlCmRCQUFBQUtCME5QVEEvMU9UMDgvY09BQUhHa1ZBeWFUcWFlbngyQXd6cDQ5dTN2'
    b'MzdvOCsrbWpPVzFhc1dPSHQ3ZTN0N1EwQXdOalkKV0dWbHBaZVhWMHRMUzE5ZjM4VEV4UFQw'
    b'ZEd0cjY5RFEwRnRTUWJoY3JxeXNyTHU3ZTBGQkFjUTZoOE1SSk44cEt5dXZXYk1HQUFBYQpq'
    b'ZGJlM2s0aWtaYWdUNlY4ZXVmeitmcjYrZ2NQSGdSQmNIQndzS09qZzhsa3pzek12R0d6TXpN'
    b'emQrN2NDUTRPVmxkWFg5aitWRkZSCmdTSXJ6NTgvMTlMUzRuSzVJQWlHaG9heTJXd1JHYUtq'
    b'bzArY09BRm5VSWtIZ1VDSWpJd0VRZERGeGNYS3lncVB4MnRxYW1wcGFYbDYKZXNiRnhUMTc5'
    b'dXhOR3ArWW1Nak56ZDI5ZTdlV2x0WkNFVzltWmxaWFZ3ZUNJSkZJcks2dUZySGNCQmFtbnA3'
    b'ZTR1dHh5NGIxSFR0MgpxS3VyMTlUVWlQaG9TMHBLRGg4K2pNVml2L25tbThIQndUZWNVVEl5'
    b'TWhiUXl2Lzg4ODlCRUl5SWlMaHc0UUlJZ3NLdU9naUZoWVZlClhsNUwxYVhMZ1BWTm16WkJX'
    b'aEtGUXJsOCtmTFUxSlR3MmJHeHNkallXQ3dXR3hFUlVWMWREYzJva21CZ1lDQXRMZTM1OCtj'
    b'QzRvdUwKaTZPaW9weWNuRkFvMUx6NVhyMTY5ZDY5ZTZGQmZPclVxWmlZR0Q2ZjM5emNMUEww'
    b'WGJ0MjVlVGt3S3lMeC9Ed01BYURFZTVXTkJvZApIaDVlV1ZrcGZCbUx4VHAzN2h5QlFGQlhW'
    b'OGZqOFE0T0RtUXltVXdtdTdxNmJ0KytmWFIwOU9XVysvcjZRa0pDTUJoTVVGQ1FpR084CnY3'
    b'OC9LU2xwZmdtNGE5YXNFUVRjVWxKU3hDYkZUazFOYVd0cmo0Mk53YXlMUjJGaDRhdHkzUzB0'
    b'TFJNU0VnUTJzV0RJMG1pMHg0OGYKVS8rSDJ0cmFXUUliazVPVG1abVpHemR1TkRNelMwaElH'
    b'QnNiaTQrUER3c0xlL3o0OGRUVVZGcGFtcjYrL3VzUzcrcnFDajB4SVNGQgpiSHJNdFd2WEtC'
    b'VEtFdmFxdEh0ay8venp6MWRWcWRYVjFVVkVSQmdZR0FRR0JoWVhGME1IRVFnRUJvTXhNVEd4'
    b'K2g4c0xTMW55Yk5UClZGVGN1WE5uU1VsSlFVRkJUMCtQbVprWm04MDJNakxhc21XTGw1ZVhw'
    b'cVptUTBQRFAvLzVUMEc1NU96bW9xR2hvYU9qbzZPakl5VHoKMDZkUHhkb0lCUVVGRkFwbEti'
    b'dFZ5c2Y2VjE5OUplR0xiTml3NGN5Wk0xUXFkUjUyM2NqSVNHVmxaVk5UMDlPblQvMzkvWWxF'
    b'SW9QQgpLQ29xMnJ4NTg1bzFhMjdkdWxWZlh6OW5wWktabVpuSXBPTG01aWJ5N1lDQXcrR0Uw'
    b'eTdnR1Y0VWVYbDVBcStXaEpDWGw5ZlYxYld6CnN5TVNpWnMzYjk2NmRldVhYMzU1NmRJbGdl'
    b'SW04Z1Voa1VnQzlXM2R1blZGUlVVLy9mU1RtWmtaWkJkUXFWUTdPenNmSDUvYTJscFgKVjlm'
    b'WkxYWElUb013TkRTRXdXQmVOdE03T3p2eGVQelM5cXEwczg3aGNJUUgyVmRmZldWb2FQaGEv'
    b'd1JXVmxaUXpkSEw0M3ZYcmwzUQpKQjhRRUpDY25Cd2ZINzlod3dZRkJZVnIxNjVsWkdUZzhY'
    b'Z295WW5QNTErOGVGRlBUKy93NGNQUjBkR3p4TWQyN2RvbGFEODJOdmJiCmI3OTkrYm1wcWFu'
    b'aDRlRXc2N05oZEhSVW1PYkl5TWoyOW5ZUnJWN0NvTWpSbzBkTFMwdWgrWDk0ZU5qQndVRk9U'
    b'dTcwNmROME92M0oKa3lmNStmbTV1YmxNSnBOQ29heGN1WkpHbzJWa1pHQ3hXREtadkduVEps'
    b'dGJXMDlQenc4Ly9CQ0x4WjQrZmRySHgwZWtmVFFhcmFxcQppa2FqSWUyeXZyNGVoOE1OREF5'
    b'OC9FWkVJckdrcEFSbWZUYnMzNzlmcEgrdlg3OCtQajcreFJkZnpFK1AwZERRSUpGSTl2YjJx'
    b'cXFxCkR4NDhlUFRva1llSGgrRHMzcjE3YTJ0cm9Va0Y4cXJXMXRZK2V2U292YjM5NXMyYkJ3'
    b'NGMwTlhWQlFDQVRDWm5aR1FJcS9kT1RrNFAKSHo1c2IyL244L25aMmRtNnVycVFYN2FxcWtv'
    b'UWJZUCtHL0I0L0dJbVN5MC8xbnQ2ZXJCWXJBaHRiZTN0ZkJCa01wa1ZGUlcrdnI3egp6a2M0'
    b'YytiTTc3Ly9Mcklpd2ZyMTYzdDdld0VBSUpGSVlrWGljcm41K2ZubTV1WWFHaHAzNzk2MXRi'
    b'VkZvVkJXVmxZYUdocEtTa29HCkJnYmEydHFmZmZiWmt5ZFBuajE3OXE5Ly9Tc3pNMVA0ZG05'
    b'dmI1RWpTd0twanJsRlJrYlNhRFRoSXpJeU1sRFlORFkyZG1CZ0lDSWkKSWpNenM3S3k4clBQ'
    b'UG52ZE9yRkRodzdOek14QXY0T0NnaVluSjNOeWNreE5UY2ZIeHlFWEczVHE0TUdEeGNYRk1q'
    b'SXkrdnI2ZW5wNgpPQnpPMk5pNHJLenMrdlhyTEJici9QbnoxdGJXQ1FrSmRYVjFxYW1wZm41'
    b'K0NBUkNUazd1OHVYTGFtcHErL2Z2THk4dnI2NnV0cmEyCkJnRGd0OTkrZS9yMEtSU0ZXMXBJ'
    b'TCtzMU5UV2xwYVVpQi9sOGZrMU5EWWZEdVh2M3JxdXJxNXFhMnNURVJGVlYxVHhLQXdXVVEr'
    b'SFIKL1B6OHVybzZlM3Y3bHBZV0JBS3hkZXZXVzdkdU5UUTBFSW5FdUxnNExwZmIzZDNkMmRu'
    b'WjI5djd4eDkvZlB2dHR6azVPVkRBRkl2RgpabWRuSnlRa25EbHpSbDVlWHVCVEdoa1pTVXBL'
    b'MnJoeEkwVDUxYXRYSXlJaVpuRTZ3Zlk2Q0lMZ0xJRm5hMnRyQm9PUm1abEpJcEZtCno3T1FF'
    b'QmdNWm5SMDFNbkpTVmxaK1lNUFB2RDM5eDhZR05EVTFJVE9PanM3RnhRVTFOZlgxOVhWMWRU'
    b'VVpHZG5oNFNFMk5qWUVJbEUKYjI5dkJRV0Y0T0RnaW9vS0hBNzNzditWdytGa1oyZHYyTENC'
    b'VENhLzdJMkh2K3N2NE9iTm14OTg4TUdyU0ZKU1VySzF0VjJvLzNzUwppVFE0T0FoVkc2RlFx'
    b'TURBUUNhVEtheml6WUlQUC94dzM3NTk3ZTN0RmhZV3pzN09jbkp5N3U3dUR4OCtIQjRlcnE2'
    b'dS91dGYvNHJECjRmejgvUDc4ODArcDZsNHBYWTJJUUNDVWxKUXN6ck82dTd2UG56OS80c1FK'
    b'SEE2WGw1ZW5xS2dZRmhaMjkrNWRTZTYxc2JIeDhmSEoKeWNuWnVYTW5tODN1NmVtNWN1VUtH'
    b'bzJlbVpuQjRYQ3VycTQ3ZHV5UW5zb3NBYVNSOWNMQ1FuOS8vN0d4c2JmOW9MUzB0SXNYTDk2'
    b'LwpmMTlkWFozSlpONjVjMGRPVHM3VDAxUENzbGtaR1pta3BLU3FxaW90TFMwREF3TU5EWTNH'
    b'eGtZOEh2Lzk5OTlUcVZSVlZWWHAxWk9sCmNIcDNjbkphbkhjdkt5dmpjRGhWVlZVQUFHemF0'
    b'R2xrWk1URXhFVHkyN0ZZN09qbzZMMTc5eXd0TFgvNDRRY2VqeGNWRlZWUlVYSDAKNkZGaEo1'
    b'MFVRdXBZdjNidDJxS1ZCS2lvcUZoWldjbkx5d01Ba0plWDk5MTMzNzNXN1hwNmVsRE5pcXVy'
    b'YTBSRVJFZEhCMVRuTmpNegpReUtSamg4L0xzak1oMW1mQTE1ZVhvcy80VGs3TzNkMWRjMWpU'
    b'ajV5NUFnVXd2SDA5UHpIUC80aDdFajI4Zkd4dDdlL2ZmdjJrbnZpCmxnSHJpN1AwSWhLSlBI'
    b'andvSjZlSGdBQXExYXQ2dXpzOVBQem0wYzc2OWF0NC9QNU16TXptcHFhWjg2Y29kRm9JcGFJ'
    b'aTR1THFhbnAKdVhQbnhPYnp3RmtWQUFBQVBCNXZZWmNFbmVWQlEwTkRrUEZkV2xwNjZkS2x2'
    b'THc4eVc5ZnVYS2xxNnZybGkxYlRFeE1Sa1pHWkdWbApyYXlzek0zTlJWYWxjbk56KytPUFB3'
    b'b0tDaDQ5ZWlUSXA0TzFPVEhZdTNjdnRITHZJa0JYVjlmRHcyTWUrWEVvRk9yUW9VUENZc2ZI'
    b'CngwZEhSM2QwZFB6NDQ0OWkzMnRpWWlJcEtVbFhWL2ZTcFV2d0RDOEc3ZTN0dWJtNUtTa3Bq'
    b'bzZPVW12N3FLbXBKU1ltQ21SKzlPaVIKdWJrNW44K2ZQVW1tdjcvZjBOQ3dxYWtKWnYyVjhQ'
    b'ZjNsK2Jna0k2T2p2RFgyc1BEbzZDZ1lNNlhTazVPaG9vNllOYkZvTDYrM3NEQQpRRHI1eHVQ'
    b'eEZ5NWNFQm15dGJXMWhvYUdjOVpqVkZaV3VydTd3NnlMUVZGUmtaUXN0Q3NXT0J4T2JEYjcr'
    b'ZlBuVFV4TXhDWnNDZERjCjNPems1QVN6TGdhTHR0N2V2QTIvSzFldWlKVzh0TFRVMXRiV3pN'
    b'enMrUEhqYlcxdEwxL3crUEZqT3pzNzJISVRBMHRMeXpjcE8xb0UKdysvNjlldGlUems1T1ZW'
    b'VVZGeTllaFdKUkxxNXVVRVJ2QmN5R21SbGhVUDdzT1gyLytEeGVGOS8vZlVDMXBrdU9Dd3NM'
    b'T1owdWsxUApUOGZIeDV1WW1IUjBkRURPNXU3dTdxNnVyblhyMXNHUlZ2RmdNcG5yMTYvdjcr'
    b'K1hUdkdVbEpSKy9mVlhGeGVYT2EvTXk4dExTa3J5CjlmVWRHaHFhbUpoQW9WREp5Y245L2Yy'
    b'THZRS1JjTFJRYWdkVFVWRVJuVTZYV3ZFbUp5ZFRVbElrdWRMUHoyOTBkTFNqb3dPQlFEeDUK'
    b'OGlRK1B0N1UxRFFqSTJNSmhaZGUxcUZpWUduVzZhcXFxa1NTT1Y4RkFvRXdQajQrT1RsWlVs'
    b'S3llZlBtbUpnWVFXRWUvRjEvQVoyZApuUnMzYnJTd3NNRGo4WklVRnk0Si9QMzlKWG1Ybkp3'
    b'Y1IwZEhIQTZucGFYRjQvRmFXMXZ0N2UxaHkyME9mUHJwcDlMSnVyYTJ0dkFhCmtxOENnOEd3'
    b'c3JKQ29WQmRYVjBnQ05iVjFiMHEzLzY5dHR4RUlCVTczNG5Ed01CQWFHam9uT3ZWbzFBb0dv'
    b'MTI5dXhaS0xiNzRNR0QKcGQwVWRIbXdMdUZHcTBzQ0twVzZaOCtlV1M3Z2NEZ0JBUUhmZlBO'
    b'TmNIQXdkT1R5NWN0TGtqeXlETDdyeXlnTW82U2s5S290VzhiSAp4NzI5dlVOQ1FnVEdmVnRi'
    b'bTc2K3Z1VHI1N3kvMzNVeW1TemxzNUc2dXZyMTY5ZEZ4SWJDcjBlT0hCSDI1M2g3ZTErOGVC'
    b'SDJ3ODhOCkd4c2JLV2Y5bzQ4K0VsNVViblIwOU5DaFF6Z2M3c2FOR3lKZStnMGJOaXg1RnVY'
    b'eVlOM2UzbDVxK1ZaVlZYVjJkaGJzMURVd01CQWQKSFkzRllyLy8vdnVYVjhmWXNtV0xKREY0'
    b'bUhVUUJNR29xQ2lwS0FvVVoxejg4c3N2QWpsLy9QRkhMQmI3d3c4L0NPL2tJK3lXMTlUVQpm'
    b'UFBsVU44WDFxZW5wOTNjM0Y1M2dacTNDaFFLNWVibUpyeGpEd2lDNmVucHMvaHR5c3JLM056'
    b'Y3BLRS9sODNPWGp3ZTcrelpzMDVPClR0cmEybUxIdmJLeXNyNitQZzZIVzV4WmZmLysvUzkv'
    b'bm1kZjVUOHhNZkhvMGFQUzBKblNHM043RlZnc1ZsVlZWWFYxOWZEdzhNVEUKaExLeXNwcWFt'
    b'b21KQ1I2UE56SXlnbmEyZjZzQ0tDc3JCd2NIbnpwMVN1elo2T2hvRlJVVnNXVTB3Y0hCQkFK'
    b'aCsvYnRTOStKNExzRgphREg1dDlkZHNyS3llL2Z1blVXQXVycTZsM2V1NEhLNXpjM05KQkpK'
    b'RXZjdDdKRjliYXhjdVpKQ29idzlEWUJBSU13ZVlJVld0aEd1CmltMXNiS3l2cjgvS3lob2NI'
    b'SlNTUEpGM2pYVUFBRTZlUE9udTdyNGdhMWlJWU8zYXRmbjUrYk5iRXdnRXd0TFNNaTB0RFFy'
    b'RjV1WGwKRlJjWFAzejQ4Tm16WjNRNmZjRTNJWmpualBYdXNTNGpJM1AxNnRYQXdFQ1IvZTNm'
    b'RURnYzd1TEZpM1B1QTE1WldWbGNYRHc4UE14bQpzMGRIUjExY1hLYW5wN095c3JxN3UwdExT'
    b'MFdXdklMSCtrSUNpVVQrOHNzdk1URXhxMWF0V3BBR1Y2eFljZXpZTVFzTGk5a3Z1M0hqCmhy'
    b'Ky8vL2J0MjF0Yld6a2Nqb0tDQXB2TnpzM04xZFRVYkd4c1hNSjlKZDl4YlU0RXZiMjlkbloy'
    b'czZ3WkxhRnBIaFlXTnVlekxseTQKWUdSazFOcmEydHpjakVLaERoOCtIQlVWNWVEZ0VCVVZK'
    b'VzNGek84NDZ5QUlzdGxzQW9Fd2I4b1JDSVNIaDhlY252UFkyTmkxYTlkQwptM0hQek15Z1VD'
    b'aGZYMTlyYSt1dnYvNWFDdnZrM1djZEJFRVdpelh2MmRYVzFsYXc3YUpZY0xuYzRPQmdFb2tr'
    b'WFBPbXJxNXViR3k4CmFkT21wWTJvdnRlc2d5Q1ltWms1ajB4a2MzUHpPZXZXTWpJeTNOemNP'
    b'QndPalVZN2Z2dzR0Q3VSbzZNakVvbGM4dHJWOThWZWZ4VjIKN3R5NWZ2MzYxN3BsMWFwVldW'
    b'bFpnclVHWHdVMEdnMnRiUFA0OFdNNm5aNlhsNWVSa1dGc2JFd2lrYVJJZlhzZmRIaXgyTEZq'
    b'aCtTQgpPd01EZzB1WEx1SHhlRW44TnMzTnpTMHRMVC8vL0RPQlFHQXdHRk5UVTBWRlJZbUpp'
    b'ZExiRitCN2cvSHhjUWwzRkRBMU5iMS8vNzdrCkxXZGxaVUdMbkI0NmRDZzhQTnpGeFdYZnZu'
    b'M1MzQlh2RWVzZ0NIcDZlczdwNGJHMnR1N3Q3WDNkbHVQajQzRTQzTmF0Vy9YMTlTa1UKQ3JR'
    b'aUdjeTZWQ0E2T25vV3lqRVlUR1JrcEdCejlOY0ZnOEVvTGk3dTdPeVUvbjVZZnBIV04wRjFk'
    b'YldIaDRkSWFiRzh2THkrdnI2VgpsVlZNVE16aWhPZVhITzhYNndBQURBd01GQlVWMWRYVmpZ'
    b'K1BJeEFJSFIwZElwSG80T0R3TnFJMU1Pc3dZTXNOQnN3NkRKaDFHRERyCk1HRFdZU3dJL2cv'
    b'M0duVHhobzkrTHdBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3T0Mwd00xUXdN'
    b'RG95T1RvMU1Dc3cKTURvd01Qa1UvcW9BQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01q'
    b'TXRNRGd0TUROVU1EQTZNams2TlRBck1EQTZNRENJU1VZVwpBQUFBQUVsRlRrU3VRbUNDCiIK'
    b'ICAgICAgIGlkPSJpbWFnZTY2ODUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'FR_20R')

FR_20R = b64_FR_20R
index.append("FR_20R")
index.append("France Corse")
catalog["FR_20R"] = FR_20R
catalog["France Corse"] = FR_20R
country["France Corse"] = ('FR_20R', '', 1)
lookup["FR_20R"] = ('FR_20R', '', 'France Corse', 1)
lookup["France Corse"] = ('FR_20R', '', 'France Corse', 1)
details["FR_20R"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_20R"] = ('FR_20R', 'France Corse', 1)
regional["France Corse"] = ('FR_20R', 'France Corse', 1)
#----------------------------------------------------------------------
b64_FR_ARA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTMzMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9yZWdpb25fQXV2ZXJnbmUtUmjDtG5lLUFscGVz'
    b'LnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9u'
    b'YW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2Rp'
    b'LnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzCiAgICAgaWQ9ImRlZnMxNTMzNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3'
    b'CiAgICAgaWQ9Im5hbWVkdmlldzE1MzM0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAg'
    b'ICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAg'
    b'aW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4w'
    b'IgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtz'
    b'Y2FwZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAg'
    b'ICBpZD0iZzE1MzM4Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhl'
    b'aWdodD0iMTAwIgogICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0'
    b'eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJl'
    b'Zj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFB'
    b'QUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpn'
    b'QUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFB'
    b'L3dEL0FQK2d2YWVUQUFBYwo0MGxFUVZSNDJ1MWRkMkFVWmRwL1ptWjdiOW5kSkp2ZUN5azBD'
    b'UkNhQWhiMFFMQ2NxS2VISjZLZURmUVV6dk9EVThSMjZ0MWhieHlLCklxaGdBMFJhNkFRSVNV'
    b'Z2hoZXh1eW1aN3RwZVpuZmY3WTBNS2hIaENRaEp2bjc5Mlo1K1puWm5mL0o3NnZ1OWdxSUtB'
    b'MzdUWWJocy8KcU1mblByU0krOUNpaS8zcVcvdWhiKzJIZzNvQ09FUmtoQXZqa3ZjTWhyQWZ0'
    b'TUlXTitzcXRXZTh5dmVMK2dqQnptYkJHVHNuVSthLwpSdVBHc0YvK2kyTkc3dEYyZnB3d2VI'
    b'MkNpMFdnQ0ZvRENhRWpTTXo2SnFuQ3dzRXhvQkU4WG1oZVBkSFlqMzRJWWJmK0dQK2pWaGpX'
    b'Cm41UG8ybmk5RHU4WHhhY1BxZDhzVTRUMTg2TDhQODF0RXJOQ0VjQUd6SkN1T1I3VjZHRHR1'
    b'Zm1zWTBuVjhuR20xOHVpanB1NC9laC8KVml2WnBoT3VtOVhzWEZMMThjeVdIM1RDRFdlay9m'
    b'UHZ6VExGWDhlWkhFdXFkdDE4dHJHRDlmSnhSUVN0Z1lTd3RKMDNRK09lRU8xbApZT2lwTVdZ'
    b'Y2c2TUdYditRcElnQ3Q2WTVDQXpkbnQ2Uklnb2NiZWYycTgvRE1YaHlqSm1Cb1luUjN1bXhu'
    b'cVB0L0FoYUF3bGhuREJZCmJ1RzRTUndBRGhsNE5JSjRFZG1QZnJ5UWJIVXpkUzRXQUdpZHJC'
    b'WVBLMTdZbjM2Q2dLUVJIRGJ3QU1BVnhNdXQ3SGhSTUlMV1FQckMKWldQTWt6ZWxGbTVJeTVY'
    b'Nzk3WUt4aXA5MXlXNit0Ry9MOGYyZHFXczZNdVVJclgza0lFblpWR0xjbXo5NkYrYjZCcXQ5'
    b'TTM3UG1HcQp4bE5wNWRoOHhMTFI1Z2hhQXdsaGppeXdZKzdaZng2UDh0dll6eVYyM0pkcncw'
    b'MXMrZ0kxMnRQSmNoSEFrWEdHZFRXU1JpUDdDYW5uCjdzd09VUnVidXZqeE1ZQnQrY2ExcDJX'
    b'SDdLelJVYjZWRTB4WnNrQUVyUUZPS3NyTjNLKzBJaGFDOTc2WEJpSDJGODBjRStDKzdtOXEK'
    b'NTMveEYyMHB3WjlqcVZGTUxFdm1qMEExSWxON2hHRUFnT0dSakhERVFrZ2pCSkVDMHVCQkdD'
    b'NnZvTUZsSVFBQWprVllPSEpaaUVHRQpoU01jUWdBQUlDSytjTVN6RUl2QU5FaStFQWJkRjlM'
    b'RC95bUxzUENYSUVRQWdFY002VWcycEZqRWtQNG1rb29JU3YwS1kxaXpNR3hJCkx5OHZsRlVm'
    b'R3NKTDZIOWt6ZitDTDhRaUxCelpFSVp3Rk1rTEJ6V3BRSU9lVktCSU9EUGlJOUpJbVh1RVF4'
    b'aU9TQ1BOcHNHS1NMRWUKZDdsTDNBUnE0dlZ4eCtWQkxDYlFyZW9ud01pNnNNa1BZaEtUVU4x'
    b'cXFNY2ZSZVFLSlJXVkFyUWd2NDhPKzZJMjVxb0dadGZYSStMUQp3dHcrQmxJOHJtTXUwekY3'
    b'R0ZJQUFDS0M0YUNtOWhjY3JtK2poeUhVKzJ2Znh5VE85NFVBa1g3aFlMTVFuUTloSjdBYnI5'
    b'UEhDWU1BCmNOZU91RVlIbTBCOVUybkxISzJTUndIQWpkOG1XdjJNODlSb05PemQ5Vy9Qa0hZ'
    b'UkpsTVdTSmNFQUNBOEY0SkFmVE5wbENJUXd5ZTcKT0gyZVdqZ2l2Y3k4MEpZOWNWRHY0Rzl0'
    b'WmxNWGk3RHpjcnVMQkNWZGtJVUpkOTdVbDNDWkc0djR3aXNKSVhtT2hseEdaOEJKMFgxZwpj'
    b'NkdFYUF3QWlONUlkM2J0STc3d1NrSVlQSGM4OWpuUVFtRVdvdk1Ta3ZPWlJTRU1BQWo2UEU2'
    b'SHk5d1JtQVlIUWdHejgzNWJtTjM0CkdNOTk1cDFqWWY4aFNkZWVZZGE2R0wyZ2RoQzlEaFdS'
    b'QVE1bnJsSjdHUmlpRURZL1AzQ1hnWWdpc1JvKytpU2FCSUE4aFo5L0R1QXcKQzg4enBCZWF4'
    b'dkVxMzQ5YTRkc2FVaFhFeGpweEh3R2ZxYWxxQVEwQWhWR1JvZHlEQTZGR1FQNXJXdHREZTJN'
    b'YmVQUnpLZDFFa2JCRApuOHhzNlhaeXFJK0VyMGM0MDJrbFZ4VzFIekx3T29CWW10NXJhUCtz'
    b'ZVBmdk16b2lPQTJXTDd3bjIvNzFEZHJwR2crWG9BRkF4cUh1Cnk3R1ZMRGpiY3dwRU9FN0Iw'
    b'Uzg0dEJ4WllQdmNwbW14bnE0dFBBYjlSS0Y1L2V4bVpxUkdPcWg1NGV3RTkrd0VOd0I0U0x6'
    b'TGVQWUsKTmNPKzhMenFURjlGbkh5RmY5dmNKcU9YY2RiQjRqSHBORWt3NGdXdmFHcmZKMzRY'
    b'eXhiUXhXdlhLaDZsNGxFUllJWXNxZWlMaFJnQQo0UFF2c3pBaXd4WENjR3Avc2VwTUJJRVJB'
    b'Q0gwa2RwSFpDUkJHTTdabmIxemR2YzVGOHdtSWdITHNJZHdndG9IQU85cXlHT2lUclRPCjhP'
    b'alZpU1FBSkltQ2tjaGxHRVdrRjVObnh4bjN0L0pzZ004cjhDdElqRWxET3hzaEFDYU9YcHJV'
    b'SGdGZ0JMQndqTXEzK1FaZHVQMXIKWVNJREd5RUFPWWY2Y0diTGpjbk9DQUFqZ0lVQU1GM2px'
    b'YnF6ZnJ0T1dHdGpVelNXTGcxY2wraUtwTzBqQ1VJQVlPTG94aVRualVtUgpHejRDRFdsRUJs'
    b'c3dhMWJSYi9zS1pSdVBSVmdZa1FpRS8wdFMzY1NsNmY4TkNPMkFhbUtpcXNmblZhdGx2eG44'
    b'eXVyRmQ3NzZPN2NYClF3ZysycDY4WWZmNThWdUlCbXFnbHphKzlJaFVwNUpqS1FsNDNWbU5w'
    b'UU1BL0FDY2Z2V2RCTlorNHl5K01zcU5RcXdvaFdMOG1FbnAKNmJXVmxVMkxIKzlUMzQ5b2R5'
    b'aWtZRENITFdBdFJxSktMOVVhNVZhWEFEQ28xZ3EvSzUvS0FQOFRIMHdyYlV5dGFNbTlzV0Rm'
    b'SFRPYQp1dlMxbGV6S24vaHpudWkxaXFmTEEzd3U0UGhRUUNpejJBMWo4MFo5djdINjJiK243'
    b'RHhRZW0xeDdyNWpVbDhmTXlVc0hKWjFhaEZ2CjRqaTNWRlN0MTgrZlAxOG9GQnFOUnFQUm1K'
    b'YWR6ZjNQdXdmdmYyUlN1eDJkRzMycWs0djlOMTh2blRwWnJJdzZzM09QNElOUFkrMnUKNFlO'
    b'Y2s0SHo3cmJDelljS21xekpOTEF2VkZoWGNwMU00RktKTzZRY2ErMGVIdVpraFF3Y3NrSEFj'
    b'RERIUHRrWUhoWnJOUkxHM1dLcQpYR0xyZ05Bazg0dzdYWmM4WFBiU0lSU0dhTjRQdTNjTCtY'
    b'U3NTb1docE9Sa3Qwd3UzYkFGQUJDQWJsUUdFdkxqRHAxa0FMU2x4azk3Ci9VVUFLQ2twOGZs'
    b'OFlyRVlBS0tqb3owZVQzTnpjKzNwU21tYzVveE1ic09ncUtxaExpazI0YzAxa21qMXlUWC9z'
    b'Tm5zY1l2L2FKV0sKUFN0ZTVLTmhNUmJ4OWErem45ODh6K1pUOWFORElZN0p4UUdBejQ3T2dY'
    b'YjhBYkl0d3l3MjhUM0VFM1c0T0ZTL2p4ODRMdUdkVXFpRApiTzBVYmRIL21ka2NkS1VOcVpu'
    b'TDhzVEhramE3d3VGV1NLWFNDZU9hOWgvMTRSQ25qT3EraklLYzhjOHNLMzMwcVpTZEI1Z0dF'
    b'd0M0ClhLNk1qSXpzN093dUhSYUxoUkM2YXVyVVk2V241R21wWXljWHRlMC9sSGJ0TmZMbzZL'
    b'TnZyTTM2YWhzQVZMYTBUZG55K1lFTlgrV2MKcmg4TytDMzk5RThJL2Jjdlp3a2g5biswOHpi'
    b'ampwZlZtK1piZUs1VnVSUWlSQmpHeERBQWFGRjJGQ3d4NFpjZGpmeHFDSnMxYXQrZgpGMlZj'
    b'TmU3NE4xdDVpcWkyTDcvTys4TkM5b3BsL01UNFkzOTZKRHFjYkFJb3Z2eE9QK3ZxOUJYTEdq'
    b'RWNxNnorWnRFU2h0a21vMUgwCjh5c29pbEtyMVFDQTQzZ3dHR3h1YmhhU2xMKzFWWldhb2tw'
    b'TjZmd2JEanNBS0VTajlEcHQ3WW1UN0RGNU1Bd2dYTDlud24rUEg5QUIKQUF4d2xwY1dQOXgy'
    b'M3dIK0Y0dTlIa09BekdCekU1bWNzSzBha0xrR3hGK2k0bjdWRGlHM1cvMVR5ZkhkZTRqQ3ZL'
    b'TGYzNVo5eXp3VwpteTNWeE5aLzgxMzhqN3ZaNXdaWWNFSzA5VWlwUHk4NzdlN2ZlNlVpdmxC'
    b'QXFSUXRibWZhakdsU3RRb2hSQkFFUlZGeXVieDFUd2xuCnl6WjFhY1dwdHBiRUdkTm9tZ1lB'
    b'emJneDJvS2M2ZzZyck5uQXV1dFdkMDJkdktMbTBxNlFlMHZyUUVINDNvNUNnME1OQUVCMVFN'
    b'Z04KdEFjd0JtQVhvUUhHQU1vT2lBVGFDN1R2dEUvVHhqRGV3ME1hbk5NaDhEbHUxREVuV3Zo'
    b'UkZKTjV4Vmtvb3dFd2pEMy9SdnFMTFI5OQo4ZFdDRForSXBCSUFDSGk5UERMVTg3bUtOcGdE'
    b'aTVmVkV4aUdRTG4xMDJTcFJDcnRmamVGeVdTeTIrMXBhV2tkQjQrTXRqZ3NiQ1pMCkxqT1pU'
    b'Q0tSNlBUK0EvNzlSMUF3T09iZ3ljYUM3S21aR2ZxS05VTk93U0NKR1cyYzhGTTh2a0J6OWVU'
    b'MEY5ODUrVXRFZEFOVEJUZ1gKUWg1Z1NYZWkyMS9nLy9DeXgwTGUxWmcxelR2RVNZWElZTTdZ'
    b'dEE1dCtTNk1Id0NNdi8rUHUwK2NLanh3b3FjYUcwRU1oYzVFaVdNRQovQ05yWHVQSlpNRVk1'
    b'VFYzTHRUcGRDNlh5MjYzNHpoZS9OcUxaVGZjaXYzdXVwVGI1d3VGUWc2SDQ5NjFMKy9iWFFE'
    b'UXBKS2wvdTJwCjB2V2ZwNWFmR1hJSVYzK1IxK3FNaDVBRmNEWVFQQXoraTJZMU8vR2NzZXQ4'
    b'eWNZRzJ3MHh5bmZXVFBFTzRJbGRZbzNVajJIRzJWTnIKQ0RScTFqV2pabDdkbWEwYlRZMEw3'
    b'azYybnQ4RjlPQ1lqYytKYy9sMEhLYnJrZnM0MlJsT3B6TTVPVmtpa1dBWTV2VjZkY3VlNWR3'
    b'OApKNlo0b2wvZm9uL2x6ZlNxUmhaQXZVYWxYUDFYajhsQ1BMdEc1YnYwNWZFdnMwWmFWaTk4'
    b'WWROMHZVbDZYRmVBZW81S1J4U1FGbUNwCis5N05Wd2NNTVREN0NGd1ptTys3cC85eDdYampF'
    b'TE9RZzFEQzlyMEpBRWN3M0I4TXBrMHFZaktaVXBXU3QySnA1YnJQRXl0cWhRZ0EKd01CaE9z'
    b'Y1hNdkp6aUdpVlhpeE96TTFtOC9sK3YxOG1rd0ZBVlZWVlZsYVcwV2dFQU8rV0gvMmo4dzNy'
    b'TitaV05RWUFsVSs5S3YrNQpaeHArK2xuOHh2dFIvcUY4eVloQ0hDaXB5VFc3TzZFU3NVM0Jn'
    b'TitQWWdGajRBenArTURoazFoY2tKQUF3ZTlNYTFFSUlBVGNWUERWCmdhY0sySEhBVGV1ZGNu'
    b'QmYzRHhqOXJqUEIycmU1QUIwS2hybXpocTk2cTltczFtbFV1RTREZ0MxQnc5Wk4yMXQ5Zm1t'
    b'TEY4YUFJaUsKaXVMeGVyME9LQkFJc05sc2lxTDBlajFGVWRiM1BzbjRjVzl0akFKRG9EVGIy'
    b'KzlmT09yM3Q1eFl0U1pqNTBIT1pWL2g1WGNxZmpxdQpldXFUT1ZFaTEzMHpEeFdtbWxadkxG'
    b'NjNkeExnVENERWhXQjRCZHVwcFFWV21nQUFDMDIvQVVVa1F3WVk2OXlsNnNGWEIrSXAzVnNB'
    b'CkFORG1KMTZlWDl3NkxDRHN3TEhnMnBkb0VUODVLOHRvTk1wa01xRlFHUDZwcnE1T3E5VVdG'
    b'UlhwZExyMDlIUVdpeFVJQkVpU0ZBZ0UKdGJXMUtwVktJcEZVVmxZR25DNHBrd1YvZWtKR2hS'
    b'd00zTGI4VVhHOHhyTHk1ZlRtZ1RFMUE5SnMrbnkzWnUyMktXNC9yOWFRcUJEWQpjdU9ieFJ3'
    b'SEZuSlREa0dzeGZjWGI0Q0RBUUE4NkUzWWlJOEZ2UGZycU9nZ09IYURlQnJnM1Eva2duRTdO'
    b'eTMvYm9ocnBKMDJuMG5ZClhuN1RxWkExamN1Zi9jRDlQcC9QYURRcUZBcWFwajBlVDNaMnRr'
    b'Nm4wMmcwQ0NFQWFHaG9TRTFOYlc1dWpvNk90bGdzRm91RnlXUTYKTjIwMVo2YWhuRFJwZWEz'
    b'dXpwdHpweFZ2ZTNaVlFNaFRNSEFBa0ZGRFB6Nmp6Y0pjdldtNmp4TG14aHNldVdIdkhkTWJP'
    b'ZXpPM01scQpZTFM4SFh1bWxwc01QQ0V3Skh3UGVHa2dUWUR6Z0JDY2F5V3dRSElOZFB3TTBs'
    b'bGRmWVZ0cDhacDI3WW54cEJEa0JkZVdHWlRkcmdZClpxdnFnWHVaUWdHRHllVHhlTlhWMVU2'
    b'bk15Y25wNjJ0TFNjbnA3NitQaVltQmdCc05wdkQ0U0JKMHUxMnA2V2xXYTFXRE1OSVhYUHcK'
    b'KzUyY1VNaklaU2YvN1NtbFd1Mm9yaFZWMXhrVzNDQ3ZxT1hSbHp1SStQTHpRaUdQZm5CT3hT'
    b'TTNsZDQrdGJZdzFjYm84ZGp6aExTaQoyT0VwRjdhYk1SR0R5SWh0bFJUcmoydnpReUdBa0tN'
    b'ckVBVU1CNVlTUEJYQWpnMXZJR2xPanI1bTlIVDc1WHZFZ1drMnljbVFjZVhMCjMxMC9uOFZp'
    b'c2Rsc2tVaUVFRnEvZm4xY1hCeEpramFicmJhMjFtcTE0amlPWVJnQVNLVlNrOG1FRUFxRlFz'
    b'eWN6SngySzBVUS9NVi8Ka01sa2paV252VjVQMU5PUFJmKzQyd01vZ0liN0tDa0dBM0I1VUho'
    b'Vmg3VzRSZDBpZmV6NjBrOGVma3NxOUFKREFtU1BWNFVSSWtCQgpRTjIwazFxVXB6ZklocEtG'
    b'UVlSY2RJaUpZemhnQkVCVWh5cytTSjArY0xDdG9xS0RSZ0sxTWo4LzMrZnowVFJ0TkJwRklw'
    b'SFA1M002Cm5Td1d5KzEyeStYeThvT0h4azJhVkZwYUtxREJkZWhZNG9iM2t5ZU10OWxzOFNr'
    b'cFRrTzdkL1diWkZhcWJseCtlblhqa0xPd2Z5RkoKTUxubzdOdnRBVW5BWFNxS1htQXFUSFdr'
    b'S3M5dU9UWTJCR3lnZzRDZkMyUVlNdkJXQVNzbS9DMlIwRSt2WVp0VURsa0NPUVFzckZMTAp5'
    b'eDY4VzN4b1crT3pqNTBXY2JzUythektPblNzTEdOTVlVWkdobFFxZFRnY1JxT3hzTEN3dWJs'
    b'WnI5Y0RnRUtoYUdscGFXcHFhdmhoClIrM3hFOEZBZ0hhNkVJRVRSR2ZLZFhUalpzT0JRK3Az'
    b'WGtsZnZpemhTSmwxMksrVndHUkMvblVlTmdjeGhSVG5YaDJYQXdBd3Y3aGwKMlp5dkFPZDIy'
    b'MUlBSUFSQWQ3LzArTEJUd2FVSjRvTlUzWEh1RUxCUTZmYkZIcTg0Y2JxU2lvc1ZYalZPZXVB'
    b'WURkREVJbHFtRldYLwo0MFZGbk1iajhkanRkclBaek9QeHBGSXBTWkt4c2JFNGp1TTRMaEtK'
    b'cEZJcE9sM0Q0UFB0ZXc4WXEydkdhZzBIU2txU2I1M0haREpCCktCeC8xeDF0cHlvTlQ2OTBq'
    b'Y29NaHNpb0R0ZHdabUdYaUVYUWswOFRNdHUvTEVtMmVlVzlsQUxOd0k3dk5HTVUvUkJUeDZF'
    b'WTFwT0MKSnBsRGszaUo3ZnhmSFpFNk9heU9HMmN4T0d4TFdUbXBhMDdPeVJISVpXZHVxdUVV'
    b'RjJWTkxlWUxCQ1JKV2l3V3Y5K3ZVQ2drRWdtSAp3d0dBbkp3Y0FHaHRiUTBHZ3hLSmhLS291'
    b'SVczSG4vdG43SHQxbEU2QXdBb290Vk1KdE5xdFNhbUpCOSsvVi9VcHEyY0pZdkVDcmxvClJ3'
    b'bU1UT0Z6NlFkbTdWdjJXZnA1V1Z5NFJRRUFKbHhwUmtGTUZoQXZyYzlOdS9TNUpiOGFRb2RN'
    b'VExsYzNESDVBWWx3eGoxM01abE0KQm9PaFhyUHFuR01nSFE2SFZDcEZDSlh2MjU4M1pYTFBm'
    b'V05qWXdIQTVYSlpyVmFsUmhQUDRpUnAyOEtWY2Q1WlhmWFJZNG1qY2dIZwo3QTg3SnIzMW1p'
    b'UW01c3dkOThXTTVGbHQ4eWJXcmZqQ0hRZ0plaUNJQTBMaFM2WnhqbzBiRk9WMnBLZGQxdHln'
    b'WCswTDQ5ck15ZHYzCmlaNTVnVlZaYytMZjc2TGVrK2hEb1pCQ29hZzZmUFRqaGZkV3Z2dGhh'
    b'MzI5d1dEdyszdXRPaUlVQ2pVYWpjUGh3QXJ6dU9kaTZ2aDIKSyt1ZVI1cXFhd0NnY00zS3hJ'
    b'TDhpdFd2cExXTjdKZS9Kc2NFUm1sNnR6bFJDTER1ZTQ2emFHUmxEVTFTWWVld3ZCS2hlRlEy'
    b'ZzhFQQpnTDN2dks4dE8xVzZjMWZOL29ON1hud2x1SGpwbklyNm0wNmZ0Unc3R1IwZGZmVEF3'
    b'UXNDY1FhTHhWSk9tYWpuZFk4OWtXRzQrZjExCjVTWDc0ekxTWFM0WFliSER5SmM0UmNmRmZt'
    b'SmhUdC8xelhhQnI3V0p1TklRTnN5YUVyTmpNeWlqY21mUFBQWFRUZ0FRTUZudUpjdm8KMWEr'
    b'VHk1L1BYLzlOTXNMWUdINktUZmpsa29NYnZqajl4dHBnNFB4V1EzUjBkR3BXbG5ObWNjK05l'
    b'ZnVQS3hjL2VXcmRaMEtoVUhETAo3N3dqZi9VMUVjL1hlMFAzRldYRzZxYk44eFF2TlFrVmw1'
    b'WDdYa3FCelJvWDNiUmtLUi9va3RNUEUvcldFbDJMNFZUNVRLY1huTDNhCllBV0JrUCtwNXpr'
    b'WW5nSHcrZnlGTVhmZE52TzJXM3A1ZGd3YnQrSXZKemtjNlE4L3E5MmR4cGFONFpyM1B6c2hr'
    b'WXk1OC9aOU8vZU0KMm4xNFJFUG9zUFdJTXhIWnM4VmZsTjZaOG9xRVYzejRVOVpIRzBVSUFN'
    b'REtaSGovdkVnNVphTDAyeDBYcXBtNExQdkRpN2hSaXFDOQpJNTlneUhPeno1dzVROU0wazhs'
    b'TVRVM3RqUGdGL0VuUExXK1lkWFhWaXVlejJxMWhteUFtUTlScmI5VWxKV1E5OVZocmFYbXN5'
    b'enRTCjhiUGpQSDJQVHBtM0dyaVpYWGplTUxaNnlNcmNvbk1Qall5a25QLyt3UC9HZTdHOUs1'
    b'a05BZzZwVlBEdm1GOTB4MjI5Nkd1MUVnVEIKNS9QTHk4dlQwOU81M002VU5yWG9xdmp0WDFW'
    b'KyswUHcwMDBaZFZvQWtBZW9obDM3MHYvMjlObWlzZkRUU00wcnFyNlVsem5UdXhmNwpvR3pB'
    b'enc5L0hKdHdjczZFZ1pua2ZGazFVZ3dnS1JnUzk4YXZWTUlqbHk1UnJQNnIrOXdxbERSTld5'
    b'eVd0clkybjg5SEVJVGY3OC9QCnp6OTc5bXd2Mzg1aWpWa3dML2ZqdFdWRkJYNkFFQ0JhTGdN'
    b'QXE0alhjUFdrcXZGNVErSVgzUTU4Mitxb2tpVXBsYXZqVFBwZjk3aWYKUGNacFBTNnJ3WEk3'
    b'di9zYWdKTnk3cjZGbnB5N2F4aTFmQytVRUtBQWpiVHg2a2s3dnNFd3pPLzN0N2EyNGpqTzQv'
    b'RkNvVkM0Mk4zZQozcDZmbjkrMXk2R1MvYTdYMzQ1L2NGSFd6S3RQbHh5Z1BKNjgyVFB4SG9N'
    b'c2ozMjhudjNXUjNHZVh6MEM0M0w2aFZZTHp1ZlQ3UTFzCnhndTVMcmtuNXU5MVlsbC9vUWRK'
    b'Z2I2UmdSd01mNWxZY0NCNkJhN2U0THkrMHdzNjlvTmtSbGp0emdsYjEvOWwxMERkN1lIcFZM'
    b'Z1oKdURZbHJpa2pLWWhoSkVJRVlEd2NUMmt4bG43eUtRQndPQncybSszUXR6VFgxZkY0UEFM'
    b'RDlDVUg5VHQzOXpTd1BKRlFYZCtFUGZOOAoyYVp2Y3FkTXpwdytOVnhmTmJXMGxEeXk3T0FO'
    b'dDRTc3RyWjdieThYODY0a0MrVUttc09GeEZHQmpuU2J5aUxTcmxQMXJ4L3dZdDdqCkl1YS9N'
    b'bU4ySjV3VUJqYzRyejNuRmZlQnFIT0o4QnNFMzY2Nlk5OEFudVFBVE5TMmlBWEdSeGJselo2'
    b'RnlPQ09mNjVWaDdCUjMrNEUKQURaZzVNY2I2RDhzeEhGY3BWSTVUT2IyNWF2YzFnNXhJSmhN'
    b'SWZxZVczb1dCT3hubTNKcElMd0IxOHBYU3c0Y0ZzeWNSZ3Y0b2ZJcQpZc3UyWEtNVkFLQnA0'
    b'NUQ0czRBZmRQWE1WaklZQTZBNnFta29jYVpPOFZ4TVdTQkNveGJhYW5ETStYUDBvK2JyT2hu'
    b'aVBBRDh2SERMCmZwNXcxLzNKdFVseDFQQ0NrT3QwcGE1NjNmRFN2MC9QS3I3MXBSZXF0Kysw'
    b'Yk51dElFTUJSSHVTNDhQR2tLSW9UVXB5YU9VeitKSW4KWXlnRUFFUjA5eE5OVVJRMHQ0WVgr'
    b'UkxTS0hmbkFkaDVZTWlERVlTZzZtc0p0aTFhN1JKYUF6NHQ3azlrY3VBL1NRWjFYWFI2ZnlP'
    b'eQpUcm1JMThqeExWUUNBQUxIWHVCbUFsTUpBSXVFMy81ZjBPNHA3aGpZODd4Y0NFT0FUQmtw'
    b'Qmo0M2F2WU02VHNmSDF6Nzd1U0hIMmhPCmltK3NyQmJHcXErWk1DRVlEUHI5Zm9JZ0FvR0FL'
    b'akdoWHNDTDhUc0FnTFozWGtrZ0VFQUlVVnd1aFJCak9LMkdYMXZCWkNDY3luVDYKeWpnWjBC'
    b'azh5MXc4OHh2SitKT05xcVMrbTN6ZkhveDU3TURkSmxkTVorQWlMQUtjdzZhOXJ5bSt2TlZO'
    b'T0lpUXFuQ0FjNlRMSFhpaAp1MmJ5NkkvZmRnVDlWOTF4dTNUTzdKaUNQRGFYSzFZb1luT3lG'
    b'SEZ4R0lZNW5VNlJTT1N3MlFrbWc2WnAyMWRib3p4K0FHaDN1K052CnV6bGNiQ05KVXBXWjNo'
    b'U3J0SW9FSG90RlBLQ2pEaSs1MlJTbHBoWFpQdVZFbHluR1FaWkoyYUhPTWhqZngzWWVrWmdF'
    b'WGtWeXIvTTAKV0ptUHZqdDl4UmQzdVFMU0h2RWlJNFZiKzdYd3V4a2VOZzZZUGRrZVA4YzJ2'
    b'Q0RVUmtmWjMxdG5yRDdqeHJIV2trTXAwNmRnUFpoawpibXZiK2U0SExDWmoxNnR2WU9WVmRy'
    b'TXBWSFZHNmZZQkFHYnY4RjkzdFVncWFXblNxbU5pQ0lKSUhGMmdtVFdEbUQyOTBlVXdKc2Fp'
    b'CkpqMGZEU1dFM1RGdEhHV1d1T0dVaEVsM29zZ05NdGtuRlBVVnJBNUVzcU9vcG5iZVM1dkdQ'
    b'L3orTGZ2cnh0TUlZOUh1RUI2dS9hSzUKbzMvKzhQR3YrZnRrZkpJSkFPNGtoM0x5QUMrWU5H'
    b'QkpSYk9BRzdodjRlZy8zbjFzL1liUnR5Mm8zN09QTkZ2cTl4OWl4V3VFVzdkVApjdG5vRmxO'
    b'UE85a2dGK1Z1MjZ3L2VVci93cXU1LzNvbEpyMXp2R3hIUndlUHl6Mzg5NWZTdnQ3T0dZZ1RH'
    b'NmdWTHhyMzg4bDFpVW9YCi8vd2lGQjQ0RmhCWmFENEdTSWdGNDVGclNhajRMQ05KeGpXdnZQ'
    b'WExoK2VlQVlEYW53VGlqekxaQ0cvTE5PV3UxQTR2WDlqSk5ya2sKdFBRQnU5RUVBTjZQUHRz'
    b'ZThCTTBuZm4rQms2U3B2aHdPUTJBdDVyUG00a1ZHcE92UFg3Qzk4THJZMXROMnNXUEIxOWRs'
    b'VGhtZE5nMQpDb1ZDYUc3bHdQQ1NsR0tQTzY5Rzk2TWtkRnpHYnVOSDBaMDlsaEJDYzVnQmdN'
    b'NkU5UTJmNml3amFYUjgrWWQvM2xTUTJrbTR6Rm51CjArNEcvcFlFYnFQWVlpQVUwYUZoWkVq'
    b'RFlyL3RKczNWMHl5ZmIyNytmcnRhYjBoYy9rVEhrUk1wNVRVSmxnNjR5QXNJSGUxRytuQXAK'
    b'WTB4Qks0Y2hicmRZclZiTjliTUF3T1Z5aVVRaVU1TldkdkwwMFByQ0M0WEZRY3BSdmdaVENM'
    b'K3B0VDZ0dlNYT3BtTzdsVjRlTDhqcQpDdTRlSnNkTUxqaTE5ZGt2RTlXOWVoVEtMRDgxMXVy'
    b'aGtrWUx4R2FRdzQ2RnREL1E5UGd6QldlMFBneE1ELzZCMDlvZXYrZGcvN3VJCkE2UitickU4'
    b'S2NtaUVNYzgrb0JRM3hMTzhibGNyc2ZqVVV5YVVMRjlWMTZMYVJoV1BqazJydVFmeVhHaFBp'
    b'WUc3ZzV3b3RQTjY1ZDkKS3hIMGtmbEZ4VkZSdDFzRy9Id0d4aGRhMkF4NWdNSUFYQXpjcW9x'
    b'S2FqUCtZaVRTSmhiU0djazJzOWs1ZnZSTnp5M3YyaDcwKzJzcQpLM1YvZXpIUjVkWFlCc0R6'
    b'RDhicVQ2WTJ3cnhYUXU5WHhOckVQYmYvazVMZStlYitWTTBWYmEwTURBc1ZnYzZIVGtqUnd0'
    b'WmZuZ3VoCkhWOFEvZnh5dVZLNWUvUFhzMjZlMjdXOWJQdU9nTDdWL2ZaSGt3UERlZ1N3TWlh'
    b'a3ZNTkszbUt0K2xTQnRxdlpGRVBOWUFGQVhFejcKRmNZUHJ0aEtpT2VYZzNWNng2d0Z6VHd1'
    b'YzFUbXh6L3V1UGY5dDJ4YWZkRHRkcmc5TVdzL1NTZEh4anFYVENZVTNHc3AwM2hnZlFvRQpX'
    b'QUJRZ0h3VUJZd3JlMU1ISnB6NTFlVmpqNDhQbUl3TXlkcU0xTyt1MWRhZWNYMzluWGZ6VnNt'
    b'MVZ3ZjBMUkxqUURxTXdSNUhHcDFDCkJUTWR0aXFld011V2Vqa05aN0dBM004Vmh5Z0tXdlc0'
    b'UklwK215enNybWpJeERNZmVlalEzWXRUU2l0SUFqZVJGSzlKRHlOTllyTUMKZ2xWMTJzK2pK'
    b'QWRqNGs3RmtHWFJqWGhBRjIzUFcyd0VHUFQ1clVPOG1HVUhrOUcyNHRIMDUxNWxZSmlGd3dJ'
    b'MlMrRndEK3hmWE1uRgpMTTBHd2wwaENEa1pFTzlKSHVmSHI4Z0tkME8vSHFsV3hFOTBlZ2J2'
    b'K0pIMVNBZGRCaFcvL3dYNWY0VWNqUkJaMFJXTEFBQUFKWFJGCldIUmtZWFJsT21OeVpXRjBa'
    b'UUF5TURJekxUQXlMVEE1VkRFME9qTXpPakUwS3pBd09qQXdpNjJ4OGdBQUFDVjBSVmgwWkdG'
    b'MFpUcHQKYjJScFpua0FNakF5TXkwd01pMHdPVlF4TkRvek16b3hOQ3N3TURvd01QcndDVTRB'
    b'QUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxNTM0MCIgLz4KICA8L2c+Cjwv'
    b'c3ZnPgo=', 'FR_ARA')

FR_ARA = b64_FR_ARA
index.append("FR_ARA")
index.append("France Auvergne-Rhône-Alpes")
catalog["FR_ARA"] = FR_ARA
catalog["France Auvergne-Rhône-Alpes"] = FR_ARA
country["France Auvergne-Rhône-Alpes"] = ('FR_ARA', '', 1)
lookup["FR_ARA"] = ('FR_ARA', '', 'France Auvergne-Rhône-Alpes', 1)
lookup["France Auvergne-Rhône-Alpes"] = ('FR_ARA', '', 'France Auvergne-Rhône-Alpes', 1)
details["FR_ARA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_ARA"] = ('FR_ARA', 'France Auvergne-Rhône-Alpes', 1)
regional["France Auvergne-Rhône-Alpes"] = ('FR_ARA', 'France Auvergne-Rhône-Alpes', 1)
#----------------------------------------------------------------------
b64_FR_BFC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTM0NyIKICAgd2lkdGg9'
    b'IjE2NyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9yZWdpb25fQm91cmdvZ25lLUZyYW5jaGUtQ29t'
    b'dMOpLnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9y'
    b'Zy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlw'
    b'b2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5r'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9z'
    b'dmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMxNTM1MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2'
    b'aWV3CiAgICAgaWQ9Im5hbWVkdmlldzE1MzQ5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIK'
    b'ICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0i'
    b'MC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBp'
    b'bmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIK'
    b'ICAgICBpZD0iZzE1MzUzIj4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE2NyIKICAgICAg'
    b'IGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAg'
    b'IHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6'
    b'aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFL'
    b'Y0FBQUJrQ0FJQUFBQnNDTGVoQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFC'
    b'NkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxS'
    b'MFFBL3dEL0FQK2d2YWVUQUFBMgpGMGxFUVZSNDJ1MWRaMXdVMTljK3M3MEJTMWw2NzRoMGFT'
    b'cDI3RjBzc1Jjc2lVYU5zU1VtVVJPVGFLSkpUS0tKR3J1Q3ZhQ0lCUlVVClVicjAzdnV5TExC'
    b'c2IvTittSFZaRUZZbFNuei95Zm54WVpnOWMrZk9QSFBQUGZjNTU5NkxpSTZjRnY1MEVGNWJh'
    b'TnMyVU9hRnZWS3QKZGZBRUpiZEZ1dzR4d0ZmbnhPK3ZMRXJ3elY1SjVKVlhxdWsvdVlYb00x'
    b'L3pLWlQxalFtLzdoZ3k5MGhjcmUvd3EzLzBwR1pDNHpZcwpIWWNkYjN1NjZydTBKVDFwem5l'
    b'Sk9SMjZBenNPdUhnaXBkR3RKODJUb1RzWHV0d0NnRFlwZzNuNHZwWksxaTJaWUVibkFNRGww'
    b'dUZoCk1idDdVbk0zS00rWk93YzdYaFczOVZET3RKNDAxM21kK3lYa1p3QWdVTUxuQThBYkFm'
    b'Ly9YWlQxamJ4RnE0WFdTdmkzQ2c0QUtPSHoKYVJzKytsZEJycXlwZXg4cWc1ZTEvV09vcTRE'
    b'LzlLUC9JTzhENFhJRTJNSE5oOUk1K0sxNGhRQUE4SEkrU2RyVTE2Z0RBR1haL3pqdwp5cnFH'
    b'OTZHVlYyUVZIYnFJM2s5Q0pSTEZjRSt1TVNmYWtIMXpiUE15RkVYNnJBNEV6WDhveStZRGdI'
    b'RGZ3ZjlOeUJldjZRUElFKytTCmFHVTVRSGNEcFJ4d2hKY1ZuUHhjS1ExMVRCMmdVWlg2Qmcx'
    b'bm1JZGk4eTNUMkQ0eXZKRmF4MFY2WTRwMWJFNDJ0NGlBU21VZ1pTcmYKSWVyL3E4QjNDM2t0'
    b'bjNVd082eW8xVXJMaFVJNTVXQzJhc0NTMXVTbVJiT3cxZlpnZGxoTEhWOGFYYlZVR1ZuSFFp'
    b'enlzb2w2MXZjOApsM1hSVE9JTnRlWmtJZ1FCRGxFWXRJb2tNckNuRk9aSzlZR3FVZ2hRbkl3'
    b'T1AyU29veWl1d3BrYUlqcDAySEd4VVZ1WElkRlJWektuCjJVR0xaaWJIR2RQczVtT2tMSnNQ'
    b'Q0NMY2UrQi91NVVYdDFudGlWK2gvZHAyS1cxMS9LYlh1VXRLb3h2dVVaNlZzQ3FIU1V6Lzdr'
    b'YlMKNlZnN3V3cHVTdVU5Nkl5NlhGS1RuUnRzM2tMR0s4WU14REYxRUU0ckdERlI5cm55S0E1'
    b'V1hkbEtqK3NHRE1Ya0F4TmpoTXVOMFlLagpvL2N0SFZyNnk0bHNIdDJqMjF2WEM0eGVzNUp4'
    b'dGI1eHRiN2RvdzRBbEtYemxGSjUyWi9uWC83SnVGMkNxMmtBQUR4T2dRQ2dLS0pBCmNkMVVC'
    b'YStqSUtIWXNTR2xqVXFRS0ZCOGc5QVFSVHQwcUFvaXVhYWhrNWVCb0RoRUNRQUtGS2Z1NTFy'
    b'RTBFcnFPaEFuNEJRbU5DNEMKYUp1VTBTNmxBUUMxbm9NWGlMdW9vYTF0b25WYmxmV043L3pq'
    b'a3JiamVkV2gzakhyUjBwVGluVi9XWnhCSk1BU25xdW1paGNhRmNiOAp4VlNYejlLSFFUNDRw'
    b'ZzRBZ0JFVEFNRFdSRXFxYjVJU1dYaGg0MGpYdW9lWjlKdXlUNEZHcXdmVHEza1B4L25jdHNR'
    b'WDVvSEh1N0x3CmFpR0ZUZmJJNk4vTkR4a0FHYlZ6bmUrY0hmMFZBTWhSUE92SVBaNlUzbFhO'
    b'VmZYMXNhZ3REVXZIWTFndWp0NTNzM3h3SjdWdmFqWC8KUzUrendNZW9DQUIrejV5OTd2R0dG'
    b'NmVIUStEd0xzWHZHZmo3WnQvN0FGRFB0Zk9JT0FjQXNMOE5vT3RBYUVsOXd0NCtnQndBU0Rx'
    b'SgovdXZOUkRWdWhPd2gvVm9CUUNDQ20rMHpRVWZqRXhTd3crY0tpSGdFUmFHV0RRWGw2R0Fm'
    b'MVpjOWR6ajNTdEVmbDJWZktTaUdPYlZNCkIrTjJ2TFJOUWFRQmdBR0ZLNUpBazh3RUtQRE9V'
    b'ZGN1OXJvcXRBaUl3cExSbU1lMTcxbXpEb01jQUJ4MGExNVZyTW9PTytpOVNsT3YKOWpVMVgx'
    b'L0tGMDJqRTBRQWNMWm83Q2VQMS9lazVtK1NIejN4RSt4NHhjUFBycFVOVmY5MG1icjMwYTMw'
    b'dTVTTjN2WUNPaFZXT0I1ZgpQL0ViQUpBcm9OK1pNMW0wSmR1dnBKb3gyazVYTDVRb0NNZEdm'
    b'c3NYaWhnMDFiVi96bzZlbVJxcjcrU1JtR0U3eGpmRFdKbGJEMlpXCmt2anc0TXhMejh5YXFB'
    b'RUFRTVpMcXhkUHh2Ui95NXI1VGNxeW5pbzUyanJwVE9oMjdEZ3M1dnRIZFQ2dmkvcDRtMFF5'
    b'UVhxOWJJankKaFEwUE1zM3hOODY3VXhWVUl6REd6aWhRWEtQUU1NQTR6MW0vTXJwaVVJdEVG'
    b'enR2eFdpY1l2OG9sMnRmM0dxRm9naUNvQUJRSjJEWgo2TllQTmN0SWFuUXZiTFZSOVNZRTZR'
    b'S1hXMjFTeHZXeUlUVjhscDRCSHdEcWhVWTZKT0U0bThRbWtmN0RHajkxbFNiWlBqWm5jSzZW'
    b'CkRhM2xxeXBRSjJUaEVPVUl5elFEU3R1MXNxRlNCVkZsVG8yS2gxcWs2N1lUWHg5MVl5cVhS'
    b'aEFEZ0M2UnIwV05pSk96cUNxeW1ZS1gKZHZtMWllSjdNY1BWMno0TkFCWUdGVFRVU0QyY0VJ'
    b'VVNIQi8rK054djg0bTJMY09xYnN4cnVkOG80UjBUdVk0T3lGQmZtRitHRWtETQpKTGRWOFIw'
    b'SmVOQWp0dk1rNVQ4Ry8ySmpMRmw4YVR3UXlBQ0FJS0MrTllNbzBsSkpNazZxMWlUaDVhL2Ix'
    b'bkdJTW5yU0p3Q3dLZkhqCnZlbnpBY0NVMXZ4bytrb2lUaTVWRUZjKzNDcEg4UVJFa1ZEbjlZ'
    b'WC84ZlZla1FCd3R5cHdUTlN2Mk9YWEoyN0ViUFZ2V2JQU21sd0gKR09lTDVTUVNYbG80YnhZ'
    b'WkwyMlgwaXhPUkdQOThjNkF3NXQ5VHdOQUd0djFWdVVnZDROeUFFaHFkTStkTzhlSzBRZ0Fv'
    b'Ni8vZHE4NgpBQUJHV3FaRVRkd0lBTjhHL2JIMTZScnNSamZLQjkrZXZDN1VLaGtBZmtoZnND'
    b'VnhEUURRQ09LRUdTc1lSS0ZJYkNKNmJ0Tm5ubVAvCjlEOERMTkkzTGM1U0RjQ3NaUEdwME5v'
    b'T1RCMGdXQWVzZVBLVklTaXJtSTRuN1Vhd0RaMjN1dTNWdkRiRUYzbVFqQklKQ0l2U21waXYK'
    b'eTVZWTd3bllObnRnM2ZKamc1NGc0ZStLcGVsSkxPaVljd2wwb29pSWt3TUFDUy9iTjNqLzdj'
    b'cGdBSGphNElsQkRnRG1qQTUyU1krawpZcUErOXJ5UVVPY0ZBTmZMaC93MjVDY3lYZ29BT2lT'
    b'aERsSHdRbFBWc1B5TUM2aDRDWW9pRFVMREdmWVBNTWdCd0p5dUtwWko1cXZkCncyVnUxMHRh'
    b'clFCQUlpZGlrQU9BK1l1cUVuRnl6RmJqQU8xVHBwTnBhOFVWbkwydVArdmdDT3pNMEFISXN5'
    b'eVUwd3FOVE9YQjBOKy8KQ2Ywank0MnhZZERCaDFOWGJKK1MwZVZ5QktDK1FSSmtuci9seXNE'
    b'ZHdiOStOS3AwOVVuL1k1d3RnT0Q2RHZXRWVpK1prbkMrZUJUMgpiMm1iSldac1A0cmJUTVRK'
    b'SzNsbWNoVHZ3S3pKNDlvZnpwMEdBR2NMeDZxdi9TdHZNZ0RzU1YrWXk3VXpwVFdqS05Jb05D'
    b'RGk1TnVlCnJnS0FoelYrZFFJV3BubXFjSUpVUVl5cERJNHNIajNOSWY1NXM5T2RxcURSMXNr'
    b'L3BDK29FN0NheFhveGxjR1k1dDNxd0twMlU0NlkKK1duQ3VrQ1QzUGc2bjhKV213bTJpWGVy'
    b'QW05VkRsU2l1TWlpMFpobW01UnhzV1FrQUZ3cUhkR1hxR2ZaajkzcGRuWk5TMHc4ZDBSbAp2'
    b'Y3BUR3pzSXlTOURKeHRHR0l0U0FVQkVzV2tVNkg4ZTRWTEw2ZFQ3S0pXQXgwTitnV0REL2FX'
    b'TGd2UERoMWVzT0RFd3B0VFhRRjcwCmJybTVUcFZBY1hHMWZsc1QxenhyNlBEa0owWHZXOVgv'
    b'eW9PYUFUdFN3ajBNU3h1RkJ1NzZwZlB2ZmUxdVVQYXN3ZjFFd1VTMTV2ZXAKaTh2YUxFUnl5'
    b'b1hpVWIrRTdHdVZNa3hvM0IzSjRRK3EvWWw0K2MvUDUzYVFXZlVlZ3k0ZkdXS2VjU2huMnRP'
    b'd3BiWHR4Z0RvN2FxZwpyNUpXVUFtUzN6Sm5za1VHNnRGejRNVmpIM2xjUHBRN3pkMndEQkNv'
    b'YWpmeE1Dd2RjdVhQY1Bmcit6UG4zSzBLVkJlN01IYjdvenB2ClZpc0NVTmIzSklGQ0p2djFy'
    b'c3UrUlFWcTYxM1oyTFRLL1pNcno1MVJISVdGYTk2NnVWaVgwY2tPVlRWQWVTMzA2MGVmSWtr'
    b'SUgxRzUKS2RMM0RudGNJT1BjSmZMOHZrTWRRZEF2bjYzc2NsSWdvKzdMbUtkSDRvKzJTbVpS'
    b'VzdoaVBiNk1PdGZwN3FiRWoxOHU0WHh4S0FEOApQblF2RWFlbzRaczQ2dFhva0lRSHNtZG1K'
    b'RHQzMFV4bHU2V3kzWmIydTlFaTFiUFJiYkNHaGlhaHZxZFI2ZHBIbjNiUmJCQWFmcFcwCndz'
    b'dW8ySWJSd0tLMUlBREZyVlpoamc5MnB5M3FvaWxSa0E1a3oxekdmL1NQVUVQTnJQRkphVWRo'
    b'RWVTVlFsTUxTaVFBSHFUeHlialAKdzNKN3VzVFdIQ3JNb0s1Wjh1MzBsSWZaQmpkS0F1ZFlI'
    b'YjllSEVqVktSTXhYTjh5NnRJN0Q3cjlRY1NYQUJoMysxT2JsUEZOeXJKSAowMWZpRUdWcG0r'
    b'V09GRzIreHJhbnEzTG1mbURKWU10UmZPQ0Y0Mkk1cVNmTlkzbVRKdGc4R1dLZUFRQ2Y1cS9U'
    b'a3BpUXlYRzZYRHI4CjRMQWZBQ0NtTXZoUWJvOTVCRVltK2lUNzdvMjhpWWpWcGRPL1dUNllR'
    b'cEFBUUFiSFJSc0RLdGFKS2cvQmptdjQzYjhpa0V2QUlpQWgKaTIzS2xKcXhFRnR6R09nTjBM'
    b'T1RvVkJDRXhlS1dxMFVLSUZPUmZmY2RBdDNqenFjTTlsVDkzRVJhWVdHR2s1OTY5eG1leTJW'
    b'YkJBWgpxVFdiUkYwNUxxVFpMYmg3YUNsVWUvOGZzT05Bazl3RnJqRnI0amRpLytxU0JKdDh6'
    b'ekJKN1dzOEw2Nk8zNlJFY1gvbVRIL2hjTFVmCkhmSHQ0dnRmWWY0NUFLejFPbzhBK2t2SXp6'
    b'ODluOHVYMHZha0x4REtWWFREb2VHN0QrVk1TMjl5VVE4eCsrbVhmZUo5THEvRkxybkIKL1hU'
    b'UjJKSVhKUGtpMTJnZGt2RDNySm5ZdnphNjllSDlvandNUzRKTmMzYWxMQ2x2TjFlVFA2NzZG'
    b'WjhOT0xrazlrdHN0SG5HcDJYZQpxbEhkUG1EczJVZWhqK2p2cnJtNzEzOC9vWC81N2ptWno3'
    b'SlFuZ0Q2T3lJV3h0cjBSM3psaTZmcUJMc0p2cDZhdW1pUFdaNW93R2lICjdITmw0d0ZQS1dQ'
    b'TzdpTUxMMVVRMU9QcHlERmYyT25XeGRmNllDNFNUMHIvOHRuS0VQUG5IempmVmZQK21Qd2Fz'
    b'bSs2dzhObXNkNksKaDUrcHptVE9KaUNLWFVHSElvckdwTEU3TE5VQzE1Z1Y3bGVIVzZiMWo0'
    b'akFCdGwzcXdMdlZnV09zRXBMclBmUXROaTJPblYvRE45RAp4TWtmMVBoaGRGQWx6K3pMWnlz'
    b'LzlyekFJSXAreTVxbDFzUWp5c2pSWDNpemlwTWEzTEdLZGNzVzk0M2ttbXkySzFuKzNWWEh1'
    b'WU5xCk9BVWlxUnpwcWEyM0MwQ0hEZ3dybHh1UzlYNks5UURnWkVjMEZlWGNLQnM0M1BEK21k'
    b'WXRiMytzOFVxTitjNHhkcnAxQUxEVjc2VG0KK1NmMW5zc2ZmdDZwWjlLcG0rOXlHd0NXOW9z'
    b'eXBuSTdyQjJLWHh6N2xicE5xeXovZ09NQTRLUlhOZDArVHZQOEQya0xUdVJQMUR5egowVGVD'
    b'aXBjUUVNV24zaEdhNTg4V2pmMDJ0Vk1pMjBUYkJHOVdNUUJzOVR2MXo0ZDljUGc0M09wRFQ0'
    b'Tyt1dFEvMEJOdlo5NFZjcVVTCnhCSUFnR1BYVUtsTWRiS2d4UW9BQmpweDJFS0RLWTVQbmpZ'
    b'TmNGVEc5WjAzcDVaZzAyenN3TnVvbUlTWHFja3ZKWXE3V2pwTVV6UFEKTkJmajRQQ0kwdDhr'
    b'UDdwaVVBZFZXZHFKU0RlZzhGeVlsZXFyemhXSGFnNFhYNnBBMWd2Tm5NNzlxNjRtYllkUmgy'
    b'cG0wSUxPcmhWbwpNNm5tZEU3Nm5GVXBqZTRySDI3dFNjZUF3b3VkdWhvNy9qMXIxckc4U1Zw'
    b'NHpGM0JxcXpMK1hkM1lqYUpyK3V6TCtDN0ZhRTFBRkJjCmpjc3ZWVXdlaHFBb05IREFqQVZK'
    b'MlNnZUR3SDlFVmM3dVB5SXpxSzJnQVFldEV6S0tyOHh3a2VZVlZyZXdKR0Z1MTB5TkRkcTFF'
    b'RTMKUDFtamhSMi9ORjcxQ0x0U2xsNHBIZDZUNWdkT2R6ZjVuZGJxd3dPWTA1dnFCQ3lCWEJY'
    b'NGxTdnhNaVdCaUpNVGNYSjEzNHl4ZUpZTQpkaTNmV0swSkFKaUNIb25mSm1Wb0ZtdEc1N1JK'
    b'R0NJWldZbmlNSDVlSkNNREFJTW9GTW9wU2cyRHpDUzM0eEZsczFpUEwxTzVDQ0k1CkJldHhV'
    b'QlFraWc2dmtJeVhzcWl0Tlh4amdheWpWaUlGQlk4b2lZaWl4M0FKVHRiUHFLaE53dEJPdm1J'
    b'TUl3Q1lVamxhTkEwb2JXcE4KT2xIeTRpWGlmc2haWGRjZXlaRFhCanR6RFBVQUFPSlRVUm9W'
    b'ekZoSVhSTlltNEpZQWd3cW5NbnNyNUJ4OEZKT085VjU5LzJRaVBDNwo2Mlp3VDBRaGxYVUtP'
    b'K01hdXRiNEJaVWdWZCthUlczVlJqblR1SmhtanhiZWlOcGF1MlJpN05RMXlRMzlzRE1QYWdj'
    b'c2RidlJzSFFjCmIrWHdsZjJ2cWpVZlQxOVJ1V2hLOFlJWmZDa05jOUdGY29wTVFjaWZON3Qx'
    b'eGNoelk3NVFhMjRQT0ZLM1pFTEQwbkVMM1c0OXFmZkUKVGlheis5MmN1SUczWWtUUi9KbjZa'
    b'SjZLMHJMSVlDOGJ5MTQyOXVpSVhWaElHQUR1Vi90L0gzeXdKWHdrZDNrbzV1cGpIMGZwd2hu'
    b'VgppeWM5bTdrMHU5bFJGYnRyY2hsdWtWYXpaR0tZNC8xLzFzdzNLQjNFTXR5R3NPWW1MZ1I3'
    b'SWFYVklKTURVd2RKemtHOVhSQUNBWjVtCm9zRmVpTFd4UEJKM1FFRXhBb0JMN1o4Y3ZtK0RJ'
    b'RERVRDhYakVKbjhIWFErV25oNGpQcWU3dmlRSTJZQ1FBcmI3ZkR3N3cwb1BEeWkKbkdJWHIv'
    b'clE4SktCWnRrQVlLZGJkM2IwVjNlcWd3QWdxbXpJaGJHZnUrcFhBTUIwaDRlWTJRZUFrWmFw'
    b'R0IxN2NPZ1BUeHM4c0pIUApJcGZvQ2JaUEVBUjEwS3ZCZW1VQUdHcVJSc1RKY1loeWFiOGJP'
    b'a1FCRm11WG8vaXRmaWNwQkNtTklCNW44eFRUZE5PdnNLQ3pzWUhHCkJwOEl6TzJQcmZhUEdQ'
    b'MmxLYTBaNlZ1TVVSUmlqakowTXgvamxHSUFZRWt5L2d6WXNIdjI4MU0zVUJJUjRsSlJuZ0Ix'
    b'c2tHSUJPRHgKd2NFS2FodWh2Qlp3T05nNEpxTy85Q0pXaUl4bzhPWHpyYmN5ak8wdElUUVlX'
    b'UHA5aURvS2lFUkJ1bE1WTk1YdThjMkt3WHdaemRPZwp0RlhDeU9JNGdrWTZrVWhCeGp6ejZJ'
    b'cEJKclRtcW5aVEFHZ1VHcGpRdUZoMEw0M3RxczZQU0tqekJvQ25EUjdOWWowSHZScXBnaGhk'
    b'Ck1YaUsvYU5IZFQ1S0ZDZFNrSE9iN1RRMXE5cE5NempPYzUzdlBtbndUR3R5bmVOMHI0eG5V'
    b'YzAzd1lnZFRET0g2OUFxMFFHQXFQS1EKSWVZWnNUWCtTaFJuU3VOS2xVUzFUcDlKWlJWU3dW'
    b'VnNuWHptSzZ1MVU4bDdyNHpmT2ora0JnQVdUMEhHaHlBakFoQWZWeVErenpBbQpRV2xzQUFB'
    b'd2NTZ3lhd3dDQVBvTTVZR3hSMWtTbFFGamszMVhQMWhmdzBhQ1BCRUU2VVBVV3lXTTdHYUhl'
    b'WGUvanEvMUVjbklXUnlICmdXWlpFMjcrL0xUQjQyamVaRTNuZWVidDcyOVZEanljTysyclp5'
    b'dU1xUzBBWUtYVCtPV3pGWWR5cHNYWCtzeS90MU90dVRObDJlOVoKTXgvWGVVK08zdXR2bkYv'
    b'UVlpTkhjUTlyL2ViZSticVVaemt6NW5zMStmcWdac0NLaDUrVnRGa091L0tuUkVFcWFiWEs0'
    b'OW94eWUyRApMaDBwYXpQLzh0bktLMlhEMURUdGhKcy9QMnZvdnlGaC9jV1NrUWlncFR6TFFO'
    b'UGNPWGQyM2FzS3JHdzM3Y3VHWHQ2bzlBb1ZWcll5CnQwL0x2THI4NG1DM3JyMXNiUk9PcjlD'
    b'Wk9Sclg5R0pla0RxK1BxUmZ5d3FiUHdGVjVTSlVrRWMrTHlhK282cHFHYThUL1MrY2NHWlcK'
    b'NFhGS2IxWWhIa0VyMnMyQ1RiTS9qTi9TSlllM25HYys0Y2JQQ0lJdWRidGhUT1dtTjdsWU1o'
    b'b2xDdUwzNllzamlzWjBZVWsvZnJRUgpHN2JWQ1l4d2lIS0FjYjVFUWNMamxNNm5MM2Fwd0pI'
    b'Y3FVZHlwNDYxZmxyTk4zWTFxRUFBTFdxMURqREpHMzd0ank0VlNLejNDTDUwCjFJVEdOYUsw'
    b'V2pMWXJSSUdBQnBnbkxjdGFaV0ZGOCtoVHlDWDgvbW4xNWphTFdqMDY0Y085TzRtZStlUFdJ'
    b'Zm9QQmQyWVY2b3Y1aE0KQktFSXR2Mkc3bHJUcVNsL1BqSHp3dSszaWlrVFg1aGJBb0MwVDlz'
    b'NkprV3QxbHVmckI1Z1hCQmdrcHZPZGptUUhkWlQyamFLSWt2dgpiek9pdHZteUNobEU0WWR4'
    b'VzdRa2VPL05tRmZhWmhsZ2t1ZHRWTFF4WVcxVnp5M3liblhnOGZ4SlFTWTVnU2E1RVVWam9p'
    b'c0c5VlJzCm85Qmd6ZU9Obm9ZbC9zWjVWZTJtMzZVdDBwNWhMbFVTTXpqT1JhM2FvdTh5SlNH'
    b'RDQ0ejlOWWlNdEdpMmxiUXEvRWd4cWRTMEFyem0KZVE2UFVGcExMS25GUmVRTmpjWnRUM0U3'
    b'anppTXZ2SkVOOWdMTjhRWE51L3ZwRXlqb09QTU93aHlMSFdsUWFCZnhyUFVjbXVSbktTdQo1'
    b'TXZrcTZhd2hRYVkyaXZHNnlZMDdqYi80M2xjdTM0RzVWWTZqVlBzSG1IMEhBQ1E4TElaOWc4'
    b'amkwZXJlYkZ2Z2c1WDg0MmRtRlYxCkF0WlhBVWMzUGxtcmZ1OXpuZTljTEJrcFU2cHVOOXN4'
    b'Vm8vRVIxRWtwOWxobS8veHBmZS81SXBWU1RqRExkTksyeXpVMzBGL3c3TFoKVHZlcTJrMkpP'
    b'UGxrdTBmUEd2cXJlMnRUV3JPWFVmR2RxaURzWHowUy81dUF3N2t0ZGdIR2VSUzhkSkZyOU9H'
    b'ZStYa0FxQk1ZaGNhYwoxdjc0WExHdTc3blRyOU42WXFqTG45VU0vYTNmS2lkckVJb1JkaHQ1'
    b'MzRPZ2pDWW5mVUY2R25HZWlUaXREaHhCVDlsZmVzbEs4bWp4CkdCNEFqQm1FVk5UTGJ6d2lU'
    b'QnJTTWJ6Y01pWXA3dmlaTFBKY0FFaXNkdm9RS3Zha0xVd256dE55NnpLZXhXdFdNcko0Tkla'
    b'WGp6eDgKRTFISE5lZzc3UGdUNzhpUCtsOTJPbk5KVTJGL3lFOGZlMTRZZitQbjIxVWRKZlEz'
    b'S011ZSs0SDlxYXZsUFBPTytLenQ0K3NUTnUzTAptTmNsTkZlM1pNS081SEJOYk16b25Kd1BQ'
    b'cWhvTnd1NGNFS1RURDBadXBOR0VNK00rVjR6SlBodzZvZCt4b1hlNTA2WHRuVTBoZmt1Ck1i'
    b'OFAzYXVlSzNyU3UyM2hoeVA2aG9jZm1YdXFIL0ZwSmcxL2JWdmEydk1qem9pLzFmelZXdnh3'
    b'c1YzRVp4T3pLT1NPa3crVDBleHkKNHRyWm5RWm5BaEZ5TGRsVUFmaVpnYlZubjFpdHlqcXFJ'
    b'T3IyTlNNTEFOZkxocHd1R3F0NXhrbXZhclhuUlFSQmZ4ajBXeWZ5dWNYdQplUDRrVGNnUkJQ'
    b'MXA4SDRFUWRkNW4xT254MkJ5dkdDU0puOEhBRi81SHpXZzhIeFpoZk9jYjJ1ZXYxQTg2a0p4'
    b'cHlES05QdTRvUllaCkRLSnd1LzlmbXVkdlZ3WWZ5Wm42and6Tm41c0dYcVF2RW9xOVQrODJ2'
    b'ZHphS1VnOVVQRlh3c0l2ZDg3b0JEa0FJQWdROFVnWG1uYi8KWFZjeVhtS20wL3J0VGErdHo3'
    b'OTY2NUFEQUlIeDg2NXVmOER6SlhDM3c0WjhuZHdwbkRyQjlna2VVUUtBaDJHcHRVNkQyaUNq'
    b'S0xMMAovaGVhbXYzMEt4eVoxUmpQTmRvNjZXamVaTTBnYkplYlRyWjdyQ0k0YlJOUEZZNVhu'
    b'Ky95Y1docVRyQjkwcWtmRlRNMUxVcGVSaFgvCmt5KzZmY0Jza1JYQUFNMHo1OGRzd3lLdDk2'
    b'b0QxZkc5bDhWVnYyTFBRTlcwK3gvVEY2Z3A1R1pERndEZ0N1eWpNMnBGQWZvQU1OdnAKM2x6'
    b'bk8wME52Q0dXT1ZiR2lpNE9mMVN5VVhZeGNJVVVnQTdxRFllRHlKTHhPVlZoSUJNQmlRN2ty'
    b'bHpocFhFcTh2Vnl5UWpOVjlSRgovRTN5dnhod1ZOV1drbFptY3B3Nm9VNGEwNzBCeEhGYTRH'
    b'NlBXU2hrdkt6akdDZlY4bG1STmJKSXlYaXA5bTlRcllDOS9kZlQxRlltCnU2Rk5XdEo5QWtH'
    b'anpYaXc3blJtb2wwQ2xpUEwwZW9UR1ZEYTFkOWNaT2RCQ2dCSTZjWjNCMjlYZngrVDdSN0hO'
    b'Nk5PVnAwYWRDV2IKdERneUxCNldvM2phS1B5ZkFNYzdoVnpObnVWd1p3R3BtOTRIajFPcWIx'
    b'M1FZcXVsa3FaVWpscnp0NnpacjJ2aEVRUzlPTzZ6NnhNMgpxbFBmRVFUOWZlamUxRm1MZGdU'
    b'OGxkWHM5R0pZcnlOU1VQNFl0dWZlbERXYXpXNngyODJVV1l0UGpkclJKcVVMWkNwK1Bvdmp0'
    b'Tlh2CjVJT3BIMzN1MS9HY1BrWkZqMmVzdUQxNTNTQ3pMSFVvTnFQSmVhcDlmUFNrVDA2Rzd0'
    b'UWhDZFgrMnBWeFd4TER3cGU3WDB0bnU2akoKMS80R1pSRmp2b3llOUltSFlhbTYyRjFCZjZi'
    b'UFdUREQ0ZUUvSG50RFg0cXZycnN5SVE2L0RzWFRBS0JkM2hYZHphT1RiTVd4NzdSSwpXcUl2'
    b'YUpqREF3QW9iYlBja0xBZUFGeVlsYXM5TGdLQW4zSEJpYnlKR0FFWFZSNXlmK3BxWjJZVkFK'
    b'alNtOVdtK092QXcxYU14Z0hHCitZR211VEdWd1dHT0Q2cmFUWmU1UnkxMnZZazU2aWNLSm1J'
    b'Smt4OTdYUmhzbGdrQXd5elN2MDliTk5vNkNRQ0VNdXJWOFp0VjlIdVYKUDJiS3h0azhuZVlR'
    b'aDRVQmR5U0ZZL0diQnpVRG5vU0Y2NUlFQU1BVjZ5MjR0d01BakNpdFdDUzNuMVdyQUd6L0ti'
    b'd2xJdW5kUkpSRQpoTkpxY0hneGk3S05EM0hjVWZDaXMyNFFzdVFLSUdpTTRDeU01RDhOK2Yz'
    b'VCt5SVd0Ym15V2FmUlpEckFXeDZ6YS9QbXNMaFdzMWhQClpTMUZCbGlZdFZXaXM5RHRWbFRG'
    b'RUt3ZmRXWldZWnFhaGhGTExXcVY2RGd6cTdDSVoxUjV5Q0tYYUV4VG9pQzF5K2lhbXUxU0dn'
    b'RW4KOTJZVjhXVzBKL1dlSDNwY2xpa0ptQnZmTE5IVDFGU2d1SFlwYmJYbjVRYzFBOFJ5a3Ax'
    b'dW5TNUowS1dxUEJrZG00UWxrcFAvd1ZaTwpvcEIwNkVDbEFFK0FsdGFwZ29SRUFoQ1FqdjZ4'
    b'aWh3U2w2Mzc5VitrZG9HR3J4cFEvemo4MjhrMkR4cFpVOTQ2NUsvZzRlOVZCV1J4CkhOWFpV'
    b'Vnl4N3ViRU5WSUZjZkRsSTg4NVRnb2xqaWVsKzdJS0QyYUhiVWxjM1NyUitmeHB4NklIbnlh'
    b'c2F4THBiM3J5OFlIc21hNzYKRlZJRmtZQlhQRzkyR25MNWtBTEZmZjcwUTNXSzFmN00yYWxz'
    b'dDVqS2dXRXh1OGRhUFgxYTN6K0hhMjlNYmZFN2Y2cE93SW9xRDduOQpJak02b2Q3cmNPNjBG'
    b'b211WitSWkJFRkxlQmFwVFc0VGJaK3NmTGcxb21oTWFadmx2b3k1YW1KeHphTk5JZ1g1UVBi'
    b'TWZ4QjFCSUZnCkx5VFFBL0Z4UlhiSERzWmM5T0pxdko5ZWNzZDd4bE9yT0RSek85UGtITFNr'
    b'cXVQYW5ITGkrckZGSCttdUE2Vzg3eXc4QUh5YnRpUzEKMFUyT2RsaWYvWmx6emhlSEVoRDVq'
    b'ZklRVzkzNnhIcFBPWXAvVUQyZ3NOWG1aTUVFTEFxQ3lkTUdEOXVUMTB4b1hMNk14cUp3SDlY'
    b'NQo2Qkg1TjhxR05JcVlUcWN2YXc3dG1zVjZnUmVQdWVwWDZCQkZWOHVHSWdqUUNaTElvbENo'
    b'Z2h4MmEzY3l1NTltbFZZKzNQcEQrbndjCkRvMG9IS05INXRmeFdXMFNSZzdYTVlQaittSGNa'
    b'czJnKyttQ2NiY3FCaTRVSjhKN0lPMENvT0pFbUl0T0lhSGJSMFFuM3B6QXB6Z0MKQUlPZlU5'
    b'OUNHaGpJSEc1ZGxWR0FwaFVRL1Z6bEFERGNSMG9rd0VENzJvUFAwYjVyNndEd3JLRy9KdVF2'
    b'K2lGRHR0Z2dyOW5la3M3VwpJL1ByQllaTlltWU8xMTRUY2t5RWNrbzV6N3hKeEJUSktYU2l5'
    b'SURDeStJNjFQQk5OU0ZYRFZKUlhCN1hYaUNqRnJkWjIrZzBPT2pXCnBMTGQrRkphRjhneEtX'
    b'MnpiSmZTc3BvZG5mU3FyWFFhTXpsT2ZCazFwZEZORTNMMTk5UWxwME83c0VVR1RTTDlKcEUr'
    b'VDhiUVR0TmkKYWswaWZiR2krNVJmb3FSMVZ2cHY3RnY1bFZ4bVVTUHpZUnIrMS9tcTBMQ0xq'
    b'WkpFUUFtZ0duckk4YnJuaTBmemxYcE5JbjFMRzRPaQpkcWRiR1NZQVFDSUNnb0NOc1dTSTRE'
    b'dVFpOVdPb2ZyV2ZCbFZXKytzSktrMTFTbVFyOUhXZS83Q3BBcWlCNnNrMkN5YlJoQzc2bGNl'
    b'Cno1K2s1ZlpLd0UxemlOTWxDWVJ5U2x5dHI1YjBSWTVZN3dQbmUzYTZ0VElsb1UzR09KWS91'
    b'V2VpVkcrUzNXTnZWaEVaTHpXaGNkVjkKVUxmUmdkZEgzZTdrMWRkUlMybDBNejU2VzdzT3Ri'
    b'MitBZC95K2R4bmFVVUdlQnh1eXBDTzROdmhXTXVpQ3B4TUtzTm1Kb3RwTmpuaQo2Wk52R3Fv'
    b'VlByTllPOTZuRVFDS2FzbWJMd2JsazZZQ2dhTDJ0RjU1YTFYOG9pcFFpeWFDb3QzREsvenpl'
    b'UG1oaXkrZk4xNDFUMi9DClNBUkJFUUFjb3NSUWZQbmxsczFmcjJqakFRQUpKMU9nT0ZOYWM3'
    b'TllUNG5pWkVvQytzSTlvWHE0V0g2M1JYT3NDQUE0UkltaUNLYUQKRmR2MDU1blc2RTVqYmp5'
    b'aVFCQ1VUaEJUQ0pJbWtUNGVVY3FVQlB1SVgvRTZYZHVvbGxVTGZyQVp2OGQ2M0RzeTZRSDU1'
    b'N3hZTVViMgpndThXVm12YStVMlJQazhyYmJLTXU1bTZwdE5XN3RDVW5XVXhlSi83eCt2SGx3'
    b'REE4VGliRSttQmovRWZvWGhxWC9UcjRxTm54TDhlCk1ldnVKeHFEVExJMGZXVVBZU3B2VjBv'
    b'NlBuQ2xtS1FQWFdmZUVuRXl6YUo2RWlZWnFCcEZkZUV0VEVDVmRFVXhOZXBtYlVsTFUrTHAK'
    b'UC9wbUhhSU8vTmpaL3B3c2hnTm51SmVxUlQwcjB2djg3dlEwbnArRWFDSXhzZTcyS3BmOHl4'
    b'UHRIbi9xYzNEbWtCYk03N3Z5aEpsSQpYb1NTcUcrOWhvUnVJZjlmV28wSVoyNnFlL0xBeTJ1'
    b'T09lbFZIeGo2WTFHcjFmN01PVDNpUnhMdURsYXR6eE5WSHFLTzczWExnR0pVCkJBRHNTUW83'
    b'WVBUMWdLYWprL0FYRWd2MGNpb1pPaVRoUTFpRmpkRVh1TVlFbWVRQWdGQkdVWlBIK3R3aUI4'
    b'ZmFXbE9qTDBiazRIRUEKQUpzdkJub0dXNDFqSGNjNHE3L3lwdlIwYXpNNjU0c0JLdFlyb21p'
    b'TU9pSHhaUmxta1Q3VDhYNDNxSXYvT3ZPL3Q3b296c3prWmVBdApHRTFqUGFMaWFuMjFvRTRq'
    b'aUQveVVFVWFhL2xHV2xCM1lWYW9OVThVVEt3U0U0WVdaRVpFVzE0aHJCN0pqakFFUHJ4Z2FV'
    b'WlpKYXZYCmtWV2pIcG9YNFJ5WU0yK2lESVA4WnFyeG9kb05SUk5YcTllUjFZSzZBYmxkZmV1'
    b'c1prY3RxSHNaRldHYXVQOTV5RFdCeDFtYTk5a2QKWTZqT0Ira25HM0Q5aTV1Y3p0QTNhMWUr'
    b'N1RnbHJTM1l3a2hhMlVoOGxLTzdJV0V0bi9RT0tVWEN2d0h5VGkxKzhXcGxkVi8wOFhrQgo2'
    b'd0VBaUxSazM5V3ZWT2FaK3ZSUFBiTnVseE5kVDBBbVFqRWg5TjIraW44SjVCM0FuemlBc3pK'
    b'L0QrdVdTbks3cEZ4emw3MHFPOEh4ClhmQnhYZHY2dndSeVRlQjVpMWNEdkY4cmhUL3dEQWRB'
    b'ZVlBVTJveDY1eTlCZE9Eb3YycHhlQlh3eDM2akdobS9mMVhybzFrYmlDU0QKQWdDZWtXY0xl'
    b'ODRXUFRmbWkybjJjUUJRSXpCMk9LVnRXNGFtOERHNlJBRUFuQ3lZb0o3TTNPMDRKMkg2Y3V4'
    b'NFVleDJ6ZG1OWFdTcgozOG1kQVVkVVkrOFRONXBFUGM0RXVUdmw0NkhtR1pnZjYzL2hSSS9H'
    b'RFZFSVZnMEZnT3MvVHgrWlVnNy9TaUdROERJQXdPRzBtVHNpClRvNnBhYWJRZEN0a25CVFR4'
    b'RmFyNnRtYlVKSmVGSVhIS2JUVkQxR29OUkd0QzBxUmNESk1rNFRUVmtrRVFWV1AzTGZMVTcx'
    b'ZjF1NGYKcndHTmsyUWxTWUQvNUg4ZWRZV0UvKzBSTkQwZnpTbEJyZVRQQnNNUjREYzRDYTY1'
    b'bDI4QnBlSS9WTjY1aFg5SDVVb2wyc0REa3hrRAo3Q0V0RCtoVXNMT2hpbWs2SDNJL3F4Y2Fs'
    b'NXQ3QWE0anRxc3J5c2MzSk1XbG9BZ0MvUnlRLzlCNnIxRy9lb2tvdWxReURuYkVlaTBiCm5Y'
    b'czIzbTB1WDY5cnlNSEtCREUyUUlWaWFHcHJER0ExNnRrb2svT0tZdGdkMlRoQnloT0h3NDU3'
    b'MklreHovWnBKcW9qS21SRDhIK1kKL1gzQld3MmRtdEhrY3F0aWtIcEppSmZGa05MV0lEVE1h'
    b'SEpKWnJ0alM3cjJKT1owenYwN3pGYTZiUjJSKzlVbnFiZFNhR01ORTVBNgpLRFh1dEpRSUNT'
    b'OG5OV2RVbFhNTmRHQmlDT3BxbzZ4dFZINHdGazFNYWkvQkR3Y0FxcmpxM0xpZGJsYmlyNjk1'
    b'WlZUb0YxYkF4R0JSCmJVVnpvckRIREhBV3RhV0tiNXJSNUpMVTZCNWY2NmRsYkdUQmFNcG9j'
    b'bW5QWXJtekcvNmxiVDM4d2JaWEt2MlJNK00xaTl0eE5taFYKOFVXN2tPZHBVajFyYy9oenhw'
    b'VmhIcndobjdkcTZqaElZOGVLanJsYmxoVzFvVjR1S3JzOXlBZXBhUVF5U1pYTjRVR01DM1FW'
    b'ZkJmbAp2cXZoRUFDQ2svTU5kV2NPdEM2R1Jobmd1cC9mKzJQR2d0ZHlLVkFjOXNoYjJtTUFN'
    b'djZ6OEc5Qm1rMTg5dW1hM0J5MDlGeEFHd0FNCjkrVGRTR1VsR1hlYU56TlY5ODhwdmxXdDdi'
    b'QjVDWkthaStyUUVUb1ZBTURTQkRZTWZ4b2JVOFluMnl0UVBBQUlGVFRNdkN2eHRIWUoKa1lL'
    b'WDk4MUxrVkVSSmJHWGJvUVNFSUdNb2w2enFYZENKVWlvQk1uZmRHUkk3U2pTUThyTTIrN1hT'
    b'WFF4eVdsUy9Lbnc0djIvem5zSwpBRFNpSElkMm1zaHlvMjFwdU9HM1phMkcwNDZPR0dhVnhX'
    b'M0xHVGRZOVlBaC9kcFdaZjY0cjNGdmdjUzNqb016cDZsV2kzWVNSVTBMCllIOTN5N2VuaHY1'
    b'MkpkTFRkOGlDQjc2c3dsNlg4S1RlYzAvYXdwdVZnM3U5WDVlZGJ0MTZyM01yM0s5cW45eWpS'
    b'VnBYK0NqYmlLK0YKK3JZQngxZjFWN0Z2RHFldmFQbG1iMDllNTI1UUJnQkpqZTVkZGhFVlVl'
    b'Mk8xcTVlWFpQbVlpa2Q2ZFZ5bWpNN09GQVBBTGFkSG5TRApQYVhJY1B5VU04MXlOczFmMEJp'
    b'ZjVPV3h1aHBlNU1NQXdDQ3o1dzdVQ1lkRmgrNW5HMXN6VzBBaDFaVlg3aGwySEFDdWxJN0NO'
    b'a0xhCk8ralgyVTczQUlBdm83bWRQYS9seVpObUxUR25jUURnZGxYdzhnZWZ2K2I3eW1wMjNI'
    b'QmgwVVNiaEczK3h3Tk5jbnZ4eGdlWlpVVk4KM0pqSmNmb3BZKzdab3JHOVdPeXduR2UrN3ZH'
    b'Rzc5TVdyZmMrOTdIbkJXd3ExcnNhcnpOSmZFc0dHL3ZUem9XWjBwb3hOV05xcDExNAppWUlH'
    b'R2lkL292UVhmWWFLN3hzVEtDa3RhTFJrc00yY2RjYzlQN1F5WmUrQ3pPejU5VW5OUkVZdTNh'
    b'NndwbE55clRGVHNXQ01pSVFYCkV3bktHaDZUSm0vWTJlL3JhUUVOSDUwSnlhZE14WFFNS0R4'
    b'MUpiVS9uam1OZzZrWlVWcmY2TDJnS0hLaklpVG80ckdReTRlNzdsWHoKMnVKbFZId3lkR2ZC'
    b'dkZrcjNLOFNrTjd3RUExQ3c2MkpxMjFPWE4rWnZGeTl6OGI3eU5MSXFFYkxzLzZjYjE1UVdF'
    b'NjQ5ZHdVQUhRWgpZR3FFWkJTZ0pBYjVpcyt5KzRiOUQ5cE5UdlJHRGIzeTE0MC85K0dFVGh2'
    b'K2VEb2plYVVvdFNVenhKVnpJc1h2Ky82ZnJSOVh0REhDCjl3eC8rMXRmSFA5MUpLSGVhMUww'
    b'UHIvenB5NldqT3lkdVhaa1ZoOGF2cnRrd1l4MVh1ZW9lRWt2U3VDSW1UdVN3MjFPWGwvLytK'
    b'TjYKZ2RGN3ljM2hDSDhFZmJreVovV28ySWpES1NFS0pRQ0FpeTB3YUFnMzk5a28zWE1sOW1Q'
    b'cnJRWjdXUEhXRGt1cjQrRHduYXZBb0FHNwpCU2ljcEttSFp5enlmNzUyVE1uSHB3Tk9KbnNx'
    b'Q0F6NDV5Uzl5V1hXN2UrOHpwMDlYVER1NVRrQ3J5TTJ1dlcvaFB4Y3NYanFqb0MvCjFOdGZ2'
    b'SkcwUzJuN00rZlluYnE2OHVGV2JDR3U5d2wxQUNuTnFONSt1cFJxVVZMWThpUlhOWi9OeVJx'
    b'V0JHZHZIaGEzaXJsNUZPRncKTXR2dGwyc21jNE9ydWx3Ymw0STJjWUhyR0Q3R3VmREQwTEpQ'
    b'STN3djFjMFl3TXFGOTBDeW14MFd4dTV3UG4zcDE4elpXcFk4MXlMRwpWTzcyZ0NOVml5ZnZI'
    b'bmpBZ01MclJRa1NCZWx3N2pTSFUxY1czZHV1ZlRKelg2UGU0Wkxveldob1VnQkFmUk1BZ0o4'
    b'Ynl1YklQZ3Q5CmRHL1YwWVJQSXk5c0xmS3c3MnJ4YUZTWU9ScXg0ZC9lT1NNcjhvblpsWXF4'
    b'c3d5T1pMYjd2VCtEWGN6UHNqdDFiVS82UXMyVlZWOWYKZEVtQ0xiNm5LaGROMlIveUU3WkU0'
    b'aHQzbzByQ3FjTHg3aEdSazIvdTdjV3lldThXZFRKZWVxZlFqUytFeEV6MFlUSWFuNHFhR2dL'
    b'RgoyS09UcUZTQ09RdHA0TUJReStkS0pmeHl6M3Vwdytub3h2SHVqTXozamVqNCszNFdneWhj'
    b'NjNXK2JPSDBVNk4yT09sVjlZWWJRSEUzCktrTDhMNXdJdmY1N1l2MGI3T3pZZGVSVzJHcXQz'
    b'ajFGcVhXOGtkamcyU2cwQUFEMTZxMHZTNHR1VUZINW9leFMvRUF2Ulg0NU9uVEEKSzd5aFox'
    b'bElVUzJaSXpId3RXKzZuYWJ2WjFweXBUQjRpdVhOeTRXRGdTNEVvb296em1tMnh5cjV5cVlX'
    b'WCt1TGJXdVd3WEYrRjloagpmdGErNTNPWHVrVnQ4VDF0UnVlOE1jR0JseTF3alpubmN1ZHk2'
    b'ZkFkeWVGYTlrUFVJckhWL3JIVi9vUE5NcmY0bnNLV1o5V3VqOENLCjFIZmFKb3hySTdZRVhs'
    b'dzdxVTRvZ3UrUEtqY3R4aG5vOWV5d0NNRDZwNzBpeENCK3hrY0dPb3BkMS9yWkc3VmVLQjdo'
    b'aUV1Sll2d0IKZU5KYnJOaVdxcGpObGJlNi9XbWo0K3pqWm04OFdxTVJ4TXZkcjMzcUU5Rmww'
    b'YVUzYXJ2WHlvWituN2JvNzZ5RjZtK1MvNW52aVNuMgpqM2dydlhwaWFkNzVXRWpHZFBrMmE2'
    b'MzNqcGs3VHh0L3VnaXZCZklMZDFBcUJVaDRoWVRaTDZ1VzVXUXBjMlRXUGF1eW5XUVRYOFIz'
    b'Cm9ncEwrOHg2MDRtOW9VU0Vjc3IrekRsL3g4L0NJY3JwRGc5VFppMU9tTEY4a3UzajNsVStw'
    b'ZEZ0ZXN3ZWw3TVhSRDBid25lT2VndmQKVDVmQVd6czA2ZnR3dGhFVGJSZEFSUjBBZ0hvQjdK'
    b'dnhLbk9VVTR3Q0FCVXZBRUR1VmZnQXdMYTVUZnJ5MHZnU3UzN01ZaEhac3M5UQozeFgweDQ4'
    b'RGYrdUZ1VmI3V2YwaklqKzRzNnZMeWs5dlN1MGx6RmorT3VhNld5bHB0ZUpKZXd5aUlrL3Zl'
    b'Z0hBbkx1N0tubG1QU2w5CkYvVEhjTXRVQUdDTDlLZEU3OVhXd1V4ZGcyMmFHRjB4YUZmcVV0'
    b'VTlGTUtOckxVYngyYmZTYUZ4bXdRelFoRkxFemdaaFM2YWpLQW8KZlBHYjh0dTF1UEphRUlu'
    b'aHhDT2J3bmJuS053dWhyajR3ZVNWL3M2Q00zZW9Fb2s4clpBOGZJVHh5dlJEV3Z5bUEwTi85'
    b'R1VWQUVCeApxOVhDMkIwOXFlRVJaY0tNNVFCUWVOeHYwdlA4N3R0NmVBVTVsQzFWRU04WGov'
    b'b21aV2x4bTNXdlA2QlJWaWs3QXc1aGk2bjNlcmk0Ck4zMStSTkdZTitVSkNwNTl6cEsxZDkv'
    b'V2cweHpna3h6dE5POEx2cVZtSnFmOFNzQ0VnSEd1WmltSTdOakRUVVVUL3U1YnMvNjAxNnoK'
    b'UmdpZGJjSFNCTXBxVkcwOVBoVWQ1SU1BUUhFbDJzOEI3bktuM2hNdkJRQSt4V2xUekhTNUFx'
    b'WVBGVEZwVWxPZDlvRldaZG96TU4wTgpTckZiZXhrVmE3ZWltSnIyM1czVmZsYkIvTmtYeG43'
    b'ZXo2Q1hXd0hHVnZzUHV2d1hSdXYyanRyek1DdzlHYnF6Y01ITWRWN25laDJKCjZRc0xyMVJD'
    b'VFM1WFBZR0RLU25jMS8vams2c3pJNkxSQWU1SVNnN0s1cUxPTnNEakE1RUFUalpJWVFXUWlB'
    b'QUEwK3p2aXlpcWFZRHgKeUljZm5RcW1VV0RjWUlSQUFHN2JQNVBTaWtPVU14M3Y1M3d3OThh'
    b'RVQzc1hpVkhUdXI0WFRwOHVHTmU3YmFmc2RXdC9DZm01Zk9IVQpMYjZuL240azVwMmdmdjBL'
    b'RWVJcmRob3V0SlhjY3hkZlBCYXlaZTNZVWlJQlFueVIzQkxVd1FvSjhrU0tLeUV5Qmgza2d6'
    b'aFpBd0F3CmRRQUF2cGlTTXhIL3c0dXE0WS95dmoxMDI1UkdnUWtoWUdIOFQrYk5JUWc2MFM3'
    b'aDJjeWxmOGZQZXQ3a3REQjJoMWRrUks5cFhWTmEKOCs2QkJ5b1hUOWtSOEpkNnQ1VDNCZlZw'
    b'WVRMS1JKUHdzUldKUzdabnJOODdMYUFlTys5b0RjUDhFWDFkRUVuQTNSR1lPaUNTQUFDNAoy'
    b'SUszS3dJQWVCd2NteC90TEZaTkJGZmk2VVdLZ2VXMW9LK0x0UEhoZlJDMW56WEo5bkh2L0t4'
    b'Y3J0M0MyQjFPcHk3OW1qbGJwT2pOCndtaEdsTmJ0QVVjd2FxOTNMdWRiUnIyaERvN3Uwcmx4'
    b'SDF4MWkwMzFGV1lHQ21Kbkh1aktNNVBETVVhZkhUTkx5b1paWTVBamw5REcKbGs2Tm1LV25X'
    b'T3B5UWIwbEFzMlFWVkdMTW5XZ3JmMDltclNnQ3AvUG1iZlE1UmEybnU2YlNrVzcrYnJIRzJ4'
    b'UFhOdVp2UHlObGt4UwppdzVKdU5icmZQbkNhWWVHNzM1VGh1QXRveDUzbmtRaUF3NUIvRjFF'
    b'T0kyeXNVeWVna3JpZ3JnOW4rVDlrWXJPL1BnRDVFNGlPbTR3CnNtbXZNcStpazdsYk83clFW'
    b'blJIdzdvQ2hheXlDdStWWUg1VzBZS3dYdnRaYkpIQmp1Unc2eE5SV3hOWHExZklmeU1oNDZV'
    b'cjNLK1cKTHB4K2F0UU9iSHVsMTJKa01RcFFvaldDVk1VM3hkUWFoQWF2Y0RyQ1RPb0tlSHA2'
    b'UWhaVEFRQVNLWng2WkZYSFk5WTFFL0IwdmZJaQpEZzFmeDJHTWxCTjByajZpVEJva0poRmg3'
    b'Vnk0ZmwvWmIxbEhJVlF5ekxLNThVTmpLT0FJVFdKOUhvSEtFNGc1Q2dzNXFpM2ZxNXhuCndh'
    b'SzJBVUJKbTVVV05SUkZzR2Q1Vzh0T1luN1dCdS9JbjU1L2NDUjNhaS9pTVR3cGZVLzZ3Z1Ba'
    b'WWN2NlJXM3lQZHVMZUF3Uko4ZG8KM1ZzVkEzZW1oTCtTMm52N2pPeXFaenNkQnlmbVNZMlBy'
    b'aTBLM1Q4akZyY1JFSVF1S0JEUTNRQ0FMaWtMTXppMmJmUWpKd3VKMmd3Ywp2WXE2MkNJaHZo'
    b'MkZLSlR3ODIzWExLNnJEcTUxOTlSSCsrKzZmRmw5N08xbVZXaGhaTEh4ZXUvYTdzL1A1eHpN'
    b'RHNQV00rMkZVQWpTCnBXNVJtM3pQMnVyMGNta0ZGRVZ1Vmc3K1BuWFI4V3VSUFkzWDN6N3F3'
    b'eEsvVC9BSy8xaXl3Y3lrNlRQaEJjMUY3UWNvenZ3VWVpcWsKWDV1bWZtazFFUEJ3NVNIaGsz'
    b'a2R3L0UySVI2VVNqMEdDZ0NuNGl3MnBYL0pKdm04M1hwcVFUMTVuT0hRQlE5NmwvY0NBTzFT'
    b'MnZIOApTYnZURi9ZNjd3V0hLR2M0UE53UjhGZXZlUUlBYUFyM3g3ZDNQL0RCZzkrS3QvczJL'
    b'eXdHS3NrTVFwbUlVNnlmcnpFQjMxWWNlMmZCClhnOWJZUmY5Nmdhb1prTmxNejNFczZOcmpF'
    b'bGpqWWpjRlpIcWZ1REp3S09Objc2TFJWb0d0NVVNYXV1ZXova1pKcSt1L0Znb3AvbXcKaWlq'
    b'NE4rNnd5WGhab0dudUdzOUxWanJzVEk0VDc4MmROUlNRUEs3OW56blQwOWh1RHN3YUMzcFRi'
    b'N2pobXlhb3BQdnhZZGVlY3I1TApqSG8xK2JsM3Z0RXlyUHhoME8rWUZjcmoydS9RM0NrQ2h3'
    b'ZUFCUGQ1Qkg0OTVtb2VIYkVMQU1UVjJaYXNUbk9NRzFzSW02Nk9qR1VQCnE0ZitYL2Y3RXVD'
    b'NStxZXhQbXlkK1BZc1V2ZjdqcS9xZjJXRVpTb0FpQlRrUmZlMmEzbnlnOE4rd1BJa2s5bjk5'
    b'cWJQZjFNLzY2Zm4KSDN6WS8vSm0zOU85eUh2Qi9LekZyamZQRjQvNk5uVkpvZGJOcExvbnUx'
    b'RGNqWXFRR3hVaFdBaDFvdDFibS9uYkZYVXZ3NUtaTC9ZMgpYWEJ2aDF6UkkrcWpyWjVoM09m'
    b'anV1WWRuZmNId1VUT01BTUFNazZLRlJqWGdtcXV4U0JYd095VHMrSUo2NENCV2NWT0RZSkto'
    b'dG0yClVUODJqZTUyK1lZQWt6eXNUTDZNdGdpMG9UN0o5akdXUjB2RXlmZSsrZHY1KzM2V09u'
    b'eittbjVXVDlSZVF2UytRV1paVzMxUDlqb2UKODg1Wm1wZWx0QnIwT3E4dWZQbVpjVHp5b2Zw'
    b'ZnJyaXJHZHc1Slcydy9IY0FvQXFMS2NMS2YzQ0V4cGZSOW1mT3NUOTFaZEc5N2IyTAp4T0FR'
    b'NVVTN2hKUlppKzlOV2FQZTJmeE41VW05NTZUb2ZkN256L1NhMXUxVDFKOFhvUGVlb3MydDhO'
    b'ZTlqckJlQTA5WE0wc2lsK3RRClhJMHYwOWh4bWtwQm84SWpEampObkVMWkx5VWEvT09qYzZt'
    b'Q2VLcHd2T3VaODdOdWY5ZTdqQmNBR0dXVmtoZ1cvbmRvM1N5T296cGoKVTZJZ3ZiK29lN3Np'
    b'cTJZaG80S1FRbmx3U2pFREFCcWFFVy9MUnFLa2cwMHM1MXNXMVpJYk9PampkRlREUENvOVRC'
    b'dUh1TGRhd2Z1UwpONmRFY1JkTFJucEVucDE4YzIrM0M1bS9QcldYTVh0K3I2bTlNcDdGdXNj'
    b'Ym5NOWMvRFZ6ZGk4WWdqNmRWMERXTTRqS2NnQUFQQUZuCm9zT2Zxbk5BL1pNMXZiYUlZekxR'
    b'RzNHelIyNDlWZ0ZQcDRLdHFmVERrY1ZobHBmZksxWU84N01DTHh6L096Tmp2Rm5GSjBOM1pu'
    b'NHcKZDZITHJkN05qS2xxTjEzM2VJUHR5V3M3azVlL3ZENy9QNFk2WGlxd0xyekhiVVlBZ01j'
    b'SHc2WmJPNlpsQWdCTFQrRnFpNDZ5N1dqQgpWR1Z6VXV0QUFEQml3aEEvWk1OcEw2VVNBTURL'
    b'QkFVQW5nQnYxQm9INzU5Z0lkVEJsNC8wT256dWJsQitNblJuOGNLd1hzK01hUkxwCjcwZ090'
    b'ejRaOWZvelk3cWlMbEtRZVZJNjlvZHFYZjZzWFViRDFMUnNTdUJZZUdXeEtPcGhFdTcyVTBK'
    b'S0h2TEpsRHBzcG90Q0NUSTUKSkZWYUlqSlZLQzFWTUVSdTBCOHJVRW1neHltV1BpOVZHYTZr'
    b'WWlhVExxZlRPeEwvaEhJS3B2bkt1QVZQeXNBMEJUTHF1OFArNy90Wgp0anAxYjJWbWpOT1pT'
    b'K3NmZi9MS21USHZOa2ZXb2lyZVNYN3E0NWtOMDRNN3V2QmFEakV5enVEd1UzK2U4ZkJHK2t2'
    b'bVVTa0RGTVZMCld0TER3anp0cFFBUUVXZjBSZXlVY3BQd1BtTmtlNWNqaTRtOWJ1MDZyL01y'
    b'KzE4bDQzdVo5OUlzMXZzOWE5YXZXYk42RjQvQmhvdHoKSE8vdE94K05hOGYxTmVyOVMyNHNx'
    b'N3p3d1Y5RkxIM0E0bTg1RmRTRFQ0SXEya3p1dDAyU2tveUIzUFdwY0RMaGpBZWYydmV2YTNh'
    b'MApPYklzQ1FDU0Myanpqazhvc2R6dzFxYzJha0c5RFU4VkV2NVdiQWFQS0JoRUVSN3AvWHBh'
    b'S0NBQ0dWV3E3UDE4ZlJNcEQ0Y3FYNHVsCmVZdFNTelBaTVBEWHlPKysyTHVreUZSZlNxY29m'
    b'bm84OUhqYlRnQ0FIandQSXI4K3hTdkl4ZTRDQmprQTNNeHpFWm9PNmVQWnJIb0sKa1o1QzlI'
    b'ZEwrYnRwVGlnRkJPL29BUWsvRGY0RkFIYW5MV1NMZWh3VEwzS054bWk0VmluajYrNW9PTFY4'
    b'Ri9RSHRzVnFjcVA3T1FpbAp0bGZQZ0xyTVl2S2k0ZzBMeVQvSitBTFFBd0N3MW1sWTczVU91'
    b'K1JNNGJqMEpoY0FBTG5rdzh4ZG54M0tOelpVK2ZBUkNaWlBwRE0yCkRrOEVTQVNBcjVKV2FG'
    b'a3k2U09QUzQ1Nk5RQlFLMkR0eTVpbmhURFpPK2hYQUNCRk1lSGZLb1JQdkNNQjRFamVGQzJv'
    b'VDdaN1BOM2gKSVFEVUNveTFvNzdHOHdLMnJlcUovSW5uaWtOcEFzNkR4cUE3Tlp2b2d2ejhK'
    b'Sis3WHFxMVk4MW96ZGg5QVNDdHlWV0ZPcXFJWm9hVQoveXFOK0t5TVJsRW01T250U0ZrNU83'
    b'aGFyYms3YmFFVzFHYzV4ZzYxeU1CNERDMm80eEVsVnVEbDJGbi9XdFRmcmVWc052VzU1NzBL'
    b'CkVKeUE1WDVoK0ErdEJscG5CUkJwSlc0emhxTnRHdzlhUFM4a0huemdVMHdjRGYvSi96dlVB'
    b'VUJKMFhzai9iUU15eitJa1VkL2RzMHQKY1BzUG5uZGw0ZCtyMnFCa3ZZc0Jtd0RCLzJYN3RS'
    b'NnY1ajk0L2hXb0E0Qlkzd0VBeEF4ek1jUDhQM2ordjFyNC8rUTlsUDhEVTc1aQpaN0FROG5N'
    b'QUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURVdE16QlVNakE2TWpRNk5UTXJN'
    b'REE2TURDUkZkUmpBQUFBCkpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEExTFRNd1ZE'
    b'SXdPakkwT2pVekt6QXdPakF3NEVoczN3QUFBQUJKUlU1RXJrSmcKZ2c9PQoiCiAgICAgICBp'
    b'ZD0iaW1hZ2UxNTM1NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'FR_BFC')

FR_BFC = b64_FR_BFC
index.append("FR_BFC")
index.append("France Bourgogne-Franche-Comté")
catalog["FR_BFC"] = FR_BFC
catalog["France Bourgogne-Franche-Comté"] = FR_BFC
country["France Bourgogne-Franche-Comté"] = ('FR_BFC', '', 1)
lookup["FR_BFC"] = ('FR_BFC', '', 'France Bourgogne-Franche-Comté', 1)
lookup["France Bourgogne-Franche-Comté"] = ('FR_BFC', '', 'France Bourgogne-Franche-Comté', 1)
details["FR_BFC"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_BFC"] = ('FR_BFC', 'France Bourgogne-Franche-Comté', 1)
regional["France Bourgogne-Franche-Comté"] = ('FR_BFC', 'France Bourgogne-Franche-Comté', 1)
#----------------------------------------------------------------------
b64_FR_BRE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIgd2lkdGg9IjEzNTAiIGhlaWdodD0iOTAwIj4NCgk8cmVjdCB3aWR0'
    b'aD0iMTM1MCIgaGVpZ2h0PSI5MDAiIGZpbGw9IiNmZmYiLz4NCgk8cmVjdCB4PSI2MDAiIHdp'
    b'ZHRoPSIxMzUwIiBoZWlnaHQ9IjEwMCIgZmlsbD0iIzAwMCIvPg0KCTxyZWN0IHg9IjYwMCIg'
    b'eT0iMjAwIiB3aWR0aD0iMTM1MCIgaGVpZ2h0PSIxMDAiIGZpbGw9IiMwMDAiLz4NCgk8cmVj'
    b'dCB5PSI0MDAiIHdpZHRoPSIxMzUwIiBoZWlnaHQ9IjEwMCIgZmlsbD0iIzAwMCIvPg0KCTxy'
    b'ZWN0IHk9IjYwMCIgd2lkdGg9IjEzNTAiIGhlaWdodD0iMTAwIiBmaWxsPSIjMDAwIi8+DQoJ'
    b'PHJlY3QgeT0iODAwIiB3aWR0aD0iMTM1MCIgaGVpZ2h0PSIxMDAiIGZpbGw9IiMwMDAiLz4N'
    b'Cgk8dXNlIHhsaW5rOmhyZWY9IiNlcm1pbmUiIHg9Ii0yMjUiIHk9Ii0xMjIuNSIvPg0KCTx1'
    b'c2UgeGxpbms6aHJlZj0iI2VybWluZSIgeD0iLTc1IiB5PSItMTIyLjUiLz4NCgk8dXNlIHhs'
    b'aW5rOmhyZWY9IiNlcm1pbmUiIHg9Ijc1IiB5PSItMTIyLjUiLz4NCgk8dXNlIHhsaW5rOmhy'
    b'ZWY9IiNlcm1pbmUiIHg9IjIyNSIgeT0iLTEyMi41Ii8+DQoJPHVzZSB4bGluazpocmVmPSIj'
    b'ZXJtaW5lIiB4PSItMTUwIi8+DQoJPGcgaWQ9ImVybWluZSIgZmlsbD0iIzAwMCI+DQoJCTx1'
    b'c2UgeGxpbms6aHJlZj0iI3MiIHRyYW5zZm9ybT0icm90YXRlKC05MCAzMDAsMTY3LjUpIi8+'
    b'DQoJCTxwYXRoIGlkPSJzIiBkPSJNIDMwMCwxNjcuNSBsIC05LC0xMy41IGwgOSwtMjIuNSBs'
    b'IDksMjIuNSB6Ii8+DQoJCTx1c2UgeGxpbms6aHJlZj0iI3MiIHRyYW5zZm9ybT0icm90YXRl'
    b'KDkwIDMwMCwxNjcuNSkiLz4NCgkJPHBhdGggZD0iTSAzMDAsMTY3LjUgbCA0MC41LDk5IGwg'
    b'LTMxLjUsLTEzLjUgbCAtOSwxOCBsIC05LC0xOCBsIC0zMS41LDEzLjUgeiIvPg0KCTwvZz4N'
    b'Cgk8dXNlIHhsaW5rOmhyZWY9IiNlcm1pbmUiIHg9IjE1MCIvPg0KCTx1c2UgeGxpbms6aHJl'
    b'Zj0iI2VybWluZSIgeD0iLTIyNSIgeT0iMTIyLjUiLz4NCgk8dXNlIHhsaW5rOmhyZWY9IiNl'
    b'cm1pbmUiIHg9Ii03NSIgeT0iMTIyLjUiLz4NCgk8dXNlIHhsaW5rOmhyZWY9IiNlcm1pbmUi'
    b'IHg9Ijc1IiB5PSIxMjIuNSIvPg0KCTx1c2UgeGxpbms6aHJlZj0iI2VybWluZSIgeD0iMjI1'
    b'IiB5PSIxMjIuNSIvPg0KPC9zdmc+', 'FR_BRE')

FR_BRE = b64_FR_BRE
index.append("FR_BRE")
index.append("France Bretagne")
catalog["FR_BRE"] = FR_BRE
catalog["France Bretagne"] = FR_BRE
country["France Bretagne"] = ('FR_BRE', '', 1)
lookup["FR_BRE"] = ('FR_BRE', '', 'France Bretagne', 1)
lookup["France Bretagne"] = ('FR_BRE', '', 'France Bretagne', 1)
details["FR_BRE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_BRE"] = ('FR_BRE', 'France Bretagne', 1)
regional["France Bretagne"] = ('FR_BRE', 'France Bretagne', 1)
#----------------------------------------------------------------------
b64_FR_CVL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc2MjI3IgogICB3aWR0aD0i'
    b'MTY3IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE2NyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQ2VudHJlLVZhbF9kZV9Mb2lyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzNjIzMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzYyMjkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNjIzMyI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNjciCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBS2NBQUFCa0NBSUFBQUJzQ0xlaEFB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVMK'
    b'ZkVsRVFWUjQydTJkYVVBVFJ4dkhuOTJFWElSYlRya1BCUlJFRkt1STRvVldSYnlxVnVHdEhL'
    b'S3RhRzFGMjFxMXAvUlFxMjBWclZacQpXNjB0YXIzd3hBdGJoSHFBS0lkUUZFVHVtMGhDeUxW'
    b'NVB5eHVZMGdDa25BbCsvK1U3T3hPWnVhM3orek04OHhzRVA2UGgxcDI3QUhOCmllTHFaSFRt'
    b'TjlDb2hKZXVjZC9kcE5rOG1URlJ6SmdvemViSmZYZVQ4TkkxemVacGRPWTNpcXVUQmpQa3h5'
    b'ZWdqR1ZockxVcmdaUnUKaUIrZndJOVBRQUdBQks5VHlBR0FpbjluTEFzREJGcSsyVU0yamRZ'
    b'aTMzMkF2K2NuL0ROS0hHVkVoYkZpU1l2WGZ1UXZVQ2ZCNndoeQplZW9rZUYxQXJvQjZHL2gx'
    b'TVdSN2FRUHlYVCsyUjY2WU9nQXdJa05KOE5xQWZPOUJoVW1vc210SThOcUtYQlYxRXJ5Mkln'
    b'Y0FSQ3FWCnFzN0NmOXJQVDBxYVFDenU3RzlTcWFpWmlXYXJJVzBWU0RuUE5Kc253dFpIOUZr'
    b'YUxpZm5tYlJWb05rOFVUTlRvRkk2ZTdaWVlpdmgKbkc4NTFnR2lEdk9wRWxBcnhUUUFXcWQv'
    b'R0tDYTF3MTNzSVlKQVZjS1hJMlhrNkw1Y3RhM3Z0VHBWQkIxeUFvbCswTWRGRW1kcEU2Swpw'
    b'RTZLcEU2S3BFNktwRTZxZjZuaiticWJvekdMU1NWYnFyOW9nRWdQS2pvNHAyUGZIS24rcGRJ'
    b'eWp2N1U2V1FQVDRxa1RvcWtycU9qCnVRWlBmOVZuK0FybmxBQmJZWks5RGJ2d2FoaE5UOEd0'
    b'TTJyZThUc1BhdnBhYlkvc0RGbzh5MDNCOFRPRm9Xc3Y5N1hTK2c0eHYzdHEKQVlMSUh4ZUpz'
    b'Y0ZUamhTWEtRNUNPdGthRnVXbGRhT3RiMXc1VWlGeUFOZ1VNN0t2TmVJZ0orT0ZNMXdWSmky'
    b'YTZlcmhZdExYQ3Z6SgpHci8yeUFGQWo0cSt2Mko0Ny9UdzlqYnM4UG51eWxKREpqdjZlVnYw'
    b'clVaODI0OUNRUlFtVVNoSVg3dE5mWWVZQjA5MFZKWWF1Y0RECnlkYXdGNmlyTUhSY20xZjFv'
    b'WGIwY0RGWk5OTlZ4UW12QjdzT0hXVGFkd3I4cVJKRDE0aTVvOTFoNkxobVRlcEQ1cjU1MVVn'
    b'VVJWUTEKQklwc2VITkUzekgwbWNvTlhYMXo3eUwxVFRFZEdIb256UjFGcGY3dXhiMXU2RDFw'
    b'N21NOWloRkVxbzZoRStiK3dadStQVWZkM29hOQpkSjU3Wjg2Y05jbHgxRENsNW80ZzBqM0xq'
    b'NlpzK1g2eTk3L2QydEFmcmU3QTBBbHovL0N0N2pYM0VML3NsQzNmeFlXZVUzSE9pS0VkCkd6'
    b'cXVpTmZjdTJidVhYR3d6NS9ta2wxUTM4bVQ1d1E1Mzc2dmVBcjNUbkRLaW1rM0FlRFkrcDk4'
    b'WTljL3FUSHJqb2EyTW1lNTJCdGwKNU5SMjVtUlhCeU1yYzFaVmJVdDNsTVRMb1RKeDNjOVVG'
    b'TnN3UHptdjFQTHdEVC9GemZ1cVMyWnViYWViMTJubndmc3ZXeEtrM21OTQpsK2ZyNm1pNFUx'
    b'bjYxenZvZW0xTGI2OW51MDMrZUpWVWlvQ1dpa0VUWld6ZjdtbFhpWDl0NGpHOTFtd29xemZX'
    b'K0E4NTJSb1dwWVIxCjQzeGRIZTJNT2tFZ0I0Q0pYb1gvQzd3RDJxdlZNLzRpa0FPQXNUNS9S'
    b'K1RKM2lwTTcxQ2Y2cE1mT09TUjNNRVA1bDlCVWUwTUFMSVoKZ2cvbVhaSHZ5VWRuRFI1WXJV'
    b'UFUzNWh3VzhGSTI3YXEvYTJnSFpybGwyTnF3R3MvZjFrK05WMVhxTk9vNGxsK09RcVRwdm5r'
    b'YXlYMQplV01VRDdpbURjL1RGZW91Vm5XR0xNWDdPZnpkaTdTU3VxOXptY0xqUSt5cWpGaDhu'
    b'YUErZUtEU1dKeTF5VFB0UTA3WEV6dVlOeWl0CnN1a3puYURPWmlqZC8yZkNidEUrNmt5YWlJ'
    b'SmlTcXVzcnh1MjNpclVVNWJFYVdGcUgvVldrU3BYV0JPUG9SUFVHM2xLZDMzV1AyTnAKSDNX'
    b'QmlNcFhmcU0zY1BWN3ZramR1T1NacmljZTYxN0VwSXNlVnczSUw3TWtqdDhySGlpVklnb2pF'
    b'TG1sMWk4VURzWDgzSjVhR0RXWAoxSnBtRlEvcys0Q0hPNVhabXpkV054bmNmV1F2eHRvc1Np'
    b'cEZzb29IamhuOFJNRmQzcXhmdzJITFRWK2RyZXI1QXIyYitjNENFYldmClVaL21rMzl3OVcv'
    b'V3Boejg2NE1uTnV0K21YczVhekFBTkRUclA2azFkYkpRNE1tL1ZlaUFmNkNnV096c2ErL052'
    b'V3IyZkpyN2Q1N0wKa2gxTE5lWENSQkRwd3JIM0VsTjlOVlZmdXdHTlI5YitFdUJSUk9EODZz'
    b'U1VuV2NtU2pBVUFPNCtjbEJJUFQzZmtYQkNUL1hKM3g1Kwowc3Voelg5WDBXZ1UvbjBZM21M'
    b'OW80Y1A4Q2c2czNFL2dSd0F2QjByTG03ZUV6dTc3YzI2eWZjVWgreFM4MXp3NGMvWlRmdStm'
    b'dU9NCm1ZeG5ZNXpuNHl1Znhoc3dXelZTd20xTFQvOFIrL09HK2NrYXljMkl4Yi82V1R5QkhB'
    b'RE1ESGpibHA1TzJyaWZRUk1CZ0RKNGFRVnQKcndWZVArZnF4WS8yRXNnQndNYUVjM2Jqdm1G'
    b'T0ZmMkcrbmZManRPbzhtODBRVkhwOXZCVHVGZnUwSTFSN2E4cUtMZk1lV3FOSU5MRAo3L3o2'
    b'NnZDSGlxWjgxZStHWEZlL2VFc24zc0x2djdqUWM4Rit1ZXBudURZa3hjMWF3WFIwdW0vZXIy'
    b'c09BOENGVE0vcUpvUDJKeHhQCjh3R0FpTW4vYkYxNnV2MGpqMFlWeDBjbjlnL3FOaVljWlU0'
    b'SkFOano1bEZiczZhYkQ1MEt5aTNsa3ZEK05uelNMV1dlTEFBSUhxRXUKSkJlcnV0M0xqeFA5'
    b'L1A0My8yanZLMzFaelJ5Wm95eHBnZis5TnliY0ZtUG9INm55a2Z0N3hiYUZsUmIyNWcyN280'
    b'OHJ1M3lzUjdHbApjWE0vb0U2bFNsU2s2dE9GVzBMUEFjRFJtL0xMdm82bCtSQ3B5dFMrQzNs'
    b'WmZSR1dKT3N3c0RibGZMTG9vcHA1NmxGVVZUa3U3Q3lMCkxqenlsengxdkFYaVFzK3g2TUp1'
    b'clhKUFVDK3ZOK1lKVkwwTzUzK0J0NGZZVmYzNWo0L3N3Znd5eTV5bjFxdG0zckF4NGFpNE5y'
    b'L2MKU3AyeWVUbFVMdkRQa2pzWU5TWGR3a2d0ZXlxb3NGU1JhbXZXRkRQOTd6dVA3RXRxVE9X'
    b'Njk2SDJsVXZHM1ZWeGJUT2ZVZDVnckhuTApOTzF3eGZ5RXcxRDJFbDVEQ1laZXl2U1E2NlZG'
    b'RWdvRndmQkFLb3BLbzZlbXZaTXdyN0xCaUJqeG5icmxMUmVERW9pb3NnRjRYT2N6ClBOV3Bi'
    b'ZWo0dSswZm55eTZjTW40akcrVEpuUTUyL01abmd2ODc3V2ZwaFBsWHo0MWJmdnBTWmV5UEpa'
    b'UHZZa2Z5UzZ4ZmxScC92MnkKUDRuZ01vWWhFaWtxMTIxY3luTEhzSmRiYVlLVlZYUzRzNlZi'
    b'Um5QYlQwK1dYUldUVzJvMU1QSnp5L0M0SHk0RzRFZkNBdS9RcUdKaQpuZ1lBNlFXT0U0Y1dP'
    b'bHZXQVFDM2xSNGR2OWhnOGJiQWpXdUU0di9tbGlVMXBvazMxWnByelIydGVNUXdWYjFZM3gr'
    b'cHZxVjEvMjJpCkVJcXA0emV1TVZpOGJjWGVSZHhXT2dDNFd0Y0dEbm44WW4yZEdUUlI2UGcy'
    b'UTk5N01jQWkvQXZicU0veVpEd1dHSVpzUHptNTM0emgKMHdzY3Q1K2VSSHpkZlg1ODdUTjJY'
    b'VFA3clgwTFAwbWNqazlzeG5rV1pUeTJJODdKZUd3M2UxUTJBTFFLOWFaK0VuUGd5aGlSaFBK'
    b'WApuc3VWKzRPSTNpSmlkNmc2amdzbVRlUnFwWGc5MmlpM0VuWHEyeXJVQy84K1ZDUnBleGZn'
    b'bGZ1RC9zNXpFVWtvKzVQSFR2dDBKVjdtCjJhTWVaRHkySnk3SkxMSWQ1MW1FRHlRLytuM0d5'
    b'bjBMNjV2MWF6Z0d1OCtQKzI5NmVXcUs3STNTMTZrRHdQdS9odXc2RjlqbXBKTVoKajN4KzlO'
    b'WHNFbXNBQ0JwV1VGUnRSclJhUmFOUjBMQjhBTmlaTkRHOXdKRTRuMEVUQXdCUFFGdTRMZUo2'
    b'dHBzNlJYS3pxVlcyVnNlVQozYUo2Uk5haHJtVVBldjJiY0h4QVE1TVp6NmJsTzMyYk5CRUFn'
    b'bnp5aTZyK2U2NC9yaHFBMS9mQkU1c3R4NmJKT2pUeEQ5OG1UZGh3Ck9MaWI2SFFYZGFrVWVm'
    b'dkEvQVZiSTB2clRHYktUTGN3RFBueHNqOEFCSGc4ZWxwclN2aWh6Tmc4ZDl0cUFOaVg3Qy9y'
    b'L1JqclhuUTkKMjgxdjNicFR0N3pWTEZMN1VZS3NxMDVaeUwvek9wRStiTlQ2MkJ1NXJnRWVS'
    b'YkpSODMyWC9BRmdpRjBWbFlJMWNsblB4N3hHQVI2UApBV0Ivc3IvczAzRG1pTnludGFienQw'
    b'YTkrOU84N2xzNzJyMnZIam1lN25NdVkwam8rTHRNbW9pSVFQenpyeE1BREhXb2F1UzFSZGdh'
    b'Cm1wbGVqcFVBVU5sZ0pEdlFkYkdxRDQ1YmNlVytacnlTS21KOUdJWTA4VFFRN3NzcnRaNnc2'
    b'ZTBnbndKbnkvcDd4YmI0d2VJYXMrb20KQTB2alppLzd5Z1l1QzQ4bU4vSll1Q2NPYnczaUda'
    b'U1k2bnY0cjVFcWl0b1BxQU1BWDZoMzRNcVlGMzF3RnJnZDA2a2lZcmpyWkZrUApBQVVWNXJK'
    b'blpoYlphckFrZGMxS0EzcE5QSllFMDFpMzE5Ny9XbEJoWVduYzdHeFZSMFJkRFptdHVOdmdY'
    b'NWtxdDIrcmJsTEg3NlZ4Cm5uQzR1RXhqNnoxOG5NcmpRcE9jTE90UlJGcGViMnhoMUV5bFlL'
    b'MGlLazlBSDJEQTViYlNNNHZzbHU5NVhaMmZNR0MyVHZkOU9NQ0EKVzFwbmNqM0hEUjlGdHox'
    b'S0VqYkxSZ2NJcGVTNFR0ejh0bXdPRTRjVzJwbzExVFd6ejJkNHl1YlFCWjM4NElEZGdFWTJR'
    b'MUQzak0yawppeGg2SWdxS2xkYWIySmsxWWxLa3VOb3NPbjV4UmFPUnBscllBYmladEZPOWJP'
    b'dHlNamZpemhqUnRrUlE0VklxUTVaYWI5cWU3UDN2CmtiVy9FRjZYWmo3anl6K25iRDA1cFMz'
    b'MlZXUTNTeEgxZjU1SFFTZ285c0c4eSsvUHUwcUVlYXFiREJidkNGZG5JRG5kTnc4ZlVzalcK'
    b'bC9qc1lWdk5aZ3Fnc1VjcDlEVDFnbkx6MklOekFHQ1lZL2xvbWVDakJFTVBwWXdTaUNncTFs'
    b'eDBLRy9IaXFTTis1ZzBrYXpWZmhGMgpkdlRna2dWYkk0Umk2dmtNejFtS2ZPYXArYzY0Ny9Q'
    b'UDl4TGs0akdXeHMxbk4rNGJ0WDVkYm1rWDNZTHYvVHFiaWtxTTlmbUxBakpmCmVCRGNkeStx'
    b'TWdPQUdvNUJEMVBvYWVwUGEwMTNuSmtFQUxlMmZqUElSbTcyTE1XVHVxeTRKVW15eUFtRitH'
    b'WEhyemdXSGI4NE1kWDMKMjhnVGNvUDVKaDRUZnhMdmV5dFJZUWlPUlJmR2hTWE4rVEs2YTZY'
    b'Ni9td2dBR3hhY0VtdXZuWFAyS3YyTDREZVVPL3NnbGo1NnQvdApIU09iRjE1U2MxZnpsR0ZL'
    b'OThZdW01SStZMFJlSTVkMTVvNlhYTktwVzk1Q01UWFlMemQ4MGkxbGx3Y05LMUNuWU82MjFl'
    b'dm15UDlyCnI3OTc4WWNhQ3ZEM2RlcFVGTnY0MnFYdm92K1VtOXpqODVha0QvZlBVaDYxN0ZB'
    b'U2xSUGNyVXRQVVZBc01WVSsxbmYwNW5BcWltMTkKNDdTS2F6RTFwczdUZlBLdmZyWmJidDA3'
    b'WHVVdG9lZTJoSjZqS2w5QnF3M1VUUTE0SnpZY2lKbWVtbE5pdmV0YzRJcTlpNTdQcWZSRAo0'
    b'cGFmdWVQVnlHUCtzREpSNFg2b3p1aGhxYXJZMXhDN3FpWGpNeTVrZXNxR0JCdTVyS3NQQm9V'
    b'RzN2R3dyVkp4YmRjZTZpZ3EvV2pSCmhWL1dIT0x3bUVkdkRwL3paWFJEYzl2YXlJaGRTL1lu'
    b'ajMxWVpoVTFPVDEreFRFMVBZTjkrcm5lMEt3ZkVyZWMrRW9NNXZVb2txUzcKUTVQdURsVXov'
    b'OU8zdlVlNmxzbzlzd1VpS3JFd0lUb283VkNLWCtwRFoySnIxWVZNVDZHWUdoMzBYK0N4cXRH'
    b'UVFSTVp2N2hNL2N3dApyeTZVQjhPUXp4S25mNVk0bmZBQUdqM1A5bEdWeFMvWFg0RmVVbSsr'
    b'WlpEeGZPVFZ4TlBNZ3VpOUZ3TUlZd0tBa2hwVDkxV2JiS0syClJPNWUwaUtnQVVDQVI1R2Jk'
    b'YzN0ZngySmMyNFZPcmpiVm8vMUtBYUFGZ0V0WWxmb3dHV2Z1Ni9hUkhpTEFhQytXZitINUxF'
    b'YWVib1IKMnlFNHZiRU12azlRSndqSnJRN3VzdXFiOVNOM0x5RzhiTWZTaGxjM0dXQVljdkRx'
    b'Nk5sZlJrc3dGRUdrd1NOelpWMSttWS90Z2tmbQpBSUFZUTJmRkxmLzUyaXNZaGxRM0dSQkxm'
    b'U1FZR3Jscmllek4xR1dKSkJUQzRhT3BLdmMvNnJjTDdldWEyUUJ3STlkVlUzbWV2dTBWCnV2'
    b'TU4zTEtOWmZaUFhiay8rTGUvUmdKQWtFK0JyS3UvdU5vVUg1OGZUdkc3bGoySU9JNTd5M2tD'
    b'MnVKdmxyWWY5bmRaRnpJOUFTQy8KekxMbjUraDloWHFMZ1BiUmtSbWNGdVlQRjhkcU1OdkVW'
    b'TitSNjlaZHpobzgwemRQZG5pY2NIa01BSXdaWEZ6eWZBV0VCRU5yT0FhagpCejBCZ0FRWkJ6'
    b'Z1Z4V2FPeUUzT2NoOFJ1LzVZMm5BTmx1M2ozNmMzOHhsZm5aZ0N2YXBlZnQzLzNvc0JLVG11'
    b'UmRVRE5KdnR3ektyCnFaL0crTHNYV3hnMUV5N3V6Q0picVJReDF1Y2JNdHE4cmR4VytrQ3pK'
    b'a05XSzRZaHN0MitwZkd6ZVY4dmt3M3phN0Jnbzk2TGxkMEoKcEl2VThZYm9wcHpUOHAxa3Yz'
    b'SmI2WlZOaGpZbUhOc0JISkdFb2tlUkNNVVVCL05HQUNodk1HNlJtYzZWTnhoM3h4cEZYTDJP'
    b'SEhvKwo1dFpic2pKNWx2eHhQSnNwb0NCU25vREdvZ3NSQUtrVWFSSHE2ZE9GRWluQzVkTzkz'
    b'OWtBL1Y5OU1lYldXNkpSeGJMN2lYUmN1a0s5CmxtT3djRnNFQUhnNVZoQXJVM0h0dVREK2Fh'
    b'MHhTVjBMeFJmcTRhUHh4ZU15bkMxZjJFNGI0UEY0N3VsbHVrVzl3eFh6bUhBT0FGczcKYWhz'
    b'V2VHZnU2QWR5QitlODh1RHQ0QnQ0UEZRTGhOcmFtS1owNTM5QjlLL24rdWFGRjM5YWZRUUF4'
    b'REpMNVBCZEZqc2pUc1NGbmUzaApFQWpadzNldjZIcmlieUpPdmVKV2ZQWEJvRHVGRHNsWjdu'
    b'OS84VzFiOS83aE82K055UnJoOG5TS2R3R1hUL3ZxUkpBV3Y4dFd0NmdMClJOUlYrMThqdnNy'
    b'dU5YOVNiZnIrcnlHNk5vYlh4WC8yb2xIYjNMUlNxV2FXd1pQVSs4TXM3bGxiQUsyQnl5STJw'
    b'NUhVdFZ3MUhJUFUKaDg0QWtKemxEam9wSGYzdnh0aURjeHU1cks5UEJ1bG05WFgwTDdadkZ6'
    b'cDRyTjZvOEExQnBLMXJzM1FXT1pEL3prdFNKMFZTSjZYTApvemtyWXoweGhRSFVUczlyeFJL'
    b'c3ZrR3pwVVFZZE1USVVMTjVTbmt0VWk1UHcrVTBNa1FZZE0zbWlkVTNncmpUcjV5alVxM29Z'
    b'bldwCk15SkQvMWtYODFLbGxEd3E1b1NFYXJibXRLQko3SjJyTlpzblB6NkJIMzlJczNteXY5'
    b'aENtelpKczNseVFrSWxqMTVtKzE4cDhQZEsKbVc5RmRMR0haMFNHc2w0U09hbStJUDZ1SC9s'
    b'N0QzYUZPaU1xakVUZXY4SHYrZW5scURPaXdsaXhLOG0yNjkvZ2R4OVFCaDRsa2VzZwplSlJF'
    b'cm9QZ1g2RE9XRVlpMTFMdzhRbUtxVE9XaGJIV2tzaTFGSHg4Z2l4NGxFU3VnK0JSRXJrT2dx'
    b'Y3lZNktZTVZGa2krZ09lS2xBCjhIOWRZRENONGJVbllBQUFBQ1YwUlZoMFpHRjBaVHBqY21W'
    b'aGRHVUFNakF5TXkwd055MHdNbFF3TkRvek1Ub3pOU3N3TURvd01KSlUKS25jQUFBQWxkRVZZ'
    b'ZEdSaGRHVTZiVzlrYVdaNUFESXdNak10TURjdE1ESlVNRFE2TXpFNk16VXJNREE2TUREakNa'
    b'TExBQUFBQUVsRgpUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2U2MjM1IiAvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'FR_CVL')

FR_CVL = b64_FR_CVL
index.append("FR_CVL")
index.append("France Centre-Val de Loire")
catalog["FR_CVL"] = FR_CVL
catalog["France Centre-Val de Loire"] = FR_CVL
country["France Centre-Val de Loire"] = ('FR_CVL', '', 1)
lookup["FR_CVL"] = ('FR_CVL', '', 'France Centre-Val de Loire', 1)
lookup["France Centre-Val de Loire"] = ('FR_CVL', '', 'France Centre-Val de Loire', 1)
details["FR_CVL"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_CVL"] = ('FR_CVL', 'France Centre-Val de Loire', 1)
regional["France Centre-Val de Loire"] = ('FR_CVL', 'France Centre-Val de Loire', 1)
#----------------------------------------------------------------------
b64_FR_GES = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTM2MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9SZWdpb25fb2ZfR3JhbmRfRXN0XyhWYXJpYW50'
    b'XzEpLnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9y'
    b'Zy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlw'
    b'b2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5r'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9z'
    b'dmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMxNTM2NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2'
    b'aWV3CiAgICAgaWQ9Im5hbWVkdmlldzE1MzY0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIK'
    b'ICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0i'
    b'MC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBp'
    b'bmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIK'
    b'ICAgICBpZD0iZzE1MzY4Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAg'
    b'IGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAg'
    b'IHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6'
    b'aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFK'
    b'WUFBQUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFC'
    b'NkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxS'
    b'MFFBL3dEL0FQK2d2YWVUQUFBVQpjRWxFUVZSNDJ1MWRlVnhUVjc2L1M1S2JQWkNRalJCMkVo'
    b'QWlJQ0tMU3RsY1dxeWl0ZHJSVHFkMTY3TlZXeDJkMTNXbW0xMWYyK204CmViVWR4K24yUnRy'
    b'YTFuSGNwa1dyZ3lzZ2k3S0toaTBRRWdoWnlaN2MrLzVJalplQTRQcXAvYnp6L1l0ejdyM24z'
    b'SHUrNS96TzcvZTkKdnh0Z2dpQWdnRjh5RURBRWdFSUFRQ0VBb0JCUUNBQW9CQUFVQWdBS0FZ'
    b'VUFnRUlBUUNFQW9CQlFDQUFvQkFBVUFnQUtBWVVBZ0VJQQpRQ0VBb0JCUUNBQW9CQUFVQWdB'
    b'S0FZVUFnRUlBUUNIQWpZTXlicTNHN0RpaE5veTRmV0NBN2hLd01VcEJnakFxakRFNWhRUUJQ'
    b'WHVnCjZkMWpGMzA0K0Z6bUxsdHRDTHl0V0xtOVRBWERFeHJTOTQ1M3ZIVzBIZkIzRjhLSEUy'
    b'OGNhWC8vM3gwVDdZVUVBYjN6NDBVd1dIY3oKM3ZueFlzam5oS01NcWRIaDBkdGMxOWxXR0lN'
    b'cTVUSm9GTVJvOXhnZEhydm5sNzF4c2pISzN0WDV3ZUxlQy8wZm5sU1RUMkJRVVl4eQpkY1pi'
    b'WEY0RWhqblkrTTZFeGVXOVE5OXQ2cXd1bzhNallOSEdwOURyeHlkdG9paEp0Q0lyZXNFVXFZ'
    b'UkxKeS9mVnIzMWFJZCsxOW11CkMxckxMM1NuS1ZXSWc4V1dBV3ZvOUY4MDljbFppY0Zpek1z'
    b'SHhSeDZ6WmFTY1Z1TGZlVmdqOUZ4UXpjZzV0QlZVbDZ3Mk5odk50amQKNDU0WlFoUGwrdnRJ'
    b'bFhBL1dKSlpvaENOUFFURFVLcUVteXJoYnB5ZHRLKzVmOE0zRGYwV0p6QjZONFRDUk9HWHY4'
    b'a05Gc3YrY3ZKUQo2OER0akFzWHFTTFBiaTRabDc4UUxzdFZzc2JmemNtU2h3TldmczY0TUFU'
    b'emtpWGZQcGFQSXZCMU5xb3hPZHYxTmpDNGR3dUZpUkhzCnJ4N05EZUZ2ZjR2MnM1cWVWcDJW'
    b'Z0FnSmgxNlVKUHBOZG13TW53bEIwSURWdGZDdko2L0h1NG5rTVR3K2ZLekZSeEVZSjI3bVp4'
    b'd2kKV0JnTFEzVldsOXMzeWFiT29LSWlEdWIwK0FkSDNEYzlkbzM5WnZsTEI4WTlOR0FOOVFv'
    b'UkdKNGk0VWFGTWZ3NG9iVTQyd2R0L2l1UgpHeFZGMkJpRlJhT0V1RmZoeko5OEZvdlRpMTk3'
    b'T0NhbjhNMzdWVHc2TlZpMGUzd3J2NmplMTZRTjFyVHJiY2N2RDcxZTJmYWZKY25iCmlwWGxm'
    b'ejNWWjc2NkVjNkk1bGVRVFB3eit5L3NhZXhibVJYOTZuMXBjUUxXamxQcUovYlVTN24wSlZP'
    b'alNwVWlsWlFYRmNZTU9INEcKdTd1aHo3eS9SZnRKZFRkWkp5cE9FdTE4YUhxd3VPR2IraU1k'
    b'ZzF1TEZCc0xrcVJjT2dSQkxxLy8rM2I5OHdlYlduVFdzWTlUcnBKdApLa2ljblNDa0lEQUVR'
    b'V2FudDZLKzk5WHZXNTFlLzQxUzZQWGo1Q2Vkd0ZIYVhLallYS2lRa2h4QXE4dDd1RTIzODB6'
    b'bjBZN0JPVXJ4CndYV3pRcTc2aWpSb2NhOGM2amJhYjVMQ2RGbllrcWxSWk0velY1OVY3Mi9S'
    b'amozVDdjTmYrYjcxdzVQcWtGWEZvS0h4QWxhd3lNR28KNjJjbS9NL1NhVUdKSVNlR2YvS3BZ'
    b'c29ZS3gzQnd1WW94WE9VNG0zRnlzVzdUdGRwVElGNjV1Z0doV3lzY24zQlBZbkNZQTJkaWk1'
    b'UwpSWllvUkhOM1ZKM3BIZzdXTTJubzV5dG5QSkFlRlJJYXJaK1pzQ3hEL3NqZmErNlFvN3R2'
    b'emN6N3BraEQ2cmwwNnZKTStmSk0rZjRXCjdjZW5PbStsaTBuY21hWHBVV1E1NTZzR3piajhC'
    b'WEV0UC9pcXQ4MW4vbkZKQnJuTjgxcUxZMEtyS3c5akhucDhkaVNQTWU3UnR4ZE8KSmZOSE5r'
    b'U2ZQendqT0ROZ0dLcDRKRGVFdnlBRUxOcWVSL1B1QklVYlppZU81WStNVnAzMUZnUElTVmJo'
    b'dlNrU2N2SFBKeTdmNGlNOQpYYWlnb2FQbWpjdnJQOUF5c0NJck9sRDA0NFRMNXcvWkdFUnM3'
    b'Sm1TNUUzZk5Zd2JUazJ3aTg5TmxnUmM4OVU1Y1F2VElzbEhjWUpvCjFWbjlPSkVtNWFFSXpL'
    b'U2hOL29zOGpEbTVzS2tjUSs5K2tPYnllR0JJR2hWYmx5dzhrREx3TWVuMVZRVXlZc1YvSHA2'
    b'aklSTE45amQKYjFTMlowYUZkUTdiMlJoRnhNYklJYnpqaW0zMzRmak5VeGhITWxrT2ovOXN6'
    b'M0RJQ2VkK1czcXRhOWZ2cWEvdE5ZWlVCdVVNbTl0WApwekUxOXBzaENQcXN0dHZzOVA2eldY'
    b'dEJhOWJiM0RoQkNObll1cno0bCs5TkRicFJ5NmZKbjlyYk1PNm0vcmZxcnZlT2RaaWMzaEtG'
    b'CjZJUEZHVUV2QUlLZ1dmRVJoMW9IRUJoK2JrNEsrWklqSGZvMVg1NExSTitSUE1aZmxtZVZU'
    b'YmhXeG9XRVM5OWNxQmozMEFkVmwwd08KRHd4RFNoR0hySTFWcVljQzBzL3ZEN2M4T2lOMnhP'
    b'Mnp1THpITHc4bHZIcG9lYWFjSEJldS92TGNkY2FGRTFGSVE1Rnd4dFhoR0J4eAorY2ZJM3hQ'
    b'RWY5Y1NuM3c0OGV5QnB2K3V1aFQwRzM5bzEvL1FyaWVmTXpUaTNsN1pKbURSZ21Na1ltUHlN'
    b'R2F2S1ZUeU9ObHBXRjF4Ckx2RDNGN1U5R0lxUW5aMkFCNUVoQ3lQUHhhWUJ5LzA3VDdtdXpI'
    b'R3R4Ymw0MStrelR4ZmY5bGlXSUNDdkh3OWFuVTlXWkw5d3NQa2YKVGYxT3I5L2w5WDkwU24z'
    b'SGd3b2ZUdmdKZ25KbDQ2SlQwTnZTNWVhOWpXTU5Na1pCOG1JRktXSXVsMDUxKy94REkrNzZQ'
    b'dk1QRi9YawphUzVrWTJNcC9FZFRQN2w0WVBUTURUaTNNK01GNU1xM2pyUzdSdnVmWGorK3Zi'
    b'THR1MVg1dDMwdlBOMDFQRWY1azI0WEwyRHRmaVRICjR2SiszYUQ1dEtiN2ROZndIYWNRSndq'
    b'RGlEdW9oUXJaR0k5T3RiaTh0OUpmdDlHK1kvVHNveUR3TTZYSld3b1ZaQU1ZRkl0RGdybXgK'
    b'RFlhNDlYcWJ5NGNUSWY1dHlINTVvdE13dHAwVGFzT05Qc3ZRaVB1VDZ1NXhEd1dqb0JjUE5S'
    b'Y2tDTW42T0k5T1hac1h2ell2L216Mwo4S2J2R3NmdU5iZlpuV25WVzRNVW9naDg3eFRKbC9V'
    b'YThnbHpQcXdLL3AwZEhmNzZBdFhFRFI1cTFZVlk0NHJmNUM2OWhxTklqa2NuCm1HY2h0Z3Nu'
    b'Q0FnYVJXR0ljMlFiTHh2QjV2YmV4SFJjVlZFNzhUblZQY2E1TzZvK1dqWXRSY3dOT1pRYkt6'
    b'ajlkUEhLTDZxL2J0RGMKUVFvUHQrbUtrNjdxb3MrVUpIL1QyRWQrSVh5azQrb2VSa0VuVitB'
    b'dURkbENwRmN5ZjcwbXg4ZW5PMXQxVm95Q3hBbFk1U3BaVGd6LwoxazNOOE9oUUp5YWNHWEFY'
    b'UjFleTdwQUFWcVVlU24rN2NtbDYxSXFzNkxuSllySkRUa0hnbmN1enZtL1QzWXB0bTRUQ3J4'
    b'czAyOHZTCmdyMm15OExlTFU5L2VtL2pUYjhNQzFrQkQ1QjBBN1BUbS92K1ViSTB0YTlKMi9y'
    b'c3ZGc2ZSTFZobExUeFlFWlV3Qk1lRlFGblJOMDUKR2RQcnh5dnFleXZxZThNWTFQdlRJcCtZ'
    b'bVpBYkt3akcrTVVLMGQ0TC9YY3F0TzgxT1hhZUdhVWRiQ3BJMnYzclhMSldGTndwSDU0ZQpj'
    b'ejFPMnFqUUtweEpsaHhEcE1XcGtiemJNb0pITy9Sa2U3dWxVQkd5dUtkRzhwNHRUYjRUNUtt'
    b'a3ZBUHJaaVZFc0lQVDlJdmFucGtmCkhPc2dXYVBBZmhHeUtLS3ZqQXdGZ1JFWXZpV1orL2VI'
    b'V3VZblM0STNBVUhRUTlQazVhcklJeDJERFgwbXU4ZlBZMUNuUllVVkpZbEMKWXZickFWbjhU'
    b'Sk55STFoWVVOK1I4UmlUN3F6WGljRVI5NzRtN2VLcHNxQUM5K09UaGU4ZDd6amNOdUR6RS9O'
    b'U0pGdUxGR3lNY3FQTgpscXRrT3gvS0dsdnZ4d25KaS9zRDNzT3VYMDNQanViUFZZcS9idXo3'
    b'cWw1VHF6R2FuZDY4V0VFazk2cllwREU3QXFwcGlEU2RKUTluClVOR2lSR0hhV3orTXRmdzNR'
    b'S0hSNFZuMDExTlZtNHI0SkkrUlRrVVhwRW9YcEY0ekhOYmJYR01EZ1BGOGJrT3drUWdXVnJl'
    b'MWRIZGQKNzRqYnB4QnhscVpIM1lSaWNpMjhlS2g1Zm9vazZOTXlhZWdMYzFOZW1KdHlLMjNT'
    b'cVVnRUM1dkF3OXBjcU1pTzVrTVFSRVdSbFZuUgpLNjhvVUNHUzVNbE9Bd1JCelFPV0VGZHVE'
    b'VW5adVhsREdrQ0x6anJqdmFNaGZVeUEvUzNhOUxjckx4dEdKajN6bzlPZE9wTHhqQTVuClBs'
    b'T2EvRnBaMmlQWk1Vd2FhcnQ5aWF3dE91dWFMODlOa0psWFVkOTcyNjNvUmIxdDdGdW5rRzFs'
    b'NDdjTkFZbWp6K3c4ZG1udzl1K0YKSkk5Z0pQdTlvNXYzTms2UUg0VVR4SStYQmd2K2RHemh6'
    b'bFBYbVVabGNuam1mVlNsSG8vc3lvdjZ4M2JYM3NZQjNWM1hlOS9ISjhhKwp0UW5rN1czOHR1'
    b'RzJVN2kvUlR2bGpYODlkNkJwM0RRVWpkbXg5SlBUNUNEdDBkMjFZOWRKMDRERjdadm9SUmhN'
    b'ZnJXcXM3cWt2OTgvCjhXM1JVR1JtZk1SY3BUaFp6Qkd5TVFxQ0RJNjR0QlpYVFkveFlPdkFX'
    b'T2JrWWN3VkpBTnl1RzFnYkg0VW5ZbyttQkZWa2lTS0NtTTYKdlg2MVlXUmZzL2JZcGNHUWEv'
    b'OWUxOU5uZGlaRXNNbHh5TDdtL3BBTWdhM0ZTdlRLL3QrbXQvNnpXUnVpMTVTclpQT1NKVEll'
    b'dytuMQp0K210bjlmMnRPbXRHQVY1K3A2clN0QTVqZkZveDZnMWtTUmtSNFV4eVZzQWowNU5s'
    b'ZkxHVzF2RThjdERveFlLREtkSnVYbXhBaW1YClFhY2lnelozUTcrNVNqMDBWckJFRWZpZUJH'
    b'R3ltQlBCd3ZvdHpoYWQ5V3gzcUlnejhNcjk1Tnl6RzZZUTRHZEhDSVhnczVoZlBDYnkKU0lW'
    b'YzFoUHpaL3k4OStjMnZKVVVWdmN6M29ESFN5bmh0L3k4Zy9CbTdhSy90UmJkcWpzRDhJdGNo'
    b'VU5XKzh0ZkgvdTU3M0FHQk0wQQpQTjJHb0FMZ3JnWDYwa3N2a2VXdWQ0K0ZmdnMwSTVyLzBE'
    b'VDVtZTVoTHAyNllYWmlJQ2VNejZSdEsxYk9UNUh3Nk5RMnZVMGV4bnkyCk5MbEtiY0FKWW42'
    b'S1pHMWUvQlFKVjIyd3I1K1ZVS29VVDRzS3ErNDFRaEFrWkdQL1daSThPMEdJRTBUWkZHbTMw'
    b'VUdub3F0eTRtcDcKalF3cStscFpXb3ZPT3VMMkZTZUpmcDBkODIvMTBIMVRwT1VxV1dPLytk'
    b'WDcwa3FWNGhRSnQ3SFB6TVlvTDkrYld0OW5kbnI5TStNaQpOc3hPbkowUU1XQjFQVG9qZHRq'
    b'dUdYWjRucCtUVXFjeGJTeElDblJkMDJzSyt0eGxVNlI1c1lMeldvdEt5dHRTcENoUmlNTVpO'
    b'SjNOCjlZZjVVMHFWNGhnKzY0TFdraE1qK0krWkNkblJmSmZQdnlvbnJ0dm9zTHE4TDkrYnFy'
    b'TzVIcDRlYzdiSG1DRUx5NHNUMEZCa1kwRlMKZGpRZmdhRmVreU9jU1ZzL015RVFBR0FVNUtt'
    b'Q3BJVnBrVGdCT1R5K0YrZE5LVldLRXlMWXpRUFc3V1ZwcFVyeDFNaXd4bjZ6RHlmeQo0d1JM'
    b'MHFPcWU0emhUTnFhM0RnR0RjMlBqV2dlc014UGtZZzRtRUxFV1owYmx4M05Oem84NUx5eXJV'
    b'VktzaHc0K1NyY1VxVFlYcWFLCjVERTRHR1Z0WG55Z2NtMWVmSVlzckw3UEZFalJlWGg2OUpZ'
    b'aVJYR1NpTStrZmJvaSs3eldQRFRpem9uaHI4Nk4wOXV1cHZHOHZrQWwKWU5IYTlWYUNnTmJr'
    b'eFFsWU5ENlR0all2RG9LZytTbVN6WVdLWlpseUNJTEtVcVV2MzVzYUhjNThxaURwMmRKa0Jo'
    b'VmRsUk5YcHpFOQptQ0ZmbGlsZnFJcmNYS2dvVjhrb0NMeDNkWDVEdjZteDM0d1R4SnJjK0ow'
    b'UFpjRXc5T1RzeEx3NHdkcThlSExYQWJ4V2x2Ym0vVk1wCkNLd1VjZkppQmVlMTVnK1daS1NJ'
    b'dWIrYUZsMm5NWldyWkJ0bUo3NjljQ29Dd3lhbmh5Q2dEYk1UUDFpU0VaREtFZ1RzOXhkbkxF'
    b'aVYKcGtxNDg1SWxmNWlmeXNXb0pxZkhUeEFCUFd4VlRteWdsOStWSkdkSDg5c0hiUldQNU1S'
    b'SHNKZW1SOVZwVE92eTQrY21pNTZZbFZpbgpNYzFSaWgvSmpvRWdhRnV4OG8wRktpRWJDMmRR'
    b'MStYSDU4WUlQbDJablN6bUZDUUlzK1RoSHo0NGJjVHRNems5dDJSSW1UVDBuZ1RoCmpsUHF4'
    b'U29adWQ2SDQzd21MWmJQQ3Noanl6UGxieDVwZnlCZHBoQngydlcyM1hXOUZmVzlMcCtmSUNB'
    b'YWl2U2FISUhnTTAzQzNYVzIKYTA5ajM2a3VBd1JCaTZmS2xxVC8xT3p5VFBrYmxlMkJKRUVo'
    b'QytzMjJvdVNSRk1rM0lDWTRNT0p6bUc3WWNSTlE1RXJaOHFpd3BnMgp0MjlmazlidHd3TlpV'
    b'aUkyZmNXMDZNQWxnZFdnTVRtQ2lxVkN5RUVSK0V6M2NHR2lDSUlndHc4M09qd2VQMDZqd0Jh'
    b'WGQwOWozNDVUCjZ2eFlBUldCcVFnTVFWQ1B5UTVCVUlxWUc4eU02aGl5dmI4NEl5QzAwbENF'
    b'UmtFZ0NCcjdCVk5PREgvSEtmVm5OZDBYdEpaNFBzdUgKRXlhSDErSHhZeFFVSndpVHd6dmk4'
    b'ZEdwS0FlajVNUUlkcDN0V2tSS3JlczAyUCswSkJPK29xSUVIaVJ3SnpkSjRYMHBVcXZieTZO'
    b'VApIMGdmUmVISHB6dS9PZDhYenFUdGVTeFBJZVRFUjdBcENGeXVraEVRUWFNZ0lXb09pWGdD'
    b'SXlYZ3lIaU1LQjR6TUZFQ3c1UVZGUzdoCjBrVWNiRTlqMzFNRlNSZTBacTNWSldMVFdUVDAw'
    b'Um14WFViN2tRNTlTWklJSjRpaUpCRUhvOEFReEtTaGorZkhMMHFUUVJDMDZidUcKMXhlb2ds'
    b'bzJGVUVDUzc5KzY1elZ1WEVQWmtUWlhENGFpZ1RtalpoRGYzNU95am1OcWZzS0Iwd3E2c1dK'
    b'Z0VRUzFIZWUvS2IrajBzeQpBc1hHUHZQMzdicXR4Y3FmWkpFclhZUXFYaEFVRUV4Z0dJSmdp'
    b'SU5SbnBpVndNWW9sZTE2Q2dLdm5CNmRIeXY0dkxabllWcWsyZW5oCjBhbms3Tll2RzNxcEtC'
    b'SjhxVExwbTZiSktWeVdLZjlYbSs1c3ozQ3FsTWVsVThVYyt1UDU4V3R5NDZSY3VzM3Q2elU1'
    b'VUJoK01DT3EKOHFLK3grVFFXcHg4SmhZdllHMHFTRnFYSDgrZ29pZ0NqM2g4MGVITXdHMVU5'
    b'eGkzRkNyVzVNWUZrbmYvZk9MeW42b3VCU2JLZWExWgphM1dlNkJ3cVY4bkVIUHBYRFpwMEdh'
    b'OUtiUml3T2tWc3pPVHdidnkyNGJmL09GK2NKRHJkUGF5enVXcDZqTk9pd3BrMDlMR2N1T0Qz'
    b'CmtoY0hiWi9WZEljeHFGNmNDSFF0RDJlK2NMQjUybjlWN2pyYnRTeFRmcUJGKzMyN2JsRmFK'
    b'QXpEOVgybTFSWG5wc3ZES1FqQ1o5TFcKNWNldm41Vnd0RVB2eFFtdm4vQVRST0E5L2ptTjZY'
    b'Q3JMamd2bnp2UUhOaUh2SDdjaHhOZUhBOThTZUwxNDVFOHh1UDU4YXR5NHM1cgpMZHRLbEw4'
    b'dFVtVEt3anVIN1gwVzU4UC9XeTFpWTN3V3plSHhyNnFvdGJpOGNYeldza3o1NFRiZHlTN0Q5'
    b'T2h3TGluRjVQR3Y2bUw1CkxBaUN2SDdDN2NQeEszZHlrKzZNaEV0LzkxakhtZTdoN21IN2dO'
    b'VjV2dDhzNHRBeEt0bzBZRkZKZVVJMjl1YVJkZ0tDUHEzcFB0SXgKMktxM09iMit6MnA2MHFS'
    b'Y3B4Zi9vVjF2OS9oNWRLckhqd2ZTNlU5MEdvUnNqSTFSdW9idG5jUDIrajZ6dyt1M3VYMTZt'
    b'M3RmczNaLwpzN2F4MzRMQ2NNZlFTT1ZGdmM3cTJ0OHkwRzIwZHhrZC9SYm5PWTBKZ3FCSUh1'
    b'T2I4MzJIV2djdWFDMEVCTzA2MjZVVWNRNjM2YzczCm05V0drYm8rODNIMWtOWGwvZTU4bjl1'
    b'SEI3c21JSWhPUmFrbzhzNlBGMnQ2alNNZTMwVzlyZHZvcU80eDJseStBYXZUN1BReXFPaS8K'
    b'THc5OWNhNm5WV2NWYytnSURQV1lITjFHZTAydnNVcHRzRGk5SnpvTitoSFhCYTJscHRlb050'
    b'ajNOMnRGSERxS3dQMFdwOGJzdExsOQpBMWFYa0Uybm9jaDd4enRZTkFxS0lHOGRiVmNiN0dh'
    b'bjU1ekdwQjRlOGZxSkxxTzl1c2ZZckxQU0tZakw2My9ueDR2VlBjWmVrOE5nCjkvU1pIRFc5'
    b'eG02am83SGYzS0t6Tmc5WWoxelVTN2tNQ0lJNmgrMFR1RE9qTk5KaHV5ZmkrWDNBVGIvTFlk'
    b'aStpUHloOWloRHltZlMKSnNodkI3Z2JJT1hTK2FPek5VZFJDTVBRNzBxVVlKanVabXdyVms3'
    b'eXV6T2I3MUc4VnBhR1VZQnFjOWVCaWlMUHpVa2h2OVFjWnk4TQpvcy9zUE5FNVpIT0JIL0M2'
    b'VzhDaFV3b1NoTEx4dnRDRHdmKzFCekkzQUtBUUFGQUlLQVFBRkFJQUNnRUFoWUJDQUVBaEFL'
    b'QVFBRkFJCktBUUFGQUlBQ2dFQWhZQkNBRUFoQUtBUUFGQUlLQVFBRkFJQUNnRUFoWUJDQUVB'
    b'aEFLQVFBRkQ0L3hEL0J4OE8xS1ZrNGxPUkFBQUEKSlhSRldIUmtZWFJsT21OeVpXRjBaUUF5'
    b'TURJeExUQTBMVEEzVkRFNE9qTTJPakk0S3pBd09qQXdMUithNGdBQUFDVjBSVmgwWkdGMApa'
    b'VHB0YjJScFpua0FNakF5TVMwd05DMHdOMVF4T0Rvek5qb3lPQ3N3TURvd01GeENJbDRBQUFB'
    b'QVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxNTM3MCIgLz4KICA8L2c+Cjwvc3Zn'
    b'Pgo=', 'FR_GES')

FR_GES = b64_FR_GES
index.append("FR_GES")
index.append("France Grand-Est")
catalog["FR_GES"] = FR_GES
catalog["France Grand-Est"] = FR_GES
country["France Grand-Est"] = ('FR_GES', '', 1)
lookup["FR_GES"] = ('FR_GES', '', 'France Grand-Est', 1)
lookup["France Grand-Est"] = ('FR_GES', '', 'France Grand-Est', 1)
details["FR_GES"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_GES"] = ('FR_GES', 'France Grand-Est', 1)
regional["France Grand-Est"] = ('FR_GES', 'France Grand-Est', 1)
#----------------------------------------------------------------------
b64_FR_HDF = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTM3NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9SZWdpb25fb2ZfSGF1dHMtZGUtRnJhbmNlLnN2'
    b'Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1l'
    b'c3BhY2VzL2lua3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNv'
    b'dXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRw'
    b'Oi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgog'
    b'IDxkZWZzCiAgICAgaWQ9ImRlZnMxNTM4MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAg'
    b'ICAgaWQ9Im5hbWVkdmlldzE1Mzc5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBi'
    b'b3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5r'
    b'c2NhcGU6cGFnZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2Fw'
    b'ZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBp'
    b'ZD0iZzE1MzgzIj4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdo'
    b'dD0iMTAwIgogICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxl'
    b'PSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0i'
    b'ZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJr'
    b'Q0FJQUFBRHJPVjZuQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFn'
    b'SVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dE'
    b'L0FQK2d2YWVUQUFBUgo4RWxFUVZSNDJ1MmRlWHhUUmJ2SG41UGtaR3UySm1uVGRFdjNmZC9Z'
    b'b1FYS1dwQUNRa0Y5VmNUWCt5cGVMM3dVQldTcGlpQlh2WGo5CldMd3U4Q0lmTndRcFlnVUtV'
    b'dG1ocFpXdWRLUDd2cVRabWowNTk0K1RobElrVkN6UzZ2eittcE16Sitka3ZwbVo1NWxuWmc1'
    b'R0VBUWcKaldWUlVCRWdoRWdJSVJKQ2lCQWlJWVJJQ0NFU1FvZ1FJaUdFU0FnaDB2MkxOdFov'
    b'Z01WS1hLM3ErclcydDAydU5acXRMbnhtcUpjZwpKVXJLWWVFT3J0S2JWQTE5MTVTNk5xMVJn'
    b'Vk5aSEliSW5SL2h5Z2xBQ1A5VTlldk5IeDRyLytTbnloNlZmc2dwQms1ZE5FRzJjWG1NCnJ4'
    b'dDN5S2t1VGUzbGh2ME44Z0tDc0E0NXhXTks0cjJXUlVyblVyQ3hWQ3pZR0kxVVhLM3Erc2U3'
    b'Wjl2bFdnZDVjQ3JsclNjVC9qVS8KbER3a0NPdUZ1cytLV2c0VDRPZ25DOW15QlJGYm5WbWVD'
    b'T0VEMUxHclRhdis1NXpCWkNFUE9TdzhOZGJEVjhKbE0ybnRjdTNaMHZiYQpOcFU5OCtQVEF6'
    b'NzRqd2s0bFhLaDd2TnJ6ZC9hUDNmbEJManpJNXpvUW92VjFOTmYxOWhYYUxMWWFqT0R4bGtV'
    b'dVYzS0MwVUlINGl1CjMreWR2Zm1Fem1BR0FEYUR0bVZsN05PcFFTekdiVTFmWGtuNytzK3ZW'
    b'clVveWNPWnNSNEhYazZtNDZhY2l1ME44bngzZmtTeS83OWMKdVlHREx6RmFkRVV0aHdvYXY3'
    b'WVFaZ0JnMDUxWHhIM0laYmdpaENNc3M0VVk5MTlIYTlxVUFDQVJzSExlbUIza3dmL05uRHFq'
    b'WmZYdQpjOGV1TnBHSGNRSGk3emJPRVBId3FxNHpJYTR6TU95M1RmRjJWVVYyNmVzR3N3WUFa'
    b'TTd4NlZFN2tGTXh3dnJpNXhxU0h3T25mcjk1CjV0MzRBUUNMVGozd1NySzlJeXlxN1VuZCtG'
    b'TmpwelpVa25vM2ZnQWc1WVhOQzl1RUFRWUFqWDJGVFgxRkNPRUlhLy9wYWpMeHIvbWgKa1Q3'
    b'Q2UvdzJESHRuVmRMT3B4TXBHQVlBZFIzcTFFM0g4NnU2SFY4bGM0NFBkazBoMDJYdHh4SENr'
    b'VlJyci9aNlhTOEFZQmc4bnhibQpPTFBPWUY3M3laV3FGdVh6YVdHZnI1MUtwMUVBb0V1aG03'
    b'LzE1UDdUTlk2dmpmVk1KeE1OOGdLeWEwUUlSMGFWelFxeTQ0NlFDZDJjCldRNXlkaXAwODdh'
    b'ZS9PeGsxYXhOeHk5V2RDNlo1UFBkcHBta3MyOHdXVjdjYyttbGp5K1RCdEZ2U3NJTll0SzRB'
    b'R0MwYU5YNkxvUncKeE5UUlovTUNQY1JzQjluT2xyWlBlZmxZWVUwUEFQUnBERWN1TlFCQVNw'
    b'VDA1RnR6Wks0Y01zKytVOVZUMS85WVhDKy9tNVhIWTBySQpsTWJRZ3hDT3BEbHFHMUtpL1Ba'
    b'amEzU21EZjh1ZUNUelZFZWZqbXh2TjYrTWZYZjFPUEpzcEkvdzdLNjBsQ2dwZVZqVm9wenhX'
    b'czdPCjc0cnQvdVZnMmR0UENrWkJDRWRNOXNhenNrVnhKOTJ2ZnJtWitGTDJSOGNxckFRQkFB'
    b'SU8vY3YxS2E4c2licHQ1SVhMK0g1ejZzYU0KR0JvVkF3Q2oyZnIyTjljbnJQc2hyNlI5Y0Rh'
    b'Q3NHb01OcXVIVFhkR2Z1R0lxVmRsT0h5eFh1TE1rZ2hZNDBOc1RuZWZ4dkRkK2ZvOQpPVGR1'
    b'dHQ4YWtSa2Y0dnJaUzFPOEI1ck5PM1d0cG1mMTduTjFIV3I3SnpOaTNGL1BpSTBQRkFOQW03'
    b'THM0UFYxNURETmN4TVBqdkloCjA5R0lVRyt5Wk93NFE4Y3BzWDZpV0g5eGJJQklJcmpOZUZG'
    b'clRkV3R5aXVWWFhrbDdXZEwyd2UzaEFJT1BmUHgrQ2RuQnBLT2hDT1QKMVdoNTczREo3dXd5'
    b'bzlrMjNrMmxZRC92bUJjWElQNmhiR3RkNzJVQUNIWk5tUnU2QWRYQyt6QmJkRUdyRHc3K2hF'
    b'YkZoRndtbjAwMwpXYXlLZm9OQ1k3enpLZzRMZjI1dXlJc0x3NFZjeHZEdlZkMnEzSEtnOEtl'
    b'Q1pnQjQ3OW54ejg0SnJ1NCsrMVBGZHZMc3NwajMzZmtSCkNPSHZscFVncEN1LzFCa3R3OHdm'
    b'NmlWNFlrYmd5bVQvM3dWdnNQS3J1a3NiNU0vTURtNVZsaDRwMldpMkdnREFYenh4UWZpMmF6'
    b'VTkKRFozcStBRHhuWEVyaE5DUkpxejdvYnl4RHdDY09ReU56bVN5M0JiYnd6RHdGSFBDWllK'
    b'cEVkS1VhUGN3YjhHSTNMUk5XWjVkdXRGbwowUUVBanluSmlQdlFZbklhdC9ab1MwOC9BSWg0'
    b'alBnQWw3UWtyNmRTZzBaVldZM1NqanBBeWlNUmJsZ1d2WHBPU0VlZnRrOWpNSnFzClZBb200'
    b'TkJkQlN6MlFHakNZTlpvREQwY2h2aVBEdjBveTdKTE41a3NPdEtLV1JpUnlhVHgvN0g3TE1t'
    b'UE5LWnlpMXB5aTFxaWZJVngKQVdLRThCNXlGOW1jOXh2TkNpb0Y4eFE3ZVlxZGJtOXNMVmNh'
    b'dm1oUmxuU29LbGs0ZjBuMExpSGJlNlQ0TFlsNlIremtaekJaTXFiNQplWWpZRjhvN3l4cmxa'
    b'R3NsRWJCQ3ZVZVhtekZLL1VMWEFSTjAzNm5xNlJ0eWh2aHRBRURCcUI3OHlDNTFqWld3OUJ2'
    b'bGg2Ni8zTnZmCmVOL3Q1OUZCL0JaSDdTQkRpUXljbXBiay9jNnFwTXpINCt5OXpZNm5FMWww'
    b'S2tKNGJ3VzY4K3pwd3BxZVJ6SnpYOXh6YWNpb3BreVkKa0JhK2xVYWhBNERXcERoYy9NcDlV'
    b'QnpjLzVIOEpOemcyM3dQZzNudEoxZklkR3FjeDlMSnZxT3RyS2pidG0wYmhRaURQUVh6RXIw'
    b'cwpWcUtxUldtMkVnQlFYQ2YvOFdyejVBZzNGejd6bGhmSThuRGxCdGIyWExBU0ZwTlZYOXQ5'
    b'M2tlWXhLWUw3bzlmZXRRT3Q5djVBVURtClYwVzVSYTBBd0diUURtK2F5WGVpSTR2MDk2bStR'
    b'NzErYi83SndoYTc1NTY5T1hXSU5kRWdML2l4UE5Oc05RSUFHeGNzaWY1dmtaUHMKZC9KelNv'
    b'L2FlU2Uva25wNThxcy9rbU96MjU5TWVIRmhPSElxN2xPSEx0U3Z5YnFrTlpnQlFNaGw1TzJj'
    b'UDhSTHU0MGkzWGxKMUM3SApGTnRWRlVkS05qam1SeEF3Yjh1Sml4V2RBQkR0SjhyYk9aOGNX'
    b'UjF0R2h2RDNFc24reDUvY3c3WmlNblZoaFh2bkJrU1h2QVJKdDdxCkY0MTloMHZXTytnWGg4'
    b'TVBBSTVjYmlENVVURHNnK2ZHajA1K01JWWlGYkgrb29NYlp1QlVDZ0JVTkNuZVAxSTJKTU9k'
    b'Rk9YYXh2dm0KWjdKWXR4d29KTk1yVS94SGxTTTRWaEVDd0lSUTE5ZVdSNVBwM2RsbGNyWEJN'
    b'Y1ZEeFVNcERwTWZBQnc2WDkvVXBRRUFEZ3ZmK2xqYwphQzZXTVRiOWFlMmlTREtFcERPWTkr'
    b'WlczNW5CQWNYaDg3TVN4UHRIU3NuMDZ0bkJRK0lrQ09FZkcweWlZdjg1WUJhU015cUdTWEVv'
    b'CnY4Z2RkK01IQVBsVjNlUTBZaVpPZldGQjJDZ3ZrN0czT0czUkJCa1pDaXhybEhjcGRIZWpP'
    b'QzlzRXhXajJmckY0bGNIOGVPa1IrMTAKNDRVNHVNVVBWMndWZCtFRTJTaXZnbU1Tb2F1QVJj'
    b'NEFKZ2k0MGF5NFd6WS8wWVFGRVpsVUNnNEEvVWI1b1ByM3RvUDZSNG9NSHdMQQovRVN2MFY4'
    b'Z1kzS0pxTjBwYk9yV09Nam1JMHhjRUw2TnBIaXIvWFJZLzhoZXRyNVRUZm9TcWJFZUNPRURF'
    b'WWRwbzJJd1dSM245QkVtCnpnOTduVVpoTUhIZWNQZ0JRRjJIMmhhVWNHWTVYbWM2V3V5RHNZ'
    b'alFORERiNVo0VFpNZ1c5Y21rdlRRS25ZWHpoL1BsNUFSR0dCVHcKUWdoSFhvMEQ3YWU3Y0Zp'
    b'bHpHVzREUC9MV1F4YkxBa2JJNlV4OWhwU2s4VmFQYkJ3MEU4Njh2TlplR3hiTE1MeEVtS0U4'
    b'UDUxdGJMYgpQdDRkNk00ZjhlKzNleEdkQ3QxdlR2UkdDUCtvamc0NGJjbVJVdXdCTkhZdWZH'
    b'YUFPdzhBekJiaVVrVW5RampDMGhrdEI4L1ZrZW4wClNUNFA2QzZUdzkzSXhQR0JPQ1ZDT0dM'
    b'NjRuUjFuOFpBMXBYWjhROXFVNHFwRVRhRU9mbk5GaXVCRUk1a0ZiVEhtSjZkRzhMRUg5UTAK'
    b'cExSeDN1U3M0dVp1algyd0RTRWNBYjEzdUlTMEV2bE85T2ZtaGp5NEd6Rng2aFBUYmZ0aDdN'
    b'NHVRd2hIUnJWdHFnK09scFBwOVV1agpuRG1NQjNxNzFYT0N5WEdEWDIvMm5pL3ZRQWhIUUh0'
    b'enErd21mb2luNEVIZnJrdWhZdzdNRjgwcmJrTUlSMENyWmdYYlY3MWs3RHh6CjRFek4vWDFQ'
    b'dDFKZjM2RnU3TkpvZEthNzVUbDJ0U2x0V3k3cGZZcDRqS2RIMlNLS0lScExTMFNMYW5zV1pw'
    b'NVNhVzByMDFZbSsrOTYKSnNrK21PSlk1OG82OXVWVy9WTGEzcXN5RFBiaUkzMkZVeVBjWnNa'
    b'NlJNaWN5Y3EzNVVEaDEyZHZrcVhDb2xPUGJFbWRHQ3BCQ0VkTQpGVTJLcGR0UDI1ZXFTQVNz'
    b'ekNmaU02YjVPUmp2Vm10TkwyUmR6TDU4RDhNeTFFc3dOVkw2emRtYnluN2JYMFRFWTN6NzJv'
    b'eWtZSmRSClhpWmpidysySHBYKytZOHVucmgyeStrT2RPZXZUWTlZTXNsbnlFNXNBS0EzV2RL'
    b'Mm5oeXlYUkNYaFFPQSt1NE5LZWthWnIwd3ljRlMKYjRUd0Q0a2dZRzl1MVJ0Zi9VcTYrYVE0'
    b'TEh6UkJObnNlTThwNFc3Mlh2Tzk3MHN6djdSdHdqVTkydjNGaGVIalExeWRtRFFBMEJuTQo1'
    b'VTJLcTVWZHViKzJYaWpyc0M5aGxBaFlHek5pbnBvWmhJMlJVQVUyZHQrYzFxY3g3RHhZL1Bu'
    b'Skt2dGllWnVGaG1FQjdyd2dENzZmCmxMczN0NW8wVzE1ZUVybGxaWnlEbXYzZCtmb1QxNXFu'
    b'UkVpZlR3dGxNOUNXc24raU9oVzYvYWRyOXVWV3RmYmVOVGJrNThZdC9EQ2QKU3NIZ3J5anNy'
    b'L0grUXJPRk9GL1dmcWE0UGEra3JheWh6M3I3ajFxeklPenRweExoTHlyc3IvY0t5bDZWb2FS'
    b'Qlh0T3FiTzd1NzFIcAo5VWJ6dXNXUjk5dzJFU0ZFUXFNelNQZXJoMmw2YVUwS2NvVTdrOFps'
    b'MEd3ZW1FcmZ3V0c0VUxCYmdhUXVUUzBWbzRtY2ZCQ3RVWWZ3CmJHMVdvN3lRVG1QM0czb2Zq'
    b'WG5malJkUzIzMitUOWVhNkoxeFc5L1dYMCtqTUJEQzBZZ1FBT0s4bGlaNXIvajA4b3BlYllQ'
    b'RzJIdXgKWVI5T1lRYTRURzVUbGhVMGZVdWowQk84bDJ1TkNwektiRkdVNU5WK1NCRFdTYjdQ'
    b'NEZUbXVadi9wek9wWWowWEpYZ3RSMzNodzFSKwo0MWQ3THFhN2NQd0R4Sk9MV2c3em1WSXFC'
    b'YS9ydVh5dDZXQks0Qm9QZnFSQzI2b3g5R2lNdmFYdE9hR1MxQVN2NWRkYmp5aDByVHltClcw'
    b'cmdDeVZ0T2FnV1BtU0VTYktWOFY3THVqVzFCR0dsWWpRbnVqREdJOTFmUEJFQURHWU4rYklC'
    b'bSttTVVheUV4VXFZTVl3S0FGUUsKVGNCeXQxaU5DT0hEUk1oanVqblJoWW5lR2U3OGlQS09r'
    b'K05rajNkcmJoYTFIS0pnMURpdnBRVk5YN2NxU3lrVUtvY2g1dEJGc1I2TApidlpjTEc0N2x1'
    b'QzFqSVVMK0V3cGpjSVFPL2tpaEtQVUwveWxOa3VoYSsxUVZTNkszRDZjdFN3STRhaVR3ZHl2'
    b'MG5kd0dTNU1uSWNnCi9YMUhaMnJiVkRRcTVpUGgvclVSUGt5bllrM1dwZnlxN3Z3UEhnR0F4'
    b'M2JsOWFvTUo5NmFjOCtydWhTNnloYWxmYmF1QTczMDhXVWgKbDNIZ2xlUzdaWmk0N2dmN085'
    b'WjhKRnp5U1JEQzN5R2oyYW9mbUpSbU1OblNOVzNLbTIxcWpkNDBQc1RWVSt4VTFhSlU2MHdK'
    b'Z2VMeQp4ajZUMmNwaDRSazd6N2dMMlJZck1UN0V0VjJ1TGFydEVmT1pjZjZpd1pOb0x0M29s'
    b'S3NOYXIySmpQMnF0YWE4a2pZTXc2Wkh1NVB4ClhsSjZreVhHWC9UUHVTRUF3R1hoZFIzcWRy'
    b'bVdJSURMeHRrTTZ1REhNRnVJNjNXOURaMXFFWmN4TFVwS3dUQ2oyWnBYM0tZeldxSjgKaFg1'
    b'dVhITHo0QkF2QVRrSDUyL2sydmVvOUd1eUxnRkFSVk1mdVlIbGEvc0tXcnI3ZTFSNm5kRlNr'
    b'clY0VDA3RnRacWVDKzh1ZU8vNwowbzQrYmJTZnFMcFZXZDJxL0tXMC9hYzM1cVMvZVNyTVc2'
    b'RFJtVDk2WWFKOXoveVBjMjY4dWk4LzNOdjVSck5DNXNJeG1DelRYdjNSCllMSXljZXJ1N0xL'
    b'ZmQ4d2IvQUFDRGozS1Z3Z0FnZTc4Tjc4dWV2LzdNZ1pPV2JzNHNxQzZlL0Jqdkh1NGRFOU9o'
    b'WkRMNkZVWjFpK04KMnBnUms3YjFaSEc5WE1paFB6MHJtTS9HTi83N1drS1F1S2kyTjN0TDZx'
    b'UXd5ZDhJb2Rsc0piY0gwZWhOcnNBQ2dDMHI0ODVjYit2WAptM1lkS3Fsc1ZnN0p2K09weEN1'
    b'VlhRRlMzcWN2VFRsVDNHWXdXUklDeGRPalBSS0RYR1p0T3E3U0dsZk5DczRwYUU2T2xCN2RP'
    b'bXZ1CjVoTUFVTkdrcUcxVExab2dvK1BVZytmcVRsOXZlMzEvQVFBYzJqUVRBRTVjYXlHbjRY'
    b'Ui84emdBY05sNDdlZkxHRGkxdUY0KzVERmsKcnR5U3JNVkx0cDgrWDk3UjB0MS9wYkxyd0N2'
    b'Smo0eVhBY0M4TFNja3pxenhJYTROblpwelpSMS9MNFJ1UXZhcHQrY0N3Tkx0UDVPdgo1RTEv'
    b'NDVTZmxFdFdLYlBWU3FOUzdweW5SSzVVbVJvaGZlT0orS3RWWFkvdHl0djkzUGlVS0tuV1lB'
    b'bHc1eGxNRmc4Ukd3YVdjWk9yCnVwbDBtbFRJV3BzZTRjSmpwc1o2QWdBNXUySitrdGV1VlVr'
    b'QXdNQ3BBTURFcVdSaXlHUFlieTBSc0RyN2RPUlVEKzdBU255emhXRFIKYVFDUU1jMHZNVkQ4'
    b'OTJwSWg0Z2dRR3N3MDJrVWJHQ1pkSWlYNE5NVGxTdmVPVk5ZMDBNdSszUGhNMysrM3ZyUC83'
    b'M3c4cExJaWlhRgpyNFJMbzJJVUNyWmhlUXg1eWFsZlcvZWZybG1UZGVsR3MySlNtQ1RNV3lE'
    b'bU1hdGFGQXljRWlGemp2WVRSdnZkQ3YreUdiaVhDK2VlCmp6RkVNZ25IeTRYejZ0NzhTQi9o'
    b'bkhqUHFSRnVXVGszdWhSNnZkRThidkdmL2VMUmg3bWxMSVpCaUNjL0lkQUZBQ2dVTEZ6bUhP'
    b'TXYKaXZFVEtmcU5aaXZ4NkJUZkdURWVDWUZpRGdzM21hMVRJcVJQelF6eUZEdEYrZ3IxUm9z'
    b'cm54WGd3Wk9yRGIwcXc0cGsveWRuQnRtbgprazRNbGJBWk5LWFdtQlRzOHVoVXYwQjMvdXdF'
    b'eno2MWdZRlRJMlRDd1crdHhEQXNNY2dsMk5QMkNZMUtDZlRneHdlS01ReUdQQWFYCmpRZDdD'
    b'bUw5UlRpTkV1YnRIT01ubXBmZ3BkR2JHVGcxMmsrMEl0bGY0RVJYOWhzRFBmalJma0t5UmlL'
    b'L0VHa3NqSkVpSVlSSUNDRkMKaUlRUUlpR0VTQWdoUW9pRUVDSWhoRWdJSVVLSWhCQWlJWVFJ'
    b'SWRJWTEvOERVTThCYmthQ1Q5UUFBQUFsZEVWWWRHUmhkR1U2WTNKbApZWFJsQURJd01qRXRN'
    b'RGN0TVRaVU1USTZOVFE2TXpZck1EQTZNRER0RFVFQ0FBQUFKWFJGV0hSa1lYUmxPbTF2Wkds'
    b'bWVRQXlNREl4CkxUQTNMVEUyVkRFeU9qVTBPak0yS3pBd09qQXduRkQ1dmdBQUFBQkpSVTVF'
    b'cmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTUzODUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'FR_HDF')

FR_HDF = b64_FR_HDF
index.append("FR_HDF")
index.append("France Hauts-de-France")
catalog["FR_HDF"] = FR_HDF
catalog["France Hauts-de-France"] = FR_HDF
country["France Hauts-de-France"] = ('FR_HDF', '', 1)
lookup["FR_HDF"] = ('FR_HDF', '', 'France Hauts-de-France', 1)
lookup["France Hauts-de-France"] = ('FR_HDF', '', 'France Hauts-de-France', 1)
details["FR_HDF"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_HDF"] = ('FR_HDF', 'France Hauts-de-France', 1)
regional["France Hauts-de-France"] = ('FR_HDF', 'France Hauts-de-France', 1)
#----------------------------------------------------------------------
b64_FR_IDF = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcyIgogICB3aWR0aD0iMTUw'
    b'IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3'
    b'dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAw'
    b'MC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnM2IiAvPgogIDxnCiAgICAgaWQ9Imc4Ij4K'
    b'ICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAg'
    b'ICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5k'
    b'ZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9w'
    b'bmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FZQUFBQmtXOG53'
    b'QUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2'
    b'QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFB'
    b'UwpPMGxFUVZSNDJ1MmNkM3hVVmRxQW4rbkpwQ2VFaEU0U0lEUkZwSVFxUlFTa0NTZ0lzcXl5'
    b'S09BS2lBVVJwYTAwRWRSbFhaVytLZ2k2CktHSUVSY1ZBcEFzaDlKSUNCQklDcVpNMmZlYnVI'
    b'emRjR0NaQmdwSHZXL2M4djEvK3lOdzdjKzQ5ODV6M3ZPZTlKMUZKa3VSR0lLaG0KdElCS2RJ'
    b'T2d1bEdMTGhBSXNRUkNMSUVRU3lBUVlnbUVXQUlobGtBZ3hCSUlzUVJDTElGQWlDVVFZZ21F'
    b'V0FLQkVFc2d4QklJc1FRQwpJWlpBaUNVUVlna0VRaXlCRUVzZ3hCSUloRmdDSVpaQWlDVVFD'
    b'TEVFUWl5QkVFc2dFR0lKaEZnQ0laWkFJTVFTQ0xFRWYzUzAvNTh2Cjdzdk5TWmhNWlY2dmg0'
    b'WDUwN3haSFpvMGlxajB2U3ZXSkhMazJFWG12RDZZbXVFQlZXbzM2M0loMzI4L3dlQ0I5eE1h'
    b'NGljcythT0oKdFhiOVhzNmR6OFhQMytEeGVuR3hCWlZLeGVDQnJaazdhd2dxbGVkL3UweE52'
    b'OHFISzNld2FPNndLa3NGY0NFamo3ZVhmay9uRG8yRgpXSDlFc1FBYU40N2d5L1hQZWJ4V1dt'
    b'Wmo0ZUt0ZkJWL21BN3RZeGp3Y0N1UDQvdjJwek4zMWhCNjkycHhSMjAyaTYzTjBzVlBVTHQy'
    b'CnNERGtmeW5IOHZjejhQS1V2Z0FrSDhud09DWkpFaDNhUnhOUk01Q2MzSklLMys5MlN4dy9t'
    b'Y24ySGFjNGR6NFhnT3dySm9xTExRQUUKQnZyUTV2NkdHSTE2ai9mWjdFNlNqMmF3WjE4cW1W'
    b'a0ZYcDliWnJaaHNkZ0J5TXdxNUpkRDU4aTZYQ2dpMXUrQkt6Y0h5M2RmNC8vbgpaNnIxYzUx'
    b'T0Z3QitmdGVueVRObnMzbGx4a2JTeitVQW9GR3JHVExvZm1aT0g0aFdxd0VnNDJJK3o3Kzhu'
    b'dFQwcThyN1JnNkxZOWZlCkZBYjFiODF6NDN0eTRPQTV4azM4bUUwYkpoTGJKQktBcjdjazgr'
    b'YmIzeXJ5QVhTS2E4U2llY01JRFpXbnkvRVRQNkZ1blJCME9nMWYKeFI5R2tpUUF1blJxekFk'
    b'TFI2TlJxMFhFdWwwY3A0NVhmbENTS0h4aEhNWHZMS2pXaXk0ejIvakhCOXZSYWpYMDYzTXZB'
    b'SG41cFR6egozRWZVcmhYTTFrMVQySjg0Z3prekh1R2JiNC93ejJVSmlvd1RYMXlIMldMbm94'
    b'VmpTZG96bTA5V1BjMzJIYWZJdW15cXRMM2RlMU41CmZjNG03cnVuSHQ5dGZvR2t2Yk5adkdB'
    b'NHgwOW1NdW1sVHhXQkFIN2FlWXJpWWd0Yk4wMGhhZTlzWG5xK0Q3djNwcEt3NDdTSVdMY3QK'
    b'VmNwcGNvZjFKZWkxZWZpTkd1TXR3TVoxMlBidlJoMGNjc2R0WE1qSVkvaWZQbEIrTHltMWtY'
    b'M0ZSSTJ3QU41LzkwODBqYTBGd1ByUAo5K055dVhuN3pjZnhNOHBSYk9namJiaWNiZUxqVC9j'
    b'dzRabnU3TjJYeHJuenVheFo5aGZhdFlrQ29FM3Joa3lmMnA4WHAzMVc2VFdzCit1aG5hb1Q1'
    b'OC9hYkk1VHBzVitmZXpHWnpNeC9hd3UvSERwUFhMdG9BSHdNT2hiTkc0YVBqdzZBTWFPN3NH'
    b'Sk5JbWRTc25ub3dSWkMKck5zS2R3R0JTRFlicHRsVGNadzlTZkRzUmFDUnB4em4rWFNLRjg0'
    b'R1FHVzg4NVdWMGFpblExd2pqOWV5czAxcysvRTQ4VnVQMEtWVApZd0FPSGI2QTBXaGcrZXBF'
    b'ajNNek13c3dtKzJrcGVWd0ppVWJ2VjVMKzdaUkh1ZDBiQjl6eTJzNGs1Sk45NjVOdlhLdW50'
    b'MmJNZit0CkxTUWZ6VkRFaW0wU3FVZ0ZvRktwTVBycUtTdXppWWgxdTJocTFVRWIwd1JuZWdw'
    b'bDZ6OUNjamdJV2JoVW5nSmZtWWk3cEZpZUVjdEsKNzdpTm11R0J2RGlwdDlmcjllcUdzbnox'
    b'VHA0ZTh3Qk5Ha1Znc3p1d1dPeWNPcDNsZFc3SHVKanlhR2ZGMTBmblZaN1FHeXJ2QnF2TgpR'
    b'VW1KbFpCZ285ZXhrUEpTUkZtWlhYbk4xMWN2bG9UVmtid2Iyc1RoVEU4QndQekZlblNOWTFI'
    b'cERkaVREMTVmaFpXV2dpVEJUVitvCk95OFh4NW1UR0xwMHIzSzczUjlveXZMVk8wbEp2VUtU'
    b'UmhGRU5Rakg3WkpZOWNFWXJ5VGZiTGJqNTIvZzZQRkxGSmRZS1RTWlBVUkoKVGJ0YWFUcytC'
    b'aDNCUVVZeUx1VjdIY3ZJeUFPZ1ZtU1FNS202azNmL3YweEFwZE1yeVhyUmdsbVk1a3p6dExk'
    b'ZWZWa3FseE5yd2c4VQp2RENPN0hheFpIZG9obm5McGp0cU55SThFSUNDQXJreUg5Y3Vtak1w'
    b'MlJ3N2tlbHgzdnZMRStnOTZHMmNUamNkNDJKUXFlVENxN0pxCmRidFp1U2J4bG0zMTZ0R2Mz'
    b'WHRUU2JsQlFFbVNXUDN4TGpRYU5kMjZ4Z3FUcWp0aWFSdkY0anQ0R09hTm4xWjZqdHRVU05I'
    b'Q1dWaTIKYnNaMTVmTDFhUEJRUDBMbXYzTkg3UWFIeUJIblVuazlhVkQvKy9oaTh5SEdQcnVH'
    b'NFVQYkV4MFZ6c25UV1h5eDZSQXZQZDhIZzE1TApkRlE0WTU5OGdCVnJFcm1jYlNJNktweTkr'
    b'OU13bWN6VUNQT3Z0SzNKei9WaTc0RTAvangySmFOR2RDUThQSUNFbmFmWnN5K1ZTYy8yCm9r'
    b'N3RFR0hTbllvbFdhM1lqeDNHWFpDUHl1Q0RPejhYZFdnWTJnWlJxQU51UFJXNFRZV1VydjdB'
    b'Y3dydDNJM1FwYXRBVS9rbGRPclkKcU5MYWowR3ZaY1JqN1pIY0VwSWtvZEdvV2ZuUHAxajk4'
    b'Yy84dE9NMFc3Y2RwWDY5TUJhODhhaEhaWDdLeElkbzBhdzJXNzgveHA1OQpxVFJ0VW9zSnov'
    b'U2c5OEFseXVPZjRHQS9Pc1Uxd3M5UGpzUmhvZjU4OXNrRWxxL2V5ZmMvSHFlazFFcFV3M0NX'
    b'TEh5Y2gzdmZvM3gyCnkrYTE4ZmYzOGJyV05xMGIwcUJCamY4cHNWVFNqVVdZV3hVazAxUElI'
    b'LzhubkJmTy9lWkc5YTN1cDhiYXIzN1RhdkZPS0NnczQyRFMKZWRxMWlmSjRCbmo2YkRhUFBm'
    b'RStxejhjUTRkZldTRUtxam5IMHNZMG9XYjhEdnpIUElzNktQak9RMlJNRThKV2JianJVZ0c0'
    b'WEc2bQp6ZGpJd3NWYktTbXhBdkpPaGpuek54TVpFY1Q5OXpVUVJ0enRpSFh6YXE1b3dRek0z'
    b'MnlTVjN0VndLZG5iMEwvdnZKWHhYSmR1VXpPCm9CNjRDK1RWbUtGZFIycXMrNHJDYVpPVmFy'
    b'L1BRLzBJZkdGNmxkcFAzSFdXT2ZNM1UxQm94dC9QZ0tuSVRIUlVPSXZuRDFlS3JiOUcKN3ZC'
    b'K1NLVWx2MzZ2ZlFZUStQdzBJVlpWc1NiOFFPSFV2K0l1TWxYcGZicVdyUWg2ZlI2R3RoMjhT'
    b'aEFBa3ROQjNxakIySk1Pb0cvVgpCdWZGQzdnTDh3bVlNQVhiTDN1eEgvNEZBT09qSXdsWjlG'
    b'N1ZJNWZiVFZwYURnV0ZaVVJHQk5Ld1FRMnYydGF0eUc0ZHJkVG9ib1Z4CjJDaTVyaWVtd2ly'
    b'bVN1MDYzTkdVNWpoeGxMeVJBOGtaMUFQcnp1MWV4NHVYek1PZWRBQjFjQWloNzYwbVpNbjdv'
    b'RkpSc253cDdxTGYKdmx0QW8xWVQyeVNTam5FeFJEVU1yNUpVZ3Q4NVlybHlycEkvN2drY0o0'
    b'Nys1b3ZRTlcxQnlKSVAwRFg5OVdkcHVjUDczVEppU1hZNwp6dk5wNEhDZ3FWMFhkV2pZYlYx'
    b'RDJiclYyQTd1SjNUcHlpcEZMRzJqV01JKy9LVGlVUnNRaUxwR2VBV2Q1OFNWY3hWMVlCQXFQ'
    b'N25NCklUbnN1QzVkeEYxYWd0cG9SQk5aRzVYL3IyeFNsQ1NjNTlPUnpHVm82aldvTlBlVmJE'
    b'WmNtUm1BQ2syOUJxajBsVDhka0d3Mm5CZlMKNWY2cld3OTFjT2pkcTJPNWNxNlFOM3FvVW5H'
    b'L1hmeWZtU2lYSzNRNkpJc1pWODVWVkRvOSt0WnQwVVRXcmxDaWEyMzRqWHlTd0pkbgpWcDcz'
    b'Rlprb2ZtYys1azJmSTFuTTVjTkdoYjV0SEVHdnpVTi96MzIzdnFlclYzQ21uYTM2eU5UcjBV'
    b'WlZ2cElzbURRVzIxNjVBR3Q4CjdBbDB6ZStsYU9GTTNIbTVCSXlmak4rVDR5bCtaejZXYmQ5'
    b'NDVHMHF2UjVEbCs0RVRaK0xOaW9HODhaMUZMMDVSNDY0ZGVzVFBHTUIKaFROZXdKbWVXaDZH'
    b'dFJpSGppQjQ3bUpVV3ZsWnBic3duK0lsOHpESGYzbTlUOVJxRE8wN0VmaktiUFQzdHI3ZWZ3'
    b'WDVGQzJlaTJYTApsMGdXeS9WejR6b1Q5TnBjZE0xYS9yNWl1Ykl1a1R0aUFLN3NyQ3AvQ1Q2'
    b'ZHUySG8wdU8yejVkS1M1VDhUYkphSzcrbTNCenlSdlRICm1YSGVhMFRiRCs0bmIrUUF3djYx'
    b'RVVPN2puZDlTcERNWmNvOTJBOGZwUFJmeThEdGxvKzVYT1NOSHVJeFFGVmFIWkxUZ1dTM1kw'
    b'MzQKQVVmS1dTSzI3MGV5MjYvbnNtNDNlVStQOEh3RzYzSmkzcmdPWFd3ei9KOGFqN3N3bjl4'
    b'aEQzdVhoOXh1YlB0M2t6ZWlQMkdyUDhmUQpzU3V1eTVueWQzbzUwL3ZjZmJ2SWZidy9OZFor'
    b'aGI3Vi9iOVBqbVdPLzVLci9icGVsMHF0UnRlc0pjWWhqeFA2M21xNHFaaHA2TmpWCjQvZVNG'
    b'ZS85TGwrZTZkWEppbFQ2Vm0yb3VTV1J5TVJrZlBzTlZxUTB2VElSWEU0NXh6dDlndnhuUm5L'
    b'bFkzT3U5dTVBeVQrWGdOdmwKOFptV2JmSGtQdGFYN0xpbTVBN3BoV1hMVnhYbmkyZFBrZDA2'
    b'MnV1bjhLVm52YzYxSng4RXR4dVZmd0NhdXZWeFhicW9TS1h5TlZMego2d1Jxbjh5a3hyck5T'
    b'bCs2TWpOd0pDZDVmdDhseGVCMll4dzhISjllRDN0ZTkzZnhBQlRObjZsSXBkTHFDQmcvbWFD'
    b'WkM5REdORlpTCkJ0T3NsK1VOQXk4OXEwaWxhOWFDbWw4bkVMbnJLTVloanl1RG8zRGFKR1ZB'
    b'Vkd2RWtwd09pdCtaTDFmYUE0TXdkTzJKYjc5SDBOYVQKYXo5U1dTa3F0UWFwdkhGZHM1YlUr'
    b'T2dMQ3A1L0dzdTJiK1NPUGJnZmQ1SHBOOVhCdkFxMzU5S3dKbDVmQUlRc2ZoOXR0THpOSm1U'
    b'UgpQN0FtYkVPeVduRmV5c0M2ZXllNjJPYmtqaGlBTmlxR3dPbHprVXBMS052d0wxeFptV2hx'
    b'MVpIenJYK3ZwZWlONlFTTW00eXV4YjNZCjlpUlM4T0o0UWlVSjM0RkRieTZPVmJoQ1ZLYWVt'
    b'd2ljT291QWNaTkFwY0oxNVRKK1R6d2xqOUhRTUdXNjBkUUlSNlhSSXJubFhST3UKL0J5dnp3'
    b'bDlkN2tpVmY2NFVWZ1R2cGZQemM3Q1hWSXNsNEt1dGZueURQeWZsdjl1d05EcEFRckdqU3J2'
    b'UENlMnhPM1lEdTVUemcxZQpzQlJkQzNuelpQRDhkN0grdEExM2NSSE90TFBZa2c3Y2R0Uy9i'
    b'YkZVV2gyUk93OVhmdHpQSDNWb0tLNGMrVUZ0d0tTcG9ORVE4dll5CjNDWEYyUFlrSWpuc1dI'
    b'LzhGdU5qVDFTYldQWWpoMjY0Q0JYNVl4Ky95VHpYRGVjbVlVdjhDWlhCUVBpblh5dUpzL0dS'
    b'eDdqYXE3MlMKdkJhLzlRYUJMOC9FLzZueDhoVCtZRi9RYUNoWnZ0UmJMSTBXZGFEM0l5MVZR'
    b'S0QzSXFYNVBRU01uM3o5clpHMVVRY0ZZL2xoSzVZZgp2OFZ4K2dUTzgybEs3ZTdHS2Qxem5s'
    b'Rmo2UGFnUi9ubW1sZzQ3SEtkcnp3Nlg2djNLZWMyYmtyRWppU1BSY3ZOT2VHTmkyUWwzd0lj'
    b'ClI1S3FYNnpiU2VqZGhZWEtTc21ueDBOeUJ4c01oQzFiUi81ZmhtTTd1QS83OGVScUZldkdH'
    b'MGVTY0Y3S3FEekJMOGpEY2VJb1BnLzIKVmFTNk5paDgrZ3pFZm5BZmpsUEhjSnNLY1dWbFVy'
    b'TDhIeDdUaitQTVNWeFhzejFsaVcxR3pmZ2R0OWZaMFo0YkZwM3BLZVNOSG9vcgo1NHFIcVBw'
    b'MkhiQW4vVkxwMUtOU2E2N3ZLQUZVNVpzcmxXNjRLWUtxSzVDOHd2NHJuM29yL1k0TDhuN2ZW'
    b'V0dGaldaZVJITElvVHRvCit0ODhiOXpYbDdCVkc4Z2JNeHpIOFNQVm1sOXBJbXQ1ak9USVhV'
    b'ZFIrZmhXc29JemtET29lNFZicFRYbFpRbkpKdS8wdEI5UFJtWHcKL0h0R1ErZHVTSGI3bmRk'
    b'MmJzcEJpOTlab0VpbGlhaEYwTXdGK0hUcmhVcXZJeXMyOHM2TGt6ZVZPSndaNTlCZnU3K3lV'
    b'b29XenJwQgo5aVllRVQveTV5T1YxaVpWZXNQZEYwdGJYOTd1NjlPekR6N2RlbFU0VllhdDJr'
    b'REJoTkhZa3craWI5MnVXdHJWdCsrRXl0Y281elJ1Ck41WnQzK0QvNURnNXlwZ0tLWncyQ2Nr'
    b'cWo4cWdxYlBRMW0yQU0vV01kNjZXY2M0anFnUzk3bG1pa0N3V1hIazVhT3ZVcTdaQjRVaTcK'
    b'dmhyMDZkMGYzNzREeTFlUHYveTJ1bURMVnFoRHduQVh5bE5xOGRKRmhDMWJoOHBnb0dUVis1'
    b'Ujk5b2t5bTlUYzhqUEZTOTZRQjR3awpZZGtXai8rWVo1VnlSZUcwU2NwZ0MzcjFiN2RkZHFp'
    b'K2lKVXI1MWErRHcrcWZDUUZCbEZqZlh6MVBqb0lDQ1Jnd3ZNVXY3dFFYZzNOCmZRM3I5dS9R'
    b'MUcyQWJWZUNzdjlMMTdncDJxYk44ZW5aRzlQYzE3QWQySU1ocnJQOEJhZWV3Zkw5RnJRTm90'
    b'SFVqRVRYckNXbHk1Y1MKOHZjVlNrMm82SzIvWWR1OWc0Z2ZEMVJydEwyMktyVEVmeUZ2aUFS'
    b'S1AxcHhVOUhYVWJYSXFOVVJPT1ZWVExPbkFtRGJ2WlBzdG8xUQpHZjA4OGplL1VXUFJSc1hn'
    b'UC9ZNVNqNThWMWxOV2hOK2tQc3ZjYnNTVVhWTlc2QnIwdlQvSUdJMWpDWnd5cXNZQncrLzY3'
    b'V2lnTCsrCmlMdWttTkkxSHlxMUY5amxVZGtQVzdZV2xWYUhjZVNUV0g3YVJ2NllZUmk2OUVB'
    b'ZEZJeDErM2RvWTVxQVUwNTRReFl1SmUvUFE4bnAKMnhuOWZXMXhabDdFY2V3d1lTczNWT3Qx'
    b'Qjc0MGc3eEQrNUZzTnR4Rkpvb1d6RktXL0pMVm9ramd5cnBZNVpXMDM2Z3h1UEp6eTBzcApi'
    b'aVNyMWFNV2FCejBLSUZUWjhqWE1lVlZKSE1acFd0WFZkeC96Vm9TdG56ZExmZk9WZHNqbmJ1'
    b'QmVlTTZYQVh5RGxGRG0vYm8yM2JBCnNpMGUxOVh5VWRRb0ZrUG5iamNrdzZsWXZ0Mk1JejBG'
    b'eVdwRlc3YytocTQ5OE9uYTA3UEc1bkpoMlJhUFBma1E2UFg0UHRRUGxkNkEKODlJRmZQc09V'
    b'b3F1bHZndmNGN0tRQk5aQytPQW9XanF5aEdsYk1QSFNIWjVldENFaGVNN1lFaWw5MkJOM0k0'
    b'clc0NmEyZ1pSWHJVOQpWK1pGeWo1Zml6TXpBNVZPajZIVEEvZ09HSUx0NXdSbGhhMnQzeEJO'
    b'elFoc2g4cWpwVnFGMy9EUjE2ZlVVOGV4SDB0VzhsbmpJOE04CitzUzgrZDg0enA0Q3B4TnR3'
    b'Mmg4SGg1VTRlck9tWFlXeTdkZjQwaFBSYkxiME5hcGg2SGJnL2gwN3U1Vm8veXZGa3Z3MzR2'
    b'NC8xZ0MKSVpaQWlDVVFZZ2tFUWl5QkVFc2d4QklJaEZnQ0laWkFpQ1VRQ0xFRVFpeUJFRXNn'
    b'RUdJSmhGZ0NJWlpBSU1RU0NMRUVRaXlCUUlnbApFR0lKaEZnQ2dSQkxJTVFTQ0xFRUFpR1dR'
    b'SWdsRUdJSkJFSXNnUkJMSU1RU0NJUllBaUdXNEErUEZoRC8wVTlRN2Z3SGNtNUhkUGtzCnZF'
    b'QUFBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpBdE1Ea3RNalJVTVRjNk1EQTZNakly'
    b'TURBNk1ERG5GTllWQUFBQUpYUkYKV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl3TFRBNUxUSTBW'
    b'REUzT2pBd09qSXlLekF3T2pBd2xrbHVxUUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBp'
    b'ZD0iaW1hZ2UxMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'FR_IDF')

FR_IDF = b64_FR_IDF
index.append("FR_IDF")
index.append("France Île-de-France")
catalog["FR_IDF"] = FR_IDF
catalog["France Île-de-France"] = FR_IDF
country["France Île-de-France"] = ('FR_IDF', '', 1)
lookup["FR_IDF"] = ('FR_IDF', '', 'France Île-de-France', 1)
lookup["France Île-de-France"] = ('FR_IDF', '', 'France Île-de-France', 1)
details["FR_IDF"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_IDF"] = ('FR_IDF', 'France Île-de-France', 1)
regional["France Île-de-France"] = ('FR_IDF', 'France Île-de-France', 1)
#----------------------------------------------------------------------
b64_FR_NAQ = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTc3NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05vdXZlbGxlLUFxdWl0YWluZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTE3ODEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxMTc3OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMTc4MyI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2'
    b'bkFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFB'
    b'QWcKV2tsRVFWUjQydTFkZDN4VFZkZys5MmF2TmszYmRLUk45NEpTU3N1UUxXQ2h6TElFWkFr'
    b'aWlpSkRGQlJGOWxBUlFSa2lZZ0ZCS1J0awppS2lVUFF1VTByMzNTa2VhcE5uait5TzFMZTE1'
    b'QTVTay9yN3Y2L21yUFRmbjN1USs5OTNQZVM5aE1wbFFzeUdjZE1Gb2ZHcW1jZnk1CnNVOWtv'
    b'RVByK2Q0THIyU1YxbU9YVEJ3ZzJyMHd2UFg4NmtQcE8wN25ZSmNJK1l6VXZhK2hqdkhjZzJ6'
    b'K2oxWnZoUEJEQ0hYMnRzZk8KMXlwMDBCSWZGdzUyUHI5Y0NTMXhzcU4zb05KMkNBc3J3RHRM'
    b'RW9oSko3R0hsQm9EdE1yRG1ZbWRyNjdUUUVzY2VMUU9WTm9PWVc0WgpDQ0dGUWtDSHRIcFFj'
    b'TVhPTE95OEZCWmNBWS9SZ1VyYklXUXhTT2h6SmhNSUlVR0FFS28wUnV3OGxVckNENFNoQTVX'
    b'MlEranJ6b1UrCnB6ZUFPREZwRk9oUVVSVmVyQjI0b01HcmtlczZVR2s3aENKSEppaHJ5Q1JW'
    b'YUxFSFdBd0xFS3J4YnFjRENLRlVydTFBcGUwUUlvVG8Kc0lxN25sS0RuWGQzWkVKTDBncGsy'
    b'UGt3d0xsRkNGVklPeUI4T1FnOVhkalFSOC9kS2NQTzkrdmlCQzE1a29lSGNOS3JJbWlKVEts'
    b'VApxUFVkd0xRZHdsZUNCTkJIRXpKcnNmTlQrb040Vk5WcGpVWjg4R2RCL1o2N1hkWUJUTnNo'
    b'bkIwdEJnMmJSS1hIQVJMc3hXUFE4WGdZClRhWlROMHV3aDBLOTdhQUxIYjNXQWVGTFFOalYx'
    b'OTZPaFErdWpVWVVlN0VBZTZoM2lBTjBnVDBYOHJIejc0NzBnWmJjUzYvdUFLYnQKRUNLRUJu'
    b'WUZiZHZCdjRxdzg0dkgra05MSHVmS3NMcDBiQjgzR2hYdi82cDF4a3NKbFIzWXRCM0NGZE1D'
    b'b1U5bkZDdGtTajNPbzNHRQpaRmR2TU82OW1JYzkxS2VUSTNTaGIwOW1kV0RUZGdqOTNMZ2VU'
    b'aXpJdG0zNExRTjdhR3cvVitnYXU4L2lkZW02V1oyZ0pRK3o2NVJhCll3YzhiWVFRSWZUT0NO'
    b'QlFIYnVHZDA5V1RndUcwZ0tGRW1VZUxvSGVTY3h6Y1dBQ2R0ZjBWVnhtQnp4dGgzRGVLQjhh'
    b'RU9QTGxEcXMKb2VKejZTRmVvSk81K3BkVTdQenNvWjdRa3JqNG9nNTQyZzRoU2FMK29hQ2gy'
    b'bndjTHg5TEp3VkFTLzU2S01FNk5Zc24rRk9CR2tpMQpYSHZqU1lkcjJsWUlFVUpyWjRSQWh4'
    b'Sno4SVpxZEM5WE5wT0tYYUxWR1E5ZExtdzlUeVhKWHNGZ1FQTFYwZjg3dWxTZFUxUjM3WUcy'
    b'ClZOSitFQVo3OFJ5NGVDZlRaRUs3eitaaUQvVVBCWk03c1JmeFRzMmljYURzM3MrcXRkRU4x'
    b'ZGZLZEpJMm50d2dxNjg4ZURaOTZpY0oKd2FOdk8vVi8xUE9OMHUyL2dSZVN5dk9XZlh2SGZm'
    b'RDl3RkZKZzk2Nks0NUtIamxmbFYzWUhoQWloS0s2dThDR3FoZzcvL0ZFTUNCSgpMVkJvOVJq'
    b'WkhSenV4QVNTTzNxOTZkUU5tMlJxVkJuNVQxNTcyNkJRSW9TS3YvMGxmOFgyNTFsVmR6VWhm'
    b'Y3JTTzI2RE1tYXRrQnk1CnFNb3ExTmZLREFvbFFhZlZYTGl1ZUpUZVV2THlTaDZHVHl6ZWNr'
    b'QlhVYzMwRWJuTUhNTWYzS3YyejV1SnZhWXFFbExhQThJbDQveWcKUS9rVlNxeHQ2K1p2RCts'
    b'U284bDA1RW9wOWxDRVAxaTQySGNwM3hZUThsNEpDenIwcGFGT1lUSVkyWUhlQklWRXhtZkVN'
    b'TG9xYWRKcgpjeVhITGhuVlQ3RkdYR2ZGRks3L01XWDBCNCs2VDY2N210Q2txN1M2bEpnRm1x'
    b'SnloSkRvd3hrOU1zOEY3bHZYNWRLUG9lZDNHdXBWCmFaTS9ibkVlbTBEb0wrSkNDUlNqeVhU'
    b'cEVUNkJFdUFHMWpvdTNzZUwxT0J1enFEc0ZpcXNCWnZKWUt3OGRLNCtPUnNaamRwU3ljUHcK'
    b'aVZXbi85SFh5akptcjZnNDhMdTJzc2JDV2sxQldkYmMxY2hvRkl3YUdQRFRhb0xhcERieWxu'
    b'K25MWlg0YmZzazdNbysrNEhkRytkTApkOFVwVTNJUVFpU1Q0YlhxUFVRMjNHcUhZWDNkNWs1'
    b'VTU1ZlduTHRxY3dnUlFwNU9JQjYvQS9XRTNyQXJtNVNMcnoxTkh1Z0JMWkVxCnRHb3J4Zmlh'
    b'Z2xKVlZvRTZvK0IrNEtqMHFjc1FRdXJjRXBvVG4rWG5vYXVzb1FsQVRWRDU2L21FempIVnY4'
    b'Y2poR3JPWGMyZXY4SFUKaWgyU3MvaXJsREVmR0RWTnhVN0prWXZtUHlnY0ZvWDNGSk5QTUxJ'
    b'L1FraGRVTlllRUhhRzZ3bFBjdXF3ODlFUm9BV1Z5UENxdzAzQQpoTVFkSVhRdHFjb3FQNVhw'
    b'NitHMVpuN1ZtWC9VZVNWMTF4OGloTXArUEtwTXozTVkzdDhodWg5QkI1bHo5VW1aUnBXbXVZ'
    b'YUUzSnlLCi9XZWEvaWNhZnBHdXBzNGdlNXBuUzZXWXYwOTdRT2p1QkZia3BmWDQ4bnFRSndk'
    b'MHoyQUNEb3RHQmUxdVpiMFZyYURIc3JjNFhZTWEKeklGS2svN0dNbDE1bGRORVMrUmowY0pw'
    b'VGZlTFFYZUk2dTA2ZHlLRmc4bEI1aTdaTEluN284SGM5dXpTNk1FckhxVTEvNWo4ZGhMRgpq'
    b'dVB3Mml0VytVVlV5NGRGQWhiNGJLcngrczJaejdSd3dpcVpGa3YyWmJNb01oWCs2UzZXcUt3'
    b'SUlTZlVQK0xoVVVWQ1N2WUhHK1QzClUrcVRNdXVUTXZsRCsxaFlRaGNKUll0bjZDcXE3UVpF'
    b'T3I4K2xPcGdoeENpT2ZHTE51MXRhVzUxT3ZzQkRlYlFNV1pRWTdDaGVKalcKYUNhTmFrMzUz'
    b'aE1lSDg5cW9WMXRKWVV1TUU5Sm93ZE5GRW1BV3JHa0NvOEhHK1kvMm9MVHh1M2V1ZE9wNzVz'
    b'dThmc1Z5NS8zM2ZLeAo4N1FSYnU5TXBOaHhwZkgzU25jYzVnL3BoZldZaXIvWmIvN2J2bjhr'
    b'OVYvN3FpMXRjdjN5bG0wbHFCVFI0aGtJb2Zya2JKdERXRkVMCmtwRVlNRkhLYUFJVnBnaW9n'
    b'VUF5alJBUzJJYmZyY29xYU9hd25KUGZmWUxSR2NjdjFWNjYxUUJKMzRqU0hZZFR4eTJxaTc5'
    b'djN5K0MKeXNkN0NmbzZlWU1wcEZMNGczbzIzSkIveldmMTJTdmxzU2VENDc0eDYrSGs0Zk9r'
    b'bCsvYUZzTGlLcERmeldIaTExYlVxQzJjRU5veQpvVkpiWVBXenJJeWV5VlN5N1dEcWhBK2JT'
    b'MC9xaE1XYVZpNGlLOEFySldiaG8xNVRrd2E5bFJBeWhxRFRPcDM2em12dGZFNTRrT3gyCkl2'
    b'VDhObzgrRzRRK0lnUWhKTHVabVBubTU4Ry9mc25yMGJsQkRFVEMvTSsrczYwdExLOEZ3MDg3'
    b'Tmg2TW5ETFErNkNTb0lKVjZVRFcKbXRpRlkxMEVEUXBsd2FwZDV0Uk00OUNXVlNVTm1STjZm'
    b'aGNyeUx2cE1lMGFGSDdqbCtvejhhd0FzY09JL2xRZVIxOHQxVmJXeU84bQpGYTdkemZCdzBS'
    b'Ulh0RGg1OWJtcnlyUmNkb2h2bysvSzd1VHJQQ2xhZmk4NWRkd2kvOTBySFdNR04zMFRwVnFW'
    b'bm9lTXhzYW8wZnBTCm1KSXZndzUxOGNWcmtvc0pGYUJLQkVTd29rYXRnemRtRElCSmptMFlp'
    b'b2Rwa2lNWG1mNmVpQ1I5dHk0aktHVHpmTmlqWGxNYjQ3a0cKQVlyczVMVjJ2bkRHYUpvanZ6'
    b'NHA4NDdib0lkZEoyUzlzOFpwUXBSb3ljeVdGajNZaDhKbXBrMzZDQm1OaW9TVWttMEg3ZnFH'
    b'ZC9segpqL3p1aytTUjcvdnYrdHg1MHJBbTI1R1lvVXpOWlhpNnZneCt6NWJDSXRnYkhORVRI'
    b'Ly9kVEFZclJGMTg4S2pIWFMyQlpaM0dwcE5XCmhKQWJFY0tOQ0RISWxieFh3dXg2ZDYzOTgx'
    b'YnR4UnROWWlHdlQ1LzZpU3E3MEczZXBPclRsMTNuakc4UldaSU11bEduOTF3Mlc3UmsKNXFQ'
    b'dVUxb3FVYlhHYTkwSExqUEhJSVRZbmYzRDRtUFpJYjdTK0h1cFl4Y0Y3RjNqTkhGb1U3cjFT'
    b'a0xHbTU4aGs4bTlXY1JpZlFpegp5dkNKYVlRUWdWQTBrQVRQTGdYTloxUTNJWGIrY2lKWWdn'
    b'a1FXVm1MTm5oVkg4NW9jUDFIRFdnT1lZUDUrUG1rUVZZdnU1WFlBa0txCndMNWJ3aEdDUm1W'
    b'NHVxU09XNndwYkdrNzFmbWxtYk8vNEEvc3dmQnlJMWtNZG9pdjdHWmk2dGhGZnR1WE83OCtG'
    b'Q0drS1NxWEhMdFUKZWVoYy9lTU04OWNRMlJUQzcwN2tXSEFzc2RUOTVIeDV2VVlQUlJyVFg4'
    b'T1RWQjlrU2FFTFRYblZFOWx5cVBNd0NzQllyeUtaZE5tdAp4SXpweTNtOXd3d0tsZnoyWTEx'
    b'VkxUczBnQlBxcnkydHJEcnhOMWd3SWttYWMwTUZWRnRSblRiNUk5R0hNMXhtaks0OGZLRnNa'
    b'NXpzClRoSXltUkJDZERjbjMyK1hOZGVyTm9IdzBnT1FDVGltTjU3czlQV1JEREMwY21Oak41'
    b'bkdKMWFwdFFZSTlSbFJIamFGc09yRVg2MG4KZFZWU1pEUzV6QndqT1hLeDh2Q0Z4bm5aN2Nm'
    b'UFBDRTd5SnRrTnlRM3N1YXVwbkRaNGhYdlpzNVpWWEdnSWZkR01obWlEMmQ0ZmpxSAp3bVZM'
    b'anY0cEdOR2Z3bVhiSktqSUxsSFV3SnVNRm83REUwZXZKWVA1ekFrRDhHQjhkeG9NYjBPOGVG'
    b'U1N0Q21FQkozR0NRc01Pcml4ClFXL3ZYZVA1MmR1c0FISGxrWXNNYi9lK3N0c093L3ErMEFs'
    b'NXZScnlhdkk3U1RYbnI3bk9HVjl6NFZvRGZnVGhQR2xZOTlRejN1c1gKbUdFclhMczdiK2tX'
    b'VzBuaHlnUHBGdVFKRzk1ZFNxaFVxRUI1V2pER0Y2T3lqT2hPT2xqbFdSamppMnc4K0svMm9Q'
    b'RHRHdmtRZHIyNgpsSHg3UURDOFA5M05TVk1xU1FnZHA4cDZzUXE3M2IreG9PVG9uK1kwVU9t'
    b'T3d3Z2hpaDBuNkplTmpxTmZiZkpJa3pKVm1mbDBWeWRiClFYamxDZWhpdkRzS1QxSGNkQVNr'
    b'dWtRRzhyRmFkTnVwYkQwUVRqRHBsQW53aGh1ck9haVJuWXdhcmZDTkVVV2I5dXFsOG9yOVoz'
    b'ZzkKdTVSOC8ydWJUOGdLYm5qc3pBNEx3OU5Wa1pDQ1NETGsyQmFIMTNvMzZlUWJqOUtuZldJ'
    b'eUdKMG52Nnc1eEt1cFBSZnl0RHE4TDBxagpFck9qdkZ2UHk1VDZsUHc2NkRLZlRjRVRNdmI5'
    b'bVE4dEdSb3B0Q2w0NW5xNktxdVFHeDVDRmRoN2IxeUVFQ3JlY29EcVlPY1ExYnZSCkJYMWgv'
    b'eWkzcUhsU1RWTlFxaW1wRkVUM05lTm4xR2dyRDU1Tkdqem44YXV6TmNVVnJuTW50bkI2clFi'
    b'aEQrZnlvQVdEdXpwanpkTzYKUStsUXZ4TjdEcTAvTGp4UEw1Q1gxWURabjFVemcyMEtvY2xn'
    b'TE5sNmtPbnJZZGMzSENIa01pdkdYT0VyMlhxUUV4WVltWEs2Wjk3RgpYZ1dYbk1ZTmVjNFQw'
    b'b1NDZ0I5WFNpL2ZhMGllZWJnZ2hGSW5MRUVtRXpleWt6bmtlQlE1T1dQV2lycXJDUlFlMjIv'
    b'NzhvQWZWcUNYCk52WlVYSVpNVVZTcGdzTEJWZFB4TFByak44RHdmTklBdkQ1Y2VUQU5XdUxs'
    b'd3ZKeVp0c1VRcWEzZTJOMGlCQWlHWFNuOGE5Vm5makwKZmY0VXFyTkR5dWdQMUhrbENNN1h0'
    b'eGdVTGx0WFdXUFNHNElPYkdoNGNBZDJseHo5MHlDdlJ3aHBTeW9SUXRuejFpclRjaEZDam1N'
    b'RworVzFmYnNiNDVRZm1FZmp5TUxnbHhVWEFETVJWZEcrbFZjdVYrSENRSUlqbGJ3UmhEOTJB'
    b'OHpoemh2bWdkaHNtay94K0NrSW8rTmN2Ck81M1lTdEJwK1o5dVUrY1dQejkrVEc5MzBlTHBD'
    b'S0htK1ZXbmlVTWJvNFhLM3k1b0s2ck5vYVRuOHJjN25kcG1MZnp3RVA2ZENJYUQKTVgzY3NQ'
    b'UGI0Q1NBanl2TGpvMlI5ZE8zeXFEVUQwa1FiNC93YWpjRXRhV1NuTVZmSXFPUm9KQ0t4eGts'
    b'V3crK3VFQ0x0R1ZWVklGOQpZNzBYSVVSejRvc1dUVzlNdk9WLy9yM0xyTEZPRTRkNnIxOWdq'
    b'dnBmMU5kOVhnaVQ4K1dRUENFQ2ZUZ2VIdzdlU2dVRGc5Y0g0dE1yCmU4N25XUWdITFhSdHNQ'
    b'cWd1VHBwQ3N1U0JzOTVHRG01Y08zdTVvY2N4dzd1L1B0MkJGU3dTVVpEWktXcnFXTjM5cU02'
    b'MkRWUG1pT0UKUkV0bU5zWU1GZnRPbC85ODB1MmRDUWloMGgySDc0bWpFb0pIcDhRc05MMTBu'
    b'NTJXZCtybmkrQ2RkYlpuWU1QQnpLSjZLTDJDQ1BUZQpLRy9za1dTNEJqSytyenRxeDBGUXlJ'
    b'RGRLMlczSDljbk5RVkZETEZieUxFdEhoL096Rm44RlZhajhnZjNFczRjMHlESFpSS1hXV01K'
    b'CkNsbHg0RXh6UGlxVnp3dU1YZHY0QkdnS3k1ZytIclYvM3N4ZHVrVzhjbDc0N1YrZHhnOXBY'
    b'dEMzRG9TMzAwQ2FlamRmUG5ZKzdncTQKQlluUG9YRnh6T0FxbWRaQzU3WXBBMFdvZllkZzVJ'
    b'RFFpN3U1RVNHSUlOaWRmSDIzTGhWT0cxa1hmejk3MFNaMWJuRmpIcWY1RXZISwplZkw3RFlW'
    b'K2graCt4Vi9IZGo3OXZiNVdwc3g4YWkrN3c3QytaalA1NytOQ3FUeDAzbWZqSXZIbjcvQjZo'
    b'cnE4R2NNUXUxblpJeTJxCkJPc01RM3ZnQTdYcktXQlNMZGdUMzA3cUdGeGRZdEVwTGdJbWF2'
    b'ZkJIOVN6Mi8wNFpETEpFMUl6NTN5aFRNbXhIeEJKVUttTmFUUEgKVVFQenY5alI0TmE5R2NN'
    b'TzhhbC9uR20yZWNJWm8xTkd2bzhJd216bldub0RteFlySHFUV1hYdUFFTXBmdWFQdVdrTEEz'
    b'dFZXL09ZdApwUkNLNkJGQ0l3RUlTNnZCMks2ckgxNXdIK2VCU1FBM3gvK3lqVjc1enlmTGZ6'
    b'cnV2M01GeTErc0thNWcvaXNpWHF2ZmwvN1RRSEt4CjY5MlZLckNyaTcrUFRDWkVFRUVITnVZ'
    b'czJHalM2VXUrTzRUZGFrUFFxTUZ4bStraUlVS284dEE1ZG1oQW94RzFQb1FsMVdyUWp5WkEK'
    b'ZHFFUzd2VGpKY1RUWGlwaFZwV0E5OS8wSXpWcXRGbHpWNXUwT3BKQlZ6eElKV2hVOGFyM3pH'
    b'RWNPOWlIN3VaczFPc1JRa3hmRDRmaAovVXEySHRSS2F1bnV6a3h2ZDJWR25pb2pIeUZrVktx'
    b'aHpCemR4VEVrYnJNNWltZDZXOW5TUDkzTXNoVGN3R0NoWXFDR0JkZGJpQy9ZCjFzaEJpcFRq'
    b'ZjlGUzFxaFVwNHhlVUI1N2loTVdXTG9ycnZ5bjQ4SnBJOHQvUEtaTXl5V1pESStsczU5RXpS'
    b'Vk9IWUVRRWkyWVp2WmEKUzdiczk5bjhrVTVTeSswYVRITnAySU5RdGl0T0w1VmpMMkhYSjl6'
    b'dDdmRUlJU3lIMkdvUVFyMG5rY1dPbFNZNEJHWURMWjRzT05JTQp1SytpallaQm9Vd2VOVi82'
    b'engyRWtQeGVzdXZiRTFUWmhma3J0c3R1SlhJalFnSmoxeFdzMm1uV2tOeHV3YnllWFNoMlhI'
    b'TzJyR2pECm5vQWZWOUdFQXBmcG94cCtsMVJldkhrZmRDSFA1VzhUTkdwemJyOVZ4bFB1akMr'
    b'OEtja0FjK25wVkZKdndHTlNJRkgyUTVoZE10RG0KVTRSUXRVeGpFNkJNcHNMMWV5cjJuM1pm'
    b'T0YzeEtDMWcxd3B6WVZaZkswc1p1MUIyNDFHREhscTZ4U0c2bjkvM3k1RUprVFNLL0ZGNgp4'
    b'cXpQelVRMHBwOW5sNy8zVWppc3lNVGpCV3QzVit3N3BVek5UWi8yQ1lYSE1TcWI4cEVsMy8v'
    b'cVB2OE51anRtcnhaRDdHYmZMd0xMCkU3QWFoR0s0aDU3UmhOUmFJN1pneEdaUW9BaWhXSUpY'
    b'bUU3Mm9NOVNJN05KUDFLRFVtM1hwNnZkZ083eW13OHJENTRsU05KL3gyZTEKLzl6Slc3cWxS'
    b'WmFrOXVLTjFtd2FoQkFuTklESzV5R0U2Q0pod0k4cjNSZE16WDUvbmV4bW9qa0wybHduNXkz'
    b'ZjFwZ3BiWG1Tc01CcQpLKzFKd3l0U09wV2t3RlRQSk1DTjVNTU9TRzQ1M3JqNndNOUt0Y0lt'
    b'elN3cEhCWi95Q3Y4QVJHMWY5OUJDRlVjT0hPVDF5dDE3Q0lvCnkwVXlHWjZmdkJWMitXZFdn'
    b'SmpwSTZMYWN6T21MMisrcDhsWXJ3bzUvTFhyVytNd3p0cXY1eHM1NEMwZC9vcHFuY1dOakZZ'
    b'SUtxQkcKTUFpaDB6ZnhlM1I3QlBLaEpROEJYaE5VdTBBSVNhUzJVYVFJVlorK25EcGhpZUpC'
    b'Nm5QZEZ6YlRlLzBDKzRIZE81M1lGbjczdDU3NQpsenFmMzJtTzdrMDZmZnFVcFlsOXBwY2ZP'
    b'RXV4NXpoRTkydXR0RFBmK2tLVjJiSmZuU29qdi9yVVAzUVhSOXRDMk5VUExITGVTc1VYCkZt'
    b'SjZnL21GWXFBcmNMQVhqMG9oQVp1RnJqK3BzdTZQMUZWSk0yYXRVT1VXVjUrNTNJTEUzWG9J'
    b'WjR6bWhQcnJhK3BrdHg0amhOaWQKL1dpT2ZJb2R4eHpNbVF6R2pKbWZTWTVkUWdqVlhyd3V2'
    b'NXZzTkI2enNVMWJWcFhZZTFyeDVuM21NcE5KcDY4K2N6a3BhcTVSbzNWNwpiNUp0SVJ6ZkI0'
    b'eGFJSUxvNEhBaEZISG85TWJIdVhqMUs0WjNTaHkrYW1XRFQzUGlCKzFmTHhqV0Y2ckNVN2hz'
    b'bnk4WEUzU2F5OHd4CnpwT0crZTljNFRadmtycW9ySFhza1RwK3Naa1VneEJTcHVVSlJnM1VW'
    b'OWVTTEl4cDEwdmxlWjl1dXl1T3VtWDN5azFPajlUeEgyckwKcWp3L25XUGUwMlJORzdGNjlW'
    b'UEpuaEF4Yit2SkhPd0xSL1FHVTdndjM4K2QweXJlUU9mdVZrQUtzRXFxR2RjUDgxaElsWHFJ'
    b'OTExVwpyVjR3MXMvcWlwUW1GQ0NEd1Z4VnR4OFFLVm80aldMSFZhYm0rRzc1T1BpM3IvaXY5'
    b'aUNaZEordmw3QUN2QmhpTjhISUFad3VUZDFVClZObUZGYkduTW1aKzFyeFRCWVhOQ2o2NGlj'
    b'SmhWeDYrWU5LMDlNSllBZUtnWHpZd1hKMUlOb3Z1N3V3NGFxRC9yaFhDYVNPdC9yc3cKT2Vo'
    b'dWZ2YjNNdkRKN2gvTzV3N3Rqa216ell6eS9PUW5mQmVPYTBBSHAvbGpmRGNmeWNSdVk2dVJh'
    b'ek9MNmdNOXJjempWcWJuVVFYMgo3QkJmKzFkNytHOWZqZ2hDVjcwRElhU3ZVNWpEYlkrUFo3'
    b'WDBZMlgxaGV0MlYvNTJRVnVPMGUwTUw3ZUV6akUrWHk5cHVRL2IvR1JUCktJTGgvUVhEKzlz'
    b'NnJzVm93QVZqUWVyZjNiUmFiRytQTjZQRWtHMVRxUFhZUGx4c09oa2dBdCtwOFBVeDYvZDlL'
    b'bGk1a3h2UktlamcKSmpOK1pzWElDaEJEL2tWOWN2YkRiaE9Mdi8wRmk1L1p4THE5UDRYS3dY'
    b'dlgyc3FhNTYvN1d4bkM0VDFjZVN5Z0Q1ZmVpRzBFUXlWSgpDODFGTjhUaEtkNFdlclpaMkI3'
    b'VjVoRzBmejJ2UjJkdXQrREdBcDdyblBIK1AzemhOZy9qWCtocjZwS2ozMVhubDFvNG9iNm1U'
    b'bnJwCkZnSzZCT2hyNmxvM0Uyb25DQkZDTWIxQnAyWVgwTHByL1d5d1o5dURMQ20yWjl2WVBt'
    b'NVFrM1cxMW1EMVRvaU5QSG56S05yNFUrSGEKSCt4ZTZZckpZNmcwNmRNKzFaWlZRY2xHNTll'
    b'SGhsM1oxN3ZxZWxoOHJIMy9DQ2p0MllJRDBLNFFycDRaQkVYNEJSVXFxTG1va0kvUAp1UmlO'
    b'cHErQmhualFEamVFMExiVHVUYjk1WjZmelEyTzI0eDFKZ3ZXL0FERjVneFAxNjdYOWdmSGJi'
    b'YnZIMEhRcUdadjFtdnRmSHdrCmV2WktlZXlwL3daQ1BwY2VJdVpCYTlZY3hPdUhXVkZnZC8z'
    b'RGwvRWl0ZjdORUtpMVFuWkpmWm5GUGQrMkcvV0FBcVFKQldGWDl0bjEKQ1c4K21UTDZnN0lm'
    b'amtLbnlsbjBaZXZOTkpxQ01tdDE3MElXdHNVc21RZzNGMzJBTjFTTEovaERMMWlybG1udjRD'
    b'Z2R6bnltbnh2awplWnJXSFVyL0R3QTBHdXRUc3BxMzZHb2NmdDh2YjFIdDA1WkthaTVjdDlE'
    b'WjBLaFVQeG55ZHY2SzdTYXR6bVF3WnIrMzdxNW9TRUxuCkdJSkNzVG1FWS91NFFYVWZqYzc0'
    b'Tys3Tk1YUXEyUVh1RnZYdENUdzk5YzBva0cvNGh3MmNtbWVPeXNOLzZHdGtJVWUvYVRIUDlQ'
    b'VncKbnRBeUVXTlFxaEJDUGw4dmFkeFRpRUZSb3kzYXRQZkpzSGV6MzE5ZnR1ZTR0cnpLY2N3'
    b'Z2drYTFPWVFJb1o3QllQSno5MWs4MGMxQwpVMjhvUHpkM3BCY0o1TmJsU2oyVTNMSFJxRGh3'
    b'SnV1ZE5WN3JGemhFOTJ0c0V0VUFvZGl0TlhsZVd5b1JqQnJvOGRHYnpwT2pMWis1Cjd0cUQ4'
    b'cjBuM041OVBTdytOdmpRSnB2YlF2TjRieVFZSUQ3S2tXTG5KdzBVUVkyYTFWb2pOa0Nra21R'
    b'UUhDQnVPNW5UbmhEYTllMFcKK2VTa3g1S1pKSU1lZW5hSHViclVnTUhOUitiT2hzMVZic1dC'
    b'TTc1YlBrWUkrVzFkNXJWMlBzbDhCdkhIY2R3USt3R1J5S3FiSmkyZAphMmgzSWRUSFNhYzNn'
    b'Y2xQSVpqOGpMdUtiMFE3QUg2NVNVSm1UWHRDeVBJWE4zYTNvNHVFOWdON05GbG1uVDU5NXZK'
    b'R21xaXVTcG84CmNyNWdSSCtXdnhnaGhFaFMvUGs3M2RQT0NHZU10b0JROXJ5MXhWc09sTzA1'
    b'WHZSVmJIbnNxV2MyUVgxWkNCRkNRZ2Z3c1RweEhaK00KN2hFSVdvWDdRTjV1TWx4NytpL2Zo'
    b'V2MwcWpLZnltUFVKMlpvL3QxTVNuTzBEOXk3eG1sQzFGTWhoOWd0YVAvNmlQdHg5Z01pTWM5'
    b'SAprTGM2dnpSdjJiZTVpNytTMzBtUzNYeWt0VWJ0OEJsR3RaT1lWdzU0OXJmVDhKY2Yxc1Bs'
    b'Q0ZCcWdHcFBZYjcyRkpJdzRITHJScVBwCmZtYXRoY2ZpSlllK3BzNWtNdEVjK2Ewdm5MOXFs'
    b'NW5CMWppNGtaMmEzQmFDTVBNS1d3OU9lRkRZNVo4TE4vNVVzR3BYOHh5YklMb2YKWjlsc25h'
    b'UldPRzBVbHBsaEV3aTloR0I1WFZLSGw0OHVQbURGVWFzRGFVOU1HZ1ZxbFpGV0tMY1JoRWEx'
    b'Sm4zR1o5eklUcm95aWZNYgp3L21EZTVrbmk3NktyVGh3cG5VL0wyN1hvT2VsZ0JLRStQTjNk'
    b'SkxhNXAzWFM3NDcxT1d2UFM2enhyWkhhTjg0WEdGaWRUMUFIN1d3Ckw5Q0VFUFI2U1JZVC9D'
    b'YkZsU29iaVNESlpJU2UzUzYvbFZnZWU4ck1nREtxTlNtalBpaGN1N3MxZm9nZ1hPZE9mS0h6'
    b'dDg2K1pyMjcKVmhMM1IrMWZ0NjM0SzU0aGhaNXdZVllGVUo1SUVoRUVtS1BQTDFlRmVtUHlQ'
    b'bHdtclFvUTYvSTZtK1JvVEFZalFTSExmejdwdGZwOQpYVzFkNFlZOW1wSkt4Y05VeFVQOHhs'
    b'V3FneDJ2WitnTFhZTHU1dHppMXZoOHVaZy81SlhtanE3TklaU3JRVDVaMjlxSjJIUHc2UUtk'
    b'CkFkU3hIRHJWRmhBbVI4OXpualEwYTk0NlJCQVVIdHVrTjVUdlBZSEpIMDBaVGpMb0ZRZk9Z'
    b'QWtXbGtkTCtvelJXSGZ0UVFzUHlPYUsKdEtRU2xBQTJDdytHUXFtM1VDWVRPYklCdFd4b2d6'
    b'Si9HVzh6K05jdlNRNExJVVRoc3JFMTI0WklMbWFRODVSb1JKSWs4NFZwNW1XNwo0cDY2MTJ5'
    b'bTcrYVByUDVUbnZHQVYwaEJDSG5BK3loeXlzSGJRUklFSkxwcWVLK2FsNHNOTnQyVEpFMG9j'
    b'SjQ4bkIzaVY3N25XTm1lCjQ0M2FrbXJQN1h4dXB6VCtYbDM4ZmJzKzRVNFRvZ2dLMmUzdWI1'
    b'V0h6a2t2M3pXN1BLRFlaZVFiRkVvS2w2MnZVMGppL3FnNGVQWXAKWTlFdHVQU0hJNDFiZjlz'
    b'Snd2UVNFQThmVi95ZHZRNDNnT0t4cVZEaVJxMERKYmQzc0swaUNvSkM2cXByeTM0NmdSQVNU'
    b'aHZwczJreAozZDM1WWNRa2sxYm4vdjRVOS9lYkdoMmEreWRhT0pVMC9wNjJ2Q3BqK25KTHFa'
    b'bXhRemhoZ1laNmxYVzNWVHhEa2VZVWd4dGxvcnJqCm82Si9Ib0U5aDRJODhJbTAzMitYSVFR'
    b'MUVDSnR0OTFRblY5YWRmU1NjUG9vZG9odjBQNzFkSkd3K2t4OGZWSm0wcUMzbnNsVmJER3EK'
    b'anY5bHNsZy9ZbnE3TzA4YXhoL1UwK3JiWWl4Sm9VS3B0L0NLK1FuQWR1clVBam0wNU5Vd2ZD'
    b'THR3bjJ3SXVIcnlrRTJHeFFPeTJQcApiSUpHYmV6TDZ4RGQxM3ZEUWsxaDJZdTJ0dlBmK2Js'
    b'Um82MDZkYm5tL0RXRWtHQkVmNjgxODR1K2lxMDZmZ2toeE83czErWGlqMVlNCjU1OVhDbmVm'
    b'Qit2bWpqdzZuNHN4N3pVeWJiVU1TSWtSYVBZd2ZFMzRUaXJZdldSa0x6ZmJRVWh6ZG1BRmlK'
    b'bmU3bzE1VVcycHBQck0KWmRGSGI3NndlNlRTRkczOFNSRGRGeEdFWU9TQVRxZS9wL0o1MHN0'
    b'M09hSCtDQ0hSb3VrMnd1OFpFQjZCS2JsREFTMzZ6WEd3WjQyNwpnSVhkWkZvZ1VVS29Fd1F4'
    b'ZjNRN05xQkJpT250M3ZuM0hTeS9GMjZDS28yL1YvYlRDYnNCM2UzN1J3UWYvcHFna0xLN1Nk'
    b'eHVJUkdKCnh3UDNyckVwbFkyMG9FWHpLOEFlVUZCTi8renRjdWlFbzRFV3BwdVBaSmxBajRu'
    b'RlpWUGJFOExtRFdGZmFOajFDUSsvZFlnVDZoOFcKSDB2aHNBeXllc212RjBMUDcwUUVvU211'
    b'Y0gxN2d1MitNbmlETnNabFFIcy8zUnhaMksxSk9XV0tzbG8xSkU5TEorSjcxcHkvQzZMKwp6'
    b'dkIyRmNHWHVvOThYdk9jQzhsbUNrWU5NSmZteFYrOGE5dW5EanB3OUJwSW9Yd3JHbS9TVnUw'
    b'SGU2cDE4YkhEMnM2L0gxYktWWGlQCmlVWWwzb3IyUnY4N0IwR2xZT21wN1FmaGpTZlZVbUNm'
    b'SDVWQ2ZoQ0RidzU3K1RFWUVTNTkzUitRZFpDMVBRUm91ZGd4bmd2Q2RiK0IKMUxGK29RSnNk'
    b'alQyWWo3VVU0M0hvZzd2NFlvMXQ4bDVNc2pjcnA0WjBnRlBHeUZVYTQwUU5RWWh0SElhdmsy'
    b'b2hSYW1ZL3ZpQTRPMQp2NlZEYjNjU09iSDhZVUpOeDNnR2hKdVBaVUtVRG1jK0k4d1hVOUV0'
    b'cVZZWEFHMmpDQUo5TVJXUCtza2JvTG1kUGN5ckE1dTJRM2ppCk9uaG54N3lDbDZkdjRJMUlZ'
    b'bWMyOWowL3FZVnlxVUlIb2Y3dVNKOE9iTm9JWVkxTUN6RmNFRUtMeCtOM2J2NXhEOHlRVFFM'
    b'ZTAvdk4KTVRBSkVPVEJZOUk3UEptMlF2ampoVHdvNCt4b3ozRERaWnd0SmRVUWd0SXJGbG9D'
    b'eDdSdk04di9heERHdzRGQm1EZWVMbkRzZWdtVQpYdUd4cWRqMGlsWnZySVhmWXpKMWtFY0hN'
    b'RzJITUxzWUxCQkdBVzhkK09zaDJCUTFFUEFxejkrcGdGQm4waWtpUjJZSE1HMkgwQUpaClpu'
    b'Z1A0RlZwY0ZrNEhHaG1lUlYrejdtRnR3ZDNqR2RES0ZWb0xhVFVQUUYySVpRaFF3aDVDdkh5'
    b'VkY0TDhncjVQRVlIS20ySE1Lc1UKbENjTGpiM1VXbkJqZ0JoZ0VsZkI3bytUYlY2Ky9QOEZR'
    b'Z3R2N3JYd0dsNDl2TGREYUkrWFFnWE1WK056T3lCOENRaTVETEQyWkVCdwp2MkFRWEpBdWJP'
    b'RWRCbUN6L1k0QmpQOEIxOWpleW5VYWd1SUFBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3'
    b'TWpNdE1Ea3RNRGhVCk1ETTZORFk2TkRJck1EQTZNRENMYkxuNEFBQUFKWFJGV0hSa1lYUmxP'
    b'bTF2WkdsbWVRQXlNREl6TFRBNUxUQTRWREF6T2pRMk9qUXkKS3pBd09qQXcrakVCUkFBQUFB'
    b'QkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTE3ODUiIC8+CiAgPC9nPgo8L3N2'
    b'Zz4K', 'FR_NAQ')

FR_NAQ = b64_FR_NAQ
index.append("FR_NAQ")
index.append("France Nouvelle-Aquitaine")
catalog["FR_NAQ"] = FR_NAQ
catalog["France Nouvelle-Aquitaine"] = FR_NAQ
country["France Nouvelle-Aquitaine"] = ('FR_NAQ', '', 1)
lookup["FR_NAQ"] = ('FR_NAQ', '', 'France Nouvelle-Aquitaine', 1)
lookup["France Nouvelle-Aquitaine"] = ('FR_NAQ', '', 'France Nouvelle-Aquitaine', 1)
details["FR_NAQ"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_NAQ"] = ('FR_NAQ', 'France Nouvelle-Aquitaine', 1)
regional["France Nouvelle-Aquitaine"] = ('FR_NAQ', 'France Nouvelle-Aquitaine', 1)
#----------------------------------------------------------------------
b64_FR_NOR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTYyNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05vcm1hbmRpZS5zdmcucG5nIgogICB4bWxuczppbmtz'
    b'Y2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAg'
    b'eG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3Nv'
    b'ZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94'
    b'bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpz'
    b'dmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZz'
    b'MTE2MzEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxMTYy'
    b'OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'CiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIi'
    b'CiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hl'
    b'Y2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIK'
    b'ICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMTYzMyI+CiAgICA8aW1h'
    b'Z2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNl'
    b'cnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9w'
    b'dGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2'
    b'NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RC'
    b'VFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFB'
    b'T3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQXIKTWtsRVFW'
    b'UjQydTFkZDNnVTFSWS85MDdibnA2UVJob3RFSHJ2SUZVVXJLaW9nUENRSnFJZ1lrRkVCVVRw'
    b'b1NwVmtTYUNORUU2U084QgpLYUdra0VKQ2V0bmRtWjEyNy9zaklSQUlvRDdDQTcrY3Y1TDlk'
    b'bWJ1bk44OS9keXo2TExWRnlyb1NTWmN3WUlLQ0N1b0FzSUtxb0N3CkFzSUtxb0N3Z2lvZ3JL'
    b'QUtDQ3NncktBS0NDdm8vMGhzQlFzQTRDelNUM25vZVdacTRrQW5ZQ3BBVGZLWktNbzhFWXRI'
    b'anlCSHFnR2MKUUtnT0lXYUUvdTYxRXFVclBkU2FJblBOcEVzWSt1YnlmNHV2R1VDdmdKNW5w'
    b'aW9HQmNCTkJhc0x1VlBrQnNpSWtFanBHWk4remw5dgoyNDEvcHB2ZzQxRzh2UFFzOHZ0Mitj'
    b'QnY2alBYdWZwYThRT1RLWW5uU0w2QmVJczRYTWNCQ0tOL040UkpsRGdScWdrSUFFNGcrbEZR'
    b'CmJWNlZ4bWZHTnlaLzZYSUtjSkhUdDFYWFRxZG8zOCswelpqbjdQK0dVWlJvOUNRcE9BQy9m'
    b'Sm1OdUsrSWFBQ2J6ZXFWSUJJUnhkUnYKeGdaVndrWWpBb0M4QXBxVFQzSXlhRTRtRWUxVU1L'
    b'T1dyYm1HVVdXb0lrb2hQWXY4dkViTzJxeHpnRzRFa0pxTjJjYk5XVGNyeXNnaQo0eWVKODdL'
    b'TVBLQi9KNFFxMFBlTnRsTzFPdXVzb2ZxVlRUM0ZuQ1lTKzBVSTZkUEh1SE9YMVAwb1VNdzNJ'
    b'dmREVWdmNG9yTHJpcWp2ClhlMis4N0Q2WEFjK0k0Y0UrT0RzZkhyOFQ3VnFDUFBPSUhzM25l'
    b'dnU0TXE4UEJ2bzNNcnk0QStOTFJweExwbWV1NktucEJCN0lmSDAKUm9FQlRPMXFETWMrbVBX'
    b'YURyTlhTQ25wUkhUUy8vUVVHdGZtU3FEOWRvYm91d1hhaXV5L1daR2V3ZkNkeFRzdldKM1ly'
    b'OURiSGUzZQpyaDVMVU5mTnNSVTZ5TWhYSFZzc1RmcG5KZlNYSEdWZW13eGthVFVsckRZejdE'
    b'OG1qcVh1MWpzZHJnSUhjWWl3ZnFNcllqR3FodTZVClJSbm9wRkI1OWdKTGVnYVpOVVhpTXFC'
    b'R0h1TWpJeU1nSjVBMEk0MTNKN292UFAwQzM3VUR6M09vQkppL291T3o4dWlZangzdExqRk4K'
    b'bGIrRUgza2s3bUs1YktWNkJGN01TemNOWnJxME5BQkFiZ0dwMVJBRHdGZnpSTGt5ZXJyU2hm'
    b'MFhoUDRwWmZFSTZISkJlZk50UStkVwpmTkVPQTRDMU8rVGExZGpxb2NWb3VWbXdtd1VZQS9y'
    b'ZHBBV0srQTc3dXNHcWpoNW5ValUwWlpRNEtrTVFpblFkdXVsK3V3QnVnSDRECmpselEzbHZr'
    b'Y0srT2UvVTIxS25CYk5xcnBHZnBnMTgxM3V1TmN2THBuQ1hpajV0Y0xUeTVmZjc2U1lNdUU4'
    b'QThZaENWQVd4R1ZPQ2kKaUFPYkFla0VuQ3BsZVdReElFcXBvNEFhVTZCM0Z2OFAvSUQvRzRR'
    b'RVlJR1hyRWFobkNOcTI2WmNhQUNUVzBBamdobE5CMERvcC9rVwpBUGhrWW1GdUN1TloycFpv'
    b'QVBPcnlQOTV6Mmcyb210cCtxeWZYT2V2YWgxYjhJbXBlby8yd3NUdnhUR0RUQ1ZmZnE2cjBL'
    b'WTVOK3RUCmFYU0tjUHROMHF5MGRnMTJ4MEdsWFFZcjNNTldNUUN0ZExiVmRiYmdPdDEyVEpy'
    b'clM5MURFREhEczRNTEF5dmhxQ3BNdXlhYzJZVHkKQzJsZUlia1FwMTlLMEcxbTZObkZNRzZr'
    b'K1I4dzVOcDFmZXdIemcrdUNkYnlRZkVoUTdpTDVkWjU0TkdqVWNkV25FT2tYODRUcDR3eQp0'
    b'MnZDT1VRcXVXaG9ZTEVrRmFZVEU5eXBBNjlUMHF3dGQvYXk5dTRieHRnRVRTZjB6eXRhcTRa'
    b'Y20wYmNyaVBLK2F0YXl6ZnlvNnF5Ckkvb2Fhb1N4QVQ0NHdBZXpsanNYNEc5SEY2NW96ZXR6'
    b'NzFXWHM1TnBoSWpkYndLcEFSUUF6Y2ZVYnFRRkF1UXhSRE1BTlNLRENha0sKZUxtaFY5dngx'
    b'QUJYcnVuN1Q2aUFrVkVBYncvY29SazMvTTE3U21kZUliMFFwMlZuVVVra2pud3F5V0FVQUFB'
    b'UUJ0OEFwbTF6MXMyQwpRd09aYjJaWkpnMTBqc2dRSG5jSTF3aW1tZlY2aE9nSE9yYktBZ0NM'
    b'Q1ZFS2xJS2ZGL2J6QWdBWTlyb0JBTlp0VkNJdlk4TmRJcUlDCjVYbGdlQUNBeUhEMjR3R21B'
    b'RjhtOVliKytSRFQ4dDljdW81eUNxaUhHNHBMSWpYQ0FBQ08vYW1scUdSU1pYbG9NdTkyODI3'
    b'UEZYTGYKakJPL2liWXNYbW85ZTFrN0c2T2xPYW1qZ0FJQ3N3MzUrT0V3WCt6dGdUM2NrTGM3'
    b'TWdqRlZ5a3F6Y3lsL2o2WXVXbTdmdHVuUkVZdwpFY0hNenNPS2h4c0o4TUdTVEZmOEpnOTR5'
    b'YkJodDlLNUpYZm1uUDdEYk1rakY2cm1ZNHVHcklDOUFJcmtYZ09RQU94WWU4L1BOWEtpCnFV'
    b'NU5OdEFYdTlWR2hSblVWZzVPN01OMFoxNHpXYjNNbnFMMSt0NmZpbm1SYjZmdTFsS0wxZ2tN'
    b'ZXNYK3lYV2hURWYwMityeSs1K2EKYWxjckZ0QURwOVFMY2RyZ1Y0M2YveXdGKzJPTENRZFZ3'
    b'dUZCdDhUMy9GVXR0NEFlK0V4NXJlQ1dkMm9IV080anU0S2dXaFFUV1plMQpXYkhGQkNZakty'
    b'U0RVeUtGZHBxV3BGOVBwcm5aaEVxZ1NZQWtxa213ejZIdVdPVWVYQWtEUUpGcEhQU0s4ZGlm'
    b'MnY1VDZvZjlqSVRBCmgxT2RJOTh5SGoycjZqclVyOEhPR0NhT3pCSHVENGdPTUx1dU12czdD'
    b'd0Q4c2tubXZpYTFFZk5ZUytFTVo0Ry9hRDlhb0UyZUJjOTIKRTZLcU1uZmdCd0FNQnQxSXM0'
    b'RjZseVdGaW9QV0NHZStYaUIrT3RBRUFEOXZrMXMxNEFCQWRNSCtVK28zSTRyMVpyNmQ1QlhT'
    b'SUQ5OApLRVo5OVduRFZ0WjErMzJzQUVPeUJKb0ZxYWRKQ3RVU0RHRG5pWVpBMEpGSlJSWUZB'
    b'Z0hWUjR6dHRuZWZZcE9mNzh5blpaTHpsN1gxCk8rVXViWVduV3d1ZlJUc0RLK0ZSYnhuejdX'
    b'VFdjdW01cDRTc1hMTGprUEpCUDlQRXNjNVIyY0pmTVczb3BsaG5aWkFhOE5qYlFuK0UKQWFD'
    b'WndncHI5YzJicEczUDRnOUhtc3BBZXA1MTVIdU9YcGZZOE5MaCtad0E1Zk9wWm80RmgwaHo4'
    b'cW1YTzZyc2p5OWMxZUJwNGZBWgo5Ym1uZUFBZ0JQNDRxYXpZTExlb3ozVnZMd1Q2TWdlUEtU'
    b'VUt5bkRkRVVBd3dzRUlnd0tnRkgrb0FNMEJxZ01VVWxvSXRNajVjZ0owCkxtQ3pOdEt0VzF5'
    b'Q0JtNW1XSFZDT2d1TVRVTW5EZXJyeXhSM2d2MFYrSDJMeTAyQjJpNW0zU0Zwc0ZNd1BnaEFD'
    b'dkM5dS96bTI4VjIKOU9vRnZRUGluNlRzekRwM3RlbW5mTnZXWlVmZnNrSS8vY3haNHlSK1Nt'
    b'SUp3TnhLTWcxRnJkcHdQVjhRQU9DUEUrcFg4NTF6eDFwcgpoREV6bDBsL25GUmY2U3IwNmli'
    b'OHRObTErNGhxRituaThaYVNlUEhGd1lYZTJSRG93TDBLeXNpOVVZQUVxcCt4Nk5jOEtPT0pU'
    b'SjdnCjdZVVJBOENDbXdYZEhjNDdKVXBWZ0p1SkI3dEVOUldvZG5QWktyaFVRbFd3R1JCQ0lH'
    b'dmdVaWpTa1ZVQWdPSi9XUW9tRGdHQWl1SEYKUGtMclpod0F4S2ZvazRlSUkzSjRyaHdFc2J4'
    b'U0RLd0t2QkVwS2kwSm4yOG5nVWZUSmx1V3JYUk5YeVg3WmFPZGVlcFhBOHd2UFNNVQpHY3N6'
    b'bDdRQkx4dDd2Rk13YTR4VmttbFdIdlRxSmlncVhidGRYajNOTm5hV2VIdThQNmkzY2Y5eDVj'
    b'd0pMWitYL1dXTVZhQUFrZ0Z5CkdGMHhJYzRIMWFqSFBOdk9FQm5Cb3Y5Zk91eHFvdWJWRUM4'
    b'U1Zia0F1SFRhTjR1M1BMelZsQmVFM1p6c2UxTWR3NGNZbjJsN1QwKzYKeit1R1o3b0orMCtx'
    b'aDlmb05hcXpKY2F5WVMyV0VGQVp5NEJvYnpEWUdGZHVrOWN6b3NKcGVEQmpGQkJ6bTlZOGUw'
    b'bVBTOUpVSGRhdgpkQk5kTkRGVlZ6WEFDSGw1SUMrM1d3N25QNk01UzF3WHo2b0NRc0tEbU9S'
    b'U1FkYm9BOVFkQ3lZQkJWWEZJYy9oK1V1VkQ2OExqenVFCkhLRHFEaVl6azF5STB5NG5raGM3'
    b'bFcwR3ZOelJ2aFBLNm1sVzQyM3NEcTZFUDV2bHRIcjVKa1MrVy96UjhTa0wzbkRzT3FvVkpj'
    b'TksKYU84SnBYTnpidWRSTlRaZWk0eGdhMVY1bUsvVHI1Y1FVNGZadWtFcHVFaGV1TUdGMFll'
    b'UUxNc0dlblNyZGducEQzR2R6THVDdVp4UQpiQ0N4RStKbHhveE1SdUJZOFBZb2d3WDVkbkx1'
    b'aXI3bnFQcm5WYTFsL1dMRDZXN0YyWG5rZEtwM2pudmpZa2NwWjE5T2x2aldDd1pQCk54d1p3'
    b'ZHB1bXJGR1VkelhDOFUzZXhnMjdsRktMbjlZeEhPb2NnRFQ0U20rYlhmKzUyemxlTFplMjRX'
    b'Wi84MlltUUJWMDVqdUd2Y1EKbFhvNXBtRjVnQzh6K2NQYjFZN05oUnBoYkZHWWVHZEdKb1BF'
    b'cCtnZG1uR2orNXVTMHZRRnYwZ3VtUUxBVzg4YlhLUlkxZUNDMUc0dAphTjBhVEpYS0RBQUUr'
    b'ZUcwTEJJYnIxRUtMQVB0bS9Cam81MmlSUC82d2lTWkpxWHBpZGQxdS9NdlhXVXhvWEdmbVh0'
    b'TkV5WUZ5NWxBCkh6ZW1sMi9GSkJpWTFqbGs3R1JIeitjTVI4Nm96N1RsNjBlV2VxTE5naE5T'
    b'OU00dCtSODN1bUppOWE2dE9JRkhBSEExU2JmelFVWGYKQ2NyYzh2RW4xTjE2SzhzVjRJT1Bu'
    b'RkhYN2xER0RqSDFhTStmdTZLTkhXSjY0R0lPbjFMWHJuQzUwaUhQU2Z5YnMwRUIyT0drcDJP'
    b'MQo4Q0FtTEJpOTNNbmc3M00vM3RhSjVLSVhNeVBmZC9hTzVTclR4NmhocGR5TFh0M3RuRzJm'
    b'TnYyOCtPTXlxN2NIWHJsRmZxRWpYMkw1CmdpdmhtaEhzNW4xS2VoYXBYWlZwV0lzcjh0VGNy'
    b'TmhtajlXdnMrN2kxZEV2Wkx0YlVWeXlIaHJJeUFvMUd4RUFNQmlwR2kzS2pmRVAKQ3JmK09L'
    b'TCsrSjFVTzVYcDcrUmRDT2JXa0tkK1pNWVlBR0RwZWxlVnlveTNPMXEwMXVVUXlhais1cExh'
    b'L2Qza2JzVno1MW1HRDNlOApjdTdPb0xhRUNvR2VBYjBxeGY3b0VjRmNqcmF3aEVJQlI3bVlk'
    b'N1k0VDhacExSdHlFY0hNald4aU5xSWl0TmJ2a2k5YzFmcytaOGd2CnBLa1p1cHNWMjh6SVpr'
    b'RjlPc25kcWwvNzhCV3hhUlFDZ0dXYlpIOGZadU51SlN1UHVGbHhZcXErYWEveVVtZGgrbzlT'
    b'OTNhOHIxZloKL0hMSmRPdzRaOVp5L2UxMElWSmxybU82SUVLWlBzdGF0QThBb0c1MWR0MU81'
    b'ZUJwVFZiQjZZS1ZXMlEvTHh3V2VNODBHTWVpcmwzNQpHWCs2ZkRLd0Y3MFQ3T084dHE2dTFu'
    b'd1V2NDJvU2hvTjFoNEZpdWlSblM5VWdFNnFJa2ZQdFRvbHVtQ045T1d3NGdwYXZ6SDJycTM0'
    b'CnA1cnhubTVGNGxWYSs4V29OYXV3cWdZM3NzanhjeXJMSXJNQjRsUDAxNTgxdkRQQjBhWWgx'
    b'NzA5WDFKS3ZJUGlrL1F2UG5IMnZjWVgKT1pONVFCZlZWMmJPc053bjJMaHlUWDluZ24zaWNI'
    b'T1RPdmR6amxTTnZqZkMwZTRNMi9CbVp3MEZXR2RSYUJmODBRY21oRUFuMFB2NQp3a0dadkFV'
    b'aDkzTHV6MENQOG9ob0J0QkZubktHalM3LzN1cGhLOFpxOGhLeFp4ZmgyQ2x0NlhxcDkvUEdO'
    b'NThyRlRDTm11SnNXWjlECkNObzNaZWV1ZE5VSVl6R0d6ZnZrNEVyNHcvNm1FbUc2bTM3ZHBP'
    b'eGFKQS9ONUVzeVljZXBacG5BZHUvNEFMVXJxL0RjZ0lMTmkyMzMKNzgvUWRQaHhoWFI2cjhZ'
    b'NWdBRElGbmo1TGFGVFd4NEFmaitnYk4wdmkvblF1RHA3STUxa3hKQlI2Y0svQk1JaVNnY3lv'
    b'N0ljNElXNwp2c0EvMDBtWXZVSktpeWR4U1hyek5semJobHpES1BaR05sbjl1L3grYitQcGkx'
    b'cE1yT1pod3doQm95aDIvUzY1c2orRE1SdzhwVTRlClpiNmRteVUyRWdCVy9DYXZXdTFxa3Nh'
    b'OElaVkN5MG5wck5yS2Q5OVoyUWRWQzE3dFcvQkdMME9QcnYrUTd5VnRISm01NVBSRmJjNVMK'
    b'cVVVUzA5UEpsNU5XL1Q5NFZ2NkFKeVliM29zUmtpWnBnL3ZhajI1Uk0vL1F6Sm1JYUxSaEZF'
    b'c3BUUHRCZXJtelFDa3NYT3RxV0l1aApRS3RVWnZZY1UxclU0N3pjVVpQYUhMbk5zWStOMTFx'
    b'OGtSOFRXeHoxVC9wT1hEeGZHcFVnM0lFZkFKZ1JldWtTTjJ5NFhWWWVFQmg0CkVXYnJPdVdm'
    b'aThWTjZjM01JUjQydlA1N1c5TXYrRit0eXI5QkNyY2lpSGJ6aXdRMEpqL2Q1ellMUVFHdUk3'
    b'SXlTRFVGb255Rjl1dG4KYU5XQSszcUIyTG9oRjFRSnh5WHB0YXV6YjM1a2Y2RURuNUZOUkJk'
    b'OFB0UlVWTWFLamRkZS9jQStiYlNaWWNETnlzeFpLQVpjUm4zegpidVc3ZitQNUV3WmJjMGRl'
    b'VjFLY0VFbEVaSFV0TlhxVzVWNUtPTjlPSnJ6dTlGQlFoNG1HWm8wZWdzZWVrVU1LSFhUeWNP'
    b'ZkhtWVluCkZjSllTaklZdlJaaGZRQjk0Z05hVGFNN09JTE82WDF6eXpCTHFaajhFcXllY1du'
    b'OTNqUysyRmxJejlUM0hGVVRycE94UTB6NWR1THIKaVV0WXJ4UG9OcmhnOGdmbTlDeHlJNU9z'
    b'WHU0YWxDM1VVWm5iTmVjM1JzdkZRT09MemJNUzlzdERrb1dpSXVWMUlFdXFLOUZ6TEc2VwpN'
    b'cFJRY2pyNXJyL1lMNStmWEVrZU9NN1l1QjVicGlHTWpkZVBIMVV1WGRDVlFnQ1Y2Z2h4Wmdp'
    b'cHdyUnV4eldvVlNxbEhodXZ4Y1RxCko0Nm8yams2UEV2QVR4Q0VFcVZmdXZuRWUwQ3ZqcG1O'
    b'NnpEN3RpdXVJOVFlUk9jdXNBTEE0bVdTWVJGdHBwWmlVQjdRWkVxeU9IckYKckcrUzFGYjF1'
    b'QmJOMmVhTnVLaXlrcDlMVnJ2VzdYUnRYT0FlL2IxMDhUZGxSSzdoamhyZVVoOUZqb1Q0Zk5L'
    b'c0tkdW5oMkhNRU1lbgpxWVlTeDJwZEMzWGFORXVaS3gvN3BiUDFkaHhLbVZWdVNrWUkxRzNL'
    b'MUtySFVnb0psL1dMZjJyT0RBcDVFR0hIa1U0Y2hoajJObDF5CmlaSVlvNWJzUXlOYnMwTUdH'
    b'b3lsWGQrdHU1VzA4WHA3bVhsaUlQekk1cld0MGFzdFhDdDJUSk9LZmNMVDJzSDk2c2ozalFC'
    b'QUNQVHYKWjMvbkNtOENPTTVvSi8wSThrTUJJU2lpT2xNNWxBa05aTzZmS3dHQXo4WTZnZzdo'
    b'QzFhOWRlNHQ1NzVrOTd6akZWUTVLdVduYncwNgpnZXc4a3BsRHo4YW8rbHpTU21VQlFBWTZN'
    b'MHhac05KYTVwMmRFaDNkMnpIeVpqRWhqdXFwSEtXVSttdE1LRUtHc29LRVJVYkxQbS9jCk9q'
    b'S0hKelRqQ2cyNGpyTHF3THg1eFZza0o1OHVXZS9LeWRPVGQ1THgrUTlablpaWGRrWUhDSGZt'
    b'VGZoandjbkdMb0RpN0ZlVEJteVQKQnNWUHhCaW1SbHUrbXkvSkVtblJucC9lc2ppMTl0Zkp6'
    b'UVBYazVoT1VobXZzSXZqTGxhdTZ5NmxmRERaNGVPSkJSNk42R09NcXNyTQp6aEZueENvY1F6'
    b'a1RHdHJybmprNXN4RngzZ2l1Ri85YkJURlZpcXErOTFqZ2F0NndLTHhaZmN2aHlWK2FpOVRz'
    b'aHQrVWt5ZVUyd3N5CkgvWXpBc0R3T0FmRVBHbTJjS0M3NkZ0WDhISmozdXFPRzBVOXpCM3p6'
    b'V1R4cWZXTVYxbDgzWTh4QnJUVDdPZzF4dmhNVzE0bndHRFEKQ2RpZHhOMktSUmMxR2RDOU9y'
    b'aGpFN1NxSWV5d1h2WVBVLzVxVUxHQndRNUIzdXVodG1uTHRXckFkVzU1cDQzUHlxT3pmaEkv'
    b'NkdjYwpOMW9jZnVZaHQxK1ViMUJ4Qk9ONjdZeXJ2akhPK1lRdnd1OUdObmxZTjArSzB6M3ZJ'
    b'UmR0Q0tsTTlCaWZrRnBWbWFLTVQ2R0RmRExkCm1aTlBBV0RtTWdrQXBpd1ZBZURQeS9yT3d3'
    b'b0FURjFhck8wMzdGYW16eFk3cC8rTjNXWUNsTlVLN1Z2ci90Vzc1cHBWMkVrTHhaUWIKcFY3'
    b'VHh3TzkzOGYwVXYvQ2F2RVBQMU5UamhBU2dHaWZVSm05RllOUFdxSWVQRk4yVFBiVEpsZEpZ'
    b'QTRBa3hhS3hXazVsWDQ1MTFuMAo5NGsvdGRTTVl0WXMvOWxWNWRyOWpvZWQ1UGtiN2sySGYr'
    b'NUt1VUd5OCttUUw1eWZEakpGQkRQbnIyb0J2dmg2QmlsSzBmNXhVcWxUCm5TVUVuQ0lCZ0t2'
    b'WDlPTzdWTGV0VUZmN3EwNUhMdERKd2ZVWU13OEFoUTRTL1pNMC9FMWpVVFBqVDZ0Y2E5YkxK'
    b'Ym8wRWpGZDdkeEQKNTNNNVZpcXVBazMwcTJZNWx5akpiR1lPK2ZRenAwY1EvcVIvc1lVL0Vh'
    b'TjUreUp2ZDJ3MUl3QklUQ1ZGdWNma2RCMEFFcThYUXlVcgpvTi9jMEF2bVNOWU0wTHdRbFdp'
    b'ZERPWjU2WDdzNktqSTU4N3ZlRmRoRi9RWFZRd3BsUDl3aGg3cHArN1lya1FHNFBrTHBIYjEy'
    b'ZEVqCkhWY0xkRmNHUFg5Rlp4QWROdGhoU3FVVGN3ekMzOGxxbnNjTUVEVmx2ejQ0WG9vcmdJ'
    b'L2VNeFNGUFpUQzNpMnFTNkdSdFpqUVFHYjUKQnFWbWJybWNPUzFIVzNnYXdYckI5TGJzV09l'
    b'bjJsVFVPWnZkMEZHZk9hRllLSWNPdFZ1UzRTaXZULy9LY2psZVAzaEc3ZG1WMzdaVApyUjdK'
    b'SW8wdSswMGVOOHdreTNUbEdsZkRwbHlJRDdOcnE5TGtQRzRwL2NNOTk2bk5KOFl6ZUU3aWli'
    b'Q2J6VGNpcFNhRWNvSEtsUG9pCi9JKzVhd2Y0bFdINzZob0FEUFFPTGZET0h0aXAwTWNENzlt'
    b'dXRJbGhhc2o0SFY5alJsQlkvU3RYSmpyMUp3eENpVklES3VVeC9HN1cKMW9hYXpPNmNiMDV1'
    b'cHlTbXFjVEdnSjRyVUU0QnJJT0N3QWJJZ1lpQlFhQ0JTZ0V3ZUZPY2lYUXpvRWpLL0MrSGcz'
    b'SVFUT0VOWDh1dQpjalgrUTMxQ3JDNTdmM3UyazlJcUNCZTEzKy9CekZkQnRWWW1udzBvbjVM'
    b'RkkwMndxVUM3aHpldVZKaXhNRHVaZzhma25QUERwRzBzClYwMVR3a3UvbWtUcGRvNS9YbFAv'
    b'RFRuU2ZLRExCV04vbDJSQy8wTDgvbCtFS2tiS1B1bFVNWGZtaWFlS3VUTUFBQzZnRjRIRVcz'
    b'VVgKZ0FWUXFCM1hBWVo1UWhiL0JDalNVNHdlcXVOTVJCME1hYXo5N1QwblVab0YxQW1BRWJn'
    b'QnVGRjBlMEVqbFpJTnZpb05RNjA3Y1RWcgpNZ1lCNlRxY1BLVWQycU9hRXVocnVmenRoem9M'
    b'Z0JaUTZnM29zYkxsandMQ3c0aCs2VlU1akpJcDJhbC8vYng1THRBVkFVcXFnN1IvCmxkK3hV'
    b'MjNSbkFXRTB0WnIxQVo5TS9nSDloUWxJckxKVnlXKzRPYUhLdmxqZ3hFaEJoejVrSjJsT3gx'
    b'QUZaQmMxR1JFZ1ZXWVBuMEUKWDg4eURNcTFOUDNyTDhWblkxbWtvUjIrS3EyRUtnVmpEeCtV'
    b'a1VaT250S21aQnNNajRkVFhTNktkSW5SdXRVclZHV1pSaG54QTZTQwpGaFNIR2E5Ync3a3hx'
    b'ZnFZZU93TkQ0aWpLY0IzL3ZKK1VkK3l5RzNSTDFML053eE5tM0QxSXRtMFRQSVRwaTkyNVdl'
    b'OExiM200a0x1CjBZK3JBU3p3a24zYU1lTUhtOTBzV05Wb29RTUtuY1REaHU0ZWdYTFArRWVq'
    b'ODFkSmJsWHhkTHZ5YkF2dTYzNldvaXdTQU93OXFNSUoKYW5oc2dxSnlHUjAwbnpmdTk2c3Fl'
    b'YXNkZ3ErR21aUnJGN1FyS3RteDFDMHRpMHpxNjlpR3d6OHB5R3A3anppcEVPakNBTVZRQzcv'
    b'VwpVd2dMWXR3c1VISzhqUkJBQ0c1a2t6K09LNGYyYUwwT2MzNWw4WEdLbnp6a2EyUFZjT2I3'
    b'UmE2NDB4cktCemNaOFRxSUxIVUlnRHhSCmxYck02NzNLbHJ6N0V5RVFQVmZLK2wzdm44ZWpm'
    b'NzBpUFFpNlBKSVoySk1IZ05NWHRmTnhXcDhlaGxrL1NXdld5RUpsYnkzVnNDUXoKdDB6NSs0'
    b'VlJXczRRYWxabHZkMkx1WFRzVDgzUEc0VUdsQkxkbGV2bHpHKzA3dmpPTk9rZW8rYjNJZFBw'
    b'S1g3d0FIdXZPSzRxbENIdwpDVlRmN3FPSmdkRHRSYjdMVXp6SG90LzJLWUYrK0k3REFuZlEz'
    b'a1BxK0dsT2F5N1VzM0FhcFNLbWdNRkJ3TUFEQVZBWXNISkFLSWc2CllBNnNIRklKbFFrZ0da'
    b'cGtNSzBWOWdsVHBIOFkxYTArdWkxR2UrTlp6bXhFc1FsNjNXb2NwUkNicUIvYzdBNmc5ZjBn'
    b'MDVsUlJzTHMKVzM4NXZBVlQ2Q0FjUzcrYUp5VmUxMS9ySnV3K29uNCsxTFJodC9KOGgxdVZ0'
    b'aXJoVE01L3lNSXR5dHVacGNwdlo5MzBXVjFNdTQ4bwo3ZVBaTXZFRGdIREVETWxtOUd3NGZF'
    b'RjliNEZpREVGdHVuQXJmbk90L2gxMWE4MDNyczJhRExjbVlWeU0xL2NjVXkvRmF6V0MyRysv'
    b'CnRIaDVJSUZIUlluc3V5Y0psQ200YXpmSzA1Zks3NWREMTB5NVFGZ0FkSUVKaHorUDE3NXJq'
    b'ay9ScC84Z2pSMWlxbCtEa1dSYTRDQkYKSlJnQUNESVQvYTdaRDJtVVJMWmovY0x4cysyRkky'
    b'ZFVxd1UyN0ZZcUIyQ2JCY1VsNit0MnlzczJTdFhEMmRIOVRSNDIxS1F1MjZRdQpPL3lVQXpK'
    b'TDNjU3NRblkrcVZtVlhlMGpoMlhnb0xzT05qZ3BMUUNhRDVDTFNMWUFOaGt5NHNnMzUwVVBM'
    b'K3psZzZNVHBZeGNVaitTCnM1aG9vUVBNSmhRV2hIdTA1MGYydmVmb0dVMEhoMGlMQnVzNEpj'
    b'cGdzSmlMQU1ZZU5vUXh2UEtDRUJpSVY0MVQzc2puSG5jSVR6SHMKNTVYcm10eHZ6QitXQlFB'
    b'UndVeGVJUVdBbWxWWUFLQVVpaVprbll0VjFkTmxUR0N4SS9EMlFVNkpBRUR6ZWx4MlB1blVn'
    b'azFNSlQ5TQp0UDZ3d2FVVHVKSkVPcmZFdng5UVhuOUdBSUNFVlAzQU5kWGlCVy9sM09vNmZD'
    b'NkgvK3BMTVhxR1pmd2k4K3BWOHZvRUJTbFUwUkdoCjFNQWpKSURWaHJ5OHNaY2Y5cS9FTnZI'
    b'SC9yNjRUQi9uYXBMT2N4QVN3Q1JlMTB0NjVnNmNVbHMzNU9LUzlTQS9iQmRoOWt3eE41R2kK'
    b'QW1yUkVFL0JvaUdrUTVIazYwQ3plVm9ZQ045TXNYallVTXNtM09vcXNuS1M4by81V2Z1WlZr'
    b'K01HSU1ydjBSQjl1NGhsUFEzSUFSRgpweWFtVDVBK3lpbWpwNkV5UmR1UHF0MTZGaXZHN3Uw'
    b'RVB5L20yblVkWXdqMHhXMGJjYjZlaUdYUWl6Yzc2czFHdEcyRjI2RlQ2cmJKCjZqTmk4UWIz'
    b'QTlRMWhoM1l4OTZnTGR1cEsxOGxCTi9SUmlhNmFGb215Y2dteWRmSWhWTnE2blZkRjRHSWNP'
    b'eUc5dk1pYTVIRlRValYKRjYxMVRYemZuSk5QNTZ4d2ZUUFNCQUF6ZjVMcVZtUFBYZEhYN25D'
    b'OTE5djR3V0RIc0dUQjY3NlE1T2JRcjc5eVRwbHFBWUNtYmJqNApFelFTUGQ0UTlpckk2Snlm'
    b'dWNxaTdEc2l0R3ZPQWNEZERvS21BeEVCbC9YbVJvVHlyNUdubXZGcmQ4Z3ZkeFlBWU9zQmhS'
    b'SUtJUHk4ClRhNVRuWjM1Y2FtZVFUOHZQSCsxOU9yVHdpU1RBdUt0enlOVkhCa3Z4TWZwTzM1'
    b'MkxUVVJGd2JnZ09PQUtLQ3BZS0hJVXdZZkVYdXAKcUNuQ3p3RERBS3l6cWY3UDhxRUJqRk9p'
    b'SzM1elpXVFRDZStaZGg5VjloeFZ4ZzAxY1N6YWVWZ0o5TVZ0R25PanB6cW5qREtQK3RneApN'
    b'Sm4zZXBCSWVRSlNDbTYrdUVMeHd6aGVXcjRRZHFNSUFONXc4TXZIeSt0TXJyYXY4eSsvZUtl'
    b'MHNReU1HRy8rWnF4elJMcHdSNDVqCm1aZnl3Z0FEeDhMK2sycVA5anpQSVllVE5vNWlBY0Rm'
    b'R3hmZVBDRXN1dWpZV2FMWkNJTmZNL0ljU2tnbVFjNHlOR0VFWWlLY0REanYKNDR6ZitqTkV3'
    b'WmQvSjhQMjJGa043Q3kxZUtJeGh4ejVJcGc5WU13SUVhazBPNTk2Mi9ET1JiTGlndmRPMlZ0'
    b'bnNQNS9JYjI4MjZBMQo2VmpNNGRoeldpTW9GMXRZWGtIRlVaT205TVg5K3BUZE01bWNSajc3'
    b'd05FL2lRK21HQUMyV05XcnZzUXZpdm5zWXhNQUhEcXR6bDdwCld2U1ZCUUErbXVhc1haM0p6'
    b'YWVmRGpSdFA2U3UyZVpLeTlDbmZHaUpxc29DZ0U2Z1I3K0NWc2xNcE16VW9zeTltSnBBOVRN'
    b'V2t1UkcKa0FWVUhvd2M0bG1Bb2trVk9rVWNVQTA0aEV3OEFJQmRCcUpUcW9PRkF3WWpXYU11'
    b'SFVBRkE0TjREQnFob2daRUF4TURIQUtWZ3FnQgpxR0JoQVFOb0ZKd2FnRWF0REZJNXFOS0dm'
    b'WCs0RVFBS0hXUlVQK2RIcWNLVEJPRVBIc3AvRmhwRDczM1cwaW5STVdPZDFVNmpVSW1aCjV1'
    b'ZWFOOTFTUGJ3WWxhL21peVlEYk42cjdscHNPM2RWR3piQmVYaWxPNE5oeUZlT0NjUE5YeThR'
    b'cDQyKzFWSjE5cEsyODRpNmRhUGMKSjVPdlRJcnpQdmxBOHhCTnM1RlVOOHA0US9XNlRQc09m'
    b'R1E0aS85UGhabmxHMXc3MXlrV2hKQUQ2dWN3N1I1cW1GaGVJZWZ6ZWR6dwpNWTcrdlkyM0Iz'
    b'T2x2SDhqbWpuVjh2dHU1ZUErVmJvQVp5N29SUkF5R0xxMjVCUVY1djVDYTd5a0FzT0RiaG85'
    b'VGRSVVluY1NMM2QwCis5R3lRZ2VaLzdQTHpZcVdMN1JkdUt6R1h5VXVHU2lBbHpjTzlFZXRn'
    b'b3NuTFB6RDFPNEo5Vks4VmpTQzJteEUvUDh3cGNMSW9oNnYKQ29oRGxYeFJmTHkrNkFkbFFB'
    b'Ny91RVBvRHNqVGlScldZaW1GMHhlMWhyWEtmdERUSGZnVGw3V0ZmUzIzajR4eHQ2TDF1eFdy'
    b'bDN0UwpuWThBQUZScDVaNHBheWZxZjV4VW9mVGNtU2xMcEVranpGT1dpQXlHVHEwRWFQVXdY'
    b'MEVIbWhwSC9qaW1WaWxrdXNqcy84aHlFYWdLCjlJd0E1ejMxVTdJMkFCNTdDQUZnY0NyLzZw'
    b'Q0N0MTQzUklhejhTbDZSSEFaQWlFcjFDbVJpL0g2dWgzSzUwT0xPK1NyaHJKWGt5U0QKN2Fi'
    b'L3lSbmQzYmlZUzByYlJod0FQTlAyMXN1UDZHdWF0bFRzMVUzWXRGZCsrMlhqdzExLzY4Wjg2'
    b'OFk4QUJ3Nm9TNmFJM1ZPWkp1bwovek83Rk9oeWc4MkFoOW5RWFk3R3dRZHduenorbDNWeXZw'
    b'MkdCTnpqT0h5eXJtb1FuNkovUHRSRUNNUW1hSVFBeThEaThWYVhmdk05ClhRWDFxdWpucjJv'
    b'dEczQUEwTFl4bDVGRHN2TXBBSGk2b1FBL1p0b1AwdUVZcmZ4ZXBHVmpidkZTVzhGYmFMNm4v'
    b'RkRhQ1AwZWFvQmYKdmxYN1RqSVg3NlJ1UnNSZ1dMOUxjYmVpOWsxTE9kYUNnRTZjMS83NDBm'
    b'M1B5L3EzaTUzTjYvSGhRWXpBbzJ0cHVzVDdGWDNITjMzNwpoREY2ZU5DdG9OREhBNi9mTFRz'
    b'bDJxZUhvZTl6UXFHRGZEemd3WE5uUkJmZHVFVTUrb2ZxZEZDbk8vWHp4UzRaQ2gyMGVUM3Vx'
    b'YVlQCkdQNkZNUXp1YjR4cHJFMzZYUHdnL2NHVExCOGxsYnVMOW5ZMlArOWpxY1BMQmY0K3VI'
    b'MVRMaVpXaytSYjFxeXlQdzROWUM0bGFITlcKaXQzYjg4M3FzRVhubTF3dXFva09jR1JaVS9k'
    b'MWpZaUxDR1owVW9xaERFYlhVZ2tBR0FXa1BVZ0Njd3ZvbHhPY28xNTNzTlBKNEJPOApXa2dY'
    b'VHJETy9OankzVGhMdlVpbVFTUno4TFE2ZEx4ajVSYVozamY0cmwrYkhSdHRuaElrTysvN1BZ'
    b'blNSd2xodWMrZHdRQWROTlpmCnhkRm5YUmVTZEpjS1RXdmZFa1FHbysySDFMM0hsV0d2RzBV'
    b'SjVkbUp6WUp0RnVUamllc0hadnVKWjk3dmxERDhWUVFBM3k0V2E0VGgKM3crb3FvbzgzVkJz'
    b'Z3I3anNQTGEwNGJOKzVTUUFCeHhiOC96MTAzS2QxOUt6NTFpdXpnNGQ0Sm0raXJEdmpTRjNK'
    b'd09YVE9DbmIxQwpValVJQ1dBU1UvU2ZOc3RONjNBbDFkMjd5Y01OTjI3RGpUOHNOU2hnN2g0'
    b'TG5BVjBSckNTMUlSc3dXcElIblovSkdYaFI5Yzdrd1YwClZYTTFlcnBGSi9EVlBPZTRvY1h6'
    b'bDNxT0tHemJtTzNXUmpBSzZPNWpvVGV5aVo4WFZqVjY5S3gySTRjNG5OUm9RQzZadG12TXZ6'
    b'RzYKc0ZNTHJub1lXNVQxdnB0Y012MzhDMmZ3Y2R4TlpBSEFCWFJhWlhuTVpITkVDSE8zanMz'
    b'SnA5bDU1RkNNdW5HUHNuS0s3VDR6b0lwVwpOZm9keDRoazRmWmsvU1dHL0ZwRG1UYkQ0bTdG'
    b'THBtT2VzTXg0cnJ3cjRJUUFJNEoraFovVmZlazM0NnhsRGc0VTVlSzNkcndKZ1A2CmVxNzRR'
    b'aGZoNmJhbHZMVlJVNXp0bTNLRVFLc0czUGRycEtvaERFWm8reUhGMHcwTmVzVndMeThKQUJK'
    b'VDlYRWZPZDlNNUVwKzNla2sKMVl6ajJSNmRIdUFOWGswaVk2WTQxc3l4M2Y5ckdUbGswbGNp'
    b'VFNSQmRpeGdkTlZDZkp2aFQwYWJXUWFPbjlPV2JaVCtqTkViK3JHYQpBb0dwMExPQUx6K3VQ'
    b'dElteEtZeTAvUWFjenhkbnoxWGlnaGpYbnhCOFBQQ0ZOQ3BHRzNaQnJsM1Q2Rm9Hb2xUb3B2'
    b'MktyMjZDU2szCmlJOG5VdFhpL0RqRElBWWpoTURBdzVoQjk1d2I5T3RPWmM4QjJYNktqczRw'
    b'NVhkVVJzem0vY29ESWF3YWd0VkNldXlNMXJUZS9aamoKNTRWblJsdEVGNDFQSmdDMGZ4QmpN'
    b'UlUvS3l5SW1mTlo4Ukh3QWdjWk1zcFI1MDlTdmR3bTd6MktHV3gzVUtDT3JRbkkrelFzMmlV'
    b'Zgp1cWpHSitpbmRta0JGS1ZxZEdRL0kwS3c0QmU1ZmczVzN3ZFBYU0wyN0dxNGtVMjgzSEZT'
    b'bXU3bmhRbUZSbEhzd2RQcWMwOFY2eWlIClNFZCs2MlFaaUtqTVVBcHJkN29XLytCcUhjdjBM'
    b'eFM0MHJiS0RDZ3preDUxYUUwYlB5RGR2SGU5ZWlWTzc5TGx3YUxEc2NqUEMvdDUKNGR0ek55'
    b'VjdhODh4WmR0QnRYMHIvcVJKY3lTVjEwaTJSd3JoVG9RbWVRWmtVcjJqcm5raDNFeGtJK0p4'
    b'ODNTdXJjeHlCS1VhaVVPQgpYN1lxYnU3UXZiM3crd0ZGSStCdVJia0Z0RU56YnZSVTU5T3Rl'
    b'Y2tGQzM2UkJ2VTBWZkxHUlh2ODZVRUZkYXR4M2RyeUZoTmF2c0cxCmFZa3lLa1dvZXpNR3ow'
    b'U3dsMlg5ZEZMVVNsRkZ3U2x4Wkh1RzJycmxQVkdVRmJwN3VZeHpvRTdIKy9rMWY0WENncGpt'
    b'ZGJscW9VemIKVnZ6Q2phN21qbkxSZVkvQ0Z1b0FMa3JOQ0drQXd6eE05bENqdjVUNTBqVm83'
    b'aXBseVZ4QTR5akpOSkNZbWlTZGtKWk4rVkg5akpUQwo4WFBxNG5XdTd1MzRmRHV0NUkzYk5M'
    b'bzFXS0hYcU1JWE9ncnRtL0xuTHF1ekYwb2hTZmdkNTYwV0ZTZWxnd3pHcklqUUtENjJSb3JT'
    b'Ckw2ZDR5UFpCUWJ2YWpvNGZWL1podHl0SitpOXZTOTBLdVJsVjVWbnpyUGRxa0tFVTRwTDFT'
    b'MWUweEt0NlppWjFzeUMvWUZ5bkxsdXIKeXAwL3JyZnZ1THIvcEhyaWdObzVtK3RXRGlpV0w0'
    b'UXJCTk1obTlFV2VDTXFBRkxpU05zazlrQ1k5djBTSzBMdzBXZU96bnZZMExJcwpSQzdRYmFB'
    b'dVp1UW1OZG5BVUxaV05lYjFaNFdTbHFRUzJyeFhXYnJPdFNiYXR2Z1hhYzBLZVdpT1VLLzBq'
    b'TkI5WnYxMGdIYktUc2FOCk5BWjQ0UjgvbHQ3SktsYS94emt0N1VYMHdmdkdNckY1ZTZCOTZI'
    b'bGVCVmdZcUVTMVo3czh6VlVQWlFtRjFBejkzRVg5eEVFMTl6b2wKZVRTb0VJVVhZbi9BYmdn'
    b'clFETXB2V3JTNHp3SUc0aDZEeEFhM1RWTE1YcStGTElDYXV0UHp0eVorVWJya2lhOWFvcnJE'
    b'czZ5RjMweQphNTU0NFpMKy9TeHJrUTBiMXRzK0pzMkFBZXdBKzR6cUZXL0t1Z0ZqQlM4ZlZM'
    b'VW1XN3NXVXkyTXZjL0l1OCsvY0dZZDE5a0E3SllHCmIrUnhmT21KWUYrYlBhVEk3Rld6alFD'
    b'dzY0amlac0U3dHlyTk51Q1FtOW1NYVdIeXZIdk1uVW5OSU5FRHhNSFpQQUFrVVhMTXFsMDMK'
    b'VVFSUVNjSGhCU2lTTUhmM3BKOWt1T1ZXM3RzdjE0eVFMWTNxR25McmhELzl1RGhuVkRSM0pp'
    b'dFh6OTFCUGlsOFF1Yk9FSUE0WGVsMgplaDJxbHdWUXZPamhRMitsd1N3bTlNNW5wdW16SmFx'
    b'QmR3anE4YkxodlRwLzc2Y2tEQWI0VDU3Z2tWZkdOUWN4ODJ1ZGJ0MU5xNzVmCkkrVVcwSm9S'
    b'Yk1mbWJHUUU4MG1LRStWU0RZQTNRUE9uN21rT2cveXc0ZytRRFFBUWduQ0lnNGZiZnkvenJn'
    b'Y2VZOWhQYTdZUE1SemYKRkcxRkNLNWMweGZQbDJMTzMrcDFMcGs3TStpOEhRcWZrS0FDQTB4'
    b'VFpGRGtnZWRkcjMyRWZEeHg3MjY0U2UxU010VzRQdHQ0aWZVZgpQMEl3NEhzTkY4ekU2TldZ'
    b'RFVsbWwxcVQrZVJ0MDVVa3ZXalR6SjVqZWVCdG5SSTFHNUVpL28wazJWR01XMTA1Y00wcmYr'
    b'bDZybVlFCjI2d3UrKzIzcFI2VWxVYzM3Wkg3dldBd1daK29vU1VBY0lQUXF2WDUxZDhLc3ov'
    b'aTdzRHZmNmZyU2ZxOUdwQmUxTFRCTGtlKzBmcGEKTndNQVZBdGhLSVVaeTZTaW1aY0xmcEVB'
    b'WU5WV0dRQ3VwZWtuem1rQThNdjI0dWtpczFkSVczY3J0ZEwveG1wZmtXVzFXbjcwZUdQWAox'
    b'bnp0YXN6ZVkycFdYcWtkNE9PQjZsWm5YeHRXeUNjOWFXbnV6ejBybWZ4dXlkbHZCL1RacStR'
    b'eXYzbmdWTEhhT1hoYXZaMmhxa1pMClJ0S2taNUdTWkhkc25BWng5RjQ2QkFIc1lmbllnR2ZI'
    b'elhJVjVaekhmK2ZzMkl5ckg4bm01Rk9IQ0twRzQ1SjBBRGh5UnJOWkVRQmMKVHRTTE1tMm5U'
    b'cWk3b3VVdWYvblhsbDFBaC9wV3J0WFEyTEFtNit1SlA1OHRBb0ROREFDdy83QjY3RlJ4RHI1'
    b'UkZPdVpoUVptUHZ3MApUVGxtWjY1VGVqRzBNUiszSFFCcE9zejlYanFWUUpaTkxRNUQwN0tJ'
    b'MVlSS0FxOTl4OVhXRFRsS1lkOXh0VlVEN3VCcHRXY1hBUUFJCmdZdnh4VVc2cWRQRW5CUVNH'
    b'STZkQllBUzZjRHMrN0dqanE1R25kL1JScU5EWXUwTUM4ZXphYU5hRkdQdDQ0bk9EazM0Wi9v'
    b'Vjl1a3AKL0x4ZTNuRlNxUkhHVEp3anVtUTZhNzU0WnIvKzdqVWg4Ty9zN0pNSVovaFYzN1U3'
    b'MmF3bzV4TkpyNWVFa29MYXFtVXVod0wxdjdmdwpITHB3VmF2a2ZCSitDUFoyU3NPb2N2eWhU'
    b'cm8wWklDdU9tbjlGS2I2aTdkWUV6MUR6RTZrNW1BMGE3SWxPNDlJTXRVSnJOa3ExNnZCCnhL'
    b'Zm9WeEowQUpCa09uK1pWTHNhbTFkSWY5M29zcDJEb2JrR0taNytsWEpkT0lWRllpRVBiS05y'
    b'TEFDTThBaDQ1enUzLzJTZS9kZ3AKU0xGUUQ0VEVTYnFONHFZOGMraVFVbHRHR2tVZWdKNUJm'
    b'NXNob1pTMGpUc3dTVWJwSy9CbWo0Q1o2d3JEZzFWdkQ3eGhzeHlSZ0dzNwptYzc5ZE9yclkw'
    b'cEluNWIzUkRVaEFrQTJVQ09GMitQbmFEOGx0NWF4ZWhoeUpvdldHUFJhTnJmY1E4a1FLRkVv'
    b'UXNqQUFDdUJaZ1NRClFjT1U1UkJMa2RHT0NtM0VvRUhEQXJiQi94QlJ4VERzWkY1WUlUbkx3'
    b'M0lvVU54cFA4Z3ZRcFlkbldtcXpORElRdHhNWXdGZ0ZTZEUKMStvNC84K3Q5UWw5d2lBc0ky'
    b'b0c2QjdhZ0NqaWdyU0xRZi9HU1EzekJGT1U2bXBEU3MzUXl3YzZWVEJOa0tWeWV1Z2poVEFM'
    b'NkRpTAp4N3ZPd2toSzROOUlOMC9GUEZLcW1Ednp4RlBGM0prS0NDdW9Bc0lLcW9Dd0FzSUtx'
    b'b0N3Z2lvZ3JLQUtDQ3NncktBS0NDdm8vMG4vCkJibGN6RjdSaTY5M0FBQUFKWFJGV0hSa1lY'
    b'UmxPbU55WldGMFpRQXlNREl6TFRBMExUSTVWREUwT2pVeE9qQTRLekF3T2pBd0pRZGEKc2dB'
    b'QUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3TkMweU9WUXhORG8xTVRvd09Dc3dN'
    b'RG93TUZSYTRnNEFBQUFBU1VWTwpSSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxMTYzNSIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'FR_NOR')

FR_NOR = b64_FR_NOR
index.append("FR_NOR")
index.append("France Normandie")
catalog["FR_NOR"] = FR_NOR
catalog["France Normandie"] = FR_NOR
country["France Normandie"] = ('FR_NOR', '', 1)
lookup["FR_NOR"] = ('FR_NOR', '', 'France Normandie', 1)
lookup["France Normandie"] = ('FR_NOR', '', 'France Normandie', 1)
details["FR_NOR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_NOR"] = ('FR_NOR', 'France Normandie', 1)
regional["France Normandie"] = ('FR_NOR', 'France Normandie', 1)
#----------------------------------------------------------------------
b64_FR_OCC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjk0NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1LDqWdpb25fT2NjaXRhbmllXyhzeW1ib2xfb25seSku'
    b'c3ZnLnBuZyIKICAgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25h'
    b'bWVzcGFjZXMvaW5rc2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGku'
    b'c291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8yMDAwL3N2ZyIKICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnMKICAgICBpZD0iZGVmczEyOTUxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcK'
    b'ICAgICBpZD0ibmFtZWR2aWV3MTI5NDkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAg'
    b'IGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBp'
    b'bmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAi'
    b'CiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3Nj'
    b'YXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAg'
    b'IGlkPSJnMTI5NTMiPgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVp'
    b'Z2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5'
    b'bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVm'
    b'PSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFB'
    b'QmtDQU1BQUFCVGhUbkNBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdB'
    b'QWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFCOVZCTVZFWEJB'
    b'QXJDQXdyRkRnblVSQWY3CnlnSC8yQUR1bmdQRURBbkRCd3I4elFIaGJ3WElHUW5xandQQkFR'
    b'cnpyd0xZVHdiS0lBbjV4QUh3b3dMTEl3ajV3d0g2eHdISkdnblUKUWdmOHpBSDh6Z0RRTXdq'
    b'TUpRanRtd1AxdFFMZmFnWEJBZ3JHRVFubmhRVC8xd0RRTkFqQ0JBckNCUXI0dndIcWtBUDd5'
    b'UUhPTHdqTQpKd2pQTVFqS0lRanRtQVBnYlFYbGZRVERDQXI2eUFIV1NnZmljZ1htZ2dUVFB3'
    b'Zk9MQWpRTlFqMXRBTHRtZ1ArMUFES0hnbmVaQVhQCk1nam9od1Rya2dQZFlnWE5LUWorMVFE'
    b'SEZnbmRZd1hlWmdYWFN3ZlRRQWZXU3dmMXRnTEhFd25zbGdQRUNRcjkwQURLSHduV1NRZmYK'
    b'WndYTkt3amNYUWJwaWdUOTBRRGdhd1haVlFicmtRUFRQZ2ZJRnduTUtBak1KZ2oydHdMVFBR'
    b'ZkVDd25ZVUFienJnTFpVd2I5MGdEaApiZ1hQTUFqLzFnRCswd0RhVmdiRkRRbnhxUUxnYkFY'
    b'MHNBTGNZQWJJR0FuN3l3SFhUZ2JrZkFUd3BBTDR3QUhZVVFiNXdnSE9MUWpoCmNRWFVRd2Zx'
    b'alFQVlJ3ZnFqZ1BqZFFYOHp3RGljd1hSTndmSkhBbjBzd0xMSWdqd3BRTEpHd25STmdmMnVB'
    b'SHlxZ0x1bkFQamR3WFcKU0FmeHBnTHZvZ1BiV1FiR0V3blNQQWZvaVFUTEpBakhGUW5PTGdq'
    b'ZmFRWHJrd1BwakFUY1h3YkpIUW41eFFIdW5RUGJXd2JHRWdudAptUVBuaGdUc2xBUG1nQVQz'
    b'dXdIZmFBWEZEd252b0FQMHNnTFZSZ2YvLy84MWwzQnZBQUFBQVdKTFIwU210N0FibFFBQUFB'
    b'ZDBTVTFGCkIrY0pEZzh3R2dNaUhHd0FBQU1oU1VSQlZHamU3WnJaV3hKUkdNWUg0MVVSS2Jj'
    b'VUU5TVFGOVRVVEV1MHpiRWlUVE96TWpLalRTa3IKSzVmS3NoUnp5VW96czkzMitqODdoMkdt'
    b'U094NXVtRG11emp2QlE4Zk4veWVjNzU5UnBLRWhJU0VoSVNFaElTRWhJUW95aFJIa1dxZApH'
    b'ZkVKNUtnU0xRQ1N5R0ZaR1JXU3lXSFoxak9zRGVTd1VsS0JOQnMxcXZRTVlHTW1OYW9zTzVD'
    b'OWlRNVBqaU4zYzE3K0ZpZWpLdUMyCnE1QUNsYXVJT1hweENmc29jbk83dE1SU1JnQ3JIR0Z0'
    b'elEvWkZVQWxBYXlxYlNFb2UzWFkzZzdVOEd4UnU4TllycDExRmc5UTN4Q0oKdFF2TzNZWWZH'
    b'ZVBhRTRtMUY5aG5PRmFqRTNMVDMxajdqZmN3QjNDQUJsYmNRVytlWmh3Q21rbGd0YkI4ZFZp'
    b'cmdLMXR3SkVvV0ludAo2ZnBpSGVWcG9VTXppNEZqVWJBNmNkeXFLOVlKanVYV3pKTkFWeFNz'
    b'WnVDVXJsZysxc2EwbmRiTWJsWjhvbUNkQVdyMXZjVWVkbHB5CmpacEZUZG5BV1FKWXRyUlEw'
    b'WkU5Zm1YY09RZmtFTUE2RDFnY0liSUw4UmU5MXJ3dXdHczhWb3FaaDk0bFQyKzRmK2hqR1NK'
    b'Z09OWmwKRm1KWGVEYTE5bDlWT3h0Y014U3J3SC9keDFnR3l0V1l2SEh6MXFDTWNHMk9pbVVk'
    b'aW5rN3pmN1hQc3c2bWNoODVMS1dkclNzaFRYQwp3dlIyak5zK1dmR2xPMnRUcjhLNnkwTzJT'
    b'ZytzK3RIL3dMb1hleXpwUGpER01yenNqZmkxTUxOeDdVdDBzekI5RUd2bmVoZ1l0MDR3CkJ3'
    b'dXF1d2QvNWVSdzd6OWQvbEZnU3A5bWF4cVlNYkV2NHhVVFJCS0VNdHJiZVRvdG0xWFRLZm9v'
    b'cEZOSkNyRGlNNnVVeGNuSGMrV0oKeVNTS2oyUjdFbUxxZmZwc1BtVFBBTjBVR3BzRkR2VjhV'
    b'YVZrTlRLQkFOYUxRZFlHTG1sbWtFZ2IrSkpmNGUrQjNnOHNrOEVhMGN4WAp3T3NvV011UTMr'
    b'aUsxZlFXZUtjTmlsV3NHQWVqWU1XOTEzdXI5Q0hRYnRLTVVXQ2E0TEMvUW1iWS8xT2xUc2cr'
    b'ZWxnZTRDT3hSZEpVCmJyWmo5ZHF0SCtneGtrcGRVczVGWXJtR3ZJWWVscmJTL2FTTXNVbkFa'
    b'K05EVUZtQUovTUYrSmRHYnJ2YitoWUlZRW1MSzNWZmxjY0YKNWxDSi9EWXZFVkxXQUJzZGx5'
    b'UnlDbVlBcVQ1NlhQekIzWGR5RCs0azB3L205OVhrc0JwNG11Z2toOVU2eHJCZTBuT3VuMmFz'
    b'dE5MRApJdnA2aHBDUWtKQ1FrSkNRa0pDUWtQUUxCM3FYN2VOdkdIQUFBQUFsZEVWWWRHUmhk'
    b'R1U2WTNKbFlYUmxBREl3TWpNdE1Ea3RNVFJVCk1UVTZORGc2TWpZck1EQTZNREM2NjRML0FB'
    b'QUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl6TFRBNUxURTBWREUxT2pRNE9qSTIKS3pB'
    b'd09qQXd5N1k2UXdBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTI5NTUi'
    b'IC8+CiAgPC9nPgo8L3N2Zz4K', 'FR_OCC')

FR_OCC = b64_FR_OCC
index.append("FR_OCC")
index.append("France Occitanie")
catalog["FR_OCC"] = FR_OCC
catalog["France Occitanie"] = FR_OCC
country["France Occitanie"] = ('FR_OCC', '', 1)
lookup["FR_OCC"] = ('FR_OCC', '', 'France Occitanie', 1)
lookup["France Occitanie"] = ('FR_OCC', '', 'France Occitanie', 1)
details["FR_OCC"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_OCC"] = ('FR_OCC', 'France Occitanie', 1)
regional["France Occitanie"] = ('FR_OCC', 'France Occitanie', 1)
#----------------------------------------------------------------------
b64_FR_PAC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjcwNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1Byb3ZlbmNlLUFscGVzLUPDtHRlX2QnQXp1ci5zdmcu'
    b'cG5nIgogICB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNw'
    b'YWNlcy9pbmtzY2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3Vy'
    b'Y2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDov'
    b'L3d3dy53My5vcmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIw'
    b'MDAvc3ZnIgogICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8'
    b'ZGVmcwogICAgIGlkPSJkZWZzMTI3MTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAg'
    b'IGlkPSJuYW1lZHZpZXcxMjcwOSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9y'
    b'ZGVyY29sb3I9IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3Nj'
    b'YXBlOnBhZ2VzaGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6'
    b'Z3JvdXBtb2RlPSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9'
    b'ImcxMjcxMyI+CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9'
    b'IjEwMCIKICAgICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0i'
    b'aW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRh'
    b'dGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NB'
    b'WUFBQUJrVzhud0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lR'
    b'QUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9B'
    b'UCtndmFlVEFBQVUKcmtsRVFWUjQydTJkZDNSVlZiN0hQK2ZjbnR4VTBnTWhrQUtoU0JHVURv'
    b'SVZVVlJrN0FVY0hSakhKelljRytxb2crUEMwV2ViVVoragpBZ3FpZ3FKWVVVQnBJdURRa3BB'
    b'SzZmMlczSnZiejNsLzNKaENvaWp3ZkpQYy9Wa3JpN1hQMmVlZXZkamY5ZDIvWGM3ZWtycGZv'
    b'L0lMCnNOMDFuRUNGNmJqNXpIY1VvUi9YZE54OHJ2ZFNjYjJiZXR4OCtqT2JNTjlaOUV1S2lH'
    b'WCthRlNuOXJqNUl2K1NpM2FRNDdqNW5LK20KNDltWWNOeDh4dk5yQ1p0MzlMajVHdXBWbjE0'
    b'bjZTS2o2ZlhJQ0FSQ1dBSWhMSUVRbHFEM1VsWnJaUDIybExhMDJ5TUpZUWxPanJWYgorM1Bl'
    b'STdmUTdEYXljVThpVnp3NW0rdWV2cWhMUHE4SGlnL29UK203dGVLL3YyZFQzYWhuMVpZaDVG'
    b'VWtVMUlUUjFsakxGNmZoQkx3CkVwQmlrQ1NKdTkrY2c4V2RoTWVuNDhLUjI0TzljaGZVbCty'
    b'eDU1dXg3SXFrL3kxVm5ZUlcvVU1ZN2tNUmVHTGNETC9VaGlRSllZVUUKTnFlV3gxWk40SldO'
    b'WjlQc2lmNWx6WlBrcDdyQnhNc1BaREQ1U0JoSmZoUE5aamNwdHhjUU45QkxYYm1XNWkyeEJM'
    b'YkdZZkJxMFZ4KwpsSUdUN2I5YVZFSllQUlI3aTVZTEhyNmVIY1VqZjlWemlxcGxiOFVvRmpD'
    b'SzJRbGIrS3RTZ0U0Ym9HVjlJcmFWZXFMS0lvbFJOUUJZCkZ4MGtjM3lMaUxGQ2lkZS9HUHFy'
    b'UlFXQXFvRHFBK0REdXFsTWE3cVk3NzBLcnIxUkZPVnAwTFdLeXErcWhQVnppK0E5MUhCNURS'
    b'MXMKeUFYK1J2QmJRZlgvL0lPU0RBRUhLQzBRc0ZIdk5US3Y1bUsraS9BdzJtUkdCaHF5RzdG'
    b'ZFV3aCtXUWdyOUFKMlk2c0RlY2xJQzJmUgp6ZE5CR3czU0w0aHNWRy93WDAwVVNCcTgrcjdj'
    b'YnIrSkEwbHVHdE90cEQ5WVF0WnNLMG5wZmlHc1VHSi9TVFNyZDB3TU9wVGlSZFpHCm9KRito'
    b'UWgwaVNDSHRZckxESUFQSTlmV1hreCtsZzI5UVQwbDVSVEJldy9oK1ErSDhmWTNaN0MvUElN'
    b'V1gwUmJ6UlVlc2ZIMHY2emcKYXdCZEhQQVRYVGhmSS9ocXdKUU5rcTdMN1FadkVrOFZuc2Nz'
    b'ZGZrSjlRS0ZZL1ZRMHVMdGZGODZsQlpmQkxMa1owUy9RMHpJMkFHSwpFNURRYXFPNTJMZVRO'
    b'RTgra3E4Ui9MWmdQQld3UWNBT3VqNWd6SUNXWEhEKzBHMDh0clhnZEZadEdpZ2NLNVNZUGFH'
    b'TUR4WS93NnRmCmpHTHUrTjJFbTNTODljM3B3U3IwTitHWHplUnJNL2xNOXlXZWdCK2JDZ0ZW'
    b'WlhIZ2RQWm9oN1hhaUJIQ1J3UjdobzdkWUJvY2pNM2EKbzN0ZS9IUXlWMDh2RWNJS0pSS2kz'
    b'ZXdxSHNMNkg4N0JiTEJ5NmRoZHZIanpjbExqbXJGYjNGajNtL215ek15c0JpMXB5SHp2MTdJ'
    b'bgowRGZvWHRxb0R2clJRY1E0Y093RlUwWXdrRzlsUjlFSWR1YkdNbTVJa3hCV3FORHMxbkhy'
    b'K2QrUUVtdGg1dGdTa21LOW5UdDg1MFBlCnlqaGNIL1FGZzhSZzJjL1phUWZZZUdRaStKdEFO'
    b'Z1gvZnNROEd1emJJWEo4VzJ5bW91WGRqekpPV2xnaXh1cEJ6QmhaellOWDdXRCsKZWZsZFJB'
    b'VWdTVERrdWdZMHlXN3FSdFJnVkRXOFBQVXJucmhpT1RwOU9LQzB4bVFkTUk4QzU4SE9jWDVC'
    b'SDBvL2l4YkNFclJUWDZYQgpOOGpLOElXMVdJYzBRSXVHKzYvY3l6OXVlUldOUnQ4Nit0NUJs'
    b'TEtwTmQwK3pMQ2xLUVBkeWdIVTVocUZzQVJCNGxNQ0RMK3RodkJJCkJXZW1sZWhwRmdCdU9x'
    b'K0F1eTVjQjVxSXJ0V3VUd1Z2VFZzeVgrbEx3Q2ZoZkdFZ2pXVTZJU3hCWjBaZWFTRTJwWDFZ'
    b'NGRIcnRqTW8Kc2JqckNMMCtFWHkxYlVtdkhFNmRNVUIwb3huYmsxa1U3TlVMWVFrNlZPNHh0'
    b'V3ZVSzl3KzY2dHVjbllkRWJVWkpWeGFQOHFjY3RLSAplWVd3QkQvUG5Ja0ZoT25zeCsrQm1p'
    b'UWNHVll5WnpTalA0SEZwVUpZSVVaQ2pKY3hBd3VQbTArajkwT1RIdlVFcHc2RnNFS1F0RGhM'
    b'Ck4xYzdLOGcyMG81MFRnMTV1d3duOUE0eFFCcUNoQm1PaVpuOHRrNmo3N0xrWmRLMEdnYWtl'
    b'RkFVNFZpQ1g0aXQ1cGdKYU04Uk1LUzMKSmNlazV6TWd4ZE50QjBBSVM5QXRsbW90YXNVeEE1'
    b'K3FQN2k2dEpXNUUvYWM5SHRFVTlnRDhQdWhZcHNaWkVnNXczbFNpL0gyL3l1Sgp6YmJUMmtj'
    b'WXZKV2dUMjY3UHlEdUNBdG43VHY1b1E1UmJmLzVGSHhuUkdyUm9xN3B4NUg3c3JIVi9uby9j'
    b'RGtsY2w5T3BLNHluam9wCnFUMWc5NVNEUHFVdGZjL3N6d2szS2lkZFp1RllQWUFoRTkyQW0x'
    b'S3RTdHovREtMeWxWUWlIeno2aTFaNjd0dGtRck1wQ1ZOWkJPYUEKaHNjQzQ5cHZPdmREMlBD'
    b'MjVEV0QzbVBockVPbnBNekNzWG9RdWt3SExZcEM0c0ZFaWo2TitrWFBqRGpMaFhGNkhWRXVJ'
    b'LytNaU9TQQpLeWQ0dzEwQzJoalFoQU93SVBaVDdqbHIzeWtycTNDc0hrRHhwMUg0dm8zRFhx'
    b'WEQ2WFV4d2hpTy9yMysxR1VlSmlIYmM5em56WU5jCnJFN3dzclRpMnRaMnNSQWtEUmpTQUZq'
    b'Y1p4M1hVa3ZPRFBzcEs3TndyUDl3RG54cndGc1NocWJKUUtZcmtoSEdvTU5FT0kwMFA1TkIK'
    b'dzlHZlgzM2c4c2pjdStJc2JxdVkxOEg2K29CeElFYlZ3VC9pWCtlZVppZUdJWGEwcDlCbWhH'
    b'UDloek44c2djbVYrTnVxYUgwcWY0awo1clZ2WFJuVFpNYisyR0NjODByb1A5SFo1ZGt2OXla'
    b'enp4dVhzSzg4NTVoYWoyV1lPWjgzREZzWllBc09QZWl6bmFlMDNFSllQUVJqCm1NcUF4VWM1'
    b'OHFSRXd1SDR0dXVSelNaOHp3OGgvK3Q2VE5QcmlSdlJ3cVlEeWJ5K2FSenJkMC9Bcitvdyt4'
    b'dHdhT1BhZW42L08zTWoKajh6ZWlQbUp3ZTFOVngrdkVGWW9pNnYvNHFNY2ZjMUwxSTRrREsx'
    b'N0xlaFVpWVNEQ1hBd2dRckpoODhieVlXcWc2dWtEYVJJTGw2UgpCL0ltY2NTRjE3UDBtalg4'
    b'L29MREFCVE9MY1gwZGpZeW9OaDFRbGloak1tc01QajJTbXJPYjhEeVRTemU0bkJrbXc2MVdZ'
    b'dHFVTUFuCk0xVjFBUzRBOGdJNjNnbU1ZSFQvZzd5NTZCMkdwZHZhZml0cnRwVkNDdEN1UzhQ'
    b'OVhUVHF1ZFpUOHJHcUVGWVBKbW1RaDczZitvZ2EKWThGdjhLTno2ZkFkakNDdVF6TUo4TFkv'
    b'amJFNXVheC84QzJpelYwL1VzMmFiYVY1cWgzTGdUQXNqVEt4Y1lvUVZxaVROcTJacHJXSgpo'
    b'TzJQSmR6WC9XcThnaGhZczNoMXQ2TDZrWWhvaFlqSmpsTmFOaUdzSGt4Y3BvZTR4V1ZZYWl0'
    b'cCtESVd3eGVwbUQxNlZJSlRnVjVWClpmNlZXMGlLOWZ6bVpSUGpXTDJBbU1RQVdkZldZM280'
    b'bDIyUmRTaXRpL1prQ2M3S3F2OS9LWk1RVmk4aVBzUExsTCtWMFpCVDM5b2MKU1ZqZlQ4TDcy'
    b'eHVXYUFwN0cxR3hDbUgzSDZINHJSWWlOdllsWVhjeVIvOFVoWlRaakZQMkV4amR5T2daYmlF'
    b'c3dhOUhwNGZCOCtwbwpPTXVDYldjMG5nbzlodWdBQ1JNdEpPZjhOdllsaE5XYmcvdDBIM0hw'
    b'SXNZUzlDS0VzQVNpS2V6eHFHQ3pxZ1FVSVN6QnFXYkF4eENiCkpvUWxPSVZJRUpXUVJXUkNw'
    b'b2l4QkFJaExJRm9DZ1gvOTdUWWJGUVhsK0t3V2JGVzE5Qi85Q2pTc3JPUVpWa0lTM0RpSFA1'
    b'OEkwMTUKaDJrdU9ZTEc3NmVndUpUNlVTTVlPMnVtRUpiZ3hERUM5WjkvUlhLTEY3UGZUL09S'
    b'Q2hMUFBWczBoWUtUdzVsZnhLZ0dPMlpaZzAzeApZemZvaU0wYytKdThXd1R2UFJoclZUVmx1'
    b'M1pUK3ZWbW5CWnJwM3NIYnIyYmZxcyt3SStLUnBKSTB1b1pVV09oWnQ1dEZHM2IwU212CnBh'
    b'aUVvanZ2cCtUVk43RFgxUW5IQ2xVVVJTSDMzaVhFZnJJSmMrdGVqaFhuVEdIUWZ6OEpnS3Fx'
    b'Mkd2ck1GNTFDWnFOMzZCcmFOL0IKcjhYblpjaVpZenY5bm4zbjk4Uit0aGsrMjB6am0rL2dl'
    b'V2taOGFjTkZZNFZhaFE4OTA5U05ueU5zY01Hb1hKaThDTUtyOGRENmI3OQpwTjUzQjdxTWRP'
    b'd1R4NUNYMGJjdFg5K2pWZXhjOGdScWgyZE5vMDdEb3cxK1NoYlZaTVB5NEdPNEhRNGhyRkRD'
    b'Vmx1TGFlVjduYTQxCmpqK2Q5RHYvQklEZVlFRFp2WStXdDk5REJmcmVlQTJKaHZiemN4ckRq'
    b'SXk4OXc2a0R0OTVKUXpOb2VMMDlsMW40b3JLS0gvbERTR3MKa0lxcnZ0MUJSRXZuRmFENkdW'
    b'UFFHZHMzb2MzOC9mVU1lZm9Kb21kTW8vUytSd2xVdFo4NjBhZkZUY0ZUejNaeUxJQ29NRk9u'
    b'dEdIVgpPcXpsRlVKWW9ZSjN4KzZ1TVZkbGRiZDVZNUlTR2Z2V2Eramk0OXF1SGIzMUJ2cmZk'
    b'RjBueHdLUW8yTTZwYzFPRjVZTm40dmdQUlJvCnNkclE3UGdlZ0JLdHpFQi9jUDJOWnUwR1Ns'
    b'S1M2SHZaUmVoTkp0eE9KOVo5QjdIWnJQamYrNGprd3RKZzcwL3hZMHhKd1ZGUmhUa3AKQ1VP'
    b'WWliSXZ2c2E3ZHg5aEc3NElOcFdLSDZmZlQ1cmVpSGZuSGxod2t4QldieWZ2cjh2b2IyME9O'
    b'bjh1RjdXU1JLSldqOW5XREU4OApTK202ajZGZkt2b2RlNGl5TzZqcmw4alE4dUFaT1NvZ3E1'
    b'RDR3RklBeWhMNzRCdVFSdHpPSHpCM2pPSDhmc0phcDN5azJqcU83UHllCjlIRmpoYkI2TSts'
    b'My94ZjFIMzlKQWpKK1ZMeEs1emdwUHJjSWNvc0FxSWt5azExV3c0K2JNVWhBbEthOXV2dlVO'
    b'a0p0WStlT1FjQ1AKUjFIYWhCVTFhUUtKSnlBcUVXUDFNSHh1RjlGcVVDak5nUURKV2ozRlhq'
    b'ZjFmbCtYdko0b003cGZzY05IbGM5THVjOURUSWZkMTVTVwpGaEZqaFFKK1d6TmhIY1Jpa21Y'
    b'Q1pSbEx3RStsejR0SkkyRkVwc1dneCtmcGZyOHJpMGFpV2ljajJ4MW9WTkJLRWw1VlJTOUp4'
    b'R2s3CmIyV2tub1N3aEdQMXFDNWhVQ3crVlVVcnR3c3NVcU5CSTBHVXJNVWd5L2hkTHFKMTNl'
    b'OTM1WW52Zzg3UlFvUXM0ME1sWE5ZUXBkRXcKUU4vMU5GV2x4U1dFRlFxb3Z1Q09NVFkxZ0Zu'
    b'U0JBTnlKRkNEN2dVUXJkRVNyOVVoUlpycDdwZ0J6YUJNWWlJaTBDQmhrbVFTdEQrOQo0WnJp'
    b'Rkk0VkltMWhVRmcralJhZEpCRlFWU1JBbGlUTWNuQkt4dGg2ZEVuNDVBazBKTWQzK1FsOXhn'
    b'RFVrY1BibXRLZlF6aFd5RGhXCk1FaFhXbXROYVJWVmZBZlhVUURubkpuMG5YOHRjbFkzUzJS'
    b'TVJoTHV2UjMzbWFOLzhqMEdTY2FqS2ljVnZBdGg5VURIVW1TSk1GbEQKUUZYUjB1RlluREFU'
    b'bG9VM01IYnBYOUFhalNqbGxWMWpyRDM3aU1uT0pHdlo0OWlHNWVBNXBzSFVJaEVteXpna1NU'
    b'aFd5TkE2UjZnQwprYktHRmxYQkpHdUN6b1ZFK01VWGtIWGJINmpmZjRpaStiY1NYOXAxcmk5'
    b'dTUxNXk3M3dBV2FkbC9Ob1ZOTVhIZHI2djFXR1FaTHl5CkVGYm9OSVd0VFpQU09vSHNVeFgw'
    b'a29SUFZmQ1pUVVJmZFJuV3NuSmFGdDVGd3A2RFAxbmhTWjl0b216aFhRVDhmb3czWE5sdGtJ'
    b'OU8KaThidHdlLzNDMkgxZW1HMTl0S1VZNzdSdHlZbmt2TCtjdUp6QnRPNFpoMFJsdU1mWFpK'
    b'NDREQVZHemVUTWY4NnZBL2ZqVmVTa0pIYQpSS1pxdElRSEZKcWJtb1N3UXNXeFVBS2Q0Nkxm'
    b'WFV5ZkFlazRHaHVSUC9pMDdYcHpWQVQxV1FQYTBpWGpSK0Z0N1FrcWdQdmo0T3FGClVkZGNp'
    b'V1g4NmNSb3REUUdXa2Z4OVZyMGtvVDdtQ1hQUWxpOVVsaXRNVThnNkN0Tnd3ZlRjTVB2R0hE'
    b'VDlhaXFTdGxmLzQ2bTBjSVAKc1JGNGRCcTBUeitLTmllclBYNDZaenEycXk3QnBnVDROamFj'
    b'aU0zYnFkb1ZQRTAxZGNsaW11Yk14SnNTUEJSVE1SbGFoeHhhaExCNgp2YkJhM1VPUndDdEw5'
    b'UC9qNzhtK2R4SFdpa3J5NzNtUWxtM2Y0WXFPcEovRFJXVmFDcWtUeHVFL2RManRlZS9PM1pn'
    b'bW5rbTEyY1RVCkppY055WW00N255QVF5KzlTbmhxTWptUFA0VGgvT25CZDRRSDF6d29EaUdz'
    b'WGsrZ3FnWVZhQjZTamZQT0JmU2JNUTJBNk5RVUlxK2EKaXpseklQRTJCOTdMTDBJOVp5clZo'
    b'L0tJTEQzYUhvOXYyNFcxdHBiNDJ4ZFFNMm9vZlN0cmFMN29mT0xQbm9aR0V4eGdUWnAzRGRX'
    b'RApCcUprOUErS3VmYkV2dG9SazlBOUJKL1hpMVJjU21PWWtTbHIza1RYWVM1UXE5Y1RzTm5v'
    b'cy9jQVZlZE9ZOGo5ZHlITE12bTMvNW1FCkRuRitsTk9GdDZDRXJJY1dZenRyTW8zWC81R0l6'
    b'NzhpWXNIOHRqd1JDZkVNWGJjU1cxVTFsbTI3Q1JTVkNzZnF6ZFRsNWhFSUQ4ZDQKMzZKT292'
    b'b1I1NXVyYWN6SkludnB3OGl5VFBHYXRVUnUvQVpQaHhwV0FQUDdHNmpjdG9Pb3ZxbUVMMzBJ'
    b'VTVPZHFqWHJ1dnhlVkVveQo4djJMcURsdzZJU0dISVJqOVJCU1I0NkFMOWQxZTY5OHkxYkM5'
    b'dWRpZXVORjlDWWpUVFcxdUp1Yk9USm1HSWJTTW9ZMDJQRklVQlVSCmhtWG9JUHJVMXBJVUNK'
    b'QjQ1aGdLYnAySHNtNERnWG5Yb0RubUpNeTBTMmFSZHNrczRWaWhSb3ZOUnVtR3ovRDg3VGxj'
    b'L1ZOSkdERU0KZ01OclA4VDZ5WmVFcDZZU3JzcThacWxobGFVV1IwNFdmV1V0OXRWcktkNjZI'
    b'WUMrY3k5Rlc5ZkE0YnNlb1A1d3dTa3JtM0NzSGtwegpReU5ITHJ1T1lyK0hTa2xscU1hQStz'
    b'd0w1Tnp4SjhiLzhSYktoZzNsM1lYL3hUT0ZoNmowQmZkMlAvLzlOVHg5NzUrWmNQZFQ2QXdH'
    b'CjdKVlZyTDN4RCt4VUhJVHQyTXIwbmJ2SXZ1SnlzdSs4VlFnclZGbStjZ1VyQy9lenN5WTQw'
    b'U3pMTW8vMVN5QUhzTlhWMC9UM2wxaC8KdExoTlZBQmJuVFpxWGx1Sko2QXdhc205MkdwcVdG'
    b'Wlp6S0c4UEFEZWlvOW5tZXRjc2s5QitVUlQyQU41L1BISCtmTkREN1dKQ3NDbwpLR3hwQ0g2'
    b'WUdwVVF6OXZacVd4M2QvNU0zcUVFV0NBNUtCOFpQQ1A2dWRXcnlNM1BiKzhnMU5mejhxY2Jh'
    b'RHJCYVJ6aFdEMll2THc4Cm5uLytlUnpIN0szZ0FuWnUzODZ5WmNzd21VeTg4TUlMK0FPQkxz'
    b'OFhscFJ3MzMzM01YandZRmFzV05IbGkraHQyN1p4eGhsbnNHTEYKQ3NhUEh5OGNLMVJZc21R'
    b'SmRkMXNOYVFDZG9lRFJ4NTVoT1hMbCtOeS9mU1NsOXpjWEs2KyttcHFhMnU3dlY5Y1hNelNw'
    b'VXRGVXhncQpQUGVQZC9qdzJ3QkVUUVU1clAyR3BJV29LUkIzT1U2MVB6VTE3WHMxWUVpRHVM'
    b'a1FNeE0wVVFEbzlYcktLMnNoZWdZa1hBdm0wMmxmCkxnaVlNdm42UURLclB5NFVUV0Z2NTdO'
    b'dnlyamptVWFNc1ZOUWZCS0JQbk9RR3BhanVvNGc5YnNmU2RaaU5ucXh1ODZpM0Y4RG1tZVIK'
    b'K3N4Q2paaUUyZURHRzlEZ2paMkoxUFEra2xKSlhkZ0NwSEFONFRvcmpvaHh5SEZ6VUNxZkRZ'
    b'b3RjaEs2OEFCNVJSWWhyTjZPeWFqbApxb3V5TVlmcFdQOVZLZFYxTGFqeDh3QklpamN4ZDJZ'
    b'V1hsK0FkejhwcHRFU0QrbFBvcW9xT1JreFhIcnVRT3FiWEt6NnFCQUhjL0FnCmdhb3lhV3dL'
    b'RjB5ZFJFR3BsYmZYNStOTmV4aFVGVmxXT0h0eU5uTm5aZ3BoOVhiR0RFOWcxSkE0M0o0QXp5'
    b'K1p6TC9leTJQaGtpMHMKdW5FRVMrOFpSMTJqQzUxVzV0a0hKL0g0aTN0NDRxWGR2THAwT2pk'
    b'ZU5waThZZ3NwQ2VFOHQyUXlDNWRzWWRWSGhXeDZhemJqUmlheAo4OTgxM0hiZGNGNThaQXFY'
    b'L3ZGVDloNnM1OThmWFVGQ25JbXFXcWVJc1hvN2hhVlcrazlaUWNxRU45aXlxNHFiNXVaZzMz'
    b'Y3pmMzlnCkl2bkZGZ2FkOHhiWlo3L05nY05OUExwb0xLNURmK0Q2U3dmeHllYWpuSGJoYW9i'
    b'TlhFMXB1WjNYL3pZZHg0R2JHWjdkaDZkZStZRUoKYzljeWJ1NzdWTmM1K2Z6MWk2ai9majU2'
    b'dmN5OHhWL3p5ZWFqd3JGNk85Wm1EeTYzSDYxR1p0Yk5HK2lYYkdiY3lFVHlpaTBjTEFpTwpP'
    b'M21WQUpPdVdNdkFmcEVNeTQ1bDc2RUdLbW9jNkhVYW1xeHVSbDI4aGtFRG8wbFBqZUM3Zjlk'
    b'aWJmWmkwR3NvT21KajZBV3JHWm9WClMweVVnZDBINm5CN0Frd2FreVNFMWR1WmVrWXE5bjAz'
    b'LzZidjFHb2tJYXplamlTQlh0ZHpJaGNSWXdtRXNBUTloLzhGZHREbk1RQVEKV3JZQUFBQWxk'
    b'RVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURJdE1qWlVNVEU2TXpVNk5UZ3JNREE2TURD'
    b'Q29PSFZBQUFBSlhSRgpXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEF5TFRJMlZERXhPak0x'
    b'T2pVNEt6QXdPakF3OC8xWmFRQUFBQUJKUlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJpbWFn'
    b'ZTEyNzE1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'FR_PAC')

FR_PAC = b64_FR_PAC
index.append("FR_PAC")
index.append("France Provence-Alpes-Côte-d’Azur")
catalog["FR_PAC"] = FR_PAC
catalog["France Provence-Alpes-Côte-d’Azur"] = FR_PAC
country["France Provence-Alpes-Côte-d’Azur"] = ('FR_PAC', '', 1)
lookup["FR_PAC"] = ('FR_PAC', '', 'France Provence-Alpes-Côte-d’Azur', 1)
lookup["France Provence-Alpes-Côte-d’Azur"] = ('FR_PAC', '', 'France Provence-Alpes-Côte-d’Azur', 1)
details["FR_PAC"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_PAC"] = ('FR_PAC', 'France Provence-Alpes-Côte-d’Azur', 1)
regional["France Provence-Alpes-Côte-d’Azur"] = ('FR_PAC', 'France Provence-Alpes-Côte-d’Azur', 1)
#----------------------------------------------------------------------
b64_FR_PDL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcyIgogICB3aWR0aD0iMTcy'
    b'IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE3MiAxMDAiCiAgIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3'
    b'dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAw'
    b'MC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnM2IiAvPgogIDxnCiAgICAgaWQ9Imc4Ij4K'
    b'ICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE3MiIKICAgICAgIGhlaWdodD0iMTAwIgogICAg'
    b'ICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5k'
    b'ZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9w'
    b'bmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFLd0FBQUJrQ0FJQUFBQ1U2RXhX'
    b'QUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2'
    b'QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFB'
    b'KwpLVWxFUVZSNDJ1MTlkMWdVVjl2M1BiTzkwWGJwdlhjVVFVQlJzUnV4UjZJUlcyeFJvOG1q'
    b'c1d1aXNjVWFvMFlsOWhqUkVMdWdZc2VLCmhhSklMNkwwdGl4bEM5dG01dnRqY0ZtUXR1RDd2'
    b'TmYzSnZmbEh5c3p2ek5uenJubm5Mc2ZwTnE5RC95enljcHdib05DL2IvZURSUkYKOUxuMC81'
    b'VkhVd0ZBUWtVVkRBWmYyZ0FBWlFZOHBaZXIrbDJoUTBtbGlFYmxxOVR3TC8xWENNZUptbnJG'
    b'Zi8rNUNBSlVBQ2kwTU0ydwo1UHRtdlplYW13bURldldmUHVYR3ZnUFVDVFpsZVhsRWZMS2dY'
    b'dnJ2RFAzZkpoUUEzakVwWVZzMzY4bFZabEtaOEcxZWZuNitTWU5TCmFzS1gxb3R4Q3ZYZk1m'
    b'cEhNTUhBdkpMWDV5L2hxNzdOc2JIb0h4cktack5yMk16NnE3R0NXckZKVGQyL1kvU1BZQUlP'
    b'VG1BWG9tc04KZWVJQmdTVU1hazVPVGsxcFdhMlRYVU5CMGI4RDlFOWhnbHc5anNxWWo4VTlO'
    b'ak16eTh2TEs4OS9KNWRJckh2MUVKb0ovaDJnZndvVAp2TGN5OGRtNkh2ZnRvVXJQbkRkdlh1'
    b'L2UvcUhaaGJLOGZFODlnMy9VV0REcEZFc0JqVXVUSVVqck4xQlE1TC9jcGYvT0U2a0FJR2hR'
    b'CnZ2aHhTOSswM0JRdjV6c0crb0dqUW91K0hHOGJGVjNwNi9rUG1YNHpQbnZSZUxPRTI0ZlQz'
    b'aVJMOHZPQnd1dy9ZZDJyY2d0Smd4b0EKUUNtQzhsczk3U0RBMTNYdCtpMlpCUTBSRnpLaUh4'
    b'Vm80SzYyQm10bTlRenBaYzVoMGQ3a1Z1ODZuWExyV1hHakF0WlFUSlRmQmxsQgpZc0tMN0VM'
    b'eDN0TUpDYmtLZ01hcGRiT2k3ZmgrY0M4M2dVS0pQWGxkdnVQVTY4eDN0ZVNsTVFOc1YzL1Zz'
    b'NWViQUFGSXpSTnRQdnc0CittbFZJeEJYOWJTcTM3bG1pcFVwYit6RXFYa1ZOREFaQkZRdUNU'
    b'UXhZcm5aR2RSTGxHbHZhOVFZM2lrdGtUUVd5UkdraWtYSEZuNVYKWjJ0SktGWFc5blpsNXk1'
    b'akNtV1BLN2YvejNQQXNKN2ZYOXNmYWk1Z0E0QlFLSnc4ZVhKbFplWGZmLzhkRTVmeDA1bGFh'
    b'd0VLZVFkRwpEdXUvZCs5ZVJHdUorUHYyMjdsYkhrbGtxcy82V3AvZlBwVExwbWt1RVFSOC8r'
    b'dXp2V2RUdzRZNERIVXMrSG5ycHNtVEorL2N1WFBWCnFsWHIxNjhmT25GcGd0QWJBOGJVa1U2'
    b'bk5nN1MvdFpsY3ZXVXRmZWlIeFVzRGZmZTgzMUxJOTZaMkx3WkcrSm9JTE5XWEwxeTlyZjgK'
    b'L0h3REF3T2hVTGgyN2RvK0EwWStGd1dWVnNrT3JlNDNlYmdqMldaMW5YelQwZVQ5VVdrZDJn'
    b'a2FtZUNObTMyOXQ1dUxnME14RlRXNQovMVFXL3JuQnFzMXNBcmdLZVEyRHp1ZEpxaVVjSTQ2'
    b'c1NzeVZLZWlXUnJWVUNsWlpwOWVncEgyMG9xcE05ZW94SEMwV0diTG9LaE85CmVwR1V5K2VT'
    b'Y0dsbHZWNkRrbVpwVkV0Rk1mSjNDemdKd1hCS3NjamdBNXpENTBxckpWd2pqb1NFV0JuVlVs'
    b'Q3NvbDVQM2lwY3YxNk4KVVVwRUJteUcwcGduYm9TTHVVYmNEM0IrRFFYQnRlRkkxS2tlM3VZ'
    b'Zmo4NkNCUXR5Sks3SGQ4NjF0K0MxT256WEhoY3UydkVrN2R3WApQSGJMbm1BNE1YVGg5ZWhm'
    b'UjJndWxaZVhPemc0VkZkWHMxaXN4Ni9LcC8xNFArdmlKQmFqcFFZdWthbEdMYmw1OTlBb0do'
    b'WDkrSW5MCjl6NGYwY2RxV0tBVkFIenp6VGVtcHFZYk5td2dMejE3VTFGZHB4amQzNllGNU1l'
    b'SXhDM0hrenZIQkhibXFza1RoRmxaaGpudlRGUzQKYk94d0UzZFg1SnZWZWl6bDNwRVcyeVpm'
    b'WG50dS9IaS8xNEViMWlBSWNYUGwvaTFYUWg5bk83ZmFhQi9uL0kwVG8wTjNmcWZHMFVjLwo3'
    b'cjd4Mm91RWovRjkwM2ZqS2hRbFlsZnMzM1I1OU5NY3gxYmh3UzV2TjN3ZU0zTG5keGlPUHQy'
    b'dzg5b3I3NThuWFZsN2JueG9qN1QrCm0xZFFVRHgyNWY2ZkxvNkp6MjBkM3M4MTc4ZngxMGZ1'
    b'K2c3SGtlY2J0MTlONmtIQ1IvaGtETnl5aklyaU4xYnVYMzloN1BNOGg2WVAKTi9IclZwdXlz'
    b'N096ZDNDTXUzK3ZuUkdzRURXWUdyRmF2ZFNnVUd2UDhjbVRKMmZQbm4zLy92MUJnd1lCUUdt'
    b'VnpNS1kzU3BRcnNTWQpkRXBiVmtYMHc4cmg2T2hvWldYMThPSEQ5ajkwcFFwM25oQlZXQzdw'
    b'd0dJSUFIeXB2UHI4MWNDaU1nTVZubStvVjVxZFkrYlhxNEZHCjRXQ29rMWtsQURpWlZ1VlhH'
    b'U01JUVJESWlCMy9hZWVwejNJZGhtOWZBZ0FJUXVSWENwcmdsY1lJUXVCNEIvQ25PWTRhK050'
    b'S1l5ZlQKcWc5UEZ5QUlnZUVvZWJVdGVwTHRSTGFQSU1UYkNpMTRoUUJCQ0hWSGNBMDlldlNv'
    b'b0tDZ3BLU2twS1RFMHRLeXJkdmE0Z0FBYVBHVgpSMFpHQXNDNWMrZElKbWlMQTBqNXRFMHgv'
    b'Z01IUEhueUpEOC92NkNnb0tDZ3dOYld0cDBYb2RQUWNTRjJ2LzJkMW9GMkFBQ1dWVFUrCitT'
    b'VUdLaHdBT0FSQWd6eDE0elpMbVlKS3dTY0hKZ0xBbDMwU2JQblZwbnJpenUrMWhteVpzMW5s'
    b'bDBHTmNBZVRLbU05U2VmaGZLN1UKeWFUeXl6NEpBREE1S05IWnRKTFAxY0dBYmF3bnNUY1dh'
    b'dUN1RmhXR2JGbm40Yi85OWhzQXFOWHFvMGVQZGwvc3lNaklpSXVMSTFtaApydTRUMk4vSTdt'
    b'RVlkdno0OFE1dkpzV2RqcG1nR1hmWDF2dkVKd2ZsRmdKQXJZeEZwZUFBUUtlcTU1K1lWbDZu'
    b'MS9tT2lxU2NPVWRuClVGRU1BR2dVYk42eDZaVjF2TTdEaFdMdTNHTXpxQ2hPd3VjY215RVVj'
    b'enNQcjZ6anpUOHhqVWJCQUlDS1lyT1B6QlJKT1ozRUZoY1gKWDdseWhmeDk5T2hSbFVyVi9U'
    b'a2pDQUlBSkJMSjZkT251OWxhU1VuSjVjdVhOZDFUS3BYdDMvKzJ1RjVuSmdBQUU3bUtRUUFB'
    b'R0hHbApid290QWVEMWUrdXIzeC95ZHlqb2ZGOTcyQlpmVzNiZ1RaRVZBS1FVV0VVdk85akxy'
    b'ckR6Y0YvYm9waGxCMUlLclFEZ1RhRmx6UGNICmU5cm9ZTUgwc3krNHN2UlFTb0VWQUtRV1dW'
    b'NWJmc0RIcHJpVDJJMGJONnJWamU3VDB0TFN3NGNQZDJmTzh2UHovL2pqRDgxL2QrelkKSVpG'
    b'SXV0UGdwazJiTkh4WlhsNGVFUkhSM3JkVUt6OTM1MjJuVk1TMnFCeGhUM2J1bDdwOVk5Q0cx'
    b'Uy9lMm5laHh6MXNpMTl2M2R4NwovZHJFZk5zdXdQM3NDeEkzLzl4cjNRK3ZDcXk3QUE5d2ZQ'
    b'OWk0N1llYTM5OFUyalYxajB0Qk1Pa3BLU0FnQUFjYjlLd0RRME5zN096CmpZMk51elpuWThl'
    b'T2pZbUowZjdMMnJWcnQyN2QyclhXa3BPVEF3SUNNQXpUL0VWUFR5OHJLOHZjdkJVRlI5cWdI'
    b'clAwWmx4aWFmdmEKQWRyaFU4dnI5SEFjS2F2VjcxcW55MnIxdXdrbkNFU25iVWliU212MGNS'
    b'd3ByK3ZzMDFVcTFZSUZDN1E1QUFCcWFtcVdMMS9ldFE1Ywp1WEtsQlFjQXdDKy8vSktSa2RH'
    b'RjFsUXExY0tGQzdVNUFBRHE2K3RYcmx6NThjMzNYcFlFekx6Y1BnYzAyaVZYR2JmM2hVa1Ey'
    b'bTdjCk43WEk4c1ZiaDY2TmdsVEJTQzJ5Zk5tbFZRUUF4SExtbXlMTGhIeTdyc0hyRzFpcFJa'
    b'Wko3MXBaaEpnRVprWElEQWpsZDZHMlJMMFkKR0hTRVNsMjJiQm1Lb2x3dVY2VlN5V1F5Rm92'
    b'RjRYQ0dEUnNta1Vqa2NubXZYcjEwZXZxN2QrOW16Wm8xYytiTTU4K2ZHeHNieTJReQpNek16'
    b'aFVLeGV2WHFYMy85ZGZMa3lRd0dRNmNHVjZ4WVFSQ0VucDZlVXFtVXlXUk1KcFBINHcwZVBM'
    b'aWhvVUVxbGZyNStUV0pSS0tHCms5SFpqNUxMRkVxc3M4YWlkcllEVDlhay81T0d3aENzOUlU'
    b'eUFRYUl3SUFGR01iZHM3bk94YUdnb0lBZ2lFbVRKdDI2ZGN2ZDNkM1gKMTNmMzd0M2p4NDlQ'
    b'VDAvUHo4LzM4L05qc1ZpZGY4U1RKMDk2OXV3NWRlcFVQejgvdFZxOWVmUG15NWN2bnp4NTBz'
    b'YkdadE9tVFcvZgp2dlgzOTlkQlVoWUszNzkvajZMb3hJa1RiOSsrN2VIaDRlM3R2WC8vL2pG'
    b'anhxU21waFlVRlBqNityTFp6UlNCbk1LNjBPOWkyeGNNCk83VWRkRWhlVnFXK3RsMTNPdnZZ'
    b'RlBld0xlNHl2S2ROa2JkMVNkZXdIRkR6Q1FWUlV3c05EUUFnRUFqOC9QeU9IVHQyOSs1ZFoy'
    b'ZG4KQndjSER3K1BrSkNRcUtpb3c0Y1A5K3ZYcjFVT1VLbFViY25uL2ZyMXk4akk4UGIyWHI5'
    b'K3ZadWJHd0Q0K1BoRVJVVlZWMWZMNWZLMgpPS0F0c1ZFZ0VQajcreDg5ZXBUc25xT2pvNmVu'
    b'Wjc5Ky9jNmRPM2Y0OE9IZzRPQVdIQUFBTGpiNlI5ZjE2M0FjdXNzRUFwNGtldG5CCks5OGZN'
    b'dEVYZHdGdXJDZSt1dlRRMWFXSGpQVzZBamZSRjE5ZGR1anE5NGNFdk03SzI4WkVneDB1c2NN'
    b'bHBrUkRNMk5jVlRWZVZDck8KeXQyNFpLbURnd01BZUh0NysvajRBTUNJRVNPbVRadldZaWZX'
    b'RUkxRysvSEhIOXQ2bkpHUjBaWXRXOGpwNS9GNGRuWjJMQllyTWpKUwpMQmEzSTBhOGVmT21M'
    b'ZjdZc0dHRG82T2pkdmVHRFJzMlk4YU10cm8zcUxjVmw0RzF1eElnM1kwZTJ6UXgydDVZQ0FC'
    b'YnY3Z3k3OWgwClhlRmJ3cTdhR1ZjRHdPYXc2QVVucHVvSy8zblNaUnUrQ0FBMlRveFo5TWVV'
    b'emtDT0t4KzY0VFdOODBjUWpRcUNDcFB0L0kzOHpYYXkKaDFNSHljSHQyYk1uK1VkblorZTJH'
    b'bnp4NGdWcENHcVZuSnljeUIrZW5wNWhZV0VvaWdJQWlxSXVMaTZ0cXlvRWNmNzhlUjZQUjA1'
    b'dwpDK0p5dVZ4dW83RmsyTEJoWGw1ZUhYWXZJU0ZCcVdnQTRQNVByUVFNbW5wYXZ4Zms3L0Mr'
    b'TDlsMHBVNXdKazBWM3ZjbCtYdHEzeGRNCm1tNDJHUlpkTmFWUEF2bDdlci9uREZxbkFxTUpB'
    b'RDZoSVA4QkVFMkRYMVBiK08rRFYyL01tREVkU29MbDVlVVRKa3pJeU1oSVRFenMKU1A1QzFx'
    b'OWYzL0ZYc1dWTGRIVDBtVE5uT3J4ejlPalIycEpncTFSUlVSSDZ4V0lsY1A4SHR3Tm4wMG9l'
    b'VTk3NEFkR1ZydVlWT3NGZApMU3E0ek1ZZ2F5NVQ0YUlqM04yaVRNTjJQS2JjeWFUeTAwcU9s'
    b'cGFXZEhvSGlRQzNidDBxS3l1VFNxV2RtVFk3dTQ1MUhOS3NkT0hDCkJaRkkxUDZkRmhZV0hT'
    b'b1h4ODdlRXZMR2RmaFFhdmRXZ21iZkxwMnFXNUlDby9uOWRDcW02enJVQlhnbHdrNUdqUUdB'
    b'QXJnblh0MzQKL2loQ2RYY0ZDZ1VBVUFHL00rMklSS0tNakl3SkV5WThldlJJS3BVdVhicjAw'
    b'YU5INXVibTdhek03YTFQQlBINjlXc0RBNE5EaHc3dAoyYk5uM0xoeEdJYmR2WHMzT0RoWUoz'
    b'MUVRNWw1WlY5dmVmQWlTd2tNd2FkbkFqWmRPY3c3VTY2aTNrOTNLeER5Q1FKQmtNWkZ0YkRh'
    b'CmlJcmlnenl5T1F6RjNYUjNpYndWUHVVd0ZNTzhNbVZLZWx5RzYzdGhzK0V1ckRhaVViQkJI'
    b'dGxzdXZKT21ydFUwUXFjeTFRTTljeVUKS2VuMzA5M2VWL0cxQmhFcEVoblNLTmhnenl3bVRY'
    b'MG4xVjJtYlAwam5rY2ZvRkVSLzFiZUJRSUhBSVJDWVMxZFFPc2IwT0hycDZXbAp4Y1RFcEtX'
    b'bFhieDRVYUZRekpvMTY4U0pFd0J3K1BEaEJRc1dBRUQvL3YwSERod1lFQkF3ZXZUb3pzejkw'
    b'YU5IQ3dvS0xsKytuSm1aCnllRndYcng0Y2V2V0xibGM3dW5wbVorZmIyaG9HQllXNXVEZ01I'
    b'LytmRU5Ed3c0YlRFOVBqNDZPVGs5UHYzRGhnZ0pubWdUOVdLbm0KZldJbTRESVZ6emR1OTdR'
    b'c0JZRDBFb3RoMjVha2w1aDdXWlVDUUU2NUtVYWdTVnUya2liNjdETFR3QTFyNm1UTnVKakhs'
    b'RC9mdU4zRApzZ3dBMG9vdGhtMWJtbGxpN201WkJnQ1pKZVlvRU1sYnQ1Q3RaWmFZQi8yMHVy'
    b'NkJxUTNYWThsZmJOem1abEVPQUc4S3JZYnRXSkpUCmJ1cGlWZ0VBNlNYbU5BcjI2dWN0bXI0'
    b'RmJWZ3RrVE1RSU93SWNUQldFWXlYV3hCU0sxd1d3aHdqUVdqdFRZeXNvWDdDRE5UQ0ZEVXgK'
    b'cGdiMm92cjdVcXd0NFVOTUVTbUwyZHZiWDcxNlZhRlFsSmVYRXdUeDVNa1RqVzh3TkRSMHlK'
    b'QWhuVFFBSUFneWJkcTArUGo0M056Ywp6TXhNbVV3bUZvc2ZQWHJrNys5ZlgxOVBydmxoWVdH'
    b'OWV2WHFEQWVRNGlkQkVBNE9EbGV2WGxWSTZueFk5OThhVEh0WEt2NlVUUEM1Ci95dHlsQUhB'
    b'MDdMMHlKekkwNCtEZGt5NUJBQm5uZ1ljK3Vxc3hrbmphbDR4T1NqeHlQMysydkN3d0dTU0Ew'
    b'anJ3dSt6STA4L0RmeDUKMGhVQU9CTWY4UHZzU0pJREFNRGRzdXlMZ0tUakQ0TzE0Wk1DRTBr'
    b'T0lLMExFVitkT2Ywa2FIUFlWUUE0OHpUd3lKeklwcjZabDAzcwpuWHpxY1I5UG92WlN3eTAr'
    b'TkFvdURVRDFJVVR4aUdrNzc0aGxaR1BDYXF5b0JBQVVNYmNRUXdPOTQvc29iczRBQUJnT0ZO'
    b'VEx5OHZMCnk4dlQwL1B4NDhmaDRlRXBLU21Sa1pFUkVSRzJ0cllDZ1dESWtDRzZyYXhzOXRD'
    b'aFEwTkNRa0pEUTIxc2JJS0NnajcvL1BQOSsvYy8KZi83ODNyMTdZV0ZoUmtaR3VwbHRQblR2'
    b'MGFOSFU2Wk0yWHJzNVM5L2YxSW1VS2liM1QvYTk4MlJ1TVpwVHN5MzJ6RGhtdmJWajhPLwpG'
    b'S3BtOExHOTNoeC8yR2pLZUYxZ3ZUa3N1aGxjVFcwZlB0N3Y5Y2xIZmNuZnFVV1dQMCs2QWdT'
    b'b1VnemtNZVo0RlVQbFRBV0FiRVJmCmpORDRSQ01Uc0VBOUNDdU5SOXRqQWxYOFMyaVFOMzJz'
    b'SERiRnlSNEFBTVBxeGs1RHJjd1oweWZSZ3dPOXZiMjl2YjBCSURZMjl2NzkKK3lpS1RwNDh1'
    b'Y3ZTRlkxRysrcXJyMGpUMC8zNzkrUGk0cVpQbjA3YUE3cG93ZlB5SWhldDBvSU1BTTZuWklM'
    b'WUZLL3lPajB6L2ZxdApWMFB2cExxZi8rNklpMWxGYVkwQm5hcDJOSzJxYldCL3NmL3JmaTU1'
    b'R3lmR1ZFczRNYTlhYXJyWFgzdFgxdkZNOU1XYkxvOStrT2x5Cjd0c2pUaWFWRmZWNkNFRTRt'
    b'MVdLcE93djlzOGY2SjZ6ZnNLMXFucmU5VmZlTGVEWFh2c0l4VndCVC9MVHBUR1BzNTNPZlh2'
    b'RTNyaTYKcXA2bnhsRWZrekxSTWFlQ2g3YVdTaGxOVFFDTm9OVHFBWUFLMEZxRTNxUUpBb3pB'
    b'Q2hFZ3JIR3BCU0g1SU13QWdSTU5FU2VWVjJJUgpDMVBWZzZmTlZtd0RQYUJTQVVBUmV3OHJM'
    b'Y2ZlRmFnU1U2aTJsdFNnM3F4djV5SXNWa3hNVEY1ZTN0dTNiN3N6WnhwNjhPQkJYVjNkCjdk'
    b'dTNwMCtmRHArQzdpZVVBVGkxZjAvSERxUkRORS90bGVCMnF1Y2dqK3dIbWE3blh2aFhpYmtq'
    b'dkRNYWxQUjZPVXVQSlQveHNOLzUKRjM2dUZoWHVGdVZqZjFuOHJrcncwYWRNdTUzbU1kZ2or'
    b'MzY2Mi9rWC9pSUpkNGhYbGxKTnJaRnhERG15SS9jSFhFem81VzVaN214VwpPWGJQb2dKaFN5'
    b'bGRycUxkU2ZVWTRwbDFKOVhqd2t1L1dobDdvRnNPVHFCQ01ZL1BsbkxQOHkxa2NncnAvOE1S'
    b'QWFhTXBEcmJFK0pKCldMNkFhUHF5VFFoNUg3ekNnNml4SnFTb2hqc0lBaStyd0hMZXFwTlNp'
    b'T3FhWmpxMEhvL2VMd2pSMTVOdDJJR1hsQUVBcU5XNFVFUlUKMXpEQ3c5S3pNdGV1WGF0WjFi'
    b'cy9aeXRXck1qS3lzck56VjJ3WU1ISFptQmRhYy9KaDVlZVk0QWc3Y3NsWFhFZ29TaGhiU1Fx'
    b'RVBJdApER3NmclBzbHRjaVNTVmRaRzlXTS8vV2IvRXFCRFY5VVVtT0E0VzFhSURSd2E2T2Ey'
    b'NnYzWnBlWm9namhhRm9WdXV2YkFpSGZWbEJkCkxESnNCMDVCY1N1am1nSWgzODY0T21iWmdm'
    b'ZFZBaldPdWx1VUphd1lFQ3ByOGtGVUk0d0tZSnRDQTErTEE3cEdpSkVCUlNEQWhVSmMKVktz'
    b'eE9kSEhmY2Jkdm43T25EbWtkaUFRQ0lxS2lwaE1abmNlVkZoWTZPam9TTWF6N042OWU5bXla'
    b'VjF1cXJSS3R1elhaMUczOHpRNQpEbTFQQjlJVll4R09JK1JuT2ozNGhhTkpWWWg3VGgrbmZI'
    b'ZkxzaG45bnBHYVhqdFQyQXplLzdteldXVi90N3hnMTdldTVoVXorajBICmdBSWh2MzA0aHFN'
    b'Zm52N2N6YUs4cjh2YkFXNjVUcVpWcFlQbGxValRwOE1uRkI1RVRmYzVBQUFJVWEwNko2K0pB'
    b'd0JRWXlQV3dsbmwKNWVWLy9mVVgrUmVoVUtqNTNXWGF0MitmSnFJcElpS2lPMkZ0RnNic05k'
    b'T2RxWFVKbmJsWnQrMmdCYjE2YjBOQmllSGVHU3k2NnRmWQpvVDlIaHlyVk9nZ1p5ZTl0NkRS'
    b'c3FHY21pNjc2NWZxdzdUR2ZxVEFkNEVudmJKazA5UkRQTEJaZHRmUGFpTTEzUHZ0TVdXSkJ0'
    b'Qm1NCktrY29GUWk3Rk9YbUk3eGNSRDhYMWM5R0RkSXBSajRqL0ZBN0c0cXROV3BoaWdyNHdP'
    b'VWdkQnFoVWdQV3B2V0o0dUxFbWpOMTBhSkYKU1VsSjJrNkVyNy8rV3RjUUFRM2w1ZVhObWpW'
    b'TDR3ZXFxYW5SMTlmdjI3ZHZsL2xnemFxbHlmZFBBTk1NV0phZmZqdlFVR2lQdEwrLwpQY0tr'
    b'cXdCQXFhYUdINXg3TmFsSDUzczUydmROMU9KanBObFJvYUpOT1RnM0p0bW44L0N4dlZMK1du'
    b'eU1ORlBLbGJRdkQ4eGpKN0wzCnF1S1pSTlBrMVNQME1vUlZqSENURWNGOXFtVUdZdml4a2VE'
    b'anZBTkNMTUZ5ODVWUFgyQnZNckN5Q3FpcXdzVk52SVV3bWV3dGE1TU0KMlAzNjlTTUlRaHU0'
    b'Y3VYS0hUdDJkRzNPUm8wYWRlUEdqV1ptRlI0dkt5dkx3c0tpQzYwbEppWUdCZ2JpT0E0Y08z'
    b'QmI4K20zQTgzVwpqZ015Y091eW15bGVEekpkKzIxY3FWUlRLQ2plZWJnYXB3ell2UHhPcXNl'
    b'OU5QY0JtNWVyTVJSRmlVN0NLU2l1d2lqOU5xNjhuKzUyCk85Vmo0TlpsR0lGZXBkc1hOWGVX'
    b'bENEc1lPYjRTWXhoMittK0wxR1Q5czFFVGRQTTQxSjcrYkMvbmNjNytxdEJkQ1JpMWt5bFJD'
    b'M00KbEgzOTU4eVowMko2ek16TURoOCsvUGp4NHk0TTV2SGp4eDg5ZXFTdjN5d016dGpZZU02'
    b'Y09TMWkzVHBERW9sazVzeVpqVkdIeWc1OApFRWgzSEVnNGp0eE04VXg2WjFzalk5ZEkySzhL'
    b'ckdOVHZOcmZ6aitHSjcrM3FaR3lhMlRzNVBjMnNTbGVPTjdaSkZ3TVIyTlR2RjRWCldOZEky'
    b'VFVTVHRJNzI1c3Bua29jZlVocEZtOXBUc2g2WXRYZDJhZXhyRnk4cWxrTDFENytPM2J2WHJ0'
    b'MmJWQlEwTkNoUSszdDdRRmcKMGFKRmRYVjExNjlmajRxS0tpOHYxK2tSYVdscEwxKytQSGZ1'
    b'bkVLaG1EbHpKZ0FNSHo3Y3ljbHAxS2hSNDhhTjYwTGlBNW4zR0J3YwpQR1RJRUF2SDN2K3pE'
    b'aVNTTGlmMFpOSzZYdC9xY3FLdnh2dlFOYmdLYTByWjJVUHJFWW9YV3VDTmVTWUdoSEtaK3Mw'
    b'MHl1QXV0OTl3CjRBUlIyNVF1Z3BxYTBHZFAzV1JxbkpLU2N1TEVpZXZYcjArWk1xV2lvbUwv'
    b'L3YxY0x2Znk1Y3NIRHg1VUtIU3JQK1hxNm5yNDhPSEoKa3llZlBYdlczdDcrMUtsVElTRWhF'
    b'UkVSSTBhTVdMZHVuYUdoSVVFUUNOTHB6d1BEZnZycHA3UzB0T1BIajErL2ZzUGhzLzBnL3k4'
    b'dwpRYUp2ZCtBWFh2YnFEdnp2NTgyczlCVUk2eDJpWndGTnlVWmV1TWdBbExXZ2MzVzRnb0lD'
    b'Vk5iQXk4MXJ0ZzNaMjlMTVRRSGcrZlBuCjBkSFJiRGJiM2QyOXVMZ1lSZEh0MjdkSFJFUlVW'
    b'MWZ6K2EzN0lSOC9mdHkvZi85V3pZWFoyZG5oNGVIanhvMlR5V1FvaW5wNmVqbzQKT055N2Q2'
    b'OGRxMUZoWVNGQkVCL25vRkVvRkFDSWo0OC9kK0hLb2wwSlZYTCtwMWtKVFBURk9pVVAvYS9B'
    b'SFlqNjc1UnA5bEJ2U1VoeApRRFNHSUN1UXpGZW5KeUVtTTlWWmZGRG9FUW9xZ0J3b0lvVDVG'
    b'RFU5VG5NbkpGTGx0VnZLZTQvd2Vna2hid0FDVUQwdVltQWc3OTBqCjQ4S2xrTEp5YlVrYUt5'
    b'bXAvMm94eGNacTd1eHdHbzhIQUgzNzlxMnBhYlF2TFZ5NFVLUGpmVXg3OSs3MTlQUnMxUmZn'
    b'NU9UazZ1cEsKR3AxNjl1eEpSb3ZZMk5oTW1kSm11RlJkWGQzUm8wZjM3OS9mNnRVUlk4S0Q1'
    b'OTNvTVBlbzhiVTYxQTZtdWZXNXYyN1B1RDNmUE1ycQppcWU4bDEzaG5UVjdSKzFhckowSTNI'
    b'bnlzeSs0dlhwZjZNNXYyMGw5Y2NERmU1VlBYWWxhUVJ0V0FRSUJPVkJZUkV1Vmp3QlFBWVZw'
    b'CmJJaFhpK0FqK1V1QkFBMmdMVkVWNFJ0U0hPeTVXOVkwR0JuY3VISGppeSsrYVA5RnJseTVF'
    b'aFlXVmx4Y2JHWm0xcUdRT0dmT25QYnYKa2N2bFE0WU04ZmIyL3YzMzM5dTZwMWFzSExQMDVw'
    b'UFg1UjJKMkIycGlCVW9peFdSWW1kY1hTSXljRm0rdVMwbmZWdkVwS215ZDYrMwo0WXVLUklh'
    b'dXl6ZC9YSkNnZldMUlZkbTdmN1EycWlrUTh0MVdiSlNyV29FdlViMlpyYzYySkhRdXR0aUFV'
    b'QWdDWVFNRzBIV0pCRFV6ClpVNy9nanA5RXBYYTNwb3FFb2xzYlcwbEVrbG9hT2oxNjlmYmIx'
    b'T3RWcmZmR2dEODhNTVBXN2R1UlJBa1BqNCtLQ2lvemRWQ29uUWMKRjFWZEoyK2ZDZEFPWjVF'
    b'TUJMVTBxcDBhL0VMWE1ab2NsRWdHZ2xvYjFVenA4MUpYK0pRK0w2Mk5hZ0RBVmxBOU9haVZJ'
    b'TDRmbFVtTAoxZWxkNEFBWlVBa0NZWU82T3h3QUFIaDVSY1B2ZnloLzYwQ0FwMUtwZW5wNkFN'
    b'RGhkSndVMnlFSEFBQzVwOUJvdFBadFUvcGMrc3pSCkxoMnpjdnVYdFNQQUJudG02enBHZ3p5'
    b'YUlJTTlkSVpyUXdaN1pyVzRPbGVkTlJ2TE5pU2FpZUp5b0JRam5EeFVyeTNsV2dXb0ZHaFUK'
    b'd05tZ2JpRlFJUndPem1hcDI2b1ZoYUtvZ3kyWW15QjBXZ3ZMa2lMcWt1S3ZpOXAvcksrdlY2'
    b'bFVFb25rOTk5L0h6OSsvTVdMRjErKwpmSG52M3IxVHAwNHRYTGd3TEN6czBxVkxLcFZLS0JT'
    b'Mk1EZTFzNVlBUUhKeThxSkZpeVpQbmp4OSt2UzR1TGlzckN5eFdEeDA2TkIxCjY5YTllL2NP'
    b'QUtxcXFscnVsWmJkaml6U3R0NFk4M1JPRGRET0p1aENaa0V6ZVBQTUFpZWk3anRWcWg3UkZO'
    b'K01BWktPR2g2Z2VkMmcKMkN4V3BTL0YzekFBYTdiL0l3QUFOTUJwMEl4REVEWWJnTUNWU3BC'
    b'SzBiWS9Dem1PM1ZPSVB6dDlSUDlObHZ6WWFYWE9XL2dnQXhKaQphY094TTdUZ1FOU21NZTJW'
    b'dytIODhNTVBNVEV4R1JrWkJFSEV4TVJVVlZVRkJBVGN2SG1UM01WdjNyelpzMmZQQlFzV1RK'
    b'czJyVE5ECmtaV1Z0WEhqeHRldlgxZFdWZ0tBdWJuNTl1M2JxVlRxaEFrVFVsSlM3dDI3ZC83'
    b'OCtZQ0FnRDE3OXJRQTVwZDBNT3dJMHRGMmdCTk4KbjRWSXd0Rlk2em8wNXpWQ3hFMnJuNlk4'
    b'Z0E1d3JZb0NMWjcrcStLWjlpNmdCdlEyeFhvRWM5UkZpZ01IVVlXcjg3UTVBS0hoV0d2QwpU'
    b'QU5RMGhBalZHQklxRlNJdXFYWWlERVlRR3Y2NkptQWpBR21nTXVqZnpaWTcrOWo5QUY5UUd2'
    b'ZHhzdktwZXUzYSt0cDI3WnRTMHRMCjI3NTlPNHZGbWpGamhwR1IwWjQ5ZXdZTkd0UzNiMTlM'
    b'Uzh1WW1KZ25UNTUwa2dOSUhlVFdyVnRKU1VuZTN0NW1abWJoNGVFUEh6NU0KU2twYXNtU0pr'
    b'WkhSNU1tVE16SXlJaU1qVFV4TW1yMmdRbjMrYm41M3RRTXhrMko3OWttallUeHE0bzFYWGtm'
    b'bm5nNXdmSjlUWmhwKwpjTTdyd3BiT0p5K3IwcjhXSC9Xd0tFdDRaemYveExRUXQ1eDkwLzht'
    b'THkwNzg4V2ROUGNqY3lKN083elBMak9kY25EdXgrbmlQamJGCmZ5MDY1bXBla1pCdjkvWHhh'
    b'Y084TW4rWmVyNVJBSXljRkpmaGVtUk9aRy83OTdrSnR2VGR0dnBZMHpLUWpQSkhNa2Q3MlJT'
    b'ZlhYVGMKK2hwTGVVdkwwRXZGbWVOS2p4YjdEM3BWYjZWc3NoOVVJcXd6Rk9ldGRGLzh4Vnpa'
    b'emdQSzJEdTRzTW5DU3JHek9XN0U4bFhpUFhQZQpFMHFWeHNUS21ES1I4OE15VW42cm0vSTFs'
    b'dDYwU1NHR2huckg5ellHb24xRVFxSFF3Y0ZCS0JSMkdNYmVTVnF5WkltSmlRa1p6ZENHClVa'
    b'V1l1U0h1VEd4ZWg5cEJCeXVCVWsxVjR5Z0FFQVJ5NTQzN25UVjcrempuVTFEYzNiTHMrTmQv'
    b'Zm56LzBibW52YXhLVVpRSWRIeDMKZStYZXVBeFgwcENNNDhpOURMYzdhL1lHT2VWVFVOekRz'
    b'dXpZM0ZZS2RoeWJlOXJEc295QzRrRk8rYmRYNzcyWDRVWWFrbkVjaWN0dwp2Yk5xYjZEak94'
    b'UWxMT01ZMmh4UWlUQ1gwb0xWZ0J6LytrOTNpeklzdFZrZU84VkN6cGhVZXJ6VzIySm5Nc1ZX'
    b'U200S1NrTjhBYVAvCkZub3ZBaENnVU5oci9zUGVzQkkxTXlHM1FLcTNoOTZaM3lOZVBObFZW'
    b'NjVaNGNrOVJmMHNFY2hkbkVybGJscU5HaGswWGF5cGFUalkKWnZHWVc3ZHVpY1hpaElRRStF'
    b'UjA0OGFOKy9mdnQzVTFJYU5xMFB5WURqbWdVNEloazY1Nm11TUVBRW52YkViMlRETTNhREtn'
    b'a21KLwpDN0kyRW1rYmVTYjJUbjZXNndBQUNlL3N4dmkrTWRWcnNsM1lDRnFEYTdWcHBsOC8x'
    b'amZsWmI0OUFEeC82ekRCLzdVbTNSRXJheGE3ClVZRHcwaWhHcEE2aWZzZkI2K2hhRmdLQ01W'
    b'QVluKy93UldDU3dLWkdiMHM2MVZXTW1zcng3d29mb3MzY1AvUWhBN2kvYmtHdExHaTkKZXZC'
    b'T0hVaDZtNWVYbDNmLzRVTjE3NTdOOWtlUkNNdktiV1F2ZHhlMHVXOEphN3NhZEZSVUZBQmN1'
    b'SERoazNCQWNuSnlibTd1NDhlUApLeXBhejloeHN0SWIzTnNTN1Z4QjFBNllnRVZUM2tsMUI0'
    b'QTdhUjVoQWNtNTVTYWJMbzhtMWYyNEROZVA3MytRNlFvQUNoVjE4NVZSCldhVm1ZWUhKZDlM'
    b'Y0FlQk9xbnRZNzZUc010Tk5sMGVUNm40N2NMbUt0dW55Nk93eTA3Q0FSdmp0Vkkrd2dLU3NV'
    b'ck5ObDBmTFM5aTQKdUprOGU0MWkrd0h1b256S0o2Uk5yZ1FwQzJVTXJyaWQ2aEhXT3ptenhI'
    b'ekxuYytZUCtib2JVbS9KMm1sWWdHMWg1ZmVud2Q1eC9jaQpUQ1pwaVZNb0ZIK3BaYWh4VTV3'
    b'Y1VTZFczR3o2L21oRG1wbUI4ZHA2dkxRVjQ4emJ0MjlKTi9FZmYvd2hsWDZDOHlQSTdpbVZ5'
    b'cllLClZ4bnFNWDc2MnUvZ3F1Q09CWUlPQlVNS1NsUkx1QUJRSkRMMHNDd2J1bTNwaG90akNx'
    b'dU5za3JObHA4TisvaitsVkdmcDVkWWxOWHEKcjc4d2RzaTJwWGFDNnNwNlBRQW9yVFZ3TWE4'
    b'ZzRjVWl3OHdTOHhWbkozNE1YM0YyWWthSmVZbklZTVBGTVVPMmZlOWtWa21XT0ttbwowN00z'
    b'cmg2eWJlbUdpMk9xQ3ZtNHJPbGJyd0ZHSE1WQ0kzYlU1UnRvTnlpaDBoQTl0VkRNdGVhTGht'
    b'eGJ1djdDMkhJWk4xMW12T3F2Cno5c3kvZ0NOVmxWVmRmNThveXl5NjQ4VHdHdW0zT05hbnpz'
    b'dDBCOVlUY3NTSVpIaTVhMThtZ2NQSGlROXdyVzF0ZDBQUUtxcXF2cjcKNzBaSjYvZmZmOGZh'
    b'RG42Wi83bEhUeGQrZDFjQ3VZcHFwbDhIQUtaNjlYZFMzUXVyalJDRWlMZ1gwbnY5MnNMcVZt'
    b'emdwVFVHZ2V0WAo3NGtkUmtYeDBocURtMjg4U2JpWmZ2MnRWTTlpa1NHS0VyL2RIdFI3L1pw'
    b'aVVTdlpGTVVpdzREMWEvYmZIa3hCOFJLUndlMVVEelA5CmVnQXcwNis3K2NhenRNYUFndUkz'
    b'SC9SRXRCSmY1U2lsREdtY3BDS1JZVkpHYytNMEF5ZmhOMTU3bDlYcVUxRjg5L1hoUVJ0V3Qx'
    b'OCsKWjl1MmJYSzVYT09ucVc1b1Z2dU9xRy9hMUZCTGM1U3J4U0p5QlY0dWJEa21wYVhIamgz'
    b'VC9IZkhqaDI2dWhsYjBJNGRPelRkS3lvcQowcTZLOWRGWERpT0RyYnZMQkNoS0RQWEtCSUNo'
    b'WHBsOG5sU1BKU2NJWk4vTklhMm1tRFd1d0FyR2I3Y0hxWEdVdzFBSWVCSU5YTUNWCjhKaHlI'
    b'RWYyM3hyY2FvcVpCcjcvMW1BTVI3bE1CWjhySmVIRHZETk45TVFjaGdMRDBaZzMzb1JXOENS'
    b'QklKaVdtMVhkUEtCQm45TkEKd2swTjZ0bDBwUnBIZjdzOXFIM2pkMFpHeG9FREI1ckpIRVZG'
    b'TFFhbGFaU1pESUtpOVVRVUFWckxVcFRMbHkvWHJrYVFsNWYzc1RiZgplY3JJeUdqaE5GcTdk'
    b'bTF0YlcxYjl4dndHTjFmQ1doa3JyRzNkY25GbDcwd1hJZks2eGlPWGszczRXNVpEZ0FlbG1X'
    b'WEUzMDdIM0pDCndpOG45SFMzS0FNQWQ0dXl5d2s5Y1FJRmdGS0VMZFVxcThBQTNCaHZzbzFM'
    b'b0prNWo0Mm9BTURWdlB4cVlnOXRtMGViZGhFYy8rYWIKYjFwRWVGS2JyN2NJdjJrSnhJWFZv'
    b'RkJxMjUxUTgyYWk0djM3OTBtUlVKdCsvdm5uOSsvZmQ4VktqZU9MRnk5dTBiM0t5c3AxNjlh'
    b'MQpCY2twcU9zdUV4QUVRaFlCMFdQSjVTcHFPMTl3cXd4VTM4QXk0a2dCd0lBdGt5cm9Pdm1m'
    b'R3BRMHFaSmh5SkVCZ0NGSFZ0L0FJZ1hTCkNvUXQxVEowY2dtbHVaYlZxQUJ0WmlWRkZRZ1F3'
    b'T2RLYTJUc1Z2MVBMV2pUcGswQTRPZm54K1B4QUlEQllIRFliQUczV1pzVUt3c3QKMzBFbFNM'
    b'VXFuakFaMmtuTjVlWGxDeFlzbURkdkhvSWdaSU1HQmdaME9uM3UzTG5UcGszVExPbWRweTFi'
    b'dG1BWTV1L3ZUN1pHcDlQWgpiUGJ3NGNPVGs1UFBuVHZYaW5HaVZ2NTNSMFVNTytVNzJCWTlF'
    b'Z0IrdVRFczBPbGRid2NkK0xlblRWR0lSODcybU04QVlQZjE0Y0d1CmIvM3NkYWlGNld0YjFN'
    b'ODFiK2YxRVFDdzgvcUlFSThjc2pKU0diUllDYkRQc1hlYS85Nm1XTW1oYVVHV1ZiT3hFdGFP'
    b'YXlNR2UyWjMKV0JsSktCVDI3ZHYzNE1HRHBhV2xEeDQ4UUZIVXc4TWpaczgrbHFMcHkwTllU'
    b'S3AvVXhTTThzWTlRcXRnRWNybG9DWk5xa1JxYXVyagp4NC9GWXZIaXhZc1hMMTVNeW5GOSsv'
    b'YWwwK2xuejU1OTllcVZUaHhRWFYwZEdCZ1lFUkZSVWxMeThPRkRDb1hpNXVaMi92ejVGeTll'
    b'ClhMbHloY1BoeUdUTlpCZXhURFZtNlUySnJPTzQ5UTU4QnpWUzlxbkhmZGFNalQwYkg1RDgz'
    b'a2FuVHI4dXRKNFJNY3ZEc216MW1KdVIKOFlGa2NkSE8wNnNDNnhrUnMzeHNpbGVPdW5YNmNW'
    b'QmFjZVAzaHlGSUdYQWNvR21YOWNHYllnQ1RFVUUxd3RSWWxCa0tRdmxVY0NxNQpUMmFKZVlk'
    b'UEZBZ0V3NGNQWDdodzRhMWJ0N3k5dlcxdGJUMDhQQUpxcEFxVW9yMFgwUHlhUXFLeDdOem15'
    b'b1d4dHNRd2JOaXcxTlJVCkF3T0RmZnYya1FXdWUvWHFkZVhLbGVuVHAzTTRuRDU5V3JmVktw'
    b'WEtWcTJLZkQ1L3hJZ1IzM3p6emMyYk4zMThmT3pzN0R3OVBVTkQKUTQ4ZE94WVJFZkhUVHo5'
    b'cDMvejRWZm5rTlhmTGhKMHE1OXp4SmwxWWJWUmVwL2Uyc292MVBOOVg4Y3ZyOVBJcnVuaWNV'
    b'bjZsY1htZApYb3RLQnJjcFZ0cXVOM05DWmswMHVwY2tDSzBTYVpZUEwzc21LS2ppZC9KeFly'
    b'RjQ1Y3FWWktZcG1kT0pKVFE3TEFBMUZzQUhMeUplClhJcFhDYlZsY2RxQXZxM3Fod2lDZUhs'
    b'NXNkbHNCd2NIZlgzOUN4Y3V0Qk9NZXZIaXhlenMxajJ1RW9saytmTGxaRGtqVGNwcFdGalkK'
    b'NTU5LzNrSlI3TzlyZG1uWGNFY3J2VS9EQkExS212ZnFEUzBxRFhTZVpFcTY5K29OWW5rWDg3'
    b'TWtjb2IzNmcwdGxKRkxGUHNLcldRagpVNkxoQjFYVFZFVlQ3WEF0OWFHdVdNOUYzbGtISm8v'
    b'SEk2T0hBV0RvMEtFaitLWlljWm5XYUZIb0lVMmZyMnp2WWUxQVpNUkVRQThkCjFxSkJiMjl2'
    b'TWthMFI0OGVZOGFNSVFNQTZYUzZwMmViS1QzWHIxOXZxOTRwbDhzbEs2dVIzUXNPYnJRRitm'
    b'ajRrQzFyVTVDM3llTmoKWTNsc3lpZGdBZ0RRcWJ6NGZ3RmVpbkp5MEdhS2ZtK3NVaDhhOSta'
    b'SWluTUowcVM3RytES0RhckVMangzekpneDlnOWZFR0tKbGxYQQpqREZ0MGdkcmdWajlKcjNa'
    b'enVwZ3B5MFFmS1JzbzVwVFN0bzNCWjQ1Y3lZMk5yYkRPMGVQSGgwUTBFRnBGU1pGUWFsNTlt'
    b'bVlvSDM2CmFrRDhOME1mZEJrK0t5Uit3WkJIdXFKMlUzdlVJVTBicHpVaCtVblpPTk1paFBH'
    b'SzBtd3lQTEVhZjd4SzEwZFkxOVREKzJabDJXbCsKUFJCMjQ0b28yM1VBTDJsYTBodG9GTmJp'
    b'dWUwMzZPN3UzdUZEOSszYkJ3QkhqeDd0c0hBVldSS3gvWHV1WGJ0V1c1YjVQODRFQVk3dgpE'
    b'ODgrczNmNnViN09iN3NBRDNMS1B6dzdjditNcUNDbmZKMkFUeWxtQlFoUCt6V0dZOFZ1UktQ'
    b'TlpEM052eFRWU2s0RitYYmxjMVNuClNESU1sMjdlMHl3SjFjU1k5ZTI4eG9zNWIxV1A0c2w2'
    b'UjQzOFlXMlZ3NkJVVjNjOTBhV29xS2k2dW5ycjFxMCtQajZiTm0xaU1CaXYKWDcvdVF2cVJS'
    b'cnJNeXNvYU8zYXN1M2Z2am53SDNXYUNueWRkcGxQVk5BcTJiZkxsTHNDM1RiNU1vMkEwQ2tZ'
    b'V3JkR0pmcUw1cXpsTgo4MnBHeVBZcm5pSkFBRUFSd2sxQW00Vlh1T04xSzFVcE9sZ3BJazVn'
    b'N3dxMVRZRzBQdjZvdVdsNmV2cXhvMGN6Wmk3UWxnWlFRNFBrClBqMDlQVDFOVFUwblRweTRm'
    b'Ly8rbXpkdmR1WXBCRUZFUmtidTNidTNmLy8rTmpZMkxpNHV2WHYzVGtsSldiVnFWVkJRa0sr'
    b'dnI0T0QKdzdwMTZ3NGRPcVNKYXUvUW5uanMyTEgvL09jL3BxYW03dTd1UC83NG81bnIwSTc2'
    b'MEQwbU1PVElCcmszeXJIOVhmTjByV3pMNTBvSAp1RGFxV0NGdU9aMHZUZHY0d29aY2xrY3pj'
    b'Nms3VWJORzFhaDhMNlAxZWFlMVZEQkJIWTdsT2hHZE9ub0d5ODVUWEw0R3lpWUxQOFhHCml2'
    b'M0RNZ0R3OVBRTXpzZzNsVFl6L292dHJWK281UUNBWVppOXZiMkxpMHNuS3hjaENQTFpaNTha'
    b'R2hxUzlTaEVJbEZ4Y1hGaVlxSlMKcVN3c0xDUWxDVzl2N3hFalJuU3ljSldIaDRlVGs1T3Ry'
    b'VzFEUXdNQTNFK3U2YkRVZmROQldGMGpCNU1xVFJBaWdoQU94bFU2SlprNAptamJCVVpTd054'
    b'YnFKRUk2bVZaeEYrZlZyZlRCS3hwMUJ6YWhucTdPZlVZeGkwTXRhaERHSVpybmVtVXk3NFBB'
    b'YUlsTFQ4b2ZoREpECnhlMVhMNVBLSkN0K3dzdWFTbU1pSEJaejNneUV3d1lBNWVOblprbHZD'
    b'SzBNRTh6VStBQWIyYnhtRFovUE56RXhtVFJKdDZMd0FvRmcKNXN5WllXRmhodzRkc3JXMURR'
    b'a0orZkxMTC9mdTNmdmd3WVBZMk5nWk0yWllXZWxtWHhrNGNPREFnUU1EQXdQMy92azA1bzBS'
    b'UU1jYgpTcmRXZ2hiVkNIUXFUZ0FBU2xVejdVV0o2UWhYVXhDZW1qbXFER0UzVFlrSjBiQkw4'
    b'WXdzWG4yQzZwYUM4bHNzRlNlVmNVZzd3Z0ZCClNMNWJnNzE5cC8ycFVIMDhHUk5HQVFCZVVT'
    b'WGI4Z3Nock5FeUVYSmYybHZFUEhsRXA5TVhMMTZzS3dkb2lNUGhyRml4WXRLa1NSaUcKM2Js'
    b'ejU4R0RCNzYrdm12WHJ0V1ZBelFrcGRpK3FyQlJxRG9sVXVqTUJIMmQzLzY1OE9TUk9aSCtE'
    b'Z1c1NVNhYWljZHdOTHZNMU5lMgo2UERzeU1pRkp3YTQ1YllLRDNaNWUzckJpU056SXYzc0M3'
    b'TEx6VFJPUHpXTzVwU1ordGtYSEprVGVYckJpWDZ1cmNkRjlYZk5QYjNnCnhPSFprYjYyUlZt'
    b'bFpoaU9Na2VYMFh6cnRCT0Y3QW54TmJoR2Fvd3ptWVB5dEpSSkJDQVFyOXlqYkZOcmtxN2Jx'
    b'a3BPQWEwd2NOVFIKanJ2M1oxSW5GQzlZaGhkcHJhNVVLblZBbjkzdnNqSXpNNHVLUHMwSjgw'
    b'K2ZQaFdKUkhmdTNPbG1POE9Eck5MT2ZURnhjS2ZPR3RHdApVb216V2VYempUdjg3QXI5N0F1'
    b'LzZ2L3NjYmF6bVVHOXMxa2xBTVJsdU9hV216NzhZWGVnMDNzZm01S3BmVjllU3VoVkpXNjJP'
    b'N2lhClZ6ejdhWHN2K3lJLys4S3ZCang3a09saWFWanJhRm9GQUhmVDNOOEwrWEhyOWdRNE5z'
    b'SXZKUGkxMkIzY0xjdmlOK3owdFNQaDhmZlQKM1d3RklnY1RJVDFRSkh4aVFSYzNNYlNoV2pX'
    b'Y1VuUU9IT3NSK2l0VU1BUXY0UkdOSm5RYTRBNUVQWjlReEZFYTYzZjg5SFZqbVdqcApwdDNL'
    b'RzNkQnk2K0RtcG53ZnR1T1dwZ1JVcGw0em4rd3pKeG1oZ0V2dDRydjU2OVl0WW9nQ0gxOS9Z'
    b'RURCM2FmQ2RhdVhadWFtcHFiCm03dDQ4ZUl1RnoxcDdCNEZkYmZBSXM2L0JrcDdsanFLcmtV'
    b'cUJubGthMnFSMDZucXc3TWovNHB2MUVEK2lnLzRmZFlaVGIxaE9sVk4KaGdKbzAyRFBMTzBi'
    b'RHMrT1BCdmZhTzZJZXQ3Nzk5bG5OTldSR1RUMWtJK3lUWVo0WkduZkVESHJiQ09jUXV4MGRz'
    b'V01tOVZZZDVQWApYbFRlWmhKWUVtcThqK290UXBvR2xFZW93ckc4dGFwbTltRFpua1BLRzNj'
    b'SUxSOE1vcS9IK3M5OGlvc2pJWmVMNXkxUnB6ZDdIWXFOCkZmZkFqcjBIRHBCYTNPSERoN3Qv'
    b'Y2w1WldSa1poQ2lSU0VoZlF6ZnAySkdEVUpQMGliZUR0eFdOSG9RYUtidTB4c0RSdEVxaVlC'
    b'QUUKQWdCQ0NkZmRzcXlzVmwrVExKQlhidEkrM05tc3NrN0dJZ2lFSUpBYUNac3NpZGdFcjJq'
    b'cHJkRDRMMFJTVGxtdHZydGxHUm42UmhCSQpDY0V4WEphRDgxWGFLMzh2VEJpdHVHbEVLSTVS'
    b'M1k5UjNlcTFzdE1OQ01VOFZkWXZ5bWNJRUVBUTBwOTJLdjYrUXRRM2FUZUlIbzhSCi9qbGoz'
    b'RWlpcGxZOGM3RTZKVU5ia0VBdHpMbS9iS3BGa1QvLy9GTXpmNWN1WGVybW5FVkVSR2dPVVRs'
    b'NDhHQTdjV09kb2RyYTJqLysKK0FPVU5aOTRPM2d2NVBkMWVldG9JbHgwS256TzBSa2hicmtv'
    b'QWdhY0JuRURzMGJLb1ZHd1hqLzg4TDVLTUxIM3E0ZFpMajllSEVjMApqK1BJcnhMMGM4MXpN'
    b'QkV1T0RIdDZ4UFRCN3JuRUlBSWVKSWFHVWNzWnlJSTRmZmpEMFZDd3dtOVg4ZGx1RzY0T0xa'
    b'RitiWDhLdU9CCjdqbDJndXA1eDZjdk9ERnRzR2UyVWswMU42aXJyTmRyVU5MQlNEMDdidEpJ'
    b'U2dGTGpXdjR3SUtRZllZWFAwTE5vcW4yRm9UTWhhaWoKZjVDV0dZQzU0Ylc5Y0tGOVdvTHEv'
    b'aU5DMnJRR29Ed2U0NHV4N0tVTHNmd0M4Znp2c2F4YzdaUkYxTXlVdDNjcnhjdDkrZkxsVDU4'
    b'MgpWYjU4K2ZMbC9QbnphVFJhMSthc3FLaG8yclJwbXVXa3Fxckt3c0pDcDBPU1d0REtsU3Nm'
    b'UDM0TWdtQmcyN1MvSGVoYXZRdzU5OEtmCmdoSXFqQktmNjFoWWJmUmxVR0pkQTZ0QlJlZHpw'
    b'YnV1RDg4cU5ROTJlWnRWYWo3MzJBeVYrbVBYQlhMdWhUK05pc2xWdEdlNURzVWkKb3k4Q2t5'
    b'Vnlwa1RCTU5FVGI0OFptVk5tMnM4MUw2M1ljdDZ4NldxTThwSGtqa1E5NjgyZ3FodFU5T2Q1'
    b'RHFXMUJoUDhYc25WOUxvRwpscmxoM1pZcm94NVgybG4xTG5XdWJtQW9tK2FNVDhpSFlTWHBG'
    b'S01UVkRkTFF1cElpRFhKU1ZRZ3JBa3BVbGdNV2lzNXd1TXlwbnpPCi92NGIxZk5FeWZmcjhl'
    b'WlI1S2lGT1cvZlZvcTNlMnBxNnRkZmY2MXQwYXVycTJNeW1TRWhJVjJiczdsejU2YWtORE5u'
    b'eGNmSHo1a3oKcDJzbExkUFQwK2ZPbll2VCtHQVREZ2lsZlNib1Z2VXlHNzRvWWRQUEwvUHRH'
    b'VFNWcTNuRjhPMUxzc3RNTzk5UmUyUGgwdzA3WHhkWQpvd2poWlZVeWNPdXl2QW9UWGV3RWxY'
    b'SHI5cVFYVzJBRTRtdGIxSGZqS3JMNGZXKzg2cWp5b1RVdWFmNGlyQ2lLMHhaNnJ4V3FsTG5x'
    b'ClRENmhVQU9pUmxCbTg2SUZpTDRlNDh2UDJkL09sZjBhb1l5KzFjeFRESUJhbXZQMmJLWjRl'
    b'OGpsOHVEZzRQZnYzMnRiK0FVQ2dVS2gKZVBqd29hK3Z6cVZiTGx5NE1IWHFWQWFEb1IyTmFH'
    b'Wm1SaDdEcFd0ckNvVWl1RjlJZGdWTFlqZ1NhQWJ0MzB5am90MnFZemc3NUttMwpUVWtmNTN4'
    b'SEUyR1ZtTmVncEQzSmNlcDhYK2NNZk9walhSTG85TTdKdEtxeVhxOUJRWCthcXdOODdzQW5Q'
    b'V3hMQWh6Zk81dFZsdGZxCk42aG84Ym1PQUZDS2NHNVRySUt4Y21OUWFMWVRMcWg3RWNLaGVN'
    b'bEdtbjg1c1B2Z0ZRREFndVljWUdUSVhqU0hNU0ZVdkdDNTZzNUQKUXZ1c0tnU2h1amp5SW5a'
    b'UlhKd0FZT1BHallHQmdSd09oOFZpb1NoYVgxLy81WmRmWm1abVhycDA2Y2lSSXlFaElUcWRW'
    b'SkdUazNQbwowS0ZObXpaRlJVV05IVHMyS3l1cmYvLythclU2UER6YzF0WTJMeTlQVjY3YXZI'
    b'bHpqNTcrRWpWSEpLTXJPNnB1M2QyVkFBQk96RHMxCkt5UWVBTTdHQjB3OU5FZFhuajIxNENS'
    b'WnlQVDAwNkFaRWJOMGhVY3VQRUZXVGZqalVkOVpSMlpxWCtJUnFqK1Y5d094U2tiem1jNUgK'
    b'ZVBVSXd4T3ZvVFgvTzdCWUNFSlFITzJKT2pGVzJDd1FEV0hRcVg0OXVQdTJrVVpEdFZxTllk'
    b'aTdkKyttVDU5TzFoUzZlL2V1UkNKWgp1SENodWJuNXBrMmJ4R0l4R1FQWVdjT09WTXJoY0di'
    b'TW1ERnc0TUFlUFhyNCsvdHYyclJwL1BqeFk4YU1lZlhxRlpWSzFhazFETU5VCktsVmhZV0Y0'
    b'ZVBpTjJKdmU0Myt2VkppMHZ4SjBxNDdodnVsL0QvYk1MaFlabHRYcTkzSE9qNWgxcHZOMURD'
    b'a29mbURtWHdOY2MwdEUKQnFVMUJ2MWRjZy9NL0VzbitLR3Z6dloxZVZ0YVkxQWlNaGpra2Ix'
    b'L1JwUjJJcjBZb1Uxa0RJK2tPbGNqemJSdEIwTGNFeGMyNHdBVQpSWmdNa01zSm1WeWRtdG1T'
    b'QXd3TTZCUEg4STd1SlRtQU5CRXhHSXhidDI3RnhzWWFHaHE2dTd1N3VycFNxZFFqUjQ2dzJl'
    b'eTZ1cnEyCjVpdzVPYmt0YzJGZVh0NlFJVU5tejU3dDZ1cUtJQWg1OEdWc2JHeDBkSFJiclJV'
    b'WEY1TnA2aTFIaGtKaE1wazNiOTZNalkwMU1SYU0KNnRseGpzTW5PQ0gxMHBMZkdUVFZxRjNm'
    b'ZG8yWnJuNS9DQUZpN0o1RlhZTmZXMzVBaFZFbS9McXdyUnZDMVhuTFZTbTJST3ZPclZwZwpH'
    b'REFJN2JEeFpsZlpUTXNmVnpER2pmejRra3FsSWhXQkN4Y3UzTGh4Z3l4ekRRQnl1Ynl0TXRk'
    b'VHAwNDllUENnZ1VFcm03UjJYS0czCnQzZDBkRFFaNE5ST2F6azVPUkVSRWIvKyttdnJOdlVQ'
    b'RFY2OGVPbUw3Y0oyS21GMGF5WFFVR21OZnBmUHcvNFVjSU95bXZiZ1o2bE8KSTVpaDl5a1dM'
    b'ZnhHQkVBdW92ODFZd0F2WWhmRjFRbWFEd1hDWW1VeUtIOEVlTFRLQVFDZ1VRV0hEUnMyYU5B'
    b'Z3pkL2Jtck80dUxqego1OCszRlIrZ0hWazZkKzVjVFloYlc2MnAxZXJ2dnZ1dUhVT0Nwa0ZY'
    b'N3o3dDEwTDVOR2NsdTVwWDBLbnExQ0xMcnMyaXUyVVpBcERSCmlXamdWc25Uc2hRajBLeFNz'
    b'dzd2bks3T1dhcEtKWmNFRVRBZlU4eS9aUVJMZ1Vva2ZrM0lGYkl0djZqaW51QTF0UUNBV2xz'
    b'K05lS08KanZxRFNxVW1KaWIyNk5HalEybThmUk52WFYyZGc0T0RTQ1FLQ3d2VFpEbDJ1VFVB'
    b'MkxwMTZ3OC8vRUNsVWhNU0VqUW5lTFpLUzM2SgozL2RYV2pzMzBHbm9KeWhtcVpOYStERmxk'
    b'blg2R3hYaWtzN1dmejVOZGJsRnNUNnNlR3dLc25YMGdEaXQxSFNFeWVCc1dhdDYvRnkyCmN6'
    b'OWlJdUR1MkpCdzREY0F3SEc4TXlraUhjNlpaZ0Zva1JyUXRkWkk2WTlzbG93YmFKVUlBdmI5'
    b'bGJvL0txMWpMME5uaG05S240U28KNS80RWdYUnRucWIwU2ZqcldlOHVUL01uaEZjaXJBbk00'
    b'WFRBbE5EU2ZpS1JTTGo5ZzJyTkJTY2pJNFUvYmRpeVpZdWJtNXVycXl0QgpFRk9tVEFrTURK'
    b'dzVjNmFob1dGOWZUMVpoNnhEZ1ovTlp1TTRmdVhLbGRqWTJERmp4ang5K2pRNU9YbnMyTEhy'
    b'MTYrdnJLd01EdzhmCk1HQ0FXQ3ptY3JtZEtWa3JrVWk0WEc1QlFjSEpreWVycXFxMmJObmk0'
    b'dUxpNHVLQ0lNaVVLVk1DQWdLKyt1b3I3ZTZkdjV2Lzg0bFgKcjNNNkZlN1dNUk44TitMK3Z1'
    b'bC8yd3FxeVZ3aVhXbnBaM2YzVER0dnhhL1pkVzE0RitETFI5M2VOZVdpdVVIZG50aXVIQzZ6'
    b'YXZTdAo3VjllTXRZVDc3L1ZWTjc0WXc0QWdJU0VoRzNidHNYSHg1UDFBemdjenViTm02bFVx'
    b'cCtmMyt2WHI2T2lvbmJ0MmpWNDhPQnQyN1oxCmhnbG9OTnFxVmFzdVhMaEFGaFg3ODg4L0t5'
    b'b3FKazZjZU92V3JjMmJOd1BBaVJNbi9Qejg1czZkMjJIZFNwSVNFeE8zYmR2MjlPbFQKc25z'
    b'c0ZtdmJ0bTBVQ2lVZ0lDQXBLU2txS21yMzd0MkRCZzNTZEcvQ0lMdVVuT3BPTWtFSE1rRVZo'
    b'V2w3OWdtVHBsSmhGTGNWbS9JcgpkY3Noc2VHTGNuYi95S0NwbFdxcTY0cE43enVkQkVLU25Y'
    b'RjE5cTcxZEtwYW9hSzZMTi9jYWpKOE8rUmdJc3phdFo1R3dlUXFtdE95CkxTV2kxbTFuMnVj'
    b'ZDVPVGtEQmt5cExhMjl0cTFhMnExbXMvbjM3dDNiOVdxVllNSEQ0Nk9qdTdDNlRZclY2N2N2'
    b'WHQzYUdob1RFek0KbmoxN3BrK2YzcjkvLzlMUzBzakl5SEhqeHVuYVdtNXU3dURCZzJ0cWFt'
    b'SmlZZ0JBWDEvLzBhTkh5NWN2SHpod1lFeE16TWNXcW05MwpQajF3THIzOU51bTBqclFERmwx'
    b'SitvNXBGSXc4M1VZbm10YnZCZWs3cGxQVjA0T2Y2d3FmSHZ5YzlCMXJuOHpkZVpyUjd4bU5n'
    b'Z0VBCms2YWEycWRUY0JjWGwvejhmS0ZRR0JJU1FwNTF0MnpaTXFsVWV2djI3YTZkYjdSejU4'
    b'NzYrdnByMTY3VjE5ZHYzNzZkeitkblpXV0oKUktJdWNBQUFPRHM3NStmblYxZFhEeG8waU96'
    b'ZWtpVkxwRkxwM2J0M1c3VlIvcnc0UUkvVGNSSndCMHhBRGlKSnZld0tkZTIwTnFTWAp2YzV3'
    b'N1FUV0xqemR6NzRyVDllVUNiMXg0MFpjWEZ3bkpiVjJpRHpzL3ZidDIwS2hNQ2twQ1VHUUxu'
    b'c2FXM1NQTEZ6VlR2ZDRiTnFJClBsYmRaUUp0a1lXaCs2RUcyZ1ZSR2RUL09senJQRzlkTzUr'
    b'V2xwYVptUmtYRjlkTy9RZWRpTlFNcjF5NThrbGF5OGpJU0U5UGYvRGcKUVllaDZEWm0zTzR5'
    b'Z1haWkNYSkx0aFZVVCt5ZHJEbVF0bFc5ZjJMdlpMSWljb0hRcUFYY3pyaDZZdSttdzNJL0pn'
    b'OXRlRFcvVmJoNwoyM0JQeTlLSnZaTnRCZVRUdGVCQ0l3Q3dOeFpPN0oyc09XdTNIZnJ0dDk5'
    b'SUlmL1VxVk9md0o1V1drcE8vOUdqUjd0UWxxQ3Q3alUwCk5KdzhlYkw5T3l0RURkMFZER3Na'
    b'TkllL0duUEVaa1RNNGpDVisyZEUwU2dZamlQZi9CRisrUDZBRnZmUERubDZaRTRrZVVEUjhy'
    b'TmgKWmJYNjU3NDkwbWcwUFRUSGtDUDdkZG81RWo3L3hMUmpEL3ExZ004ZCtPVHc3RWdVSlZR'
    b'WVpjbnBTVFZTenRsRmpkVit2and3ejBSUAovTXZVOHpRS2h1SG8xOGVublhqWXNqVFgvTUdQ'
    b'RG4xMWxvUi85K2VYRWdYajlJSkdhMjdZdnZuVy9KcGQ0UmVvS0k3aDZKeWpNMDQ5Cjd2T3hZ'
    b'Tmo0MXJXMVZsWldVcWtVcUR4bmUvUHM3S3hXdFRpQ2FQUFlTWmxjeldZMmFWN3IxcTM3K2Vl'
    b'ZnlkK1JrWkhoNFZQYjBRcVQKTW9XK3J2eFdxOCtwMURnRlJlcnI2Nnl0clNVU0NRQTRPanJt'
    b'NU9TZ0tOcmlpWTB2SWxZNmp2dExWSzlvWHpEc2dBa1VLSVV4cUpKQgpVNnN3U2t5eXp3VC8x'
    b'NXFqYW1RS3VtWWNteVRCNEJjOGxsd3pSbGVTZkVmMVNLWFQxQ28xNWRvcm4vRmFjSW1jY2Zw'
    b'Snl4cnQwL3M5CjV6SVZIK0RJbGNTZW8zM2YwS2lZVWsyNS90cG52TjhyemRpSkc1aVJUd05i'
    b'U29MOW4zTVlUZkRMaVQzSCtMNmhVVEdGaWhxYjRqWE8KNzdVR1hpOWpub2x2aEg5MWY3OUEw'
    b'R3pOWEw5K1BhbklnZDFYVUpkMi9zaXFzTEJXU3JWdE9aNGNOc1RCemE0VnBlUGJuVStYaEh1'
    b'VAptZUZDb2REVjFWVVRlZUR0N2UweGFzK2FXYjQ5V3FzckpsZGlYcFBPYjV6dlAzVmtLMTcx'
    b'SHc0bENBeVl0VGtYTjI3Y3FQbGpWRlRVCnFER2YrMDY5R0xHbS85Q0FKcnV0UW9sTlduMDMr'
    b'bEZCaDlwQkIwendUNkNsbjI4K3ZuRVE5VVA5cWZ6OGZFOVBUN2xjRHVhaFlERVcKc0FZVDhj'
    b'WDhsSnN0cXRSZmYxSTRjZVVkWDFmK2pYMGpEZldhaVdZUGtrcEhmaHZyWXF0Lzg3ZFFjd0Y3'
    b'L3Z6NVI0NGMwU3k5WURrTwp6RWJhVy9DaWZ4M2g1V2pVZ2dPK1dIWG4ydU5DZlM3OTVtK2hR'
    b'ZDdOWE1DLy9aMjI5SmRuQ0FKb3lYbGx5VjFOeEp1bHRiMzN1UDAzCm41VWlDSHc1M0NuOE15'
    b'Y3pQaXMxVC9STDVKdjAvSTRERFA5bEFnQUFjLzNaL3U3R2EyYjVEZ3UwWk5BcEkwSW4zSDcy'
    b'RGt5R0F1L0QKU1FHRTJzZEtmbkJqdUkrekVRQmt2YS85SXlibnlLVk1EQ2NBd05YVzRJYzV2'
    b'cVA3MnhydzZJWGxrcFBSMmJ0T3AwZ2IxQUJnTG1CUApDRGI0ZmNjaVhGRU5WQzV3SE1CNElI'
    b'RHN5Rlk1TE9xM2s3Mm1qblJ5dE5JVDFTa2VKSlZ0UFpHYythNVJEbVhRS2ZQR3U0ME5zZVhy'
    b'Ck03UGUxeDY5blBVZ1NVc09rMWRBWFFxbzZvRE9CNlBlUU8zNjZVSjBHb29JM2ZzaTNUdjQ0'
    b'ZjhBRXlnL1pPclFLS0RDdWo2YVNoWCsKLzkzcjAya29xa1RRZi9oS29PM2RWWFVqeVB2L1J3'
    b'NkF6cFMxL1NkUUo4OGUrVDlNL3pMQnYvUXZFd0FRL3pMQnYwenc3M2J3THhQQQpQNTRIL21X'
    b'Q2Z3bmcvd0cvanV3cU1lSmJhd0FBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VBTWpBeU15MHdP'
    b'UzB3TWxReE56b3pNVG95Ck9Dc3dNRG93TUl1UjBBY0FBQUFsZEVWWWRHUmhkR1U2Ylc5a2FX'
    b'WjVBREl3TWpNdE1Ea3RNREpVTVRjNk16RTZNamdyTURBNk1ERDYKekdpN0FBQUFBRWxGVGtT'
    b'dVFtQ0MKIgogICAgICAgaWQ9ImltYWdlMTAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'FR_PDL')

FR_PDL = b64_FR_PDL
index.append("FR_PDL")
index.append("France Pays-de-la-Loire")
catalog["FR_PDL"] = FR_PDL
catalog["France Pays-de-la-Loire"] = FR_PDL
country["France Pays-de-la-Loire"] = ('FR_PDL', '', 1)
lookup["FR_PDL"] = ('FR_PDL', '', 'France Pays-de-la-Loire', 1)
lookup["France Pays-de-la-Loire"] = ('FR_PDL', '', 'France Pays-de-la-Loire', 1)
details["FR_PDL"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["FR_PDL"] = ('FR_PDL', 'France Pays-de-la-Loire', 1)
regional["France Pays-de-la-Loire"] = ('FR_PDL', 'France Pays-de-la-Loire', 1)
#----------------------------------------------------------------------
b64_GA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmU3MDAiIGQ9Ik02NDAgNDgwSDBWMGg2NDB6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjMzZhMTAwIiBkPSJNNjQwIDE2MEgwVjBoNjQweiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iIzAwNmRiYyIgZD0iTTY0MCA0ODBIMFYzMjBoNjQweiIvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'GA')

GA = b64_GA
index.append("GA")
index.append("GAB")
index.append("Gabon")
catalog["GA"] = GA
catalog["GAB"] = GA
catalog["Gabon"] = GA
country["Gabon"] = ('GA', 'GAB', 0)
lookup["GA"] = ('GA', 'GAB', 'Gabon', 0)
lookup["Libreville Gabon"] = ('GA', 'GAB', 'Gabon', 0)
lookup["GAB"] = ('GA', 'GAB', 'Gabon', 0)
lookup["Gabon"] = ('GA', 'GAB', 'Gabon', 0)
details["GA"] = {"continent":"Africa","capital":"Libreville","currency":"CFA Franc BEAC","web":".ga","lang":"fr-GA","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_GB = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdiIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAxMjE2OSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI0ZGRiIgZD0ibTc1IDAgMjQ0IDE4'
    b'MUw1NjIgMGg3OHY2Mkw0MDAgMjQxbDI0MCAxNzh2NjFoLTgwTDMyMCAzMDEgODEgNDgwSDB2'
    b'LTYwbDIzOS0xNzhMMCA2NFYwaDc1eiIvPgogIDxwYXRoIGZpbGw9IiNDODEwMkUiIGQ9Im00'
    b'MjQgMjgxIDIxNiAxNTl2NDBMMzY5IDI4MWg1NXptLTE4NCAyMCA2IDM1TDU0IDQ4MEgwbDI0'
    b'MC0xNzl6TTY0MCAwdjNMMzkxIDE5MWwyLTQ0TDU5MCAwaDUwek0wIDBsMjM5IDE3NmgtNjBM'
    b'MCA0MlYweiIvPgogIDxwYXRoIGZpbGw9IiNGRkYiIGQ9Ik0yNDEgMHY0ODBoMTYwVjBIMjQx'
    b'ek0wIDE2MHYxNjBoNjQwVjE2MEgweiIvPgogIDxwYXRoIGZpbGw9IiNDODEwMkUiIGQ9Ik0w'
    b'IDE5M3Y5Nmg2NDB2LTk2SDB6TTI3MyAwdjQ4MGg5NlYwaC05NnoiLz4KPC9zdmc+Cg==', 'GB')

GB = b64_GB
index.append("GB")
index.append("GBR")
index.append("United Kingdom")
catalog["GB"] = GB
catalog["GBR"] = GB
catalog["United Kingdom"] = GB
country["United Kingdom"] = ('GB', 'GBR', 0)
lookup["GB"] = ('GB', 'GBR', 'United Kingdom', 0)
lookup["London United Kingdom"] = ('GB', 'GBR', 'United Kingdom', 0)
lookup["GBR"] = ('GB', 'GBR', 'United Kingdom', 0)
lookup["United Kingdom"] = ('GB', 'GBR', 'United Kingdom', 0)
details["GB"] = {"continent":"Europe","capital":"London","currency":"Pound Sterling","web":".uk","lang":"en-GB | cy-GB | gd","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_GB_ENG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdiLWVuZyIgdmlld0JveD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9'
    b'Ik0wIDBoNjQwdjQ4MEgweiIvPgogIDxwYXRoIGZpbGw9IiNjZTExMjQiIGQ9Ik0yODEuNiAw'
    b'aDc2Ljh2NDgwaC03Ni44eiIvPgogIDxwYXRoIGZpbGw9IiNjZTExMjQiIGQ9Ik0wIDIwMS42'
    b'aDY0MHY3Ni44SDB6Ii8+Cjwvc3ZnPgo=', 'GB_ENG')

GB_ENG = b64_GB_ENG
index.append("GB_ENG")
index.append("United Kingdom England")
catalog["GB_ENG"] = GB_ENG
catalog["United Kingdom England"] = GB_ENG
country["United Kingdom England"] = ('GB_ENG', '', 1)
lookup["GB_ENG"] = ('GB_ENG', '', 'United Kingdom England', 1)
lookup["London United Kingdom England"] = ('GB_ENG', '', 'United Kingdom England', 1)
lookup["United Kingdom England"] = ('GB_ENG', '', 'United Kingdom England', 1)
details["GB_ENG"] = {"continent":"Europe","capital":"London","currency":"","web":"","lang":"","tz":"±00:00","altname":""}
regional["GB_ENG"] = ('GB_ENG', 'United Kingdom England', 1)
regional["United Kingdom England"] = ('GB_ENG', 'United Kingdom England', 1)
#----------------------------------------------------------------------
b64_GB_NIR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1nYi1uaXIiIHZp'
    b'ZXdCb3g9IjAgMCA2NDAgNDgwIj4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0'
    b'ODBIMHoiLz4KICA8cmVjdCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHJ4PSIw'
    b'IiByeT0iMCIvPgogIDxyZWN0IGlkPSJnYi1uaXItYSIgd2lkdGg9IjY0MCIgaGVpZ2h0PSI5'
    b'NiIgeT0iMTkyIiBmaWxsPSIjYzAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHJ4PSIwIiByeT0i'
    b'MCIvPgogIDx1c2UgeGxpbms6aHJlZj0iI2diLW5pci1hIiB3aWR0aD0iNjAwIiBoZWlnaHQ9'
    b'IjMwMCIgdHJhbnNmb3JtPSJtYXRyaXgoMCAuNzUgLTEgMCA1NjAgMCkiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZWJlYWUzIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIuNSIgZD0iTTM1NS4yIDE0Ni42YzMtNC44IDEuMi04LTMuNC04LjkgMCAwLTE0'
    b'LjkgNC44LTMxIDUuMy0xNiAuNS0zNS00LTM1LTQtMy41IDIuMS0yLjcgNy4yLTEgMTAuNCAw'
    b'IDAgMTYuOCA1LjYgMzYgNWExMTEgMTExIDAgMCAwIDMwLjEtNS41YzMuNy0xLjIgNC4zLTIu'
    b'MiA0LjMtMi4zeiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzE2MTExMSIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjYiIGQ9Im0zMjAgMzU3LjYtMzAuOS02NC4yLTcwLjkgNS40IDQwLTU4'
    b'LjgtNDAtNTguOCA3MSA1LjQgMzAuOC02NC4xIDMwLjkgNjQgNzAuOS01LjMtNDAgNTguOCA0'
    b'MCA1OC44LTcxLTUuNHoiLz4KICA8cGF0aCBmaWxsPSIjYjAyMzIwIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjMiIGQ9Ik0zMTkuNSAxMjIu'
    b'MmMzOC44IDYuNCAzNy40IDguMiAzNy40IDguMmwxMC4xLTMwLjJzMS4xLTYtMS43LTkuNi0x'
    b'MC41LTEuNi0xMC41LTEuNi0xLTQuOS00LjUtNmMtMy40LTEuMi0xNiA0LjUtMjAgNS44LTQg'
    b'MS4zLTYgMi41LTExLjUgMi40LTUuNSAwLTE1LjQtNS0xNy4zLTYtMS43LS45LTQuNC0xLjgt'
    b'Ni45LTEuNy0yLjQgMC01IC43LTYuMyAyLjQtMS4yIDEuNy0xLjIgMy45LTEuMiAzLjlzLTIt'
    b'MS4zLTUuMi0xLjMtNSAuNC02LjUgMi4xYy0xLjUgMS43LTMuNCA2LjUtMy40IDYuNWwzLjYg'
    b'OC4yLjIgMTEuMyA3LjUgMTIgMzYuMi02LjR6Ii8+CiAgPHBhdGggZmlsbD0iI2ViZWFlMyIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjUiIGQ9'
    b'Ik0zNTUuNyAxMzkuM3MyIDIuMyAxLjkgMy4yYy0uMS44LTEgMS41LTEgMS41cy43LjYuNSAx'
    b'LjVjLS4xIDEtMS40IDEtMS40IDFzLjMuOC0uNSAxLjJjLS43LjQtMy44IDEtMy44IDFzLTE1'
    b'LTQuMi0zMS00LjItMzUgNS4yLTM1IDUuMi0yLS43LTItMmMtLjItMS4yLjEtMi4xLjEtMi4x'
    b'cy0xIDAtMS4zLS45Yy0uNC0xLjMuMS0yLjMuMS0yLjNzLS43LjIuMS0xLjVjLjYtMS4zIDEu'
    b'NS0xLjcgMS41LTEuN3MxNi44LTYgMzYtNi4xYzE5LjEgMCAzNS44IDYgMzUuOCA2LjJ6Ii8+'
    b'CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMSIg'
    b'ZD0iTTI3Ni4yIDEwMS41cy0uNi0yLjIuOC00LjFhNC4zIDQuMyAwIDAgMSA0LjctMS40Yy44'
    b'LjQuNyAxLjMgMS43IDEuNSAxIC4zIDEuOC0uNSAxLjgtLjUiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZmMwIiBmaWxsLW9wYWNpdHk9Ii45IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Im0zNjkuOCAxMDYuNi01LjggMTItMi4zLjRzLTEu'
    b'NC0uOC01LjQtLjVjLTIuOC4yLTMuNyAxLTMuNyAxbDUuMi0xMnMuNCAyLjUgMSA0Yy44IDIg'
    b'My43IDMuNyAzLjcgMy43cy40LTIuMy0uNC01YTU1LjkgNTUuOSAwIDAgMC0yLjgtNy4zbDEw'
    b'LjUgMy43eiIvPgogIDxwYXRoIGZpbGw9IiMxMjExMTYiIHN0cm9rZT0iIzEyMTExNiIgc3Ry'
    b'b2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zMTYuNSA2OS4y'
    b'aDYuNXYyNy43aC02LjV6Ii8+CiAgPHBhdGggZmlsbD0iI2Y2Y2ExZiIgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBzdHJva2U9IiMwMDAiIGQ9Im0yNzYuNiAxMjAuMiA0LjEgOXMxNy45LTcgMzgu'
    b'OS02LjhjMzEuNS4yIDQwLjUgNi41IDQwLjUgNi41bDQuNi0xMS4xLTMuNSAyLTMuNiAyLjMt'
    b'NCAxLjUtNS0uMy00LjQtMy4yLTIuMi00LjctMy43IDMuNC02LjYgMS40LTYuNC0xLjYtNS42'
    b'LTcuMXMtNC4yIDcuOS05LjYgOC40Yy03LjcuNi0xMi4xLTMuNy0xMi4xLTMuN3MtMi45IDYu'
    b'NC03LjYgNy41Yy03LjUgMS45LTEzLjctMy41LTEzLjgtMy41eiIvPgogIDxnIHN0cm9rZS13'
    b'aWR0aD0iMi4yIj4KICAgIDxwYXRoIGZpbGw9IiNlZWUiIHN0cm9rZT0iIzFlMWUxZSIgc3Ry'
    b'b2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zNDguNCA2NS43'
    b'YzAgMS44LTEuNCAzLjQtMy4zIDMuNGEzLjQgMy40IDAgMCAxLTMuNC0zLjQgMy40IDMuNCAw'
    b'IDAgMSAzLjQtMy41IDMuNCAzLjQgMCAwIDEgMy4zIDMuNCIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2EzYWZiOCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzQzLjUgNjcuNHMyLjcgMCAzLTEu'
    b'MWMuMy0xLjItLjItMi42LS4yLTIuNnMxLjMgMS40IDEgMi41Yy0uNCAxLjEtLjggMS40LTEu'
    b'NyAxLjdhMyAzIDAgMCAxLTItLjV6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZWVlIiBzdHJva2U9'
    b'IiMxZTFlMWUiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4yIiBk'
    b'PSJNMzQwLjMgNjkuNWMwIDEuOC0xLjUgMy40LTMuNCAzLjRhMy40IDMuNCAwIDAgMS0zLjQt'
    b'My40QTMuNCAzLjQgMCAwIDEgMzM3IDY2YTMuNCAzLjQgMCAwIDEgMy40IDMuMyIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2EzYWZiOCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzM1LjMgNzEu'
    b'MnMyLjggMCAzLTEuMWMuMy0xLjEtLjItMi42LS4yLTIuNnMxLjMgMS41IDEgMi42Yy0uNCAx'
    b'LS44IDEuNC0xLjcgMS42YTMgMyAwIDAgMS0yLS41eiIvPgogICAgPHBhdGggZmlsbD0iI2Vl'
    b'ZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lk'
    b'dGg9IjEuMiIgZD0iTTM1OCA2My40YzAgMS45LTEuNiAzLjQtMy40IDMuNGEzLjQgMy40IDAg'
    b'MCAxLTMuNC0zLjQgMy40IDMuNCAwIDAgMSAzLjMtMy40IDMuNCAzLjQgMCAwIDEgMy40IDMu'
    b'NCIvPgogICAgPHBhdGggZmlsbD0iI2EzYWZiOCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJN'
    b'MzUzIDY1LjJzMi43IDAgMy0xLjJjLjMtMS4xLS4yLTIuNS0uMi0yLjVzMS4zIDEuNCAxIDIu'
    b'NWMtLjQgMS4xLS44IDEuNC0xLjcgMS42YTMgMyAwIDAgMS0yLS40eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBz'
    b'dHJva2Utd2lkdGg9IjEuMiIgZD0iTTM2OC42IDY1LjZjMCAxLjgtMS41IDMuNC0zLjMgMy40'
    b'YTMuNCAzLjQgMCAwIDEtMy40LTMuNCAzLjQgMy40IDAgMCAxIDMuNC0zLjQgMy40IDMuNCAw'
    b'IDAgMSAzLjMgMy4zIi8+CiAgICA8cGF0aCBmaWxsPSIjYTNhZmI4IiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIGQ9Ik0zNjMuNyA2Ny4zczIuNyAwIDMtMS4xYy4zLTEuMi0uMi0yLjYtLjItMi42'
    b'czEuMyAxLjQgMSAyLjZjLS40IDEtLjggMS4zLTEuNyAxLjZhMyAzIDAgMCAxLTIuMS0uNXoi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiNlZWUiIHN0cm9rZT0iIzFlMWUxZSIgc3Ryb2tlLWxpbmVq'
    b'b2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zNzYuOCA3Mi4zYzAgMS44LTEu'
    b'NSAzLjQtMy40IDMuNGEzLjQgMy40IDAgMCAxLTMuNC0zLjQgMy40IDMuNCAwIDAgMSAzLjQt'
    b'My40IDMuNCAzLjQgMCAwIDEgMy40IDMuMyIvPgogICAgPHBhdGggZmlsbD0iI2EzYWZiOCIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzcxLjkgNzRzMi43IDAgMy0xLjFjLjItMS4xLS4y'
    b'LTIuNi0uMi0yLjZzMS4zIDEuNS45IDIuNmMtLjQgMS0uNyAxLjQtMS43IDEuNi0uNi4xLTEu'
    b'NS0uMS0yLS41eiIvPgogICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBz'
    b'dHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTM4MC4zIDgz'
    b'LjNjMCAxLjktMS41IDMuNC0zLjQgMy40YTMuNCAzLjQgMCAwIDEtMy4zLTMuNCAzLjQgMy40'
    b'IDAgMCAxIDMuMy0zLjQgMy40IDMuNCAwIDAgMSAzLjQgMy40Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYTNhZmI4IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zNzUuNCA4NXMyLjcgMCAzLTEu'
    b'MWMuMi0xLjEtLjItMi42LS4yLTIuNnMxLjMgMS41LjkgMi42Yy0uNCAxLS43IDEuNC0xLjcg'
    b'MS42YTMgMyAwIDAgMS0yLS41eiIvPgogICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIj'
    b'MWUxZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0i'
    b'TTM3OSA5NC40YzAgMi0xLjUgMy40LTMuNCAzLjRhMy40IDMuNCAwIDAgMS0zLjMtMy4zIDMu'
    b'NCAzLjQgMCAwIDEgMy4zLTMuNSAzLjQgMy40IDAgMCAxIDMuNCAzLjQiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNhM2FmYjgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTM3NCA5Ni4yczIuOCAw'
    b'IDMtMS4yYy4zLTEtLjEtMi41LS4xLTIuNXMxLjMgMS40LjkgMi41LS43IDEuNC0xLjcgMS42'
    b'YTMgMyAwIDAgMS0yLS40eiIvPgogICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUx'
    b'ZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTM3'
    b'NCAxMDQuMmMwIDEuOS0xLjUgMy40LTMuMyAzLjRhMy40IDMuNCAwIDAgMS0zLjQtMy40IDMu'
    b'NCAzLjQgMCAwIDEgMy40LTMuNCAzLjQgMy40IDAgMCAxIDMuMyAzLjQiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNhM2FmYjgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTM2OS4xIDEwNnMyLjcg'
    b'MCAzLTEuMmMuMy0xLS4yLTIuNS0uMi0yLjVzMS4zIDEuNCAxIDIuNWMtLjQgMS4xLS44IDEu'
    b'NC0xLjcgMS42YTMgMyAwIDAgMS0yLS40eiIvPgogICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ry'
    b'b2tlPSIjMWUxZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEu'
    b'MiIgZD0iTTMzMi4zIDcyLjRjMCAxLjktMS41IDMuNC0zLjMgMy40YTMuNCAzLjQgMCAwIDEt'
    b'My40LTMuNCAzLjQgMy40IDAgMCAxIDMuMy0zLjQgMy40IDMuNCAwIDAgMSAzLjQgMy40Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjYTNhZmI4IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zMjcu'
    b'NCA3NC4yczIuNyAwIDMtMS4yYy4zLTEuMS0uMi0yLjUtLjItMi41czEuMyAxLjQgMSAyLjVj'
    b'LS40IDEuMS0uOCAxLjQtMS43IDEuNi0uNy4yLTEuNiAwLTIuMS0uNHoiLz4KICAgIDxnIHN0'
    b'cm9rZS13aWR0aD0iMi43Ij4KICAgICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUx'
    b'ZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTMy'
    b'Mi4xIDcxLjVhMi44IDIuOCAwIDAgMS0yLjggMi45IDIuOCAyLjggMCAwIDEtMi44LTIuOSAy'
    b'LjggMi44IDAgMCAxIDIuOC0yLjggMi44IDIuOCAwIDAgMSAyLjggMi44Ii8+CiAgICAgIDxw'
    b'YXRoIGZpbGw9IiNhM2FmYjgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMxOCA3M3MyLjMg'
    b'MCAyLjUtMWMuMy0uOS0uMS0yLS4xLTJzMSAxLjEuOCAyYy0uNCAxLS43IDEuMi0xLjQgMS40'
    b'YTIuNSAyLjUgMCAwIDEtMS44LS40eiIvPgogICAgPC9nPgogICAgPGcgc3Ryb2tlLXdpZHRo'
    b'PSIyLjciPgogICAgICA8cGF0aCBmaWxsPSIjZWVlIiBzdHJva2U9IiMxZTFlMWUiIHN0cm9r'
    b'ZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNMzIyLjIgNzVhMi44'
    b'IDIuOCAwIDAgMS0yLjggMyAyLjggMi44IDAgMCAxLTIuOC0zIDIuOCAyLjggMCAwIDEgMi44'
    b'LTIuOCAyLjggMi44IDAgMCAxIDIuOCAyLjgiLz4KICAgICAgPHBhdGggZmlsbD0iI2EzYWZi'
    b'OCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzE4IDc2LjVzMi4zIDAgMi42LTFjLjItLjgt'
    b'LjItMi0uMi0yczEgMS4yLjggMmMtLjMgMS0uNiAxLjItMS40IDEuNGEyLjUgMi41IDAgMCAx'
    b'LTEuNy0uNHoiLz4KICAgIDwvZz4KICAgIDxnIHN0cm9rZS13aWR0aD0iMi43Ij4KICAgICAg'
    b'PHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJva2UtbGluZWpvaW49InJv'
    b'dW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTMyMi40IDgwLjNhMi44IDIuOCAwIDAgMS0y'
    b'LjggMi44IDIuOCAyLjggMCAwIDEtMi45LTIuOCAyLjggMi44IDAgMCAxIDIuOS0yLjkgMi44'
    b'IDIuOCAwIDAgMSAyLjggMi45Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiNhM2FmYjgiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgZD0iTTMxOC4zIDgxLjhzMi4yIDAgMi41LTFjLjItMS0uMi0yLjEt'
    b'LjItMi4xczEgMS4yLjggMmMtLjMgMS0uNiAxLjMtMS40IDEuNGEyLjUgMi41IDAgMCAxLTEu'
    b'Ny0uM3oiLz4KICAgIDwvZz4KICAgIDxnIHN0cm9rZS13aWR0aD0iMi41Ij4KICAgICAgPHBh'
    b'dGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5k'
    b'IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTMyMi43IDg1LjhhMyAzIDAgMCAxLTMgMy4xIDMg'
    b'MyAwIDAgMS0zLjEtMyAzIDMgMCAwIDEgMy0zLjIgMyAzIDAgMCAxIDMgMy4xIi8+CiAgICAg'
    b'IDxwYXRoIGZpbGw9IiNhM2FmYjgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMxOC4yIDg3'
    b'LjRzMi41IDAgMi43LTEtLjItMi4zLS4yLTIuMyAxLjIgMS4zLjkgMi4zYy0uNCAxLS43IDEu'
    b'Mi0xLjUgMS40YTIuNiAyLjYgMCAwIDEtMS45LS40eiIvPgogICAgPC9nPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBz'
    b'dHJva2Utd2lkdGg9IjEuMiIgZD0iTTMyMyA5My4zYzAgMS44LTEuNSAzLjQtMy40IDMuNGEz'
    b'LjQgMy40IDAgMCAxLTMuMy0zLjQgMy40IDMuNCAwIDAgMSAzLjMtMy41IDMuNCAzLjQgMCAw'
    b'IDEgMy40IDMuNCIvPgogICAgPHBhdGggZmlsbD0iI2EzYWZiOCIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNMzE4IDk1czIuOCAwIDMtMS4xYy4zLTEuMS0uMS0yLjYtLjEtMi42czEuMyAx'
    b'LjUuOSAyLjZjLS40IDEtLjcgMS40LTEuNyAxLjZhMyAzIDAgMCAxLTItLjV6Ii8+CiAgICA8'
    b'ZyBzdHJva2Utd2lkdGg9IjIuNCI+CiAgICAgIDxwYXRoIGZpbGw9IiNlZWUiIHN0cm9rZT0i'
    b'IzFlMWUxZSIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9'
    b'Ik0zMjIuNyAxMDguNWMwIDEuOC0xLjQgMy4yLTMuMiAzLjJhMy4yIDMuMiAwIDAgMS0zLjIt'
    b'My4yYzAtMS43IDEuNC0zLjIgMy4yLTMuMmEzLjIgMy4yIDAgMCAxIDMuMiAzLjIiLz4KICAg'
    b'ICAgPHBhdGggZmlsbD0iI2EzYWZiOCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzE4IDEx'
    b'MC4yczIuNiAwIDIuOC0xLjFjLjMtMS0uMS0yLjQtLjEtMi40czEuMiAxLjMuOCAyLjRjLS4z'
    b'IDEtLjcgMS4zLTEuNSAxLjUtLjYuMS0xLjUtLjEtMi0uNHoiLz4KICAgIDwvZz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNlZWUiIHN0cm9rZT0iIzFlMWUxZSIgc3Ryb2tlLWxpbmVqb2luPSJyb3Vu'
    b'ZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zMTMuNiA3Mi4zYzAgMS45LTEuNiAzLjQtMy40'
    b'IDMuNGEzLjQgMy40IDAgMCAxLTMuNC0zLjQgMy40IDMuNCAwIDAgMSAzLjQtMy40IDMuNCAz'
    b'LjQgMCAwIDEgMy40IDMuNCIvPgogICAgPHBhdGggZmlsbD0iI2EzYWZiOCIgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBkPSJNMzA4LjYgNzRzMi43IDAgMy0xYy4zLTEuMi0uMi0yLjYtLjItMi42'
    b'czEuMyAxLjQgMSAyLjVjLS40IDEuMS0uOCAxLjQtMS43IDEuNmEzIDMgMCAwIDEtMi0uNHoi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiNlZWUiIHN0cm9rZT0iIzFlMWUxZSIgc3Ryb2tlLWxpbmVq'
    b'b2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zMDUuMiA2OWMwIDEuOS0xLjUg'
    b'My40LTMuNCAzLjRhMy40IDMuNCAwIDAgMS0zLjMtMy40IDMuNCAzLjQgMCAwIDEgMy4zLTMu'
    b'NCAzLjQgMy40IDAgMCAxIDMuNCAzLjQiLz4KICAgIDxwYXRoIGZpbGw9IiNhM2FmYjgiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMwMC4zIDcwLjhzMi43IDAgMy0xLjJjLjItMS0uMi0y'
    b'LjUtLjItMi41czEuMyAxLjQgMSAyLjVjLS41IDEuMS0uOCAxLjQtMS44IDEuNi0uNi4yLTEu'
    b'NSAwLTItLjR6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZWVlIiBzdHJva2U9IiMxZTFlMWUiIHN0'
    b'cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4yIiBkPSJNMjk3LjIgNjUu'
    b'M2MwIDEuOC0xLjUgMy40LTMuMyAzLjRhMy40IDMuNCAwIDAgMS0zLjQtMy40IDMuNCAzLjQg'
    b'MCAwIDEgMy4zLTMuNSAzLjQgMy40IDAgMCAxIDMuNCAzLjQiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNhM2FmYjgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTI5Mi4zIDY3czIuNyAwIDMtMS4x'
    b'Yy4zLTEuMS0uMi0yLjYtLjItMi42czEuMyAxLjUgMSAyLjZjLS40IDEtLjggMS40LTEuNyAx'
    b'LjZhMyAzIDAgMCAxLTIuMS0uNXoiLz4KICAgIDxwYXRoIGZpbGw9IiNlZWUiIHN0cm9rZT0i'
    b'IzFlMWUxZSIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9'
    b'Ik0yODggNjMuM2MwIDEuOS0xLjQgMy40LTMuMyAzLjRhMy40IDMuNCAwIDAgMS0zLjQtMy40'
    b'IDMuNCAzLjQgMCAwIDEgMy40LTMuNSAzLjQgMy40IDAgMCAxIDMuNCAzLjQiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNhM2FmYjgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTI4My4xIDY1czIu'
    b'NyAwIDMtMS4xYy4zLTEuMS0uMi0yLjYtLjItMi42czEuMyAxLjUgMSAyLjZjLS40IDEtLjgg'
    b'MS40LTEuNyAxLjZhMyAzIDAgMCAxLTItLjV6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZWVlIiBz'
    b'dHJva2U9IiMxZTFlMWUiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0i'
    b'MS4yIiBkPSJNMjc3LjIgNjUuOGMwIDItMS41IDMuNC0zLjMgMy41YTMuNCAzLjQgMCAwIDEt'
    b'My40LTMuNCAzLjQgMy40IDAgMCAxIDMuNC0zLjUgMy40IDMuNCAwIDAgMSAzLjMgMy40Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjYTNhZmI4IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yNzIu'
    b'MyA2Ny42czIuNyAwIDMtMS4xYy4zLTEuMi0uMi0yLjYtLjItMi42czEuMyAxLjQgMSAyLjVj'
    b'LS40IDEuMS0uOCAxLjQtMS43IDEuN2EzIDMgMCAwIDEtMi0uNXoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNlZWUiIHN0cm9rZT0iIzFlMWUxZSIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjIiIGQ9Ik0yNjkuNiA3My41YzAgMS45LTEuNSAzLjQtMy40IDMuNGEz'
    b'LjQgMy40IDAgMCAxLTMuMy0zLjQgMy40IDMuNCAwIDAgMSAzLjMtMy40IDMuNCAzLjQgMCAw'
    b'IDEgMy40IDMuNCIvPgogICAgPHBhdGggZmlsbD0iI2EzYWZiOCIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNMjY0LjcgNzUuMnMyLjcgMCAzLTEuMWMuMi0xLjEtLjItMi42LS4yLTIuNnMx'
    b'LjMgMS41LjkgMi42Yy0uNCAxLS43IDEuNC0xLjcgMS42YTMgMyAwIDAgMS0yLS41eiIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJva2UtbGluZWpvaW49'
    b'InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTI2Ni40IDg0LjJjMCAxLjktMS41IDMu'
    b'NC0zLjMgMy40YTMuNCAzLjQgMCAwIDEtMy40LTMuNCAzLjQgMy40IDAgMCAxIDMuMy0zLjQg'
    b'My40IDMuNCAwIDAgMSAzLjQgMy4zIi8+CiAgICA8cGF0aCBmaWxsPSIjYTNhZmI4IiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yNjEuNSA4NnMyLjctLjEgMy0xLjJjLjMtMS4xLS4yLTIu'
    b'Ni0uMi0yLjZzMS4zIDEuNSAxIDIuNmMtLjQgMS0uOCAxLjQtMS43IDEuNmEzIDMgMCAwIDEt'
    b'Mi4xLS41eiIvPgogICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJv'
    b'a2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTI2Ny44IDk1LjNj'
    b'MCAyLTEuNSAzLjUtMy4zIDMuNWEzLjQgMy40IDAgMCAxLTMuNC0zLjQgMy40IDMuNCAwIDAg'
    b'MSAzLjMtMy41IDMuNCAzLjQgMCAwIDEgMy40IDMuNCIvPgogICAgPHBhdGggZmlsbD0iI2Ez'
    b'YWZiOCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjYyLjkgOTcuMXMyLjcgMCAzLTEuMmMu'
    b'My0xLS4yLTIuNS0uMi0yLjVzMS4zIDEuNCAxIDIuNWMtLjQgMS4xLS44IDEuNC0xLjcgMS43'
    b'YTMgMyAwIDAgMS0yLS41eiIvPgogICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUx'
    b'ZTFlIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTI3'
    b'MyAxMDUuNWMwIDEuOC0xLjUgMy40LTMuNCAzLjRhMy40IDMuNCAwIDAgMS0zLjMtMy40IDMu'
    b'NCAzLjQgMCAwIDEgMy4zLTMuNSAzLjQgMy40IDAgMCAxIDMuNCAzLjQiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNhM2FmYjgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTI2OCAxMDcuMnMyLjgg'
    b'MCAzLTEuMWMuMy0xLjEtLjEtMi42LS4xLTIuNnMxLjMgMS40IDEgMi41Yy0uNSAxLjEtLjgg'
    b'MS40LTEuNyAxLjdhMyAzIDAgMCAxLTIuMS0uNXoiLz4KICAgIDxnIHN0cm9rZS13aWR0aD0i'
    b'Mi44Ij4KICAgICAgPHBhdGggZmlsbD0iI2VlZSIgc3Ryb2tlPSIjMWUxZTFlIiBzdHJva2Ut'
    b'bGluZWpvaW49InJvdW5kIiBkPSJNNDMwLjYgMjQ3LjRhNi41IDYuNSAwIDAgMS02LjQgNi41'
    b'IDYuNSA2LjUgMCAwIDEtNi41LTYuNSA2LjUgNi41IDAgMCAxIDYuNC02LjUgNi41IDYuNSAw'
    b'IDAgMSA2LjUgNi41IiB0cmFuc2Zvcm09Im1hdHJpeCguMzE1OTcgLS4wODQ2NiAuMTM0OTkg'
    b'LjUwMzc4IDEwOS40IDMwKSIvPgogICAgICA8cGF0aCBmaWxsPSIjYTNhZmI4IiBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGQ9Ik0yNzYuMyAxMjAuN3MxLjYtLjUgMS41LTEuNmMwLTEuMS0uNy0y'
    b'LjQtLjctMi40czEuMSAxLjEgMS4yIDIuM2MwIDEtLjEgMS40LS42IDEuOC0uMy4yLTEgLjIt'
    b'MS40LS4xeiIvPgogICAgPC9nPgogICAgPGcgc3Ryb2tlLXdpZHRoPSIyLjgiPgogICAgICA8'
    b'cGF0aCBmaWxsPSIjZWVlIiBzdHJva2U9IiMxZTFlMWUiIHN0cm9rZS1saW5lam9pbj0icm91'
    b'bmQiIGQ9Ik00MzAuNiAyNDcuNGE2LjUgNi41IDAgMCAxLTYuNCA2LjUgNi41IDYuNSAwIDAg'
    b'MS02LjUtNi41IDYuNSA2LjUgMCAwIDEgNi40LTYuNSA2LjUgNi41IDAgMCAxIDYuNSA2LjUi'
    b'IHRyYW5zZm9ybT0ibWF0cml4KC4zMTc1OCAuMDc4NCAtLjEyNSAuNTA2MzYgMjYwIC00MC4y'
    b'KSIvPgogICAgICA8cGF0aCBmaWxsPSIjYTNhZmI4IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0zNjIuMyAxMTkuOHMxLjcuNCAyLjEtLjdjLjUtMSAuNS0yLjUuNS0yLjVzLjUgMS42IDAg'
    b'Mi42LS44IDEuMy0xLjQgMS4zYy0uNC4xLTEtLjMtMS4yLS43eiIvPgogICAgPC9nPgogIDwv'
    b'Zz4KICA8cGF0aCBmaWxsPSIjYjNhMTkyIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Im0zMTYuNyA1My44LjMgNS43cy02LjguNi03'
    b'IDEuMmMtMS40IDMgMS41IDcgMS41IDdzMi4zLTEuOCA4LTEuOGM1LjUgMCA4LjMgMS40IDgu'
    b'MyAxLjRzMS40LTIuMyAxLjQtNGMwLTEuNy0uNi0zLjQtLjYtMy40bC0zLjYtLjRoLTIuNWwt'
    b'LjItNS44LTUuNi4xeiIvPgogIDxwYXRoIGZpbGw9IiNmMGRkY2IiIHN0cm9rZT0iIzEyMTEx'
    b'NiIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuNiIgZD0iTTMyNi40'
    b'IDYyLjZjMCAuNy0uNiAxLjItMS4yIDEuMi0uNyAwLTEuMy0uNS0xLjMtMS4xIDAtLjcuNi0x'
    b'LjIgMS4yLTEuMi43IDAgMS4yLjUgMS4zIDEuMW0yLjcuN2MwIC42LS41IDEuMi0xLjIgMS4y'
    b'cy0xLjMtLjYtMS4zLTEuMmMwLS43LjYtMS4yIDEuMy0xLjIuNyAwIDEuMi41IDEuMiAxLjJt'
    b'LTUuNS0uN2MwIC42LS42IDEuMi0xLjIgMS4yLS43IDAtMS4yLS42LTEuMi0xLjJzLjUtMS4y'
    b'IDEuMS0xLjJjLjcgMCAxLjMuNiAxLjMgMS4ybS01LjYgMGMwIC43LS42IDEuMy0xLjMgMS4z'
    b'LS43IDAtMS4yLS42LTEuMi0xLjIgMC0uNy41LTEuMiAxLjItMS4yczEuMy41IDEuMyAxLjJt'
    b'LTMuMS4yYzAgLjYtLjYgMS4yLTEuMyAxLjItLjcgMC0xLjItLjUtMS4yLTEuMnMuNS0xLjIg'
    b'MS4yLTEuMiAxLjMuNSAxLjMgMS4ybTUuNy0zLjVjMCAuNi0uNSAxLTEgMWExIDEgMCAwIDEt'
    b'MS4yLTFjMC0uNi41LTEgMS4xLTEgLjYgMCAxIC40IDEgMW0wLTQuN2MwIC41LS40IDEtMSAx'
    b'YTEgMSAwIDAgMS0xLTFjMC0uNi40LTEgMS0xczEgLjQgMSAxbTAgMi41YzAgLjYtLjQgMS0x'
    b'IDFzLTEtLjQtMS0xYzAtLjUuNC0xIDEtMXMxIC40IDEgMW0tOC44IDYuNWMwIC43LS41IDEu'
    b'Mi0xLjIgMS4yLS42IDAtMS4yLS41LTEuMi0xLjIgMC0uNi41LTEuMSAxLjItMS4xczEuMi41'
    b'IDEuMiAxLjEiLz4KICA8cGF0aCBmaWxsPSIjOTE2YzY4IiBzdHJva2U9IiM0ZDMxMjYiIHN0'
    b'cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iLjYiIGQ9Ik0zMjAuOSA2Mi40'
    b'YzAgLjctLjYgMS4yLTEuNCAxLjJhMS4zIDEuMyAwIDAgMS0xLjMtMS4yYzAtLjcuNi0xLjMg'
    b'MS4zLTEuMy43IDAgMS4zLjYgMS4zIDEuMyIvPgogIDxnIHN0cm9rZS13aWR0aD0iMi41Ij4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNlZWUiIHN0cm9rZT0iIzFlMWUxZSIgc3Ryb2tlLWxpbmVqb2lu'
    b'PSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zMjIgNDUuNWEyLjUgMi41IDAgMCAx'
    b'LTIuNCAyLjUgMi41IDIuNSAwIDAgMS0yLjUtMi41IDIuNSAyLjUgMCAwIDEgMi41LTIuNiAy'
    b'LjUgMi41IDAgMCAxIDIuNSAyLjUiLz4KICAgIDxwYXRoIGZpbGw9IiNhM2FmYjgiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgZD0iTTMxOC40IDQ2LjhzMiAwIDIuMi0xYy4yLS43LS4xLTEuOC0u'
    b'MS0xLjhzMSAxIC43IDEuOWMtLjMuOC0uNiAxLTEuMiAxLjJhMi4yIDIuMiAwIDAgMS0xLjYt'
    b'LjN6Ii8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNMjgwIDEzMC4xczIuMiAyLjEg'
    b'Mi44IDRjLjYgMS44IDEuNSA2LjggMS41IDYuOHMyMy4yLTYuNSAzNC42LTZjMTEuNC42IDM3'
    b'LjcgNi4zIDM3LjcgNi4zbDEtNS43Yy41LTMgMi43LTYuMyAyLjctNi4zcy0yNS4xLTcuOC00'
    b'MS03YTExNiAxMTYgMCAwIDAtMjcuMyAzLjUgMjU4LjUgMjU4LjUgMCAwIDAtMTIgNC40eiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTMxNC43IDM2aDEwcy0yLjUgMS43LTMgMy40Yy0u'
    b'NCAxLjQtLjMgMy43LS4zIDMuN3MyLjcgMCA0LTFhNzguOCA3OC44IDAgMCAxIDMuNy0yLjl2'
    b'MTIuN3MtMi41LTIuMy00LTMuMWExNC40IDE0LjQgMCAwIDAtMy41LTEuM3MwIDIgLjggMy4z'
    b'IDQuMyA1LjggNC4zIDUuOGwtMTQuMy41czMuNC0zLjUgNC44LTYuMWMuOS0xLjcuNS0zLjUu'
    b'NS0zLjVzLTIuNCAwLTMuNi45Yy0xLjMuOC0zLjQgMy4zLTMuNCAzLjNWMzkuNXMxIDIuNCAz'
    b'IDMuM2MyIC45IDMuOC40IDMuOC40cy40LTIuNC0uNC00Yy0uOC0xLjUtMi42LTMuMi0yLjQt'
    b'My4xeiIvPgogIDxwYXRoIGZpbGw9IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tl'
    b'PSIjMTIxMTE2IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTMxMy45IDc2LjVzLTcuMS0uMS0x'
    b'My4yLTMuNy0xMi4zLTcuNC0yMS4zLTUuM2MtMS44LjUtOC42IDMuNS0xMS42IDEzLjJhMjYg'
    b'MjYgMCAwIDAgMi40IDE4LjcgNTAuMiA1MC4yIDAgMCAwIDUuNiA3LjRsMy43LTIuNXMtOS4z'
    b'LTgtOC4yLTE4LjJjMS0xMC4zIDYuMi0xMi43IDYuMi0xMi43czYuNC01IDE0LjktLjNhODAg'
    b'ODAgMCAwIDAgMjUuMyA4LjdjLjYtLjEtNC01LjQtMy44LTUuM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmMwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIxLjIiIGQ9Im0yNzQuNSAxMTUtMy44LTcuNCAxMS40LTQuNHMtMi44IDMuNi0zLjQgNi4y'
    b'Yy0uOCAzLjItLjUgNS45LS41IDUuOXMxLS44IDIuMy0yLjljMS0xLjUgMi42LTcuMyAyLjYt'
    b'Ny4zbDUuMSAxNi4zcy0yLjYtMi42LTQuNS0yLjljLTItLjQtNC42LjMtNC42LjNsLTMgMS0x'
    b'LjYtNC44eiIvPgogIDxwYXRoIGZpbGw9IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlPSIjMTIxMTE2IiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTMyNi43IDc2LjNzNy4xIDAg'
    b'MTMuMi0zLjdjNi4xLTMuNiAxMi4yLTcuMyAyMS4zLTUuMiAxLjguNCA4LjYgMy40IDExLjYg'
    b'MTMuMWEyNiAyNiAwIDAgMS0yLjUgMTguNyAxMTYuNyAxMTYuNyAwIDAgMS0zLjYgNS45bC00'
    b'LjQtMS42czguMS03LjMgNy0xNy42Yy0xLjEtMTAuMy02LjItMTIuNy02LjItMTIuN3MtNi40'
    b'LTUtMTQuOS0uMmMtOC41IDQuNy0xNi44IDYuOC0xNi44IDYuOHMtNy44IDItOC41IDEuOGMt'
    b'LjcgMCA0LTUuNCAzLjgtNS4zeiIvPgogIDxwYXRoIGZpbGw9IiNmYzAiIHN0cm9rZT0iIzEy'
    b'MTExNiIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0z'
    b'MjMgNjkuM2gzVjk3aC0zem0tMTAtLjJoMy41djI3LjdIMzEzeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNmYzAiIHN0cm9rZT0iIzEyMTExNiIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjIiIGQ9Ik0zMjkuMiA2Mi43YzAgNS00LjMgOS05LjcgOS01LjMgMC05Ljct'
    b'NC05LjctOSAwLTQuOSA0LjMtOC45IDkuNi04LjkgNS40IDAgOS44IDQgOS44IDguOSIvPgog'
    b'IDxwYXRoIGZpbGw9IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBk'
    b'PSJtMzEwLjkgOTYuOCAxNi43LS4ycy0yIDEuMi0zLjcgNC4yYy0xLjYgMy0xLjQgNC44LTEu'
    b'NCA0LjhzMi41IDAgNC4zLTEuM2EyNS45IDI1LjkgMCAwIDAgMy44LTMuN3YxNS4zcy0xLjMt'
    b'Mi0zLjMtM2MtMi0xLjMtNC44LTEuMy00LjgtMS4zaC01LjdzLTIuNi4yLTMuNyAxYTI5IDI5'
    b'IDAgMCAwLTMuNyAzLjJsLS4zLTE0LjZzLjggMi42IDMuNSAzLjYgNC4yIDEgNC4yIDEgMC0z'
    b'LjQtMS40LTVhMzMgMzMgMCAwIDAtNC41LTR6Ii8+CiAgPHBhdGggZmlsbD0iI2Y2Y2ExZiIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjkiIGQ9'
    b'Ik0zMjAuMiAxMDguOHMyLjQgNS43IDUuMyA4LjJjMS42IDEuNSA2LjYgMi42IDguOCAyIDUt'
    b'MS4zIDguNi01LjMgOC42LTUuM3MtLjIgNC40IDMgNi45YzMuMSAyLjQgNS42IDMgOC4yIDIu'
    b'MyAyLjctLjcgMTAtNi4yIDEwLTYuMmwxLjYgMS4zcy00LjMgNC4yLTguNyA2LjNjLTIuMyAx'
    b'LjItOS4zLjUtMTEuNS0xLjMtMi4zLTEuOC0zLjYtNi4xLTMuNi02LjFzLTEuNCAyLjgtNC40'
    b'IDMuOGMtMyAxLTcgMS0xMC45LS4yLTIuNS0uOC01LjktNC4zLTYuNS01LjUtLjYtMS4xLS40'
    b'LTEuOC0uNC0xLjhzLTIgNS40LTUuOCA2LjlhMTguNyAxOC43IDAgMCAxLTExLjUuNGMtMy42'
    b'LTEtMy45LTMuMS0zLjktMy4xcy0uMiA1LjctOCA3LjNjLTggMS42LTE0LjItNC4xLTE0LjIt'
    b'NC4xbDEuMS0xLjdzNC40IDUgMTEuMiA0LjZjNi44LS41IDktOS4yIDktOS4yczMgNC41IDEx'
    b'IDQuNmM3LjkuMSAxMC4yLTEwLjMgMTAuMi0xMC4zbDEuNC4yeiIvPgogIDxnIGZpbGw9IiNm'
    b'YzAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjEiPgogICAgPHBhdGggZmlsbC1y'
    b'dWxlPSJldmVub2RkIiBkPSJNMzAwLjYgMTEyLjFzMC0yLjcuNy0zLjZjLjgtMS4xIDItMS4y'
    b'IDIuNi0xIC43LjIgMS40LjggMS4zIDIuOC0uMSAxLjktLjcgMi44IDAgMy42LjUuNy42IDEu'
    b'MiAxLjcgMSAxLS4yIDEuNi0uNSAxLjMtMS41cy0uNSAwLS43LS44Yy0uMi0uOSAxLTQuNi44'
    b'LTYuOS0uMi0yLjItMS00LTIuOC00LjUtMS42LS40LTMtLjQtNC41LjctMS40IDEtMy4zIDQu'
    b'NS0zLjMgNC41djcuNWwzLS4ydi0xLjZ6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5v'
    b'ZGQiIGQ9Ik0yOTUgMTE0LjFzLTEuMi0yLjUtMi0zYTIuNSAyLjUgMCAwIDAtMi44IDBjLS42'
    b'LjUtMSAxLjQtLjEgMy4xLjggMS43IDEuNyAyLjQgMS40IDMuMy0uMi45IDAgMS40LTEuMSAx'
    b'LjctMS4xLjMtMS43LjEtMS45LTEtLjItMSAuNiAwIC40LTEtLjEtLjgtMi44LTMuNy0zLjUt'
    b'NS45LS43LTIuMS0uNi00LjEuOC01LjIgMS4zLTEgMi41LTEuNiA0LjMtMS4yIDEuOC40IDQu'
    b'OSAyLjkgNC45IDIuOWwzIDYuOC0yLjggMS0uNi0xLjV6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGQ9Ik0yOTQuNCA5Mi4xcy0zIDUtMi4zIDguOGMuNyAzLjggNC42IDEy'
    b'IDQuNiAxMnYxbDIuMi0uMi0uNS0xLjFzMS05LjguNC0xMi45YTMzIDMzIDAgMCAwLTQuNC03'
    b'LjZ6bTQuNyAyMi43czEuNSAxLjcgMy4yIDIuNmMyIC45IDIuOCAxIDMuNS4zLjYtLjQuNC0y'
    b'LjItLjMtMi43LS42LS41LTEuNC0uMi0xLjUuMy0uMi44LS40LjgtMSAuNC0xLS40LTMtMS43'
    b'LTMtMS43bC0uOS44em0tMi4zLjRzLS42IDIuMi0xLjggMy43Yy0xLjQgMS42LTIuMSAyLTMg'
    b'MS43LS43LS4xLTEuMy0xLjgtLjktMi42LjQtLjcgMS4yLS44IDEuNS0uNC41LjcuNy42IDEu'
    b'MSAwbDItMi43IDEuMS4yeiIvPgogICAgPHBhdGggc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIg'
    b'ZD0iTTMwMi40IDExMy40Yy4yLjYtMS44IDEuNS00LjMgMS45LTIuNS40LTQuNi4zLTQuOC0u'
    b'NCAwLS42IDEuOS0xLjUgNC40LTIgMi41LS40IDQuNi0uMiA0LjcuNSIvPgogIDwvZz4KICA8'
    b'ZyBmaWxsPSIjZmMwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS4xIj4KICAgIDxw'
    b'YXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTM0NS42IDExMy4yczEtMi41IDItMy4xYzEu'
    b'MS0uOCAyLjItLjUgMi43IDAgLjYuMyAxIDEuMi4zIDMtLjggMS43LTEuNiAyLjQtMS40IDMu'
    b'My4zIDEgLjIgMS40IDEuMyAxLjYgMS4xLjMgMS43LjEgMS44LTEgLjEtMS0uNSAwLS40LTEg'
    b'MC0uOCAyLjYtMy45IDMuMi02IC42LTIuMy40LTQuMi0xLTUuMy0xLjQtMS0yLjctMS40LTQu'
    b'NS0uOS0xLjcuNS00LjcgMy4xLTQuNyAzLjFsLTIuNiA3IDIuOS45LjQtMS42eiIvPgogICAg'
    b'PHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMzM5LjcgMTEzLjFzLS4yLTIuNy0uOS0z'
    b'LjVjLS45LTEuMS0yLTEuMS0yLjYtMS0uNy4zLTEuNCAxLTEuMiAyLjkuMiAyIC44IDIuOC4z'
    b'IDMuNi0uNi44LS42IDEuMi0xLjcgMS4xLTEuMSAwLTEuNy0uNC0xLjUtMS40LjItMSAuNiAw'
    b'IC44LS45LjEtLjgtMS4zLTQuNS0xLjItNi44IDAtMi4yLjgtNCAyLjUtNC42IDEuNi0uNSAz'
    b'LS42IDQuNS41IDEuNSAxIDMuNiA0LjMgMy42IDQuM2wuNCA3LjRoLTN2LTEuNnoiLz4KICAg'
    b'IDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTM0Ni44IDkyLjNzLTQuNSAzLjYtNS4y'
    b'IDcuNGMtLjcgMy44LjEgMTIuOC4xIDEyLjhsLS4zIDEgMiAuNnYtMS4yczQuNC04LjggNC45'
    b'LTEyYTMyIDMyIDAgMCAwLTEuNS04LjZ6bS0zLjUgMjIuOXMuOCAyLjEgMi4xIDMuNWMxLjUg'
    b'MS42IDIuMiAxLjkgMy4xIDEuNi43LS4yIDEuMS0yIC43LTIuNi0uNC0uNy0xLjItLjctMS41'
    b'LS4zLS41LjctLjcuNS0xLjEgMGE3Ny43IDc3LjcgMCAwIDEtMi4yLTIuNmwtMS4xLjR6bS0y'
    b'LjMtLjVzLTEuMyAxLjktMyAyLjhjLTEuOSAxLjEtMi43IDEuMi0zLjUuNi0uNi0uMy0uNS0y'
    b'LjEuMS0yLjcuNy0uNSAxLjQtLjMgMS42LjIuMi44LjUuNyAxIC40bDIuOC0yIDEgLjd6Ii8+'
    b'CiAgICA8cGF0aCBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNMzQ2LjkgMTE1Yy0uMS43'
    b'LTIuMy44LTQuOC4zcy00LjQtMS40LTQuMy0yYy4xLS43IDIuMy0uOCA0LjgtLjNzNC40IDEu'
    b'NCA0LjMgMiIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSIjY2NhNzE1IiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTI3OSAxMjkuOXMu'
    b'NiAyIDEuNyAxYzEuMi0xLjEgMTcuMy03LjUgNDAtNy41czM3LjUgNi4zIDM4LjQgNi43Yy45'
    b'LjMgMS4zLjggMiAwIC44LTEtLjctMi4zLS43LTIuM3MtMTUuOC02LjctNDAuNC02LjZjLTI0'
    b'LjcuMS00MC42IDcuMS00MC42IDcuMXMtMSAuOC0uMyAxLjZ6Ii8+CiAgPHBhdGggZmlsbC1y'
    b'dWxlPSJldmVub2RkIiBkPSJNMzA3LjkgMTM5LjNzLjctMiAyLTIuNGMxLS4zIDIuNS43IDIu'
    b'NS43cy0xLjktLjItMi41LjJjLS41LjMtLjcgMS4yLS43IDEuMnMuNC0uOCAxLjktLjdoMS42'
    b'cy0yLjUuMy0zIDFjLS42LjcgMi4zIDEgMi4zIDFzLTQuNSAwLTUtLjJjLS42LS4zLTEtMS4y'
    b'LTItMS0xIC40LTIgMS4zLTIgMS4zczEuMS0yIDEuOC0yIDEuMiAwIDEuOC4zbDEuMy42em0t'
    b'MTYuOCAzLjZzLjMtMiAxLjUtMi43YzEtLjUgMi43LjIgMi43LjJzLTIgLjItMi41LjZjLS40'
    b'LjQtLjQgMS40LS40IDEuNHMuMy0uOCAxLjctMWE2OC41IDY4LjUgMCAwIDAgMS42LS4zcy0y'
    b'LjQuNy0yLjggMS41Yy0uNS44IDIuNS42IDIuNS42cy00LjQuOC01IC43Yy0uNy0uMi0xLjIt'
    b'MS0yLjEtLjUtMSAuNC0xLjggMS41LTEuOCAxLjVzLjgtMi4xIDEuNS0yLjNjLjctLjEgMS0u'
    b'MiAxLjggMGwxLjMuM3ptMzAuOS00LjNzLjgtMiAyLTIuM2MxLjEtLjMgMi43LjggMi43Ljhz'
    b'LTItLjMtMi42IDBjLS41LjMtLjcgMS4yLS43IDEuMnMuNC0uNyAxLjktLjVsMS42LjFzLTIu'
    b'NSAwLTMuMS44Yy0uNi42IDIuMyAxLjEgMi4zIDEuMXMtNC41LS4yLTUtLjVjLS42LS4zLTEt'
    b'MS4yLTItMS0xIC4yLTIgMS0yIDFzMS4yLTEuOCAxLjktMS44IDEuMSAwIDEuOC40bDEuMi43'
    b'em0xNC4xIDEuNnMxLTEuOSAyLjQtMmMxLS4yIDIuNCAxIDIuNCAxcy0xLjgtLjQtMi41LS4y'
    b'Yy0uNi4yLS45IDEtLjkgMXMuNS0uNiAyLS4zbDEuNi40cy0yLjUtLjItMy4yLjRjLS43LjYg'
    b'Mi4xIDEuNCAyLjEgMS40cy00LjQtLjgtNS0xLjFjLS40LS40LS43LTEuNC0xLjctMS4zLTEg'
    b'LjEtMi4yLjgtMi4yLjhzMS41LTEuNiAyLjItMS41Yy43IDAgMS4xLjEgMS43LjVsMS4xLjl6'
    b'bTE0IDIuNXMxLTEuNCAyLjEtMS41Yy45IDAgMS45IDEuMSAxLjkgMS4xcy0xLjUtLjUtMi0u'
    b'NGMtLjUuMS0uOC44LS44LjhzLjUtLjUgMS42LS4xbDEuMy40cy0yLS40LTIuNiAwYy0uNi41'
    b'IDEuNiAxLjQgMS42IDEuNHMtMy41LTEtNC0xLjNjLS4zLS4zLS40LTEuMS0xLjItMS4xLS45'
    b'IDAtMS45LjUtMS45LjVzMS4zLTEuMyAxLjktMS4xYy41IDAgLjkuMiAxLjMuNWwuOS44eiIv'
    b'PgogIDxwYXRoIGZpbGw9IiMwZjY1NDUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2lu'
    b'PSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuNyIgZD0iTTMwNSAxMjkuN2MuNCAxLjctMS42IDMu'
    b'NS00LjQgNC0yLjguNi01LjMtLjMtNS42LTItLjMtMS42IDEuNi0zLjQgNC40LTQgMi44LS42'
    b'IDUuMy4zIDUuNiAyeiIvPgogIDxwYXRoIGZpbGw9IiNjZWNmYzEiIGQ9Ik0yOTguOCAxMjku'
    b'NGMwIC40LS40LjktMSAxLS42LjEtMS4yLS4xLTEuMy0uNSAwLS40LjQtLjggMS0xIC42IDAg'
    b'MS4yLjEgMS4zLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzBmNjU0NSIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNMzQ0LjEgMTMx'
    b'LjhjLS41IDEuNi0zIDIuMi01LjggMS40LTIuNy0uOS00LjQtMi45LTQtNC41LjYtMS42IDMu'
    b'Mi0yLjMgNS45LTEuNCAyLjcuOCA0LjUgMi44IDQgNC40eiIvPgogIDxwYXRoIGZpbGw9IiNj'
    b'ZWNmYzEiIGQ9Ik0zMzguOCAxMjguNWMtLjIuNC0uNy42LTEuMy40LS42LS4yLTEtLjctLjkt'
    b'MSAuMS0uNS43LS42IDEuMy0uNS42LjIgMSAuNy45IDF6Ii8+CiAgPHBhdGggZmlsbD0iIzFm'
    b'MmQ4NiIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNMzE0LjYg'
    b'MTI2aDEwLjF2NWgtMTAuMXoiLz4KICA8cGF0aCBmaWxsPSIjNzA3YzhiIiBkPSJNMzE4Ljkg'
    b'MTI3YzAgLjMtLjQuNS0xIC41cy0xLS4yLTEtLjVjMC0uMi41LS40IDEtLjRzMSAuMiAxIC40'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiM5ZjEyMDkiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJtMjg2IDEzMSAxLjYgNS0zIDEuN3MtMS41'
    b'IDEtMyAuMmMtMS40LS43LTIuMi0zLTEuNC00IDEuNS0xLjggNS43LTMgNS43LTIuOXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjOGYzMjJmIiBkPSJNMjgzLjQgMTM0LjZjMCAuOC0uNyAxLjUtMS41'
    b'IDEuNXMtMS40LS43LTEuNC0xLjVjMC0uOS42LTEuNSAxLjQtMS41czEuNS42IDEuNSAxLjV6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2UyYTQ5NCIgZD0iTTI4MiAxMzRhLjguOCAwIDAgMS0uMi43'
    b'LjQuNCAwIDAgMS0uNSAwIC44LjggMCAwIDEtLjQtLjUuOC44IDAgMCAxIC4yLS43LjQuNCAw'
    b'IDAgMSAuNS0uMWMuMiAwIC40LjMuNC42eiIvPgogIDxwYXRoIGZpbGw9IiM5ZjEyMDkiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJt'
    b'MzUzLjkgMTMxLjctMS43IDQuNCA0IDJzMS43LjggMi44LS4xYzEtLjggMS4yLTIuOC40LTMu'
    b'Ny0uNy0xLTUuNi0yLjYtNS41LTIuNnoiLz4KICA8cGF0aCBmaWxsPSIjYWE2NzVkIiBkPSJN'
    b'MzU4LjYgMTM1LjJjMCAuNi0uNiAxLTEuMyAxcy0xLjItLjQtMS4yLTEgLjYtMSAxLjItMWMu'
    b'NyAwIDEuMy41IDEuMyAxeiIvPgogIDxwYXRoIGZpbGw9IiNlMmE0OTQiIGQ9Ik0zNTcuNCAx'
    b'MzVjMCAuMy0uMS42LS4zLjdhLjUuNSAwIDAgMS0uNiAwIC44LjggMCAwIDEtLjMtLjZjMC0u'
    b'My4xLS41LjMtLjZhLjUuNSAwIDAgMSAuNiAwYy4yIDAgLjMuMy4zLjZ6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2Y1ZDhiYyIgZD0iTTMyOC42IDEyNi40YS43LjcgMCAwIDEtLjguNy43LjcgMCAw'
    b'IDEtLjctLjcuNy43IDAgMCAxIC43LS43Yy40IDAgLjguMy44Ljd6bTQuMy4yYS43LjcgMCAw'
    b'IDEtLjcuNy43LjcgMCAwIDEtLjgtLjcuNy43IDAgMCAxIC44LS42Yy4zIDAgLjcuMi43LjZ6'
    b'bS0yLjIgMS43YzAgLjUtLjQuOS0xIC45cy0uOC0uNC0uOC0uOS40LS45LjktLjkuOS40Ljkg'
    b'MXptMiAyLjhhLjcuNyAwIDAgMS0uNi43LjcuNyAwIDAgMS0uOC0uNy43LjcgMCAwIDEgLjct'
    b'LjdjLjUgMCAuOC4zLjguN3ptLTQuMS0uNWEuNy43IDAgMCAxLS43LjcuNy43IDAgMCAxLS43'
    b'LS43LjcuNyAwIDAgMSAuNy0uN2MuNCAwIC43LjMuNy43em0tMjAuOS0zLjVhLjcuNyAwIDAg'
    b'MS0uNS44LjcuNyAwIDAgMS0uOS0uNS43LjcgMCAwIDEgLjYtLjguNy43IDAgMCAxIC44LjV6'
    b'bTQuMy0uN2EuNy43IDAgMCAxLS42LjguNy43IDAgMCAxLS44LS41LjcuNyAwIDAgMSAuNS0u'
    b'OC43LjcgMCAwIDEgLjkuNXptLTEuOCAyLjFjLjEuNS0uMiAxLS42IDFhLjkuOSAwIDAgMS0x'
    b'LjEtLjZjLS4xLS40LjItMSAuNy0xYS45LjkgMCAwIDEgMSAuNnptMi43IDIuM2EuNy43IDAg'
    b'MCAxLS41LjguNy43IDAgMCAxLS45LS41LjcuNyAwIDAgMSAuNS0uOC43LjcgMCAwIDEgLjku'
    b'NXptLTQuMi40YS43LjcgMCAwIDEtLjUuOC43LjcgMCAwIDEtLjktLjUuNy43IDAgMCAxIC42'
    b'LS44LjcuNyAwIDAgMSAuOC41em0tMTkuMi0uMmEuNy43IDAgMCAxLS40IDEgLjcuNyAwIDAg'
    b'MS0uOS0uNC43LjcgMCAwIDEgLjQtMSAuNy43IDAgMCAxIDEgLjR6bTQuMS0xLjNhLjcuNyAw'
    b'IDAgMS0uNCAxIC43LjcgMCAwIDEtLjktLjUuNy43IDAgMCAxIC40LS45LjcuNyAwIDAgMSAx'
    b'IC40em0tMS40IDIuNGEuOS45IDAgMCAxLS41IDEgLjkuOSAwIDAgMS0xLjEtLjQuOS45IDAg'
    b'MCAxIC41LTEuMS45LjkgMCAwIDEgMS4xLjV6bTMgMS44YS43LjcgMCAwIDEtLjQgMWMtLjQg'
    b'MC0uOC0uMS0xLS41cy4xLS43LjUtLjlhLjcuNyAwIDAgMSAuOS40em0tNC4xIDFhLjcuNyAw'
    b'IDAgMS0uNCAxIC43LjcgMCAwIDEtMS0uNC43LjcgMCAwIDEgLjUtMSAuNy43IDAgMCAxIDEg'
    b'LjR6bTU2LjItNS44Yy0uMS40LS41LjYtMSAuNWEuOC44IDAgMCAxLS41LTFjMC0uMy41LS41'
    b'IDEtLjQuMyAwIC42LjUuNS45em00LjQgMS4zYzAgLjQtLjUuNy0uOS42YS44LjggMCAwIDEt'
    b'LjYtMWMuMS0uMy41LS42IDEtLjUuNC4xLjYuNS41IDF6bS0yLjcgMS4yYTEgMSAwIDAgMS0x'
    b'LjEuNyAxIDEgMCAwIDEtLjgtMS4xIDEgMSAwIDAgMSAxLjItLjdjLjUuMS44LjYuNyAxLjF6'
    b'bTEuNSAzLjVjLS4xLjQtLjUuNi0xIC41YS44LjggMCAwIDEtLjUtLjljMC0uNC41LS42Ljkt'
    b'LjUuNC4xLjcuNS42IDF6bS00LjMtMS42YzAgLjQtLjUuNi0uOS41YS44LjggMCAwIDEtLjUt'
    b'LjljMC0uNC41LS42LjktLjUuNCAwIC42LjUuNS45eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zNTYgODlzLTIgMS45LTQu'
    b'NSAxLjlhNyA3IDAgMCAxLTQuNi0xLjZjLS44LS41LjItMiAuMi0yIi8+CiAgPHBhdGggZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0iTTMxMi45IDky'
    b'LjhzLTMuNy0uNy01LjMtMS4yYy0xLjUtLjUtMS4xLTEuNS0zLTEuNC0xLjcuMS0zLjUgMS40'
    b'LTMuMSAzLjIuNCAxLjggMS43IDIgMyAxLjcgMS4yLS40LjgtMi42LS44LTIuNC0xLjcgMC0u'
    b'MyAxLjUtLjMgMS41Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJN'
    b'Mjg3LjMgOTBzMSAxLjUgMy43IDEuMmMyLjctLjIgMy43LTEuNiAzLjgtMi4zLjItLjYgMC0x'
    b'LjgtLjUtMi4zLS41LS41LTIuMy0uNy0yLjMtLjciLz4KICA8ZyBzdHJva2U9IiMxNjExMTEi'
    b'IHN0cm9rZS13aWR0aD0iMS42Ij4KICAgIDxwYXRoIGZpbGw9IiNjMDAiIGQ9Ik0zMzkuMiAy'
    b'NzAuNGMyLjUtMi41IDYuNS01LjIgOC43LTExIDItNS42IDMtMTUuNyA1LTIwLjggMi41LTgu'
    b'OCA3LjUtMTcuNCAxLjUtMTYuOC01LjcuNi03LjUgNi05LjYgMTAtMSAxLjUtMy4zIDQuNy0z'
    b'LjcgNi41LS4xLTMtMS43LTExLjktMi0yMC44LS4zLTguNCAwLTE3LS4zLTIwLjMtLjItNC4z'
    b'LS4yLTguMy0xLjItMTEuNC0uNS0xLjUtMi42LTMtMy44LTIuOS0yLjIgMC0zLjYgMi00IDMu'
    b'OWwtLjIgMi44Yy0uMiAyLjQgMCA1LjUtLjIgOC4zLS4xIDMgLjIgNi4yIDAgOS0uMiA1LjQt'
    b'LjYgMTAuNS0uOCAxMS41IDAtMi0xLTExLjctMS4zLTIwLjlsLS4yLTEwYzAtMi42IDAtNS40'
    b'LS4yLTcuNC0uNS0zLjQtMS42LTUtNC01LTEuOCAwLTQuMiAxLjMtNSA1LS4zIDIuMS0uNCA0'
    b'LjYtLjMgNy40bC4yIDhjLS4yIDEwLjUtLjQgMjEuNS0uOCAyNC44IDAtMS0xLjEtNi41LTEu'
    b'NC0xMy45bC0uNC05LjYtLjMtOS42YzAtMS42LS43LTYuMi0zLjctNi0xLjctLjItMy40IDEt'
    b'NCA1LjMtLjQgMi41LS40IDYuNi0uNSA5LjktLjEgNi0uNCAxMS40IDAgMTYuOWwuMSA3Ljdj'
    b'MCAuNC0uOS0yLjktMS4zLTcuNGwtLjgtOC42YzAtMi4zLS4xLTUuNy0uMy04LjUtLjItMi4x'
    b'LS4xLTQuNS0yLjUtNC4zLTIuNC4xLTMuOCAxLTQuMyA1LS40IDIuNy0uNCA4LjUtLjUgMTAu'
    b'NS4yIDUuMy0xLjIgMTcuNy0xLjggMjEuMi0uMiAyLjUtMS4yIDUuNy0xLjYgOS4yYTcwIDcw'
    b'IDAgMCAwIDEgMjAuNmMyIDcgNyAxMC4yIDYuOCAxNS0uMyA0LjggMCAxMy4zIDAgMTcgMCAz'
    b'LjggMy4zIDQgMTAgMi42IDExLjItMi40IDE3LjMgMi40IDI2LjQtMS4yLTEuMS0xMC40IDEu'
    b'MS0xNi43IDEtMjAuNXptLTYuNS0yNC43YzIuMy02LjQgNS4yLTguOSA4LTEwLjIiLz4KICAg'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik0zMDcuNCAyMzkuMmMzLjUtMS40IDctMi40IDEwLjYt'
    b'My42IDQuMy0xLjIgOC41LTMgMTMtMy42IDItLjUgNC4yLTEgNi40LTFtLTM2LjEgNDJjLjQt'
    b'LjMgMSAuMiAxLjQuMy42LjIgMS4zLjQgMiAuM2ExMDcuNCAxMDcuNCAwIDAgMSA0IDBjMS43'
    b'IDAgMy0uMiA0LjMtMW0xMCAuNiAxLjYuOWMuOC4zIDEuOC40IDcuMyAwIDMuNS4yIDYuNS0y'
    b'LjggNy40LTMuNiIvPgogIDwvZz4KPC9zdmc+Cg==', 'GB_NIR')

GB_NIR = b64_GB_NIR
index.append("GB_NIR")
index.append("United Kingdom Northern Ireland")
catalog["GB_NIR"] = GB_NIR
catalog["United Kingdom Northern Ireland"] = GB_NIR
country["United Kingdom Northern Ireland"] = ('GB_NIR', '', 1)
lookup["GB_NIR"] = ('GB_NIR', '', 'United Kingdom Northern Ireland', 1)
lookup["Belfast United Kingdom Northern Ireland"] = ('GB_NIR', '', 'United Kingdom Northern Ireland', 1)
lookup["United Kingdom Northern Ireland"] = ('GB_NIR', '', 'United Kingdom Northern Ireland', 1)
details["GB_NIR"] = {"continent":"Europe","capital":"Belfast","currency":"","web":"","lang":"","tz":"±00:00","altname":""}
regional["GB_NIR"] = ('GB_NIR', 'United Kingdom Northern Ireland', 1)
regional["United Kingdom Northern Ireland"] = ('GB_NIR', 'United Kingdom Northern Ireland', 1)
#----------------------------------------------------------------------
b64_GB_SCT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdiLXNjdCIgdmlld0JveD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMDY1YmQi'
    b'IGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogIDxwYXRoIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdp'
    b'ZHRoPSIuNiIgZD0ibTAgMCA1IDNNMCAzbDUtMyIgdHJhbnNmb3JtPSJzY2FsZSgxMjggMTYw'
    b'KSIvPgo8L3N2Zz4K', 'GB_SCT')

GB_SCT = b64_GB_SCT
index.append("GB_SCT")
index.append("United Kingdom Scotland")
catalog["GB_SCT"] = GB_SCT
catalog["United Kingdom Scotland"] = GB_SCT
country["United Kingdom Scotland"] = ('GB_SCT', '', 1)
lookup["GB_SCT"] = ('GB_SCT', '', 'United Kingdom Scotland', 1)
lookup["Edinbrugh United Kingdom Scotland"] = ('GB_SCT', '', 'United Kingdom Scotland', 1)
lookup["United Kingdom Scotland"] = ('GB_SCT', '', 'United Kingdom Scotland', 1)
details["GB_SCT"] = {"continent":"Europe","capital":"Edinbrugh","currency":"","web":"","lang":"","tz":"±00:00","altname":""}
regional["GB_SCT"] = ('GB_SCT', 'United Kingdom Scotland', 1)
regional["United Kingdom Scotland"] = ('GB_SCT', 'United Kingdom Scotland', 1)
#----------------------------------------------------------------------
b64_GB_WLS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdiLXdscyIgdmlld0JveD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMGFiMzki'
    b'IGQ9Ik0wIDI0MGg2NDB2MjQwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2'
    b'NDB2MjQwSDB6Ii8+CiAgPGcgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNCI+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZDIxMDM0IiBkPSJNNDE5IDcwLjhoLS4xem0tLjEgMGE2OTMuOCA2'
    b'OTMuOCAwIDAgMC0xMTEuOCA3NWMtMTcgMTQuOS0xMi4yIDI2LjctMTIuOSA0MCAuNiA5LTEu'
    b'OSAxNy40LTcuNCAyMi40bC0zNy44IDcuNi0zLjYtMTAuNGMxLjEtNS40IDUuNS04IDE0Ljkt'
    b'NC43LjctNi44LTQuOS05LjYtMTEuMy0xMi0yLjMtMS44LTUtMy00LjctOS0xLTEzLjUgMjAu'
    b'NiAxIDIwLjggMSAuMiAwLS44LTEzLjctMTAuNy0xNi40LTUuNC0xLjktNy43LTcuNi01LjYt'
    b'MTEuOCA0LjMtOC43IDEyLjUuNiAxOC43IDEtLjItNS43LTEuOC05LjctNi43LTE0LjItMi42'
    b'LTEuNy05LTIuOS05LjItNS42LS4xLTMuNiA2LTUuMiAxNC41LTQuMi0xLjgtNS4xLTcuNS04'
    b'LjQtMTUuMy0xMC44bC00LjYtOC4xYy0yLjItNC0zLjItNC4yIDEuOS0xMS44IDQuNS0zIDEw'
    b'LjYtNy4yIDE1LjItMTAuMWwtNS0uNmMuNi01LjUuNy03LjQgMi0xNi41LTUgNi43LTExIDUu'
    b'NS0xNi42IDguMiAwIDAtMTUuNiAyLjgtMjAuNyA5LjVsLTM5LjQtMmMtOC40IDEuMS0xNS41'
    b'IDMuNS0xNi45IDExLjYtMTkuMSAyLTM5LjEuMy01My43IDE4LjUgMTAtLjQgMTguNi0yLjgg'
    b'MjkuOC0xLjQgMCAwIDkuNS4yIDExLjQgMTAuMy4yLjQgMy4zLjQgMy4zLjRsMy42IDIuOCAx'
    b'LjQtMy44IDMuMiAyLjIgMS00LjIgMy4yIDIuMi4yLTUgNC4yIDN2LTYuN3MxNS42IDAgMjAu'
    b'NCAxMGMuMi4xLTQzLjcgOC04Ni4xIDQuM2wxMi4yLTZjLTE1LjQtMy4yLTMwLTYtNDMuNi0x'
    b'Ni43IDUuMSAxOS40IDMxLjcgNDIuMSAzNy4yIDQybC01LjItOS40IDQ2IDJjMS43IDUuMSAx'
    b'IDEwLjggNSAxNS4zIDAgMC0yLjUgOC40IDMuMiAxMS44LjIuNCA2LjctMTcgNi43LTE3czIg'
    b'NC43IDQgNy44YzMtMTUgMTkuNC0xNy41IDE5LjQtMTcuNWwzLjQgOGMtNS4xLjgtMTEuNSAx'
    b'MS4yLTggMTctMy41IDAtOS42IDEwLjEtNy43IDE1LjYtMi45IDIuOS0xMCA2LjctOC4zIDE4'
    b'LjgtNS42IDEuMi05IDExLjUtNy4yIDIyLjUtOC44IDguMS02LjYgMjMgMS4yIDI5LjEtMy4y'
    b'IDMtNS4yIDUuMS01LjIgOC43LTMuMS0xLjEtNi0uMi03LjMgMS44LTMuOC0zLjktOS4yLTcu'
    b'Mi0xMy0zLjYtMS00LjYtNy05LjYtMTMuNS05YTEyLjMgMTIuMyAwIDAgMC05LTEzcy0xLjUt'
    b'MjIuNi04LjMtMzBjLS43LTQgLjQtNi44IDYtMTAuMiA1LjctMyA2LjktNS4zIDYuNC0xMy45'
    b'IDIuMy01LjcgNC0xMS41LTMtMTUuNC4yIDYuOC0xLjggMTAtNC42IDEzLTMuMy0uNC00LjQg'
    b'My40LTYuNiA1LTMuMS00LjEgNi41LTEwLjYtLjYtMTkuOS0uNC0uNC01LTEyLTE2LjMtMTEu'
    b'OCA1LjMgMy4xIDcuNiA4LjQgNy42IDEzLjlhNDEuMyA0MS4zIDAgMCAwLTEuOCAyOS4zYy00'
    b'LjctNy03LjQtMjAuNC0xMS4zLTIyLjctMy40LS43LTUtOC43LTE4LjMtNi40IDUuNyAxLjUg'
    b'Ny42IDUuOSA5IDkuOC0zLjQgMS44LTEuNyA2LjYuOSA5LjktLjUgNy43IDQuMSAxMi4yIDEx'
    b'IDE1TDg1LjYgMjM3Yy0yLjctLjMtNyAxMC40LTguNiAxMC43LTIuNyAxLjctNy40IDYuMi0y'
    b'IDcuNS0xLjYgNS43LTMuMSA5LjItMTEuNyAxMC40IDAgMCA5IDUuNCAxNi42LTMuOCA4LS4y'
    b'IDUuNC05LjggOS4zLTE0IDAtLjMgMi4zLTEuNyA1LjUtMTAuMiAxLjQgNy42IDkuMiAzMC44'
    b'IDI2LjcgNDIuMyAxNS4zIDE2LjQgMjggMzEuOSAyNy44IDUzLjdhNTQgNTQgMCAwIDAgMTIu'
    b'My0yMi43IDg5IDg5IDAgMCAxIDMwLjgtMy42Yy0xLjggMy45LTMuOSA3LjYtMS4zIDEwLTcu'
    b'NCAyLjYtOSA4LTYgMTMuMy03LjggNS4zLTguMyA4LjctOC40IDE3LjUtMTQuNSAxOC41LTIz'
    b'LjQgMTcuOS0zNy43IDEzLTQuNi0yLjctMTItNi42LTE1LjMtNC41LTYuMS00LjItMTUtNC44'
    b'LTE2LjUgNC42IDQuNy0zLjkgNy40LTMuMSAxMS4xLjYtLjcgMS45LTEuMyAzLjcgMS40IDQu'
    b'OGwtMy42IDRjLTYuNi0xLTE1LjYtMS0xNy45IDguNyAzLjQtMi45IDExLTMuNSAxNy0uOGwz'
    b'LjUgMS4yLjQgNC42cy05LTEuNC0xMS40IDEzLjNjOC40LTkgMTQuNC02LjcgMTQuNC02Ljcg'
    b'My4zIDQuOCAxNS4zIDQuMSAyNC0zLjggMTIuMS02LjggMTUuNyAzIDIzLjUtMy40IDYuNS00'
    b'LjggMTQuMi0xLjYgMTkuNSA0IDYuMSAyLjMgMTIuNSA0LjIgMTcuNSAwIDAgMCA2LjItMy45'
    b'IDEyLjMgMi40IDAtNy01LTEwLjktMTEuOC0xMWwtMi0yYy02LjUtMS40LTEzLjctLjgtMTku'
    b'NC00YTU4IDU4IDAgMCAxIDE0LjEtMjdjOS4zLTEwIDE2LjItMTQuNiAyOC0yOS45LS41IDgu'
    b'NyA2LjEgMTguMyA5LjYgMjcgMCAwIDctMTEuMSA4LTIwLjMuMyAwIDguOS00LjQgMTIuNS04'
    b'LjMgNy44IDQuOSAyMC40LTMuOCAyOC42LTExIDUgMiA4LjkgMS44IDE0LjcgMC00LjcgOS42'
    b'IDIuNyAxOC41IDE0LjUgMjIuMiAxIDguNCA5LjYgMTAuMiAyMi41IDEwLjIuNiA1IDguMyA1'
    b'LjcgOC4zIDUuNy01IDIuMi03LjQgNC41LTcuMyA5LjYtNSAwLTguNyAxLjMtMTAgNy02Ljku'
    b'Mi0xMy45LjctMTkuOCA0LTYuMy0uOS0xNC0zLjUtMTguOS04LjYtMi41LTIuMS0zLjItNS4y'
    b'LTcuNi02LjQtMi44LTMuMy02LjItMi42LTcuMy42LTIuOS0yLjMtMTMuOC0zLjMtMTUuNyA3'
    b'IDUuMi0zLjcgOS43LTUuMSAxMy0uNS0xLjggMy4xIDQuMiA1IDkuNCA2LjIgMy43LjIgMTAu'
    b'MiAzLjYgMTIuMiA5LjJhMjAgMjAgMCAwIDEtMTYuNy0yLjYgMTEgMTEgMCAwIDAtMTMtLjhj'
    b'LTQuNC0yLjgtMTQuNyAyLjUtMTUuMSAxMC45IDQuMy00IDguMy02IDEyLjMtMy40LTIgLjQt'
    b'MS4zLjYtMSAxLjhsMTAgNS44Yy01IDEuMy05LjYgMy4zLTcuNCAxMi41IDAgMCA0LTggMTMt'
    b'NSAuMi0uMyAxLjMgMi44IDMuOS43IDMuOS00LjQgMTIuOC02LjQgMjAuNy03LjIgNi4zLS43'
    b'IDEyLjYtMi42IDE4IDEgNS0yLjUgMTAuNC00LjIgMTYtLjIgNi42IDIgMTEuNCA5LjggMTku'
    b'NyA2LjMgNC4yLTMgOS4zLTMgMTQuNSAyLjggMC03LjQtNS41LTkuOS0xMy4zLTExLjVsLTUu'
    b'NC0zLjJjLTUtLjgtMTAgLjEtMTUuMS0yLjNhOTIuMyA5Mi4zIDAgMCAwIDU3LjctNDIuNGwx'
    b'Mi41IDQuNGMzIC4yIDMuMiAxLjIgOS4zIDMgLjItOC45LTMuNy0xOC4xLTE5LjgtMTlsLTIx'
    b'LThjLTQuNi00LjgtNi42LTE0LjktLjktMjAuOCA1LjYtNSA2LjYtNC40IDEwLjMtMTAuNSA0'
    b'LjUtLjQgOC43IDQuMiAxMi44IDQuMiAyIDUuOSAxMy40IDExIDIwLjYgOS4zIDQuNSA0IDEz'
    b'IDYuMiAyMi41IDNhMTguMiAxOC4yIDAgMCAwIDIwLjUgM2MyLjIgMi4yIDYuOCA0IDEyIDIu'
    b'OC41IDAgMi44IDUuOCA4LjUgNy45LTIuNSAyLjQtMSAxMyAxLjcgMTYuOWExNyAxNyAwIDAg'
    b'MC0uOSAxMi43Yy01LjggMy43LTcgNi41LTQuNCAxMi44LTcuNiAxMi4zLTE2LjcgMTMuNy0y'
    b'NS4zIDEwbC05LjMtNi05LjgtOS42Yy0xLjctMS42LTUuMi0yLTUuOSAxLjQgMCAwLTEyLjYt'
    b'Mi44LTEzLjcgNy45IDUuMy01LjEgMTIuNy0uNiAxMi43LS40cy0xLjggMS40LS40IDMuNGMu'
    b'My0uMyA5LjMgMy4zIDE3LjIgNi43IDQuMyAxLjcgNS4zIDIuMiA3LjIgMy4yYTM0MC44IDM0'
    b'MC44IDAgMCAwLTcuMi0zLjIgMzIuOCAzMi44IDAgMCAwLTExLTIuOWMtNC40LS40LTkuMi0x'
    b'LTExLjQgMi40LTQuOCAyLTEyLjQgMy43LTEyIDEyLjcgMy4yLTUuNCA3LjctNS4xIDEzLjQt'
    b'NC42bC0uNCAxLjJjNi4yIDIuOCA1LS44IDEwLjgtMS4zYTQ0IDQ0IDAgMCAxIDE1LjMgMi41'
    b'Yy00LjUgMS4zLTEwLjcuNy0xMy42IDQtLjYgMS0yLjUuNi0xLjYgMy4yIDAgMC05LS4yLTEx'
    b'LjMgMTIgOS01LjcgMTUuOS01LjUgMTYtNS41bDIuOS42IDExLTcuM2MuMyAwIDEwLjYtNC42'
    b'IDE1LjMuNiA0LjIgMiA4LjYgMi4yIDEzLS40IDguNC0zLjcgMTYuMy00IDI0IDEuMmw3LjEg'
    b'NC4yIDMtMnM4LTIuMiAxMy44IDQuOWMtMi40LTEyLjMtMTEuMi0xMi43LTExLjItMTIuN2wt'
    b'Mi0xLjgtMTIuNC00LjljLTEuOS00LjUtNi40LTgtMS45LTEzLjQgNC43LTIzLjEgMTAuMi00'
    b'MC40IDEuMi02My44IDguNCAzLjYgMTQuNyAxNC44IDI1LjIgMTAuOSAwLTkuNC0zNC42LTI3'
    b'LjMtNjEtNDEuNkM1MDggMjY0IDU2MCAyMzIuMSA1NDAgMTkxLjVsOS40LTI5LjRjNC41IDkg'
    b'MTMuNSAxNS44IDIxLjYgMTguNy02LjctMTIuNy0xMC41LTUxLjYtNi43LTc4LjRhNjI3IDYy'
    b'NyAwIDAgMS01Ny4xIDYwYzEwIDIuNCAxOC45LjcgMjguNi0uNWwtOC4yIDE3Yy0yNi42LTE1'
    b'LjctNTcuOC00LTU4IDE2LjguOSAyNC4yIDMwLjggMjcuNyA0OC4xIDE5LjItMy40IDIyLjEt'
    b'NTQuMiAxNC01NC4yIDE0LTE4LTYuMi0zNS4xLTUuMi01NC01IDMuOS0xMi4xIDI1LjctMjIu'
    b'OSA0Mi40LTE4LjEtMjMuMy0yNi4yIDMuMy01OC43IDM1LjQtNjguNi0zNS0xMS42LTQuOS0z'
    b'OC4zIDIxLjMtNTcuNCAwIDAtNzUuMyAzMS43LTgyLjIgMzEuNi0yMS40LTEuNi0xNS42LTI3'
    b'LTcuNC00MC42em0tMjM2LjQgMzAuNGMxLjggMCAzLjguMiA1LjUuNiAzLjQuOSA3LjUgMS4z'
    b'IDcuNSAyLjQtMS42IDIuNi01LjUgNS43LTkuMyA1LjYtMy44LS4yLTYtMi41LTcuMi04LjIu'
    b'NC0uMiAxLjgtLjQgMy41LS40em0zMTcgODkuNGM1IDAgMTAuOSAyIDE2LjYgOC4yLTIuNyA4'
    b'LTI2LjggMTItMjguNC4yLS41LTMuNiA0LjYtOC4zIDExLjgtOC40eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0ibTIwNy40IDE3MS4yIDMu'
    b'NyA1LjNtLS4yLjFzMCA3LjIgMS41IDcuM20tMy4zIDMuOSAzLjggNi4zbS0xMC41IDEuNmMu'
    b'MiAwIDQuNyA1LjIgNC43IDUuMm0zLjktNGMwIC4yIDQuMiA4LjEgNC41IDguMW0tMTAtMi42'
    b'czEuNCA5LjYgMi43IDkuM20tOSA4LjMgNC4yIDYuNW0zLjctMTMuM3MyLjMgOS4xIDQuMSA4'
    b'LjNtMS45LTEzLjhjLjEuMiA0LjMgNi4xIDUuNCA1LjNtLTEgMi4zIDQgOG0tMTAuNi0xLjgg'
    b'My4zIDkuNG0tMTEtNC42czMgMTAuMSA1LjcgOC41bS02LjggNXMuMiA1LjMgMi44IDUuNm0x'
    b'LjgtOC4zYzAgLjIgMi43IDMuOCAyLjcgMy44bTUtMTAuMSAyLjEgMy41bTQuOS0xMCAzLjMg'
    b'NC4xTTIwNiAxNzYuN2MuMSA0LjUgNy4yLTEuNiAxMC01LjRtLTEzIDIxczcuNy01LjUgMTMu'
    b'Ny0xMy44bS0xNi4zIDI2LjljNS41LTEuNSAxNS42LTEzLjcgMTcuNi0yMC4ybS0xOC43IDMy'
    b'LjNjMS41LjcgMjAuMy0xMyAyMC44LTIyLjlNMTk4LjggMjI4YzAtLjEgMTcuMi00LjQgMjQu'
    b'My0yMy4zTTE5OCAyNDIuM3MyNy41LTE2LjUgMjktMjguNk00MTIuNCAyNzBzLTEuOCAxNC4y'
    b'LTE2IDE2LjRtMjAuNSA5Yy4xLS4yIDEzLjYtMTUgMTAuMS0xOS41bTIxLjEgNS4ycy0uMiAx'
    b'MC4zLTguNiAxNy40bTI1LjQtMTQuNHMuMyAxMi40LTUgMTcuNG0yMC40LTEwcy02IDExLjct'
    b'OC4xIDEyLjltNy45IDcuOHM3LjggMiAxMC4zLTMuMm0tOC4zIDIwLjFzNy4yIDEuMyAxMC42'
    b'LTUuNm0tMTEuNCAxOC43czUuOSA1IDkuOS0xLjZtLTk0LTk0LjRzLS43IDI1LjMgMzQuOCAz'
    b'MC40YzM5LjcgMTEgNTguNSA1LjIgNjAuOCA0OS43LTEuNSAxNy0zLjYgMzYtMTYgMjguN20t'
    b'MTE3LjQtODUuNXM1LjcgMTAuMSAxMi41IDkuNGM5LTIuNiAxMi4zIDIuOSAxMi4zIDIuOW0t'
    b'NDktMi4yczE1IDcuMyAyNy43LTQuNW0tMjYtNmMxLjMgMTcuNS0yMC4xIDI3LjUtMjguNiAy'
    b'NS44bTI5LjYgNDFjLjEgMCAxMS42LTYuOCA5LjMtMTEuNm0tMzIuMSAxLjVjLjMtLjQgMTku'
    b'My0yLjIgMjIuOC05bS0zMS42LTE5czI2LjkuMiAyOC43IDUuMW03LTIxcy0yNi4yIDQ0Ljkg'
    b'MjIuMiA0NC45bS01MC00NS41cy01LjYgMTYuNy0xMy42IDIyLjRtLTE0LjItMjguMnM5Ljcg'
    b'MTguOCAwIDI4LjFNMjYxIDI4MC44Yy4xLjMgMy4xIDI2LjctMy41IDM0LjJtLTkuMi0zMy40'
    b'czEgMTYuOC00IDIyLjggMS4yIDE4LjQgMS4yIDE4LjRtLTYwLjUgOHMzLjYgNi4zIDguNSA0'
    b'LjFtLTIuNS0xNy44czggMy41IDEwLjcgMi4ybS0yLTMwLjRzLTExLjggMy4zLTcuMyAxNy4z'
    b'YzYuOCA1LjUgMTMuNCA0LjYgMTMuNCA0LjZtLTI5LjQgMzcuNGMtLjEgMCAxLjQgMTEgOSAy'
    b'LjcgNS4zLTExLjIgMjItNDIuNiAyNS45LTUzLjRtNy44LTUuMXMtOC4xLTYuMy03LjggMi41'
    b'Yy0uMiA1LjUgMi41IDYuOCAyLjUgNi44LjMgNCAzLjggOS42IDYuNiA0LjUgMS4yLTUtLjgt'
    b'Ny4yLS44LTcuMm00LjctOWMtNy4zLS40LTExLjMgMTUuNyAyLjggNS42bTQuOC0xMXMtMS44'
    b'IDIuNS00LjctLjJjLTEuNS0yLjYtNi44IDEyIDIuNSAxMi41IDEuNy00LjMgNi44LTUuNSA2'
    b'LjgtNS41bTQuNC0xMy44cy00LjIgMi01LjcgMS43Yy01IDEuMS00IDEyLjggMi4zIDEyLjEg'
    b'Mi4yLTIuNSA0LjUtNiA0LjUtNm0tNDAuMy0yM2MtLjIgMC0xNi41IDI1LjcgOS4xIDMyLjVt'
    b'MTk4LTcxcy0xMCA4LjQtLjcgMjJjLTMxLS41LTQ3LjUgMTMuOC00OC44IDIzLjQtMzkuNC0y'
    b'LjgtMzIuMiA4LjgtNDUgMTIuNi0xNy4xLTE0LjMtNDIuMi02LjMtNDAuNiA4LTExLjQtMTYu'
    b'MS0yOS04LjMtMzEuMi00LjMtMi4xIDQtMS4zLTE5LjgtMS4zLTE5LjhzLTExLjUgNS4yLTE5'
    b'LjQgMTQuNnYtMTkuOWMtOS42IDItMTguOSAyLTI4LjggMS44bS0yNS45LTcuM3MxNC4zIDgg'
    b'MzItMi44TTE2NiAyMjYuM3MxMSAxMCAzMiA2LjhtLTI1LTI5LjdzMi40IDguMSAyNi4zIDgu'
    b'Nk0xODEgMTg0LjZzOSAxMSAyMS4yIDkuM20tMTMuNS0yNXMzLjUgNiAxNi44IDdtLTktMjQu'
    b'NXM3IDcuNiAxNSA2LjNNMjM4IDg5LjNzMy4xLTMgOC4zLTEuNW0tMTAuNSAxNy44cy05LjYt'
    b'LjMtOS00Yy44LTQuNCAxMC4yLTcuNSAxMC4yLTcuNXMxMi41LTggMTQuNC0xMC44bS01Ni42'
    b'IDQ0IDEyLjIgMjMuMyA1LjgtOC44IDMgNiA1LTguNyA4LjYgNS41LTMuMi0xMC43IDcuMi0u'
    b'NXMtMi01LjEtOC40LTYuMmMxLjctMS4zIDcuNy01LjMgNy43LTUuM3MtMy40LTQtOC44LTQu'
    b'MWMxLjgtMS45IDQuMi02LjUgNC02LjVsLTUuMy0xLjJzMTIuMiA0IDIxLjYtMS42TTIyMSA4'
    b'OS43Yy4xLjEtLjcgNC44LTMuMyA3LjVtLTQzLjcgNS4zczcuNS0yIDEzLjEtLjljNS42IDEu'
    b'MiAxMy4xIDMuMiAxMy4xIDMuMnM5LTEuMiAxMS45LTMuM20tNTYuOCA2cy0xIDMuNi0xLjQg'
    b'NmMwIDEuNy01LjUgNC01LjUgNG0xMC4zLTE3LjRzNC44IDYgNSA5LjVjLjEgMy40LTMuNiA2'
    b'LTMuNiA2TTEwOSAxNDFsLTUtOCA0LjUtMS42bTkwLjUgMTIxYy00LTUuMiAzLTg0LjIgMTcu'
    b'Ny0xMDQuOC01LjEgMzcuMiAxMiA3NS4yIDE2LjMgNzVtLTc5LTk3czYuOCAyLjUgMjAuNy04'
    b'LjZtMTguOSAyNi44IDEwIC4xbTMwMC4zLTYycy0xNjYuNyA3Ny44LTE2OS4xIDgyYzI4LjEt'
    b'OC42IDE0Ny41LTI4LjUgMTUwLjQtMjYuOC03IDEuNy0xNTEuOSAzNS0xNTguNyA0MyAzNi4y'
    b'LTEuMiAxMTEuOSAxMS42IDEyMy44IDI0QzQyNC41IDE5OC4zIDM0Ny42IDE4NyAzMjQgMTky'
    b'YzE3LjIgNC4xIDgzLjIgNDYuOCA4My4yIDUzLjYtMTAtOS41LTg5LjMtNDIuMi05Mi40LTM5'
    b'IDE4LjIgMTAuOSA0My45IDUxLjQgNDMuOSA2MS4zLTUuMy04LjQtNTEuMi01Ny43LTUzLjkt'
    b'NTQuNSA0LjkgNi43IDE0LjUgNjQuOSA5LjYgNjcuNiAwLTctMTcuOC01OC0xOS4zLTU5LjQt'
    b'My42IDEtMjYuMyA2Mi0yMS44IDY3LjgtMy0yMC40LjUtNjMgNi02MS4zLTEwIDEuNS00MS43'
    b'IDQzLjQtMzguMyA1MCAxLTEwLjUgMi40LTE3LjQgMjAuNC01Mi4xLTIwIDEuMi02MS4yIDI3'
    b'LjEtNjguMiAzNi40IDUuNi0xNi41IDQwLjUtNDQuNCA1NS44LTQ2LjRtNzItNjAuN2MxNy42'
    b'LTkuOCA3Mi0yOS43IDEwOC40LTQ0LjRtLTE0Mi42IDk3czEyLS4yIDI0LTMyLjhjMTEuOC00'
    b'NC42IDEwNS43LTk0LjMgMTA3LjYtMTAzLjZNMTI4IDI1Mi44cy0yLjggNi02LjIgNy42bTE5'
    b'LjcgMS40cy0zLjcgNy4yLTQuNiAxMC42bTE3LjUtN3MzIDkuOC41IDE0LjRtLTM2LjQtNDAu'
    b'MWMtOS40IDUuMyA1LjQgMzkgNTAuMSA0Mi4ybS03LjItMTguMnMtMS4yIDYgNy4yIDE4Yy0y'
    b'LjQgMTMuNCAxMC4yIDIzLjkgMTUuMiAyNS42bS0yNi0xNjQuMiAxLjQtMy42IDEuNSA0IDIu'
    b'NS0uMSAxLjYtNCAxLjQgNGgyLjRsMS41LTQuNCAyLjMgNC4yaDJsMS41LTUgMyAzLjYgMS4y'
    b'LS40IDEtNS4yIDMuMSAzLjYgMS0uNSAxLjQtNSAyLjUgMy43IDEuMy0uNCAxLjItNC4zIDIu'
    b'NCA0bS0zOSA2LjIgMTguOC0uM2M2IDAgMTUuOC04LjMgMjYuNy01LjdtLTg0LjkgNDZzMy4x'
    b'IDYuOCA3LjQgM20tMTQuNiAxLjVzLTYgMTYuMiAxLjIgMjBtLTkuOC0zNy44czAgMy44IDgt'
    b'Mm0tMzIuNSA4Ni43czYuMyAyIDUuMyA2LjdtLTMtODAuOHM0IDEuOSA3LjgtNG0zNC4yIDE4'
    b'OS43YzYuMS0uNCA3LjUgMi40IDEzIDIuNCA2LjYuMiAxMi45LTIuNCAyMS00LjdtNTMuMSAx'
    b'NWMtLjIgMC0zIDUuOC0uNSA4LjdtLTg3LjUtOC4yczkuOC04IDE1LTMuMWM0LjkgMS43IDcu'
    b'NiAxLjQgNy42IDEuNG0tMTcuNS0yMS4zczIuNCA2LjItNS42IDUuM20tMi40IDlzNS4xIDMu'
    b'Mi0uNyA3LjVtMy44IDUuOHM3IDEgMi45IDYuN00zNDYgMzQxLjZzMTkgMiAyMCAzLjRjMi4y'
    b'LTIuMyAxOS4yLTE2LjItMS43LTE4LjFhMTkgMTkgMCAwIDEtMTguMyAxNC43em0tNi44IDku'
    b'NWM3LjEgNS43IDQuMiA5LjEgMjYuNi01LjltLTM2LjggMTNzMTAuNSAxMS40IDE4LjItMi40'
    b'bS0zOC4zIDYuNS0xNC4zIDcuNU0yNjkgMzgwLjNzOC43LTcuNCAxMi43LTMuNWM0LjEgNCAy'
    b'MS4zLTMuNCAyMS4zLTMuNE0yNzUuNSAzNDhzMyA2LTIuOCA2LjdtLTguNSAxMS45czMgNS42'
    b'LTIuOCA3bTkuNSA4LjFzOSAuNSA1LjggNy4zbTc4LjQtOC41cy01IDQuMi0xLjMgOW03My0z'
    b'OXM1LjcgMi44LTEuMSA3LjVtLTUuNyA5LjlzNC4zIDQuNSAxLjQgOC4ybTEwLjYgOXM1Ljkg'
    b'MS43IDUuMiA2LjZtNzcuOC0xMXMtNSAzLjctMi4zIDguNE00MjcgMjM2LjNjMTEuOC0xLjQg'
    b'MjguOCAyNSAzNy41IDMwLjFtNTEuOS02Ny40czYgNS4zLjcgMThtMTAuNC0zOC4yYzEuNyAx'
    b'LjMgOC4xIDQuOCAxMi40IDEyLjhtNC4xLTUyLjItOC4zIDIyLjVtMTcuNi0yMy42cy0xLjYg'
    b'MjAtNCAyNE01MTYgMTk4LjhjLTIuNyA4LTI2LjggMTItMjguNC4yLS45LTYgMTQuMi0xNS4z'
    b'IDI4LjQtLjJ6Ii8+CiAgICA8cGF0aCBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJtMTgy'
    b'LjMgMTAxLjMgOS4zIDEuN3MtNi41IDguOC05LjMtMS43eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'GB_WLS')

GB_WLS = b64_GB_WLS
index.append("GB_WLS")
index.append("United Kingdom Wales")
catalog["GB_WLS"] = GB_WLS
catalog["United Kingdom Wales"] = GB_WLS
country["United Kingdom Wales"] = ('GB_WLS', '', 1)
lookup["GB_WLS"] = ('GB_WLS', '', 'United Kingdom Wales', 1)
lookup["Cardiff United Kingdom Wales"] = ('GB_WLS', '', 'United Kingdom Wales', 1)
lookup["United Kingdom Wales"] = ('GB_WLS', '', 'United Kingdom Wales', 1)
details["GB_WLS"] = {"continent":"Europe","capital":"Cardiff","currency":"","web":"","lang":"","tz":"±00:00","altname":""}
regional["GB_WLS"] = ('GB_WLS', 'United Kingdom Wales', 1)
regional["United Kingdom Wales"] = ('GB_WLS', 'United Kingdom Wales', 1)
#----------------------------------------------------------------------
b64_GD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1nZCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGcgaWQ9ImdkLWMiPgogICAgICA8ZyBp'
    b'ZD0iZ2QtYiI+CiAgICAgICAgPHBhdGggaWQ9ImdkLWEiIGZpbGw9IiNmY2QxMTYiIGQ9Ik0w'
    b'LTF2MWguNSIgdHJhbnNmb3JtPSJyb3RhdGUoMTggMCAtMSkiLz4KICAgICAgICA8dXNlIHhs'
    b'aW5rOmhyZWY9IiNnZC1hIiB0cmFuc2Zvcm09InNjYWxlKC0xIDEpIi8+CiAgICAgIDwvZz4K'
    b'ICAgICAgPHVzZSB4bGluazpocmVmPSIjZ2QtYiIgdHJhbnNmb3JtPSJyb3RhdGUoNzIpIi8+'
    b'CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI2dkLWIiIHRyYW5zZm9ybT0icm90YXRlKDE0NCki'
    b'Lz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjZ2QtYiIgdHJhbnNmb3JtPSJyb3RhdGUoMjE2'
    b'KSIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiNnZC1iIiB0cmFuc2Zvcm09InJvdGF0ZSgy'
    b'ODgpIi8+CiAgICA8L2c+CiAgPC9kZWZzPgogIDxwYXRoIGZpbGw9IiNjZTExMjYiIGQ9Ik0w'
    b'IDBoNjQwdjQ4MEgweiIvPgogIDxwYXRoIGZpbGw9IiMwMDdhNWUiIGQ9Ik02Ny4yIDY3LjJo'
    b'NTA1LjZ2MzQ1LjZINjcuMnoiLz4KICA8cGF0aCBmaWxsPSIjZmNkMTE2IiBkPSJNNjcuMiA2'
    b'Ny4zaDUwNS42TDY3LjIgNDEyLjloNTA1LjZ6Ii8+CiAgPGNpcmNsZSBjeD0iMzE5LjkiIGN5'
    b'PSIyNDAuMSIgcj0iNTcuNiIgZmlsbD0iI2NlMTEyNiIvPgogIDx1c2UgeGxpbms6aHJlZj0i'
    b'I2dkLWMiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KDUy'
    b'LjggMCAwIDUyLjggMzIwIDI0MCkiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNnZC1kIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSItMTAwIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgt'
    b'MzAuMykiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNnZC1jIiBpZD0iZ2QtZCIgd2lkdGg9IjEw'
    b'MCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJtYXRyaXgoMzEuMiAwIDAgMzEuMiAzMjAg'
    b'MzMuNikiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNnZC1kIiB3aWR0aD0iMTAwJSIgaGVpZ2h0'
    b'PSIxMDAlIiB4PSIxMDAiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDMwLjMpIi8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2NlMTEyNiIgZD0iTTEwMi4zIDI0MC43YTgwLjQgODAuNCAwIDAgMCAzMy41IDMz'
    b'LjIgMTExIDExMSAwIDAgMC0xMS4zLTQ1bC0yMi4yIDExLjh6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'I2ZjZDExNiIgZD0iTTkwLjEgMTk0LjdjMTAuNCAyMS43LTI3LjEgNzMuNyAzNS41IDg1Ljlh'
    b'NjMuMiA2My4yIDAgMCAxLTEwLjktNDEuOSA3MCA3MCAwIDAgMSAzMi41IDMwLjhjMTYuNC01'
    b'OS41LTQyLTU1LjgtNTcuMS03NC44eiIvPgogIDx1c2UgeGxpbms6aHJlZj0iI2dkLWQiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii0xMDAiIHRyYW5zZm9ybT0idHJhbnNsYXRl'
    b'KC0zMC4zIDQxNC42KSIvPgogIDx1c2UgeGxpbms6aHJlZj0iI2dkLWMiIHdpZHRoPSIxMDAl'
    b'IiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KDMxLjIgMCAwIDMxLjIgMzIwIDQ0'
    b'OC4yKSIvPgogIDx1c2UgeGxpbms6aHJlZj0iI2dkLWQiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9'
    b'IjEwMCUiIHg9IjEwMCIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMzAuMyA0MTQuNikiLz4KPC9z'
    b'dmc+Cg==', 'GD')

GD = b64_GD
index.append("GD")
index.append("GRD")
index.append("Grenada")
catalog["GD"] = GD
catalog["GRD"] = GD
catalog["Grenada"] = GD
country["Grenada"] = ('GD', 'GRD', 0)
lookup["GD"] = ('GD', 'GRD', 'Grenada', 0)
lookup["St. George's Grenada"] = ('GD', 'GRD', 'Grenada', 0)
lookup["GRD"] = ('GD', 'GRD', 'Grenada', 0)
lookup["Grenada"] = ('GD', 'GRD', 'Grenada', 0)
details["GD"] = {"continent":"Americas","capital":"St. George's","currency":"East Caribbean Dollar","web":".gd","lang":"en-GD","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_GE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0icmVkIiBkPSJNMjcyIDBoOTZ2NDgwaC05'
    b'NnoiLz4KICA8cGF0aCBmaWxsPSJyZWQiIGQ9Ik0wIDE5Mmg2NDB2OTZIMHoiLz4KICA8cGF0'
    b'aCBmaWxsPSJyZWQiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTE0Ni44IDM3My4xYzEtMTYu'
    b'OCA0LTMxLjEgNC0zMS4xcy05LjggMS0xNC44IDFjLTQuOSAwLTE0LjgtMS0xNC44LTFzMyAx'
    b'NC4zIDQgMzEuMmMtMTYuOS0xLTMxLjItNC0zMS4yLTRzMSA3LjQgMSAxNC44LTEgMTQuOC0x'
    b'IDE0LjggMTQuMy0zIDMxLjItNGMtMSAxNi45LTQgMzEuMi00IDMxLjJzNy40LTEgMTQuOC0x'
    b'IDE0LjggMSAxNC44IDEtMy0xNC4zLTQtMzEuMmMxNi45IDEgMzEuMiA0IDMxLjIgNHMtMS05'
    b'LjgtMS0xNC44YzAtNC45IDEtMTQuOCAxLTE0LjhzLTE0LjMgMy0zMS4xIDR6bTM2OC0yODhj'
    b'MS0xNi44IDQtMzEuMSA0LTMxLjFzLTkuOCAxLTE0LjggMWMtNC45IDAtMTQuOC0xLTE0Ljgt'
    b'MXMzIDE0LjMgNCAzMS4xYy0xNi45LTEtMzEuMi0zLjktMzEuMi0zLjlzMSA3LjQgMSAxNC44'
    b'LTEgMTQuOC0xIDE0LjggMTQuMy0zIDMxLjItNGMtMSAxNi45LTQgMzEuMi00IDMxLjJzNy40'
    b'LTEgMTQuOC0xIDE0LjggMSAxNC44IDEtMy0xNC4zLTQtMzEuMWMxNi45IDEgMzEuMiA0IDMx'
    b'LjIgNHMtMS0xMC0xLTE0LjkgMS0xNC44IDEtMTQuOC0xNC4zIDMtMzEuMiA0em0tMzY4IDBj'
    b'MS0xNi44IDQtMzEuMSA0LTMxLjFzLTkuOCAxLTE0LjggMWMtNC45IDAtMTQuOC0xLTE0Ljgt'
    b'MXMzIDE0LjMgNCAzMS4yYy0xNi45LTEtMzEuMi00LTMxLjItNHMxIDcuNCAxIDE0LjgtMSAx'
    b'NC44LTEgMTQuOCAxNC4zLTMgMzEuMi00Yy0xIDE2LjktNCAzMS4yLTQgMzEuMnM3LjQtMSAx'
    b'NC44LTEgMTQuOCAxIDE0LjggMS0zLTE0LjMtNC0zMS4yYzE2LjkgMSAzMS4yIDQgMzEuMiA0'
    b'cy0xLTkuOC0xLTE0LjhjMC00LjkgMS0xNC44IDEtMTQuOHMtMTQuMyAzLTMxLjEgNHptMzY4'
    b'IDI4OGMxLTE2LjggNC0zMS4xIDQtMzEuMXMtOS44IDEtMTQuOCAxYy00LjkgMC0xNC44LTEt'
    b'MTQuOC0xczMgMTQuMyA0IDMxLjJjLTE2LjktMS0zMS4yLTQtMzEuMi00czEgNy40IDEgMTQu'
    b'OC0xIDE0LjgtMSAxNC44IDE0LjMtMyAzMS4yLTRjLTEgMTYuOS00IDMxLjItNCAzMS4yczcu'
    b'NC0xIDE0LjgtMSAxNC44IDEgMTQuOCAxLTMtMTQuMy00LTMxLjJjMTYuOSAxIDMxLjIgNCAz'
    b'MS4yIDRzLTEtOS44LTEtMTQuOGMwLTQuOSAxLTE0LjggMS0xNC44cy0xNC4zIDMtMzEuMiA0'
    b'eiIvPgo8L3N2Zz4K', 'GE')

GE = b64_GE
index.append("GE")
index.append("GEO")
index.append("Georgia")
catalog["GE"] = GE
catalog["GEO"] = GE
catalog["Georgia"] = GE
country["Georgia"] = ('GE', 'GEO', 0)
lookup["GE"] = ('GE', 'GEO', 'Georgia', 0)
lookup["Tbilisi Georgia"] = ('GE', 'GEO', 'Georgia', 0)
lookup["GEO"] = ('GE', 'GEO', 'Georgia', 0)
lookup["Georgia"] = ('GE', 'GEO', 'Georgia', 0)
details["GE"] = {"continent":"Asia","capital":"Tbilisi","currency":"Lari","web":".ge","lang":"ka | ru | hy | az","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_GF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdmIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'GF')

GF = b64_GF
index.append("GF")
index.append("GUF")
index.append("French Guiana")
catalog["GF"] = GF
catalog["GUF"] = GF
catalog["French Guiana"] = GF
country["French Guiana"] = ('GF', 'GUF', 0)
lookup["GF"] = ('GF', 'GUF', 'French Guiana', 0)
lookup["Cayenne French Guiana"] = ('GF', 'GUF', 'French Guiana', 0)
lookup["GUF"] = ('GF', 'GUF', 'French Guiana', 0)
lookup["French Guiana"] = ('GF', 'GUF', 'French Guiana', 0)
details["GF"] = {"continent":"Americas","capital":"Cayenne","currency":"Euro","web":".gf","lang":"fr-GF","tz":"-03:00","altname":""}
#----------------------------------------------------------------------
b64_GG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1nZyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgw'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNlODExMmQiIGQ9Ik0yNTYgMGgxMjh2NDgwSDI1NnoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZTgxMTJkIiBkPSJNMCAxNzZoNjQwdjEyOEgweiIvPgogIDxwYXRo'
    b'IGlkPSJnZy1hIiBmaWxsPSIjZjlkZDE2IiBkPSJtMTEwIDI4Ni43IDIzLjMtMjMuNGgyMTB2'
    b'LTQ2LjZoLTIxMEwxMTAgMTkzLjN6Ii8+CiAgPHVzZSB4bGluazpocmVmPSIjZ2ctYSIgd2lk'
    b'dGg9IjM2IiBoZWlnaHQ9IjI0IiB0cmFuc2Zvcm09InJvdGF0ZSg5MCAzMjAgMjQwKSIvPgog'
    b'IDx1c2UgeGxpbms6aHJlZj0iI2dnLWEiIHdpZHRoPSIzNiIgaGVpZ2h0PSIyNCIgdHJhbnNm'
    b'b3JtPSJyb3RhdGUoLTkwIDMyMCAyNDApIi8+CiAgPHVzZSB4bGluazpocmVmPSIjZ2ctYSIg'
    b'd2lkdGg9IjM2IiBoZWlnaHQ9IjI0IiB0cmFuc2Zvcm09InJvdGF0ZSgxODAgMzIwIDI0MCki'
    b'Lz4KPC9zdmc+Cg==', 'GG')

GG = b64_GG
index.append("GG")
index.append("GGY")
index.append("Guernsey")
catalog["GG"] = GG
catalog["GGY"] = GG
catalog["Guernsey"] = GG
country["Guernsey"] = ('GG', 'GGY', 0)
lookup["GG"] = ('GG', 'GGY', 'Guernsey', 0)
lookup["St Peter Port Guernsey"] = ('GG', 'GGY', 'Guernsey', 0)
lookup["GGY"] = ('GG', 'GGY', 'Guernsey', 0)
lookup["Guernsey"] = ('GG', 'GGY', 'Guernsey', 0)
details["GG"] = {"continent":"Europe","capital":"St Peter Port","currency":"Pound Sterling","web":".gg","lang":"en | nrf","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_GH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdoIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwNmIzZiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjZDExNiIgZD0iTTAgMGg2NDB2'
    b'MzIwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+'
    b'CiAgPHBhdGggZD0ibTMyMCAxNjAgNTIgMTYwLTEzNi4xLTk4LjlINDA0TDI2OCAzMjB6Ii8+'
    b'Cjwvc3ZnPgo=', 'GH')

GH = b64_GH
index.append("GH")
index.append("GHA")
index.append("Ghana")
catalog["GH"] = GH
catalog["GHA"] = GH
catalog["Ghana"] = GH
country["Ghana"] = ('GH', 'GHA', 0)
lookup["GH"] = ('GH', 'GHA', 'Ghana', 0)
lookup["Accra Ghana"] = ('GH', 'GHA', 'Ghana', 0)
lookup["GHA"] = ('GH', 'GHA', 'Ghana', 0)
lookup["Ghana"] = ('GH', 'GHA', 'Ghana', 0)
details["GH"] = {"continent":"Africa","capital":"Accra","currency":"Ghana Cedi","web":".gh","lang":"en-GH | ak | ee | tw","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_GI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1naSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNkYTAwMGMiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjMyMS42SDB6Ii8+CiAg'
    b'PGcgc3Ryb2tlPSIjMDAwIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtMTYwKSBzY2FsZSgxLjg3'
    b'NSkiPgogICAgPGcgaWQ9ImdpLWEiIGZpbGw9IiNkYTAwMGMiIHN0cm9rZS1saW5lY2FwPSJz'
    b'cXVhcmUiPgogICAgICA8cGF0aCBmaWxsPSIjMDAwIiBzdHJva2U9Im5vbmUiIGQ9Ik0xOTYu'
    b'NiAxMTYuM2g2NHY0NGgtNjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMjkuOCAxNTMuOWgtMzls'
    b'LTguNyA1Ljd2Nmg0Ny43bS0xNi4zLTM3YzUuNiAwIDEwLjIgNC43IDEwLjIgMTAuNXYxNC43'
    b'aDcuM3YtNTZoLTQwLjN2NTZoMTIuNnYtMTQuN2MwLTUuNiA0LjUtMTAuNSAxMC4yLTEwLjV6'
    b'Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiMwMDAiIHN0cm9rZT0ibm9uZSIgZD0iTTIwNC41IDYw'
    b'aDE4LjZ2MzRoLTE4LjZ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMjMgODguN2gtMTYuMnYtNS44'
    b'aC0xMS45djUuOGgtOHYtNS44SDE4MnYxMC40aDQxbS0zNi4yIDBoMzV2NC41aC0zNXptMTQt'
    b'NDUuN1Y4M2g2di05LjdjMC0zLjYgMi41LTYuNiA2LjEtNi44aC40YTYuOCA2LjggMCAwIDEg'
    b'Ni44IDYuOFY4M2g1LjdWNDcuNnptLTIuMy00Ljh2NC44aDI5LjN2LTQuOHptLTMuNy05LjF2'
    b'OS4xaDM1di05LjFoLTUuM3Y0LjdoLTYuNnYtNC43aC0xMHY0LjdoLTYuNXYtNC43ek0xODIg'
    b'MTU5LjZoNDhtMzEtMi44aC0zMi40bC05LjggNC43djdIMjYxIi8+CiAgICAgIDxwYXRoIHN0'
    b'cm9rZS1saW5lY2FwPSJidXR0IiBkPSJNMjE4LjggMTYxLjVIMjYyIi8+CiAgICA8L2c+CiAg'
    b'ICA8dXNlIHhsaW5rOmhyZWY9IiNnaS1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgtMSAwIDAgMSA1MTIgMCkiLz4KICAgIDxnIGZpbGw9IiNmOGQ4'
    b'MGUiPgogICAgICA8ZyBzdHJva2UtbGluZWNhcD0icm91bmQiPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZS13aWR0aD0iLjgiIGQ9Ik0yNzMuMyAxNTBjLTIuNyAxLTUgMi40LTcuNSAzLjhhNzIu'
    b'NCA3Mi40IDAgMCAwLTguOSA2Yy0xIC43LTIgMS40LTIuNyAyLjQtMSAuOC0yIDItMS44IDMu'
    b'NSAwIC42LjgtLjggMS40LS45YTQuNCA0LjQgMCAwIDEgMy4xLS40YzEuMy0xLjQgMy0yLjMg'
    b'NC40LTMuNGE3Ny40IDc3LjQgMCAwIDEgMTMtNy42bC0xLTMuNHoiLz4KICAgICAgICA8cGF0'
    b'aCBkPSJNMjYwLjQgMTU3LjR2My45bTIuNC01LjZ2My45bTIuNC01LjR2My44bTIuNS01LjN2'
    b'NCIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjgiIGQ9Im0yMzguOSAxNTAuMi0x'
    b'LjIgMy4zYTg2LjYgODYuNiAwIDAgMSAxNS44IDhjMS43IDEuMiAzLjUgMi4zIDQuOCAzLjku'
    b'My44LS41IDEuNS0xLjMgMS4yLS43LS4yLTEuNS0uNS0yLjIgMC0xLjEuNS0yLjEgMi4yLS41'
    b'IDIuNyAyLjQgMS42IDYuMS45IDcuMi0xLjguNi0xLjQuNy0zLjItLjUtNC40LTItMi4zLTQu'
    b'OC00LTcuNC01LjdhODkuMiA4OS4yIDAgMCAwLTE0LjctNy4yeiIvPgogICAgICAgIDxwYXRo'
    b'IGQ9Im0yNTQgMTU4LS4zIDMuNG0zLjEtMS43LS44IDMuM20zLjgtMS0xLjggMi42bTIuNyAz'
    b'LjYtMi42LTEuNG0zLjQtMS40LTMgLjNtLS44IDQtLjItMi42bS0xLS4zLTIuNCAxLjhtLTku'
    b'NC0xNS43djMuMW02LjMuM3YzLjVtLTMuMi01LjJ2My4zIi8+CiAgICAgIDwvZz4KICAgICAg'
    b'PHBhdGggZD0iTTIzNS44IDIyNy42djhoNXYtNGg2Ljl2NGg1LjR2LTh6bTAgMTF2OEgyNTN2'
    b'LThoLTUuNHY0aC02Ljl2LTR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNTMgMTkzLjdoNXY1OGgt'
    b'NXoiLz4KICAgICAgPHBhdGggZD0iTTI1MyAxOTguN2g1djUwaC01em0yLjYtMTkuMyAxMC42'
    b'IDYuMi0xMC42IDYuMi0xMC43LTYuMnptLTE0LjMgNGgtMi43djQuNGgyLjdsMTQuMyA4LjMg'
    b'MTQuMi04LjNoMi44di00LjRoLTIuOGwtMTQuMi04LjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0y'
    b'NTUuMyAxNjQuM2E1IDUgMCAwIDAtNCA1LjF2MTEuMmE1IDUgMCAwIDAgNC42IDQuNiA0Ljkg'
    b'NC45IDAgMCAwIDQuOC0yLjhsLTEuNy0xYTIuOSAyLjkgMCAwIDEtMyAxLjhjLTEuNiAwLTIu'
    b'OS0xLjYtMi43LTMuMXYtMTEuMmEyLjkgMi45IDAgMCAxIDMtMi42Yy42LS4yIDEuNS43IDEu'
    b'OSAwIC42LS45LS40LTEuNS0xLTJoLTEuOXptNS44IDMuOWE1IDUgMCAwIDEtMS45IDEuNnY3'
    b'LjVsMiAxLjF2LTEwLjJ6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSIjZGEwMDBjIj4KICAg'
    b'ICAgPHBhdGggZmlsbD0iIzAwMCIgc3Ryb2tlPSJub25lIiBkPSJNMjQwLjggMzguNGgyOS4z'
    b'djUzLjJoLTI5LjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yMzguOCAzOC40djQ0LjVoOS4zVjY5'
    b'LjdjMC0zIDItNy4zIDcuOS03LjNzOCA0LjMgOCA3LjNWODNoOS4yVjM4LjR6bTE1LjggNWgy'
    b'Ljh2MTUuMmgtMi44em0tOC4zIDNoM3YxMS4xaC0zem0xNi41IDBoMi45djExLjFoLTN6TTIz'
    b'NS42IDMydjYuM2g0MC44VjMyem0tMy44LTcuNFYzMmg0OC41di03LjRoLTYuMXY0aC03di00'
    b'aC03Ljh2NGgtNi44di00aC03Ljl2NEgyMzh2LTR6bS05IDczLjJ2NC42aDY2LjV2LTQuNnoi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTIyMCA4Mi45djE1aDcydi0xNWgtNi44djUuOEgyNzZ2LTUu'
    b'OGgtMTIuMnY1LjhIMjQ4di01LjhoLTEyLjJ2NS44aC05di01Ljh6Ii8+CiAgICAgIDxwYXRo'
    b'IHN0cm9rZS1saW5lam9pbj0icm91bmQiIGQ9Ik0yMjguNyAxMDIuNHY1NC40aDEyLjh2LTIw'
    b'LjRjMC05LjUgNi40LTE0IDE0LjUtMTQgNy44IDAgMTQuNSA0LjUgMTQuNSAxNHYyMC40aDEy'
    b'Ljh2LTU0LjR6Ii8+CiAgICA8L2c+CiAgPC9nPgo8L3N2Zz4K', 'GI')

GI = b64_GI
index.append("GI")
index.append("GIB")
index.append("Gibraltar")
catalog["GI"] = GI
catalog["GIB"] = GI
catalog["Gibraltar"] = GI
country["Gibraltar"] = ('GI', 'GIB', 0)
lookup["GI"] = ('GI', 'GIB', 'Gibraltar', 0)
lookup["Gibraltar Gibraltar"] = ('GI', 'GIB', 'Gibraltar', 0)
lookup["GIB"] = ('GI', 'GIB', 'Gibraltar', 0)
lookup["Gibraltar"] = ('GI', 'GIB', 'Gibraltar', 0)
details["GI"] = {"continent":"Europe","capital":"Gibraltar","currency":"Gibraltar Pound","web":".gi","lang":"en-GI | es | it | pt","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_GL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdsIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2QwMGMzMyIgZD0iTTAgMjQwaDY0MHYy'
    b'NDBIMHptODAgMGExNjAgMTYwIDAgMSAwIDMyMCAwIDE2MCAxNjAgMCAwIDAtMzIwIDAiLz4K'
    b'PC9zdmc+Cg==', 'GL')

GL = b64_GL
index.append("GL")
index.append("GRL")
index.append("Greenland")
catalog["GL"] = GL
catalog["GRL"] = GL
catalog["Greenland"] = GL
country["Greenland"] = ('GL', 'GRL', 0)
lookup["GL"] = ('GL', 'GRL', 'Greenland', 0)
lookup["Nuuk Greenland"] = ('GL', 'GRL', 'Greenland', 0)
lookup["GRL"] = ('GL', 'GRL', 'Greenland', 0)
lookup["Greenland"] = ('GL', 'GRL', 'Greenland', 0)
details["GL"] = {"continent":"Americas","capital":"Nuuk","currency":"Danish Krone","web":".gl","lang":"kl | da-GL | en","tz":"-03:00","altname":""}
#----------------------------------------------------------------------
b64_GM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImdtLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMC00OGg2NDB2NDgw'
    b'SDB6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1bGU9ImV2ZW5v'
    b'ZGQiIHN0cm9rZS13aWR0aD0iMXB0IiBjbGlwLXBhdGg9InVybCgjZ20tYSkiIHRyYW5zZm9y'
    b'bT0idHJhbnNsYXRlKDAgNDgpIj4KICAgIDxwYXRoIGZpbGw9InJlZCIgZD0iTTAtMTI4aDY0'
    b'MFY4NS4zSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCA4NS4zaDY0MFYxMjFI'
    b'MHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDkiIGQ9Ik0wIDEyMC45aDY0MFYyNjNIMHoiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDI2My4xaDY0MHYzNS42SDB6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjMDkwIiBkPSJNMCAyOTguN2g2NDBWNTEySDB6Ii8+CiAgPC9nPgo8L3N2'
    b'Zz4K', 'GM')

GM = b64_GM
index.append("GM")
index.append("GMB")
index.append("Gambia")
catalog["GM"] = GM
catalog["GMB"] = GM
catalog["Gambia"] = GM
country["Gambia"] = ('GM', 'GMB', 0)
lookup["GM"] = ('GM', 'GMB', 'Gambia', 0)
lookup["Banjul Gambia"] = ('GM', 'GMB', 'Gambia', 0)
lookup["GMB"] = ('GM', 'GMB', 'Gambia', 0)
lookup["Gambia"] = ('GM', 'GMB', 'Gambia', 0)
details["GM"] = {"continent":"Africa","capital":"Banjul","currency":"Dalasi","web":".gm","lang":"en-GM | mnk | wof | wo | ff","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_GN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWduIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSJyZWQiIGQ9Ik0wIDBoMjEzLjN2'
    b'NDgwSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmYwIiBkPSJNMjEzLjMgMGgyMTMuNHY0ODBI'
    b'MjEzLjN6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDkwIiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'GN')

GN = b64_GN
index.append("GN")
index.append("GIN")
index.append("Guinea")
catalog["GN"] = GN
catalog["GIN"] = GN
catalog["Guinea"] = GN
country["Guinea"] = ('GN', 'GIN', 0)
lookup["GN"] = ('GN', 'GIN', 'Guinea', 0)
lookup["Conakry Guinea"] = ('GN', 'GIN', 'Guinea', 0)
lookup["GIN"] = ('GN', 'GIN', 'Guinea', 0)
lookup["Guinea"] = ('GN', 'GIN', 'Guinea', 0)
details["GN"] = {"continent":"Africa","capital":"Conakry","currency":"Guinean Franc","web":".gn","lang":"fr-GN","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_GP = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdwIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'GP')

GP = b64_GP
index.append("GP")
index.append("GLP")
index.append("Guadeloupe")
catalog["GP"] = GP
catalog["GLP"] = GP
catalog["Guadeloupe"] = GP
country["Guadeloupe"] = ('GP', 'GLP', 0)
lookup["GP"] = ('GP', 'GLP', 'Guadeloupe', 0)
lookup["Basse-Terre Guadeloupe"] = ('GP', 'GLP', 'Guadeloupe', 0)
lookup["GLP"] = ('GP', 'GLP', 'Guadeloupe', 0)
lookup["Guadeloupe"] = ('GP', 'GLP', 'Guadeloupe', 0)
details["GP"] = {"continent":"Americas","capital":"Basse-Terre","currency":"Euro","web":".gp","lang":"fr-GP","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_GQ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdxIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2UzMjExOCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MzIw'
    b'SDB6Ii8+CiAgPHBhdGggZmlsbD0iIzNlOWEwMCIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzAwNzNjZSIgZD0iTTAgMHY0ODBsMTgwLTI0MHoiLz4KICA8ZyBzdHJv'
    b'a2U9IiMwMDAiPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI4MS42IDE5MS44aDc2LjZW'
    b'MjcyYzAgMjctMzUuMiA2LjItMzguMiAyMC42LTUuMi0xNC44LTM4LjIgNi42LTM4LjItMjIu'
    b'MmwtLjItNzguNnoiLz4KICAgIDxwYXRoIGZpbGw9IiM3MzQ1MmIiIHN0cm9rZS13aWR0aD0i'
    b'LjIiIGQ9Ik0zMjUuNCAyNzkuOHMtMSAxLTIuOC4yYy0xLjgtLjgtMi01MS40LTItNTEuNCA0'
    b'LTQuNCA3LjItNS44IDcuMi01LjhsMi40IDJjLTkgNC42LTguMiAxMS4yLTcuNCAyMi42LjIg'
    b'NC4yLjIgOS42IDEuMiAxNC44IDEuNCA2LjYgNC4yIDEyLjIgNC40IDE2LjQuMiAyLjYtMyAx'
    b'LjItMyAxLjJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjNzM0NTJiIiBzdHJva2Utd2lkdGg9Ii4y'
    b'IiBkPSJNMzE5LjIgMjIxLjZoMy42Yy0zIDI5LS40IDQ2LjItLjQgNTQuNiAwIDIuOCAxLjYg'
    b'My44IDEuNCAzLjgtMy42IDQtNS40LS4yLTUuNC0uMnoiLz4KICAgIDxwYXRoIGZpbGw9IiNh'
    b'MzY2MjkiIHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik0zMTMuNiAyNzkuOGMtMy40IDEuNi0zLjgt'
    b'MS42LTMuNi0yIDcuNC0xNSAxMC42LTQ4IDMuOC01MS42bC40LTMuMmMyLjYuOCA1IDQuMiA1'
    b'IDQuMiAxIDM3IDAgNTIuMi0uNiA1Mi44LTMuNiAzLjgtNS0uNi01LjItMSIvPgogICAgPHBh'
    b'dGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIuMiIgZD0iTTMxMy40IDI3OS4yYy0uNi0z'
    b'LjIgNS4yLTExLjQgNC44LTIwbTUgN2MxLjggNSAyLjYgOS40IDIuMiAxMy42Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjMDA5YTNiIiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJNMzMxIDIwOGMxLjIt'
    b'MS40IDEuMi0xLjQgMy40LTEuNC40LTMgNS40LTMgNS44LjggNC0uOCA0LjggMS42IDMuMiA0'
    b'IDMuOC0xIDcuMiAwIDYuMiA0LjQgNi44IDEuOCA0LjIgNi42IDEuMiA3LjYtLjQgMy0zLjIg'
    b'NC03IDIuOC00LjggMy40LTcuNiAyLjItOS44LTEuMi01LjQuOC01LjgtLjQtOC4yLTMuNC00'
    b'LjIgMS44LTUgMS44LTguNi0uNC0uMiAyLjgtMS4yIDItMyAxLjguMiAzLjYtMS4yIDUuMi00'
    b'LjQgNCAyLjQgNS0zLjggNy4yLTYuOCAzLTIuOC4yLTMtLjYtNC40LTEuNi0xLjIgNC01LjYg'
    b'My40LTYuNCAxLjItNS42LS44LTUtMy44LS40LTQgLjQtMy4yIDMuMi0yLjYgNS0yLjIuMi0y'
    b'IDEuNC0xLjYgMi40LTEuMi0uNi0xLjQtLjItMi4yIDEuNi0yLjYtMi42LTMuNC0xLTQuNiAx'
    b'LjYtNS44LTEuNC0zLjIgMS0zIDIuOC0zLjItLjItMy40LjgtNCA0LjQtNC40LS40LTEuMi4y'
    b'LTIuMiAyLjItMi4yLTEuMi0zLjQuNC00LjIgNC0zLjYuNi01IDExLjItMi42IDEwLjQgNC4y'
    b'IDMgLjQgNCAxIDQuOCAzLjR6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2Utd2lk'
    b'dGg9Ii4yIiBkPSJNMzA5LjYgMjA2LjJjLjguNCAxLjggMCAyIDIuMiAxLjYtMi44IDMuNi0x'
    b'LjIgMy42IDJtMTEtNS44Yy0uOCAxLjItMy44IDEuMi0zLjQgNC40LTEtMS40LTMtMS44LTMu'
    b'OC0uNG0xMi0uNmMwIC44LS4yIDMuMi0xIDQuNG0xMy40LTFjLjIuMi0yLjggMC00LjIgMW0x'
    b'MS42IDExYy0uOC0uNC0yLjQtMS40LTMuNi4yIDAtLjggMC0zLTIuMi0zbS0xLjIgNS42YzAt'
    b'Mi0uNC0yLjYtLjgtMy4ybS01LjguNGMtMS42LTEuMi0zLjIuNi0zLjIgMS42bS04LjQtMy40'
    b'YzAtLjgtLjYtMi40LjgtM00zMDIuOCAyMzBjLjQtMiAxLjgtMiAxLjYtMy0uMi0xLjYtMi0z'
    b'LTQuMi0uOG00LjIuOGMxLjItLjQgMi40LS4yIDIuOC40bS02LjItNy44Yy44LS44IDIuOC0u'
    b'NiA0IDBtMC00LjhjMSAwIDIuOC0uNCAzLjQgMS40IDIuMi0zLjQgMy44LTMgNC4yLTIuMm00'
    b'LS40YzEuNi0uNiA0LjQgMSA2IDMuOC44LTIuMiAyLTEuOCAzLjItMm03LjYgMmMyLjYtMS4y'
    b'IDQuMiAxLjIgNSAyLjIgMS4yLTEuNiAyLjItMS42IDMuNC0xLjZtLTMyLjYgNC4yYy42LTEg'
    b'Mi0xLjIgMy0uNi0uMi0xLjggMS0yLjYgMS44LTIuMiIvPgogICAgPHBhdGggZmlsbD0iZ29s'
    b'ZCIgc3Ryb2tlLXdpZHRoPSIuNyIgZD0ibTMxNy40IDE4MC41LTQuNC4yLTIuMiA0LTIuNC0z'
    b'LjgtNC40LjIgMi00LTIuNC0zLjcgNC42LS4yIDItNCAyLjQgMy44IDQuNC0uMi0yIDR6bS0x'
    b'OC44IDEuNS00LjQgMS0xLjIgNC4zLTMuMi0zLjItNC4yIDEgMS4yLTQuMi0zLTMuMiA0LjIt'
    b'MS4xIDEuMi00LjMgMy4yIDMuMiA0LjQtMS0xLjQgNC4zem0tMTguMiAzLjctNCAyLS4yIDQu'
    b'NC0zLjgtMi40LTQgMiAuNC00LjUtMy44LTIuNCA0LTIgLjQtNC41IDMuNiAyLjUgNC0yLS4y'
    b'IDQuNHptNDIuOC01LjIgNC40LjIgMiA0IDIuNC0zLjggNC40LjItMi00IDIuNC0zLjctNC40'
    b'LS4yLTIuMi00LTIuNCAzLjgtNC40LS4yIDIgNHpNMzQyIDE4Mmw0LjIgMSAxLjIgNC4zIDMu'
    b'Mi0zLjIgNC4yIDEtMS4yLTQuMiAzLjItMy4yLTQuNC0xLjEtMS4yLTQuMy0zLjIgMy4yLTQu'
    b'Mi0xIDEuMiA0LjN6bTE4IDMuNyA0IDIgLjIgNC40IDMuOC0yLjQgNCAyLS4yLTQuNSAzLjYt'
    b'Mi40LTQtMi0uMi00LjUtMy44IDIuNS00LTIgLjQgNC40eiIvPgogICAgPGcgZmlsbD0iI2Zm'
    b'ZiIgc3Ryb2tlLXdpZHRoPSIuNyI+CiAgICAgIDxwYXRoIGQ9Im0zNjUuNCAyNzAuNCA1IDcu'
    b'MiA0LjYtNi44LTMuMi01Ljh6bS0zMS44IDIxIC40IDcuMnMyIDAgMy44LS42YzEuNi0uNiAz'
    b'LTEuOCAzLTEuOGwtLjItMy44em0tMjYuOCAwLS40IDdzLTEuOCAwLTMuNi0uNGMtMS42LS40'
    b'LTMtMS40LTMtMS40bC0yLTQuOHptLTMyLjItMjEtNS4yIDcuMi01LjYtOS4yIDQuMi00LjR6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yOTkuNiAzMDUuOGMwIDYuOCA0MS4yIDYuOCA0MS4yIDB2'
    b'LTkuNmMwIDUtNDEuMiA0LTQxLjIgMHoiLz4KICAgICAgPHBhdGggZD0iTTI2Mi44IDI4My42'
    b'YzMuNiAxOC40IDM2LjggMTguOCAzNi44IDE4Ljh2LTYuMmMtLjgtMi40LjYtMy4yIDYtNCAy'
    b'LjItLjIgMS4yLTMuNCAxLjItMy40cy0xNC40IDIuNi0yNC42LTEuNGMtMTMuOC01LjYtMTUu'
    b'OC0xNi40LTE1LjgtMTYuNHMtMSA4LjQtMy42IDEyLjZ6bTExNC42IDBjLTMuNCAxOC40LTM2'
    b'LjYgMTguOC0zNi42IDE4Ljh2LTYuMmMuNi0yLjQtLjgtMy4yLTYuMi00LTIuMi0uMi0xLTMu'
    b'NC0xLTMuNHMxNC40IDIuNiAyNC42LTEuNGMxMy42LTUuNiAxNS4yLTE2LjQgMTUuMi0xNi40'
    b'czEuNCA4LjQgNCAxMi42eiIvPgogICAgICA8cGF0aCBkPSJNMjY1LjQgMjc2LjZjLTkuMi01'
    b'LTItMTAuMi0xLjItMjUgMS40IDkgMTEuNiAxMi44IDEwLjQgMTguNi00LjIuMi02LjItNi4y'
    b'LTguMi44bC0xIDUuNnptMTA5LjQgMGM5LjItNS4yIDEuNi0xMC4yLjgtMjUtMS40IDktMTEu'
    b'NCAxMi44LTEwLjIgMTguNiA0IC4yIDYtNi4yIDggLjhsMS40IDUuNHoiLz4KICAgIDwvZz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0ibm9uZSIgZD0ibTI3MSAyODMuNCAxIC44LTIuMiAyLjRjLTEg'
    b'MS0xLjEgMS42LS41IDIuMi43LjcgMS4zLjQgMi0uNGwyLjUtMi42LjguOC0yLjQgMi44Yy0x'
    b'LjMgMS41LTIuNSAxLjItMy42LjItLjgtLjgtMS40LTIgMC0zLjVsMi40LTIuN3ptNCAzLjQg'
    b'MSAuNi0uMiA0LjggMi4yLTMuNCAxIC42LTMuMiA1LjItMS4yLS42LjItNC44LTIuMiAzLjQt'
    b'MS0uNnptMS44IDguNCAyLjgtNS42IDEgLjYtMi42IDUuNHptNC40LTQuOC0yLjIgNS44IDIu'
    b'Mi44YzIgLjcgMy0uMiAzLjYtMS45LjctMS44LjQtMy0xLjYtMy45bC0yLS44em0uOCAxLjRj'
    b'MiAuNyAyLjIgMS41IDEuNiAzLS42IDEuMy0xIDEuOC0zIC44bDEuNC0zLjh6bTUuOC44LTMu'
    b'NiA1LjQgMS40LjQuOC0xLjQgMi40LjYuMiAxLjQgMS40LjItMS40LTYuNC0xLjItLjJ6bS40'
    b'IDEuNC40IDIuNC0xLjYtLjIgMS4yLTIuMnptMy0uOS0uMiA2LjJoMi4zYzIuMi4xIDIuOC0x'
    b'IDIuOS0zIDAtMS44LS43LTMtMi45LTNsLTIuMS0uMnptMS4yIDFjMi4yLjEgMi41LjggMi41'
    b'IDIuMy0uMSAxLjUtLjQgMi4xLTIuNiAxLjh2LTR6bTE5LjggNy43djYuNGgxLjR2LTIuNHMx'
    b'LjIgMCAyLjItLjJjLjctLjIgMS4zLS43IDEuMy0yIDAtMS4yLS43LTEuOC0xLjktMS44aC0z'
    b'em0xLjQgMWgxLjRjMS4xIDAgMSAxLjggMCAxLjhoLTEuNHYtMS44em01LjgtMS0yLjYgNi40'
    b'aDEuNGwuNi0xLjZoMi42bC42IDEuNmgxLjRsLTIuNi02LjRoLTEuNHptLjYgMS40IDEgMi40'
    b'aC0xLjhsLjgtMi40em0zLjQgMy44IDMuNC00LjJoLTN2LTFoNC44djFMMzI1IDMwN2gzLjZ2'
    b'MS4yaC01LjJ6bTIwLjItMTIuNCAxLjItLjIuNiAzLjZjLjIgMS4zLS40IDIuMS0xLjMgMi41'
    b'LTEgLjQtMi40IDAtMi41LTEuN2wxLS4yYy4yIDEgLjYgMS4xIDEgMSAuNS0uMi43LS44LjYt'
    b'MS40em0yLS40IDEuMS0uMi42IDNjLjIgMS4zLjYgMS44IDEuNSAxLjcgMS0uMiAxLjEtLjgu'
    b'OS0ybC0uNy0zLjEgMS4yLS4yLjggMy4zYy40IDItLjYgMi43LTIgMy0xLjEuMi0yLjQgMC0y'
    b'LjgtMnptNi4yIDIuOCAxLS40Yy41LjkgMS4yLjggMS44LjYuOC0uNCAxLTEuMS41LTEuNC0u'
    b'Ni0uMy0yIC4yLTIuNyAwLS45LS40LTEuMy0xLTEuMi0xLjcgMC0xIC44LTEuNCAxLjctMS43'
    b'IDEtLjMgMi0uMiAyLjcgMWwtMS4yLjRjLS40LS43LTEtLjYtMS40LS40LS40LjItMSAuNS0u'
    b'NiAxIC4yLjUgMS43LjIgMi41LjJzMS40LjYgMS41IDEuM2MuMiAxLjEtLjIgMS43LTEuNSAy'
    b'LjItMS41LjYtMi45IDAtMy4xLTEuMXptNS40LTUtMS42LjgtLjQtMSA0LjQtMS44LjQuOC0x'
    b'LjYuOCAxLjggNC40LTEgLjZ6bTIuNi0yLjIgMS0uNiAyLjggNS4yLTEgLjZ6bTYuOC40IDEu'
    b'Mi0uNGEyLjQgMi40IDAgMCAxLTIuNCAzLjNjLTMgMC0zLjQtMy40LTIuOS00LjUuOC0xLjkg'
    b'My0xLjggNC0uOGwtMSAuOGMtLjYtLjgtMi0uMy0yIC40YTIuNyAyLjcgMCAwIDAgMS40IDNj'
    b'MSAuNCAyLjQtLjggMS43LTEuOHptLS42LTQuMiAxLS44IDMuNiA0LjgtMSAuOHptMy44LTMt'
    b'MSAuOCAyLjIgNiAxLTEtLjYtMS4yIDEuOC0xLjYgMS4yLjYgMS0uOC01LjYtMi44em0uNCAx'
    b'LjQgMiAxLTEuMiAxLjItLjgtMi4yeiIvPgogIDwvZz4KPC9zdmc+Cg==', 'GQ')

GQ = b64_GQ
index.append("GQ")
index.append("GNQ")
index.append("Equatorial Guinea")
catalog["GQ"] = GQ
catalog["GNQ"] = GQ
catalog["Equatorial Guinea"] = GQ
country["Equatorial Guinea"] = ('GQ', 'GNQ', 0)
lookup["GQ"] = ('GQ', 'GNQ', 'Equatorial Guinea', 0)
lookup["Malabo Equatorial Guinea"] = ('GQ', 'GNQ', 'Equatorial Guinea', 0)
lookup["GNQ"] = ('GQ', 'GNQ', 'Equatorial Guinea', 0)
lookup["Equatorial Guinea"] = ('GQ', 'GNQ', 'Equatorial Guinea', 0)
details["GQ"] = {"continent":"Africa","capital":"Malabo","currency":"CFA Franc BEAC","web":".gq","lang":"es-GQ | fr","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_GR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWdyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzBkNWVhZiIgZmls'
    b'bC1ydWxlPSJldmVub2RkIiBkPSJNMCAwaDY0MHY1My4zSDB6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMCA1My4zaDY0MHY1My40SDB6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzBkNWVhZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMCAxMDYuN2g2'
    b'NDBWMTYwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBk'
    b'PSJNMCAxNjBoNjQwdjUzLjNIMHoiLz4KICA8cGF0aCBmaWxsPSIjMGQ1ZWFmIiBkPSJNMCAw'
    b'aDI2Ni43djI2Ni43SDB6Ii8+CiAgPHBhdGggZmlsbD0iIzBkNWVhZiIgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBkPSJNMCAyMTMuM2g2NDB2NTMuNEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTAgMjY2LjdoNjQwVjMyMEgweiIvPgogIDxwYXRo'
    b'IGZpbGw9IiMwZDVlYWYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTAgMzIwaDY0MHY1My4z'
    b'SDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMCAz'
    b'NzMuM2g2NDB2NTMuNEgweiIvPgogIDxnIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlLXdpZHRoPSIxLjMiPgogICAgPHBhdGggZD0iTTEwNi43IDBIMTYwdjI2Ni43'
    b'aC01My4zeiIvPgogICAgPHBhdGggZD0iTTAgMTA2LjdoMjY2LjdWMTYwSDB6Ii8+CiAgPC9n'
    b'PgogIDxwYXRoIGZpbGw9IiMwZDVlYWYiIGQ9Ik0wIDQyNi43aDY0MFY0ODBIMHoiLz4KPC9z'
    b'dmc+Cg==', 'GR')

GR = b64_GR
index.append("GR")
index.append("GRC")
index.append("Greece")
catalog["GR"] = GR
catalog["GRC"] = GR
catalog["Greece"] = GR
country["Greece"] = ('GR', 'GRC', 0)
lookup["GR"] = ('GR', 'GRC', 'Greece', 0)
lookup["Athens Greece"] = ('GR', 'GRC', 'Greece', 0)
lookup["GRC"] = ('GR', 'GRC', 'Greece', 0)
lookup["Greece"] = ('GR', 'GRC', 'Greece', 0)
details["GR"] = {"continent":"Europe","capital":"Athens","currency":"Euro","web":".gr","lang":"el-GR | en | fr","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_GS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ncyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGxpbmVhckdyYWRpZW50IGlkPSJncy1i'
    b'Ij4KICAgICAgPHN0b3Agb2Zmc2V0PSIwIiBzdG9wLWNvbG9yPSIjZDVkZmZmIi8+CiAgICAg'
    b'IDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iI2ZmZiIvPgogICAgPC9saW5lYXJHcmFk'
    b'aWVudD4KICAgIDxsaW5lYXJHcmFkaWVudCBpZD0iZ3MtYSI+CiAgICAgIDxzdG9wIG9mZnNl'
    b'dD0iMCIgc3RvcC1jb2xvcj0iIzQ3NDc0NyIvPgogICAgICA8c3RvcCBvZmZzZXQ9IjEiIHN0'
    b'b3AtY29sb3I9IiNmNTAiLz4KICAgIDwvbGluZWFyR3JhZGllbnQ+CiAgICA8bGluZWFyR3Jh'
    b'ZGllbnQgeGxpbms6aHJlZj0iI2dzLWEiIGlkPSJncy1jIiB4MT0iMTA5LjMiIHgyPSIxMTAu'
    b'OSIgeTE9IjIxOC41IiB5Mj0iMTczLjQiIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoMS4x'
    b'NzggMCAwIC41MDg0OSAzODggMzguMykiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNl'
    b'Ii8+CiAgICA8bGluZWFyR3JhZGllbnQgaWQ9ImdzLWQiIHgxPSIxMjUuOSIgeDI9IjEyNiIg'
    b'eTE9IjMxNi40IiB5Mj0iMzM3LjIiIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoLjk2MDY3'
    b'IDAgMCAuNjIzNSAzODggMzguMykiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIj4K'
    b'ICAgICAgPHN0b3Agb2Zmc2V0PSIwIiBzdG9wLWNvbG9yPSIjYjUwMDAwIi8+CiAgICAgIDxz'
    b'dG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iI2ZmYzUwMCIvPgogICAgPC9saW5lYXJHcmFk'
    b'aWVudD4KICAgIDxsaW5lYXJHcmFkaWVudCB4bGluazpocmVmPSIjZ3MtYiIgaWQ9ImdzLWUi'
    b'IHgxPSI0MDcuOSIgeDI9IjQ1Ni40IiB5MT0iMTQ5LjQiIHkyPSIxNDcuNCIgZ3JhZGllbnRU'
    b'cmFuc2Zvcm09Im1hdHJpeCguNDM2MSAwIDAgMS4zNzM0OSAzODggMzguMykiIGdyYWRpZW50'
    b'VW5pdHM9InVzZXJTcGFjZU9uVXNlIi8+CiAgICA8bGluZWFyR3JhZGllbnQgeGxpbms6aHJl'
    b'Zj0iI2dzLWEiIGlkPSJncy1mIiB4MT0iMjE1LjgiIHgyPSIyMjkiIHkxPSIxMDMiIHkyPSIx'
    b'MDMiIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoLjU3Nzk0IDAgMCAxLjAzNjQxIDM4OCAz'
    b'OC4zKSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5lYXJHcmFk'
    b'aWVudCB4bGluazpocmVmPSIjZ3MtYiIgaWQ9ImdzLWciIHgxPSIxMTcuNiIgeDI9Ijc4LjIi'
    b'IHkxPSIxMDQwLjQiIHkyPSIxMDAzLjciIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoMS45'
    b'OTkxIDAgMCAuMjk5NjIgMzg4IDM4LjMpIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVz'
    b'ZSIvPgogICAgPGxpbmVhckdyYWRpZW50IHhsaW5rOmhyZWY9IiNncy1iIiBpZD0iZ3MtaCIg'
    b'eDE9IjI2NC43IiB4Mj0iMjU1IiB5MT0iMjQ2IiB5Mj0iMjI2LjQiIGdyYWRpZW50VHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjY5MTQyIDAgMCAuODY2MjggMzg4IDM4LjMpIiBncmFkaWVudFVuaXRz'
    b'PSJ1c2VyU3BhY2VPblVzZSIvPgogIDwvZGVmcz4KICA8cGF0aCBmaWxsPSIjMDA2IiBkPSJN'
    b'MCAwaDY0MHY0ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjNmE0YzJkIiBzdHJva2U9IiMwMDAi'
    b'IGQ9Ik00NzEgMzQ1cy0yLjYgNi44LTQgNi44Yy0xLjYgMC03LTMtNy0zcy0zLjkgNi40LTYg'
    b'Ni43Yy0yIC40LTcuNC0uOS03LjQtLjlzLTUuMiAwLTUuNC0uN2MtLjItLjguMi0yLjMuMi0y'
    b'LjNzLTcuNSA2LTkuMSA1LjZjLTEuNy0uMy03LjMtNy40LTcuMy03LjRsLTEgMy43LTEwLjYt'
    b'LjQtOS4zLTZzLTUuMiA4LjYtNS40IDguNGMtLjItLjEtOS4xIDIuMS05LjEgMi4xbC0uNi0x'
    b'LjctNi0zLjVzNC43LTYuNSA0LjctNi43YzAtLjItMi4yLTEtMi4yLTFsLTMuNCAyLjgtNi45'
    b'IDQuNS02LjktMy4yIDMtNS42LjQtNCA1LjQtOC4zIDY2LjItNjQuMyAzMi42IDYwLjJ6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBkPSJtNTE4IDM0OC44IDE3LjMt'
    b'LjYtNy40LTMuNiA2NS43LTIuNS05LjMtMy41LTguMi0xMS4yLTM0LTIuNXMtMi42LTItNi43'
    b'LTFjLS4yLTIuNi0zLjQtNi0zLjQtNmwtMjEtMS43LTEzIDkgOC44IDIyLjZ6Ii8+CiAgPHBh'
    b'dGggZmlsbD0idXJsKCNncy1jKSIgc3Ryb2tlPSIjMDAwIiBkPSJtNDUxIDE1NiAxLjgtNnMz'
    b'LTUgMy03LjRjMC0yLjIgMi4zLTQuOSAyLjMtNC45czYuOS0yIDguNCAyLjNjNy40LTExLjMg'
    b'MTYuMi0uNiAxNi4yLS42bDIuNC0yLjggNS02czcgNi41IDcgNy42Yy4yIDEuMiAxLjMuNCAx'
    b'LjMuNGw3LjYtLjZhOSA5IDAgMCAwIDIuOSA4LjJjMi43IDEuNiA1LjEgMTEgNS4xIDExeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiM2NTYyNjMiIHN0cm9rZT0iIzAwMCIgZD0iTTUxOCAyMjYuMWMx'
    b'LjQtLjggNS41LTIuMSA1LTguMi0uNS02LTUuNy02LjgtOC43LTYuNi0zIC4yLTUuNSAyLjgt'
    b'NS41IDIuOGwtOS44LTYuMnM0LjktMzAuNyAxMC0zMi42YzUtMy41IDUuOC01IDUuOC01Ljgg'
    b'MC0uOS0xLjgtMi45LTEuOC0yLjlsLTMxLjctMy43LTMwIDMuNXMtMi4yIDMuNi0yIDVjLjQg'
    b'MS40LjUgMi45IDUuOCA3IDYgNC42IDEwIDMwLjggMTAgMzAuOHMtOC4zIDQuMi04LjkgMy42'
    b'Yy0uNS0uNS0zLTEtNC4zLS44LTEuMy4yLTUuNyAyLjUtNS43IDguMiAwIDUuOCA0LjQgOS4x'
    b'IDQuNCA5LjFzMjguNi0zLjMgMzIuOSA0LjZjNC4xLTkuNSAzMS4zLTYuMiAzNC42LTcuOHoi'
    b'Lz4KICA8cGF0aCBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIGQ9Ik01'
    b'NDguOSAxOTQuMnMuMy0zLjMgMi43LTQuOWMyLjQtMS42IDE4LjItMi40IDIyIDAgMy44IDIu'
    b'NCA1LjIgMTQuMSA1LjIgMTQuMXMyLjQgNC4xIDIuNiA3LjJjLjEgMyAuNSA1IC41IDVzMTIu'
    b'NiAxNi41IDEyLjggMzEuNGMxLjQgMTAuMSAxLjEgMzcuMi0yLjkgNDcuNWE0My40IDQzLjQg'
    b'MCAwIDEtNS41IDIxLjNzMS4zIDIuMiAxLjEgNC42Yy0uMiAyLjMtMS40IDQuNi0xLjQgNC42'
    b'bDE4LjUgOS4xLTYuOC0yLjUgNi44IDUuNy03LjctMy42IDQuNSA0LjZjLS4xLS4yLTExLjIt'
    b'NS4xLTExLjItNS4xbDUgNC43LTguNS00czUgNS41IDUgNS4yYTkxIDkxIDAgMCAwLTcuNC0z'
    b'LjJsLjQgMi43cy01LjgtLjMtNS44LTQuNmExOSAxOSAwIDAgMS00LjctMy44bC0xMy4yLTIu'
    b'Mi0xNC45LTQ0LjYgMy41LTc1LjIgMS0zLjh6Ii8+CiAgPHBhdGggZmlsbD0iI2ZiMCIgc3Ry'
    b'b2tlPSIjMDAwIiBkPSJNNTM5IDQzNC44cy03LjctMTYtMTEuNS0xNi4zYy0zLjQtNi42IDEy'
    b'LTYwIDQxLjctNjMuMSAxNi4zIDEuMyAxLjMgMTguOC05LjQgMTMuNGE0NC43IDQ0LjcgMCAw'
    b'IDAgNi43IDExLjVzLTIxLjMgOS4yLTI3LjYgNTQuNXptLTEwMi4zIDIuM3M2LjMtMTguMyAx'
    b'MC4xLTE4LjVjMy45LS4yLTEwLjEtNjAuOS00MC42LTYxLjMtMTYuNCAxLjMtMS4zIDE4Ljkg'
    b'OS41IDEzLjVhNDQuOCA0NC44IDAgMCAxLTYuOCAxMS41czIxLjUgOS4yIDI3LjggNTQuOHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjMDA3MTNkIiBzdHJva2U9IiMwMDAiIGQ9Ik00NjQuNiAzMjNj'
    b'MC0uMi03LjYgMi4zLTIuNyAxMC41LjMtMy4yIDMuNy01IDMuNy01cy01LjEgNiAuMyAxMS4x'
    b'Yy43LTQuOCAzLjgtNi4zIDMuOC02LjNzLTMuOSAxMS4yIDAgMTMuNWMuNS00LjUgMy4zLTYu'
    b'NSAzLjMtNi41cy0zLjQgMTAtLjMgMTIuM2MuMy0zLjggMi45LTUuNSAyLjktNS41cy0xLjUg'
    b'MTAuNSAyLjUgMTEuMmMwLTMuNyAzLTcuMyAzLTcuM3MtMS4zIDguNSA1IDguOWMwLTMuMiAx'
    b'LjItNi45IDEuMi02LjlzMi45IDkgNyA3LjZ2LTcuN3MyLjcgOC42IDcuNyA3Yy0uNy0yLjQu'
    b'My01LjMuMy01LjNzMi42IDUuNCA3LjQgMy42Yy44LTEuNi0uMi00LjgtLjItNC44czcgNy4y'
    b'IDkgMi45YzIuMi00LjMtNS41LTUuOC01LjUtNS44aDUuMnMtMS43LTQuNC04LjctNS40YzIu'
    b'NC0xIDQuOS0uMiA0LjktLjJzLTEuNS01LjUtOC43LTYuMWMyLjgtMSA2LS4zIDYtLjNzLTEt'
    b'NS4yLTktNi43YzEuMy0xLjQgNC43LTEgNC43LTFzLTMuMi00LjktNi44LTQuNmMtMy42LjMt'
    b'MzYtMy4zLTM2LTMuMnoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMzZWMyNmQi'
    b'IHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTQ5Ni42IDM0OS41czMgMS40IDIuOCAyLjZt'
    b'LTEuMS00LjlzMy43IDIuNiAzLjYgNC41bS0uMy01LjhzMi45IDEuOCAzIDQuN20xLjktMy42'
    b'czEuNCAzLjIgMSAzLjhtMS45LTIuMWMuMiAyLjUtLjIgMi44LS4yIDIuOG0tMzYtMTguNXMz'
    b'LjUgMi4yIDMuMiA1LjNtLTMuNC0yLjdzMS42IDEuNiAxLjMgMi42bTMtNS4yczIuMyAzLjIg'
    b'MS41IDUuNG0yLjQtMy4zczEgMiAwIDNtMS44LTIuMXMxLjIgMiAuMSAyLjdtLTEuNSAzLjlz'
    b'My4yLjcgMy43IDMuMW0tMS44LTUuM3MzLjQuMiAzLjggMy44bS43LTUuMXMyLjMgNCAxLjkg'
    b'NS4ybTIuNC00LjhzLjkgMy43LjIgNW0yLjYtMy41djQuM20tNC4yLTEwLjJzMiAuOCAyIDIu'
    b'OW0tLjEtNC44czIuNyAxLjUgMi41IDQuNW0uNy01LjdzMi4zIDIuNyAxLjUgNS44bTIuNS01'
    b'LjJzLS44IDMuNS0uNCA0LjltMy0yLjVzLTEuNSAxLjEtLjcgMi42bS0xMi43IDEwLjhzLjUg'
    b'Mi42IDAgM20tMy4zLTQuNnMxLjYgMyAxIDQuNG0tNC42LTQuNXMxLjkgMi4yIDEuOCA0bS00'
    b'LjgtMy42czEuOCAxLjcgMS42IDIuN20tMy4xLS4xczEuNyAxLjggMS42IDIuMSIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzAwMCIgZD0ibTQ0MS4zIDIyOS4zIDI0LjMtLjVz'
    b'MTYgMCAxNy43IDUuMmMzLTYuOSAxNy02LjUgMTctNi41bDI1LS44LjUgNjAuNmMtNSAyMy42'
    b'LTIyIDQwLjItNDAuNyA0Ny4zYTYyLjMgNjIuMyAwIDAgMS00MS4yLTQ3LjdsLTIuNi01Ny42'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiMwMDZiMDAiIHN0cm9rZT0iIzAwMCIgZD0ibTQ1MCAyMjkg'
    b'MzUuMyA5NC4yIDMyLTk2LjJjLTEwIC42LTMxLjItMS42LTMzLjkgNy41LTQtOC4xLTI2LjQt'
    b'NC45LTMzLjUtNS41eiIvPgogIDxwYXRoIGZpbGw9IiNmZmM5MDAiIHN0cm9rZT0iIzAwNmIw'
    b'MCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDc0IDI4'
    b'MGMxLjQuNyAxLjMtMjUuNSAzLjEtMjYuM2wxLjQtNS41Yy0xLjUtMi43LTguNC0yLjYtMTEt'
    b'LjJsMS43IDQuOGMzLjUgNS42IDIuOCAyNy44IDQuOCAyNy4yeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNjZGFkNTYiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0iTTQ2'
    b'NC41IDc3czIuNS0yLjkgMi42LTMuNWMuMi0uNyAxMS40LTEuMiAxOC0xMy43IDMuOC02LjUg'
    b'MC0yLjcgMC0yLjdMNDg1IDU0czQuNi00LjQgMy02LjhjLTEuOC0yLjQtMS4yIDMtNCAzLTIu'
    b'Ny0uMS0xLjItNi0xLjItNnMtLjItLjYtMS0xYy0xLjEuMi0uOCAyLjItMS44IDIuNC0xIC4z'
    b'LTItNC43LTItNC43cy0xLjctMi4zLTMuMSA0LjhjLjggNy43IDUuNiA2LjIgNS42IDExLjIg'
    b'MCA1LTQuMyA4LjgtNS41IDktMS4zIDAtLjgtNC4zLS44LTQuM3MtLjctMi0xLjEtMmMtLjUg'
    b'MCAyLjUtLjUgMi02LjEtMS02LjgtMS44IDEuNi0zLjYgMS4yLTEuOS0uMy0uNS02LjIuMi03'
    b'IC43LS42LS44LTMuNC00LjggMy44LS4zIDMuNi0uOC0uOS0xLjYtLjYtMS4zIDIuOC0xLjEg'
    b'NC44LjggNy40IDIuOSAyLjcgNC43IDUuMyA0LjYgNi42LS4xIDEuNC0xLjYgNC41LTMuNyA0'
    b'LjUtMiAwIC4xLTMuOCAwLTUgMC0xLjMtMy41LTUuOC0zLjUtNS44cy0yLjQtMy45LTIuMS00'
    b'Yy4yLS4xLS4zLS43LTEuNCAzLjMtMS4xIDQtMi41LTIuNi0yLjUtMi42cy0xLjYgNC45IDEu'
    b'OCA3LjhjLTIuNi0uMy0yLjguNy0yLjguNyAwIDEuNCAzLjUgMiA0IDQuMy40IDIuNC0zLjcg'
    b'My44LTMuNyAzLjhzMS43IDIuMyA2LjUtMi4zYy4xIDMtMS44IDUtMS44IDUgMS42LjcgMi44'
    b'LjYgMyAyLjV6Ii8+CiAgPHBhdGggZmlsbD0iI2NkYWQ1NiIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9Ii45IiBkPSJNNDQ5IDc3cy0yLjIt'
    b'My4yLTIuMy0zLjhjMC0uNi0xMC40LjgtMTUuMy0xMS44LTMuMi02IDAtMi41IDAtMi41bC4y'
    b'LTIuOXMtMy40LTQuMS0yLTYuM2MxLjUtMi4yIDEgMi44IDIuOCAyLjggMi4zLS4xIDEtNS40'
    b'IDEtNS40cy4yLS42IDEtLjljLjkuMSAxLjMgMy4yIDIuMSAzLjQuOS4yIDIuNy0zLjYgMy4z'
    b'LTQuNC44LS4xLjctMy4yIDIgMy4zLS43IDYuOS02LjQgNS41LTYuNCAxMCAwIDQuNiAzLjYg'
    b'OC4xIDQuNyA4LjIgMSAuMi43LTMuOC43LTMuOHMuNi0xLjggMS0xLjhjLjMgMC0zLjQuNy0z'
    b'LTQuNS44LTQuOCAyLjcuMyA0LjMgMCAxLjUtLjMtLjItNSAuMi01LjguMS0uOCAyLjQtMy45'
    b'IDMuMyAzIC4zIDMuMyAyLTIuNyAyLjctMi41IDEuMiAyLjYtLjUgNi0yLjEgOC40LTIuNCAy'
    b'LjQtMy41IDUtMy40IDYuMiAwIDEuMy42IDIuOCAyLjQgMi44IDEuNyAwIC41LTIuMi42LTMu'
    b'My4xLTEuMSAzLTQuOCAzLTQuOC42LTEgLjEtMi42LjctMy40IDEgMCAxLjQtMS4zIDIuMyAy'
    b'LjMgMSAzLjYgMi4xLTIuNCAyLjEtMi40czEuNCA0LjUtMS41IDcuMmMyLjItLjMgMi40LjYg'
    b'Mi40LjYgMCAxLjItMSAxLjctMS40IDRhMy43IDMuNyAwIDAgMCAxLjEgMy4zcy0xLjQgMi4y'
    b'LTUuNS0yYTcgNyAwIDAgMCAxLjYgNC41Yy0xLjQuNy0yLjQuNi0yLjYgMi4zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZmM5MDAiIGQ9Ik01MTEuMyAyNDNjLTItMS44LTIuMy0uMi0zLjQtLjYt'
    b'LjUtLjItLjktLjctMS4zLTEuMS0uNC0uNC0uOS0uNi0xLjQtLjhsLS42IDEuN2MtLjIuNi42'
    b'IDEuNS42IDIuNC0uMiAxLjMtLjcgMi4zLTIuMyAyLjcuNS0uOS43LS45LjYtMiAwLS41LTEu'
    b'Ni0xLjUtMS40LTIgLjItLjkuNy0xLjguNC0yLjctLjcuNS0xLjUuMi0yLjIuNS0uNS4zLS42'
    b'IDEuMy0xLjMgMS43LS44LjQtMi41LjItNC0uNi45LS43IDEuNi0uMiAyLjUtMSAuNC0uMi40'
    b'LTEuNy45LTJsMS45LTFjLS40LS41LS40LTEuMi0uOC0xLjYtLjQtLjUtMi4xLS40LTIuNS0u'
    b'OC0uOC0xLS43LTIuMS0xLjQtMyAyIC43IDEuNyAxLjcgMi4yIDEuNiAxLS41IDItLjUgMi41'
    b'LS4zczEuNCAxLjUgMiAxLjdsLjYtMS45Yy4yLS42LS44LTEuNS0uNy0yLjEuNC0xLjEgMS40'
    b'LTIuMSAxLjgtMy4zbC40IDMuMWMuMS42IDEuMi45IDEuMiAxLjQuMS42LS41IDEuOC0uNSAy'
    b'LjQuNi0uMSAxLjUgMCAyLS4yLjctLjEgMS0xLjUgMS42LTEuNiAxLjItLjIgMi0uMSAzLjMg'
    b'MC0xIC45LTEuNi44LTIuMSAxLjYtLjUuMy4xIDEuNC0xLjEgMi4yLS41LjMtMS44IDAtMi4y'
    b'LjNsMS4yIDEuM2MuNC41IDIuMS43IDIuNSAxLjIuOC44IDEuMiAyIDEgMi45em0tNTQuMyAx'
    b'YzItMS45IDIuMy0uMiAzLjQtLjcuNS0uMi45LS42IDEuMy0xIC40LS41LjktLjYgMS40LS45'
    b'bC42IDEuOGMuMi41LS42IDEuNS0uNiAyLjMuMiAxLjMuNyAyLjMgMi4zIDIuOC0uNS0xLS43'
    b'LTEtLjYtMiAwLS42IDEuNi0xLjYgMS40LTIuMS0uMi0uOC0uNy0xLjgtLjQtMi42LjcuNCAx'
    b'LjUuMiAyLjIuNC41LjMuNiAxLjMgMS4zIDEuNy44LjQgMi41LjIgNC0uNi0uOS0uNy0xLjYt'
    b'LjItMi41LS45LS40LS4zLS40LTEuOC0uOS0yLS40LS40LTEuNS0uOC0xLjktMS4xLjQtLjUu'
    b'NC0xLjIuOC0xLjYuNC0uNSAyLjEtLjQgMi41LS44LjgtMSAuNy0yLjEgMS40LTMtMiAuNy0x'
    b'LjcgMS43LTIuMiAxLjYtMS0uNC0yLS41LTIuNS0uM3MtMS40IDEuNS0yIDEuN2wtLjYtMS45'
    b'Yy0uMi0uNS45LTEuNS43LTItLjQtMS4yLTEuNC0yLjItMS44LTMuNGwtLjQgMy4yYy0uMS41'
    b'LTEuMi44LTEuMiAxLjMtLjEuNi41IDEuOS41IDIuNC0uNi0uMS0xLjUgMC0yLS4yLS43IDAt'
    b'MS0xLjQtMS42LTEuNi0xLjItLjItMi0uMS0zLjMuMSAxIC44IDEuNi44IDIuMiAxLjUuNC40'
    b'LS4yIDEuNSAxIDIuMi41LjMgMS44IDAgMi4yLjNsLTEuMiAxLjRjLS40LjQtMi4xLjYtMi41'
    b'IDEtLjggMS0xLjIgMi0xIDN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmYzkwMCIgc3Ryb2tlPSIj'
    b'MDA2YjAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQi'
    b'IHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik01MDkuNCAyNDkuMmMtMS45IDEuNS0xNC4zIDQuNi0x'
    b'NC40IDE1LjMtLjEgMTAuOCAyLjIgMTMuMi0uMSAxMy41LTQuNSAwLTUuMS0xMi01LTE3LjMu'
    b'MS01LjMuMy00LjUuMy00LjVzMyAuOCAyLjggMy40Yy0uMyAyLjYgMy02LjQgMS45LTguOCAy'
    b'IDIgNC43IDEuMiA0LjcgMSAwIDAtMS41LTEuNy0yLjItMy0uNi0xLjEgMi4zLjggMi4zLjhz'
    b'LjItMi0yLjQtMmMtMy4zIDAgLjUtMSAuNS0xczIgMS43IDMuMi0uMmExMSAxMSAwIDAgMC0z'
    b'LjQtMi4zcy0xLjgtMy40LTQuMi00Yy0yLjgtLjctMi41IDEuMi01LjcuOS0uNiAxLjItLjYg'
    b'MS40LjcgMS44LTIuMiAxLjUtMSA0LjQtMSA0LjRzMy40LTEuNCAzLjMgMWMtLjEgMi41LTIg'
    b'Mi0zLjMuNS0xLjItLjYtMS42LjctMS42LjdsMS44IDJzLTMuNC0uMi00LjMgMi4xYzEuOS0u'
    b'MSAzIC40IDMgLjRzLTQgMS44LTQuNCAyLjdjLS40IDEtLjUtMS0uNy0xbC0zLjgtMS40LTEu'
    b'MyA1LjlzMi42IDIuNSA0IDEuNyA0LTMuMyA1LjUtMi42Yy00LjUgMy40LTkgOC4zLTExLjQg'
    b'OS0uNi0uNi0yLjgtMi43LTMuNy0xLjYtLjkgMS0uMiAyLjQgMSAyLjMgMS0uMi0zLjggMS0y'
    b'LjggMy4xIDEgMiAxIDEuOSAxLjggMS40IDEtLjYtLjctLjcgMi42LTEuN3MzLjItMS45IDMu'
    b'Mi0xLjktLjcgMS41LTIuNSAyYy0xLjcuMy0zLjEuMy0yLjguOS40LjUgMS4yIDEuNSAxIDIt'
    b'LjMuNiAzLjYtMi44IDQuNy0uMSAyLjYtLjIgNC40LTMuNCAzLjEtNS4zLjIgMiAxLjQgMi43'
    b'LjcgMy43LS44LjkgNi0zLjIgMi43LTUuNi44IDIgMSAzLjYgMSAzLjZzMS41IDAgMS45LS42'
    b'Yy40LS42LS44IDEuNS0uMyAxLjkuNS40IDMgMi43IDIgNC4zLS43LTEtLjgtMi40LTEuNi0y'
    b'LjMtLjguMS00IDIuNS01LjkgMi42LTEuOS4xIDIuMyA3IDIuMyA3cy0yLjktLjMtMy4zIDBj'
    b'LS40LjItMi4zLTIuNS0yLjYtLjktLjcgMiAuNiAxLjIuNiAxLjJzLTEuNy0uOC0yLjYuMmMt'
    b'LjkgMS0xLjcgMS45LTEuMSAyLjMuNi40IDMuNC40IDMuOC4zLjQtLjItMy4yLjItMy40LjYt'
    b'LjMuNC0uOCAyIDAgMi41LjcuNSAyLjctLjMgMi44LS43LjEtLjQuMiAxLjUuMiAxLjVzMy4z'
    b'LjMgMy4zLTMuMS4zIDIuNC4zIDIuNCAzLjMuNiAzLjQtMi44Yy4yLTMuNC40IDIuMy40IDIu'
    b'M3MyLjItLjcgMi4yLTEuMmMwLS42LS4xIDYuNy0xLjcgOC44LTIuNC0xLjYtNCAxLTQgMXMu'
    b'MiA0IDAgNWMtLjMgMSAxLjYtLjYgMS43LTEgLjItLjQgMi41LTEuNSAyLjYtMS43bC44LTEu'
    b'N3MtLjYgMi0xLjQgMi4yYy0xIC4zLTEuOCAxLjItMS40IDIgLjMuOSAxLjcgMS40IDIuMiAy'
    b'LjIuNi44IDIuMy00LjcgMi4zLTQuN2wuMiAxLjJzMi4zLS42IDIuNS0xLjdjLjMtMS0yLjQt'
    b'Mi0uMi0zLjggMi4xLTEuNyAwIDEuNyAwIDEuN3MuNyAyLjYgMS4yIDIuNmMuNiAwIDEuOC01'
    b'IC42LTYuMi0xLjMtMS4yIDEuOSAxLjUgMS45IDEuNXMxLjgtNS0uMi01LjdsLTIuOC0xczEt'
    b'MS4zLjUtMS40Yy0uNS0uMiAyLjcgMyAzLjIgMi4xLjUtLjggMS4zLTMuMi0yLjQtNC42LTMu'
    b'Ny0xLjMtLjEtNS4xLS4xLTUuMXMyLjMgMi43IDQgMS4yYzEuNi0xLjUtLjItMS41LS4yLTEu'
    b'NXM0LjctMyA0LjktNC41Yy0xLS4xLTIuNS4xLTIuNS4xczIuNy0xLjcgMi00LjZjLTEgMS41'
    b'LTIuNCAxLjUtMi40IDEuNXMyLjMtMi4zIDItNC41Yy0xLjQgMS4xLTEuMyAyLTIuMiAxLjct'
    b'LjktLjMtMi40LTguOSAxLjEtOS40IDMuNi0uNiAxLjcgNC4yIDEuOCA0LjIuMiAwIDUuNC0y'
    b'LjIgMC01LjcgMS4zLS40IDQgMiA0IDJzLTEuMi02LTctMi4zYzEuNS0xLjUgMi40LTIuNCAz'
    b'LjUtMi4yIDEuMi4zIDUuMy0uMSA1LjMtMS4zLTEtLjgtMy4yLjQtNC40IDAtMS4xLS40IDgu'
    b'Mi0xLjEgNy40LTUuN3oiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDZiMDAi'
    b'IHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTQ2OSAyNTIu'
    b'N3M1LjEtMi45IDcuNi43bTIuMSA1LjRjLS4xIDAtMS44IDEuOC0yLjIgMS44bTUuNiAzLjlz'
    b'NC44LjQgNy44LTQuNiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwNmIwMCIg'
    b'c3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDg3LjIgMjYz'
    b'cy40IDIuNyAxLjIgMi43Yy43IDAtMS4zLjctMiAuMi44IDEuMiAxLjMgMy40IDAgNC4yIi8+'
    b'CiAgPHBhdGggZmlsbD0iI2U4MDAwMCIgc3Ryb2tlPSIjMDA2YjAwIiBzdHJva2UtbGluZWNh'
    b'cD0icm91bmQiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00ODQuOCAyOTcuM3MtMS42IDEuOS0z'
    b'LjcgMiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwNmIwMCIgc3Ryb2tlLWxp'
    b'bmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNNDg2LjcgMjg4LjZzLTEtNS41'
    b'LS40LTYuOGMuNC0xLjggMi0yLjUgMy40LTQuOCIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwNmIwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9Ii41'
    b'IiBkPSJNNDg2LjIgMjg0LjZzLTEuMyAzLjMtNi45IDIuMm04LjQtMTAuM3MuNCA0LjMtNC43'
    b'IDIuN20tMS41LTIyLjJzLTIgMS44LTEuMyA0LjQiLz4KICA8cGF0aCBmaWxsPSIjMDA2YjAw'
    b'IiBkPSJNNDg5LjEgMjUyLjFzMi43LTEgMy4yLTEuNmE4IDggMCAwIDAgMS43LTIuNGMuMi0u'
    b'OC0xLjgtMi0uOC0zLjguNy0uOSAxLjYtMSAzIDAgMS42IDEtMS4zLTMtMi44LTMuMi0xLjYt'
    b'LjEtMi42IDEuMS0zIC44LS40LS4yLjEgMS4xLS41IDEuMXMxLjMgMS4xIDEuMiAxLjhjLS4y'
    b'LjcgMiAzIDEuOSAzLjUtLjIuNi0zLjIgMy43LTMuOSAzLjh6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'I2ZmYzkwMCIgc3Ryb2tlPSIjZmZjOTAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9r'
    b'ZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00OTEgMjQzLjJjMS4y'
    b'LS4zIDEuNCAwIDEuMiAxYTMgMyAwIDAgMS0xLjEtMXoiLz4KICA8cGF0aCBmaWxsPSIjZTgw'
    b'MDAwIiBzdHJva2U9IiMwMDZiMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13'
    b'aWR0aD0iLjUiIGQ9Ik00ODMgMzAzLjdzLS41IDIuOS41IDMuMWMwLTEgLjMtMS44LjUtMi4x'
    b'bC0xLTF6bS0yLjUtMy41Yy0xLS4xLTIuNS44LTIgMS44LjctLjcgMS40IDAgMi0uN3YtMXpt'
    b'MC0ycy0xLjUtLjItMS43LjljMS0uMiAxLjQtLjMgMS43IDB2LS45eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNlODAwMDAiIHN0cm9rZT0iIzAwNmIwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIg'
    b'c3Ryb2tlLXdpZHRoPSIuNiIgZD0iTTQ3NC4xIDI4Mi4yczEgLjMgMS4yIDEuM2MuNy0uNCAx'
    b'LTIuNi0xLjItMS4zem0tMi4zIDIuNHMyLTEuMiAyLjEgMGMtLjQuMy0uNS42LS44LjctLjMg'
    b'MC0uOC0uOC0xLjMtLjd6bS0uMSAzLjlzMS4yLTEgMS42LS40Yy41LjgtLjQuNy0uNC43bC0x'
    b'LjItLjN6bS0xLjctMjEuOXMtMS41LS42LTIuMS41YzEgLjIgMS4zLjUgMS44LjktLjItLjUt'
    b'LjQtMS4yLjMtMS40em0tMi45IDguM3MwLTEuOSAxLTIuNmMuNC4zLjUuNy44IDEuMi0uNi4y'
    b'LTEuNC4yLTEuOCAxLjR6bTMuOS0xLjNzLTEuNi44LTEgMS43Yy41LS43IDEuMS0uNSAxLjEt'
    b'LjV2LTEuMnoiLz4KICA8cGF0aCBmaWxsPSIjZmZjOTAwIiBzdHJva2U9IiMwMDZiMDAiIHN0'
    b'cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iLjYiIGQ9Ik00NjguNyAyNTUu'
    b'OGMtLjYuNy43IDIuMiAyLjEgMiAuNC0xLjYtMS43LTIuNS0yLTJ6Ii8+CiAgPHBhdGggZmls'
    b'bD0ibm9uZSIgZD0iTTQ2OC43IDI1Mi42Yy0uMy44LjkgMS45IDEuNSAxLjYuMy0uOC0xLjIt'
    b'Mi4yLTEuNS0xLjZ6Ii8+CiAgPHBhdGggZmlsbD0iI2U4MDAwMCIgc3Ryb2tlPSIjMDA2YjAw'
    b'IiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9Ii42IiBkPSJNNDcwLjIg'
    b'MjU0LjZzLjMgMS4zIDEuNSAxYTQgNCAwIDAgMC0xLTEuOWMwIC4zLjEuOC0uNS45em0uOCAz'
    b'LjdzLjcuOCAyLS43Yy0uNi4xLTEuNi0uNC0xLjYtLjRzMCAxLS40IDEuMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZjOTAwIiBzdHJva2U9IiMwMDZiMDAiIHN0cm9rZS1saW5lam9pbj0icm91'
    b'bmQiIHN0cm9rZS13aWR0aD0iLjYiIGQ9Ik00NjguNiAyNTIuOGMtLjUuNy4zIDEuNyAxLjcg'
    b'MS41LjMtMS43LTEuMy0yLTEuNy0xLjV6Ii8+CiAgPHBhdGggZmlsbD0idXJsKCNncy1kKSIg'
    b'ZD0iTTQ2OS4yIDI0Ni4zczUuNS0xLjYgOC40LjhjMyAyLjMgMyAuMiAzIC4yczQuMiAxLjYg'
    b'NS40IDEuMmMxLjItLjMtLjkuMi44LS45IDEuNy0xLTMuNC4zLTMuOC0xLjktLjgtMS4zIDAt'
    b'My0xLjctMi40LTEuMi0xLjYuOC0yLjcuMy00LjQtMS4yIDEtMS45LS4zLTIuOSAyLTIuMy0u'
    b'NS0uMy0zLjgtMi45LTQuMSAwIDIuMy0xLjkgMi40LTIgMy44LTEuMS44LTYgMy43LTQuNiA1'
    b'Ljd6Ii8+CiAgPHBhdGggZmlsbD0iI2MwMTUwMCIgc3Ryb2tlPSIjMDAwIiBkPSJNNDA2IDQy'
    b'NWMzLjYtMSAyMi45IDQuMiAzMC4zIDEyLjItMS42LTE0LjMtNS41LTI1LjEtNS41LTI1LjFz'
    b'LTExLjUtMy4zLTEzLTEuN2E4MC44IDgwLjggMCAwIDAtMTEuOCAxNC41em0tNS45LTY1Ljdj'
    b'LTEuMy4yLTIuNyAxLjEtNCAzLjQtMS42IDMuOC0yLjcgMTMuNS01IDE1LjgtMi4yIDIuMi00'
    b'LjMgMi40LTQuMyA0LjUgMCAyIC4zIDYuNyA2LjMgOC41IDYuMS4zIDE1LjgtOS43IDE1Ljgt'
    b'OS43czUtNS40IDctMTEuMmMtMTEuNyA0LTIwLTYuOC0xNS44LTExLjN6bTE2OS42IDYzLjRh'
    b'NTMgNTMgMCAwIDAtMzAuNCAxMi4xYzEuNi0xNC4xIDUuNS0yNSA1LjUtMjUgMS4zLS4zIDEx'
    b'LjMtMy4yIDEyLjgtMS42IDIuMyAyLjQgOS43IDkuNyAxMi4xIDE0LjV6bTUuNS02NS4zYzEu'
    b'My4yIDEuOCAyIDMgNC4yIDEuNSAzLjkgMyA5LjQgNS4zIDExLjYgMi4zIDIuMyA0LjMgNS42'
    b'IDQuMyA3LjZzLS41IDQuOC02LjUgNi42Yy02IC4yLTE0LjgtNy42LTE0LjgtNy42cy01LTUu'
    b'My03LTExLjJjMTEuNyA0IDE5LjItNi4zIDE1LjctMTEuMnoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZmIwIiBzdHJva2U9IiMwMDAiIGQ9Ik0zOTMuNCA0MTIuNXMxMi4xIDguNCAxMi40IDEyLjJj'
    b'MzIuNy00OC41IDExNi4xLTYzLjYgMTYzLjctMy40IDYuMy04LjMgMTIuOC0xMSAxMi44LTEx'
    b'LTUwLTY1LjQtMTQ5LjctNTcuMy0xODkgMi4yeiIvPgogIDxwYXRoIGZpbGw9IiMxZTVhYTYi'
    b'IHN0cm9rZT0iIzAwMCIgZD0ibTUxNy40IDIyNyA0LjgtLjEtOC41IDEwLjggMTAuMiAxMS45'
    b'LTIwLjEgMjUuMyAxOSAyMi44YTU3LjkgNTcuOSAwIDAgMS03LjggMTRsLTEwLjktMTJMNTI0'
    b'IDI3NWwtMTYuMi0xOC40em0tNjguMSAyLjJoLTVsOS41IDEwLjQtMTAuMSAxMi42IDIxIDIy'
    b'LjgtMTcuNCAyMy4zYzIgNSA1IDEwLjggOC4zIDE1bDEwLjMtMTMuMS0yMS4yLTIzLjYgMTUu'
    b'NS0xOS43eiIvPgogIDxwYXRoIGZpbGw9IiMxZTVhYTYiIHN0cm9rZT0iIzAwMCIgZD0ibTQ3'
    b'MyAyOTAuNC03LjYgMTAgMjYuOCAzMWM0LjgtMi40IDguNS01LjEgMTIuNS04LjRsLTE0LTE2'
    b'LjEgNS43LTE2LjcgOC4yIDkuNC0yNS41IDMyLjZjLTQuMy0xLjgtOS00LjYtMTMuMy04LjJs'
    b'MTMuNS0xNy4xem0tOC4zLTE1LjUgNC44IDYuMS0zLjEtOC4zem0zNC45IDUuNCA0LTUuMi0x'
    b'LjUtMnoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiNmZmY3MDAiIHN0cm9rZS1s'
    b'aW5lY2FwPSJyb3VuZCIgZD0iTTU1NiAxOTVzNC44LTQgOC4xLTQiLz4KICA8cGF0aCBmaWxs'
    b'PSJub25lIiBzdHJva2U9IiNmZmY3MDAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTU1'
    b'Ni43IDE5NC41Yy4xLS4xIDI4LjEtNCAyOS01bS0yOC45IDUuMiAzMS40LTIuN20tMzEuNSAy'
    b'LjhzMzMuMy0xLjUgMzUuMy4yIi8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjZmZm'
    b'NzAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik01NTYuNiAxOTQuN3MzMi42LjMgMzMu'
    b'MiAxbS0zMy4xLTEgMzEuNCAyLjZtLTMxLjctMi4zczMyIDIuOCAzNSA2LjgiLz4KICA8cGF0'
    b'aCBmaWxsPSJub25lIiBzdHJva2U9IiNmZmY3MDAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIg'
    b'ZD0iTTU5My4xIDIwNy41YzAtLjEtMTAuOC0xMi45LTM2LjgtMTIuNyIvPgogIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iI2ZmZjcwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBkPSJN'
    b'NTU2LjQgMTk1czE4IDEuMyAyMy43IDcuNiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9r'
    b'ZT0iI2ZmZjcwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBkPSJNNTU2LjcgMTk0LjhzMTEu'
    b'Ny0yLjIgMjMuOSAxMi41Ii8+CiAgPHBhdGggZmlsbD0idXJsKCNncy1lKSIgc3Ryb2tlPSIj'
    b'MDAwIiBkPSJNNTQ5LjQgMjA4LjJzMTYuMS42IDE2LjEgMi4yLTEyIDQuNi0xMi4yIDExLjJj'
    b'LS4xIDYuNyA5LjIgNy4yIDkuOSAxNS42LjYgOC40LTcuMyA5LjYtOSAxMS45LTEuNSAxLTUu'
    b'MyAxMy00LjggMjAgLjUgNi45IDIuNSAzMC41IDYuMiAzNS4zIDIuOCAyLjIgNyA5LjMgMTEu'
    b'NyA3IDQuNi0yLjEgMS40LTEwLjIgMS0xMi40LS41LTIuMiAxLjgtNS45IDEuOC05LjIgMC0z'
    b'LjQtMS43LTYtMS41LTYuOC4xLS44IDEyLjggMyAxMiAxNS41LS44IDEyLjUtNS45IDguNy01'
    b'LjkgOC43czEuNiAxNS40LTIuMyAxNy40Yy03LjIgMy44LTEyLjQtLjgtMTIuNC0uOGwuNyAz'
    b'LjItNS41LTIuOHMtNy0xMC04LjUtMTQuNWExMjYgMTI2IDAgMCAxLTIuOS0yOC41Yy43LTQu'
    b'MyAxLjEtMjkuMy44LTMwLjYtLjMtMS4yLTEuNi0yMi4xLS44LTI1LjMuOC0zLjIgNS43LTE3'
    b'LjEgNS42LTE3LjF6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmNzAwMCIgc3Ryb2tlPSIjMDAwIiBk'
    b'PSJNNTMyIDIwNHMxMS4yLTEwLjkgMTcuNy05LjZjMy4zIDAgLjIgMi40LjIgMi40czUuNy40'
    b'IDYuNSAzYy4xIDEtMi43IDEuNC0yLjcgMS40czIuMy41IDIuNSAyLjVjLjIgMi4xLTI0IC41'
    b'LTI0LjMuNHoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik01MzIu'
    b'NiAyMDMuNnMxMi0xLjYgMTcuMS02LjciLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiMwMDAiIGQ9Ik01NDQuOCAyMDAuM3M4LjktLjQgOC45IDEiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIGQ9Ik01NzYuMyAz'
    b'MjkuOXM3LjYtMS44IDkuNy00LjVjMS4yLTEgNy45IDEwLTkuNyA0LjV6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjZmZmIiBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik01'
    b'NzQuMyAyNjdzMSA1LjgtMS44IDkuOGMtMS40IDEuNi01LjcgNC4zLTUuNyA2LjIgMCAxLjkg'
    b'MS42IDQuNCAxLjMgNi42LS4zIDIuMi0yLjcgNC41LTIuNiA2LjQgMCAxLjkgMi43IDEyIDIu'
    b'NCAxMi4ybS03LjYtNjAuMnMtNiAyLTcuMyA4Ii8+CiAgPHBhdGggZmlsbD0iI2M3NWIwMCIg'
    b'c3Ryb2tlPSIjMDAwIiBkPSJNNTU3LjggMjAwLjNzMiA1LjcgOC43LjNjLTQuMy01LjktOC43'
    b'LS4yLTguNy0uM3oiLz4KICA8cGF0aCBkPSJNNTYyLjcgMjAwYzAgLjMtLjMuNi0uNy42LS40'
    b'IDAtLjctLjMtLjctLjZzLjMtLjUuNy0uNWMuNCAwIC43LjIuNy41eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIHN0cm9rZT0iIzAwMCIgZD0iTTUwMy40IDE4N3MxMi42IDEzLjcgMjAuNyAx'
    b'My41YzEuNSA0LTMuNyA3LjgtNS43IDkuNS00LjItMS4zLTggLjMtMTcuNi0xMS42LjYtNy42'
    b'IDIuNy0xMSAyLjYtMTEuNHptMTctMzEuOGMxLjctNSA1LTkgNy44LTkuNS0uOC0zLjggNS45'
    b'LTIwLjkgMjUuMy0yNy40IDEuMiA4LjctOC4zIDE3LjQtOC4zIDE3LjRzMjguNy01IDM0LjUt'
    b'MTIuMmMtLjYgMy4yLTYuNCAyMy42LTM3IDIzLjQgMTEuNiAxMS0zLjcgMTkuOC0xMC4yIDE3'
    b'LjEgMTItOS4yLTMuNS0xNC43LTEyLTguOHoiLz4KICA8cGF0aCBmaWxsPSIjY2NjY2NkIiBz'
    b'dHJva2U9IiNjY2MiIGQ9Ik01MzAuMiAxNDguMWM1LjgtMy43IDcuOS0zLjcgMTIuNy0zbC0z'
    b'LjUuNnMtLjMuNSAxLjggMi40Yy0yLjQtLjYtNC40LTItMTEgMHoiLz4KICA8cGF0aCBmaWxs'
    b'PSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik01MjggMTQ1LjdzMTEuNC02IDE3LjgtMTAuMiIv'
    b'PgogIDxwYXRoIGZpbGw9IiMwMGYiIHN0cm9rZT0iIzAwMCIgZD0iTTUxOC4yIDIxMHMxNS43'
    b'IDQuMyAxNy41LTE4LjJjLTMuNC05LjgtOC4xLTMxLS45LTM3LTYuNi00LjYtMTQgLjItMTQg'
    b'LjItLjQgMS02LjMgOS41IDEuNyAyNC4zLTE5LTUtMTEuMyAxMy0xMS4zIDEzIC44LTMgMTAu'
    b'OS01LjYgMTMuNCA4LjggMSAzLjYtNi44IDktNi40IDl6Ii8+CiAgPHBhdGggZmlsbD0iIzAw'
    b'ZiIgc3Ryb2tlPSIjMDAwIiBkPSJNNTM1LjkgMTkyczE2LjYtOSAxNi4yLTMwYy0xNC4yLjQt'
    b'MTkuMiAxOC42LTE5LjIgMTguNnoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMw'
    b'MDAiIGQ9Ik00NjEuMyAxOTAuOXMtMTIuMyAxMC43LTE5LjMgNy4zYy01LjEgMy0xMS4yLTIu'
    b'NC0xMS4yLTIuNHM3IDI2LjMgMzIuNiA3LjNhNjAuNSA2MC41IDAgMCAwLTItMTIuMnoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjMDBmIiBzdHJva2U9IiMwMDAiIGQ9Ik00NDEuOSAxOTcuN2MxLTUu'
    b'NSA1LjMtOC4yIDguOC0zIDQuNiAxIDkuMi0xOC03LjItMTQuOCA0LjYtMjQuNy05LjItMzMu'
    b'OS05LjItMzMuOXMtNC45IDI3LjQtMi42IDMyLjRjMi4yIDUtMy4zLTkuMy0yMS0xMy40LS4z'
    b'IDIwLjcgMTkuOCAzMC4zIDE5LjggMzAuM3M1LjYgNS4yIDExLjQgMi40eiIvPgogIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0iTTQ0My41IDE3OS43cy03LjcgNi42LTYg'
    b'MTUuNW0tNS43LTE2LjNzLTEuOCA2LjMgMiAxNS40Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlPSIjMDAwIiBkPSJNNDMwLjYgMTk2LjRzMy42LTUuOCAxMS4zIDEuNiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzAwMCIgZD0iTTQzMi4xIDE1Ni4zYzAtLjItMTEu'
    b'NyAwLTQuOCAxMS45LTUuMSAxLjYtMTYuNy02LTguNy0xNi0yNi4zLS43LTM3LTEzLjMtMzct'
    b'MjQuOSA3LjcgOCAyNi4yIDQuOCAzMi43IDkuNy04LTcuNC02LjQtMTcuNy02LjQtMTcuN3My'
    b'Mi40IDYuNyAyNi40IDI2LjZjLTEuMyAzLjktMS45IDEwLjctMi4yIDEwLjR6Ii8+CiAgPHBh'
    b'dGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBkPSJNNDE0IDEzNi41YzQuNCA0LjQgMTUu'
    b'NSA1LjcgMjEuMSAxMC42Ii8+CiAgPHBhdGggZmlsbD0iI2NjY2NjZCIgc3Ryb2tlPSIjY2Nj'
    b'IiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNNDE5LjIgMTQ5LjVzOS4yLTEuMiAxMS45IDJjLTMu'
    b'NiAwLTQuOC0uOS0xMCAxIDEuNC0uNyAxLTIgMS44LTJzLTMuMy0xLTMuNy0xeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM5MjNmMDAiIHN0cm9rZT0iIzAwMCIgZD0iTTQ2NSA3Ny41czUuMS00LjUg'
    b'MTAuNi0uNWMtMi41IDcuNC0xMS40IDQuNi0xMS40IDQuNnMuMyAzLjctLjYgNS41YzEuOCAx'
    b'LjQgMy4yIDUuOCAzLjIgNS44czkuMi0yLjIgMTEuMiAxLjhjMy41LS41IDYgMCA2IDBzNy4y'
    b'LTEuOCA5LjctMS44YzIuNSAwIDEwLjUgMiAxMS4zIDMuNi43IDEuNCAzLjQgMTEuNCA1LjIg'
    b'MTEuMiAxLjgtLjEtNC4zIDIuNC02LS4xLTEuNi0yLjUtMS4xIDMuMy0xLjEgMy4zczUgNS4z'
    b'IDUuNiA2LjVjLjYgMS4yLTMuMSAxMC44LS4zIDE3LjUtMi41LjItMi43IDIuOC0yLjcgMi44'
    b'LS4xIDMtMy44IDMuNy0zLjggMy43bC0xLTQtMi40IDEuNSAxLTMuMXMzLjQtOC4zIDMuNy0x'
    b'MWMuMy0yLjctMy4xLTcuNC01LjgtNy40LTIuNyAwLTQuNiA4LjUtNC42IDguNXMtMS4zIDYu'
    b'My0uOSA3bC0xLjgtMi4xcy0xLjEgMy44LTIgNWMtMSAxLjItMi45IDEuNi0yLjkgMS42cy0x'
    b'LjMtMy44LS44LTUuM2MuNC0xLjUgNy4yLTcuMyA2LjYtMTEuNC0uNi00LjIgMC0zLjItLjEt'
    b'My4zLS4yLS4yLTMuNi0zLjEtMy43LTQuOC0uMi0xLjYtNC41IDIuMS0xMC4xIDEtMS43IDMt'
    b'MiAxMC41LTIgMTAuNXMtLjUgOSAuNiAxMGMxLjIgMS4xLTMgMy4zLTMgMy4zbC0yLjkgNC0x'
    b'LTIuMy0yLjEgMS41IDEuMi0zYy0uMS0yLjMgMi45LTguNCAyLjktMTMuNiAwLTUuMi4zLTEw'
    b'LjguMy0xMC44cy01LjQtLjMtNS4zIDUuNGMuMSA1LjYtMS4zIDYtMSA3LjUuMyAxLjcgMS43'
    b'IDYuMyAxLjMgNy42LS40IDEuNC0yLjIgMS44LTIuMiAxLjhsLS41LjdzLTUuNSAyLjYtNS4z'
    b'IDMuNmwtLjItMy0uMy00LjNzMy4zLTIgMy4zLTcuMi0uNy02LS42LTcuMmMuMS0xLjIuOS01'
    b'LjUuNy02LS4xLS40LTMgMS4zLTQgMS4zLS45IDAgMS43LTMuMSAyLTUuNC4zLTIuMi0zIDIu'
    b'MS01LjctLjQgMS4zLTIuNyAzLjEtMy42IDMuNC01LjYuMy0yLjEtMiAxLjctNC4xLjIuMi0y'
    b'IDIuMi0zLjcgMi4yLTMuN3MtMS43LS4yLTIuNCAwYy0xLjMtLjQgMS41LTIuNSAxLjctNS41'
    b'LjEtMy0xLjctNC4xLTEuNy00LjMgMC0uMS0zLTIuNi0zLjQtMy43LS40LTEtLjQtMi4yLS40'
    b'LTIuMnMtNSAzLjYtMTAuNy00YzUuMy00LjUgMTEtMS4yIDExLTEuMnMxLjUtNC4yIDguMy0z'
    b'LjljNi44LjMgOC4yIDQuMiA3LjkgMy44eiIvPgogIDxwYXRoIGZpbGw9IiMwMGYiIHN0cm9r'
    b'ZT0iIzAwMCIgZD0iTTUwMi40IDE1NC4yYy4xIDAgMTIuNi40IDEyLjcgNy4xLjIgNi43LTMu'
    b'OCA1LTQgNWwtOS0xLjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZmVmZiIgc3Ryb2tlPSIjMDAw'
    b'IiBkPSJNNDkwLjMgMTUyLjRzMTUuNi0uMSAxNC43IDYuN2MtLjkgNi44LTQuOCA1LjQtNC44'
    b'IDUuNGwtNy42LS42eiIvPgogIDxwYXRoIGZpbGw9IiMwMGYiIHN0cm9rZT0iIzAwMCIgZD0i'
    b'bTQ4MS41IDE1MS43IDkgLjdzNS41LjcgNS4yIDZjLS4yIDUuMS01LjUgNS4yLTUuNSA1LjJs'
    b'LTguOC0uNXoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDAiIGQ9Ik00NjAu'
    b'NCAxNTQuMmMtLjIgMC0xMi42LjQtMTIuOCA3LjEgMCA2LjcgMy45IDUgNCA1bDkuMS0xLjJ6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iIzAwZiIgc3Ryb2tlPSIjMDAwIiBkPSJNNDcyLjUgMTUyLjRz'
    b'LTE1LjYtLjEtMTQuNyA2LjdjLjggNi44IDQuOCA1LjQgNC44IDUuNGw3LjUtLjZ6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBkPSJtNDgxLjMgMTUxLjctOSAuN3Mt'
    b'NS41LjctNS4zIDZjLjMgNS4xIDUuNiA1LjIgNS42IDUuMmw4LjgtLjV6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzVlMDA0MyIgc3Ryb2tlPSIjMDAwIiBkPSJNNTA1LjQgMjI2LjdzNi41LTkuNSA5'
    b'LjMtOC41YzIuNC44LjUgOC4yLS42IDguOXptLTQ0LjQgMS43Yy0yLjEtMi44LTUtMTAuNy03'
    b'LjgtOC41LTIuNC44LS42IDguMi42IDguOXoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiMwMDAiIGQ9Ik00NjUuMiAyMDkuNXMxMi43IDcuOCAxNi44IDhjNC4yLjIgMTcuMy0x'
    b'MC4xIDE3LjMtMTAuMSIvPgogIDxwYXRoIGZpbGw9IiM1ZTAwNDMiIHN0cm9rZT0iIzAwMCIg'
    b'ZD0ibTQ2Ni41IDE3OSAyLjQtMyAxMi4xIDYgMTIuNC01LjUgMi40IDIuNi0xMy44IDkuN3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjNDc0NzQ3IiBzdHJva2U9IiM0NzQ3NDciIHN0cm9rZS1saW5l'
    b'am9pbj0icm91bmQiIGQ9Ik00NTYuOCAxNzguOGE1MSA1MSAwIDAgMSAxMC4zIDE4LjdjMS40'
    b'IDcuOS0uOC0xMC45LS44LTEwLjlzOS43IDQuOCAxMCA3LjhjLjMgMyA0LjYtLjIgNC44LS43'
    b'bC0yOC0xOC4yem00OC0uNXMtMTAuMiAxMy40LTkgMjhjLTIuMS03LS40LTE4LjUtLjQtMTgu'
    b'NWwtMi4yIDEuNHMtMi40IDkuOS01LjMgMTEuNGMtLjUtMS4yLS40LTEuNi0uNC0xLjZzLTMu'
    b'MSA0LTMuNyA0LjRjLS42LjQuMiAxMy43LjIgMTMuN3MxIDkuNiAyLjIgOS41YTQxIDQxIDAg'
    b'MCAwLTMgMS43bC0xLjMtMjUuNiAyLjktMi45czMuOC00LjcgNC4xLTkuMmMtMS42IDEuNC0z'
    b'LjUgMS44LTMuNSAxLjhzLS41IDYuNS0yIDcuNGMtMS42IDEtMS42IDIuNi0xLjYgMi42bC0u'
    b'NC04LjV6Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGlu'
    b'ZWNhcD0icm91bmQiIGQ9Im00ODEuNCAxOTMuOCAyIDQwLjUiLz4KICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIGQ9Ik00NTYuNSAyMTMuMnM0LjcgMi43IDYuNCAxMWMxNS4y'
    b'LTEuMSAyMCA0LjIgMjAgNC4yczEyLjQtNiAxOC4yLTQuOGMyLTQuMyA3LjgtOS43IDcuOC05'
    b'LjciLz4KICA8cGF0aCBmaWxsPSIjYjRiNmI5IiBzdHJva2U9IiMwMDAiIGQ9Im00NTAuMiAx'
    b'NzMuNSAzMS4yIDIwLjQgMjguMi0xOC45czUuOC0zLjIgNS4zLTUuNWMtLjUtMi40LTIuNS0x'
    b'LjUtMy41LTEtMSAuMy0yOS41IDIwLjUtMjkuNSAyMC41bC0zMC4yLTE5LjJzLTIuMi0uNy0y'
    b'LjYuOGMtLjQgMS40LjggMi4yIDEuMSAyLjl6Ii8+CiAgPHBhdGggZmlsbD0iIzQ3NDc0NyIg'
    b'c3Ryb2tlPSIjNDc0NzQ3IiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNNTA2IDE2OC4y'
    b'cy04LTMuNC04LS41YzAgMyAuMyAzLjMgMS42IDUuMiAxLjMgMS44LTEgMy0xIDNsLS44LTJj'
    b'LS40LTEuMy00LjctMi4yLTUtMy44LS41LTEuNS44LTMuOS0xLjctNC4yLTIuNi0uMy01LjEg'
    b'MS01LjYgNGE2MSA2MSAwIDAgMS0zLjkgOS44bC41LTE1LjZjNS42LjQgMTYgMS42IDI0LjEg'
    b'Mi42LTIuNC0uNCAxIC4xLjggMS0uMi42LTEgLjctMSAuNXptLTI4LjItMy45YTM3IDM3IDAg'
    b'MCAwLTEwLjQgMS45Yy0xLjggMSAzIDIuNyAyLjMgNC0uNiAxLjUtLjcgNC40LTMgMy44LTIu'
    b'Mi0uNi05LjgtNC40LTEwLTUuNy0uMy0xLjItMS44LTEuMy0xLjgtMS4zczIxLjgtMyAyMi45'
    b'LTIuN3oiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik00ODEuMiAx'
    b'NjIuNXYxOS4xbS0xNC43LTQxLjctOSAxNC42Ii8+CiAgPHBhdGggZmlsbD0idXJsKCNncy1m'
    b'KSIgc3Ryb2tlPSIjMDAwIiBkPSJNNDgyLjYgMTM5LjVzMy44IDUuMiAzLjQgNi43YzEuNSAx'
    b'LjIgMy4zIDYgMy4zIDYiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9'
    b'Ik00OTcuMyAxMzguN3MtOC4yIDExLjYtOCAxMi41Ii8+CiAgPHBhdGggZD0iTTQ1NS4xIDgz'
    b'LjRjLS4yLjYtMS4yLjktMi4zLjYtMS4xLS40LTEuOS0xLjItMS43LTEuOC4yLS43IDEuMy0x'
    b'IDIuNC0uNiAxIC4zIDEuOCAxLjEgMS42IDEuOHptMy40LS4yYy4yLjYgMS4yLjkgMi4zLjUg'
    b'MS4xLS4zIDEuOS0xLjEgMS43LTEuOC0uMi0uNi0xLjMtLjktMi40LS41LTEgLjMtMS44IDEu'
    b'MS0xLjYgMS44eiIvPgogIDxwYXRoIGZpbGw9IiNmZjcwMDAiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLWxpbmVqb2luPSJyb3VuZCIgZD0iTTU1NSAzMjRzLTMuMi41LTMgLjhjMCAuMy05IC42'
    b'LTkuMS4zLS4yLS4zLTEuNCAxLjUtMS40IDEuNWwxLjUtLjlzMi4yIDIuMyAyLjggMi4xYy43'
    b'LS4xLS4zIDEgMCAxLjEuMS4yLjgtLjQuOC0uNGwxNC44LS4yem01LjQgNC41LTEyIC40cy0z'
    b'LjEgMi44LTMuMyAzLjRjLS4yLjcgMiAuOSAyIC45bC42IDIuMyAxLjYtLjZzMTAuMyAxLjUg'
    b'MTkuNy0uNmM0LjgtMS42IDUuNy0zLjYgMi4zLTQuOS0zLjMtMS4yLTEwLjgtLjgtMTAuOS0u'
    b'OXoiLz4KICA8cGF0aCBmaWxsPSJ1cmwoI2dzLWcpIiBzdHJva2U9IiMwMDAiIGQ9Im01MTkg'
    b'MzUzLjQgMjEuNy0xLTQtMy40IDU5LTIuNC0yLTQuNy02Ni4xIDIuNyA4IDMuNy0xOCAuNS42'
    b'IDEuOS00LjctLjJzNS4zIDIgNS40IDN6Ii8+CiAgPHBhdGggZmlsbD0idXJsKCNncy1oKSIg'
    b'c3Ryb2tlPSIjMDAwIiBkPSJNNTQzLjQgMjMyLjljLTEuNy0uOS05LjQtMi0xNy45IDMuNmwu'
    b'NCAxOS42czEyLjUtNi43IDE4LjUtNS4yYy0uMy02LS4zLTEzLjgtMS0xOHoiLz4KICA8cGF0'
    b'aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Im00MjIuNyAyOTIuNC01MS40IDUxbTc0'
    b'LjQtNTAuNy00MS44IDU1bTM5LjktNjkuMy01NS43IDY3LjVtLTEuNy0uOSA1LjQtNi40bTYy'
    b'LjYtMjYuMy0yMS42IDI5LjhtLS45IDMuOS41IDExLjRtMzEuOS0zNC43LTIzIDI4LjhtMTgu'
    b'OS0yLjMgOS4zLTE1LjNtLTUuNy0yLjktMTEuMiAxMi42bTcuOC0yNC42LTcuNiA5LjNtLTIu'
    b'My0yMi45cy0yMy4zIDM0LjEtMjIuOSAzN20yMC41LTQxLjRjLS42LjMtMjAuMSAyNi4yLTIw'
    b'LjEgMjYuMm0tMS4xIDguMi0zLjYgNC4zbS00LjUgNi41LTUuNCA3LjEiLz4KICA8cGF0aCBm'
    b'aWxsPSIjOGE5Mzk2IiBzdHJva2U9IiMyYjJiMmIiIGQ9Ik00MjAuMiAyMTMuOHMtMS42IDUg'
    b'MCA3LjUgMTEuNSAyMi41IDExLjUgMjIuNSA2LjgtOC4zIDkuMy04LjVjMi40LS4zIDEuMyAy'
    b'MS42IDEuMyAyMS42cy00IDMuOC02LjUgMy42Yy0yLjUtLjIgNiA4LjYgNS44IDE2LS4yIDcu'
    b'NS0xMS4yIDQ0LjUtMTUuMyA0NS4xLTQgLjcgMS44LTYuNyAxLjYtOC44LS4zLTItMS40LS42'
    b'LTIuMy0yLjktLjktMi4yIDEuNC01LjYgMS03LjktLjUtMi4yLTIuNi0xLjgtMi44LTMuNC0u'
    b'Mi0xLjYgMS40LTIgMS4xLTMuOC0uMi0xLjgtMi43LTEuNC0yLjQtMyAuMi0xLjUuNC0uOC4y'
    b'LTMuOC0uMi0yLjktLjcgMi0zLjIgMi4zLTIuNS4yLTQuNSA1LjktNC41IDUuOXMtNSA3LTku'
    b'OSAzLjhjMyA2LjMuNyA5LS41IDkuMi0xIC4zIDEgNS0xLjggNS4yLTIuNy4yIDIgMTAuNi0x'
    b'IDExLjUgMy4zIDEuNi42IDMuNi42IDMuNnMtNy44LjctNi4xIDEwLjljLTIzLTguMi0zNC4z'
    b'LTIyLjEtMzQtMzYuNC4yLTE0LjIgNC43LTI3IDE1LjctMzEuNyAzLjItMTEuOCA4LjYtMjQu'
    b'NCA4LjYtMjQuNHMtLjktNS4yLS4yLTguNmExNyAxNyAwIDAgMSAzLjgtNi43cy0uNC04LjIt'
    b'LjItMTIuMiAxLjgtNS45IDItOC4xYy4yLTIuMy0uNy0xMy44IDEuNi0xNS44IDIuMi0yIDYu'
    b'NS0xLjggOC44LTMuMiAyLjItMS4zIDUuMi0zLjggOC4xLTMuNiAzIC4yIDUuNCAyLjMgNS40'
    b'IDIuM3MxMSAwIDExLjcgNC4yYy43IDQuMy0yLjIgNi0yLjIgNnMxLjYgNi01LjIgMTEuNnoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjY2VjZmNmIiBzdHJva2U9IiMyYjJiMmIiIGQ9Ik00MTAuNCAx'
    b'OTguMmMuMy43LS41IDEuOC0xLjggMi41LTEuNC43LTIuNy44LTMgLjItLjQtLjcuNC0xLjgg'
    b'MS43LTIuNSAxLjQtLjggMi43LS44IDMtLjJ6Ii8+CiAgPHBhdGggZD0iTTQwOC41IDE5OS40'
    b'YzAgLjQtLjQuNy0uOC43LS41IDAtLjktLjMtLjktLjcgMC0uNS40LS44LjktLjguNCAwIC44'
    b'LjMuOC44eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzJiMmIyYiIgc3Ryb2tl'
    b'LXdpZHRoPSIuNSIgZD0iTTQyNSAyMDYuOHMyLjcgMTIuMi0uNSAyMC43bTEuNC0yNnM1LjMg'
    b'NyA0LjYgMTUuOG0tNC4xLTE3LjNjLjEgMCA0LjUgMy43IDQuMyA2LjNtLTMuMy03LjlzMyAy'
    b'IDMuNiA0LjEiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIGQ9Ik00MjYg'
    b'MTk3LjJzLTEwLjUgMTctOS4xIDI3LjciLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiMyYjJiMmIiIHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00MjYuNyAxOTYuNnMtMTQgOC4zLTE2'
    b'LjUgMzUuNCIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgZD0ibTQyNS4y'
    b'IDIwMS42LTUuNiA0LjIiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMyYjJiMmIi'
    b'IHN0cm9rZS13aWR0aD0iLjUiIGQ9Ik00MDUgMjMzLjVzNy44LTMyLjIgMjEuNS0zNi45Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzJiMmIyYiIgc3Ryb2tlPSIjMmIyYjJiIiBkPSJNNDMxLjkgMjQ0'
    b'LjRzNy40LTkuMyA5LjEtOWMxLjcuNCAxLjIgMjEuNiAxLjIgMjEuNnMtNS41IDQuMS02Ljcg'
    b'NGMtMS4yLS4yIDYuMiAxMCA2IDEzLjctLjEgMy44LS4zIDMuOC0uMyAzLjhzMC0yLjItMS43'
    b'LTUuOGMtMS44LTMuNy0uNy03LjgtMTItMTctMi43LTUuNiA1LjYgMy41IDcuMyAyLjEgMS43'
    b'LTEuMy0zLTEzLjItMy0xMy40eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzJi'
    b'MmIyYiIgZD0iTTQxOC43IDE5MnMtMy4xLjgtMy41IDJjLS41IDEuNC0yLjMgMi42LTMuMyAy'
    b'LjItMS0uNC0yLjgtMi0yLjgtMiIvPgogIDxwYXRoIGZpbGw9IiMyYjJiMmIiIHN0cm9rZT0i'
    b'IzJiMmIyYiIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0iTTQwMSAyMDIuOXMtNC43IDQu'
    b'Ni0yLjQgNS4yYzIuMy42IDQuNy0zLjcgNC43LTMuN3MwIDcuMyAyIDYuMWMyLTEuMSA3Ljct'
    b'NS4yIDcuNy01LjJzMi0uMiAyLjUgMGMuNC4xIDUuMyA0LjQgOC42IDIuOC0xLjkgNC44LTQg'
    b'NS40LTQgNS40cy0zLjQgNC40LTcuOCAzLjRjLTQuNC0xLTUuNS0yLjgtNS41LTIuOHMtMy43'
    b'LjItNC44LTEuNWwtMS42LTIuNnMtMiAyLTIuNyAxYy0uNS0xIDAtNi43IDMuMy04LjF6Ii8+'
    b'CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMmIyYjJiIiBkPSJNNDI3LjUgMTk2LjRz'
    b'LTguNi0yLjYtMTEuNiAxLjdjLTMgNC4yLTIuMyA2LjYtLjcgNyIvPgogIDxwYXRoIGQ9Ik00'
    b'MjguOCAxOTYuMWMwIDEtLjcgMS45LTEuNiAxLjktMSAwLTEuNi0uOS0xLjYtMS45IDAtMSAu'
    b'Ny0xLjggMS42LTEuOC45IDAgMS42LjggMS42IDEuOHoiLz4KICA8cGF0aCBmaWxsPSIjMmIy'
    b'YjJiIiBzdHJva2U9IiMyYjJiMmIiIGQ9Ik00MDMuNyAyMTguMnMzLjUgNS40IDcuNyA2Ljkt'
    b'MyAyLjctNy4xIDBjLTMtNC4yLTIuMi03LjItMi4yLTcuMnMuOC0uOCAxLjYuM3ptMzAuMSAz'
    b'MS45cy05LjktMTMuNy0xMi43LTE0LjVjLTIuOS0uNyAyLjItMS4zIDUuMiAxLjYgMyAzLS44'
    b'LTQuNy0uOC00Ljd6Ii8+CiAgPHBhdGggZmlsbD0iIzJiMmIyYiIgc3Ryb2tlPSIjMmIyYjJi'
    b'IiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNNDAyLjcgMzI5LjZjMy44LTEgMjAuNCA5'
    b'LjUgMjQgMTIuMSAzLjggMi43IDExLjYgMSAxMS42IDFzLTMuNiAyLjItNS44IDIuN2MtMi4z'
    b'LjUgNi42LjUgNi42LjVzLTIxLjEgNS45LTQyLjYtNS40Yy0yLTguOCA0LjYtMTAuOCA2LjIt'
    b'MTAuOXoiLz4KICA8cGF0aCBmaWxsPSIjMmIyYjJiIiBzdHJva2U9IiMyYjJiMmIiIGQ9Ik00'
    b'MjcgMjUzLjVzLTIuOS0uNS00LjMtMi4xYy0xLjQtMS43LTMuNC01LjctNS41LTcuNC0yLjEt'
    b'MS42LTEyLjYtNy40LTE2LjQtNy0zLjguNC01LS40LTUuNS0uOS0uNC0uNS0yIC4yLTEuNyAy'
    b'LjIuMyAyLTMgNi4zLTEuOCA4LjNhNjIgNjIgMCAwIDAgNy43IDEwLjZjMSAuMy40IDQuOC40'
    b'IDQuOHM0LjggNC45IDYgNS4xYzEuMi4zIDIuNSAxLjIgMi4zIDIuNC0uMSAxLjEtNS4zIDcu'
    b'NC01LjMgNy40cy01LjUgMy01LjYgNC41YzAgMS43IDEuNCA1IDUuOCA2LjFhNDEgNDEgMCAw'
    b'IDAgMTYuOC0uOGMuNi0xIDEuNi03IDEuMi03LjctLjQtLjYtMy4zLTIuNC00LjgtMi4yLTEu'
    b'NS4zLTIuOSAxLjUtMi43IDEuOC4xLjMtMi4xIDEuNC0yLjEuMyAwLTEgNC40LTYgNC44LTUu'
    b'NS40LjQgNi42IDEgNy44IDQuMSAxLjEgMy4xIDEuMSA1LjQgNC40IDUgMy4yLS4zIDcuOC0z'
    b'LjMgOC4yLTkuNWExMyAxMyAwIDAgMC00LjctMTFjLTEtLjctNC40LTIuNy00LjctMy43LS4y'
    b'LTEtMS00LS40LTQuOHoiLz4KICA8cGF0aCBmaWxsPSIjMmIyYjJiIiBzdHJva2U9IiMyYjJi'
    b'MmIiIGQ9Ik0zNjguMyAyODFzMTAuNS0yLjcgMTMuMi0yLjZjMi43IDAgMTMgNC44IDE2IDcu'
    b'NyAzIDMgOSA5LjggMTMgOS4yIDQtLjYgNS4yLTEuNCA1LjItMS40bC0xLjYgM3MtMy4yLjkt'
    b'NC45LjVjLTEuNi0uNC00LjgtMS41LTgtNC42LTMuMS0zLTEzLTExLjUtMjEuMy0xMC45LTgu'
    b'My42LTEzLjEgOC44LTEzLjEgOC44czAtNCAuNC00LjljLjMtLjgtMS44IDItMS44IDJ6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzJiMmIyYiIgc3Ryb2tlPSIjMmIyYjJiIiBkPSJNNDA3IDI4OS4y'
    b'czIuNi43IDcgLjdjNC4zIDAgNi42LTEuOSA2LjYtMS45bC0uMy0xLjcuNy0yLjNzMy4zIDMu'
    b'MyAzLjMgNGMwIC43LTEuNCAxLTEuNCAxbC0uNS0xLjctMS4xIDEuNXMtNi4zIDUtOS44IDQu'
    b'MmMtMy40LS43LTYuNi0zLTUuNy0zLjUuOS0uNSAxLjMtLjMgMS4yLS4zem0tMTUuMyA4Ljhz'
    b'LTMuOCAwLTUuNS44Yy0xLjcuOC0yLjMgMS44LTMuNSAxLjctMS4xLS4yLTItMS42LTEuNy0y'
    b'LjIuNS0xIDIuOC0yLjIgNy0xLjkgNC4zLjQgMy43IDEuNiAzLjcgMS42em0xMy4zIDEwLjNj'
    b'MC0uMi0uMy01LjUtMi40LTcuN2E2LjQgNi40IDAgMCAwLTUuOC0xLjljLTEuMi4zIDQuMiAy'
    b'LjcgNC44IDQuMi41IDEuNiAyLjMgNiAxLjggNy0uNSAxLTEuMy0zLTQuNy00LjItMy4zLTEu'
    b'Mi03LjktLjUtNyAxIDEgMS40IDQuNyAwIDYuNiAzLjNhNjAgNjAgMCAwIDEgMy4zIDYuNWwu'
    b'Ny0yLjMgMS42LS40LjMtNC40eiIvPgogIDxwYXRoIGZpbGw9IiMyYjJiMmIiIHN0cm9rZT0i'
    b'IzJiMmIyYiIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0ibTQwMi4zIDMyNS43LTMuNS03'
    b'cy0xLTQuMy00LTUuNWMtMy0xLjMtNi44LTEtNi44LjQtLjEgMS41IDYuMiAzLjQgNi42IDQu'
    b'Mi40LjguMiAyLjItLjMgMi4zLS42IDAtMy40LTEtNC44LS43LTEuNC4zLTIuMiAyLjItNC4z'
    b'IDEuNi0yLjEtLjUtMy45LTcuMi0zLTggLjctLjYtMS42IDEuMy0yLjEtLjUtLjUtMS43Ljct'
    b'Ny4yLS4xLTcuOS0uOC0uNy00LjgtMy00LjgtMy41LS4xLS41LjItMjcgMjIuMy01LTkuNS0x'
    b'MS4zLTEzLjItMTAtMTUtMTAuMS0xLjIgMC05LjkuNy0xMiAxMS43LTIuMiAxMS00LjggNC4x'
    b'LTQuOCA0LjFzLS40IDQuOCAxLjkgNi4xYzIuMyAxLjQtMS4xIDUuMy0xLjEgNS4zcy00LjIt'
    b'MTAtMy41LTE0LjVjLS45IDMuNS0uOCAxMi4zIDQuNCAyMS44YTcxLjIgNzEuMiAwIDAgMCAy'
    b'Ny4yIDE5LjFjOC0xMi4zIDcuNy0xMy44IDcuNy0xNHoiLz4KICA8cGF0aCBmaWxsPSIjOGE5'
    b'Mzk2IiBzdHJva2U9IiMyYjJiMmIiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIGQ9Ik0zODcu'
    b'OCAzMjUuOHM0LjQuNSA1LjYgMi44YzEuMyAyLjMgMS44IDUuOCAxLjggNS44LjgtMS41IDEt'
    b'Mi43IDIuNi0zLjggMS41LTEuMSAyLjYtMS4zIDIuNS0yIDAtLjktNC44LTUuOC03LjEtNi4x'
    b'LTIuNC0uMy02LjUgMi42LTYuNSAyLjZzLS44IDEgMSAuN3oiLz4KICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiM4YTkzOTYiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTM5OCAz'
    b'MzcuNHMxMS42IDUuMyAzMC42IDUuNiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0i'
    b'IzJiMmIyYiIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBkPSJNNDM2LjcgMjgzLjZzLTEgOS43'
    b'LTguNSAyOSIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzJiMmIyYiIgZD0iTTQz'
    b'NS4yIDI4OS42cy0yLjMgNy04LjUgMTIuMiIvPgogIDxwYXRoIGQ9Im00MDEuMyA0MTAuMyAy'
    b'LTIuMi42LjUtLjEuMi0uMi4zdi4ybC4yLjIgMi42IDIuMy4yLjJoLjJsLjEtLjJxLjQtLjQu'
    b'NS0uOC4yLS40LjEtLjggMC0uNS0uNC0xbC44LS40IDEuMiAyLTMuMiAzLjYtLjYtLjUuMi0u'
    b'My4xLS4ydi0uMmwtLjItLjItMi42LTIuMy0uMy0uMmgtLjFsLS4zLjItLjIuMi0uNi0uNnpt'
    b'NC40LTQuOSAzLjctMy42IDEuOC45LS4zLjctMS0uMi0uNi4ycS0uMy4xLS42LjVsLS43LjYg'
    b'MSAxLjEuMy0uMnEuMy0uMi4zLS40di0uMmwtLjItLjMtLjItLjIuNi0uNiAxLjggMS45LS42'
    b'LjUtLjItLjEtLjMtLjNoLS4ybC0uNC4zLS4yLjIgMSAxIC4yLjJoLjFsLjItLjIuNC0uMy42'
    b'LS44cS4yLS40LjEtMSAwLS40LS4zLS45bC44LS40IDEgMi4zLTMuOCAzLjctLjYtLjZoLjJs'
    b'LjItLjR2LS4ybC0uMi0uMy0yLjQtMi40LS4zLS4yaC0uMmwtLjIuMS0uMi4yLS42LS42em03'
    b'LjctNy40cTEuMi0xIDIuNC0uOSAxLjMuMSAyLjIgMS4yLjYuNy44IDEuNS4yLjktLjEgMS42'
    b'LS4zLjgtMS4xIDEuNS0xIC45LTIuMi45LTEuNCAwLTIuNC0xLjItMS0xLS44LTIuMy4xLTEu'
    b'MyAxLjItMi4zem0uNy43cS0uNS41LS41IDEuMiAwIC44LjcgMS42dDEuNSAxcS42IDAgMS4x'
    b'LS40LjYtLjQuNi0xIDAtLjktLjgtMS43LS40LS41LTEtLjgtLjQtLjItLjktLjItLjQgMC0u'
    b'Ny4zem02LjEtNi4yLjUtLjMuMS4xIDIuOS0ydi0uMmwuNC0uMyAxLjkgMS4zLS41LjctLjct'
    b'LjNxLS40LS4yLS44LS4xbC0uNC4xLS4xLjF2LjJsMi4xIDMgLjIuM2guM2wuNS0uMy40Ljct'
    b'Mi40IDEuOC0uNS0uNy4xLS4xLjMtLjN2LS4ybC0uMS0uMy0yLjEtMy0uMi0uMi0uMS4xcS0u'
    b'Mi4xLS4zLjQtLjIuMy0uMi43bC4xLjgtLjguMi0uNi0yLjJ6bTUuNi0zLjUgNC40LTIuOCAx'
    b'LjcgMS4zLS42LjctLjgtLjRoLS43cS0uMyAwLS43LjNsLS44LjUuOCAxLjMuMi0uMi40LS4y'
    b'di0uM2wtLjEtLjQtLjEtLjIuNy0uNCAxLjMgMi4zLS43LjQtLjEtLjMtLjMtLjNoLS4ybC0u'
    b'NC4yLS4zLjEuOCAxLjMuMS4yaC4xbC4zLS4xLjQtLjMuOC0uNi4zLS45di0xbC44LS4yLjUg'
    b'Mi40LTQuNiAyLjgtLjQtLjcuMS0uMS4zLS4zcS4xIDAgMC0uMnYtLjNsLTEuOC0yLjktLjMt'
    b'LjNoLS4xbC0uMy4xLS4yLjEtLjUtLjd6bTYuMi0zLjggMy41LTEuOC43LS4zcS40LS4yLjkt'
    b'LjEuNCAwIC43LjJsLjUuNnEuNC43LjEgMS4zLS4yLjYtLjggMWwxLjguOGguMWwuMy4xaC4z'
    b'bC4yLS4xLjMtLjEuMy43LTEuNyAxLTMtMS41LS41LjIuNiAxLjEuMi40aC41bC4yLS4yLjQu'
    b'OC0yLjcgMS40LS40LS44LjMtLjEuMi0uMi4xLS4yLS4xLS4zLTEuNi0zLjEtLjItLjJxMC0u'
    b'MS0uMiAwaC0uM2wtLjIuMS0uNC0uN3ptMi42LS4yLjcgMS40LjgtLjRxLjUtLjIuNy0uNWwu'
    b'Mi0uNHYtLjVsLS40LS4zaC0uNGwtLjcuMi0xIC41em00LjQtMy40IDMuNi0xLjYuNy0uMmgu'
    b'OXEuNCAwIC43LjJsLjUuN3EuMy42IDAgMS4ydC0uOSAxbDEuOC45LjQuMWguNWwuMi0uMi40'
    b'LjgtMS44LjgtMy0xLjYtLjQuMi41IDEuMS4yLjRoLjRsLjMtLjEuMy43LTIuNyAxLjMtLjQt'
    b'LjguMy0uMS4yLS4yLjEtLjItLjEtLjMtMS40LTMuMnEwLS4yLS4yLS4zaC0uNWwtLjIuMi0u'
    b'My0uOHptMi42IDAgLjYgMS41LjktLjQuNy0uNHEuMi0uMi4yLS41di0uNGwtLjMtLjRoLS41'
    b'bC0uNy4yLTEgLjR6bTYuOC0zLjkgMS4zLS41IDMuNCAzLjkuNC4zaC41bC4yLjgtMi43IDEt'
    b'LjMtLjguMi0uMXEuMiAwIC4zLS4ydi0uMmwtLjItLjItLjQtLjUtMS43LjZ2MWwuMy4xLjQt'
    b'LjEuMy44LTIuMy44LS4zLS44cS4yIDAgLjMtLjJsLjEtLjF2LS40bC4yLTUuMnptMSAzLjIg'
    b'MS4xLS40LTEuMS0xLjR2MS44em0zLjgtNC45IDIuNy0uOCAyLjEgMy4zdi00bDIuOC0uNy4y'
    b'LjgtLjMuMXEtLjIgMC0uMy4ydi40bDEgMy40LjEuMi4yLjFoLjZsLjIuNy0yLjkuOS0uMi0u'
    b'OWguMnEuMyAwIC4zLS4ybC4xLS4xdi0uM2wtMS0zLjctLjEgNS40LS44LjItMi44LTQuNCAx'
    b'IDMuNy4xLjEuMi4xaC4zbC4zLS4xLjIuOC0yLjQuNy0uMy0uOGguM2wuMy0uMnYtLjVsLTEt'
    b'My4zdi0uM2wtLjItLjFoLS42bC0uMy0uN3ptMTIuNC0zLjMgMy4yLS42aDFxLjUgMCAuOC4y'
    b'LjQuMi42LjVsLjMuN3EuMS44LS40IDEuNC0uNS43LTEuNS45bC0xIC4yLjIgMS4xdi4zaC44'
    b'bC4xLjgtMyAuNnYtLjhoLjFsLjQtLjJ2LS41bC0uNi0zLjN2LS40bC0uMi0uMWgtLjZsLS4y'
    b'LS44em0yLjQuNi40IDEuN2guNWwuNy0uMy4zLS40di0uNXEwLS40LS40LS42LS4zLS4xLS44'
    b'IDBoLS43em00LjItMS44IDMuOC0uNWguOGwuOC4ycS40LjIuNi41LjMuMy4zLjcuMS43LS4z'
    b'IDEuMi0uNS41LTEuMS44bDEuNCAxLjMuMy4yLjIuMWguNnYuOGwtMS45LjMtMi4zLTIuNGgt'
    b'LjVsLjIgMS4ydi40bC4yLjJoLjZ2LjhsLTMgLjR2LS45aC4ybC4zLS4xLjItLjJ2LS4zbC0u'
    b'NS0zLjV2LS4zaC0uOGwtLjEtLjl6bTIuNC43LjIgMS42aDFsLjctLjMuNC0uM3YtLjVsLS4x'
    b'LS40LS40LS4yaC0uOGwtMSAuMXptOC44LTEuOXExLjQtLjEgMi40LjcgMSAuOSAxIDIuMyAw'
    b'IDEtLjMgMS43LS40LjctMSAxLjItLjguNC0xLjguNS0xLjQgMC0yLjMtLjYtMS4xLS45LTEu'
    b'Mi0yLjQgMC0xLjQuOC0yLjQuOS0xIDIuNC0xem0wIDFxLS43IDAtMSAuNi0uNi42LS41IDEu'
    b'NyAwIDEgLjYgMS42LjQuNSAxLjEuNS43IDAgMS4xLS42LjUtLjYuNC0xLjcgMC0uNy0uMy0x'
    b'LjItLjItLjUtLjYtLjctLjQtLjMtLjgtLjJ6bTQuNi0xLjFoMy40bDEgLjEuNy40LjQuNi4y'
    b'LjhxMCAuOC0uNiAxLjN0LTEuNy41aC0xdjEuNWwuNC4xaC4zdi45aC0zdi0uOWguNWwuMS0u'
    b'MXYtLjRsLjEtMy40di0uNGwtLjEtLjFoLS42di0xem0yLjMgMXYxLjhoLjZsLjctLjEuMy0u'
    b'M3EuMi0uMi4yLS41IDAtLjUtLjMtLjctLjMtLjItLjgtLjJoLS43em00LjUtMSAzLjguMy44'
    b'LjEuOC40cS4zLjIuNS42bC4xLjhxMCAuNy0uNiAxLS41LjUtMS4yLjZsMS4yIDEuNXYuMWwu'
    b'Mi4zaC4ybC4zLjFoLjN2LjlsLTItLjEtMS45LTIuOGgtLjV2MS42aC42djFsLTMtLjN2LS44'
    b'aC42bC4yLS4ydi0uM2wuMi0zLjV2LS4zbC0uMy0uMmgtLjR2LS45em0yLjIgMS4yLS4xIDEu'
    b'NmguOXEuNS4xLjggMCAuMyAwIC40LS4yLjItLjIuMi0uNXYtLjRsLS40LS4zLS44LS4xaC0x'
    b'em01LjQtLjYgMyAuNHYuOWgtLjNxLS4zLS4xLS40IDBsLS4yLjQtLjQgMy40di40aC4xbC4z'
    b'LjJoLjNsLS4xLjktMy0uNC4xLS45aC4ycS4zLjEuNCAwaC4xbC4xLS4zLjQtMy41di0uNWgt'
    b'LjRsLS4zLS4xLjEtLjl6bTYuNS45IDEuNC4zIDEgNXEwIC40LjIuNWwuNC4yLS4yLjgtMi45'
    b'LS41LjItLjhoLjVsLjEtLjF2LTFsLTItLjMtLjMuNnYuMnEtLjEuMSAwIC4yaC4xbC40LjIt'
    b'LjEuOC0yLjQtLjQuMS0uOGguNGwuMi0uMS4yLS4zIDIuNy00LjV6bS0uOCAzLjMgMS4zLjIt'
    b'LjMtMS44LTEgMS42em01LjktMi40IDIuNy43LjIgNCAyLTMuNCAyLjcuNy0uMi44aC0uM3Et'
    b'LjItLjItLjMgMC0uMiAwLS4yLjNsLS45IDMuNHYuNGwuMy4xLjMuMS0uMi45LTIuOS0uOC4y'
    b'LS44aC4zbC4zLjFoLjJ2LS40bDEtMy43LTIuNyA0LjctLjgtLjMtLjMtNS4xLS45IDMuNnYu'
    b'MmwuMS4yaC4zbC4zLjEtLjIuOS0yLjUtLjYuMi0uOWguM2wuMy4xaC4xbC4yLS40LjgtMy40'
    b'di0uNGwtLjMtLjEtLjMtLjEuMi0uOXptMTIuNSAzLjUgMyAxLjEgMSAuNS41LjYuMi43LS4x'
    b'LjhxLS4zLjctMSAxLS44LjMtMS44IDBsLTEtLjQtLjQgMXYuNWwuMy4yaC4zbC0uMy45LTIu'
    b'OS0xIC4zLS45aC4ybC40LjJoLjFsLjItLjQgMS4yLTMuMnYtLjVsLS4zLS4yaC0uMmwuMy0u'
    b'OXptMS43IDEuNy0uNiAxLjcuNS4yLjcuMS41LS4xLjMtLjVxLjEtLjQtLjEtLjctLjItLjMt'
    b'LjYtLjRsLS43LS4zem00LjYuNiAzLjUgMS42LjcuNHEuNC4yLjYuNmwuMy43LS4yLjhxLS4z'
    b'LjctLjkuOWgtMS4zbC41IDEuOS4yLjMuMS4yLjMuMmguMmwtLjMuOS0xLjgtLjgtLjgtMy4z'
    b'LS41LS4yLS41IDEuMXYuNmwuMi4xLjMuMi0uNC43LTIuNy0xLjIuMy0uOC4zLjEuMy4xaC4y'
    b'bC4xLS4zIDEuNC0zLjIuMS0uM3YtLjJsLS4yLS4xaC0uMmwtLjItLjEuNC0uOXptMS43IDEu'
    b'OS0uNyAxLjUuOS4zcS40LjMuNy4zbC41LS4xcS4yLS4xLjMtLjQuMS0uMiAwLS40bC0uMS0u'
    b'NC0uNy0uNC0xLS40em04LjUgMi45cTEuMy43IDEuNyAxLjkuNCAxLjItLjMgMi41LS40Ljgt'
    b'MS4xIDEuMi0uNy41LTEuNi41LS44IDAtMS43LS41LTEuMi0uNi0xLjctMS43LS41LTEuMy4z'
    b'LTIuNi42LTEuMyAxLjktMS43IDEuMi0uMyAyLjUuNHptLS40LjlxLS42LS40LTEuMy0uMS0u'
    b'Ny4zLTEuMiAxLjMtLjUuOS0uNCAxLjcuMS42LjggMSAuNi4zIDEuMiAwIC43LS4zIDEuMi0x'
    b'LjIuNC0uNy40LTEuMiAwLS42LS4yLTFsLS41LS41em01IDEuNS41LjN2LjJsMyAxLjkuMS0u'
    b'MS41LjMtLjUgMi4yLS44LS4ydi0uOHEwLS40LS4yLS43bC0uMy0uNGgtLjJsLS4xLjItMS45'
    b'IDMtLjIuNHYuMWwuMS4xLjQuMy0uNC43LTIuNi0xLjYuNS0uNy4xLjEuNC4yaC4xbC4zLS40'
    b'IDItM3YtLjNoLS4xcS0uMi0uMi0uNi0uMmwtLjYuMS0uNy40LS42LS42IDEuOC0xLjV6bTUu'
    b'NiAzLjggNC4yIDMtLjYgMi0uOC0uMnYtMWwtLjItLjZxLS4yLS4zLS42LS41bC0uNy0uNi0x'
    b'IDEuMy4zLjIuNC4yaC4zbC4yLS40LjItLjIuNi41LTEuNSAyLjEtLjYtLjQuMS0uMi4yLS40'
    b'di0uMmwtLjQtLjQtLjMtLjEtLjggMS4xLS4xLjMuMi4zLjQuMyAxIC40cS40LjEuOCAwIC41'
    b'LS4xIDEtLjVsLjQuNy0yIDEuNC00LjMtMyAuNS0uOC4xLjEuNC4yaC4ybC4yLS4zIDItMi44'
    b'LjItLjN2LS4xbC0uMy0uMy0uMi0uMS41LS43em02LjkgOC44IDIuMyAyLS41LjYtLjItLjEt'
    b'LjItLjJoLS4ybC0uMy4zLTEuMiAxLjUtLjctLjYuMS0uNS0xLS4yLS43LS41cS0uNy0uNi0x'
    b'LTEuMy0uMi0uOCAwLTEuNiAwLS44LjYtMS42LjYtLjcgMS40LTEgLjgtLjMgMS42LS4xLjgu'
    b'MSAxLjUuNmwuNS42LjQuNy4zLS4xLjUuNC0uOSAyLS44LS40di0xLjFsLS4xLS43LS40LS41'
    b'LS44LS4zLS45LjJxLS40LjItLjkuOGwtLjYgMXYxLjFxLjEuNC41LjdsLjUuM2guNWwuNC0u'
    b'Mi4xLS4yLjItLjN2LS4xbC0uMy0uMy0uMi0uMi41LS43em02LjcgMiAxIDEtMS45IDQuOHEt'
    b'LjIuMy0uMS41bC4yLjMtLjYuNy0yLTIgLjUtLjcuMS4yLjMuMWguMmwuMi0uMy4yLS41LTEu'
    b'NC0xLjMtLjYuMy0uMi4xdi4zbC4zLjMtLjYuNi0xLjctMS42LjYtLjYuMi4yaC4ybC40LS4x'
    b'IDQuNy0yLjN6bS0yLjQgMi4zLjkuOS43LTEuNy0xLjYuOHptNi41IDEuNC40LjQtLjEuMiAy'
    b'LjQgMi41aC4ybC40LjMtMSAyLS44LS4zLjItLjh2LS43cTAtLjMtLjItLjVoLS4ybC0uMi4x'
    b'LTIuNSAyLjUtLjMuM3YuMmwuMy40LS42LjYtMi0yLjIuNi0uNnYuMmwuNC4yaC4ybC4zLS4y'
    b'IDIuNi0yLjUuMS0uMnYtLjFsLS41LS4zaC0uN2wtLjguMi0uMy0uOCAyLTF6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzAxMjE2OSIgZD0iTTAgMGgzMjB2MjQwSDBaIi8+CiAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZD0ibTM3LjUgMCAxMjIgOTAuNUwyODEgMGgzOXYzMWwtMTIwIDg5LjUgMTIwIDg5'
    b'VjI0MGgtNDBsLTEyMC04OS41TDQwLjUgMjQwSDB2LTMwbDExOS41LTg5TDAgMzJWMFoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjYzgxMDJlIiBkPSJNMjEyIDE0MC41IDMyMCAyMjB2MjBsLTEzNS41'
    b'LTk5LjVabS05MiAxMCAzIDE3LjUtOTYgNzJIMFpNMzIwIDB2MS41bC0xMjQuNSA5NCAxLTIy'
    b'TDI5NSAwWk0wIDBsMTE5LjUgODhoLTMwTDAgMjFaIi8+CiAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZD0iTTEyMC41IDB2MjQwaDgwVjBaTTAgODB2ODBoMzIwVjgwWiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNjODEwMmUiIGQ9Ik0wIDk2LjV2NDhoMzIwdi00OFpNMTM2LjUgMHYyNDBoNDhWMFoiLz4K'
    b'PC9zdmc+Cg==', 'GS')

GS = b64_GS
index.append("GS")
index.append("SGS")
index.append("South Georgia and Sandwich Islands")
catalog["GS"] = GS
catalog["SGS"] = GS
catalog["South Georgia and Sandwich Islands"] = GS
country["South Georgia and Sandwich Islands"] = ('GS', 'SGS', 0)
lookup["GS"] = ('GS', 'SGS', 'South Georgia and Sandwich Islands', 0)
lookup["Grytviken South Georgia and Sandwich Islands"] = ('GS', 'SGS', 'South Georgia and Sandwich Islands', 0)
lookup["SGS"] = ('GS', 'SGS', 'South Georgia and Sandwich Islands', 0)
lookup["South Georgia and Sandwich Islands"] = ('GS', 'SGS', 'South Georgia and Sandwich Islands', 0)
details["GS"] = {"continent":"Americas","capital":"Grytviken","currency":"No universal currency","web":".gs","lang":"en","tz":"-02:00","altname":""}
#----------------------------------------------------------------------
b64_GT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ndCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHJhZGlhbEdyYWRpZW50IHhsaW5rOmhy'
    b'ZWY9IiNndC1hIiBpZD0iZ3QtZCIgY3g9IjQ0Ny40IiBjeT0iMzA4LjMiIHI9IjE2LjUiIGdy'
    b'YWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIi8+CiAgICA8cmFkaWFsR3JhZGllbnQgaWQ9'
    b'Imd0LWEiPgogICAgICA8c3RvcCBvZmZzZXQ9Ii4yIiBzdG9wLWNvbG9yPSIjZjlmMGFhIi8+'
    b'CiAgICAgIDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iI2IwN2UwOSIvPgogICAgPC9y'
    b'YWRpYWxHcmFkaWVudD4KICAgIDxyYWRpYWxHcmFkaWVudCB4bGluazpocmVmPSIjZ3QtYSIg'
    b'aWQ9Imd0LWUiIGN4PSI0NTEuNiIgY3k9IjMxMyIgcj0iMTAuOSIgZ3JhZGllbnRVbml0cz0i'
    b'dXNlclNwYWNlT25Vc2UiLz4KICAgIDxyYWRpYWxHcmFkaWVudCB4bGluazpocmVmPSIjZ3Qt'
    b'YSIgaWQ9Imd0LWYiIGN4PSI0NTQuMSIgY3k9IjMwOC42IiByPSI5LjgiIGdyYWRpZW50VW5p'
    b'dHM9InVzZXJTcGFjZU9uVXNlIi8+CiAgICA8cmFkaWFsR3JhZGllbnQgeGxpbms6aHJlZj0i'
    b'I2d0LWEiIGlkPSJndC1nIiBjeD0iNDU4LjQiIGN5PSIzMDcuMSIgcj0iMTcuNCIgZ3JhZGll'
    b'bnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxyYWRpYWxHcmFkaWVudCB4bGluazpo'
    b'cmVmPSIjZ3QtYSIgaWQ9Imd0LWoiIGN4PSI0NDYiIGN5PSIyNTIuNCIgcj0iMTMiIGdyYWRp'
    b'ZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIi8+CiAgICA8cmFkaWFsR3JhZGllbnQgaWQ9Imd0'
    b'LW0iIGN4PSI0NzcuOSIgY3k9IjIxNS4zIiByPSIuMyIgZ3JhZGllbnRVbml0cz0idXNlclNw'
    b'YWNlT25Vc2UiPgogICAgICA8c3RvcCBvZmZzZXQ9Ii4zIiBzdG9wLWNvbG9yPSIjYTUwYTBh'
    b'Ii8+CiAgICAgIDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iIzRjMDUwNSIvPgogICAg'
    b'PC9yYWRpYWxHcmFkaWVudD4KICAgIDxyYWRpYWxHcmFkaWVudCBpZD0iZ3QtbiIgY3g9IjQ4'
    b'OS4xIiBjeT0iMjEwLjMiIHI9Ii4zIiBmeD0iNDg5LjEiIGZ5PSIyMTAuMyIgZ3JhZGllbnRU'
    b'cmFuc2Zvcm09InNjYWxlKC45NzcwNyAxLjAyMzQ2KSIgZ3JhZGllbnRVbml0cz0idXNlclNw'
    b'YWNlT25Vc2UiPgogICAgICA8c3RvcCBvZmZzZXQ9IjAiIHN0b3AtY29sb3I9IiNmZmYiLz4K'
    b'ICAgICAgPHN0b3Agb2Zmc2V0PSIxIiBzdG9wLWNvbG9yPSIjZmZmIiBzdG9wLW9wYWNpdHk9'
    b'IjAiLz4KICAgIDwvcmFkaWFsR3JhZGllbnQ+CiAgICA8bGluZWFyR3JhZGllbnQgaWQ9Imd0'
    b'LWgiIHgxPSI0NzMuOSIgeDI9IjQ3Mi40IiB5MT0iMjU5LjIiIHkyPSIyMzIiIGdyYWRpZW50'
    b'VW5pdHM9InVzZXJTcGFjZU9uVXNlIj4KICAgICAgPHN0b3Agb2Zmc2V0PSIuMiIgc3RvcC1j'
    b'b2xvcj0iI2IwN2UwOSIgc3RvcC1vcGFjaXR5PSIwIi8+CiAgICAgIDxzdG9wIG9mZnNldD0i'
    b'MSIgc3RvcC1jb2xvcj0iI2IwN2UwOSIvPgogICAgPC9saW5lYXJHcmFkaWVudD4KICAgIDxs'
    b'aW5lYXJHcmFkaWVudCBpZD0iZ3QtaSIgeDE9IjQ4My4xIiB4Mj0iNDg1LjUiIHkxPSIyOTYu'
    b'NyIgeTI9IjMyNi42IiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSI+CiAgICAgIDxz'
    b'dG9wIG9mZnNldD0iLjIiIHN0b3AtY29sb3I9IiNiMDdlMDkiIHN0b3Atb3BhY2l0eT0iMCIv'
    b'PgogICAgICA8c3RvcCBvZmZzZXQ9IjEiIHN0b3AtY29sb3I9IiNiMDdlMDkiLz4KICAgIDwv'
    b'bGluZWFyR3JhZGllbnQ+CiAgICA8bGluZWFyR3JhZGllbnQgaWQ9Imd0LWsiIHgxPSI0NTEu'
    b'NSIgeDI9IjQ1NS40IiB5MT0iMjQ5LjUiIHkyPSIyNDAuNiIgZ3JhZGllbnRVbml0cz0idXNl'
    b'clNwYWNlT25Vc2UiPgogICAgICA8c3RvcCBvZmZzZXQ9Ii4yIiBzdG9wLWNvbG9yPSIjZjlm'
    b'MGFhIi8+CiAgICAgIDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iI2IwN2UwOSIvPgog'
    b'ICAgPC9saW5lYXJHcmFkaWVudD4KICAgIDxsaW5lYXJHcmFkaWVudCBpZD0iZ3QtbCIgeDE9'
    b'IjQ3My4zIiB4Mj0iNDc1LjkiIHkxPSIyMzcuMiIgeTI9IjI3MC40IiBncmFkaWVudFVuaXRz'
    b'PSJ1c2VyU3BhY2VPblVzZSI+CiAgICAgIDxzdG9wIG9mZnNldD0iLjIiIHN0b3AtY29sb3I9'
    b'IiNmOWYwYWEiLz4KICAgICAgPHN0b3Agb2Zmc2V0PSIxIiBzdG9wLWNvbG9yPSIjYjA3ZTA5'
    b'Ii8+CiAgICA8L2xpbmVhckdyYWRpZW50PgogIDwvZGVmcz4KICA8cGF0aCBmaWxsPSIjNDk5'
    b'N2QwIiBkPSJNMCAwaDY0MHY0ODBIMFoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjEz'
    b'LjMgMGgyMTMuNHY0ODBIMjEzLjNaIi8+CiAgPGcgdHJhbnNmb3JtPSJtYXRyaXgoLjgxMTMz'
    b'IDAgMCAuODI2NCAtNjkuNCAtOCkiPgogICAgPGcgc3Ryb2tlPSIjMjQ0MjBlIj4KICAgICAg'
    b'PHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0iTTQ1Mi4xIDM3Ny41YzIu'
    b'Ny0uNCA0LjItMS4yIDYtMS44bTIuMy00LjFhMTMgMTMgMCAwIDEgMyA0LjdtLTguMS01LjFh'
    b'MTMgMTMgMCAwIDEgMyA0LjJtLTQ5LjUtMTM2LjZjLTEgMS42LTMgMi43LTQuOCAzLjRtLS4z'
    b'LS4yYzAtMS40LS4yLTMgMC00LjRtLTEuOSA1YzAgLjQuNCAxLjQuNiAybTIuMSAxLTIgLjNt'
    b'LTQtLjljMCAyLjYuMyA1LjYuNSA3LjltLTEuOC0xYy41LjggMSAxLjUgMS42IDEuOW0tNC42'
    b'IDYuNWMuNS45IDEgMiAxLjMgNG0zLjctNC43LTIgMS41bTEuNyA0LjRjLTEgLjktMi4yIDEu'
    b'NS0zLjUgMi4xbS0zLjggNDAuNGExNiAxNiAwIDAgMCA0IDQuN20uNiAxLjdhOCA4IDAgMCAx'
    b'LTMtMW00LjQgOC41IDEuNyAxbS0uNCAzLjRjMS4yLjggMi41IDIuMyAzLjcgMy45bS0xLjQg'
    b'Mi44YzEuNC4zIDIuNS43IDMuMiAxbS0xIDIuNWgybTEuMy01LjMtLjUgNC4ybTEgMS42LjQt'
    b'MS42bTQuNyA2LS4xIDMuMm0zOS4yIDI3LjktMS4yIDEuNm0tMi40LTMuOS0uNy0xLjgiLz4K'
    b'ICAgICAgPGcgc3Ryb2tlLXdpZHRoPSIuMiI+CiAgICAgICAgPHBhdGggZmlsbD0iIzQwNjMy'
    b'NSIgZD0iTTQ4Ni4xIDM4NWE3LjggNy44IDAgMCAwLTMuMy0yLjdjLTcuNy00LTE1LjQtNS45'
    b'LTI0LTcuMy0yLjEtLjMtNC4xLTIuMi02LjItMy4yLTUtMi4zLTEwLjUtMy4yLTE1LjMtNS43'
    b'LS4zLS4xLTEuNS0uOC0yLTEuNS0yLTIuMi01LjUtMi45LTcuNi01LTguNC03LjgtMTcuMi0x'
    b'NS0yMS44LTI1LjUtNS42LTEyLjctMTIuNS0yNS44LTExLjYtNDAuMi42LTkuMi0uNy0xOC40'
    b'IDEuNS0yNyAzLjQtMTMgNy42LTI1LjcgMTUuNC0zNi40bC0xLjMuOGExMDMuOCAxMDMuOCAw'
    b'IDAgMC0xNS40IDM2LjNjLTIuMyA4LjctMSAxOC0xLjUgMjctMSAxNC41IDYgMjcuNiAxMS41'
    b'IDQwLjMgNC42IDEwLjQgMTMuNSAxNy43IDIxLjggMjUuNiAyLjIgMiA1LjYgMi43IDcuNiA1'
    b'YTEwIDEwIDAgMCAwIDIgMS41YzQuOSAyLjQgMTAuNCAzLjMgMTUuNCA1LjcgMiAxIDQgMi44'
    b'IDYgMy4yYTc2LjUgNzYuNSAwIDAgMSAyNC4yIDcuMiA4IDggMCAwIDEgMy4zIDIuN2wxLjMt'
    b'LjkiLz4KICAgICAgICA8ZyBmaWxsPSIjNjc5MjNkIj4KICAgICAgICAgIDxwYXRoIGQ9Ik00'
    b'MDYuMyAzMzEuNmE0Ni45IDQ2LjkgMCAwIDEtLjItMjMuNWM2LjcgMTMgNC41IDIzLjcuMiAy'
    b'My41em00NS45IDQ1LjRhNDkgNDkgMCAwIDAtMjEuOSAxMS40YzE1LjEuMSAyNC03LjMgMjEu'
    b'OS0xMS40em03LjUtNC4zYTYwLjEgNjAuMSAwIDAgMS0xNC0yNi41YzE1IDEwLjkgMTguOSAy'
    b'NC4zIDE0IDI2LjV6Ii8+CiAgICAgICAgICA8cGF0aCBkPSJNNDU0LjYgMzcyLjhhNTUuMSA1'
    b'NS4xIDAgMCAxLTE2LTIyLjhjMTUuMyA4LjIgMjAuMyAyMC4yIDE2IDIyLjh6TTQzOSAzNjZj'
    b'MS03LjgtNS42LTI0LjItNy41LTI2LTMgMTYuNSAzIDI3LjYgNy41IDI2em0tMjcuMy0yNC4z'
    b'YTQyIDQyIDAgMCAxIC41LTIxYzUuNSAxMS43IDMuMyAyMS4yLS41IDIxek0zOTggMjY0Ljlh'
    b'NTEgNTEgMCAwIDEgMjEtMTZjLTYuOCAxNC42LTE4IDE5LjktMjEgMTZ6Ii8+CiAgICAgICAg'
    b'ICA8cGF0aCBkPSJNMzk4LjcgMjU5LjNhNTEuOCA1MS44IDAgMCAxIDE3LjQtMjBjLTMuNyAx'
    b'NS43LTEzLjcgMjMuMi0xNy40IDIwem0yNy45IDk5LjJhNTUgNTUgMCAwIDEtNy4zLTI2LjRj'
    b'MTEuMiAxMi41IDEyIDI1LjMgNy4yIDI2LjR6TTM5Ny45IDMyMmMtNyAxLjEtMjEuNC00LjYt'
    b'MjMtNi4zIDE0LjYtMy4yIDI0LjQgMiAyMyA2LjN6bS0yLjItOS43Yy44LTUuNSA4LjYtMTUu'
    b'OCAxMC4zLTE2LjYtMSAxMi03LjQgMTguNi0xMC4zIDE2LjZ6bTUxLjMgNTguNmE1NyA1NyAw'
    b'IDAgMC0yNi4xIDEzLjZjMTggLjEgMjguNy04LjcgMjYuMS0xMy42eiIvPgogICAgICAgIDwv'
    b'Zz4KICAgICAgICA8ZyBmaWxsPSIjNDA2MzI1Ij4KICAgICAgICAgIDxwYXRoIGQ9Ik00MDYu'
    b'NCAzMzEuNWM0LjIuMiA2LjQtMTAuNC0uMy0yMy40YTc4LjkgNzguOSAwIDAgMSAuMyAyMy40'
    b'em0xMS4yIDIwYTQ4LjggNDguOCAwIDAgMC0yMS43LTExLjJjOC45IDEyLjEgMTkuOSAxNS4x'
    b'IDIxLjcgMTEuMnptLTI0LjQtNTNhNTYuOCA1Ni44IDAgMCAwLTE0LjgtMjRjMS41IDE3LjIg'
    b'MTAuNiAyNi43IDE0LjggMjR6bTguNCAzNC4zYy01LTMuNy0xOS01LjQtMjEtNC44IDEwLjIg'
    b'OC40IDIwLjIgOC41IDIxIDQuOHptLTkuNC0yNC44YTQyIDQyIDAgMCAwLTE2LjktMTMuOGM1'
    b'LjUgMTIuNCAxNC42IDE3IDE2LjkgMTMuN3ptMi44LTQ3LjZjLjgtNy42LTUuNi0yMy40LTcu'
    b'NC0yNS4yLTIuOSAxNiAyLjkgMjYuNyA3LjMgMjUuMnptNC40LTE0LjljMi43LTYuNS44LTIy'
    b'LjQtLjUtMjQuNC02LjQgMTMuNS0zLjggMjQuNi41IDI0LjR6Ii8+CiAgICAgICAgICA8cGF0'
    b'aCBkPSJNNDA0LjQgMjM3LjhhNDAuMyA0MC4zIDAgMCAwIDMuNS0xOS40Yy03LjIgOS43LTcg'
    b'MTguOS0zLjUgMTkuNHptNi02LjFhMzguOCAzOC44IDAgMCAwIDktMTcuNGMtOS43IDctMTIu'
    b'MiAxNS44LTkgMTcuNHptLTE2LjEgNDMuMmMuMS45LTEtOC4yLTEwLTE4LjMuNCAxNC44IDYu'
    b'MiAyMC40IDEwIDE4LjN6bTMyLjYgODUuOGE1MyA1MyAwIDAgMC0yNS44LTZjMTIuNiAxMC40'
    b'IDI0LjkgMTAuNiAyNS44IDZ6TTQzOSAzNjZjLTQuNiAxLjUtMTAuNS05LjUtNy42LTI2YTk5'
    b'IDk5IDAgMCAwIDcuNSAyNnptMTMuMyAxMWMyIDQuMS02LjggMTEuNS0yMS44IDExLjQgMTIt'
    b'NSAyMS4yLTkuOSAyMS44LTExLjN6bTcuMy00LjRjNC45LTIuMyAxLjEtMTUuNS0xNC0yNi40'
    b'IDguNiAxMy4yIDE0LjUgMjQuNiAxNCAyNi40eiIvPgogICAgICAgICAgPHBhdGggZD0iTTQ1'
    b'NC42IDM3Mi43YzQuMi0yLjctLjctMTQuNS0xNi0yMi43IDkuNSAxMS4yIDE2LjIgMjEgMTYg'
    b'MjIuN3ptLTQyLjgtMzFjMy43LjIgNi05LjMuNS0yMSAuNyAxMSAuNCAyMC0uNSAyMXpNMzk4'
    b'IDI2NWMzIDMuOCAxNC0xLjQgMjAuOS0xNmE5MC42IDkwLjYgMCAwIDEtMjAuOSAxNnoiLz4K'
    b'ICAgICAgICAgIDxwYXRoIGQ9Ik0zOTguOSAyNTkuM2MzLjYgMy4yIDEzLjUtNC4zIDE3LjIt'
    b'MjAtOCAxMS4zLTE1LjYgMTkuOC0xNy4yIDIwem0yNy43IDk5LjFjNC43LTEuMSA0LTEzLjgt'
    b'Ny4zLTI2LjMgNSAxMy41IDggMjQuOCA3LjMgMjYuM3pNMzk3LjcgMzIyYzEuNC00LjMtOC4z'
    b'LTkuNC0yMi44LTYuMyAxMi4zIDIuMiAyMiA1IDIyLjggNi4zem0tMS45LTkuNmMyLjkgMS44'
    b'IDkuMS00LjcgMTAuMy0xNi43YTY4LjYgNjguNiAwIDAgMS0xMC4zIDE2Ljd6TTQ0NyAzNzFj'
    b'Mi41IDUtOCAxMy43LTI2IDEzLjYgMTQuMi01LjkgMjUuMy0xMS44IDI2LTEzLjZ6Ii8+CiAg'
    b'ICAgICAgICA8cGF0aCBkPSJNMzk5LjQgMzI2LjNhNDUgNDUgMCAwIDAtMTctMTUuOGM1IDEz'
    b'LjYgMTQuMiAxOS4xIDE3IDE1Ljh6Ii8+CiAgICAgICAgPC9nPgogICAgICAgIDxnIGZpbGw9'
    b'IiM2NzkyM2QiPgogICAgICAgICAgPHBhdGggZD0iTTM5Mi40IDI3NGM0LTQuNyAxNy41LTku'
    b'MiAxOS42LTktOCAxMC41LTE4IDEyLjYtMTkuNiA5em0yNS4xIDc3LjVjLTEuOCA0LTEyLjcg'
    b'MS0yMS43LTExLjFhODQuNCA4NC40IDAgMCAwIDIxLjcgMTEuMXptLTI0LjQtNTNjLTQuMiAy'
    b'LjctMTMuMS02LjgtMTQuNy0yNCA2LjYgMTMuMyAxMyAyMy41IDE0LjcgMjR6bTguNCAzNC4z'
    b'Yy0uNyAzLjctMTAuNyAzLjYtMjAuOC00LjdhNzQgNzQgMCAwIDAgMjAuOCA0Ljd6bS05LjUt'
    b'MjQuOWMtMi4zIDMuMi0xMS4yLTEuMy0xNi43LTEzLjcgOC4yIDggMTUuNSAxMy43IDE2Ljgg'
    b'MTMuN3ptMi44LTQ3LjZjLTQuNCAxLjYtMTAuMS05LTcuMy0yNSAyLjcgMTMuNSA2IDI0LjIg'
    b'Ny4zIDI1em00LjUtMTQuOWMtNC4zLjMtNi45LTEwLjgtLjUtMjQuMy0uOCAxMi44LS41IDIz'
    b'LjMuNSAyNC4zem01LTcuNmMtMy40LS42LTMuNy05LjcgMy42LTE5LjRhNjYuMiA2Ni4yIDAg'
    b'MCAwLTMuNiAxOS40em02LTYuMWMtMy4xLTEuNy0uNy0xMC40IDktMTcuM2E2Ni4yIDY2LjIg'
    b'MCAwIDAtOSAxNy4zeiIvPgogICAgICAgICAgPHBhdGggZD0iTTM5NC4zIDI3NC45Yy0zLjkg'
    b'Mi4xLTkuNi0zLjUtMTAtMTguMyA1IDExLjcgOC42IDE3LjggMTAgMTguM3ptMzIuNSA4NS44'
    b'Yy0uOSA0LjYtMTMuMSA0LjQtMjUuNy01LjkgMTMuMiA0LjMgMjQuMyA2LjcgMjUuNyA1Ljl6'
    b'bS04LjItOS41QTQxIDQxIDAgMCAxIDQxMiAzMzJjOSA4LjcgMTAuMiAxOC4xIDYuOCAxOS4y'
    b'em0tMTYuOC0yNWMtMy42LTUuOC00LTIwLjktMy0yMyA4LjMgMTEuOSA3LjMgMjIuNyAzIDIz'
    b'em0tMi43LjFjLTIuNyAzLjMtMTEuOS0yLjEtMTYuOC0xNS44YTc3LjMgNzcuMyAwIDAgMCAx'
    b'Ni44IDE1Ljh6Ii8+CiAgICAgICAgPC9nPgogICAgICAgIDxnIGZpbGw9IiM0MDYzMjUiPgog'
    b'ICAgICAgICAgPHBhdGggZD0iTTM5Mi40IDI3NGMxLjYgMy42IDExLjQgMS41IDE5LjUtOC45'
    b'LTEyIDYuOC0xNi43IDkuOC0xOS41IDguOXptOS4zIDUyYzQuMy0uMyA1LjMtMTEtMy0yMi44'
    b'YTcyLjcgNzIuNyAwIDAgMSAzIDIyLjl6bTE3IDI1LjJjMy40LTEgMi4yLTEwLjUtNi43LTE5'
    b'LjIgNC40IDkuNyA3LjIgMTggNi43IDE5LjJ6Ii8+CiAgICAgICAgICA8cGF0aCBkPSJNMzk0'
    b'LjIgMjkxLjhjMi04LjQtMS43LTIyLjYtNC4zLTI1LjYtNC43IDE1LjQtLjIgMjYuNiA0LjMg'
    b'MjUuNnoiLz4KICAgICAgICA8L2c+CiAgICAgICAgPHBhdGggZmlsbD0iIzY3OTIzZCIgZD0i'
    b'TTM5NCAyOTMuOGMtNiAxLjMtOC43LTEyLTQuMS0yNy4xIDEgMTMuNSAyLjggMjYuMSA0IDI3'
    b'eiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiM2NzkyM2QiIGQ9Ik0zOTIuNyAyOTMuN2E1MyA1'
    b'MyAwIDAgMSA5LTI0LjdjMiAxNS44LTQuNSAyNi4zLTkgMjQuN3oiLz4KICAgICAgICA8cGF0'
    b'aCBmaWxsPSIjNDA2MzI1IiBkPSJNMzkyLjggMjkzLjZjNC41IDEuNiAxMC45LTguOCA4Ljkt'
    b'MjQuNi0zLjUgMTMuMy03LjUgMjMuOC04LjkgMjQuNnoiLz4KICAgICAgICA8cGF0aCBmaWxs'
    b'PSIjNjc5MjNkIiBkPSJNMzk0LjEgMzAzLjNhNTAgNTAgMCAwIDEgMTAuNi0yMy43Yy44IDE2'
    b'LjItNi4zIDI1LjktMTAuNiAyMy43eiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiM0MDYzMjUi'
    b'IGQ9Ik0zOTQuMiAzMDMuNGM0LjIgMi4yIDExLjMtNy40IDEwLjUtMjMuNS00LjQgMTIuOC05'
    b'IDIyLjktMTAuNSAyMy41eiIvPgogICAgICA8L2c+CiAgICAgIDxnIGZpbGw9IiNiYTFmM2Ui'
    b'IHN0cm9rZT0iIzUxMTEyNCIgc3Ryb2tlLXdpZHRoPSIuMiI+CiAgICAgICAgPGNpcmNsZSBj'
    b'eD0iMzk2LjgiIGN5PSIyNTEuMyIgcj0iMS4xIi8+CiAgICAgICAgPGNpcmNsZSBjeD0iNDA1'
    b'LjIiIGN5PSIyNDUuMSIgcj0iMS4xIi8+CiAgICAgICAgPGNpcmNsZSBjeD0iNDAxLjYiIGN5'
    b'PSIyNDEuNyIgcj0iMS4xIi8+CiAgICAgICAgPGNpcmNsZSBjeD0iMzkyLjUiIGN5PSIzMTMu'
    b'MSIgcj0iMS4zIi8+CiAgICAgICAgPGNpcmNsZSBjeD0iMzk1IiBjeT0iMjk3LjEiIHI9IjEu'
    b'MyIvPgogICAgICAgIDxjaXJjbGUgY3g9IjQwOC4yIiBjeT0iMzM0LjUiIHI9IjEuMyIvPgog'
    b'ICAgICAgIDxjaXJjbGUgY3g9IjQwMi40IiBjeT0iMzM2LjQiIHI9IjEuMyIvPgogICAgICAg'
    b'IDxjaXJjbGUgY3g9IjQ0Ni43IiBjeT0iMzY3LjYiIHI9IjEuMyIvPgogICAgICAgIDxjaXJj'
    b'bGUgY3g9IjQ0OS42IiBjeT0iMzc0LjciIHI9IjEuMyIvPgogICAgICA8L2c+CiAgICA8L2c+'
    b'CiAgICA8ZyBzdHJva2U9IiMyNDQyMGUiPgogICAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2Utd2lkdGg9Ii40IiBkPSJNNTYxLjEgMjU5Yy43LjYgMS4yLjggMi4zIDEuOW0tNi42LTE4'
    b'LjljMC0xLjQtLjYtMy43LS45LTVtMy41IDNjMCAxLjktLjMgMy43LTEuMSA1LjRtLTQuMi0u'
    b'NWMxLjggMS42IDMuNSAzIDUuMyAzLjltMy44IDEuMmMuMSAyLS4xIDQtLjcgNm0uNCAxLjUg'
    b'MS4zLTIuM20tMS45IDEyLjJjMS40LjMgMi44IDIgMy41IDMuNW0uNS0xLjMgMS42LTIuMm0x'
    b'LjcgMzAuOGEyNCAyNCAwIDAgMS0yLjQgMy40bS00IDBjLjggMS40IDEuNiAzIDIuNiA0bTIu'
    b'NSA1LjlhMTMuMiAxMy4yIDAgMCAxLTQuNSA0bS4yIDQuNWMtMS4xLjgtMi41IDMtMy43IDQu'
    b'N204LjQtMjAuMi0yLjEuOW0tMS40LTcuNCAxLjIgMW0tOS4zIDM3LjRoLTJtLTIuMS0xLjgu'
    b'NiAxLjZtLTcuNiA1LjFjLS4zIDEuOS0uMSAzLjcuMSA1LjZtNC4zLTkgMSAyLjJtMy45LS4x'
    b'LTIuNS4zTTUyMiAzNjUuNmwtMSAxLjhtMTEuOS00Yy0xLjUuMi0yLjggMC00LjEtLjJtLTUu'
    b'NSA2Yy0xLS41LTItLjctMy0xbS0xNC43IDIuN2MtLjkuNy0yIDIuNC0zIDRtLS42LTQuNWMt'
    b'Mi40IDEuMy0zLjIgMy43LTQuNCA1LjhtMi44IDIuOGMtMS42LS40LTMuNC0xLjItNS4zLTJt'
    b'MTYuNy0uN2MtMi4zLTEuMi00LjctMS03LjEtMS40bTEwLjgtLjRjLTMuNy0uNy03LS42LTEw'
    b'LjMtLjFtNy44LTIuNi0xLjQtLjZtLTUuNiA1LjUtMi4zLTEuM201Ny45LTQ5LjJjLTEuMi44'
    b'LTIuNSAyLjMtMy43IDMuOW0xLjgtNzkuNi0yLjItLjgiLz4KICAgICAgPGcgc3Ryb2tlLXdp'
    b'ZHRoPSIuMiI+CiAgICAgICAgPHBhdGggZmlsbD0iIzQwNjMyNSIgZD0iTTQ3NC40IDM4NC45'
    b'Yy44LTEuMyAyLjEtMiAzLjMtMi43IDcuNy00IDE1LjQtNS44IDI0LTcuMiAyLjEtLjQgNC4x'
    b'LTIuMyA2LjItMy4yIDUtMi40IDEwLjUtMy4zIDE1LjMtNS43LjMtLjIgMS41LS45IDItMS42'
    b'IDItMi4yIDUuNS0yLjkgNy42LTUgOC40LTcuOCAxNy4yLTE1IDIxLjgtMjUuNSA1LjYtMTIu'
    b'NyAxMi41LTI1LjggMTEuNi00MC4yLS42LTkuMi43LTE4LjQtMS41LTI3YTEwNC42IDEwNC42'
    b'IDAgMCAwLTE1LjQtMzYuNGwxLjMuOGExMDMuOCAxMDMuOCAwIDAgMSAxNS40IDM2LjRjMi4z'
    b'IDguNiAxIDE3LjkgMS41IDI3IDEgMTQuNC02IDI3LjUtMTEuNSA0MC4zLTQuNiAxMC40LTEz'
    b'LjUgMTcuNi0yMS44IDI1LjUtMi4yIDItNS42IDIuNy03LjYgNWExMCAxMCAwIDAgMS0yIDEu'
    b'NWMtNC45IDIuNC0xMC40IDMuNC0xNS40IDUuNy0yIDEtNCAyLjgtNiAzLjJBNzYuNSA3Ni41'
    b'IDAgMCAwIDQ3OSAzODNhOCA4IDAgMCAwLTMuMyAyLjdsLTEuMy0uOCIvPgogICAgICAgIDxn'
    b'IGZpbGw9IiM0MDYzMjUiPgogICAgICAgICAgPHBhdGggZD0iTTU1My42IDMzNC42YzIuOC03'
    b'LjQgMC0yNC44LTEuNC0yNy02LjcgMTUuNC0zLjQgMjcuNiAxLjQgMjd6Ii8+CiAgICAgICAg'
    b'ICA8cGF0aCBkPSJNNTQ2LjUgMzQxLjZjMi4zLTUuNi43LTE5LjMtLjQtMjEtNS41IDExLjct'
    b'My4zIDIxLjMuNCAyMXptMTYuOS03NC4xYTQ2LjkgNDYuOSAwIDAgMC0xOS4zLTE0LjZjNi4y'
    b'IDEzLjMgMTYuNSAxOC4yIDE5LjMgMTQuNnoiLz4KICAgICAgICAgIDxwYXRoIGQ9Ik01NjEu'
    b'OCAyNTkuNWE0My4zIDQzLjMgMCAwIDAtMTQuNS0xNi43YzMuMSAxMyAxMS40IDE5LjMgMTQu'
    b'NSAxNi43em00LjcgMTQuOWMtMy41LTQtMTUuMi03LjktMTctNy43IDcgOSAxNS42IDEwLjkg'
    b'MTcgNy43em0tMi44IDQ2LjRhNDAgNDAgMCAwIDAgMjAuMy01LjdjLTEyLjktMi44LTIxLjUg'
    b'MS45LTIwLjMgNS43em0tLjItNS43YzAtNS42LTYuMy0xNi44LTgtMTgtLjUgMTIgNC45IDE5'
    b'LjUgOCAxOHoiLz4KICAgICAgICAgIDxwYXRoIGQ9Ik01NjQgMzAxLjRhNTAgNTAgMCAwIDAt'
    b'MTAuNi0yMy42Yy0uOCAxNi4yIDYuMyAyNS44IDEwLjYgMjMuNnptLTUzIDc1LjNhNDcuNyA0'
    b'Ny43IDAgMCAwIDIyLjIgMTFjLTguOC0xMi4zLTIwLjEtMTUuMS0yMi4xLTExeiIvPgogICAg'
    b'ICAgIDwvZz4KICAgICAgICA8ZyBmaWxsPSIjNjc5MjNkIj4KICAgICAgICAgIDxwYXRoIGQ9'
    b'Ik01NTMuNiAzMzQuNGMtNC45LjYtOC4xLTExLjQtMS40LTI2LjgtLjUgMTQuMi4yIDI1Ljcg'
    b'MS40IDI2Ljh6TTUwMC4yIDM3OGE1MCA1MCAwIDAgMSAyMS45IDExLjVjLTE1LjEuMS0yNC03'
    b'LjMtMjItMTEuNHptMC03LjljMi04IDE1LTIxLjIgMTcuNS0yMi4xLTMuNiAxNy4xLTEzLjcg'
    b'MjUuNS0xNy41IDIyLjF6bTIxLjMtNC4xYTU0IDU0IDAgMCAxIDcuNS0yNmMzIDE2LjQtMyAy'
    b'Ny41LTcuNSAyNnptMjEuNS0xNC42YTQ4LjggNDguOCAwIDAgMSAyMS42LTExLjJjLTguOSAx'
    b'Mi4xLTE5LjggMTUuMS0yMS43IDExLjJ6bTI1LjctNTMuM2MxLTYuMyA5LjctMTcuOSAxMS42'
    b'LTE4LjktMS4yIDEzLjYtOC4zIDIxLTExLjYgMTl6Ii8+CiAgICAgICAgICA8cGF0aCBkPSJN'
    b'NTU3IDMzNi4yYTUwLjUgNTAuNSAwIDAgMSAyNC40LTUuNWMtMTEuOCA5LjctMjMuNSA5Ljgt'
    b'MjQuNCA1LjV6bTEwLjMtMjQuNWE0NCA0NCAwIDAgMSAxNy43LTE0LjRjLTUuOCAxMy0xNS4z'
    b'IDE3LjgtMTcuNyAxNC40em0tMS41LTQ1LjZjMC03LjYgOC0yMi43IDEwLTI0LjIgMS4xIDE2'
    b'LjEtNS43IDI2LjItMTAgMjQuMnptLTYuOS0yNS45YTQwLjQgNDAuNCAwIDAgMS0uMS0yMGM1'
    b'LjUgMTAuOSAzLjcgMjAgMCAyMHoiLz4KICAgICAgICAgIDxwYXRoIGQ9Ik01NTQuNiAyMzhh'
    b'NDkuNyA0OS43IDAgMCAxLTEwLjQtMjIuMWMxMS44IDkuMyAxNC40IDIwLjQgMTAuNCAyMi4x'
    b'em0xMS43IDM0LjVjLS4zLjkgMy03LjcgMTQuMi0xNS4zLTQgMTQuMy0xMSAxOC4zLTE0LjIg'
    b'MTUuM3ptLTM0LjEgODkuOWE2MSA2MSAwIDAgMSAyOS4yLTYuN2MtMTQuMiAxMS44LTI4LjIg'
    b'MTItMjkuMiA2Ljd6bTE0LjMtMjAuOGMtMy43LjItNi05LjMtLjUtMjEtLjcgMTEtLjQgMjAg'
    b'LjUgMjF6bTE2LjktNzQuMWMtMi43IDMuNi0xMy0xLjItMTkuMi0xNC42YTc4LjggNzguOCAw'
    b'IDAgMCAxOS4yIDE0LjZ6bS0xLjctOGMtMy4xIDIuNi0xMS4zLTMuNi0xNC40LTE2LjcgNi43'
    b'IDkuNCAxMyAxNi41IDE0LjQgMTYuN3ptNC44IDE1Yy0xLjQgMy4xLTkuOSAxLjMtMTYuOS03'
    b'LjcgMTAuNCA1LjkgMTQuNSA4LjQgMTcgNy43em0tMi42IDQ2LjJjLTEuMy0zLjggNy4zLTgu'
    b'MyAyMC4yLTUuNWE2OSA2OSAwIDAgMC0yMC4yIDUuNXptLS40LTUuNmMtMy4yIDEuNS04LjUt'
    b'NS45LTgtMTcuOWE2OC43IDY4LjcgMCAwIDAgOCAxOHoiLz4KICAgICAgICAgIDxwYXRoIGQ9'
    b'Ik01NjMuOSAzMDEuNmMtNC4zIDIuMi0xMS4zLTcuNC0xMC41LTIzLjUgNC40IDEyLjggOSAy'
    b'Mi45IDEwLjUgMjMuNXptLTUyLjcgNzUuMWMyLTQuMiAxMy4xLTEuNCAyMiAxMC44LTExLTYu'
    b'Ny0yMC41LTExLjMtMjItMTAuOHoiLz4KICAgICAgICA8L2c+CiAgICAgICAgPGcgZmlsbD0i'
    b'IzQwNjMyNSI+CiAgICAgICAgICA8cGF0aCBkPSJNNTIxLjUgMzY1LjhjNC42IDEuNiAxMC41'
    b'LTkuNCA3LjYtMjUuOS0yLjggMTQtNi4yIDI1LjEtNy42IDI2eiIvPgogICAgICAgICAgPHBh'
    b'dGggZD0iTTUzMS44IDM2MC42YTU1IDU1IDAgMCAwIDQuNi0yN2MtMTAgMTMuNi05LjQgMjYu'
    b'My00LjYgMjd6bS0zMS43IDE3LjVjLTIgNC4xIDYuNyAxMS41IDIxLjggMTEuMy0xMi00Ljgt'
    b'MjEuMi05LjgtMjEuOC0xMS4zem0uMi04LjFjMy44IDMuNCAxMy44LTQuOSAxNy40LTIyLTgu'
    b'MSAxMi40LTE1LjcgMjEuOC0xNy40IDIyem00Mi43LTE4LjZjMS44IDQgMTIuNyAxIDIxLjct'
    b'MTEuMWE4NC40IDg0LjQgMCAwIDEtMjEuNyAxMS4xem0yNS44LTUzLjNjMy4zIDIuMSAxMC4z'
    b'LTUuMyAxMS41LTE4LjhhNzQuOCA3NC44IDAgMCAxLTExLjUgMTguOHpNNTU3IDMzNi4yYzEg'
    b'NC40IDEyLjUgNC4yIDI0LjQtNS41LTEyLjUgNC0yMyA2LjItMjQuMyA1LjV6bTEwLjQtMjQu'
    b'NmMyLjUgMy40IDExLjktMS40IDE3LjctMTQuNGE3NSA3NSAwIDAgMS0xNy43IDE0LjR6TTU2'
    b'NiAyNjZjNC4yIDIgMTEtOCA5LjgtMjQtNCAxMy04LjQgMjMuMy05LjkgMjR6bS03LTI1Ljlj'
    b'My41LjEgNS40LTktLjItMjAgMSAxMC41IDEgMTkuMS4yIDIwem0tNC4zLTIuMmM0LTEuNyAx'
    b'LjQtMTIuNy0xMC40LTIyYTgxLjcgODEuNyAwIDAgMSAxMC40IDIyem0xMS42IDM0LjdjMy4y'
    b'IDMgMTAuMi0xIDE0LjItMTUuNC03LjggMTAuMS0xMi43IDE1LjItMTQuMiAxNS40em0tMzQg'
    b'ODkuOWMxIDUuMiAxNC45IDUgMjktNi43LTE0LjkgNC44LTI3LjQgNy42LTI5IDYuN3oiLz4K'
    b'ICAgICAgICAgIDxwYXRoIGQ9Ik01MzkuMSAzNTQuOGE0MSA0MSAwIDAgMCAzLjYtMjAuMWMt'
    b'Ny41IDEwLTcuMiAxOS41LTMuNiAyMHptMTkuNi0yOC43YzMuNi01LjcgNC0yMC45IDMtMjMt'
    b'OC4zIDExLjktNy4zIDIyLjctMyAyM3oiLz4KICAgICAgICA8L2c+CiAgICAgICAgPHBhdGgg'
    b'ZmlsbD0iIzY3OTIzZCIgZD0iTTUzMS44IDM2MC41Yy00LjgtLjYtNS4zLTEzLjMgNC41LTI2'
    b'LjgtMy42IDEzLjgtNS40IDI1LjQtNC41IDI2Ljh6bTM1LjItNjguM2MtMS03LjggNC0yMC4x'
    b'IDYuNi0yMi41IDIuNiAxNC40LTIuNyAyNC02LjYgMjIuNXptLTI3LjkgNjIuNWMtMy42LS41'
    b'LTMuOS0xMCAzLjYtMjBhNjcuNCA2Ny40IDAgMCAwLTMuNiAyMHptMjMuNC0xMDQuMmMtMi4y'
    b'LTYgMC0yMCAxLjItMjEuOCA1LjMgMTIuMiAyLjYgMjIuMS0xLjIgMjEuOHptLTU4LjEgMTIw'
    b'LjFjMi41LTggMTYuMi0yMSAxOC44LTIyLTQuMyAxNy41LTE1IDI1LjYtMTguOCAyMnpNNTU5'
    b'IDMyOWE0NSA0NSAwIDAgMSAxNi45LTE1LjhjLTUgMTMuNi0xNC4yIDE5LjEtMTcgMTUuOHpt'
    b'LS4yLTNjLTQuMy0uNC01LjMtMTEgMy0yMi45YTcyLjcgNzIuNyAwIDAgMC0zIDIyLjl6Ii8+'
    b'CiAgICAgICAgPHBhdGggZmlsbD0iIzQwNjMyNSIgZD0iTTU2NyAyOTRjNS4yIDEuOSA5LTku'
    b'OCA2LjYtMjMuOWE5OCA5OCAwIDAgMS02LjYgMjR6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0i'
    b'IzQwNjMyNSIgZD0iTTU2Ny44IDI5My42Yy41LTcuNS03LTIzLTktMjQuNy0yIDE1LjggNC41'
    b'IDI2LjMgOSAyNC43em0tNS4zLTQzLjJjMy45LjQgNi41LTkuNCAxLjItMjEuNy40IDExLjUt'
    b'LjIgMjAuOC0xLjIgMjEuN3ptLTU4IDEyMC4xYzMuOCAzLjcgMTQuNC00LjQgMTguNy0yMS44'
    b'LTguOCAxMi4zLTE3IDIxLjYtMTguNyAyMS44em01NC42LTQxLjVjMi44IDMuMyAxMi0yLjEg'
    b'MTctMTUuOGE3Ny4zIDc3LjMgMCAwIDEtMTcgMTUuOHoiLz4KICAgICAgICA8cGF0aCBmaWxs'
    b'PSIjNjc5MjNkIiBkPSJNNTY3LjcgMjkzLjVjLTQuNSAxLjctMTAuOS04LjctOC45LTI0LjUg'
    b'My41IDEzLjIgNy41IDIzLjcgOC45IDI0LjV6Ii8+CiAgICAgIDwvZz4KICAgICAgPGcgZmls'
    b'bD0iI2JhMWYzZSIgc3Ryb2tlPSIjNTExMTI0IiBzdHJva2Utd2lkdGg9Ii4yIj4KICAgICAg'
    b'ICA8Y2lyY2xlIGN4PSI1NjQuNiIgY3k9IjI1NC45IiByPSIxLjEiLz4KICAgICAgICA8Y2ly'
    b'Y2xlIGN4PSI1NjguNCIgY3k9IjI2Ni44IiByPSIxLjEiLz4KICAgICAgICA8Y2lyY2xlIGN4'
    b'PSI1NjkuOCIgY3k9IjMwNC4zIiByPSIxLjMiLz4KICAgICAgICA8Y2lyY2xlIGN4PSI1NjQu'
    b'NiIgY3k9IjI5Ny4zIiByPSIxLjMiLz4KICAgICAgICA8Y2lyY2xlIGN4PSI1NDkuOSIgY3k9'
    b'IjMzNy4yIiByPSIxLjMiLz4KICAgICAgICA8Y2lyY2xlIGN4PSI1NTYuMiIgY3k9IjMzOS45'
    b'IiByPSIxLjMiLz4KICAgICAgICA8Y2lyY2xlIGN4PSI1MTMuOCIgY3k9IjM3Mi4zIiByPSIx'
    b'LjMiLz4KICAgICAgICA8Y2lyY2xlIGN4PSI1MDYuOCIgY3k9IjM3Ny4zIiByPSIxLjMiLz4K'
    b'ICAgICAgICA8Y2lyY2xlIGN4PSI1NTcuMSIgY3k9IjI0OS4zIiByPSIxLjEiLz4KICAgICAg'
    b'PC9nPgogICAgPC9nPgogICAgPGcgaWQ9Imd0LWIiIGZpbGw9IiM4Yzk1OWQiIHN0cm9rZT0i'
    b'IzQ4NTY1NCIgc3Ryb2tlLXdpZHRoPSIuMSI+CiAgICAgIDxwYXRoIGQ9Ik00MzQuMyAzMzYu'
    b'M2MtLjIgMSAuOCAyLjMgMiAyIC41IDAgLjctLjUuMi0uNS0uNC4yLS45IDAtMS4yLS4zYTIg'
    b'MiAwIDAgMS0uNC0ybC0uNi44eiIvPgogICAgICA8cGF0aCBzdHJva2U9Im5vbmUiIGQ9Ik00'
    b'MzcuMiAzMzguM2MtMSAxLjItMi41IDEuNy0zLjQuOS0uNi0uNi0uOC0xLjItLjUtMmwtMSAx'
    b'LjNzLjYgMS4zIDEuNiAxLjhjMS4zLjUgMy0uMyA0LTEuNi44LTEgMS42LTIuNCAxLTMuNmE0'
    b'IDQgMCAwIDAtMi0xLjdsLTEgMWMuNS0uMiAxLjIgMCAxLjcuNCAxLjMgMSAuNiAyLjUtLjQg'
    b'My41eiIvPgogICAgICA8cGF0aCBmaWxsPSIjNDg1NjU0IiBzdHJva2U9Im5vbmUiIGQ9Ik00'
    b'MzcuMiAzMzguM2E0IDQgMCAwIDEtMS4xIDFjLS41LjItMSAuNC0xLjUuM2ExIDEgMCAwIDEt'
    b'LjctLjMgMSAxIDAgMCAxLS41LS42Yy0uMi0uMi0uMi0uNC0uMy0uNyAwLS4zIDAtLjUuMi0u'
    b'OGwuMS4xLTEuMSAxLjN2LS4xbDEgMS4zLjcuNC44LjFhMyAzIDAgMCAwIDEuNi0uNWMuNS0u'
    b'MiAxLS42IDEuMy0xbDEtMS40Yy4yLS41LjQtMSAuMy0xLjYgMC0uMyAwLS41LS4yLS44YTQu'
    b'MiA0LjIgMCAwIDAtMS45LTEuNmguMWwtMSAxLjFoLS4xYy4yLS4yLjUtLjIuNy0uMmwuOC4y'
    b'Yy40LjMuOC43LjkgMS4yLjEuNSAwIDEtLjIgMS40LS4yLjUtLjUuOS0uOSAxLjJ6bTAgMGMu'
    b'NC0uMy42LS43LjgtMS4yLjItLjQuMy0xIC4yLTEuNC0uMS0uNS0uNS0uOC0uOS0xLS40LS4z'
    b'LTEtLjQtMS4zLS4yaC0uMWwxLTEuMmE0LjIgNC4yIDAgMCAxIDIgMS43Yy4yLjIuMy41LjMu'
    b'OCAwIC42LS4xIDEuMi0uNCAxLjctLjIuNS0uNSAxLTEgMS40LS4zLjUtLjguOC0xLjMgMS4x'
    b'LS41LjMtMSAuNS0xLjcuNWEyLjIgMi4yIDAgMCAxLTEuNi0uNiA1IDUgMCAwIDEtMS0xLjRs'
    b'MS0xLjNoLjJsLS4xLjhjMCAuMiAwIC41LjIuN2wuNS41Yy4xLjIuNC4zLjYuMy41LjEgMSAw'
    b'IDEuNS0uMmwxLjEtMXoiLz4KICAgICAgPHBhdGggZmlsbD0iIzZjMzAxZSIgc3Ryb2tlPSIj'
    b'MzUxNzEwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJt'
    b'NTE1LjIgMjQ5LjMtNDAuMSAzOS41TDQzNCAzMjhsLTQuNiA1LjRjLTIgMi4zLTQuNCA1LjMt'
    b'Ny4yIDgtLjUuNy0xLjEuNC0xLjcuOC0xLjggMS0zLjcgMi44LTUgNC4zTDQwMy4yIDM2MGMt'
    b'LjcuOS0xIDEuNC0uNCAybDYuNiA4LjhjMS4yIDEuMiAyLjYgMS44IDMuMi44IDMuMS01LjUg'
    b'MTEtMTMuOCAxNC0yMC4zIDEuNy00IDMuOS0xMS4xIDUuNS0xMi44IDItMi4yIDcuMS03Ljgg'
    b'MTEuOC0xMi43bDEtMWMuMi0uNC41LS43LjktMSAyMy41LTI0IDUwLjctNTMuMSA3MC41LTcz'
    b'LjZsLTEtMXoiLz4KICAgICAgPHBhdGggZD0iTTQzMS45IDMyOC4xYy0xLjIgMC0yLS43LTIu'
    b'OS0xLjQgMS4yLjQgMi40LjggMy41LjNsLS42IDEuMXoiLz4KICAgICAgPHBhdGggZmlsbD0i'
    b'I2IyYjZiYSIgc3Ryb2tlLXdpZHRoPSIuMiIgZD0ibTU1NyAyMjAuMS0zMS44IDI2LjJjLS4z'
    b'LjQtLjYuMy0uOSAwbC0yLjktMi40di0uNmwxLjQtMS40Yy4yLS4yIDAtLjMtLjEtLjZsLS42'
    b'LS42Yy0uMy0uMS0uNSAwLS43LjJsLTEuNCAxLjVjLS43IDAtMS4zLjYtMS40IDEuNC0xOS4y'
    b'IDE4LjctMzUuOCAzNS40LTU0LjkgNTMuOGwtMjIuNiAyMS42Yy0uOCAxLTQuMyAyLjktNi42'
    b'IDQuNC0uOC41LTEuNSAxLTEuOCAxLjVsLTEuOCA1LjVjLS42IDEuMi0yLjUgNC0yLjUgNC4y'
    b'bDMuOCAzLjcgMTEuMS0xMS45LjktMWExMy4zIDEzLjMgMCAwIDAtMi42LTIuN2wtLjctLjVj'
    b'LS4xLS4yLjMtLjUuNS0uNyAyNi40LTI1LjYgNTUtNTMuNyA3OC4yLTc2LjZhMS40IDEuNCAw'
    b'IDAgMCAxIDBsMi45IDMuMWMuNi43IDEuMi43IDEuNy40bDMxLjktMjguNXoiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iIzQ4NTY1NCIgc3Ryb2tlPSJub25lIiBkPSJNNDMxIDMzMC40aC42bC41'
    b'LS4xLjctMi40LjgtMi40Yy0uMi0uMi0uNC0uNC0uNy0uNC4zIDAgLjUuMi43LjRsLS43IDIu'
    b'NC0uNyAyLjQtLjYuMi0uNy0uMXoiLz4KICAgICAgPGNpcmNsZSBjeD0iNDM4LjIiIGN5PSIz'
    b'MjguMSIgcj0iLjYiIGZpbGw9Im5vbmUiIHN0cm9rZS13aWR0aD0iLjIiLz4KICAgICAgPGNp'
    b'cmNsZSBjeD0iNDM0LjQiIGN5PSIzMzEuOSIgcj0iLjYiIGZpbGw9Im5vbmUiIHN0cm9rZS13'
    b'aWR0aD0iLjIiLz4KICAgICAgPHBhdGggZmlsbD0iIzQ4NTY1NCIgc3Ryb2tlPSJub25lIiBk'
    b'PSJNNDQxIDMyMi40YTExLjcgMTEuNyAwIDAgMS0xLjgtMS42IDExLjYgMTEuNiAwIDAgMSAx'
    b'LjggMS42eiIvPgogICAgICA8cGF0aCBkPSJtNTAyLjIgMjU5IDMuNSAzLjUuNi0uNi0zLjUt'
    b'My40LS42LjZ6Ii8+CiAgICA8L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNndC1iIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InNjYWxlKC0xIDEpIHJvdGF0ZSgt'
    b'Mi44IC05LjMgMTk2NDAuMikiLz4KICAgIDxnIHN0cm9rZT0iIzI0NDIwZSIgc3Ryb2tlLXdp'
    b'ZHRoPSIuMiI+CiAgICAgIDxwYXRoIGZpbGw9IiM2NzkyM2QiIGQ9Ik00MzQgMzY1LjRhNTUu'
    b'OCA1NS44IDAgMCAwLTI5LjMuOWMxNi4zIDggMjkuNSA0LjYgMjkuMi0xem04OSAzLjNjNy44'
    b'LTMuMyAyNi44LS43IDI5LjEgMS0xNi4yIDcuOS0yOS41IDQuNS0yOS4yLTF6Ii8+CiAgICAg'
    b'IDxwYXRoIGZpbGw9IiM0MDYzMjUiIGQ9Ik00MzMuOCAzNjUuNWMuMyA1LjUtMTIuOCA4Ljkt'
    b'MjkuMS45IDE1LjMgMSAyNy44LjQgMjktMXptODkuMiAzLjNjLS4yIDUuNSAxMi45IDguOSAy'
    b'OS4yLjktMTUuMyAxLTI3LjguNC0yOS4xLTF6Ii8+CiAgICA8L2c+CiAgICA8ZyBpZD0iZ3Qt'
    b'YyI+CiAgICAgIDxwYXRoIGZpbGw9IiNiMmI2YmEiIHN0cm9rZT0iIzQ4NTY1NCIgc3Ryb2tl'
    b'LXdpZHRoPSIuMiIgZD0iTTUwOC41IDM2MGEyMzcuNSAyMzcuNSAwIDAgMC03Ni4xLTY4YzMu'
    b'NS0uMiAxMS40IDMuOSAxNC43IDYgMjMuOSAxNS40IDQ0LjMgMzUuOCA2NS42IDU5LjgtMS4y'
    b'IDEuMi0yIDItMy40IDNsLS44LS44eiIvPgogICAgICA8cGF0aCBmaWxsPSIjOGM5NTlkIiBk'
    b'PSJNNTEwLjYgMzU5LjggNTA5IDM2MWMtMjMtMjkuNi01NS01Ny45LTc2LjctNjkgMzAuMSAx'
    b'My44IDU1LjQgNDEuNyA3OCA2Ny42aC4xeiIvPgogICAgICA8cGF0aCBmaWxsPSIjNDg1NjU0'
    b'IiBkPSJNNTEwLjYgMzU5LjggNTA5IDM2MWEzMDMgMzAzIDAgMCAwLTM1LjItMzggMjg1IDI4'
    b'NSAwIDAgMC0zMC40LTI0LjNjLTMuNi0yLjQtNy4zLTQuNy0xMS4xLTYuN3YtLjJjOCAzLjcg'
    b'MTUuNCA4LjIgMjIuNSAxMy4zIDcgNSAxMy42IDEwLjcgMjAgMTYuNmEzNjAgMzYwIDAgMCAx'
    b'IDE4LjMgMTguNWM2IDYuNCAxMS42IDEzIDE3LjQgMTkuNXptMCAwYy01LjgtNi42LTExLjUt'
    b'MTMtMTcuNS0xOS40YTM1NSAzNTUgMCAwIDAtMTguMy0xOC41Yy02LjQtNS45LTEzLTExLjUt'
    b'MjAtMTYuNi03LTUtMTQuNS05LjYtMjIuNC0xMy4ydi0uMmExOTYuMiAxOTYuMiAwIDAgMSAy'
    b'MS43IDE0LjMgMjg0LjkgMjg0LjkgMCAwIDEgMzguMiAzNS4xIDMxNCAzMTQgMCAwIDEgMTYu'
    b'OCAxOS44bDEuNS0xLjN6Ii8+CiAgICAgIDxnIGZpbGw9IiNmYWI4MWMiIHN0cm9rZT0iIzZj'
    b'MzAxZSIgc3Ryb2tlLXdpZHRoPSIuMSI+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIu'
    b'MiIgZD0iTTUxNy41IDM1NWMtMiAuNi0zLjcgMS4zLTUuMyAyLjMtLjIgMS40LTIgMy0zLjUg'
    b'My4zbC0uNi0uOGgtLjJsLS42LjNjLS42IDAtMS4zLjItMS42IDEtLjQgMSAuMyAyLjMgMS4y'
    b'IDMuMSAxIC43IDEuNCAxIDIuNCAxIDEuMS0uMyAxLjctMS4zIDItMS42IDMuNyA0LjUgNi41'
    b'IDcgMTEuMiAxMC42IDIuMSAwIDMuMi0xLjMgMi41LTIuOC0uMi0uNS0uOC0uOC0xLjMtLjZ2'
    b'LS41YzIuNC0yLjIgMy41LTUgLjktOS44LTIuMi00LTQuNy01LjQtNy01LjRoLS4xem02LjIg'
    b'NC42Yy41LjcuNyAxLjQgMSAyIDEuNiAzIC4zIDYuNy0yLjMgNy44aC0uMmMuNC0uNy0uOC0y'
    b'LjItMS40LTEuNy4zLS43LS43LTItMS41LTEuNy40LS43LS41LTEuOS0xLjQtMS41LjQtLjct'
    b'LjMtMS44LTEuMy0xLjYuMy0uOC0uNC0xLjgtMS4zLTEuNiAwLS44LS4yLTEuMi0uNS0xLjUg'
    b'MS0uOCAyLjMtMi4xIDMuNC0yLjcgMi43LTEuMiA0LjQgMSA1LjUgMi41eiIvPgogICAgICAg'
    b'IDxwYXRoIGQ9Ik01MjQuOSAzNjIuOGMtLjUtLjMtLjgtLjgtLjYtMS4xLjItLjQuNy0uNSAx'
    b'LjItLjIuNS4yLjguNy43IDEtLjIuNC0uOC41LTEuMy4zeiIvPgogICAgICAgIDxwYXRoIGQ9'
    b'Ik01MjQuNiAzNjEuOGMtLjUtLjMtLjgtLjgtLjYtMS4yLjItLjMuNy0uNCAxLjItLjEuNS4y'
    b'LjguNy43IDEtLjIuNC0uOC41LTEuMy4zeiIvPgogICAgICAgIDxwYXRoIGQ9Ik01MjQgMzYw'
    b'LjZjLS41LS4yLS44LS43LS42LTEgLjItLjQuNy0uNSAxLjItLjMuNS4zLjguOC42IDEuMS0u'
    b'MS40LS43LjUtMS4yLjJ6Ii8+CiAgICAgICAgPHBhdGggZD0iTTUyMy4yIDM1OS42Yy0uNS0u'
    b'My0uOC0uOC0uNi0xLjEuMi0uMy43LS40IDEuMi0uMi41LjMuOC44LjcgMS4xLS4yLjMtLjgu'
    b'NS0xLjMuMnoiLz4KICAgICAgICA8cGF0aCBkPSJNNTIyLjIgMzU4LjZjLS42LS4yLS44LS44'
    b'LS42LTF2LS4yYy4yLjEuNy4yLjYtLjEgMC0uMi0uMS0uMyAwLS4ybC42LjJjLjUuMy44Ljgu'
    b'NiAxLjEtLjEuNC0uNy41LTEuMi4yeiIvPgogICAgICA8L2c+CiAgICAgIDxwYXRoIGZpbGw9'
    b'IiNmYWI4MWMiIGQ9Ik01MTEuMyAzNjMuNmMuNy0xLjggMi0zLjQgMy41LTMuOG0tMy4zIDQu'
    b'MWMxLjMuMiAzLjMtMS4zIDMuOC0yLjZtLTIuNiA0YzEuNi40IDMuMy0xLjIgNC0yLjRtLTIu'
    b'NSA0YzIgMCAzLjEtMS4zIDMuNy0yLjRtLTIuMiAzLjljMS43IDAgMy4yLTEuMyAzLjYtMi40'
    b'bS0yLjIgMy44YzEuOSAwIDMuMS0uOSAzLjctMm0tMiAzLjRjMS43LjEgMy0uOSAzLjQtMS44'
    b'bS0xLjYgMy4zYzEuNiAwIDIuNy0xIDMuMS0yIi8+CiAgICAgIDxwYXRoIGZpbGw9IiM2YzMw'
    b'MWUiIGQ9Ik01MTEuMyAzNjMuNmE3IDcgMCAwIDEgMi4zLTMuMmMuMy0uMy43LS41IDEuMi0u'
    b'NmE0IDQgMCAwIDAtMS4yLjYgNiA2IDAgMCAwLTEgMSA4IDggMCAwIDAtMS4zIDIuMnptLjIu'
    b'M2MuNCAwIC44IDAgMS4yLS4ybDEtLjYgMS0uOC42LTFhMiAyIDAgMCAxLS42IDEgNS4zIDUu'
    b'MyAwIDAgMS0yIDEuNGMtLjQuMi0uOC4zLTEuMi4yem0xLjIgMS40aDEuMmwxLS42YTUuNiA1'
    b'LjYgMCAwIDAgMS43LTEuOGwtLjcgMS0uOS45LTEgLjVoLTEuM3ptMS41IDEuNmMuNCAwIC44'
    b'IDAgMS4xLS4ybDEtLjUgMS0uOC42LTFhNCA0IDAgMCAxLTEuNSAxLjlsLTEgLjVoLTEuMnpt'
    b'MS41IDEuNWMuOCAwIDEuNS0uMyAyLjEtLjhhNS4yIDUuMiAwIDAgMCAxLjUtMS42Yy0uMS4z'
    b'LS4zLjctLjYgMWwtLjguNy0xIC42YTMgMyAwIDAgMS0xLjIuMXptMS40IDEuNGMuNCAwIC44'
    b'IDAgMS4xLS4yYTQuNiA0LjYgMCAwIDAgMi0xbC42LS45LS42IDFjLS4zLjItLjYuNS0xIC42'
    b'LS42LjQtMS4zLjUtMiAuNXptMS43IDEuNGE0LjUgNC41IDAgMCAwIDItLjVsLjgtLjVjLjIt'
    b'LjMuNS0uNS42LS44IDAgLjMtLjMuNi0uNS44YTMuNiAzLjYgMCAwIDEtMyAxem0xLjggMS41'
    b'IDEtLjEuOC0uNC43LS42LjYtLjhhMyAzIDAgMCAxLTMuMSAxLjl6Ii8+CiAgICA8L2c+CiAg'
    b'ICA8dXNlIHhsaW5rOmhyZWY9IiNndC1jIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0'
    b'cmFuc2Zvcm09InNjYWxlKC0xIDEpIHJvdGF0ZSgtMy40IC0xMy44IDE2NDcwLjgpIi8+CiAg'
    b'ICA8ZyBzdHJva2U9IiMyNDQyMGUiIHN0cm9rZS13aWR0aD0iLjIiPgogICAgICA8cGF0aCBm'
    b'aWxsPSIjNDA2MzI1IiBkPSJNNDA5LjIgMjQwYTUyLjQgNTIuNCAwIDAgMCAxOS41LTE3Ljlj'
    b'LTE1LjYgNC4yLTIyLjcgMTQuMy0xOS41IDE4em0xNDUuOCA0LjdhNTAgNTAgMCAwIDAtMTUu'
    b'Ni0xOS45YzIuOCAxNS4yIDEyIDIyLjggMTUuNiAyMHoiLz4KICAgICAgPHBhdGggZmlsbD0i'
    b'IzY3OTIzZCIgZD0iTTQwOS4yIDI0MGMtMy4zLTMuNiAzLjgtMTMuNiAxOS40LTE3LjgtMTEg'
    b'OC40LTE5LjIgMTYuMi0xOS40IDE3Ljh6bTE0NS44IDQuN2MtMy43IDMtMTIuNy00LjYtMTUu'
    b'NS0xOS43IDcuMiAxMSAxNCAxOS41IDE1LjUgMTkuN3oiLz4KICAgIDwvZz4KICAgIDxnIHN0'
    b'cm9rZT0iIzk5OTI3MCIgc3Ryb2tlLXdpZHRoPSIuMiI+CiAgICAgIDxwYXRoIGZpbGw9InVy'
    b'bCgjZ3QtZCkiIGQ9Ik00NTIuMiAzMTguMXMtNi4xLjctNy45LTcuOGMtMS44LTkuMSA1LjMt'
    b'MTAgNS4zLTEwczguMS0uOSAxMy4yLTFsMi4yIDE4LTEyLjguOHoiLz4KICAgICAgPHBhdGgg'
    b'ZmlsbD0idXJsKCNndC1lKSIgZD0iTTQ1MyAzMTUuNHMtNCAuNy00LjgtNS42Yy0uNi00LjUg'
    b'Mi4yLTUuMSAyLjItNS4xbDkuMiAxLjZ2OC4ybC02LjYuOXoiLz4KICAgICAgPHBhdGggZmls'
    b'bD0idXJsKCNndC1mKSIgZD0iTTQ1MC40IDMwNC43czYtLjQgOS0uOGwxLjMgNS43LTcuMS40'
    b'cy0uNS01LjEtMy4yLTUuM3oiLz4KICAgICAgPHBhdGggZmlsbD0idXJsKCNndC1nKSIgZD0i'
    b'TTQ0OS4yIDMwMC40czcuNS0xLjkgOC41IDYuNGMuMiAyLjItMSA3LjItNC43IDguNmwxMy45'
    b'LTEuNS0xLjMtMTUtNC42LjRzLTEwIC4zLTExLjggMXoiLz4KICAgICAgPHBhdGggZmlsbD0i'
    b'I2Y5ZjBhYSIgZD0iTTQ1Mi4yIDMxOC4xczUxLjktMy41IDU3LjItMy4zYzE1LjgtOC42IDAt'
    b'NDIuNS0xMy4zLTYxLjUgMS41LTQuMy0yOS45LTEzLjktNDQtMTMtMS45IDAtMy42LjItNS4y'
    b'LjMtNy43LjgtNy44IDEwLjctNC43IDE3IDMgNiAzMC40IDU1IDExLjIgNjAuM2wtMS4yLjJ6'
    b'Ii8+CiAgICAgIDxwYXRoIGZpbGw9InVybCgjZ3QtaCkiIGQ9Ik01MDcuOCAyNzMuM2MtMy41'
    b'LTcuMy03LjctMTQuMy0xMS43LTIwIDEuNS00LjMtMjkuOS0xMy45LTQ0LTEzLTEuOSAwLTMu'
    b'Ni4yLTUuMi4zLTcuNy44LTcuOCAxMC43LTQuNyAxNyAxIDEuOCA0LjMgOCA3LjkgMTUuNyIv'
    b'PgogICAgICA8cGF0aCBmaWxsPSJ1cmwoI2d0LWkpIiBkPSJNNDU1IDI4NWM1LjYgMTQuNiA4'
    b'LjcgMzAtMS42IDMyLjlsLTEuMi4yczUyLTMuNSA1Ny4yLTMuM2M4LjYtNC43IDcuOC0xNi44'
    b'IDMuMi0zMCIvPgogICAgICA8cGF0aCBmaWxsPSJ1cmwoI2d0LWopIiBkPSJNNDQ3LjQgMjQz'
    b'LjVjLTMuNyAwLTQuNyAzLjYtNC42IDUuOC4xIDYgNC42IDYuMiA0LjYgNi4ybDYtLjMgMi44'
    b'LTEyLjItOC44LjV6Ii8+CiAgICAgIDxwYXRoIGZpbGw9InVybCgjZ3QtaykiIGQ9Im00NDcu'
    b'NCAyNDMuNSA4LjgtLjUgMSA5LjEtNy44LjRzMi41LTcuMy0yLTl6Ii8+CiAgICAgIDxwYXRo'
    b'IGZpbGw9InVybCgjZ3QtbCkiIGQ9Ik00OTYuMSAyNTMuM2M2LjctMSA2LjYtMTAgMi0xMy43'
    b'LTE1LjUtLjYtMzUuOC0uMS01MC42IDEgMS43IDAgNi40LjQgNi45IDYuNWE4LjIgOC4yIDAg'
    b'MCAxLTMgNyA3IDcgMCAwIDEtNCAxLjRoMy42bDMtLjRjMjEtMi43IDQyLTEuOCA0Mi0xLjho'
    b'LjF6Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiNiMDdlMDkiIHN0cm9rZT0ibm9uZSIgZD0iTTQ1'
    b'OC41IDI2Ny40Yy0uMi0uMy0uNC0uNy0uOC0uOC0uMiAwLS42IDAtLjUtLjRoLjhsMS42LS4y'
    b'Yy40LjEuMy41IDAgLjUtLjUgMC0uMi41LS4xLjhsMS4zIDNjLjEuNC40LjcuNy43bDEuMS0u'
    b'MWMuMy0uMi4yLS42LjItMS0uMS0uMy41LS4yLjUgMGwuNCAxLjRjMCAuMi0uMi4xLS40LjFs'
    b'LTMgLjJjLS4zIDAtLjguMy0xIDAgMC0uNC42LS4yLjYtLjVsLS4zLTEtMS4xLTIuN3ptNC44'
    b'LS40Yy0uMS0uMi0uMy0uNi0uNy0uNy0uMiAwLS42IDAtLjYtLjQuMi0uMi41IDAgLjcgMGwx'
    b'LjctLjJjLjMgMCAuNC41IDAgLjQtLjMgMC0uMy40LS4yLjdsMS41IDMuNGMwIC4yLjIuNS41'
    b'LjYuMiAwIC42IDAgLjcuMyAwIC4zLS40LjEtLjYuMS0uNSAwLTEgMC0xLjYuMi0uMiAwLS41'
    b'IDAtLjUtLjNzLjUgMCAuNi0uNGMwLS4zLS4yLS42LS40LTFsLTEuMS0yLjZ6bTQuNS44YzAg'
    b'LjIuNCAwIC41IDAgLjMgMCAuNi0uMS42LS40IDAtLjUtLjMtMS0uNy0xLjItLjMtLjMtLjct'
    b'LjItMS4xLS4ybC4xLjUuNiAxLjN6bS42IDEuNmMuMi4zLjMuNy42IDEgLjIuMi42LjEuOCAw'
    b'IC4zIDAgLjUtLjMuNC0uNS0uMS0uNy0uNS0xLjMtMS4yLTEuNWgtMWwuMi41LjIuNXptLTIt'
    b'Mi40Yy0uMi0uMy0uMy0uOC0uNy0xLS4yIDAtLjYuMS0uNy0uMiAwLS4zLjYtLjEuOC0uMi45'
    b'IDAgMS44LS4zIDIuNiAwIC43LjIgMS40LjggMS41IDEuNiAwIC40LS4zLjctLjYuOGwuNS4x'
    b'Yy42LjIgMS4xLjYgMS40IDEuMi4yLjQuMy45IDAgMS4zLS40LjQtMSAuNC0xLjQuNC0uOCAw'
    b'LTEuNSAwLTIuMy4yLS4zIDAtLjQtLjUgMC0uNS4zIDAgLjMtLjQuMi0uNmwtMS4zLTN6bTcu'
    b'NC0xLjljLjMgMCAuNC4zLjUuNWwuMy45Yy0uMy4yLS41LS4yLS42LS40LS4yLS4yLS40LS41'
    b'LS43LS40aC0xLjJjLS4yLjIgMCAuNC4xLjZsLjYgMS40Yy4yIDAgLjYgMCAuOC0uMyAwLS4y'
    b'LS4zLS43LjItLjYuMy4yLjIuNi40LjlsLjUgMS4xYy0uMy4zLS41LS4xLS42LS40LS4yLS4z'
    b'LS43LS4zLTEtLjMtLjIgMCAwIC4yIDAgLjNsLjYgMS41Yy4yLjMuNy4zIDEgLjMuMyAwIC44'
    b'IDAgMS0uNC4yLS4yLS4zLS43IDAtLjguNCAwIC40LjQuNS42IDAgLjMuMi42LjMuOCAwIC4y'
    b'LS4zLjItLjQuMmwtMyAuMmMtLjQgMC0uOS4yLTEtLjIgMC0uMy43LS4xLjYtLjVsLS40LTEt'
    b'MS4xLTIuN2MtLjItLjMtLjQtLjctLjgtLjctLjIgMC0uNiAwLS40LS40aDFsMi44LS4yem0y'
    b'LjMgMS4zYy0uMS0uMy0uMy0uNy0uNy0uOS0uMiAwLS43IDAtLjctLjQuMy0uMi43IDAgMSAw'
    b'IC44IDAgMS42LS4zIDIuNCAwIC44LjEgMS41LjkgMS42IDEuOCAwIC40LS4zLjctLjcuOC0u'
    b'MyAwIC4yLjEuMy4yLjcuMyAxIC45IDEuNCAxLjUuMS4yLjUuNy42LjIgMC0uNS42IDAgLjUu'
    b'MyAwIC40LS40LjYtLjcuNi0uNCAwLS45LS4yLTEuMS0uNi0uNC0uNi0uNy0xLjMtMS4zLTEu'
    b'N2EuOC44IDAgMCAwLS44LS4ydi41bC42IDEuMmMuMi4zLjYuMyAxIC4zLjMuMS4yLjYtLjIu'
    b'NWgtMS43Yy0uMy4yLS45IDAtLjctLjMuMyAwIC43LS4yLjUtLjVsLTEtMi42LS4zLS43em0x'
    b'LjQgMWMuMi4yLjYgMCAuOSAwIC4zIDAgLjMtLjUuMi0uNy0uMS0uNS0uNC0xLS45LTEuMi0u'
    b'MiAwLS44LS4yLS45LjFsLjcgMS42di4xem03LjIgMS42Yy4xLjMuMy42LjYuNy4yIDAgLjYg'
    b'MCAuNy4zIDAgLjMtLjQuMS0uNi4yaC0xLjZjLS4zLjEtLjYgMC0uNi0uMy4yLS4yLjcgMCAu'
    b'Ny0uNGwtLjUtMS4xLTEuMS0yLjljLS4xLS4zLS41LS4zLS43LS4zLS4zIDAtLjcgMC0uNy40'
    b'IDAgLjMuMi42IDAgLjgtLjMgMC0uNC0uMy0uNS0uNSAwLS4zLS4yLS42LS40LTEgMC0uMi40'
    b'LS4xLjUtLjFsNC4yLS4yYy4zIDAgLjUuMi41LjVsLjQgMWMtLjEuMy0uNSAwLS42LS4zLS4x'
    b'LS4zLS41LS43LS45LS43LS4yIDAtLjYgMC0uOC4ybC4yLjcgMS4yIDN6bTMuOC0uOWMtLjIg'
    b'MC0uMS4zLS4xLjR2LjhjLjEuNC41LjMuOC40LjIgMCAuMS41LS4yLjRoLTEuMmMtLjMuMS0u'
    b'OC0uMS0uNS0uNC4yIDAgLjQtLjEuNS0uM3YtNWMuMi0uMy41IDAgLjYuMmwzLjYgNC41Yy4y'
    b'LjIuNS40LjguNC4zIDAgLjQuNSAwIC40aC0xLjVjLS4yIDAtLjUuMi0uNyAwLS4yLS4xIDAt'
    b'LjQuMi0uNC4zIDAgMC0uNC0uMS0uNmwtLjYtLjhoLTEuNnptMS4xLS41Yy4yIDAgMC0uMSAw'
    b'LS4ybC0xLjMtMS43djJoMS4zem0zLjEtMS44Yy0uMS0uNC0uMy0xLS44LTEtLjMgMC0uNy0u'
    b'Mi0uNS0uNGgxLjdjLjctLjEgMS40LS4xIDIgLjEgMS41LjUgMi43IDEuOCAzIDMuNCAwIC42'
    b'LS4xIDEuMy0uNiAxLjYtLjguNS0xLjcuNC0yLjUuM2wtMS40LjFjLS4zIDAtLjQtLjUgMC0u'
    b'NC40IDAgLjQtLjUuMi0uN2wtMS4xLTN6bTIgMi41Yy4xLjMuMi43LjUgMWgxYy41IDAgLjct'
    b'LjUuNy0uOWE1IDUgMCAwIDAtLjYtMi4xYy0uNC0uNy0xLTEuMi0xLjgtMS40YTMgMyAwIDAg'
    b'MC0xIDBjLS4xIDAgMCAuMiAwIC40bDEuMiAzem0tMjEuMSAxMi40YzAgLjMuNC42LjguNi4y'
    b'IDAgLjcgMCAuNy40LS4yLjItLjYgMC0uOCAwbC0xLjUuMmgtLjljLS4yIDAtLjItLjQuMS0u'
    b'NC4zIDAgLjYtLjEuNi0uNGwtLjItLjgtMS4yLTIuOGMwLS4zLS40LS4zLS43LS4zLS4yIDAt'
    b'LjYuMS0uNy0uMiAwLS4zLjUtLjIuNy0uNGwxLS4zYy4yIDAgLjMuMS4zLjNsMS44IDR6bS43'
    b'LTQuNWgyYy40IDAgLjItLjUuNC0uNS40IDAgLjQuNS40LjcgMCAuNC0uMy43LS42LjZINDc1'
    b'bC41IDEuMi42LS4yYzEgMCAyLjIuNiAyLjYgMS42LjIuNS4zIDEgMCAxLjUtLjQuNS0xIC42'
    b'LTEuNi42LS41IDAtMS0uMS0xLjQtLjYtLjEtLjItLjEtLjcuMi0uNi40IDAgLjcuMi43LjYu'
    b'MS4yLjUuMS43LjEuMyAwIC42LS4yLjYtLjUgMC0uNS0uMi0xLS41LTEuNC0uMi0uNC0uNy0u'
    b'Ny0xLjMtLjdsLS44LjFjLS4zIDAtLjMtLjMtLjQtLjVsLS43LTEuOS4yLS4xem02LjkgMWMt'
    b'LjItLjQtLjQtLjktLjktMS0uMiAwLS43LS4xLS40LS40aDEuNmMuNy0uMiAxLjUtLjEgMi4x'
    b'LjEgMS41LjUgMi43IDEuOCAzIDMuNCAwIC42LS4xIDEuMi0uNyAxLjYtLjcuNC0xLjYuMy0y'
    b'LjQuM2wtMS4zLjJjLS4zIDAtLjQtLjUgMC0uNS4zIDAgLjMtLjQuMi0uN2wtMS4yLTN6bTIg'
    b'Mi41Yy4xLjMuMy43LjYgMWgxYy40LS4xLjYtLjYuNi0xIDAtLjctLjMtMS40LS43LTIuMS0u'
    b'NC0uNy0xLTEuMi0xLjgtMS4zYTMgMyAwIDAgMC0xIDB2LjRsMS4zIDN6bTYuNC00LjNjLjMg'
    b'MCAuNC4zLjUuNSAwIC4zLjIuNS4zLjgtLjIuMy0uNSAwLS42LS4zLS4xLS4yLS4zLS41LS42'
    b'LS41aC0xLjNjLS4yLjIgMCAuNSAwIC42bC42IDEuNGMuMyAwIC42IDAgLjgtLjIuMi0uMi0u'
    b'My0uNy4yLS42LjMgMCAuMy41LjQuOGwuNSAxLjFjLS4xLjQtLjUgMC0uNi0uMy0uMS0uMy0u'
    b'NS0uMy0uOC0uMy0uMiAwLS40IDAtLjIuMmwuNiAxLjVjLjIuNC43LjMgMSAuMy40IDAgLjgg'
    b'MCAxLS4zLjItLjItLjItLjYgMC0uOC40IDAgLjUuMy41LjVsLjMgMWMwIC4xLS4zIDAtLjQg'
    b'MGwtMy4xLjJjLS4zIDAtLjcuMi0uOS0uMS0uMi0uNC41LS4yLjYtLjVsLS4zLS45LTEuMS0y'
    b'LjljLS4yLS4zLS40LS42LS44LS43LS4yIDAtLjYgMC0uNC0uNGgxbDIuOC0uMXptLTI3LjIg'
    b'MTQuM2MuMS41LjYuNyAxIC44LjguMiAxLjcuNSAyLjIgMS4xLjMuNC41LjkuNSAxLjQgMCAu'
    b'NS0uNS45LTEgMS0uNS4yLTEuMS4xLTEuNy0uMS0uMi0uMS0uMS40LS41LjMtLjItLjItLjEt'
    b'LjYtLjItLjlhOSA5IDAgMCAwLS40LTFjMC0uMy40IDAgLjUuMi4zLjYuOSAxIDEuNiAxLjEu'
    b'NCAwIC44LS4yLjgtLjYgMC0uNS0uNC0xLS44LTEuMi0uNy0uMy0xLjQtLjQtMi0uOGEyIDIg'
    b'MCAwIDEtMS0xLjZjMC0uNC40LS44LjgtLjkuNS0uMiAxLS4yIDEuNiAwIC4yIDAgLjMtLjMu'
    b'Ni0uMSAwIC4yIDAgLjQuMi42bC4zLjljLS4yLjItLjUgMC0uNS0uMi0uMy0uNC0uNS0uOC0x'
    b'LS44LS40IDAtLjggMC0xIC4zdi41em02LjYtMS43Yy40IDAgLjQuMy41LjVsLjIuOGMwIC4z'
    b'LS40IDAtLjUtLjItLjEtLjItLjMtLjUtLjctLjVoLTEuMmMtLjIuMiAwIC41IDAgLjZsLjUg'
    b'MS40Yy4zIDAgLjYgMCAuOC0uMi4yLS4yLS4yLS42LjEtLjcuNCAwIC40LjUuNS43IDAgLjQu'
    b'My44LjQgMS4zLS4xLjMtLjUgMC0uNS0uMy0uMS0uMy0uNS0uNC0uOC0uMy0uMiAwLS40IDAt'
    b'LjMuMmwuNiAxLjVjLjEuMy40LjMuNy4zLjQgMCAuOSAwIDEuMi0uMy4yLS4yIDAtLjYgMC0u'
    b'OC4zLS4yLjYgMCAuNi4zbC4yIDFjMCAuMi0uMy4yLS40LjJsLTMgLjJjLS40IDAtLjguMy0x'
    b'IDAgMC0uNC41LS4zLjYtLjYgMC0uMiAwLS41LS4yLS44bC0xLTNjMC0uMy0uMy0uNi0uNy0u'
    b'Ni0uMiAwLS42LS4xLS40LS40aDFsMi44LS4zem00LjIgNC4yYy4xLjMuMy42LjYuNy4zIDAg'
    b'LjctLjEuOC4yIDAgLjQtLjUuMi0uNy4yLS42IDAtMSAwLTEuNi4yLS4yIDAtLjUgMC0uNi0u'
    b'MiAwLS40LjUtLjIuNi0uNGwtLjEtLjgtMS0zYy0uMi0uMy0uMy0uNy0uNy0uNy0uMiAwLS42'
    b'IDAtLjUtLjQuMS0uMi40IDAgLjcgMCAuNyAwIDEuNC0uMyAyLjItLjJhMiAyIDAgMCAxIDEu'
    b'NyAxLjJjLjIuNC4yIDEgMCAxLjMtLjUuNC0xLjEuNS0xLjcuNi0uMiAwIDAgLjIgMCAuM2wu'
    b'MyAxem0tLjYtMS44aC43Yy4zLS4xLjUtLjQuNC0uNyAwLS41LS4yLS45LS41LTEuMi0uMy0u'
    b'My0uOC0uMy0xLjEtLjItLjIuMSAwIC4zIDAgLjVsLjUgMS42em02LjIgMS41YzAgLjIuMi42'
    b'LjUuNi4yIDAgLjcgMCAuNy4zcy0uNS4yLS43LjJsLTEuNi4xYy0uMiAwLS41IDAtLjUtLjMu'
    b'Mi0uMi43IDAgLjctLjRsLS4zLTEuMi0xLTIuOWMwLS4zLS40LS4yLS43LS4yLS4yIDAtLjYg'
    b'MC0uNy4zdi44Yy0uMi4yLS41IDAtLjQtLjNsLS40LTFjMC0uMy4zLS4yLjUtLjNsNC4xLS4y'
    b'Yy4zIDAgLjUuMi41LjVsLjQgMWMtLjEuMi0uNSAwLS41LS4yLS4yLS4zLS41LS43LTEtLjct'
    b'LjIgMC0uNS0uMS0uOCAwbC4yLjcgMSAzLjJ6bTIuMS0zLjNjLS4xLS4zLS4yLS43LS42LS44'
    b'LS4yIDAtLjYgMC0uNi0uNC4xLS4yLjQgMCAuNiAwbDEuOC0uMmMuMy0uMS41LjQuMi40cy0u'
    b'Ni4yLS41LjVsLjUgMS42LjcgMi4yYzAgLjIuMy40LjUuNC4zIDAgLjcgMCAuNi40aC0uN2wt'
    b'MS42LjJjLS4yIDAtLjYtLjItLjQtLjQuMi0uMS42IDAgLjYtLjRsLS4zLTEuMi0uOC0yLjN6'
    b'bTUuOC0xLjZjLjMgMCAuMy4zLjQuNWwuMi44Yy0uMS4zLS41IDAtLjUtLjItLjEtLjMtLjMt'
    b'LjYtLjctLjZINDg1Yy0uMi4yIDAgLjUgMCAuN2wuNSAxLjNjLjIgMCAuNSAwIC44LS4yLjIt'
    b'LjEtLjItLjYuMS0uNi40IDAgLjQuNC41LjYgMCAuNS4zLjkuNCAxLjMtLjEuMy0uNSAwLS41'
    b'LS4yLS4xLS4zLS41LS40LS44LS40LS4xIDAtLjUgMC0uMy4ybC41IDEuNWMuMS4zLjUuNC43'
    b'LjQuNCAwIC45IDAgMS4yLS4zLjItLjIgMC0uNi4xLS45LjMtLjEuNS4xLjUuNGwuMiAxYzAg'
    b'LjItLjIuMi0uNC4ybC0zIC4xYy0uNCAwLS43LjItMSAwLS4xLS40LjUtLjMuNi0uNWExIDEg'
    b'MCAwIDAtLjEtLjhsLTEtM2MwLS4zLS4zLS43LS43LS43LS4yIDAtLjYtLjItLjQtLjRoMWwy'
    b'LjktLjJ6bTIgMWMtLjEtLjQtLjQtLjctLjgtLjctLjMuMS0uNS0uNiAwLS40aDEuNWwuNy45'
    b'IDIuMiAyLjljLS4yIDAgMC0uMi0uMS0uM2wuNC0zLjZjLjItLjIuNyAwIDEtLjIuMyAwIDEg'
    b'MCAuOC40LS40IDAtLjguMi0uNi42bDEuMiAzLjZjMCAuNC40LjYuOC41LjMgMCAuMy42IDAg'
    b'LjVINDk0Yy0uMy4xLS44LjEtLjctLjMuMyAwIC44LS4yLjYtLjZsLTEtMy4yYy4xLjEgMCAu'
    b'MyAwIC40bC0uMiAzLS4xLjhjLS4zLjEtLjQtLjEtLjUtLjNsLTIuOS0zLjcuMi4zYy4zIDEg'
    b'LjUgMiAuOSAyLjkgMCAuNC41LjUuOC41LjQuMi4xLjUtLjIuNGgtMS41Yy0uMyAwLS4zLS40'
    b'IDAtLjQuNSAwIC40LS41LjItLjhsLTEtMy4yem04LjcuOGMwIC4yLjQgMCAuNSAwIC4zIDAg'
    b'LjYgMCAuNy0uNCAwLS40LS4yLTEtLjUtMS4yLS40LS4zLS44LS4yLTEuMi0uMnYuNWwuNSAx'
    b'LjN6bS41IDEuNi40IDFjLjMuMi42LjEuOS4xLjIgMCAuNS0uMi40LS41IDAtLjYtLjMtMS4z'
    b'LS45LTEuNWgtMXYuM2wuMi42ek00OTYgMjg4Yy0uMS0uNC0uMi0uOC0uNi0xLS4yIDAtLjYg'
    b'MC0uNi0uM3MuNSAwIC43LS4xYzEgMCAxLjgtLjIgMi43IDAgLjcuMiAxLjMuOSAxLjMgMS42'
    b'IDAgLjQtLjQuNy0uNy45IDAtLjIuNCAwIC41IDAgLjUuMiAxIC42IDEuMiAxLjIuMi40LjMu'
    b'OSAwIDEuMy0uNC40LTEgLjQtMS41LjRsLTIuMy4xYy0uMyAwLS40LS41IDAtLjQuMyAwIC40'
    b'LS40LjItLjdsLS45LTN6bTUuMS0uMmMwLS4zLS4yLS44LS42LTEtLjIgMC0uNiAwLS42LS4z'
    b'LjItLjMuNiAwIDEtLjFoMmMuOCAwIDEuNS42IDEuNyAxLjQuMS40IDAgMS0uNCAxLjJsLS40'
    b'LjJjLjYuMiAxLjEuNyAxLjQgMS4ybC41LjhjLjIuMi4zLS4xLjMtLjMuNC0uMi42LjMuNC42'
    b'LS4xLjQtLjcuNS0xIC40YS45LjkgMCAwIDEtLjgtLjZsLTEtMS43Yy0uMy0uMS0uNi0uMy0u'
    b'OS0uMXYuNGwuNSAxLjJjLjEuMy41LjQuOC40LjQgMCAuNC41IDAgLjRoLTEuOGMtLjIgMC0u'
    b'Ni4yLS43IDAtLjItLjUuNC0uMy42LS41bC0uMi0uOS0uOC0yLjd6bTEuMyAxYy4xLjMuNiAw'
    b'IC44IDAgLjMgMCAuNS0uMy40LS41IDAtLjUtLjItMS0uNS0xLjMtLjMtLjItLjctLjItMS0u'
    b'MS0uMiAwLS4xLjMgMCAuNWwuMyAxLjN6bTYuOS0yLjZjLjMgMCAuMy4zLjQuNSAwIC4zLjIu'
    b'Ni4zLjgtLjIuMy0uNSAwLS42LS4yIDAtLjItLjItLjYtLjYtLjZoLTEuM2MtLjIuMSAwIC40'
    b'IDAgLjZsLjQgMS40Yy4zIDAgLjYgMCAuOC0uMi4zLS4xLS4xLS41LjItLjcuNCAwIC40LjQu'
    b'NC43IDAgLjUuMy45LjQgMS4zLS4xLjMtLjUgMC0uNS0uMiAwLS4zLS40LS41LS43LS40LS4x'
    b'IDAtLjUtLjItLjQgMGwuNSAxLjdjLjEuMy40LjMuNy4zLjQgMCAuOSAwIDEuMi0uMi4yLS4y'
    b'IDAtLjYuMS0uOC4zLS4yLjYgMCAuNS4zbC4yIDFjMCAuMi0uMy4yLS40LjJoLTMuMWMtLjMg'
    b'MC0uNi4yLS44IDAtLjMtLjQuMi0uMy40LS41czAtLjUgMC0uN2wtLjktMy4xYzAtLjMtLjMt'
    b'LjctLjYtLjdzLS42LS4xLS41LS40aDFsMy0uMXptLTMyLjggMTMuMWMwLS4zLS4yLS44LS42'
    b'LTEtLjMgMC0uNyAwLS41LS4zbDEtLjFjLjggMCAxLjYtLjIgMi40IDAgMS4yLjIgMi4zIDEu'
    b'MiAyLjYgMi4zLjIuOC4zIDEuNi0uMiAyLjMtLjUuNi0xLjQuOC0yLjIuOC0uNyAwLTEuMyAw'
    b'LTEuOS4yLS4yLjEtLjYtLjEtLjQtLjQuMyAwIC43LS4xLjYtLjVsLS40LTEuNS0uNC0xLjh6'
    b'bTEuNiAyLjVjLjEuMy4yLjcuNC45LjMuMi43LjEgMSAwIC40IDAgLjgtLjQuOS0uOWE0IDQg'
    b'MCAwIDAtLjQtMi4yIDIgMiAwIDAgMC0xLjUtMS4yIDMgMyAwIDAgMC0xLjEgMGMtLjEgMCAw'
    b'IC4yIDAgLjRsLjcgM3ptNy4xLTQuNWMuMyAwIC4zLjMuNC41bC4yLjljLS4yLjItLjUgMC0u'
    b'NS0uMi0uMS0uMy0uMy0uNi0uNi0uNmgtMS4zYy0uMi4xIDAgLjQgMCAuNiAwIC41LjIgMSAu'
    b'MyAxLjQuMyAwIC42IDAgLjgtLjIuMi0uMi0uMS0uNi4yLS43LjQgMCAuMy41LjQuN2wuMyAx'
    b'LjNjMCAuMy0uNSAwLS41LS4yIDAtLjMtLjQtLjUtLjctLjQtLjEgMC0uNS0uMS0uMy4xIDAg'
    b'LjUuMiAxIC40IDEuNiAwIC4zLjQuMy43LjMuNCAwIC45IDAgMS4yLS4zLjItLjIgMC0uNi4y'
    b'LS44LjItLjIuNC4xLjQuNCAwIC4zIDAgLjYuMiAxLS4xLjItLjMuMS0uNS4xbC0zIC4yYy0u'
    b'MyAwLS42LjItLjkgMC0uMi0uMi4xLS40LjQtLjQuMy0uMS4yLS41LjEtLjdsLS43LTMuMmMt'
    b'LjEtLjMtLjMtLjctLjYtLjdzLS42LS4xLS41LS40aDFsMi45LS4zem02LjUgNC4xYzAgLjMu'
    b'My42LjYuNy4yIDAgLjYgMCAuNy4yLjEuMy0uNC4yLS42LjJsLTEuNy4xYy0uMyAwLS42LjEt'
    b'LjggMC0uMyAwLS4yLS40LjEtLjQuMyAwIC42LS4xLjctLjRsLS4xLS44LS43LTIuOGMwLS4z'
    b'LS4zLS4zLS42LS4zLS4yIDAtLjYuMi0uNy0uMSAwLS40LjUtLjMuNy0uNGwxLjEtLjRjLjIg'
    b'MCAuMy4xLjMuM2wxIDQuMXptMy43LTMuM2MwLS40LS4zLS44LS43LS44LS4zIDAtLjcgMC0u'
    b'OC4zLS4xLjQgMCAuOC40IDFsLjkuNS4yLS42di0uNHptLjggMi45YzAtLjUtLjYtLjgtMS0x'
    b'LS4yIDAtLjQtLjItLjUtLjFhMSAxIDAgMCAwLS40IDFjLjIuNi41IDEgMSAxIC40LjEuOCAw'
    b'IDEtLjR2LS41em0xLS4yYzAgLjUtLjIgMS0uNiAxLjMtLjUuNC0xLjMuNC0yIC4yLS42LS4x'
    b'LTEtLjYtMS4yLTEuMiAwLS41LjEtMSAuNS0xLjQuMSAwIC41LS4xLjItLjItLjUtLjItMS0u'
    b'Ni0xLTEuMi0uMi0uNSAwLTEgLjUtMS4zYTIgMiAwIDAgMSAyLjYuN2MuMi40LjIuOSAwIDEu'
    b'MmwtLjYuNWMuNSAwIDEgLjQgMS4yLjguMi4xLjMuNC4zLjZ6bTMuMi42Yy4yIDAgLjUtLjIu'
    b'NS0uNC4xLS4yIDAtLjcuMy0uNi4zIDAgLjIuMy4zLjYgMCAuNCAwIC44LS40IDEuMS0uMi4y'
    b'LS41LjEtLjguMWgtMS43Yy0uMiAwLS41LjItLjcgMC0uMi0uMiAwLS41IDAtLjcuMi0uNy42'
    b'LTEuMiAxLTEuNi40LS4zLjgtLjYuOC0xLjEgMC0uNCAwLS44LS4yLTEuMmExIDEgMCAwIDAt'
    b'MS40LS4zYy0uMy4xLS41LjUtLjMuNy4yLjIuNiAwIC43LjQuMi4yIDAgLjYtLjMuNi0uNCAw'
    b'LS44LS4zLTEtLjctLjEtLjUuMS0xLjEuNi0xLjQuNS0uMyAxLjEtLjMgMS43LS4yLjUuMiAx'
    b'IC42IDEuMiAxLjIuMS40LjEuOS0uMSAxLjMtLjQuNy0xLjIgMS0xLjcgMS43LS4xLjEtLjIu'
    b'My0uMS42IDAtLjMuNC0uMi41LS4yaDF6bTMuOS0uNGMwIC4yLjMuNS42LjYuMiAwIC42IDAg'
    b'LjcuMi4yLjMtLjMuMy0uNS4zaC0yLjdjLS4yLS4xIDAtLjUuMi0uNC4zIDAgLjYtLjEuNy0u'
    b'NHYtLjhsLS43LTIuOGMwLS4zLS4zLS4zLS41LS4zLS4zIDAtLjYuMi0uNyAwLS4yLS40LjMt'
    b'LjQuNS0uNWwxLjItLjRjLjMgMCAuMy4xLjQuM2wuOCA0LjF6Ii8+CiAgICA8L2c+CiAgICA8'
    b'ZyBmaWxsPSIjNDQ4MTI3IiBzdHJva2U9IiMzNDU0MWYiIHN0cm9rZS13aWR0aD0iLjIiPgog'
    b'ICAgICA8cGF0aCBmaWxsPSJ1cmwoI2d0LW0pIiBzdHJva2U9IiM0YzA1MDUiIGQ9Ik00NzUu'
    b'OCAyMTkuNCA0NzIgMjI0Yy0xLjIgNS4yIDEuOCA5LjIgNy43IDEyLjYgNC43IDMgMTMuNSAz'
    b'LjcgMTYuMyAxLjNsLTEzLjctMTMtNi41LTUuNHoiLz4KICAgICAgPHBhdGggZD0ibTUwMy42'
    b'IDM1NC4zLTItMi41YTEwMC44IDEwMC44IDAgMCAxLTMyLjcgMjguNmMxNS4xLTQuMiAyNS0x'
    b'NS4yIDM0LjctMjYuMXpNNDg4LjEgMzkwYTQ1NS44IDQ1NS44IDAgMCAxIDE4LjItMzIuM2wt'
    b'Mi4xLTIuN2MtNy40IDEyLjItMTYgMjYuNy0xNiAzNXptNDEuOC0xMTQuNWE2MiA2MiAwIDAg'
    b'MC00LjMtMTMgMTI2LjYgMTI2LjYgMCAwIDAtNDMuOC00NHYtLjNoLjRsLS4xLS4xaC40bC0u'
    b'Mi0uM2guNGwtLjMtLjRoLjRsLS4zLS4zaC41bC0uMy0uNGguNGwtLjQtLjMuNi0uMS0uNS0u'
    b'My41LS4xLS40LS4zLjYtLjItLjUtLjMuNi0uMy0uNi0uNC43LS4yLS44LS4zLjctLjRoLS44'
    b'bC41LS43aC0uN2wuMy0uNWgtLjZsLjMtLjUtLjcuMS4zLS42LS42LjQuMi0uNy0uNy40LjEt'
    b'LjctLjYuNS4xLS43LS41LjV2LS43bC0uNS42di0uN2wtLjQuNS0uMi0uNi0uNC42LS4xLS43'
    b'LS4zLjctLjItLjctLjMuNy0uMi0uNi0uMi42LS4yLS42LS4yLjgtLjItLjctLjMuOC0uMy0u'
    b'N3YuOGwtLjQtLjd2LjhsLS41LS42di44bC0uNC0uNnYuN2wtLjQtLjMuMi43LS41LS4zLjIu'
    b'Ni0uNC0uMi4xLjZoLS40bC4yLjRoLS4zbC4yLjRhOSA5IDAgMCAwLS40IDMuNWMwIC4yLjYu'
    b'NC43LjYuMy40LjIuNi4yLjYtMS42IDIuNi0zIDQuNi0zLjEgNy42IDEuMi0xLjYgMi42LTMu'
    b'NiA0LjQtMy42LS45IDEuNS0xLjMgNi4xLS4zIDYuOGwuOC0xLjNjMCAxIC4xIDEuOC40IDIu'
    b'My4zLS42LjYtMS4zIDEtMS43IDAgMS41LjIgMi43LjYgMy4zLjUtLjggMS0xLjIgMS42LTEu'
    b'Ni0uMi45LS41IDEuNy0uMyAyLjcuNi0xIDEuMi0xLjcgMS45LTIuNS0uNCAxLjYgMCAyLjgu'
    b'NCA0LjUuNC0yIC42LTIuMyAxLjUtMy4xLjEgMS45LS4yIDMuNi4yIDQuNy44LTEuNyAxLjQt'
    b'MS41IDItMi42LS4yIDEuNi0uNSAzLjMgMCA0LjdhNC41IDQuNSAwIDAgMSAxLjktMi42YzAg'
    b'Mi4yLjUgMS44LS44IDMuNy42LjIgMi41LS40IDMuNi0uOS0uNSAxLjItLjQgMi4xLS45IDMg'
    b'MS0uNiAyLTEuNSAyLjktMi40LS40IDEuNC0xLjUgMi44LTEgNC4xLjMtMS4zIDEuMy0yLjMg'
    b'Mi4zLTIuNS0uMi43LS4zIDIuMi0xLjMgMi45IDIuNC4yIDMuNC0xLjQgNC42LTIuNy0uMSAx'
    b'LjMgMCAyLjQgMS42IDQuMy0uMy0yLjQuMi0xLjkgMS4zLTMuMy42IDIuMSAxLjIgNC40IDMu'
    b'NCA2LTEtMi4zLTEtMy41LS42LTQuOS4zIDEuNSAxLjcgMy4zIDIgNC42LjMtMS41LjUtMyAx'
    b'LTRhMjAgMjAgMCAwIDEgMS40IDUuNmMuNS0xIC45LTIgMS4xLTMgMTkuOCAyMC41IDI0LjIg'
    b'NDYuNyAyLjUgNzQuNCA3LjgtNS4yIDkuOC0xMy41IDE0LjEtMjAuNi00LjIgOS4zLTYgMTku'
    b'Ny0xMy41IDI3LjQgNy4yLTYuMiA4LjctMTEuOSAxMy0xNy45LTQuNSAxMi41LTExIDI2LjIt'
    b'MTkuOCAzOC44bDQuOCA1LjIgNC02LjljOS40LTE1LjQgMjQuNy0zNy41IDE3LTcxLjF6Ii8+'
    b'CiAgICA8L2c+CiAgICA8cGF0aCBmaWxsPSIjZWFjMTAyIiBzdHJva2U9IiNhMDgzMDciIHN0'
    b'cm9rZS13aWR0aD0iLjIiIGQ9Ik00NzMuMiAyMTUuM2MtMSAuMi0xLjQuNi0yLjIgMS40IDEg'
    b'LjIgMS43LjMgMi42LjMuMiAwIC4zLS40LjMtLjZsLS4yLTFjMC0uMi0uNi0uMS0uOCAwbC4z'
    b'LS4xeiIvPgogICAgPHBhdGggZmlsbD0iI2EwODMwNyIgZD0iTTQ3MSAyMTYuN2E5LjkgOS45'
    b'IDAgMCAxIDIuMi0uNSA5LjggOS44IDAgMCAxLTIuMi41eiIvPgogICAgPGNpcmNsZSBjeD0i'
    b'NDc3LjciIGN5PSIyMTUuNCIgcj0iLjgiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIu'
    b'MSIvPgogICAgPGVsbGlwc2UgY3g9IjQ3Ny45IiBjeT0iMjE1LjMiIGZpbGw9InVybCgjZ3Qt'
    b'bikiIHJ4PSIuMyIgcnk9Ii40Ii8+CiAgICA8ZyBmaWxsPSIjMzQ1NDFmIj4KICAgICAgPHBh'
    b'dGggZD0iTTQ4OC4yIDM4OS43YTgzLjQgODMuNCAwIDAgMSA3LjQtMTcuMiAxOTkuNiAxOTku'
    b'NiAwIDAgMSA3LjEtMTIuMmwyLjYtNC0yLjUgNGE0MDcgNDA3IDAgMCAwLTcgMTIuMyAxMzMu'
    b'NyAxMzMuNyAwIDAgMC03LjYgMTd6bS0xOC45LTkuNWE3NS44IDc1LjggMCAwIDAgMjkuNy0y'
    b'My4xIDE1My41IDE1My41IDAgMCAwLTExLjIgMTEuOCA3MCA3MCAwIDAgMS0xOC41IDExLjN6'
    b'bTM3LjMtMjkuM2MuOC0xIDEuNS0yLjIgMi4yLTMuM2ExMzYuMiAxMzYuMiAwIDAgMCA2LTEw'
    b'LjJjMS40LTIuMyAyLjYtNC43IDMuOC03bDMuNy03LTEuNyAzLjUtMS44IDMuNmEyNTYgMjU2'
    b'IDAgMCAxLTcuNyAxMy44IDkzLjggOTMuOCAwIDAgMS00LjUgNi42em01LjktMjUuMWE1OC40'
    b'IDU4LjQgMCAwIDAgOC41LTEzLjQgNzIuNiA3Mi42IDAgMCAwIDYtMjMgNTQuMiA1NC4yIDAg'
    b'MCAwLS4xIDQgNTguOCA1OC44IDAgMCAxLTUuOCAxOSA1OS45IDU5LjkgMCAwIDEtOC42IDEz'
    b'LjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MTAuOSAzMjBhNTIgNTIgMCAwIDAgOC43LTEyLjVB'
    b'OTYgOTYgMCAwIDAgNTI0IDI5N2wuMy0uOS4zLS45LjYtMS44YTQxLjYgNDEuNiAwIDAgMCAu'
    b'Mi0xNS40IDU4IDU4IDAgMCAwIC43IDcuN2MwIDIuNi0uMiA1LjItLjcgNy43LS4zLjYtLjQg'
    b'MS4zLS42IDEuOWwtLjMuOS0uNC45YTIyOSAyMjkgMCAwIDEtNC40IDEwLjYgNTEuNiA1MS42'
    b'IDAgMCAxLTMuOCA2LjYgMzYgMzYgMCAwIDEtNSA1Ljh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01'
    b'MDUgMzQ5LjJjMS4zLTEuNiAyLjQtMy4zIDMuNi01bDEuOC0yLjUgMS43LTIuNSAzLTUuNCAy'
    b'LjYtNS41YzEuOC0zLjcgMy41LTcuNCA1LTExLjNhNzguOCA3OC44IDAgMCAwIDUuMy0yMy44'
    b'IDU4LjQgNTguNCAwIDAgMC0yLjYtMjQuMiA1Mi40IDUyLjQgMCAwIDEgMi44IDI0LjIgODAg'
    b'ODAgMCAwIDEtNS4zIDIzLjljLTEuNSAzLjgtMy4yIDcuNS01IDExLjJsLTIuOCA1LjVjLS45'
    b'IDEuOS0xLjggMy43LTIuOSA1LjQtLjUgMS0xLjEgMS43LTEuNyAyLjZsLTEuOCAyLjUtMy42'
    b'IDV6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MDcuOCAzNTIuM2E0NDMuNCA0NDMuNCAwIDAgMCAx'
    b'My40LTIzLjUgODEuOSA4MS45IDAgMCAwIDguNy0zOS4yYzAtNC41LS40LTktMS4yLTEzLjRh'
    b'NTcuNiA1Ny42IDAgMCAwIC4xIDBjLjkgNC40IDEuMiA5IDEuMiAxMy40YTEwMi45IDEwMi45'
    b'IDAgMCAxLTMuNiAyNi43IDgyIDgyIDAgMCAxLTUgMTIuNiA0NDIuNiA0NDIuNiAwIDAgMS0x'
    b'My41IDIzLjR6TTQ4MCAyMjAuOGgxLjRhMTQuMyAxNC4zIDAgMCAxIDQuMSAxLjMgMzUuOCAz'
    b'NS44IDAgMCAxIDkgNi44IDM3LjggMzcuOCAwIDAgMC05LTYuNiAxOSAxOSAwIDAgMC01LjUt'
    b'MS41eiIvPgogICAgPC9nPgogICAgPGcgZmlsbD0iIzQ0ODEyNyI+CiAgICAgIDxwYXRoIGQ9'
    b'Ik00OTYuNCAyMzEuNnMzIDEuOCA0LjcgNC40YzAgMC00LjctLjktOC00LjYiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iIzM0NTQxZiIgZD0iTTQ5Ni40IDIzMS42YTE0LjQgMTQuNCAwIDAgMSA0'
    b'LjggNC40bC4xLjJoLS4yYTE0LjUgMTQuNSAwIDAgMS00LjQtMS44Yy0xLjQtLjgtMi42LTEu'
    b'OC0zLjctM2ExNS4yIDE1LjIgMCAwIDAgNS45IDMuOGwyLjIuN3YuMmExMS4xIDExLjEgMCAw'
    b'IDAtMi4yLTIuNSAxNy43IDE3LjcgMCAwIDAtMi41LTJ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00'
    b'ODkuNiAyMzAuN3M3LjIgNC42IDguMyA1YzAgMC0xLjctMy41LTUuMS01Ii8+CiAgICAgIDxw'
    b'YXRoIGZpbGw9IiMzNDU0MWYiIGQ9Im00ODkuNiAyMzAuNyA0LjEgMi41YTE1Ni45IDE1Ni45'
    b'IDAgMCAwIDMuMSAxLjhsMSAuNnYuMWExMC43IDEwLjcgMCAwIDAtMi4xLTIuOSAxMC43IDEw'
    b'LjcgMCAwIDAtMi45LTIuMSA4LjQgOC40IDAgMCAxIDMgMiAxMSAxMSAwIDAgMSAyLjEgM2wu'
    b'Mi4yLS4zLS4xLTIuMS0xLjJhMTUzLjUgMTUzLjUgMCAwIDEtNi4xLTR6Ii8+CiAgICAgIDxw'
    b'YXRoIGQ9Ik00OTIuNSAyMjguNHMzLjcgMS42IDQuNiA0LjNjMCAwLTYuOC0yLjgtOC00LjMi'
    b'Lz4KICAgICAgPHBhdGggZmlsbD0iIzM0NTQxZiIgZD0iTTQ5Mi41IDIyOC40YTEwLjcgMTAu'
    b'NyAwIDAgMSAyLjggMS42bDEuMSAxLjIuOCAxLjV2LjJoLS4yYTc3LjIgNzcuMiAwIDAgMS03'
    b'LTMuN2wtLjktLjguOS43IDEgLjZhMzYgMzYgMCAwIDAgNi4xIDNoLS4xYy0uMi0uNC0uNC0x'
    b'LS44LTEuM2E0IDQgMCAwIDAtMS0xLjIgMTAuOCAxMC44IDAgMCAwLTIuNy0xLjh6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik00ODYuOCAyMzEuM3M2LjYgNC43IDguNiA0LjdjMCAwLTItMy4zLTUu'
    b'NC00LjciLz4KICAgICAgPHBhdGggZmlsbD0iIzM0NTQxZiIgZD0iTTQ4Ni44IDIzMS4zYTEy'
    b'NCAxMjQgMCAwIDAgNy40IDQuM2wxLjIuMy0uMS4yYTEyLjQgMTIuNCAwIDAgMC0yLjMtMi44'
    b'IDEzIDEzIDAgMCAwLTMtMiAxMC43IDEwLjcgMCAwIDEgNC40IDMuMmwxIDEuNS4yLjFoLS4y'
    b'Yy0uNSAwLS45LS4xLTEuMy0uM2wtMS0uNWEzMy4zIDMzLjMgMCAwIDEtNi4zLTR6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik00ODYuOCAyMzIuN3MzLjQgMyA1LjQgM2MwIDAtMi0zLjMtNS40LTQu'
    b'OCIvPgogICAgICA8cGF0aCBmaWxsPSIjMzQ1NDFmIiBkPSJNNDg2LjggMjMyLjdhMzIgMzIg'
    b'MCAwIDAgNCAyLjVsLjYuMi44LjItLjEuMWExMi40IDEyLjQgMCAwIDAtMi4zLTIuNyAxMyAx'
    b'MyAwIDAgMC0zLTIgMTAuNyAxMC43IDAgMCAxIDQuNCAzLjFsMSAxLjUuMi4yaC0uMmE0IDQg'
    b'MCAwIDEtMS42LS40IDExLjUgMTEuNSAwIDAgMS0yLjYtMS43IDQgNCAwIDAgMS0xLjItMXoi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTQ4NSAyMjYuMnM3LjIgNS4xIDggNy45YzAgMC02LjQtMy03'
    b'LjYtNC41Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiMzNDU0MWYiIGQ9Ik00ODUgMjI2LjJhNTEu'
    b'NiA1MS42IDAgMCAxIDcuNSA2LjZsLjcgMS4ydi4zbC0uMi0uMWE3OS42IDc5LjYgMCAwIDEt'
    b'Ni44LTMuOWwtLjgtLjcuOC43IDEgLjZhMzcuMyAzNy4zIDAgMCAwIDYgM2wtLjIuMi0uNy0x'
    b'LjJhMjkuMyAyOS4zIDAgMCAwLTUtNWwtMi4zLTEuN3oiLz4KICAgIDwvZz4KICAgIDxnIHN0'
    b'cm9rZT0iIzI0NDIwZSIgc3Ryb2tlLXdpZHRoPSIuMiI+CiAgICAgIDxwYXRoIGZpbGw9IiM0'
    b'MDYzMjUiIGQ9Ik00NDUgMzcwLjNhNDIuMiA0Mi4yIDAgMCAxLTIwLjQgNC44YzEwLTguMiAx'
    b'OS43LTguNCAyMC40LTQuOHptNjkuOCA0LjVjNS4yIDQuNyAyMSA4IDIzLjUgNy40LTEwLjYt'
    b'MTAuNy0yMi4xLTExLjgtMjMuNS03LjR6Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiM2NzkyM2Qi'
    b'IGQ9Ik00NDUgMzcwLjNjLS43LTMuNy0xMC41LTMuNC0yMC40IDQuOGE2OS42IDY5LjYgMCAw'
    b'IDEgMjAuNC00Ljh6bTY5LjkgNC40YzEuNC00LjQgMTIuOC0zLjMgMjMuNCA3LjVhODQgODQg'
    b'MCAwIDAtMjMuNC03LjV6Ii8+CiAgICA8L2c+CiAgPC9nPgo8L3N2Zz4K', 'GT')

GT = b64_GT
index.append("GT")
index.append("GTM")
index.append("Guatemala")
catalog["GT"] = GT
catalog["GTM"] = GT
catalog["Guatemala"] = GT
country["Guatemala"] = ('GT', 'GTM', 0)
lookup["GT"] = ('GT', 'GTM', 'Guatemala', 0)
lookup["Guatemala City Guatemala"] = ('GT', 'GTM', 'Guatemala', 0)
lookup["GTM"] = ('GT', 'GTM', 'Guatemala', 0)
lookup["Guatemala"] = ('GT', 'GTM', 'Guatemala', 0)
details["GT"] = {"continent":"Americas","capital":"Guatemala City","currency":"Quetzal","web":".gt","lang":"es-GT","tz":"-06:00","altname":""}
#----------------------------------------------------------------------
b64_GU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWd1IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2JlMDAyNyIgZmls'
    b'bC1ydWxlPSJldmVub2RkIiBkPSJNMCAwaDY0MHY0ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'M2I1YWEzIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yNS42IDI3LjNoNTg5LjV2NDI4LjRI'
    b'MjUuNnoiLz4KICA8cGF0aCBmaWxsPSIjY2JlMGU1IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0zMTQuNCA0MTMuMmExMCAxMCAwIDAgMCA4LjQuMWMxMzcuOC03My4zIDEzNy44LTI3NC4z'
    b'LjEtMzQ2LjZhMTAgMTAgMCAwIDAtOC43LjJjLTEzNC4zIDczLjQtMTM0LjcgMjcyLjEuMSAz'
    b'NDYuM3oiLz4KICA8cGF0aCBmaWxsPSIjYWRkMmQ5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0zMTQuNCA0MTYuOWMyIDEuNyA2LjQgMS41IDguNCAwIDEwMS41LTc2IDEwMi0xMjMuMyA5'
    b'Ny42LTEyMy4zaC0yMDFjLTMgMCAxLjggNDguMiA5NSAxMjMuM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmRmOWExIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yMzUuMyAzMzEuMmEzOS4yIDM5'
    b'LjIgMCAwIDEgMjcuOSAxLjdjNy42IDQgMTIgNCAyMC4yIDQgOC42LjIgMTUuMyA2LjUgMjQu'
    b'NiA2LjggMTcuMS40IDI0LjMgOC45IDExIDktNi4yIDAtMTkuNy00LjMtMjYuMi0zLjQtMTMu'
    b'NiAxLjQtMjIuMiA0LjQtMzUgMTguN2wxNC44IDEwYzEyLjgtNS4xIDE0LjktMTEgMjItMTEu'
    b'MiA4LS4zIDEwLjctNS4yIDIwLTUuMmE5Mi42IDkyLjYgMCAwIDAgMzMtMy4yYzE0LjgtMy40'
    b'IDcuOC0xMy44LTEuMi0xNy41LTcuMy0zLjEtMjAuOC0uMS0yOS4yLTMuMi02LjQtMi41LTEu'
    b'Mi02LjUgMi4zLTcuMyAzLjQtLjcgNy4xLjUgMTEuNCAxLjIgNy43LjYgMTcuNC0uMSAyNC4x'
    b'LTEuMiAxNC0yLjEgMTMuNC02LjIgMjAtNi4zIDUtLjMgOC43LTEuNyAxMi00LjEgNC0yLjcg'
    b'OC4xLTggMTIuOS03LjhsMTIuNy41LTE4IDQwLjQtNTAuNyA1MS43LTI2LjMgMTAtNTcuOC0z'
    b'Ny43LTI5LjEtNDQuNyA0LjctMS4yeiIvPgogIDxwYXRoIGZpbGw9IiMxNzlhM2IiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgZD0ibTMwMS44IDI5MiAxMTYtLjYgMi0xMC4zcy00LjEtLjYtNy41'
    b'LS44Yy00LjEtLjMtMTEuMyA0LjQtMTYgNC4zLTMuNSAwLTcuMy02LTEwLjctNi02IDAtNi40'
    b'IDUuMy0xMiA1LjUtNC41LS4yLTYuNC0zLjYtMTIuMy0zLjItNiAuMy01LjYgMy43LTEzLjMg'
    b'My41LTEwLjItLjMtMTQuMy05LjEtMjIuNS05LjItMTMuNi0uMi0xNCAxMy0yMy44IDE2Ljd6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZkZjlhMSIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtMzAx'
    b'LjggMjk0LjQgMTE5LjQtLjZ2LTMuMmwtMTIyLjIuNiAyLjcgMy4yeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNhNzkyNzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTM1MC44IDMzMC4zYzEuOSA3'
    b'IDMuOCA5LjQgMTEuMiAxMS4zIDcuMyAxLjcgMTguNS01LjQgMTEuNi0xMi4zLTYuNi02LjQt'
    b'MTMuNi04LTE5LjUtMTMuOC0xMi41LTEyLjMtMzEuMy00Mi41LTMxLjMtNjMuOCAwLTE4LjMt'
    b'MS44LTU1LjgtMS44LTkxLjMgMC0yLjMtNyA2LjQtNyA4LjguNCAzMS4zLjQgNTUgMS42IDg2'
    b'LjYgMiAyMy4xIDEzIDM4LjcgMjIuNyA1Mi43IDQuMyA2LjggMTAuNiAxNCAxMi41IDIxLjh6'
    b'Ii8+CiAgPHRleHQgeD0iNDY1LjEiIHk9IjI2OS41IiBmaWxsPSIjYmQwNzI4IiBzdHJva2U9'
    b'IiNmZmYiIHN0cm9rZS13aWR0aD0iMS42IiBmb250LWZhbWlseT0iaGVsdmV0aWNhIiBmb250'
    b'LXNpemU9IjI1LjYiIHRyYW5zZm9ybT0ibWF0cml4KDEuMzMgMCAwIDEuMzMgLTM2MyAtMTA4'
    b'KSI+PHRzcGFuPkc8L3RzcGFuPjwvdGV4dD4KICA8dGV4dCB4PSI0ODguMSIgeT0iMjY5LjYi'
    b'IGZpbGw9IiNiZDA3MjgiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxLjYiIGZvbnQt'
    b'ZmFtaWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'MS4zMyAwIDAgMS4zMyAtMzYzIC0xMDgpIj48dHNwYW4+VTwvdHNwYW4+PC90ZXh0PgogIDx0'
    b'ZXh0IHg9IjUxNiIgeT0iMjY5LjYiIGZpbGw9IiNiZDA3MjgiIHN0cm9rZT0iI2ZmZiIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjYiIGZvbnQtZmFtaWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUu'
    b'NiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4zMyAwIDAgMS4zMyAtMzYzIC0xMDgpIj48dHNwYW4+'
    b'QTwvdHNwYW4+PC90ZXh0PgogIDx0ZXh0IHg9IjUzOS41IiB5PSIyNjkuNSIgZmlsbD0iI2Jk'
    b'MDcyOCIgc3Ryb2tlPSIjZmZmIiBzdHJva2Utd2lkdGg9IjEuNiIgZm9udC1mYW1pbHk9Imhl'
    b'bHZldGljYSIgZm9udC1zaXplPSIyNS42IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjMzIDAgMCAx'
    b'LjMzIC0zNjMgLTEwOCkiPjx0c3Bhbj5NPC90c3Bhbj48L3RleHQ+CiAgPHBhdGggZmlsbD0i'
    b'IzIzOWU0NiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjU5LjYgMTYwLjljLTEuNSAzIDMu'
    b'Ni0uOSA0LjgtMS4zIDYuNy0yLjQgOS4zLTEwLjggMjAuOC01LjcgOSAzLjkgMjEuMSAxLjYg'
    b'MTQuOCA1LjYtNy44IDQuNy0yMy41IDkuOS0yMy44IDMzLjIgMS4zIDIuMiAxLjQgMS45IDIu'
    b'NS0uNiAyLjQtNS40IDEzLjctMjAuMSAxOS4zLTE4LjkgMi4zLjYgOC45LTYuNyA5LTQuNi43'
    b'IDUuOC05IDE3LjYtOC44IDMzLjMgMCAzLjcgNC41IDQuOSA2LjYgMi4zIDIuMi0yLjMgMy40'
    b'LTQuNiA3LjItNy42IDYuNi01LjQgNC44LTI4LjYgNS42LTI3LjUgNC43IDYgNS40IDIzLjMg'
    b'MTIuNCAzMC4zIDUuOSA1LjkgMTAuNiAzIDkuMy01LTIuNS0xNi40LTEwLjItMTEuNy0xMy45'
    b'LTI4LjYtLjgtMy4zLTEtNi4yIDMuNC00LjkgNS4zIDEuNiA4LjUgNCAxMi40IDEwIDQgNS44'
    b'IDExLjQgMTEuMyAxNS43IDE0LjYgNy41IDUuOCAxMC4yLjggNi42LTYuNmEzOS42IDM5LjYg'
    b'MCAwIDAtMjEtMTguMmMtNi4yLTIuMi04LjQtMi40LTEzLjgtMy40LTEuNS0uMy0zLTMuNC0u'
    b'NC01LjFhNDIuNSA0Mi41IDAgMCAxIDE5LjYtNy43YzYuNy0uMiAxMiA1LjIgMTYuNyA2LjYg'
    b'OS40IDIuNCA5LjQtMy41IDUuMi04LTMuNC0zLjctMTAuNi0xMC0xNy4zLTkuMS0xMy41IDEu'
    b'Ny0xMi42IDEuMy0yMSA2LjgtMyAxLjgtNi40IDMuOC01LjEgMS42IDMtNS41LjItNC41IDQu'
    b'OS0xMC4xIDMuNi00IDYuMy03IDEwLTggMy40LS45IDgtNC41IDkuMy02LjQgMy40LTQuNi41'
    b'LTcuMy00LjctNS43LTQuNiAxLjItNyA0LjItMTAgNS03LjQgMi40LTEzLjMgMTktMTQuMiAy'
    b'MS40LTEuMSAyLjgtMi40IDEuNC0yLjItMSAxLTExLjcgMi0zMS41LTItMzkuNi02LjQtMTIt'
    b'NS44LTYuNC04LjItLjctMy42IDktMi4zIDE3LjUgMCAyNi4zIDEgNC40IDQuNiA5LjQgNS4z'
    b'IDEyLjkuNSAyLjctMS42LS44LTIuOC0yLjUtMy45LTYtNi44LTEwLTEzLjItMTMuM2EzNS4z'
    b'IDM1LjMgMCAwIDAtMjAuMi0yYy0xLjguNiAyIDMuMiAzLjUgNC40IDQuMyAzLjQgMTIuNCA0'
    b'LjUgMTggNy45IDQuNiAyLjkgOC4yIDQuNyA5LjggOC43LjYgMyAxLjYgNy40LS40IDcuMy01'
    b'LjEtLjMtMTMtNC44LTI5LjQtMy04LjQgMS4yLTE1LjYgOC4zLTIwLjMgMTYuOXoiLz4KICA8'
    b'cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yOTUuMyAzMTAuNmg0Ljd2Ny45aC00Ljd6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZkZjlmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjcx'
    b'LjcgMjU3LjljMTguOCAyNiA0OSA0MS4yIDQ5LjYgNTNoLTU4LjhjMTMuNS0xNi4yIDIxLjgt'
    b'MjcuMiA5LjItNTN6Ii8+CiAgPHBhdGggZmlsbD0iI2E2ODg2MSIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNMjU0LjYgMzExLjVjMjUuNiA1LjcgNTYuMSA4LjkgNzUuNi0uOC4yIDUuNy02'
    b'LjMgMTQtMTEuNyAxNGgtNDljNS43LS45IDktMi42IDE4LjItM2wtMjYgLjJjLTMgLjEtOC03'
    b'LjYtNy4xLTEwLjR6Ii8+CiAgPHBhdGggZmlsbD0iI2JlMDAyNyIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNMzEyLjYgNDI1YzIuNiAxLjUgNi43IDEuNCA5IC4yIDE0Ny44LTc4LjcgMTQ3'
    b'LjktMjk0LjQuMi0zNzJhMTAuNyAxMC43IDAgMCAwLTkuNC4yYy0xNDQgNzguOC0xNDQuNCAy'
    b'OTIgLjIgMzcxLjd6bS43LTE3LjdhOS4zIDkuMyAwIDAgMCA4IC4xYzEyMy42LTcyLjggMTI1'
    b'LjEtMjY1LjEuMS0zMzQtMi40LTEuOC01LjktMS4yLTguMyAwLTExOC40IDcwLjEtMTI1IDI1'
    b'NC41LjIgMzMzLjl6Ii8+CiAgPHBhdGggZmlsbD0iI2JkMDcyOCIgZD0iTTI2OC44IDIyNS40'
    b'cTMuNCAwIDYgMS40IDMuNSAxLjggNC4zIDYuNkgyNzZxLS42LTIuNi0yLjYtNC0xLjgtMS4y'
    b'LTQuNy0xLjItMy4zIDAtNS43IDIuNy0yLjMgMi41LTIuMyA3LjYgMCA0LjIgMS45IDcgMiAy'
    b'LjcgNi4zIDIuNyAzLjMgMCA1LjQtMS45IDIuMy0xLjkgMi4zLTYuMkgyNjl2LTIuN2gxMC42'
    b'djEzaC0yLjFsLS44LTMuMnEtMS42IDEuOS0zIDIuNy0yLjIgMS4yLTUuNSAxLjItNC4zIDAt'
    b'Ny41LTIuOC0zLjQtMy42LTMuNC05Ljd0My4zLTkuN3EzLjItMy41IDguMi0zLjV6bS0uNiAw'
    b'eiIgYXJpYS1sYWJlbD0iRyIgZm9udC1mYW1pbHk9ImhlbHZldGljYSIgZm9udC1zaXplPSIy'
    b'NS42Ii8+CiAgPHBhdGggZmlsbD0iI2JkMDcyOCIgZD0iTTI5Mi40IDIyNi4xdjE1LjJxMCAy'
    b'LjYgMSA0LjMgMS40IDIuNyA1IDIuNyA0LjEgMCA1LjctMi44LjgtMS42LjgtNC4yVjIyNmgz'
    b'LjR2MTMuOHEwIDQuNC0xLjQgNy0yLjEgNC4zLTguMiA0LjMtNi4zIDAtOC41LTQuNC0xLjIt'
    b'Mi41LTEuMi02LjlWMjI2em02LjMgMHoiIGFyaWEtbGFiZWw9IlUiIGZvbnQtZmFtaWx5PSJo'
    b'ZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIvPgogIDxwYXRoIGZpbGw9IiNiZDA3MjgiIGQ9'
    b'Im0zMzguNCAyNDAuNS0zLjctMTAuNy00IDEwLjd6TTMzMyAyMjZoMy43bDkgMjQuNWgtMy44'
    b'bC0yLjQtNy4zaC05LjdsLTIuNyA3LjNoLTMuM3oiIGFyaWEtbGFiZWw9IkEiIGZvbnQtZmFt'
    b'aWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIvPgogIDxwYXRoIGZpbGw9IiNiZDA3'
    b'MjgiIGQ9Ik0zNTcgMjI2aDQuOWw2LjkgMjAuNyA3LTIwLjdoNC43djI0LjRoLTMuMnYtMjAu'
    b'NmwtNyAyMC42aC0zLjFsLTctMjAuNnYyMC42SDM1N3oiIGFyaWEtbGFiZWw9Ik0iIGZvbnQt'
    b'ZmFtaWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIvPgo8L3N2Zz4K', 'GU')

GU = b64_GU
index.append("GU")
index.append("GUM")
index.append("Guam")
catalog["GU"] = GU
catalog["GUM"] = GU
catalog["Guam"] = GU
country["Guam"] = ('GU', 'GUM', 0)
lookup["GU"] = ('GU', 'GUM', 'Guam', 0)
lookup["Hagåtña Guam"] = ('GU', 'GUM', 'Guam', 0)
lookup["GUM"] = ('GU', 'GUM', 'Guam', 0)
lookup["Guam"] = ('GU', 'GUM', 'Guam', 0)
details["GU"] = {"continent":"Oceania","capital":"Hagåtña","currency":"US Dollar","web":".gu","lang":"en-GU | ch-GU","tz":"+10:00","altname":""}
#----------------------------------------------------------------------
b64_GW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ndyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNjZTExMjYiIGQ9Ik0wIDBoMjIwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmY2QxMTYiIGQ9Ik0yMjAgMGg0MjB2MjQwSDIyMHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjMDA5ZTQ5IiBkPSJNMjIwIDI0MGg0MjB2MjQwSDIyMHoiLz4K'
    b'ICA8ZyBpZD0iZ3ctYiIgdHJhbnNmb3JtPSJtYXRyaXgoODAgMCAwIDgwIDExMCAyNDApIj4K'
    b'ICAgIDxwYXRoIGlkPSJndy1hIiBkPSJNMC0xdjFoLjUiIHRyYW5zZm9ybT0icm90YXRlKDE4'
    b'IDAgLTEpIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNndy1hIiB3aWR0aD0iMTAwJSIgaGVp'
    b'Z2h0PSIxMDAlIiB0cmFuc2Zvcm09InNjYWxlKC0xIDEpIi8+CiAgPC9nPgogIDx1c2UgeGxp'
    b'bms6aHJlZj0iI2d3LWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0i'
    b'cm90YXRlKDcyIDExMCAyNDApIi8+CiAgPHVzZSB4bGluazpocmVmPSIjZ3ctYiIgd2lkdGg9'
    b'IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoMTQ0IDExMCAyNDApIi8+'
    b'CiAgPHVzZSB4bGluazpocmVmPSIjZ3ctYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIg'
    b'dHJhbnNmb3JtPSJyb3RhdGUoLTE0NCAxMTAgMjQwKSIvPgogIDx1c2UgeGxpbms6aHJlZj0i'
    b'I2d3LWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0icm90YXRlKC03'
    b'MiAxMTAgMjQwKSIvPgo8L3N2Zz4K', 'GW')

GW = b64_GW
index.append("GW")
index.append("GNB")
index.append("Guinea-Bissau")
catalog["GW"] = GW
catalog["GNB"] = GW
catalog["Guinea-Bissau"] = GW
country["Guinea-Bissau"] = ('GW', 'GNB', 0)
lookup["GW"] = ('GW', 'GNB', 'Guinea-Bissau', 0)
lookup["Bissau Guinea-Bissau"] = ('GW', 'GNB', 'Guinea-Bissau', 0)
lookup["GNB"] = ('GW', 'GNB', 'Guinea-Bissau', 0)
lookup["Guinea-Bissau"] = ('GW', 'GNB', 'Guinea-Bissau', 0)
details["GW"] = {"continent":"Africa","capital":"Bissau","currency":"CFA Franc BCEAO","web":".gw","lang":"pt-GW | pov","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_GY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWd5IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMzOTk0MDgiIGQ9Ik0yLjQgMEg2NDB2NDgwSDIuNHoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0uMiAwYy0uOSAwIDYxOS42IDI0MS41IDYxOS42IDI0'
    b'MS41TDAgNDc5LjguMiAweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZGUwOCIgZD0iTS4zIDIw'
    b'LjJjMy40IDAgNTU5IDIxNy45IDU1NS45IDIyMEwxLjkgNDYzLjIuMyAyMC4zeiIvPgogICAg'
    b'PHBhdGggZD0iTTEuOS44YzEuOCAwIDI5MC45IDI0MC45IDI5MC45IDI0MC45TDEuOCA0NzdW'
    b'Ljh6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZGUyMTEwIiBkPSJNLjMgMzMuOWMxLjYtMTUgMjYw'
    b'LjkgMjA4LjQgMjYwLjkgMjA4LjRMLjIgNDUxLjdWMzMuOXoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'GY')

GY = b64_GY
index.append("GY")
index.append("GUY")
index.append("Guyana")
catalog["GY"] = GY
catalog["GUY"] = GY
catalog["Guyana"] = GY
country["Guyana"] = ('GY', 'GUY', 0)
lookup["GY"] = ('GY', 'GUY', 'Guyana', 0)
lookup["Georgetown Guyana"] = ('GY', 'GUY', 'Guyana', 0)
lookup["GUY"] = ('GY', 'GUY', 'Guyana', 0)
lookup["Guyana"] = ('GY', 'GUY', 'Guyana', 0)
details["GY"] = {"continent":"Americas","capital":"Georgetown","currency":"Guyana Dollar","web":".gy","lang":"en-GY","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_HK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1oayIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNFQzFCMkUiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgwIi8+CiAgPHBhdGggaWQ9ImhrLWEiIGZpbGw9IiNmZmYiIGQ9Ik0zNDYuMyAxMDMuMUMy'
    b'NjcgOTggMjMwLjYgMjAxLjkgMzA1LjYgMjQwLjNjLTI2LTIyLjQtMjAuNi01NS4zLTEwLjEt'
    b'NzIuNGwxLjkgMS4xYy0xMy44IDIzLjUtMTEuMiA1Mi43IDExLjEgNzEtMTIuNy0xMi4zLTku'
    b'NS0zOSAxMi4xLTQ4LjlzMjMuNi0zOS4zIDE2LjQtNDkuMXEtMTQuNy0yNS42IDkuMy0zOC45'
    b'ek0zMDcuOSAxNjRsLTQuNyA3LjQtMS44LTguNi04LjYtMi4zIDcuOC00LjMtLjYtOC45IDYu'
    b'NSA2LjEgOC4zLTMuMy0zLjcgOC4xIDUuNiA2Ljh6Ii8+CiAgPHVzZSB4bGluazpocmVmPSIj'
    b'aGstYSIgdHJhbnNmb3JtPSJyb3RhdGUoNzIgMzEyLjUgMjQzLjUpIi8+CiAgPHVzZSB4bGlu'
    b'azpocmVmPSIjaGstYSIgdHJhbnNmb3JtPSJyb3RhdGUoMTQ0IDMxMi41IDI0My41KSIvPgog'
    b'IDx1c2UgeGxpbms6aHJlZj0iI2hrLWEiIHRyYW5zZm9ybT0icm90YXRlKDIxNiAzMTIuNSAy'
    b'NDMuNSkiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNoay1hIiB0cmFuc2Zvcm09InJvdGF0ZSgy'
    b'ODggMzEyLjUgMjQzLjUpIi8+Cjwvc3ZnPgo=', 'HK')

HK = b64_HK
index.append("HK")
index.append("HKG")
index.append("China - Hong Kong")
catalog["HK"] = HK
catalog["HKG"] = HK
catalog["China - Hong Kong"] = HK
country["China - Hong Kong"] = ('HK', 'HKG', 0)
lookup["HK"] = ('HK', 'HKG', 'China - Hong Kong', 0)
lookup["Hong Kong China - Hong Kong"] = ('HK', 'HKG', 'China - Hong Kong', 0)
lookup["HKG"] = ('HK', 'HKG', 'China - Hong Kong', 0)
lookup["China - Hong Kong"] = ('HK', 'HKG', 'China - Hong Kong', 0)
details["HK"] = {"continent":"Asia","capital":"Hong Kong","currency":"Hong Kong Dollar","web":".hk","lang":"zh-HK | yue | zh | en","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_HM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWhtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwMDA4QiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTM3LjUgMCAxMjIg'
    b'OTAuNUwyODEgMGgzOXYzMWwtMTIwIDg5LjUgMTIwIDg5VjI0MGgtNDBsLTEyMC04OS41TDQw'
    b'LjUgMjQwSDB2LTMwbDExOS41LTg5TDAgMzJWMHoiLz4KICA8cGF0aCBmaWxsPSJyZWQiIGQ9'
    b'Ik0yMTIgMTQwLjUgMzIwIDIyMHYyMGwtMTM1LjUtOTkuNXptLTkyIDEwIDMgMTcuNS05NiA3'
    b'Mkgwek0zMjAgMHYxLjVsLTEyNC41IDk0IDEtMjJMMjk1IDB6TTAgMGwxMTkuNSA4OGgtMzBM'
    b'MCAyMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMTIwLjUgMHYyNDBoODBWMGgtODBa'
    b'TTAgODB2ODBoMzIwVjgwSDBaIi8+CiAgPHBhdGggZmlsbD0icmVkIiBkPSJNMCA5Ni41djQ4'
    b'aDMyMHYtNDh6TTEzNi41IDB2MjQwaDQ4VjB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0i'
    b'bTUyNyAzOTYuNy0yMC41IDIuNiAyLjIgMjAuNS0xNC44LTE0LjQtMTQuNyAxNC41IDItMjAu'
    b'NS0yMC41LTIuNCAxNy4zLTExLjItMTAuOS0xNy41IDE5LjYgNi41IDYuOS0xOS41IDcuMSAx'
    b'OS40IDE5LjUtNi43LTEwLjcgMTcuNiAxNy40IDExLjFabS0zLjctMTE3LjIgMi43LTEzLTku'
    b'OC05IDEzLjItMS41IDUuNS0xMi4xIDUuNSAxMi4xIDEzLjIgMS41LTkuOCA5IDIuNyAxMy0x'
    b'MS42LTYuNi0xMS42IDYuNlptLTEwNC4xLTYwLTIwLjMgMi4yIDEuOCAyMC4zLTE0LjQtMTQu'
    b'NS0xNC44IDE0LjEgMi40LTIwLjMtMjAuMi0yLjcgMTcuMy0xMC44LTEwLjUtMTcuNSAxOS4z'
    b'IDYuOEwzODcgMTc4bDYuNyAxOS4zIDE5LjQtNi4zLTEwLjkgMTcuMyAxNy4xIDExLjJaTTYy'
    b'MyAxODYuN2wtMjAuOSAyLjcgMi4zIDIwLjktMTUuMS0xNC43LTE1IDE0LjggMi4xLTIxLTIw'
    b'LjktMi40IDE3LjctMTEuNS0xMS4xLTE3LjkgMjAgNi43IDctMTkuOCA3LjIgMTkuOCAxOS45'
    b'LTYuOS0xMSAxOCAxNy44IDExLjNabS05Ni4xLTgzLjUtMjAuNyAyLjMgMS45IDIwLjgtMTQu'
    b'Ny0xNC44LTE1LjEgMTQuNCAyLjQtMjAuNy0yMC43LTIuOCAxNy43LTExTDQ2NyA3My41bDE5'
    b'LjcgNi45IDcuMy0xOS41IDYuOCAxOS43IDE5LjgtNi41LTExLjEgMTcuNiAxNy40IDExLjVa'
    b'TTIzNCAzODUuN2wtNDUuOCA1LjQgNC42IDQ1LjktMzIuOC0zMi40LTMzIDMyLjIgNC45LTQ1'
    b'LjktNDUuOC01LjggMzguOS0yNC44LTI0LTM5LjQgNDMuNiAxNSAxNS44LTQzLjQgMTUuNSA0'
    b'My41IDQzLjctMTQuNy0yNC4zIDM5LjIgMzguOCAyNS4xWiIvPgo8L3N2Zz4K', 'HM')

HM = b64_HM
index.append("HM")
index.append("HMD")
index.append("Heard Island and McDonald Islands")
catalog["HM"] = HM
catalog["HMD"] = HM
catalog["Heard Island and McDonald Islands"] = HM
country["Heard Island and McDonald Islands"] = ('HM', 'HMD', 0)
lookup["HM"] = ('HM', 'HMD', 'Heard Island and McDonald Islands', 0)
lookup["HMD"] = ('HM', 'HMD', 'Heard Island and McDonald Islands', 0)
lookup["Heard Island and McDonald Islands"] = ('HM', 'HMD', 'Heard Island and McDonald Islands', 0)
details["HM"] = {"continent":"Oceania","capital":"","currency":"Australian Dollar","web":".hm","lang":"","tz":"+05:00","altname":""}
#----------------------------------------------------------------------
b64_HN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1obiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMxOGMzZGYiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDE2MGg2NDB2MTYwSDB6Ii8+CiAg'
    b'PGcgaWQ9ImhuLWMiIGZpbGw9IiMxOGMzZGYiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDMyMCAy'
    b'NDApIHNjYWxlKDI2LjY2NjY1KSI+CiAgICA8ZyBpZD0iaG4tYiI+CiAgICAgIDxwYXRoIGlk'
    b'PSJobi1hIiBkPSJtLS4zIDAgLjUuMUwwLTF6Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0i'
    b'I2huLWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ic2NhbGUoLTEg'
    b'MSkiLz4KICAgIDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2huLWIiIHdpZHRoPSIxMDAl'
    b'IiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0icm90YXRlKDcyKSIvPgogICAgPHVzZSB4bGlu'
    b'azpocmVmPSIjaG4tYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJy'
    b'b3RhdGUoLTcyKSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjaG4tYiIgd2lkdGg9IjEwMCUi'
    b'IGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoMTQ0KSIvPgogICAgPHVzZSB4bGlu'
    b'azpocmVmPSIjaG4tYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJy'
    b'b3RhdGUoLTE0NCkiLz4KICA8L2c+CiAgPHVzZSB4bGluazpocmVmPSIjaG4tYyIgd2lkdGg9'
    b'IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTMzLjMgLTQyLjcp'
    b'Ii8+CiAgPHVzZSB4bGluazpocmVmPSIjaG4tYyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAw'
    b'JSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTMzLjMgMzcuMykiLz4KICA8dXNlIHhsaW5rOmhy'
    b'ZWY9IiNobi1jIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InRyYW5z'
    b'bGF0ZSgtMTMzLjMgLTQyLjcpIi8+CiAgPHVzZSB4bGluazpocmVmPSIjaG4tYyIgd2lkdGg9'
    b'IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTEzMy4zIDM3LjMp'
    b'Ii8+Cjwvc3ZnPgo=', 'HN')

HN = b64_HN
index.append("HN")
index.append("HND")
index.append("Honduras")
catalog["HN"] = HN
catalog["HND"] = HN
catalog["Honduras"] = HN
country["Honduras"] = ('HN', 'HND', 0)
lookup["HN"] = ('HN', 'HND', 'Honduras', 0)
lookup["Tegucigalpa Honduras"] = ('HN', 'HND', 'Honduras', 0)
lookup["HND"] = ('HN', 'HND', 'Honduras', 0)
lookup["Honduras"] = ('HN', 'HND', 'Honduras', 0)
details["HN"] = {"continent":"Americas","capital":"Tegucigalpa","currency":"Lempira","web":".hn","lang":"es-HN | cab | miq","tz":"-06:00","altname":""}
#----------------------------------------------------------------------
b64_HR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ociIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMxNzE3OTYiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjMyMEgweiIvPgogIDxw'
    b'YXRoIGZpbGw9InJlZCIgZD0iTTAgMGg2NDB2MTYwSDB6bTMyMCAzNjQuMWM1MS4zIDAgOTMu'
    b'My00MiA5My4zLTkzLjNWMTYwSDIyNi43djExMC44YzAgNTEuNCA0MiA5My40IDkzLjMgOTMu'
    b'NHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMzIwIDM2Mi42YTkxLjggOTEuOCAwIDAg'
    b'MCA5MS42LTkxLjVWMTYxLjhIMjI4LjVWMjcxYTkxLjggOTEuOCAwIDAgMCA5MS41IDkxLjV6'
    b'Ii8+CiAgPGcgZmlsbD0icmVkIj4KICAgIDxwYXRoIGQ9Ik0yNjcuMSAxNjUuMkgyMzJ2Mzgu'
    b'N2gzNS4yem0wIDc3LjRoMzUuM3YtMzguN0gyNjd6TTIzMiAyNzAuOWMwIDMuNS4yIDcgLjYg'
    b'MTAuNGgzNC42di0zOC43SDIzMnYyOC4zem0xMDUuNy0yOC4zaC0zNS4ydjM4LjdoMzUuMnpt'
    b'MCA3Ny40aDM1LjJ2LTM4LjdoLTM1LjJ6bTM1LjIgMjEuMkE4OS4yIDg5LjIgMCAwIDAgMzkz'
    b'IDMyMGgtMjB2MjEuMnpNMjY3LjEgMzIwaDM1LjN2LTM4LjdIMjY3em0tMjAuMSAwYTg5LjIg'
    b'ODkuMiAwIDAgMCAyMC4xIDIxLjJWMzIwSDI0N3ptNzkuMSAzOC43YzQtLjMgNy43LS44IDEx'
    b'LjUtMS42VjMyMGgtMzUuMnYzNy4xYTg3IDg3IDAgMCAwIDExLjQgMS42YzQuMS4zIDguMi4y'
    b'IDEyLjMgMHoiLz4KICAgIDxwYXRoIGQ9Ik00MDcuNCAyODEuM2MuNC0zLjQuNi02LjkuNi0x'
    b'MC40di0yOC4zaC0zNS4ydjM4LjdoMzQuNnptLTY5LjgtMzguN2gzNS4ydi0zOC43aC0zNS4y'
    b'em0wLTc3LjRoLTM1LjJ2MzguN2gzNS4yem03MC40IDM4Ljd2LTM4LjdoLTM1LjJ2MzguN3oi'
    b'Lz4KICA8L2c+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTQxMCAxNTguOCAyMS44LTQ5LjUt'
    b'MTYuNi0yNi44LTI3LjYgMTAuMi0xOS40LTIyLjItMjUuNCAxNC43TDMyMCA2Ni41bC0yMi43'
    b'IDE4LjYtMjUuNS0xNC42LTE5LjQgMjIuMi0yNy42LTEwLjMtMTYuNiAyNyAyMS44IDQ5LjRh'
    b'MjE3LjggMjE3LjggMCAwIDEgOTAtMTkuM2MzMiAwIDYyLjUgNi45IDkwIDE5LjN6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzAwOTNkZCIgZD0ibTI1MyA5NC44LTI3LjQtMTAtMTUuMyAyNC43IDUu'
    b'OSAxMy4zIDE0LjggMzMuN2EyMTkuNyAyMTkuNyAwIDAgMSAzNC42LTEyTDI1MyA5NC44eiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIg'
    b'ZD0iTTI1MS40IDExOS4zYTEzLjMgMTMuMyAwIDAgMSAxLjYgNi4yYzAgNy4zLTYgMTMuMy0x'
    b'My40IDEzLjNhMTMuNCAxMy40IDAgMCAxLTEzLjEtMTAuOCAxMy40IDEzLjQgMCAwIDAgMTEu'
    b'NyA2LjkgMTMuNCAxMy40IDAgMCAwIDEzLjItMTUuNnoiLz4KICA8cGF0aCBkPSJtMjI3LjYg'
    b'MTE0IDEtNC45LTMuOC0zLjItLjEtLjEuMi0uMSA0LjYtMS42IDEtNC44di0uMmwuMi4xIDMu'
    b'NyAzLjIgNC42LTEuNmguMnYuMmwtMSA0LjggMy43IDMuMi4yLjJoLS4zbC00LjYgMS42LTEg'
    b'NC44di4ybC0uMS0uMS0zLjctMy4yLTQuNiAxLjZoLS4zeiIvPgogIDxwYXRoIGZpbGw9IiNm'
    b'N2RiMTciIGQ9Im0yMzMuNiAxMDcuNiAzLjUgMyA0LjMtMS41em0wLS4yIDcuOCAxLjYtMy40'
    b'LTN6bS04LjMtMS42IDcuOCAxLjUtMy41LTN6bTcuOCAxLjctNy44LTEuNSAzLjQgM3ptLjQt'
    b'LjMgNS4yLTYtNC4zIDEuNXptLTUuNiA2LjQgNS4yLTYtNC4zIDEuNXptNS4zLTUuOS01LjIg'
    b'NiA0LjMtMS41em01LjYtNi40LTUuMiA2IDQuMy0xLjV6bS01LjYgNi0yLjYtNy42LS45IDQu'
    b'NXptMi43IDgtMi41LTcuNS0uOSA0LjV6bS0yLjQtNy42IDIuNiA3LjUuOS00LjV6bS0yLjct'
    b'OCAyLjUgNy41IDEtNC41eiIvPgogIDxwYXRoIGZpbGw9IiMxNzE3OTYiIGQ9Ik0yOTcuNSA4'
    b'Ny40IDI3Mi4xIDczIDI1MyA5NC45bDEyLjYgNDkuNmEyMTkuOCAyMTkuOCAwIDAgMSAzNi4x'
    b'LTZsLTQuMi01MS4xeiIvPgogIDxwYXRoIGZpbGw9InJlZCIgZD0iTTI2Mi41IDEzMi4yYTIz'
    b'Mi4zIDIzMi4zIDAgMCAxIDM4LjItNi40bC0xLTEyLjlhMjQ1LjYgMjQ1LjYgMCAwIDAtNDAu'
    b'NCA2LjdsMy4yIDEyLjZ6bS02LjMtMjVhMjU4IDI1OCAwIDAgMSA0Mi40LTdsLTEuMS0xMi43'
    b'YTI3MC43IDI3MC43IDAgMCAwLTQ0LjUgNy40bDMuMiAxMi4zeiIvPgogIDxnIHRyYW5zZm9y'
    b'bT0idHJhbnNsYXRlKC0xNjApIHNjYWxlKC4wMDIzNykiPgogICAgPHBhdGggZmlsbD0iIzAw'
    b'OTNkZCIgZD0ibTIxMjEwNSAzNjg5MC0yMyAxMy05NTE3LTc3OTQtOTQ5NyA3Nzc4IDE3ODgg'
    b'MjE1NjBjMjU0My0yMTAgNTExMy0zMjIgNzcwOS0zMjIgMjYwOCAwIDUxOTAgMTEzIDc3NDQg'
    b'MzI1bDE3OTUtMjE1NjB6Ii8+CiAgICA8ZyBpZD0iaHItYSI+CiAgICAgIDxwYXRoIGQ9Ik0y'
    b'MDI1NDUgNDY1ODVjLTE4LTItNDQgMTAtNjkgNDUtMTg2IDI1MC0zNTkgNDY5LTU0NSA3MjAt'
    b'MTk1IDYxLTI0MiAxODAtMTY3IDM0OC0yNjEtMjYtMjkxIDE5My0zMDIgNDMyLTI1MC0zNzkt'
    b'NTIyLTQ4Mi04MTQtMzA3LTExLTIzMC0xODctMzM4LTQzOS0zOTItMTgwLTEwLTMxOS02NS00'
    b'MzYtMTQ1LTYwLTQyLTExMC02NC0xNzAtMTA2LTEyNi04OC0yMjYtNS0xNzIgNzQgMjY3IDQz'
    b'NCA1MzUgODY4IDgwMiAxMzAyLTE0IDgwIDYgMTUxIDg4IDIwNCA0NyAxMzMgOTMgMjY1IDE0'
    b'MCAzOTctMTEgMzgtMjEgNzUtMzIgMTEzLTIyMS0xMDUtNDQzLTExOC02NjQtMTMzLTE3MC04'
    b'LTI4Ny01MC0zNjEtMTM3LTU0LTYzLTkxLTI2LTkyIDgyLTMgNTM0IDE2MiAxMDE0IDU5OSAx'
    b'NDkyLTIzMSA0LTQ2MiAxMS02OTQgMjEtNzkgNi05NSAzOS03MyAxMDQgMTI2IDMwNCAzMzkg'
    b'NTc5IDgyMiA3NjYtMjA4IDExMi0zMjcgMjg1LTM1NyA1MjAtOSAyMjQtNzUgMzgyLTIxMiA0'
    b'NTUtNjAgMzItODEgNjUtMjQgMTA2IDI1MyAxODUgNTY1IDE5MyA4OTUgMTEyLTE1NyAyNzAt'
    b'MjI2IDU1My0xOTggODUwIDIwOCA1NiA0MTIgMTUgNjE0LTUyLTI5IDYxLTQ0IDE3NS01MiAz'
    b'MDktNyAxMTUtNDEgMjI5LTEwNCAzNDMtMzIgMzMtNjUgODQgNCAxMDIgMzM2IDkxIDY0OCA1'
    b'MiA5MTUtNDcgMCAyNDMgMiA0ODcgNzYgNzI3IDE4IDU4IDcwIDEwMiAxMjUgMjYgMTU1LTIx'
    b'NCAzMjItMzk2IDUyNy01MTcgMzEgOTAgNzUgMTY4IDE1NiAyMTUgOTYgNTUgMTQ3IDE3MCAx'
    b'NTMgMzQzIDAgMzAtMiA2MCAzNSA5MCAxNDkgNyA1MTQtMzgwIDU4OS01OTcgMjA2IDEyMSAy'
    b'ODQgMjQ2IDQzOSA0NjEgNTUgNzYgOTkgMjkgMTI4LTI1IDYyLTI0MyA2Ny00ODEgNjYtNzI0'
    b'IDI2NyA5OSA1NzkgMTM4IDkxNSA0NyA2OS0xOSAzNi03MCA0LTEwMi02Mi0xMTQtMTA1LTI1'
    b'MC0xMTMtMzY1LTktMTMzLTE0LTIyNi00My0yODcgMjAyIDY4IDQwNSAxMDggNjE0IDUyIDI5'
    b'LTI5Ny01My01NzktMjExLTg1MCAzMzAgODAgNjU1IDczIDkwOC0xMTIgNTctNDEgMzUtNzQt'
    b'MjQtMTA2LTEzNi03My0yMDMtMjMxLTIxMi00NTUtMzAtMjM1LTE0OS00MDktMzU3LTUyMCA0'
    b'ODMtMTg3IDY5Ni00NjMgODIyLTc2NiAyMi02NiA2LTk5LTczLTEwNC0yMzEtMTAtNDgwLTI0'
    b'LTcxMS0yNyA0MzctNDc4IDYwNi05NjEgNjA0LTE0OTUtMS0xMDgtMzgtMTQ2LTkyLTgyLTc0'
    b'IDg3LTE3OSAxMzctMzQ4IDE0Ni0yMjIgMTUtNDM1IDI0LTY1NiAxMjgtMTEtMzgtMjEtNzUt'
    b'MzItMTEzIDQ2LTEzMiAxMDYtMjYwIDE1My0zOTMgODItNTMgMTAyLTEyMyA4OC0yMDQgMjY3'
    b'LTQzNCA1MTMtODY4IDc4MS0xMzAyIDU0LTc5LTQ2LTE2Mi0xNzEtNzQtNjAgNDItMTEwIDY0'
    b'LTE3MCAxMDYtMTE3IDgwLTI1NyAxMzQtNDM3IDE0NS0yNTEgNTQtNDE3IDE2Ny00MjggMzk3'
    b'LTI5My0xNzUtNTY0LTczLTgxNCAzMDctMTEtMjM5LTQxLTQ1Ny0zMDItNDMyIDc1LTE2OCAx'
    b'Ny0yOTEtMTc4LTM1Mi0xODYtMjUwLTQ1OC00NzAtNjQ0LTcyMC0zMS0zNS01MS00Ny02OS00'
    b'NXoiLz4KICAgICAgPGcgZmlsbD0iI2Y3ZGIxNyI+CiAgICAgICAgPHBhdGggZD0iTTIwNTA3'
    b'NSA0Nzk3OGMtNTEtMjYtMTI0IDE3LTE2MiA5NXMtMzMgMTcwIDE5IDE5NmM0MCAyMCA4NC02'
    b'IDExOS01NmwyMi0zNmMyLTMgNC02IDUtOSAzOC03OCA0OS0xNjMtMi0xODh6bS01MDA4IDBj'
    b'NTItMjYgMTI0IDE3IDE2MiA5NXMzOSAxNjUtMTMgMTkxLTEwMy0yNC0xNDEtMTAyLTYwLTE1'
    b'OC05LTE4NHptNDUzOSA5MDVjLTMyIDAtNTkgMjctNTkgNTlzMjYgNTkgNTkgNTkgNTktMjYg'
    b'NTktNTljMC0zMi0yNi01OS01OS01OXptLTQwMzIgMGE1OS4xIDU5LjEgMCAxIDAgLjIgMTE4'
    b'LjIgNTkuMSA1OS4xIDAgMCAwLS4yLTExOC4yem00Mjk0LTMwNGMtNzU0LTkxLTE1MDYtMTMz'
    b'LTIyNjAtMTMzcy0xNTA5IDQxLTIyNjkgMTE1Yy0yNiA4LTIxIDkwIDE0IDg2IDc1Ni03MyAx'
    b'NTA3LTExMyAyMjU2LTExMyA3NDMgMCAxNDg1IDQwIDIyMjggMTI5IDM5IDQgNTQtODAgMzIt'
    b'ODR6Ii8+CiAgICAgICAgPHBhdGggZD0iTTIwMDMxOSA0ODQ5NWM3NjgtNzUgMTUzMC0xMTcg'
    b'MjI4OS0xMTYgNzU0IDAgMTUwNyA0MiAyMjYxIDEzM2wxMTEtMTg0Yy0zMiAxMC02MiA5LTkw'
    b'LTUtNzYtMzgtOTItMTYxLTM2LTI3NCA1Ni0xMTQgMTY0LTE3NSAyNDAtMTM4IDM5IDE5IDYy'
    b'IDYyIDY4IDExNGw0NDYtNzM5Yy0yMDQgMTMwLTMyOCAyMTQtNTgxIDI1Mi0yODEgNDEtNDA5'
    b'IDEzOS0zNjggMzA3IDM4IDE1Ni01NyAxMzMtMjAxIDU0LTMxNC0xNzEtNTQxIDcxLTY1MiAz'
    b'NTMtNzMgMTg2LTE1OSAxODEtMTY4LTEzLTQtNzAgMC0xMzEtNy0yMDAtMjEtMjIzLTg5LTI4'
    b'Ni0yMTYtMjI0LTE2MSA3OC0xNzUgMjUtMTM3LTU4IDI4LTYwIDg2LTEyOCA2Ni0yMjEtOS02'
    b'Ny02Ni05Mi0xNTEtOTgtMTgyLTI0NC00NjctNDgzLTY0OS03MjctMTgyIDI0NC0zNzQgNDgz'
    b'LTU1NiA3MjctODYgNS0xNDIgMzAtMTUyIDk4LTIwIDkzIDUyIDE1NyA4MCAyMTcgMzggODIg'
    b'MjMgMTM1LTEzNyA1Ny0xMjctNjEtMTg2LTMtMjA3IDIyMC03IDY5LTEwIDEzOS0xMyAyMDkt'
    b'OSAxOTQtOTUgMTk5LTE2OCAxMy0xMTEtMjgyLTM1Mi01MjQtNjY3LTM1My0xNDUgNzktMjAz'
    b'IDEwMi0xODItNTQgMjMtMTcyLTEwNy0yNjYtMzg4LTMwNy0yNTMtMzctMzc3LTEyMi01ODEt'
    b'MjUybDQxOSA2ODJjMTItMjUgMjktNDUgNTMtNTcgNzYtMzggMTg0IDI0IDI0MCAxMzggNTYg'
    b'MTEzIDQwIDIzNy0zNiAyNzQtMTAgNS0yMSA4LTMyIDEwbDEwMCAxNjN6bTQzODkgOTExYy03'
    b'IDMtNyA0LTI0IDExLTQ2IDE5LTgwIDY2LTEzNCAxMjQtNTcgNjAtMTI4IDEyNS0yMTEgMTg4'
    b'LTEyIDEwLTI1IDE5LTQ0LTZzLTctMzUgNi00NGM4MC02MiAxNDktMTI0IDIwNC0xODIgMzAt'
    b'MzIgNTYtNjMgNzctOTItOTUtMTEtMTkwLTIxLTI4NC0zMC03OSAyNC0xNTcgNTUtMjIyIDk1'
    b'LTU5IDM1LTEwNyA3Ny0xMzcgMTI1LTggMTQtMTYgMjctNDQgMTEtMjctMTYtMTktMzAtMTEt'
    b'NDQgMzUtNTggOTEtMTA3IDE1OC0xNDcgMzMtMjAgNjktMzggMTA2LTU0LTEwNy05LTIxNC0x'
    b'OC0zMjEtMjUtMjIgMTMtNDIgMjktNjEgNDctMjAgMTktMzkgNDItNTYgNjctOSAxMy0xOCAy'
    b'Ni00NCA4cy0xOC0zMS04LTQ0YzE5LTI5IDQxLTU0IDY0LTc3bDktOWMtODAtNS0xNjEtMTAt'
    b'MjQxLTE0LTIgMi01IDUtOCA3YTM0MC40IDM0MC40IDAgMCAwLTkzIDEyNmMtNiAxNS0xMiAy'
    b'OS00MSAxOC0yOS0xMi0yMy0yNi0xNy00MSAxMi0yOSAyNy01NSA0NS04MSA4LTExIDE4LTIy'
    b'IDI3LTMzLTExNS01LTIzMC05LTM0NC0xMi00IDUtOSA4LTE0IDExLTI1IDE1LTQ3IDMyLTY2'
    b'IDUxcy0zNSA0MC00OCA2M2MtOCAxNC0xNiAyOC00MyAxMi0yOC0xNi0yMC0yOS0xMi00MyAx'
    b'Ni0yOCAzNS01NCA1OS03NyA3LTcgMTQtMTMgMjEtMTktMTIyLTItMjQ0LTQtMzY1LTQtMTIw'
    b'IDAtMjQwIDEtMzYwIDMgOCA3IDE1IDEzIDIyIDIwIDIzIDIzIDQyIDQ5IDU5IDc3IDggMTQg'
    b'MTYgMjctMTIgNDNzLTM1IDItNDQtMTJjLTEzLTIzLTI5LTQ0LTQ4LTYzcy00MS0zNi02Ni01'
    b'MWMtNi0zLTEyLTctMTUtMTItMTE1IDItMjMwIDYtMzQ1IDExIDExIDExIDIwIDIzIDI5IDM1'
    b'IDE5IDI1IDMzIDUyIDQ1IDgxIDYgMTUgMTIgMjktMTcgNDFzLTM1LTMtNDEtMThjLTktMjQt'
    b'MjItNDYtMzgtNjctMTUtMjEtMzQtNDEtNTUtNTktNC0zLTctNi0xMC0xMC04MSA0LTE2MiA4'
    b'LTI0MyAxMyA0IDQgOSA4IDEzIDEyIDI0IDIzIDQ1IDQ4IDY0IDc3IDkgMTMgMTggMjYtOCA0'
    b'NHMtMzUgNS00NC04Yy0xOC0yNi0zNi00OC01Ni02N3MtNDEtMzUtNjQtNDljLTEtMS0zLTIt'
    b'NS0zLTExMCA3LTIyMCAxNC0zMzAgMjMgNDMgMTggODUgMzggMTIyIDYxIDY3IDQwIDEyNCA4'
    b'OSAxNTggMTQ3IDggMTQgMTYgMjctMTEgNDQtMjcgMTYtMzUgMy00NC0xMS0yOS00OC03OC05'
    b'MC0xMzctMTI1LTcyLTQ0LTE1OS03Ny0yNDYtMTAyaC0yYy05MCA3LTE3OSAxNS0yNjggMjQg'
    b'MjIgMzMgNTEgNjggODYgMTA2IDU1IDU4IDEyNCAxMjAgMjA0IDE4MiAxMyA5IDI1IDE5IDYg'
    b'NDRzLTMyIDE1LTQ0IDZjLTgzLTY0LTE1NS0xMjgtMjExLTE4OC0zNy0zOC05OS0xMTEtMTM1'
    b'LTE0MC0xOTYtOTAtMzU0LTEyNy01NzUtMTQ3LTE1My0xNC0zMTgtOS00NTgtNzkgMzYgODUg'
    b'NzUgMTY0IDEyNiAyMjkgNTMgNjggMTIwIDEyMSAyMDkgMTQ3IDggMiAyMSAxNiAyMiAyNSAy'
    b'OCAxNTcgODQgMjg2IDE2OSAzODYgNTIgNjAgMTE0IDExMCAxODggMTQ5LTc1LTgxLTEzMi0x'
    b'NjYtMTcyLTI1MS02Ny0xNDItOTAtMjg2LTc3LTQyMCAxLTE2IDMtMzIgMzQtMjkgMzIgMyAz'
    b'MCAxOSAyOSAzNS0xMSAxMjMgOSAyNTYgNzIgMzg3IDU2IDExOCAxNTkgMjM3IDI5MSAzNDYg'
    b'MjQgMTkgMCA2My0yOSA1NS0xNTQtNDQtMjkwLTEyMy0zODMtMjMxLTg5LTEwNC0xNDktMjM3'
    b'LTE4MC0zOTctOTQtMzItMTY1LTkwLTIyMi0xNjQtNDctNjAtODUtMTMxLTExOC0yMDUgMjgg'
    b'NDI4IDE4MiA4MDEgNDU2IDExMzcgNjEgNzUgMTY1IDE4MiAyNTUgMjE2IDkyIDM1IDk1IDEw'
    b'MC0yMCAxMDEtMzQgMS02OSAxLTEwNSAxIDg0IDMxIDE2NCA2NiAyMzMgMTA1IDEyNyA3MyAy'
    b'MTcgMTYyIDIyNCAyNzMgMSAxNiAyIDMyLTI5IDM0LTMyIDItMzMtMTQtMzQtMjktNi04Ni04'
    b'Mi0xNjAtMTkyLTIyMy0xMTMtNjUtMjU5LTExNy00MDItMTYwLTE1NCAwLTMxMi0xLTQ1OSAz'
    b'IDM5IDI4IDgwIDU3IDEzMSA4NCA4MiA0NCAxODggODYgMzQzIDEyMiA4OSAyMSAxNjYgNTIg'
    b'MjMzIDkxIDcxIDQyIDEzMCA5MyAxNzcgMTUwIDEwIDEyIDIwIDI1LTUgNDVzLTM0IDgtNDUt'
    b'NWMtNDItNTItOTUtOTgtMTU5LTEzNS02MS0zNi0xMzMtNjQtMjE2LTg0LTE2MS0zOC0yNzIt'
    b'ODEtMzU4LTEyOC03NS00MC0xMzEtODItMTg0LTEyMyAxODAgMzkzIDQ1MCA1NzMgODM1IDY4'
    b'OSAyMyA3IDQzIDEzIDYxIDE5IDMgMSA2IDEgOSAyIDg2IDIxIDE3NSA0MCAyNjYgNTUgOTIg'
    b'MTUgMTY2IDI4IDI2MSAzNyAxNiAxIDMyIDMgMjkgMzQtMyAzMi0xOSAzMC0zNCAyOS05OS05'
    b'LTE3NC0yMi0yNjYtMzgtNTgtMTAtMTE1LTIxLTE3MS0zMy0yNiA2LTY0IDktMTA3IDEyLTIz'
    b'MiAxNC00MjAgMjI1LTQzNSA0OTQgMCA1IDAgMTEtMSAxNiA4OC04MCAxNzktMTU3IDI3My0y'
    b'MTIgMTE3LTY4IDIzOS0xMDMgMzY0LTY5IDE1IDQgMzEgOCAyMiAzOS04IDMxLTIzIDI3LTM5'
    b'IDIyLTEwNi0yOC0yMTIgMy0zMTYgNjMtMTA4IDYzLTIxMyAxNTgtMzE1IDI1My0yNCAxNDct'
    b'ODIgMjg1LTIwNSAzNzcgNjEgMzQgMTA0IDY1IDE2MyA0NSA4Ni0zOSAxNzItNzggMjYxLTEw'
    b'OCA5MS0zMSAxODQtNTIgMjgyLTU3IDE2LTEgMzItMSAzMyAzMXMtMTQgMzItMzEgMzNjLTkx'
    b'IDQtMTc5IDI0LTI2NCA1My03NSAyNi0xNDkgNTgtMjIyIDkxIDIyMSA0NyA0NjAtMSA2Njct'
    b'NzkgNjAtMjIgMTA1LTQyIDEzMy00MSA1MS0zMCAxMTItNTMgMTcyLTc5IDY2LTI4IDEzMi01'
    b'MSAxODItNTcgMTYtMiAzMi00IDM1IDI4IDQgMzItMTIgMzMtMjggMzUtMTEyIDEzLTEyNyAy'
    b'MS0yMjIgNzkgMCAyMS02NiA1Ny0xMjYgOTYtMzYgMjQtNzAgNTItODcgNjctOTUgODYtMTQ0'
    b'IDE4MS0xODggMjg3LTI5IDcwLTUyIDE0NS02OCAyMjQgNTUtMTA4IDEyMS0yMTEgMjAxLTMw'
    b'MyA5NC0xMDggMjA4LTIwMSAzNDUtMjY1IDE0LTcgMjktMTMgNDIgMTUgMTMgMjktMSAzNS0x'
    b'NSA0Mi0xMjkgNjAtMjM2IDE0Ny0zMjQgMjUwLTkwIDEwMy0xNjEgMjIyLTIxOSAzNDUtMzEg'
    b'NjQtOCAxLTQyIDg2IDExMC0xMjIgMjEyLTIyNCAzMjMtMzA3IDEzMi0xMDAgMjgzLTE1NyA0'
    b'MTgtMTMzIDE1IDMgMzEgNiAyNiAzN3MtMjEgMjgtMzcgMjZjLTExNi0yMS0yNTAgMzItMzY5'
    b'IDEyMS0xMjEgOTItMjQ0IDIyMy0zNjYgMzYxIDE4NCAyNiAzNjYtMjYgNTQyLTg1IDkxLTMw'
    b'IDE4My0xMzUgMjM5LTE1MiAxOS0yNCAzOC00NiA1Ny02NyAzMy0zNyA2Ny03MSAxMDItMTAw'
    b'IDEyLTEwIDI0LTIwIDQ1IDRzOCAzNC00IDQ1Yy0zMyAyOC02NSA2MC05NiA5NC0zMiAzNS02'
    b'MiA3My05MiAxMTMtNiA4LTEzIDE3LTI0IDE2LTYwIDcwLTE1MSAxNjItMTcyIDI0MC01NyAy'
    b'MTAtMjUgMzcwLTEyMiA1NzYgNzEtMzggMTI4LTgxIDE3NS0xMzQgNTMtNjAgOTQtMTM1IDEy'
    b'OC0yMzAgMzctMTA0IDk1LTE5NSAxNjctMjcwIDc1LTc3IDE2NS0xMzYgMjYxLTE3MiAxNS01'
    b'IDMwLTExIDQxIDE5cy00IDM1LTE5IDQxYy04NyAzMi0xNjkgODYtMjM4IDE1Ny02NiA2OC0x'
    b'MTkgMTUxLTE1MyAyNDctMzcgMTAyLTgxIDE4My0xNDEgMjUwLTQ0IDUwLTk1IDkxLTE1NiAx'
    b'MjcgNTItMyA3OC0xMCAxMjEtNyA3OS02IDIxMS02NiAyNzktMTE5IDY2LTUxIDExNi0xMjAg'
    b'MTU0LTIwNiA2LTE1IDEzLTI5IDQyLTE2czIzIDI3IDE2IDQyYy00MiA5Ni05OSAxNzQtMTcz'
    b'IDIzMS01NiA0My0xMjEgNzUtMTk2IDkzIDE2MS01IDMxMS00MiA0NjctMTAwIDY1LTI0IDg3'
    b'LTE2OCAxMjctMjA4IDMyLTU4IDY2LTExMiAxMDUtMTU4IDQ3LTU2IDEwMS0xMDEgMTY0LTEy'
    b'NyAxNS02IDI5LTEyIDQxIDE4IDEyIDI5LTMgMzUtMTcgNDEtNTIgMjEtOTggNjAtMTM5IDEw'
    b'OC0zNiA0Mi02OCA5My05OCAxNDcgMTAgNzMtNTEgMjI4LTUzIDMwNS03IDIwNS0yIDQwOSA1'
    b'MyA2MTIgNTMtNzEgMTA3LTEzNCAxNjItMTkyIDAtNSAwLTEwIDEtMTUgMTgtMTA2IDMzLTIx'
    b'OSA0MC0zMzIgNy0xMTIgNy0yMjMtNi0zMjktMi0xNi00LTMyIDI3LTM1IDMyLTQgMzQgMTIg'
    b'MzUgMjggMTQgMTExIDE0IDIyNiA3IDM0MC02IDkwLTE2IDE4MC0zMCAyNjkgNTQtNTEgNTMt'
    b'NTEgNzctMTAzIDM3LTgwIDU5LTE1OSA2Ny0yMzcgOS04MCA1LTE1Ny0xMy0yMzAtNC0xNS03'
    b'LTMxIDI0LTM4czM1IDggMzggMjRjMTkgODAgMjUgMTY1IDE0IDI1Mi04IDY1LTI0IDEzMi00'
    b'OSAxOTkgNTYtNDIgMTE0LTgyIDE3OC0xMjItNC03NS01LTE1My0zLTIyNyAyLTY4IDctMTM0'
    b'IDE4LTE5MCA0LTIwIDctNDAgNDctMzNzMzcgMjcgMzMgNDhjLTkgNTAtMTQgMTExLTE2IDE3'
    b'Ny0yIDc4IDAgMTYyIDQgMjQzIDUgODIgNDkgMTg1IDEyNSAyMzAgMTAzIDYyIDE1OCAxNjMg'
    b'MTg2IDI3NCAxNi0xNDUgMTctMjgwIDMtNDAwLTE3LTE0My01NS0yNjctMTE0LTM2OC04LTE0'
    b'LTE2LTI3IDEyLTQ0IDI3LTE2IDM1LTIgNDMgMTIgNjMgMTEwIDEwNCAyNDEgMTIyIDM5MyAx'
    b'NyAxNDYgMTMgMzEwLTEzIDQ4OCAxMDItODIgMzgxLTI1OCAzNTItNTk0LTctMjctMTYtNTIt'
    b'MjgtNzUtNy0xNC0xNC0yOCAxNC00MnMzNSAwIDQyIDE0YzE3IDMzIDMwIDY5IDM5IDExMCA1'
    b'IDI0IDggNDkgMTEgNzYgMTMtNyA0NS00MyA1MS0zOSAyNCAxNiA1OCAzOCA4MCA1NC0yMS02'
    b'MC0zNS0xMjAtNDItMTc4LTEwLTg3LTUtMTcyIDE0LTI1MiA0LTE1IDctMzEgMzgtMjRzMjcg'
    b'MjMgMjQgMzhjLTE4IDczLTIyIDE1MS0xMyAyMzAgOSA3NyAzMSAxNTcgNjcgMjM3IDQgOCA4'
    b'IDE2IDUgMjUgMjQgMjEgNDcgNDIgNzAgNjUtMTMtODQtMjItMTcwLTI4LTI1NS04LTExNS03'
    b'LTIzMCA3LTM0MSAyLTE2IDQtMzIgMzUtMjhzMjkgMjAgMjcgMzVjLTEzIDEwNi0xMyAyMTct'
    b'NiAzMjkgNyAxMTMgMjIgMjI1IDQwIDMzMiAxIDIgMSA1IDEgNyA1NCA1OSA5NSAxMjAgMTUy'
    b'IDE5NiA1NS0yMDMgNzMtNDA3IDY2LTYxMi0yLTc2LTY5LTIyNy02NS0zMDItMzAtNTUtNjMt'
    b'MTA3LTEwMC0xNTEtNDEtNDktODctODctMTM5LTEwOC0xNS02LTI5LTEyLTE4LTQxIDEyLTI5'
    b'IDI3LTI0IDQxLTE4IDYyIDI2IDExNyA3MSAxNjQgMTI3IDM4IDQ1IDcyIDk4IDEwMyAxNTQg'
    b'NTcgNyA3OCAxNzkgMTQzIDIxMiAxNTQgNTcgMjk4IDk0IDQ1MyAxMDAtNzUtMTktMTQwLTUw'
    b'LTE5NS05My03NC01Ny0xMzEtMTM1LTE3My0yMzEtNi0xNS0xMy0yOSAxNi00MnMzNSAyIDQy'
    b'IDE2YzM4IDg2IDg4IDE1NiAxNTQgMjA2IDg1IDY2IDI4OSAxMjQgNDAwIDEyNy02MS0zNy0x'
    b'MTMtNzgtMTU3LTEyOC01OS02Ny0xMDQtMTQ4LTE0MS0yNTAtMzQtOTUtODctMTc5LTE1My0y'
    b'NDdhNjQyIDY0MiAwIDAgMC0yMzgtMTU3Yy0xNS02LTI5LTExLTE5LTQxIDExLTI5IDI2LTI0'
    b'IDQxLTE5IDk2IDM2IDE4NiA5NCAyNjEgMTcyIDcyIDc0IDEzMCAxNjYgMTY3IDI3MCAzNCA5'
    b'NSA3NSAxNjkgMTI4IDIzMCA0NyA1NCAxMDUgOTggMTc3IDEzNS05OC0yMDctNjYtMzY3LTEy'
    b'Mi01NzctMzUtMTI5LTIzMi0yNzctMTkzLTMyMCA0NS01MSAxMzMgODggMjQ4IDEyNyAxNzUg'
    b'NTkgMzU3IDExMSA1NDAgODUtMTIyLTEzOC0yNDQtMjY5LTM2Ni0zNjEtMTE5LTkwLTIzNy0x'
    b'NDAtMzUyLTEyMC0xNiAzLTMxIDYtMzctMjYtNS0zMSAxMC0zNCAyNi0zNyAxMzUtMjQgMjY5'
    b'IDMyIDQwMSAxMzIgMTExIDg0IDIwMSAxNzUgMzExIDI5OC0xOC00NyAwLTE0LTMwLTc3LTU5'
    b'LTEyMy0xMzAtMjQxLTIyMC0zNDUtODktMTAyLTE5Ni0xODktMzI0LTI1MC0xNC03LTI4LTEz'
    b'LTE1LTQyIDEzLTI4IDI4LTIyIDQyLTE1IDEzNyA2NSAyNTEgMTU3IDM0NSAyNjUgODEgOTMg'
    b'MTQ3IDE5OCAyMDMgMzA3LTE1LTgxLTM5LTE1Ny02OC0yMjctNDQtMTA2LTkzLTIwMS0xODgt'
    b'Mjg3LTYyLTU2LTIwOS0xNDAtMjA4LTE3OS0yOS0xNS0zMy0xMS02My0yNC02MS0yNi0xMjEt'
    b'NDYtMTY0LTUyLTE2LTItMzItNC0yOC0zNSA0LTMyIDE5LTMwIDM1LTI4IDUwIDYgMTE1IDI4'
    b'IDE4MiA1NiAzMyAxNCA2NiA0MyA5OCA2MCA1MyA0IDEzOSA0NyAyMDggNzQgMjA2IDc4IDQ0'
    b'NiAxMjYgNjY2IDc5LTczLTMzLTE0Ny02NS0yMjMtOTEtODUtMjktMTcyLTQ5LTI2NC01My0x'
    b'Ni0xLTMyLTEtMzEtMzNzMTctMzEgMzMtMzFjOTggNCAxOTEgMjYgMjgyIDU3IDg5IDMwIDE3'
    b'NSA2OSAyNjEgMTA4IDU5IDI3IDEwMS03IDE2My00NS0xMjMtOTItMTgxLTIzMC0yMDUtMzc2'
    b'bC0yLTJjLTEwMi05NS0yMDctMTkwLTMxNS0yNTMtMTA0LTYwLTIxMC05MS0zMTYtNjMtMTUg'
    b'NC0zMSA4LTM5LTIyLTgtMzEgNy0zNSAyMi0zOSAxMjUtMzMgMjQ3IDEgMzY0IDY5IDk0IDU1'
    b'IDE4NiAxMzIgMjc0IDIxMyAwLTYtMS0xMS0xLTE3LTE1LTI3MC0yMDMtNDgwLTQzNS00OTQt'
    b'NzgtNS0xODkgMjEtMTg2LTMyIDQtNTkgOTctNDQgMjM0LTg2IDM4NS0xMTYgNjU1LTI5NiA4'
    b'MzYtNjkwLTU0IDQxLTExMCA4My0xODYgMTI0LTg2IDQ3LTE5OCA5MS0zNTggMTI4LTgyIDE5'
    b'LTE1NCA0OC0yMTYgODQtNjQgMzgtMTE3IDg0LTE1OSAxMzUtMTAgMTItMjAgMjUtNDUgNXMt'
    b'MTQtMzItNS00NWM0Ny01NyAxMDYtMTA4IDE3Ny0xNTAgNjctMzkgMTQ1LTcwIDIzMy05MSAx'
    b'NTUtMzYgMjYxLTc4IDM0My0xMjIgNTEtMjcgOTItNTUgMTMxLTg0LTE0OC00LTMwNS0zLTQ1'
    b'OS0zLTE0MyA0NC0yODkgOTYtNDAyIDE2MC0xMTAgNjMtMTg2IDEzNi0xOTIgMjIzLTEgMTYt'
    b'MiAzMi0zNCAyOS0zMi0yLTMxLTE4LTI5LTM0IDgtMTExIDk3LTIwMCAyMjQtMjczIDY5LTM5'
    b'IDE0OS03NCAyMzMtMTA1LTM1IDAtNzAgMC0xMDQtMS0xMTYtMi0xMTItNjYtMjAtMTAxIDkw'
    b'LTM0IDE5MC0xNDEgMjUxLTIxNiAyNzEtMzM0IDQxMi03MTQgNDU2LTExMzAtMzMgNzItNjkg'
    b'MTQwLTExNSAxOTgtNTcgNzMtMTI4IDEzMS0yMjIgMTY0LTMxIDE2MC05MSAyOTMtMTgwIDM5'
    b'Ny05MiAxMDgtMjE2IDE4NS0zNjkgMjMwLTI5IDgtNTItMzUtMjktNTUgMTMyLTEwOSAyMjEt'
    b'MjI2IDI3OC0zNDQgNjItMTMxIDgzLTI2NCA3Mi0zODctMS0xNi0zLTMyIDI5LTM1IDMxLTMg'
    b'MzMgMTMgMzQgMjkgMTIgMTM0LTEwIDI3OC03OCA0MjAtNDAgODUtOTcgMTcwLTE3MiAyNTEg'
    b'NzMtMzkgMTM2LTg5IDE4Ny0xNDkgODUtMTAwIDE0MS0yMjkgMTcwLTM4NiAxLTggMTQtMjIg'
    b'MjItMjUgODktMjcgMTU1LTc5IDIwOS0xNDcgNTEtNjUgOTAtMTQzIDEyNi0yMjgtMTQwIDY5'
    b'LTMwNCA2NC00NTcgNzgtMjEzIDE5LTM2OSA2OC01NTQgMTUyeiIvPgogICAgICAgIDxwYXRo'
    b'IGQ9Ik0yMDQ2NDkgNDkyMzFjLTY4MC04OC0xMzU5LTExMy0yMDQxLTExNC02ODQgMC0xMzY5'
    b'IDQwLTIwNTggMTEyLTIwIDYtMTUgMzMtMTQgNDYgMiAyOCAzNyAzNSAxMjEgMjcgNjQzLTYw'
    b'IDEyODUtOTMgMTkzMi05MyA2NzQgMCAxMzUxIDIxIDIwMzggMTAyIDMzIDkgNzctODUgMjIt'
    b'ODF6Ii8+CiAgICAgICAgPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjAwNTcwIDQ5'
    b'MTYwYzY4My03MSAxMzYyLTExMCAyMDM4LTExMCA2NzUgMCAxMzQ5IDQwIDIwMjUgMTI3bDMx'
    b'LTEyN2MtMTcgOS0zNyAxNS01OCAxNWExMjMgMTIzIDAgMSAxIDExMy0xNzFsNjAtMTcwYy03'
    b'MjQtODQtMTQ0Ni0xMjItMjE3MS0xMjItNzI5IDAtMTQ1OSAzOC0yMTkzIDEwN2w1OCAxNjRj'
    b'MjItMzIgNTktNTQgMTAxLTU0YTEyMyAxMjMgMCAxIDEgMCAyNDZjLTEyIDAtMjUtMi0zNi02'
    b'bDMzIDk0LTIgN3ptMzA2Ny00MTZhMTIzIDEyMyAwIDEgMCAwIDI0NiAxMjMgMTIzIDAgMSAw'
    b'IDAtMjQ2em0wIDY0YTU5LjEgNTkuMSAwIDAgMCAwIDExOGMzMiAwIDU5LTI3IDU5LTU5cy0y'
    b'Ni01OS01OS01OXptLTEwODItOTFhMTIzIDEyMyAwIDEgMCAxMjMgMTIzYzAtNjgtNTUtMTIz'
    b'LTEyMy0xMjN6bTAgNjRhNTkuMSA1OS4xIDAgMSAwIC4yIDExOC4yIDU5LjEgNTkuMSAwIDAg'
    b'MC0uMi0xMTguMnptLTEwNjQtNDBhMTIzIDEyMyAwIDEgMC0uMiAyNDUuOCAxMjMgMTIzIDAg'
    b'MCAwIC4yLTI0NS44em0wIDY0Yy0zMyAwLTU5IDI2LTU5IDU5czI2IDU5IDU5IDU5YTU5LjEg'
    b'NTkuMSAwIDAgMCAwLTExOHoiLz4KICAgICAgPC9nPgogICAgICA8cGF0aCBkPSJNMjAyNjAx'
    b'IDQ3OTc0Yy0xNC02OC00OS0xMjktMTAwLTE3NS01MS00Ny0xMTYtNzgtMTg3LTg4LTMzLTQt'
    b'MzktNTgtNy02OCA2MC0yMCAxMTQtNjcgMTU3LTEzMyA0NS02OSA3OS0xNTcgOTUtMjU2IDUt'
    b'MzQgNjQtMzUgNjktMSAxNSA4NCA1MSAxNTMgOTcgMjA4IDU1IDY2IDEyNSAxMTIgMTkzIDEz'
    b'OCAzMSAxMiAyNSA2My04IDY4LTU5IDktMTA1IDQyLTE0MSA4Ny01MCA2Mi04MSAxNDUtMTAw'
    b'IDIyMS04IDMzLTYyIDMxLTY5LTJ6bTMzLTExOGMyMC01MiA0Ny0xMDMgODEtMTQ2IDI4LTM0'
    b'IDYwLTY0IDk5LTg0LTUxLTMwLTEwMC03MC0xNDMtMTIwLTI4LTM0LTUzLTczLTczLTExNi0x'
    b'OSA1OS00NSAxMTItNzUgMTU4LTMxIDQ3LTY3IDg2LTEwOCAxMTYgNTAgMTkgOTUgNDcgMTM0'
    b'IDgyIDM0IDMxIDYzIDY4IDg1IDExMHptNzk5IDUxMTUtNTE1IDIwNmMtMTcgNy0zNSAxNC00'
    b'OC0yMS0xNC0zNCA0LTQxIDIxLTQ4bDUxNS0yMDZjMTctNyAzNS0xNCA0OCAyMSAxNCAzNC00'
    b'IDQxLTIxIDQ4em01OS0zMjYtNjA0IDMyOGMtMTYgOS0zMyAxOC01MS0xNXMtMS00MiAxNS01'
    b'MWw2MDQtMzI4YzE2LTkgMzMtMTggNTEgMTVzMSA0Mi0xNSA1MXptLTE4MjYtNjUgNjA0IDMy'
    b'OGMxNiA5IDMzIDE4IDE1IDUxcy0zNCAyNC01MSAxNWwtNjA0LTMyOGMtMTYtOS0zMy0xOC0x'
    b'NS01MXMzNC0yNCA1MS0xNXptNTEgMzIyIDUxNSAyMDZjMTggNyAzNSAxNCAyMSA0OC0xNCAz'
    b'NS0zMSAyOC00OSAyMWwtNTE1LTIwNmMtMTctNy0zNC0xNC0yMS00OCAxNC0zNSAzMS0yOCA0'
    b'OC0yMXptMjI0IDQzNGMxMzcgMzMgMjYxIDQ4IDM1OCAzMSA4OC0xNiAxNTUtNjAgMTkxLTE0'
    b'NnYtNDkzYy0xMDctMS0yMTItMTUtMzAzLTQxLTEwOS0zMS0xNzAtOTgtMjAxLTE3OC00MS0x'
    b'MDctMjctMjM1LTQtMzI5IDUtMTggOS0zNiA0NS0yN3MzMiAyNyAyNyA0NWMtMjAgODItMzMg'
    b'MTk0IDEgMjg0IDIzIDYwIDY5IDExMCAxNTIgMTMzIDkxIDI1IDE5OCAzOCAzMDcgMzggMTA3'
    b'IDAgMjE0LTEzIDMwNC00MCA4Mi0yNCAxNDgtNjkgMTkyLTEyM3M2NS0xMTcgNTctMTc2Yy01'
    b'LTM2LTI0LTYyLTQ5LTgwLTM0LTI0LTgyLTM1LTEyOC0zNy00Ny0yLTk0IDctMTQyIDE2LTI1'
    b'IDUtNTAgOS03NyAxMy0xOSAyLTM3IDUtNDItMzJzMTQtNDAgMzItNDJjMjMtMyA0OC04IDcz'
    b'LTEyIDUyLTEwIDEwNS0yMCAxNTktMTggNjAgMiAxMjEgMTggMTY4IDUxIDQyIDI5IDcyIDcy'
    b'IDgwIDEzMSAxMSA4MC0xNiAxNjMtNzMgMjMzLTUzIDY1LTEzMSAxMTktMjI5IDE0Ny04MyAy'
    b'NC0xNzggMzgtMjc0IDQydjQ4M2MzIDUgMyAxMSAyIDE2IDM3IDgyIDEwMiAxMjUgMTg4IDE0'
    b'MSA5NyAxOCAyMjEgMiAzNTgtMzEgMTgtNSAzNi05IDQ1IDI3IDggMzctOSA0MS0yOCA0NS0x'
    b'NDYgMzUtMjc5IDUxLTM4OCAzMi05Mi0xNy0xNjUtNTgtMjE1LTEzMi00OSA3NC0xMjQgMTE1'
    b'LTIxNSAxMzItMTA5IDIwLTI0MiA0LTM4OC0zMi0xOC00LTM3LTgtMjgtNDUgOC0zNiAyNy0z'
    b'MiA0NS0yN3ptMzU2IDIxMCA0MDItOWMxOSAwIDM4LTEgMzggMzcgMSAzOC0xOCAzOC0zNyAz'
    b'OGwtNDAyIDljLTE5IDAtMzcgMS0zOC0zN3MxOC0zOCAzNy0zOHptNTkzLTMwODJjMTUxLTEy'
    b'NSAyOTMtMjI3IDQyMy0yOTcgMTMzLTcyIDI1NC0xMTEgMzU5LTEwNiAxOSAxIDM3IDEgMzYg'
    b'MzktMSAzNy0yMCAzNy0zOSAzNi05Mi00LTIwMCAzMi0zMjIgOTctMTI1IDY3LTI2MyAxNjYt'
    b'NDEwIDI4OS0xNCAxMi0yOSAyNC01My01cy05LTQxIDUtNTN6bS02MDUgNTZjLTE0MS0xMzAt'
    b'Mjk4LTI0MC00NDUtMzE0LTEzOS03MS0yNjgtMTA4LTM2My0xMDAtMTkgMi0zNyA0LTQwLTM0'
    b'LTQtMzcgMTUtMzkgMzQtNDAgMTEwLTEwIDI1MiAzMSA0MDQgMTA3IDE1MiA3NyAzMTUgMTkx'
    b'IDQ2MSAzMjUgMTQgMTMgMjggMjUgMiA1My0yNSAyNy0zOSAxNS01MyAyem0tMjEzIDEwMDRj'
    b'MzctODMgODMtMTU1IDEzNi0yMTkgNTMtNjMgMTEyLTExOSAxNzQtMTcwIDE0LTEyIDI5LTI0'
    b'IDUyIDUgMjQgMjkgOSA0MS01IDUzLTU5IDQ4LTExNCAxMDEtMTY0IDE2MC00OSA1OS05MSAx'
    b'MjUtMTI1IDIwMS04IDE3LTE1IDM0LTQ5IDE5cy0yNy0zMi0xOS00OXptMzcxLTE3MzRjNDkg'
    b'NjYgODggMTM5IDExNCAyMjMgMjYgODIgNDAgMTc1IDM5IDI3OSA1IDgwIDYgMTY1LTcgMjQ5'
    b'LTEzIDg2LTQyIDE3MC05NyAyNDYtNDMgNjAtMTAxIDk3LTE2NSAxMTMtNTMgMTMtMTA5IDEw'
    b'LTE2NC03IDI5IDEwMCA1MSAyMDggNiAzMDgtOCAxOC0zMyAyNy01MSAxOC00My0yMi04Ni00'
    b'My0xMjgtNjJzLTg0LTM2LTEyNy01MWwtMS0xYy05NS0zNy0xNzMtNzMtMjM2LTExMi02NS0z'
    b'OS0xMTUtODAtMTUwLTEyNGwxIDJjLTQ0LTQ5LTcyLTEwNi04OC0xNzAtMTQtNTUtMjAtMTE0'
    b'LTIyLTE3NC03Mi0zOS0xMzgtNzgtMTk0LTExNi02NC00My0xMTgtODctMTYxLTEzMS0xMy0x'
    b'NC0yNi0yNyAxLTUzczQwLTEyIDUzIDFjMzkgNDAgODkgODAgMTUwIDEyMSA2MCA0MCAxMjgg'
    b'ODEgMjA0IDEyMSAxMjQgMTMgMjQ3IDUxIDM3MCAxMDkgMTA2IDUwIDIxMSAxMTUgMzE3IDE5'
    b'MiAxMyA3IDE5IDE2IDI3IDIwIDggNiAxNiAxMyAyNSAxOSA1MSAyMiAxMDQgMjggMTUyIDE2'
    b'IDQ3LTExIDkwLTM5IDEyMi04NCA0OC02NiA3Mi0xMzkgODQtMjE0IDEyLTc3IDExLTE1NyA2'
    b'LTIzNHYtMmMxLTk3LTEyLTE4My0zNS0yNTgtMjQtNzYtNTgtMTQyLTEwMi0yMDEtMTEtMTUt'
    b'MjItMzAgNy01MnM0MS03IDUyIDd6bS0zNzUgMTA0N2MtMTA0LTc3LTIwNy0xNDEtMzExLTE5'
    b'MC0xMDUtNDktMjEwLTgzLTMxNC05OCAyIDQ4IDggOTMgMTggMTM1IDEzIDUyIDM1IDk5IDcx'
    b'IDEzOGwxIDFjMzAgMzcgNzMgNzIgMTMwIDEwNyA2MCAzNiAxMzQgNzEgMjI1IDEwNmwtMS0x'
    b'YzQ1IDE2IDg5IDM0IDEzMyA1NCAzMSAxNCA2MSAyOCA5MyA0NCAxOS04My0xMC0xNzktMzct'
    b'MjY3LTItOC01LTE1LTktMjl6bTc3Ni0xMDAzYy00NCA1OS03OSAxMjUtMTAyIDIwMS0yNCA3'
    b'Ni0zNiAxNjEtMzUgMjU4djJjLTUgNzctNiAxNTggNiAyMzQgMTIgNzUgMzcgMTQ4IDg0IDIx'
    b'NCAzMiA0NSA3NSA3MiAxMjIgODQgNDggMTIgMTAxIDYgMTUyLTE2bDI1LTE5YzYtNCAxMy0x'
    b'MiAyNy0yMCAxMDUtNzcgMjExLTE0MyAzMTctMTkyIDEyMy01OCAyNDYtOTUgMzcwLTEwOSA3'
    b'NS00MCAxNDQtODAgMjA0LTEyMXMxMTEtODEgMTQ5LTEyMWMxMy0xMyAyNi0yNyA1My0xczE0'
    b'IDM5IDAgNTNjLTQzIDQ0LTk3IDg4LTE2MSAxMzEtNTcgMzgtMTIyIDc3LTE5NCAxMTYtMiA2'
    b'MS04IDExOS0yMiAxNzQtMTYgNjMtNDQgMTIxLTg4IDE3MGwxLTJjLTM1IDQ0LTg1IDg1LTE1'
    b'MCAxMjQtNjMgMzgtMTQxIDc1LTIzNyAxMTJsLTEgMWMtNDMgMTUtODUgMzItMTI3IDUxLTQz'
    b'IDE5LTg1IDQwLTEyOCA2Mi0xOCA5LTQzIDAtNTEtMTgtNDUtMTAwLTIzLTIwOCA2LTMwOC01'
    b'NSAxOC0xMTEgMjAtMTY0IDctNjQtMTUtMTIyLTUzLTE2NS0xMTMtNTUtNzYtODQtMTYwLTk3'
    b'LTI0Ni0xMy04NS0xMi0xNjktNy0yNDktMS0xMDQgMTMtMTk2IDM5LTI3OSAyNi04NCA2NS0x'
    b'NTggMTE0LTIyMyAxMS0xNSAyMi0zMCA1Mi03IDMwIDIyIDE5IDM3IDcgNTJ6bTk0MCA3MTVj'
    b'LTEwNSAxNS0yMDkgNDktMzE0IDk4LTEwNCA0OS0yMDcgMTEzLTMxMSAxOTAtNCAxMy02IDIx'
    b'LTggMjktMjcgODgtNTYgMTg0LTM3IDI2NyAzMS0xNSA2Mi0zMCA5My00NCA0NC0yMCA4Ny0z'
    b'OCAxMzMtNTRsLTEgMWM5MS0zNSAxNjUtNzAgMjI1LTEwNiA1OC0zNCAxMDAtNzAgMTMxLTEw'
    b'N2wxLTFjMzUtMzkgNTctODYgNzEtMTM4IDExLTQyIDE2LTg3IDE5LTEzNXoiLz4KICAgICAg'
    b'PHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjAzNDU5IDUwNjAyYTIxNi40IDIxNi40'
    b'IDAgMCAwIDAgNDMzIDIxNi42IDIxNi42IDAgMCAwIDAtNDMzem0wIDY5Yy04MSAwLTE0NyA2'
    b'Ni0xNDcgMTQ3czY2IDE0NyAxNDcgMTQ3IDE0Ny02NiAxNDctMTQ3LTY2LTE0Ny0xNDctMTQ3'
    b'em0wIDYwYTg3IDg3IDAgMSAwIC4xIDE3NC4xIDg3IDg3IDAgMCAwLS4xLTE3NC4xem0tMTY5'
    b'Ny0xMjRjMTE5IDAgMjE3IDk3IDIxNyAyMTZzLTk3IDIxNy0yMTcgMjE3YTIxNi42IDIxNi42'
    b'IDAgMCAxIDAtNDMzem0wIDY5YzgxIDAgMTQ3IDY2IDE0NyAxNDdzLTY2IDE0Ny0xNDcgMTQ3'
    b'LTE0Ny02Ni0xNDctMTQ3IDY2LTE0NyAxNDctMTQ3em0wIDYwYTg3IDg3IDAgMSAxLS4xIDE3'
    b'NC4xIDg3IDg3IDAgMCAxIC4xLTE3NC4xeiIvPgogICAgPC9nPgogICAgPHVzZSB4bGluazpo'
    b'cmVmPSIjaHItYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3Rh'
    b'dGUoLTIuMiAtNTU1MzIuOCAxNTYyNzUuOCkiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2hy'
    b'LWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0icm90YXRlKDIuMiA0'
    b'NTk4NjUuOCAxNTYyNzUuOCkiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iIzE3MTc5NiIgZD0i'
    b'bTM4Ny4yIDk0LjktMTkuMy0yMi0yNS4yIDE0LjUtNC4zIDUxLjFhMjE5LjcgMjE5LjcgMCAw'
    b'IDEgMzYuMiA2TDM4Ny4yIDk1eiIvPgogIDxwYXRoIGQ9Ik0zNDcuNyA5OGMuOC0uMiAxLjct'
    b'LjIgMi42LjMuMy4xLjYuMy44LjYuNC0uMy43LS42IDEuMi0uOGE0IDQgMCAwIDEgMS44LTFj'
    b'LjktLjUgMS44LS44IDIuNy0uOWgyLjhjLjggMCAxLjYuMiAyLjMuNmwyIDFjLjguNCAxLjUu'
    b'OCAyLjIgMWE5LjEgOS4xIDAgMCAwIDQuNS41Yy40LS4yLjcuMS4yLjQtMy4zIDItNS45LjIt'
    b'OC4xLS42YTE2LjIgMTYuMiAwIDAgMSAyLjEgMS43Yy44LjggMS44IDEuNiAzLjUgMi40YTgu'
    b'NCA4LjQgMCAwIDAgNSAuN2wuNC4xLS4xLjVhNC44IDQuOCAwIDAgMS0yLjYuNyAxMCAxMCAw'
    b'IDAgMS01LjItMS4zYy0xLjQtLjctMi4zLTEuNi0zLjMtMi40YTcuNSA3LjUgMCAwIDAtMy0x'
    b'LjQgNiA2IDAgMCAwLTIuOSAwYy4zLjEuNS4yLjYuNC41LjMgMSAuNCAyIC41LjQgMCAuMi4z'
    b'LS41LjdhMiAyIDAgMCAxLTEuNi44Yy0xIC42LTEuMy4yLTEuNy0uMiAwIC4zIDAgLjUtLjIu'
    b'OGEuNi42IDAgMCAxIDAgLjRsLjIuN2MwIC4yIDAgLjMuMi40LjIuMi4zLjQuMy43IDAgLjIu'
    b'MS4zLjMuNGwuNi42Yy42LjIuOC43IDEgMS4yLjQuMi42LjUuNy45LjIgMCAuNC4yLjYuNGwy'
    b'LjYuMWMuOC4xIDEuNC42IDIgMS4yaDEuMmE0IDQgMCAwIDEgMS4zLS4zaDIuM2MuNS4yLjku'
    b'NCAxLjIuOC41LjUgMS4yLjQgMS44LjJhMi43IDIuNyAwIDAgMSAyLjQgMCAyLjMgMi4zIDAg'
    b'MCAxIDEtLjJjLjQtLjMuNy0uNCAxLS40LjYgMCAxIDAgLjkuOCAwIC4yLS4yLjQtLjMuNC0u'
    b'My42LS43LjctMS4zLjctLjEuNC0uMy43LS41LjguMy45IDAgMS4zLS43IDEuMiAwIC4zLS4z'
    b'LjQtLjYuNGExLjQgMS40IDAgMCAxLTEgLjVsLjQuNmMuNC43LS4yIDEtLjggMXYxLjJjLjcu'
    b'NC44LjguMiAxLjIuNC43LjMgMS4zLS41IDEuNiAwIC40IDAgLjgtLjMgMS0uMi4yLS41LjMt'
    b'LjMuNi4zLjUuMiAxLjEtLjIgMS4ybC0uMi4xLS4yLjJhOS42IDkuNiAwIDAgMC0xLjUgMWMt'
    b'LjEgMC0uMi4xLS4yIDBhOS42IDkuNiAwIDAgMS0xLjggMi40YzAgLjUtLjQgMS0xIDEuMWEu'
    b'NC40IDAgMCAxLS4zLjRjLjMuMy41LjYuMiAxYTMgMyAwIDAgMS0xLjMuOGMtMSAuMy0xLjcu'
    b'Mi0yLS4yLS40LS4zLS4zLS42IDAtLjctLjcgMC0uOC0uMi0uOC0uNyAwLS4yLjEtLjIuMy0u'
    b'MS40IDAgLjctLjIgMS0uM2wuNS0uNmMwLS43LjUtMSAxLjEtMS4zLjUtLjIgMS0uNiAxLjQt'
    b'MS4ybC45LTEuNWExLjIgMS4yIDAgMCAxLS4zLS43IDEuNSAxLjUgMCAwIDEtLjUtLjZjLS41'
    b'IDAtLjctLjItLjctLjVhMS4xIDEuMSAwIDAgMS0uMyAwYy0uMy4xLS41LjMtLjcuMmE2Ljkg'
    b'Ni45IDAgMCAxLTEuMSAxYy0uMi4zLS40LjUtLjcuNS0xIC4xLTEuNSAxLjItMiAxLjctLjIu'
    b'MS0uMy40LS40LjcgMCAuNi0uMSAxLS40IDFoLS40YTEuMiAxLjIgMCAwIDAtLjQgMGMuMy4z'
    b'LjMuNiAwIC45LS4xLjMtLjQuNC0uOC40YTMuNiAzLjYgMCAwIDEtMS42LS4yYy0uNC0uMi0u'
    b'NS0uNS0uNS0uNy0uMy0uMi0uNC0uMy0uMy0uNSAwLS4yLjItLjMuNC0uMmwuNi0uMmE1LjIg'
    b'NS4yIDAgMCAxIDEuOC0xLjQgMyAzIDAgMCAxIC43LS43YzAtLjUuNS0xIDEtMS40bC4xLS42'
    b'di0uM2MtLjItLjMtLjMtLjctLjEtMWExLjMgMS4zIDAgMCAxIDAtLjZjLTEuMS42LTEuNS40'
    b'LTEuNi0uMS0uNC4zLS44LjUtMSAwLS40LjEtLjguMy0xLjIuMWwtLjguMi0uNC43YzAgLjUt'
    b'LjIgMS0uNSAxLjVhOS4zIDkuMyAwIDAgMS0uNyAxLjUgMSAxIDAgMCAxLS4xLjVjMCAuNi0u'
    b'Mi45LS41IDFhMi40IDIuNCAwIDAgMS0uNC44di4yYy4xLjMuMS43LS4yIDFsLTEgLjZoLTFj'
    b'LS40LS4zLS40LS40LS4zLS42YS42LjYgMCAwIDEtLjUgMGwtLjQtLjNjLS4xLS4yLS4xLS40'
    b'LjEtLjVsLjktLjZjMC0uMi4yLS4zLjQtLjQuMi0uNC40LS42LjYtLjdsLjctMS41Yy4xLS4x'
    b'LjItLjMuMS0uNGwuMS0uM3MuMi0uMSAwLS4yYTEuNCAxLjQgMCAwIDEgLjItMS4yYy4zLS40'
    b'LjYtMS40LjMtMnYtLjhoLS4zYy0uMi0uMi0uNCAwLS42LjJsLS40LjZjLS4xLjgtLjUgMS41'
    b'LTEgMS42djEuMmMwIC40IDAgLjctLjIuN3MtLjQuMi0uNS41YTEgMSAwIDAgMC0uMS4zYy4z'
    b'LjMuMi43LS4xIDEtLjYuNi0xLjQuNS0yLjIuMy0uNi0uMy0uOC0uNS0uNy0uOC0uOCAwLS43'
    b'LS43IDAtLjkuOC0uMiAxLjQtLjcgMS45LTEuNCAwLS44LjItMS4zLjctMS40IDAtLjUuMi0x'
    b'IC40LTEuNC4yLS40LjMtLjguMi0xLjMtLjQtLjMtLjQtLjYgMC0xIC4xIDAgLjEgMCAwLS4y'
    b'LS4zIDAtLjMtLjMtLjMtLjVzMC0uMi0uMi0uMmMtLjYtLjEtLjUtLjQtLjItLjcuMSAwIC4y'
    b'LS4zIDAtLjRsLS4xLS40Yy0uNC0uMy0uMi0uNiAwLS45bC0uNC0uOGMtLjcgMC0xLS40LS42'
    b'LS45YTMuNCAzLjQgMCAwIDEgLjctLjZjLjEtLjMuMy0uNi4yLS44LS4yLS42LjUtMSAxLTEu'
    b'NGEuOS45IDAgMCAxLS4xLS40Yy0uMy0uMy0uMi0uNi4xLS44YTEgMSAwIDAgMS0uMS0uNWMt'
    b'LjguMi0uOC0uMy0uNC0xLS41LS4zLS40LS44LjUtMS41YTEgMSAwIDAgMSAwLS40IDIgMiAw'
    b'IDAgMC0xIC4zYy0uMy4zLS42LjItLjkuMWExLjUgMS41IDAgMCAwLS40LS40LjYuNiAwIDAg'
    b'MS0uMi0uNmMtMSAwLTEuMS0uNy0uNi0xIC4zLS4zLjYtLjYuNy0uOS4yLS42LjctMSAxLjMt'
    b'MS41di0uNWExLjYgMS42IDAgMCAwLS43LS4zIDEuMiAxLjIgMCAwIDAtLjYtLjdjLS4xIDAt'
    b'LjItLjIgMC0uNC0uNi0uNC0uNS0uNy0uMy0xeiIvPgogIDxnIGZpbGw9IiNmN2RiMTciPgog'
    b'ICAgPHBhdGggZD0iTTM2NC41IDEyMmExLjQgMS40IDAgMCAxLS4yIDAgOC40IDguNCAwIDAg'
    b'MS0uOC43Yy0uMi0uMy0uNSAwLS4yLjFsLS4yLjJjMCAuMy0uMi40LS41LjRoLS4xYTMgMyAw'
    b'IDAgMSAwLS4zIDMuNSAzLjUgMCAwIDEgMC0uNCAzLjkgMy45IDAgMCAwLS4xLjQgMi44IDIu'
    b'OCAwIDAgMCAwIC40Yy0uOC4zLTEuMyAxLjEtMS45IDEuN2wtLjQuOGMwIC4yIDAgLjktLjMu'
    b'OWgtLjJjMC0uMS0uMi0uMS0uNCAwaC0xYy0uMi4yLjQuMi43LjMuMS4xLjIuMy4xLjUtLjIu'
    b'Ny0xLjguNS0yLjMuMi0uMi0uMS0uMi0uMy0uMi0uNWguM2MuMiAwIC40IDAgLjUtLjIgMCAw'
    b'IC4xIDAgMC0uMSAwLS4xIDAtLjEgMCAwYTEuMyAxLjMgMCAwIDEtLjUgMCAyLjYgMi42IDAg'
    b'MCAxLS41IDBoLS4yYzAtLjEuMiAwIC4yIDBsLjctLjNhNS4zIDUuMyAwIDAgMSAxLjktMS40'
    b'bC44LS43YzAtLjcuNC0xIC44LTEuNWwuMy0uN3YtLjNjLS4yLS40LS4zLS43LS4xLTFhMS41'
    b'IDEuNSAwIDAgMSAwLS44LjMuMyAwIDAgMCAwLS4xIDYuMiA2LjIgMCAwIDEgLjgtLjZ2Ljhh'
    b'MS4zIDEuMyAwIDAgMC0uMi4zLjUuNSAwIDAgMCAwIC4ydi4xYS40LjQgMCAwIDEgMC0uM2wu'
    b'My0uMi43LS40LjctLjZ2MWwtLjYuN3YuMWguMWEyLjMgMi4zIDAgMCAxIC41LS43IDMuMiAz'
    b'LjIgMCAwIDEgMS0uNnYxYTEuNSAxLjUgMCAwIDAgLjUuOXoiLz4KICAgIDxwYXRoIGQ9Im0z'
    b'NDkgMTEzIC4yLS4yLjQtLjZhNCA0IDAgMCAxIC41LS42IDQgNCAwIDAgMC0uNC43IDUuOCA1'
    b'LjggMCAwIDAtLjQuNXYuMmMuMS4zLjEuNS4zLjdsLjMtLjRhMS42IDEuNiAwIDAgMSAuNC0u'
    b'NCAxLjggMS44IDAgMCAwIC41LS42aC4xbC0uMi40YTIgMiAwIDAgMS0uMy4zbC0uNC4zYTEu'
    b'MyAxLjMgMCAwIDAtLjIuNHYuM2MtLjIuMy0uNS41IDAgLjdhLjYuNiAwIDAgMCAuMS41bC0u'
    b'MS43Yy0uMy4yIDAgLjIuMS4ybC40LS40YTQuMyA0LjMgMCAwIDEgLjMtLjRsLjQtLjUuMS0u'
    b'NWguMWExLjQgMS40IDAgMCAxLS4xLjYgMiAyIDAgMCAxLS41LjUgMy44IDMuOCAwIDAgMC0u'
    b'Mi40IDIuNiAyLjYgMCAwIDAtLjMuNGMuMi4xLjIuNC4yLjdoLjFsLjItLjIuMi0uNGguMWwt'
    b'LjIuNC0uMi4zYy4yLjEuMi4zIDAgLjUtLjQuMy0uMy40IDAgLjd2MS4ybC4xLjNoLS4xdi0u'
    b'M2MtLjQuNy0uNiAxLjEtLjcgMS44LS42LjEtLjUuOC0uNiAxLjNhMy45IDMuOSAwIDAgMS0x'
    b'LjkgMS41Yy0uMSAwLS41LjEtLjUuMyAwIC4xLjIuMy40LjIuNC0uNS43LS4yLjIuMnYuM2Mu'
    b'NS40IDEuNi41IDIuMi4yLjMtLjMuNS0uNS4yLS45IDAtLjUuMi0xIC44LTEuMnYtLjRsLjEt'
    b'MS4zLjItLjFjLjIgMCAuNi0uNy43LTEuM3YtLjRjLjEtLjIuMi0uMi4zIDAgMC0uMiAwLS4z'
    b'LjItLjQuMi0uMy41LS42LjgtLjRhMyAzIDAgMCAxLS4xLS44IDIuNyAyLjcgMCAwIDEgMC0x'
    b'bC4yLS4yLjMtLjcuMy0uN2guMWwtLjMuNy0uMy44di4xYTIuNSAyLjUgMCAwIDAtLjEgMWwu'
    b'Mi45LjIuNHYuNmMuNC42IDAgMS43LS4zIDIuMmExIDEgMCAwIDAtLjEuOGMuMi4yIDAgLjQt'
    b'LjEuNnYuMWMwIC4yIDAgLjQtLjIuNWwtLjcgMS42Yy0uNC4xLS41LjMtLjYuNy0uMy4xLS4z'
    b'LjItLjQuNGEyLjcgMi43IDAgMCAxLS45LjZjLS4zLjEgMCAuMi4yLjQuMi4xLjQtLjIuNi0u'
    b'NC4yLS4zLjMtLjIuMiAwYTIgMiAwIDAgMC0uMi43bC43LjNjLjQgMCAuOS0uNCAxLjItLjYu'
    b'My0uMi4yLS41LjEtLjhhMiAyIDAgMCAxLS41IDAgMy40IDMuNCAwIDAgMS0uNS0uMyAyLjgg'
    b'Mi44IDAgMCAwIDEgLjJ2LS4zYTIuNyAyLjcgMCAwIDAgLjUtLjhjLjQtLjIuNC0uNC40LS45'
    b'bC4xLS41YTEwIDEwIDAgMCAwIC43LTEuNmMuNC0uNC41LS45LjUtMS40IDAtLjIuMS0uMy4z'
    b'LS4zYTMuOCAzLjggMCAwIDAgLjMtLjVsLjEtLjRhLjguOCAwIDAgMSAuMi0uMiAxIDEgMCAw'
    b'IDAgMC0uNSAxLjEgMS4xIDAgMCAwLS4xLS40LjUuNSAwIDAgMS0uMS0uMnYtLjJoLjFjLjEg'
    b'MCAwIDAgMCAwdi4xYS41LjUgMCAwIDAgMCAuMmMuMi4yLjIuMy4yLjVhMSAxIDAgMCAxIDAg'
    b'LjUuNy43IDAgMCAwLS4yLjIgMS43IDEuNyAwIDAgMCAwIC4zbC42LS4xLjQtLjUuMi0uNmMu'
    b'MSAwIDAgMCAwIDBhMiAyIDAgMCAxLS4xLjdsLS4zLjNjLjQuMi43IDAgMSAwVjExOWwuNC0u'
    b'N2MuMSAwIC4xIDAgMCAwbC0uMi44djFjLjEuNC4yLjUuNS4zbC40LS4ydi0uMWExOC4yIDE4'
    b'LjIgMCAwIDEgMS44LTEuNmMuMS4xIDAgLjEgMCAuMWE2LjUgNi41IDAgMCAwLS44LjdsLS44'
    b'Ljd2LjNjMCAuMy4xLjUuNi4zbC42LS4yYTEuMyAxLjMgMCAwIDEgLjMtLjIgOCA4IDAgMCAx'
    b'IC41LS4zbC41LS4zYTMgMyAwIDAgMSAuMS0uNmwuNy0xLjNhMi4zIDIuMyAwIDAgMCAxLjEt'
    b'MS4xaC4xbC0uNC43YTIuNSAyLjUgMCAwIDEtLjcuNWwtLjcgMS4yYTIuNyAyLjcgMCAwIDAt'
    b'LjEuNXYuMWEyLjggMi44IDAgMCAwIDAgLjhjLjIgMCAuNCAwIC43LS4zbC43LS43YTEuNyAx'
    b'LjcgMCAwIDEgLjItLjUgMSAxIDAgMCAxIC40LS40aC4xdi4xYS45LjkgMCAwIDAtLjQuMyAx'
    b'LjcgMS43IDAgMCAwLS4yLjV2MS4xbDEtLjV2MWMwIC4zLjIuNi40LjhhMi44IDIuOCAwIDAg'
    b'MSAuNS0uNmwuMy0uMy4yLS4yLjMtLjItLjIuMy0uMi4yLS4zLjJ2LjVoLjZjMCAuNSAwIC42'
    b'LjUuNmEzLjIgMy4yIDAgMCAxIDAtLjVsLjEtLjVoLjFhMS45IDEuOSAwIDAgMC0uMS41IDMu'
    b'MSAzLjEgMCAwIDAgMCAuNWMuMi4zLjMuNC43LjZsLjItLjVhMS40IDEuNCAwIDAgMCAwLS40'
    b'aC4xdi41bC0uMy41di41YTMgMyAwIDAgMSAuMi0uM2wuMy0uNGMuMSAwIC4xIDAgMCAwIDAg'
    b'LjIgMCAuMy0uMi40YTQgNCAwIDAgMC0uMi40bC4yLjJjLS42IDEtMS4zIDIuNS0yLjUgMy0u'
    b'Ni4yLS45LjUtMSAxLjJhMSAxIDAgMCAwLS41LjZsLTEuMi4zYzAgLjMgMCAuNC4zLjRsLjct'
    b'LjNjLjEgMCAwIC41LS41Ljh2LjFjLjQuNiAxLjQuNCAxLjkuMi40IDAgMS0uNSAxLjItLjku'
    b'MS0uMiAwLS40LS4yLS42LS44LjEtLjYtLjYgMC0uMy4yIDAgLjMgMCAuMy0uMy42LS4yLjkt'
    b'LjUgMS0xIC42LS43IDEuMi0xLjQgMS42LTIuMS4xLS4yLjItLjQuMS0uNWExIDEgMCAwIDAg'
    b'LjItLjVsLjEtLjRoLjF2LjVhNC41IDQuNSAwIDAgMS0uMi4zYzAgLjEgMCAuMi4yLjJsMS41'
    b'LTFjMC0uMy4yLS40LjQtLjRsLjItLjFjLjEtLjQgMC0uNi0uMi0uOC0uMS0uNC4xLS41LjQt'
    b'LjcuMi0uMi4yLS43LjItMXYtLjJhMi42IDIuNiAwIDAgMCAwLS4zbC4xLjN2LjFjLjMtLjEu'
    b'Ni0uMy43LS42IDAtLjMtLjEtLjYtLjMtLjhhOS42IDkuNiAwIDAgMS0uNi4yIDEwLjIgMTAu'
    b'MiAwIDAgMCAuNy0uNCAxLjMgMS4zIDAgMCAwIC4zLS4yYy4yLS4zLS4zLS41LS41LS42bC0u'
    b'Ny0uN3YtLjFsLjcuNnYtMS4xbC0uMi0uNGExLjEgMS4xIDAgMCAxLS41LS40IDEgMSAwIDAg'
    b'MS0uMS0uNWwuMi40LjQuNGgxYy4zLS4zLS4yLS43LS4zLS45bC0uMS0uNWguMWExIDEgMCAw'
    b'IDAtLjItLjIuNi42IDAgMCAwLS4xIDB2LS4yYS43LjcgMCAwIDEgLjIuMWwuMi4yYS45Ljkg'
    b'MCAwIDAgLjEgMGMuMyAwIC41LS4yLjctLjVhMy42IDMuNiAwIDAgMC0uMy0uNCAxMCAxMCAw'
    b'IDAgMC0uNS0uM3YtLjFoLjFhNCA0IDAgMCAxIC44LjhjLjQgMCAuNCAwIC42LS4zYTEuNSAx'
    b'LjUgMCAwIDAtLjItLjQgMi41IDIuNSAwIDAgMC0uMy0uNGMwLS4xIDAgMCAwIDAgLjIgMCAu'
    b'My4yLjQuM2wuMi41LjQtLjFjLjMtLjIgMC0uOCAwLTFhMi44IDIuOCAwIDAgMC0uMSAwbC0u'
    b'Mi0uMmMwLS4xIDAgMCAwIDBoLjJsLjIuMS40LS42YzAtLjQgMC0uMi41LS4zLjQgMCAuNiAw'
    b'IC45LS42LjEgMCAuMiAwIC4yLS4zczAtLjQtLjMtLjRjLS41IDAtLjggMC0xIC4zdi4zYzAg'
    b'LjEgMCAwIDAgMGwtLjItLjJjLS40IDAtLjcgMC0xLjEuMmgtLjJsLjIuMy4xLjRhMSAxIDAg'
    b'MCAwLS4yLS40IDEuOCAxLjggMCAwIDAtLjMtLjQgMi42IDIuNiAwIDAgMC0xLS4ybC4yLjEu'
    b'Mi4ydi4xYTcuNyA3LjcgMCAwIDEtLjItLjIgNi41IDYuNSAwIDAgMS0uMi0uMiAyLjcgMi43'
    b'IDAgMCAwLS45LjJsLS42LjIuNC41LjIuNmEyLjEgMi4xIDAgMCAwLS4zLS42IDEuOSAxLjkg'
    b'MCAwIDAtLjQtLjQgMS44IDEuOCAwIDAgMS0uNSAwbC4yLjMtLjMtLjRhMS40IDEuNCAwIDAg'
    b'MS0uNS0uMiA4LjMgOC4zIDAgMCAxIC4yIDEuNSA3LjggNy44IDAgMCAwLS4yLS45IDQuNyA0'
    b'LjcgMCAwIDAtLjEtLjcgMS43IDEuNyAwIDAgMS0uMi0uMiAyLjEgMi4xIDAgMCAwLS42LS40'
    b'IDEgMSAwIDAgMS0uMi43Yy0uMSAwIDAgMCAwIDBhLjguOCAwIDAgMCAuMS0uOCAzLjEgMy4x'
    b'IDAgMCAwLTEtLjIgNS4zIDUuMyAwIDAgMSAuNS44bC4zLjV2LjVhMiAyIDAgMCAwLS4xLS41'
    b'LjcuNyAwIDAgMC0uMy0uNCA1LjYgNS42IDAgMCAwLS4zLS41IDQuNiA0LjYgMCAwIDAtLjMt'
    b'LjRoLS40LjFhLjYuNiAwIDAgMSAwIC4zLjUuNSAwIDAgMCAwLS4yLjcuNyAwIDAgMC0uMi0u'
    b'MWgtLjhhNSA1IDAgMCAxIDEgMi4zIDQuOCA0LjggMCAwIDAtLjQtMS4yIDUuMSA1LjEgMCAw'
    b'IDAtLjctMWgtLjZhMS43IDEuNyAwIDAgMSAuNC40YzAgLjEgMCAuMSAwIDBhMS42IDEuNiAw'
    b'IDAgMC0uMy0uMSAyLjQgMi40IDAgMCAwLS4zLS4yIDUgNSAwIDAgMC0uMyAwbC0uMS4xYTQu'
    b'NyA0LjcgMCAwIDEgMSAxLjFjMCAuMSAwIDAgMCAwYTMuOCAzLjggMCAwIDAtLjYtLjYgNC43'
    b'IDQuNyAwIDAgMC0uNi0uNGgtLjZhNSA1IDAgMCAxIC41IDEuN2gtLjFhMy41IDMuNSAwIDAg'
    b'MC0uMi0uOCA2LjIgNi4yIDAgMCAwLS4zLS45IDggOCAwIDAgMS0uNCAwIDkuMSA5LjEgMCAw'
    b'IDEgLjMgMS42di4xYTkuMyA5LjMgMCAwIDAtLjItMSA5LjMgOS4zIDAgMCAwLS4zLS44IDMu'
    b'OSAzLjkgMCAwIDAtMS4zLTEgMS43IDEuNyAwIDAgMSAuNCAxLjF2LjFhMS42IDEuNiAwIDAg'
    b'MC0uMi0uNyAxLjcgMS43IDAgMCAwLS40LS42IDIgMiAwIDAgMC0uMyAwIDE1LjYgMTUuNiAw'
    b'IDAgMC0xIDBjLjIuMS40LjQuNC42IDAtLjItLjMtLjUtLjYtLjdoLS42bC4zLjMuMi41LjIu'
    b'Ni40LjRzLjEgMCAwIDBjMCAuMSAwIC4xIDAgMGExLjEgMS4xIDAgMCAxLS41LS4zIDEuNSAx'
    b'LjUgMCAwIDEtLjItLjcgMS4zIDEuMyAwIDAgMC0uMi0uNCAyLjcgMi43IDAgMCAwLS4zLS40'
    b'aC0uN2wuMi44LjEgMWgtLjFhNy4xIDcuMSAwIDAgMCAwLTEgNC41IDQuNSAwIDAgMC0uMy0u'
    b'OCAxIDEgMCAwIDAtLjYtLjUuNi42IDAgMCAxIDAgLjNoLS4xYS41LjUgMCAwIDAgMC0uM2Mt'
    b'LjItLjUtLjMtLjctLjYtLjh2LjRsLS4yLjRoLS4xbC4xLS41di0uNGMwLS42LS4yLTEtLjgt'
    b'MS4ydi4ybC0uMS41aC0uMXYtLjVhMS45IDEuOSAwIDAgMCAwLS4zbC0uNS0uNWEyLjMgMi4z'
    b'IDAgMCAxIDAgLjcgMyAzIDAgMCAxLS40LjhoLS4xYTMgMyAwIDAgMCAuMy0uOCAyLjIgMi4y'
    b'IDAgMCAwIC4xLS44IDEgMSAwIDAgMS0uMi0uM3YuMmgtLjF2LS4ybC4xLS4xdi0uMWEuNy43'
    b'IDAgMCAwLS4zLS41IDEuNSAxLjUgMCAwIDEtLjIuNWgtLjFjLS4xIDAgMCAwIDAgMGwuMS0u'
    b'My4xLS4zYTEgMSAwIDAgMS0uMS0uMi44LjggMCAwIDEtLjEuMiAxLjIgMS4yIDAgMCAxLS4y'
    b'LjJjLS4xLS4xIDAtLjEgMC0uMWwuMS0uMmEuNy43IDAgMCAwIC4xLS4ydi0uMmMwLS4zIDAt'
    b'LjQtLjItLjdhLjkuOSAwIDAgMC0uMyAwIDIuOCAyLjggMCAwIDAtLjUuNHYtLjFhMy4yIDMu'
    b'MiAwIDAgMSAuNC0uMy45LjkgMCAwIDEgLjQtLjEuNC40IDAgMCAwIDAtLjJsLTEgLjNhMS42'
    b'IDEuNiAwIDAgMS0uOS0uMmguOGMuMyAwIC43IDAgMS4xLS4ybC4yLS42YTEuNyAxLjcgMCAw'
    b'IDEtLjUgMGwuNi0uMXYtLjJjMC0uMi4zLS4yLjQgMCAuMiAwIC4zLjIuNC4zLjMuMi42IDAg'
    b'LjktLjJoLS4ydi0uMWguM2MuNiAwIDEgMCAxLjQtLjVhNyA3IDAgMCAxLTEgMGMtLjIgMC0u'
    b'NCAwLS42LS4ybC43LjFoMWwuNS0uM2E1LjQgNS40IDAgMCAxLTItLjYgMS40IDEuNCAwIDAg'
    b'MC0uNi0uM2MtLjUgMC0xIDAtMS40LjNsLS4zLS4zLS40LS4yaC0uNnMtLjEgMCAwIDBoMS4y'
    b'YTQuNSA0LjUgMCAwIDEgMS43LS4zIDUuNyA1LjcgMCAwIDEgMS43LS4ydi0uMmMuMy0uMy40'
    b'LS42LjMtLjktLjEtLjItLjQtLjUtLjgtLjdoLTEuM2E0IDQgMCAwIDAtLjguMWwuNi40LjQg'
    b'MXYuMWgtLjJhMiAyIDAgMCAwLS40LTFjLS4xLS4yLS42LS4zLS43LS40bC0xLjMuMi0uNy40'
    b'Yy4zLS4xLjYgMCAuOCAwIC4zLjIuNS40LjYuOHYuMWgtLjJhMSAxIDAgMCAwLS41LS43Yy0u'
    b'NC0uMi0xLjIgMC0xLjYuM2E0LjIgNC4yIDAgMCAwLS42LjZoLS4ydi0uMmwuNy0uNi43LS40'
    b'YTIgMiAwIDAgMSAxLS41bDEuMy0uMmExIDEgMCAwIDAtLjUtLjUgMS40IDEuNCAwIDAgMC0u'
    b'OCAwYy0uNS4xLTEgLjQtMS41LjdoLjVsLjEuMmgtLjVhMS40IDEuNCAwIDAgMC0uNCAwbC0x'
    b'LjUgMS4yYy0uNSAwLS44IDAtMSAuMmwtLjEuNi0uMi43Yy0uNS41LTEgLjktMS4zIDEuNWEx'
    b'LjQgMS40IDAgMCAxLS4zLjUuNS41IDAgMCAxIC4zLjF2LS4ybC4yLS40aC4xYTEuMiAxLjIg'
    b'MCAwIDAtLjEuNHYuNWgtLjJhLjMuMyAwIDAgMC0uMS0uMi41LjUgMCAwIDAtLjMgMGwtLjMu'
    b'Mi0uMi4zYzAgLjMuMi4zLjUuMy42IDAgLjEuNC40LjdsLjUuNGguNWMwLS40IDAtLjYuMi0u'
    b'NmEuOC44IDAgMCAxIC4yLS40LjguOCAwIDAgMCAwIC4yLjguOCAwIDAgMC0uMS4ydi40YTIu'
    b'NCAyLjQgMCAwIDEgMS0uMmMuNy0uOCAxLS42LjQgMGwtLjEuMmExLjQgMS40IDAgMCAwLS4y'
    b'LjZjLS4yLjEtMSAuOC0uNyAxIC4yIDAgLjQgMCAuMy4yLS4xLjItLjQuNi0uMy45aC4zYTYu'
    b'MiA2LjIgMCAwIDAgLjctLjYgMy44IDMuOCAwIDAgMCAuNS0uOGguMWE5IDkgMCAwIDEgLjMt'
    b'LjhjMC0uMi4xLS41LjMtLjdsLjMuM2EuNC40IDAgMCAwIC4yIDAgLjQuNCAwIDAgMCAuMyAw'
    b'bC4yLS4zaC4xYTEuMiAxLjIgMCAwIDEtLjMuNC41LjUgMCAwIDEtLjMgMCAuNS41IDAgMCAx'
    b'LS4yIDAgMS4xIDEuMSAwIDAgMS0uMy0uMyAxMiAxMiAwIDAgMC0uNSAxLjR2LjFhNS42IDUu'
    b'NiAwIDAgMS0xLjIgMS40bC4yLjUgMS0xIC44LTFhNiA2IDAgMCAxLS4zLjZ2MS4xaC0uMXYt'
    b'LjlsLS4zLjNhMTEuNiAxMS42IDAgMCAxLTEgMWMtLjMuMy0uNi4zLS4yLjdsLjMtLjMuNC0u'
    b'M2guMXYuMWwtLjQuMy0uNC4zYS42LjYgMCAwIDAgLjEuMy41LjUgMCAwIDEgLjEgMGwuOC0u'
    b'NmMuMSAwIDAgLjEgMCAuMWwtLjcuNmEuNy43IDAgMCAxLS4xIDBjLS4zLjMtMS4yLjgtMSAx'
    b'LjJsLjYtLjIuNi0uNWMuMSAwIDAgMCAwIC4xYTIuNSAyLjUgMCAwIDEtLjYuNXYuMi0uMWEz'
    b'LjYgMy42IDAgMCAxLS43LjFjLjEuNCAwIC43LS4zIDEgMCAuMS0xIC45LS42IDFhMSAxIDAg'
    b'MCAwIC4zLjJ6Ii8+CiAgICA8cGF0aCBkPSJNMzQ5LjQgMTAwLjFhMi4yIDIuMiAwIDAgMC0u'
    b'Ni0uMyAxLjQgMS40IDAgMCAwLS41LS41Yy0uMi0uMi0uMi0uMS0uMS0uM2wuMi0uMWEuOS45'
    b'IDAgMCAxIC4zIDAgLjQuNCAwIDAgMSAuMi4yaC4xYy4xIDAgMCAwIDAgMGEuNS41IDAgMCAw'
    b'LS4yLS4yIDEgMSAwIDAgMC0uNC0uMS43LjcgMCAwIDAtLjQgMGwtLjItLjUuNC4xLjIuMWEu'
    b'Ny43IDAgMCAwLS4yLS4yIDIgMiAwIDAgMC0uMiAwIDIuOSAyLjkgMCAwIDEgMi4xLjJjLjQu'
    b'MS42LjMuOC42bC0uMi4yYy0uNSAwLS44IDAtMSAuMi0uMi4xLS4yLjQtLjIuNnoiLz4KICA8'
    b'L2c+CiAgPHBhdGggZD0ibTM2NSAxMjEuOC0uNC4yYzAtLjMuMi0uNC4zLS42di4ybC4xLjJ6'
    b'bTIgNC4yYTIuMyAyLjMgMCAwIDEtLjQuNCA0IDQgMCAwIDEtLjUuNHYtLjFsLjQtLjQuNC0u'
    b'NHptMS4zLTEuNi0uMi4zaC0uMWwuMi0uM3ptLS43IDBhMS4xIDEuMSAwIDAgMS0uMi4zIDEg'
    b'MSAwIDAgMS0uNS40di0uMWExIDEgMCAwIDAgLjQtLjMgMSAxIDAgMCAwIC4xLS40aC4xem0x'
    b'LjItMS42YTEgMSAwIDAgMC0uMS4yIDEuMSAxLjEgMCAwIDAtLjEuMmgtLjFhMS4xIDEuMSAw'
    b'IDAgMSAuMy0uNXptMSAwdi41bC0uMy41Yy0uMSAwIDAgMCAwIDBsLjEtLjUuMi0uNXptLS40'
    b'LTZjLjMuNS40IDEgLjQgMS41YTcuMyA3LjMgMCAwIDEgLjEtLjYgMS40IDEuNCAwIDAgMCAu'
    b'My0xLjFjMC0uMS4xIDAgLjEgMHYuNmExLjcgMS43IDAgMCAxLS4zLjZsLS4yIDFoLS4xdi0u'
    b'MWMwLS42IDAtMS4yLS40LTEuOHYtLjF6bS0uOCAxdi4zaC0uMXYtLjRoLjF6bS0uMiAxLjRh'
    b'Ni4yIDYuMiAwIDAgMSAuMiAxLjQgMSAxIDAgMCAxIC4xLS4xbC4zLS4zaC4xYTEgMSAwIDAg'
    b'MC0uMy4zLjcuNyAwIDAgMC0uMi40IDUgNSAwIDAgMC0uMS0uOSA1LjkgNS45IDAgMCAwLS4y'
    b'LS44em0xIC41YTMuNiAzLjYgMCAwIDEgLjEgMS4ydi0uNmEzLjYgMy42IDAgMCAwLS4xLS42'
    b'em0xLS4ydi42YTEuNSAxLjUgMCAwIDEgMCAuNSAxLjIgMS4yIDAgMCAwIDAgLjZsLjEuNmEy'
    b'LjUgMi41IDAgMCAxLS4zLS42IDEuMyAxLjMgMCAwIDEgMC0uNiAxLjQgMS40IDAgMCAwIC4y'
    b'LS41IDIuMyAyLjMgMCAwIDAgMC0uNnptLjUtMS41LS4xLjN2LjJoLS4xdi0uNmguMXptLS41'
    b'LTIuNnYuMmMuMSAwIC4xIDAgMCAwIDAgLjEgMCAwIDAgMHYtLjJzLS4xIDAgMCAwYzAtLjEg'
    b'MCAwIDAgMHptLjItMnYuOGEuOC44IDAgMCAwLS4yLjMgMS40IDEuNCAwIDAgMCAwIC42aC0u'
    b'MWExLjQgMS40IDAgMCAxIDAtLjYuOS45IDAgMCAxIC4zLS40di0uN3ptLTItLjdjLjQuMi42'
    b'LjQuOC43LjIuMi4zLjUuMy45bC0uNi0uMnYxLjhjLS4yLjUtLjUuOC0xIDFhMy44IDMuOCAw'
    b'IDAgMCAwLTEuOGguMWEzLjYgMy42IDAgMCAxIDAgMS42IDEuNSAxLjUgMCAwIDAgLjctLjgg'
    b'My43IDMuNyAwIDAgMCAuMS0xLjlsLjYuMmMwLS4zLS4xLS41LS4zLS44YTIuNSAyLjUgMCAw'
    b'IDAtLjctLjZ2LS4xem01LjItMXYuMmgtLjF2LS4yczAtLjEgMCAwaC4xem0tMS4yIDAgLjMu'
    b'MWEuOC44IDAgMCAxIC4xLjJ2LjFhLjguOCAwIDAgMC0uMi0uMi42LjYgMCAwIDAtLjItLjJ6'
    b'bS0xLjguNS4zLjV2LjZjLS4xIDAtLjEgMCAwIDBsLS4xLS42YTEgMSAwIDAgMC0uMy0uNWgu'
    b'MXptLTYgLjV2LjRsLS4xLjF2LS41em0xLS42LjIuNHYuMWgtLjF2LS4xbC0uMS0uM3ptMi40'
    b'IDEuNnYuMWExLjEgMS4xIDAgMCAxIDAgLjIuOC44IDAgMCAwIDAtLjIuNi42IDAgMCAwLS4x'
    b'IDB2LS4xem0uOC0xLjh2LjJhLjIuMiAwIDAgMSAwIC4yLjEuMSAwIDAgMCAwLS4yYy0uMS0u'
    b'MS0uMS0uMSAwLS4xem0tNS41LjNhMSAxIDAgMCAwIC4yLjdjLjIuMS4yLjMuMy40di40aC0u'
    b'MXYtLjRhLjkuOSAwIDAgMC0uMi0uMyAxIDEgMCAwIDEtLjItLjQgMS4xIDEuMSAwIDAgMS0u'
    b'MS0uNHptMi4yIDEuNS4yLjd2LjdjMCAuMyAwIC42LjIuOGwuNi43YTIuOSAyLjkgMCAwIDEt'
    b'LjEtMWwuMy0xYy4yIDAgLjItLjIuMy0uM3YtLjRoLjF2LjRhMS41IDEuNSAwIDAgMS0uMy41'
    b'IDEuNiAxLjYgMCAwIDAtLjMuOWMwIC4zIDAgLjYuMiAxaC0uMWMtLjQtLjItLjYtLjUtLjgt'
    b'LjhhMS4zIDEuMyAwIDAgMS0uMi0uOHYtLjdhMS44IDEuOCAwIDAgMC0uMi0uNmMwLS4xLjEg'
    b'MCAuMSAwem0tLjkgMS40YzAgLjIgMCAuNS0uMi43YTMuNCAzLjQgMCAwIDEtLjQuNmguM2Ey'
    b'LjIgMi4yIDAgMCAwIC43LS42bC4zLS4zYy4xIDAgMCAwIDAgMGEzLjYgMy42IDAgMCAxLS4y'
    b'LjQgMi41IDIuNSAwIDAgMS0uMy4yIDI0LjUgMjQuNSAwIDAgMSAwIC40di0uMmExLjUgMS41'
    b'IDAgMCAwLS4xLS4xIDIuMiAyLjIgMCAwIDEtLjQuMmwtLjQuMnYtLjFsLjQtLjcuMi0uN2gu'
    b'MXptLTEgMHYuMWgtLjFjLS4xIDAgMCAwIDAgMHYtLjJ6Ii8+CiAgPHBhdGggZD0iTTM2MyAx'
    b'MTMuN2MuMi4zLjIuNi4yIDFhMS45IDEuOSAwIDAgMS0uNC44IDEuOSAxLjkgMCAwIDAtLjUu'
    b'NiAyLjYgMi42IDAgMCAwLS4yLjZsLjItLjMuNS0uM2E0LjYgNC42IDAgMCAwIDEuMS0uOWgu'
    b'MWMuMSAwIDAgMCAwIDBhNCA0IDAgMCAxLTEuMiAxIDEgMSAwIDAgMC0uNC4zIDIuMyAyLjMg'
    b'MCAwIDAtLjQuNWMwLS40IDAtLjcuMi0xbC41LS42LjQtLjhjMC0uMyAwLS42LS4yLS45aC4x'
    b'em0yLjMgMy41LjEuNC4xLjFjLjIuMy4zLjUuMy44bC0uMSAxaC0uMWExLjggMS44IDAgMCAw'
    b'LS40LTEgMy40IDMuNCAwIDAgMC0uOC0uNnYtLjFjLjQuMi43LjQuOS43bC4zLjZhMy40IDMu'
    b'NCAwIDAgMCAwLS42IDEuMyAxLjMgMCAwIDAtLjEtLjdsLS4xLS4yYy0uMi0uMi0uMy0uMy0u'
    b'Mi0uNHptMSAwIC4xLjJjMCAuMSAwIDAgMCAwaC0uMWwtLjItLjJoLjF6bTEgLjMtLjIuNy0u'
    b'Mi43LjItLjcuMi0uN3ptLjcgNHYuMWEuMy4zIDAgMCAxIDAtLjJ6bS0uNy0xLjJ2LjNsLS4y'
    b'LjR2LS40bC4xLS40aC4xem0tMSAwaC4xdi4xaC0uMXYtLjF6bS0xLjEtLjZhNy4zIDcuMyAw'
    b'IDAgMS0uMS4ydi4yaC0uMWE1IDUgMCAwIDEgMC0uMiA1IDUgMCAwIDEgMC0uMmguMWMuMSAw'
    b'IDAgMCAwIDB6bS0xLjcgMS44YS43LjcgMCAwIDAtLjEuMiAxLjMgMS4zIDAgMCAwIDAgLjJz'
    b'LS4xLjEtLjIgMHYtLjJhLjguOCAwIDAgMSAuMi0uM2guMXptLTQuOCA0LjZhLjcuNyAwIDAg'
    b'MSAwIC4yIDEuMSAxLjEgMCAwIDEtLjIuMWMtLjEgMC0uMSAwIDAgMGEuOC44IDAgMCAwIC4x'
    b'LS4zaC4xem0uOC0uNGEuMy4zIDAgMCAxLS4xLjIuNi42IDAgMCAxLS4yIDAgLjQuNCAwIDAg'
    b'MCAuMS0uMS4zLjMgMCAwIDAgMC0uMWguMnptMS0uNmEuNS41IDAgMCAxIDAgLjEuNS41IDAg'
    b'MCAxLS4yLjEuNC40IDAgMCAwIDAtLjJoLjJ6bTEuNS0zLjgtLjEuNGExLjQgMS40IDAgMCAw'
    b'IDAgLjRoLS4xYTEuNCAxLjQgMCAwIDEgMC0uNHYtLjVoLjF6bTEtMTAuM2EuOS45IDAgMCAx'
    b'LS4xLjMgMS40IDEuNCAwIDAgMS0uMi4zaC0uMWwuMi0uM2EuOC44IDAgMCAwIDAtLjNsLjEt'
    b'LjF6bS0xLTFhMS45IDEuOSAwIDAgMSAuMSAxIDEuOCAxLjggMCAwIDAgMC0uNSAxLjUgMS41'
    b'IDAgMCAwLS4yLS40YzAtLjEgMCAwIDAgMHptLTEuNCAxLjdhMS41IDEuNSAwIDAgMS0uNC0u'
    b'NC43LjcgMCAwIDEtLjEtLjRsLjIuNC4zLjR6bTEuNSAyLjZ2LjJoLS4xdi0uMnptLTItMiAu'
    b'NiAxIC4xLjhjLjIgMCAuMy0uMS40LS4zdi0uOWExLjkgMS45IDAgMCAwIC4zLS42IDMuNSAz'
    b'LjUgMCAwIDAgLjEtLjVoLjFsLjQuOC4zLjloLS4xYTIuOSAyLjkgMCAwIDAtLjMtLjkgMy45'
    b'IDMuOSAwIDAgMC0uMy0uNiAyLjkgMi45IDAgMCAxIDAgLjQgMiAyIDAgMCAxLS4zLjVsLS4x'
    b'IDEtLjQuM3YuNGgtLjFjMC0uNCAwLS44LS4yLTEuMmEyIDIgMCAwIDAtLjUtMXptMS4yIDV2'
    b'LjNsLS4xLjRoLS4xdi0uOGguMWMuMSAwIC4xIDAgMCAwem0tMi4yLjl2LjNsLS4xLS4zYzAt'
    b'LjEuMSAwIC4xIDB6bTEuOS0yLjVhMi4zIDIuMyAwIDAgMS0uMi42bC0uMy41YTEuMSAxLjEg'
    b'MCAwIDAtLjMuNiAxLjggMS44IDAgMCAwIDAgLjdjMCAuMSAwIDAgMCAwYTEuOSAxLjkgMCAw'
    b'IDEtLjEtLjdjMC0uMi4xLS41LjMtLjdhMi4xIDIuMSAwIDAgMCAuMy0uNSAyLjEgMi4xIDAg'
    b'MCAwIC4yLS42Yy4xIDAgMCAwIDAgMHptLS41LS44di42YTIuMiAyLjIgMCAwIDEtLjUuNiAx'
    b'LjggMS44IDAgMCAwLS40LjVsLS4yLjVoLS4xbC4yLS42LjUtLjVhMiAyIDAgMCAwIC4zLS41'
    b'IDEgMSAwIDAgMCAuMS0uNmguMXptLTIuNCAxLjJjMCAuNCAwIC43LS4yIDEtLjEuMy0uMy42'
    b'LS42LjhoLS4xdi0uMWMuMy0uMi41LS41LjYtLjguMi0uMi4yLS42LjItMXptLTMgMS43di4y'
    b'bC4xLjF2LjFoLS4xbC0uMS0uMnYtLjJzLS4xIDAgMCAwem0tMS4zIDBhMi43IDIuNyAwIDAg'
    b'MCAwIC43bC40LjYuMS41di40bC40LS41YTEuNCAxLjQgMCAwIDAgLjItLjYgMS42IDEuNiAw'
    b'IDAgMSAwIC42bC0uNS42aC0uMWEzLjMgMy4zIDAgMCAwIDAtLjUgMS44IDEuOCAwIDAgMC0u'
    b'Mi0uNCAyIDIgMCAwIDEtLjMtLjcgMi43IDIuNyAwIDAgMS0uMS0uN3ptLjIgNC4yYTIuNiAy'
    b'LjYgMCAwIDEgLjEtLjhoLjFhMi41IDIuNSAwIDAgMC0uMS44aC0uMXptLS4yIDEuMXYtLjRz'
    b'MC0uMS4xIDB2LjR6bS0uOCAyIC4yLS4zLjItLjNoLjFhNCA0IDAgMCAxLS4yLjRsLS4yLjJj'
    b'LS4xIDAtLjEgMCAwIDB6bS0xLjEtNi42di4yaC0uMXYtLjJ6bS0yIDQuNWEyLjkgMi45IDAg'
    b'MCAwIDAtLjF2LS4yaC4xdi4zem01LTgtLjMgMWMwIC4zLjEuNi4zLjcuMy4yLjQuNC41Ljd2'
    b'LS40Yy4xLS4xLjEtLjMgMC0uNGguMWEyLjcgMi43IDAgMCAxIDAgMWgtLjFhNiA2IDAgMCAx'
    b'IDAtLjJsLS41LS42Yy0uMy0uMi0uNC0uNC0uNC0uOGwuMi0xaC4xem0tLjQtMS4zYTIuNSAy'
    b'LjUgMCAwIDEgMCAuOCA0IDQgMCAwIDEtLjMuNyAyLjQgMi40IDAgMCAwLS4yIDFjMCAuNC4x'
    b'LjcuMyAxdi4xYTIuNSAyLjUgMCAwIDEtLjItMi4xIDMuOCAzLjggMCAwIDAgLjItLjdjMC0u'
    b'My4xLS41IDAtLjhoLjFjLjEgMCAwIDAgMCAwem0tMi4zIDMuM2EuOC44IDAgMCAwIDAgLjRs'
    b'LjEuNWMwIC4xIDAgMCAwIDBhMS41IDEuNSAwIDAgMS0uMy0uNS45LjkgMCAwIDEgLjEtLjVo'
    b'LjF6bS0xLS40di4zYS45LjkgMCAwIDEgMCAuMy40LjQgMCAwIDAtLjEuM2wuMS4ydi4xYS44'
    b'LjggMCAwIDEtLjItLjMuNS41IDAgMCAxIDAtLjQuOC44IDAgMCAwIC4xLS4ydi0uM2guMXpt'
    b'NS44LTguNmEyLjMgMi4zIDAgMCAwIC4zIDEuNSAyLjYgMi42IDAgMCAxLS40LS43IDIuMyAy'
    b'LjMgMCAwIDEgMC0uOGguMXptLS43LjdhNCA0IDAgMCAxIC41IDEuN2gtLjFhMy44IDMuOCAw'
    b'IDAgMC0uNS0xLjZ2LS4xem0tMy42LjFjLS40LjUtLjUgMS0uNiAxLjNsLjIuOS4yLjhhMi42'
    b'IDIuNiAwIDAgMS0uMi44Yy0uMSAwIDAgMCAwIDB2LS44YTIuMyAyLjMgMCAwIDAgMC0uOCAx'
    b'LjcgMS43IDAgMCAxLS4zLTFjMC0uMy4yLS43LjYtMS4yLjEgMCAwIDAgMCAwem0zLjMtMS40'
    b'di41bC0uNC40YS44LjggMCAwIDAtLjMuNHYuN2MwIC4xIDAgMCAwIDBhMS45IDEuOSAwIDAg'
    b'MSAwLS43IDEgMSAwIDAgMSAuMy0uNSAxIDEgMCAwIDAgLjMtLjQuNi42IDAgMCAwIDAtLjRo'
    b'LjF6bS0zLjUuM3YuN2MwIC4yLS4yLjQtLjQuNmExLjIgMS4yIDAgMCAwLS40LjYgMi45IDIu'
    b'OSAwIDAgMC0uMS43aC0uMWEzIDMgMCAwIDEgLjEtLjhjMC0uMi4yLS40LjQtLjZsLjQtLjZh'
    b'MSAxIDAgMCAwIDAtLjZ6bTIgLjFhLjguOCAwIDAgMCAwIC4yLjUuNSAwIDAgMCAuMS4zLjYu'
    b'NiAwIDAgMS0uMi0uMi44LjggMCAwIDEgMC0uM2guMXptMC0uNWEuOC44IDAgMCAwLS41LjRs'
    b'LS4yLjcuMi41di43YTIuNCAyLjQgMCAwIDAgMC0uN2wtLjMtLjRhMiAyIDAgMCAwLS41IDEu'
    b'MmMwIC41LjEgMSAuNSAxLjVoLS4xYTIuNyAyLjcgMCAwIDEtLjUtMS41YzAtLjUuMi0uOS42'
    b'LTEuMyAwLS4zIDAtLjYuMi0uOGExIDEgMCAwIDEgLjUtLjR6bS0uNy0uOHYuMWMwIC4zIDAg'
    b'LjYtLjIuN2EuOC44IDAgMCAwLS4yLjMgMS42IDEuNiAwIDAgMC0uMS40aC0uMWExLjcgMS43'
    b'IDAgMCAxIDAtLjQgMSAxIDAgMCAxIC4zLS40Yy4yLS4xLjItLjQuMi0uNmEyLjcgMi43IDAg'
    b'MCAwIDAtLjFoLjF6bTUuNyA2IC4xLjV2LjRhMS40IDEuNCAwIDAgMCAwLS40IDEuOSAxLjkg'
    b'MCAwIDAtLjItLjRoLjF6bTAgMnYuNmwtLjIuNi0uMy42LjItLjZhMi4xIDIuMSAwIDAgMCAu'
    b'Mi0uNiAxLjYgMS42IDAgMCAwIDAtLjdoLjF6bS0xLjItMS44YTIuNSAyLjUgMCAwIDEgLjcg'
    b'Mi41aC0uMWEyLjQgMi40IDAgMCAwLS42LTIuNHYtLjFjMC0uMSAwIDAgMCAwem0wIDJhNS4z'
    b'IDUuMyAwIDAgMS0xIDEuNCAyLjUgMi41IDAgMCAwLS41IDEgMS40IDEuNCAwIDAgMC0uMS0u'
    b'NiAxLjkgMS45IDAgMCAwLS4yLS40IDEuNCAxLjQgMCAwIDEtLjMtLjlsLjMtLjguMy0uNmEy'
    b'LjQgMi40IDAgMCAwIDAtLjZoLjFjLjEgMCAwIDAgMCAwYTIuNiAyLjYgMCAwIDEtLjMgMS4z'
    b'IDEgMSAwIDAgMC0uMy43YzAgLjMgMCAuNi4yLjhhMiAyIDAgMCAxIC4zLjggMi42IDIuNiAw'
    b'IDAgMSAuNS0uOCA1IDUgMCAwIDAgLjUtLjZsLjMtLjdoLjF6bS0zLjItMWEyLjggMi44IDAg'
    b'MCAwIC40IDEuNHYuMWgtLjFhMi4zIDIuMyAwIDAgMS0uMy0uNyAzIDMgMCAwIDEgMC0uN3pt'
    b'LTEuNyAxdi4zaC0uMXYtLjN6bS42LTEuNi0uMS41YTEuNCAxLjQgMCAwIDEtLjMuNWMtLjEg'
    b'MCAwIDAgMCAwbC4yLS41YTEuNCAxLjQgMCAwIDAgMC0uNWguMXptLTEuNiAzLjFhMy4zIDMu'
    b'MyAwIDAgMS0uMy0xLjdjMC0uNS4zLS44LjYtMWwuNC0uN2MuMS0uMi4yLS41LjEtMXMuMSAw'
    b'IC4xIDB2MWwtLjYuN2ExLjkgMS45IDAgMCAwLS41IDFjMCAuNSAwIDEgLjMgMS43aC0uMXpt'
    b'LTEtMS4xYS43LjcgMCAwIDAgMCAuM2wuMS40YTEgMSAwIDAgMS0uMi0uNC44LjggMCAwIDEg'
    b'MC0uNGguMXptNC42LTMuMmMuMS4yLjMuNS4zLjggMCAuMyAwIC42LS4yLjloLS4xYy0uMSAw'
    b'IDAgMCAwIDBsLjItLjlhMS41IDEuNSAwIDAgMC0uMy0uOHptMS40LTEuMWEyLjQgMi40IDAg'
    b'MCAxIDAgMS43IDEuOCAxLjggMCAwIDAtLjItLjggMS41IDEuNSAwIDAgMC0uNS0uNWMwLS4x'
    b'IDAtLjEuMSAwYTEuNiAxLjYgMCAwIDEgLjYgMXYtLjZhMi4zIDIuMyAwIDAgMC0uMS0uOHpt'
    b'LjgtMS4yLjQuOHYxYTIgMiAwIDAgMCAwIC41IDEgMSAwIDAgMCAuMi40IDEgMSAwIDAgMS0u'
    b'Mi0uNCAyLjMgMi4zIDAgMCAxIDAtLjUgMy41IDMuNSAwIDAgMC0uMS0xIDEuNSAxLjUgMCAw'
    b'IDAtLjQtLjdjMC0uMSAwIDAgLjEgMHptLTIuMi0uMmExIDEgMCAwIDAtLjMuNXYuN2EyIDIg'
    b'MCAwIDEgMC0uN2MwLS4yIDAtLjQuMi0uNS4xIDAgLjEgMCAwIDB6bS00LjQgM2EyIDIgMCAw'
    b'IDEtLjMgMSAyLjUgMi41IDAgMCAxLS44LjdjLS4xIDAgMCAwIDAgMGwuNy0uN2MuMi0uMy4z'
    b'LS42LjMtMWwuMS0uMXptMC0xLjZ2LjVhMi4yIDIuMiAwIDAgMS0uMy41bC4xLS41di0uNWgu'
    b'MXptMi45LS4ydjFoLS4xdi0xem0uNy0xLjNjLS4yLjMtLjMuNS0uMy44bC4yLjcuMyAxLjJj'
    b'MCAuNC0uMi43LS40IDEuMWwuMy0xLjFhMS45IDEuOSAwIDAgMC0uMy0xLjJsLS4yLS43YzAt'
    b'LjMgMC0uNi4zLS44LjEgMCAwIDAgMCAwem0tNC42LTguMWEyIDIgMCAwIDEgMS0uNWMuNCAw'
    b'IC44IDAgMS4yLjNoLjgtLjhjLS40LjUtLjguNy0xLjEuN2ExIDEgMCAwIDEtLjktLjJjMC0u'
    b'MSAwLS4xIDAgMGExIDEgMCAwIDAgLjkgMGMuMiAwIC42LS4xIDEtLjVhMS45IDEuOSAwIDAg'
    b'MC0xLS4xIDIgMiAwIDAgMC0xIC40Yy0uMSAwIDAgMCAwLS4xeiIvPgogIDxwYXRoIGQ9Ik0z'
    b'NTEuNiAxMDFhLjMuMyAwIDAgMSAuMy4zLjMuMyAwIDAgMS0uMy4yLjMuMyAwIDAgMS0uMi0u'
    b'Mi4zLjMgMCAwIDEgLjItLjN6bTEuOCAxLjZhMi4yIDIuMiAwIDAgMCAuOC0uN2MuMSAwIDAg'
    b'MCAwIC4xYTIuMyAyLjMgMCAwIDEtLjIuM2wtLjUuNGMtLjEtLjEgMC0uMSAwLS4xem0zLjct'
    b'MS42YS41LjUgMCAwIDEgLjMgMCAuOC44IDAgMCAxIC4zLjIuNy43IDAgMCAwLS4zIDAgLjUu'
    b'NSAwIDAgMC0uMiAwbC0uMS0uMXptLTIgLjFhLjguOCAwIDAgMSAuMy0uNGwuNy0uMXYuMWEx'
    b'IDEgMCAwIDAtLjcgMCAuNy43IDAgMCAwLS4zLjVjLS4xIDAtLjEgMCAwIDB6bS4yLjRhLjQu'
    b'NCAwIDAgMSAwLS4zLjYuNiAwIDAgMSAuMy0uMWguMWEuNS41IDAgMCAwLS4zLjIuMy4zIDAg'
    b'MCAwIDAgLjJoLS4xem0tMy42IDEuMS0uMS4zYS44LjggMCAwIDAgMCAuM2wtLjEuMWExIDEg'
    b'MCAwIDEgMC0uNGMwLS4xIDAtLjIuMi0uM3ptMSAuNXYuMi0uMnptLS42LTEuMWExIDEgMCAw'
    b'IDAgLjMgMGguM2ExLjQgMS40IDAgMCAxLS4zLjEgMSAxIDAgMCAxLS4zIDBzLS4xIDAgMC0u'
    b'MXptLjYtMmEuMy4zIDAgMCAwLS4yLjEuNC40IDAgMCAwLS4xLjJoLS4xYS41LjUgMCAwIDEg'
    b'LjItLjMuNC40IDAgMCAxIC4yIDBoLjF6bS0xIC4yYS44LjggMCAwIDAtLjIgMCAuMy4zIDAg'
    b'MCAwIDAgLjJoLS4xYy0uMSAwIDAgMCAwIDBhLjQuNCAwIDAgMSAwLS4yLjkuOSAwIDAgMSAu'
    b'My0uMXptLS43IDBhLjguOCAwIDAgMC0uMS4xLjcuNyAwIDAgMC0uMS4yaC0uMWEuNy43IDAg'
    b'MCAxIC4xLS4yLjkuOSAwIDAgMSAuMi0uMnYuMXptLS44LjdhMS43IDEuNyAwIDAgMC0uNC40'
    b'di0uMWEyIDIgMCAwIDEgLjQtLjR6bTAgLjl2LjFsLS4yLjJjLS4xIDAtLjEgMCAwIDB2LS4y'
    b'bC4yLS4yYy4xIDAgLjEgMCAwIDB6bS0uNy4ydi4zbC0uMS4xYy0uMSAwIDAgMCAwIDB2LS40'
    b'em0xIDEuNHYuNmgtLjF2LS42aC4xem0tLjYtLjR2LjNoLS4xdi0uM2guMXptLS42LTQuNWEu'
    b'Ny43IDAgMCAxIC41LjR2LjFoLS4xYS43LjcgMCAwIDAtLjItLjMuNy43IDAgMCAwLS4yLS4x'
    b'di0uMXptNS4yIDYuN2ExLjYgMS42IDAgMCAxIDAgMS40aC0uMWExLjYgMS42IDAgMCAwIDAt'
    b'MS4zdi0uMXptLTEuNyAyYzAtLjMuMi0uNS4zLS43bC40LS42Yy4yLS4yLjMtLjQuMy0uN2Ex'
    b'LjggMS44IDAgMCAwIDAtLjdoLjFhMiAyIDAgMCAxLS4zIDEuNSA2LjMgNi4zIDAgMCAwLS40'
    b'LjVsLS4zLjdoLS4xem0tMi4yLS42YS43LjcgMCAwIDEgLjItLjMuOS45IDAgMCAxIC4zLS4x'
    b'LjguOCAwIDAgMC0uMi4yLjYuNiAwIDAgMC0uMi4yem0tLjQtLjIuMy0uMy4zLS4ydi4xYTEg'
    b'MSAwIDAgMC0uMy4yIDIgMiAwIDAgMC0uMi4zYy0uMSAwLS4xIDAgMCAwem0yLjMtMi4yaC4y'
    b'YS44LjggMCAwIDAgLjMgMHYuMWEuOC44IDAgMCAxLS42IDBjMC0uMSAwLS4xIDAgMHptLTEu'
    b'Mi0uMS4xLS4xYy4xIDAgLjEgMCAwIDB2LjFjLS4xIDAgMCAwIDAgMHptMjQuMiA3YTEuMSAx'
    b'LjEgMCAwIDEgLjIuM2gtLjFhLjguOCAwIDAgMCAwLS4xLjguOCAwIDAgMC0uMi0uMmMwLS4x'
    b'IDAgMCAwIDB6bS0yNi44IDEyLjUuMy4zYTEgMSAwIDAgMCAuNSAwdi4xYTEgMSAwIDAgMS0u'
    b'NSAwIDEuNyAxLjcgMCAwIDEtLjQtLjNjMC0uMSAwLS4xIDAgMHoiLz4KICA8ZyBmaWxsPSJy'
    b'ZWQiPgogICAgPHBhdGggZD0iTTM2OC45IDk5LjZhOC4yIDguMiAwIDAgMCAxLjcgMGMtLjYu'
    b'My0xLjIuNi0yIC43YS44LjggMCAwIDAgLjMtLjQuNC40IDAgMCAwIDAtLjN6bS0xLjQtLjFo'
    b'MS4ydi40czAgLjItLjIuM2MwIDAtLjEgMCAwIC4xYTUuNiA1LjYgMCAwIDEtMS4zIDAgMSAx'
    b'IDAgMCAwIC4zLS41LjYuNiAwIDAgMCAwLS40em0tMTAuNS0zYy43LS4yIDEuMy0uMiAyLS4y'
    b'YTEgMSAwIDAgMSAuNS40Yy4xLjIuMi41LjEuOGwuMS4xaC4xbC0uMS0xYTEgMSAwIDAgMC0u'
    b'My0uMmguMmE1IDUgMCAwIDEgMi4xLjZjLjIuMi4zLjMuMi41bC0uMy41di4yaC4ybC4zLS43'
    b'YS43LjcgMCAwIDAgMC0uM2wxLjcuOGEuNS41IDAgMCAxIDAgLjUgMSAxIDAgMCAxLS41LjN2'
    b'LjFsLjEuMWMuMyAwIC41LS4yLjYtLjRhLjYuNiAwIDAgMCAwLS40bDEuMi42di4zYzAgLjIt'
    b'LjEuMy0uMy40IDAgMC0uMSAwIDAgLjEgMCAuMSAwIDAgMCAwIC4zIDAgLjUtLjIuNi0uNGEu'
    b'NS41IDAgMCAwIDAtLjNsLjQuMWE4LjEgOC4xIDAgMCAwIDEuMy40LjUuNSAwIDAgMSAuMS40'
    b'LjcuNyAwIDAgMS0uMi4zdi4yYy0xLjQtLjEtMi43LS45LTQuMS0xLjRsLS41LS4yLTEuNi0u'
    b'Ni0uMS0uMWE4LjUgOC41IDAgMCAwLTEuNS0uNCA2LjEgNi4xIDAgMCAwLTEuNiAwaC0uMWwt'
    b'LjEtLjhhMS4zIDEuMyAwIDAgMC0uNS0uNHoiLz4KICAgIDxwYXRoIGQ9Ik0zNTQuNiA5N2E4'
    b'LjcgOC43IDAgMCAxIDItLjVjLjQuMS42LjMuNy41di42YTQuMiA0LjIgMCAwIDAtMS43LjIg'
    b'MS4yIDEuMiAwIDAgMC0uNy0uNiAxLjIgMS4yIDAgMCAwLS4zLS4xem03LjQgMy45YTkuNCA5'
    b'LjQgMCAwIDAtLjUtLjQgNyA3IDAgMCAwLTMtLjhjLjMtLjQuNC0uOC4zLTEuMWExLjcgMS43'
    b'IDAgMCAwLS43LS44aDFhOCA4IDAgMCAxIDIgLjZjMCAuMy4xLjYgMCAuOCAwIC4zLS4yLjUt'
    b'LjUuNyAwIDAtLjEgMCAwIC4xIDAgLjEgMCAuMSAwIDAgLjQtLjEuNi0uNC43LS43di0uOGwx'
    b'IC42IDEgLjhjMCAuNCAwIC42LS4zLjhoLS45di4yeiIvPgogICAgPHBhdGggZD0ibTM2NCAx'
    b'MDIuNC0xLjgtMS40Yy40IDAgLjcgMCAxLS4yLjEtLjEuMy0uNC4zLS44bDEuMSAxIC42LjV2'
    b'LjRhLjUuNSAwIDAgMSAwIC4yLjYuNiAwIDAgMS0uNC4yaC0uN3oiLz4KICAgIDxwYXRoIGQ9'
    b'Ik0zNjYuMiAxMDMuOGExMS44IDExLjggMCAwIDEtMi0xLjNoLjdhLjguOCAwIDAgMCAuNC0u'
    b'MmwuMS0uNGExIDEgMCAwIDAgMC0uMiAxMC41IDEwLjUgMCAwIDAgMi4xIDEuNGMwIC4zIDAg'
    b'LjQtLjMuNWEzIDMgMCAwIDEtMSAuMXoiLz4KICAgIDxwYXRoIGQ9Ik0zNjguNCAxMDQuN2Ex'
    b'MS45IDExLjkgMCAwIDEtMi0uOGMuNCAwIC43IDAgMS0uMi4yIDAgLjMtLjIuMy0uNWExMC44'
    b'IDEwLjggMCAwIDAgMS4zLjZ2LjRsLS41LjRzLS4xIDAgMCAweiIvPgogICAgPHBhdGggZD0i'
    b'TTM3My4yIDEwNC4ycy40LS4xLjIgMGMtMS40IDEtMy4xIDEtNC44LjUuMy0uMS41LS4yLjYt'
    b'LjRhLjYuNiAwIDAgMCAwLS41bDEuNy40YS40LjQgMCAwIDEtLjEuM2wtLjUuM3MtLjEgMCAw'
    b'IC4xYzAgLjEgMCAwIDAgMCAuMyAwIC41LS4yLjYtLjNhLjYuNiAwIDAgMCAuMi0uNCA5IDkg'
    b'MCAwIDAgMiAwem0tOS43IDI0LS4yLjQtMS4yLjNjMCAuMyAwIC40LjMuNGwuNy0uM2MuMSAw'
    b'IDAgLjUtLjUuOHYuMWMuNC42IDEuNC40IDEuOS4zYTMgMyAwIDAgMCAxLjMtMWwtLjMtLjZj'
    b'LS40LjEtLjYgMC0uNS0uMmEzLjkgMy45IDAgMCAwLTEuNS0uMnptLTE1LjEtNC44Yy0uMy4z'
    b'LS43LjUtMSAuNi0uMiAwLS42LjEtLjYuMyAwIC4xLjIuMy40LjIuNC0uNS43LS4yLjIuMnYu'
    b'M2MuNS40IDEuNi41IDIuMi4yLjMtLjIuNi0uNS4yLS45YTEuNyAxLjcgMCAwIDEgMC0uMmgt'
    b'LjZsLS40LS4zLS40LS40em0xMCAzLjVoLS4xYy0uMi4yLjMuMi42LjMuMi4xLjIuMy4yLjUt'
    b'LjMuNy0xLjkuNS0yLjQuMi0uMi0uMS0uMi0uMy0uMi0uNWguM2MuMiAwIC40IDAgLjYtLjJ2'
    b'LS4yaC0uMmExLjMgMS4zIDAgMCAxLS40LjIgMi42IDIuNiAwIDAgMS0uNSAwbC0uMi0uMmgu'
    b'MmwuNy0uMi4xLS4xYy41IDAgMSAwIDEuMy4yem0tNy4yLS40LS4yLjNhMi43IDIuNyAwIDAg'
    b'MS0uOS42Yy0uMi4xIDAgLjIuMi40LjIuMS41LS4yLjYtLjQuMi0uMy4zLS4yLjIgMGwtLjIu'
    b'Ny43LjNjLjQgMCAxLS40IDEuMi0uNi4zLS4yLjItLjUuMS0uOGEyIDIgMCAwIDEtLjUgMCAz'
    b'LjQgMy40IDAgMCAxLS41LS4zbC0uNy0uMnptMi44LTI2LjRoLjNsLjYuMWE0LjUgNC41IDAg'
    b'MCAxIDEuNy0uMyA1LjcgNS43IDAgMCAxIDEuNy0uMnYtLjJjLjMtLjMuNC0uNi4zLS45LS4x'
    b'LS4yLS40LS41LS44LS43aC0xLjNhNCA0IDAgMCAwLS44LjFsLjYuNC40IDFjLS4yLjEtLjIg'
    b'MC0uMiAwIDAtLjQtLjItLjYtLjMtLjlsLS44LS40YTkgOSAwIDAgMC0xLjMuMmMtLjMgMC0u'
    b'NS4yLS43LjNsLjguMWMuMy4xLjUuNC42LjgtLjEuMS0uMSAwLS4xIDBhMSAxIDAgMCAwLS41'
    b'LS42Yy0uNC0uMi0xLjMgMC0xLjcuMmE0LjIgNC4yIDAgMCAwLS42LjZsMiAuNHptLTIuMy0u'
    b'NHYtLjFsLjctLjYuNy0uNGEyIDIgMCAwIDEgMS0uNWwxLjMtLjJhMSAxIDAgMCAwLS41LS41'
    b'bC0uOC0uMS0xLjUuOGguNWwuMS4yaC0uNGExLjQgMS40IDAgMCAwLS40IDBoLS4xbC0xLjMg'
    b'MWMuMy4xLjYuMi43LjR6Ii8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiMwMDkzZGQiIGQ9Im00'
    b'MDkgMTU2LjUgMjAuOC00Ny0xNS4zLTI0LjctMjcuMyAxMC0xMi43IDQ5LjhhMjE5LjQgMjE5'
    b'LjQgMCAwIDEgMzQuNSAxMS45eiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zODIuNiAx'
    b'MTNhMjUxLjcgMjUxLjcgMCAwIDEgMzkuNiAxMy43bC04IDE4LjJhMjMyIDIzMiAwIDAgMC0z'
    b'Ni41LTEyLjd6Ii8+CiAgPHBhdGggZmlsbD0icmVkIiBkPSJtNDE1LjQgMTQyIDUuNC0xMi4y'
    b'YTI0OC42IDI0OC42IDAgMCAwLTM5LTEzLjVsLTMuMiAxMi40YTIzNS45IDIzNS45IDAgMCAx'
    b'IDM3IDEyLjhsLS4xLjR6Ii8+CiAgPHBhdGggZD0iTTM4NS42IDEyNS44Yy4zLS4zLjctLjIg'
    b'MS4xLS4xLjMtLjIuNy0uMiAxLS4ybC42LS4yYy4yIDAgLjItLjIgMC0uM2EuNi42IDAgMCAx'
    b'IDAtLjNjLS43LS40LTEtMS0xLjItMS41LS4zIDAtLjUtLjItLjUtLjNoLS41Yy0uOCAwLTEt'
    b'LjMtMS4zLS41YTEgMSAwIDAgMS0uNi0uNGwtLjMtLjNjLS4yLS4zLS4xLS43LjItLjdoLjdh'
    b'MiAyIDAgMCAxIC45LS4xYy4zIDAgLjUtLjMuOS0uNnYtLjRzMC0uMi4yLS4xYTEgMSAwIDAg'
    b'MSAuOC41Yy41IDAgMSAuMyAxLjIuNy43IDAgMS4xLjMgMS4yLjUgMCAuMi0uMi40LS41LjZ2'
    b'LjJsLjQuNCAxIC43YzEtLjEgMi42LjYgNC44IDJhMTguNiAxOC42IDAgMCAxIDQuMSAxLjJo'
    b'LjljMi40LS40IDQuNyAwIDYuOCAxLjUuOC4xIDEuNS40IDIuMi43LjUuMiAxIC4zIDEuNi4z'
    b'YTggOCAwIDAgMSAyLjYuN2MxIC4yIDEuOS42IDIuNCAxLjIuNC41LjMgMS0uMiAxLjItLjMu'
    b'Ni0uOS42LTEuOC4zLS42LjEtMS4zLS40LTItLjktLjgtLjItMS42LS44LTIuNC0xLjNsLTEu'
    b'My0uNmgtLjh2LjJjLjIuMi40LjQuNC44djFjMCAuNC4zLjYuNy45bDEgLjRjLjIgMCAuMy4x'
    b'LjMuM2wuNCAxLjcuNC4zYy42LjUuMiAxLS4zIDFhMy4xIDMuMSAwIDAgMS0xLjMuOGMtLjQu'
    b'Mi0uNiAwLS43LS4yYS41LjUgMCAwIDEtLjQtLjJjLS41LS40LS4xLTEgMS0uN2wuMi0uMmEx'
    b'LjUgMS41IDAgMCAxIDAtLjlsLS4zLS4yYTIuOCAyLjggMCAwIDEtMS0uNmMtLjYtLjUtMS41'
    b'LTEtMi40LTEuNC0uNyAwLTEuMi0uNC0xLjgtLjdoLS44Yy0uMiAwLS40IDAtLjUuMi0uMi4z'
    b'LS41LjItLjguMmgtMS42Yy0uNCAwLS43IDAtMSAuMy0uMi4yLS40LjItLjcgMGExIDEgMCAw'
    b'IDEtLjMtLjJjLS4zIDAtLjUgMC0uNS0uMi0uNS0uMS0uNi0uMi0uNi0uNC0uNi0uMS0uMy0u'
    b'NiAwLS42bDEuNC4xYy40LjEgMSAwIDEuMi0uMmwuNS0uNWE0IDQgMCAwIDEtMS44LS41Yy0x'
    b'LjEtLjctMi0uOS0yLjgtLjMtLjIuMi0uMy4yLS42LjFhMSAxIDAgMCAwLS41IDBjLS41LjEt'
    b'LjkgMC0xLjMtLjFhNCA0IDAgMCAxLTEuOCAwYy0uNi4zLTEgLjQtMS4yLjJhOC42IDguNiAw'
    b'IDAgMS0uNi0uNGMtLjQtLjEtLjUtLjItLjUtLjMtLjQgMC0uNS0uMi0uNS0uNC0uMi0uMiAw'
    b'LS4zIDAtLjQuNC0uMi43LS4yIDEgMCAuMyAwIC41LjIuNi4zaC42Yy4xLS4yLjUtLjIgMS0u'
    b'MmwuNy0uMnYtLjJjLS40IDAtLjYtLjQtLjktLjdhMyAzIDAgMCAxLTEuNS0uNWMtLjQgMC0u'
    b'Ny0uMS0xLS4zaC0uN2EyLjUgMi41IDAgMCAxLTEuNCAwaC0uOGExIDEgMCAwIDEtMSAuMiAx'
    b'LjUgMS41IDAgMCAwLS44LS41Yy0uMy0uMS0uNC0uMi0uNC0uNC0uNC0uMi0uMy0uNCAwLS41'
    b'LjMtLjEuNS0uMiAxIDBsLjUuMnoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDAxLjIg'
    b'MTMwLjVzMC0uMi0uMyAwYy0uOCAwLTEuNiAwLTIuMi0uNC0uNy0uNC0xLjMtLjgtMi0uOGwu'
    b'Ny0uNGgxLjVjLjcgMCAxLjQuMiAyIC40LjQuMi44LjUgMSAuOGEzLjQgMy40IDAgMCAxIC44'
    b'LjcgMi41IDIuNSAwIDAgMS0uNyAwIDIuOSAyLjkgMCAwIDEtLjgtLjN6Ii8+CiAgPHBhdGgg'
    b'ZD0iTTQwMyA5NC43di4ybC45IDQuOS0zLjcgMy4yLS4yLjEuMi4xIDQuNyAxLjYgMSA0Ljl2'
    b'LjJsLjItLjEgMy43LTMuMyA0LjYgMS42aC4zdi0uMWwtMS00LjkgMy43LTMuMi4yLS4yaC0u'
    b'M2wtNC42LTEuNi0xLTQuOVY5M2wtLjIuMS0zLjcgMy4zLTQuNy0xLjZ6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2Y3ZGIxNyIgZD0ibTQwMC42IDEwMyAzLjUtMyA0LjQgMS40em04LjUtMS43IDMu'
    b'NC0zIDQuNCAxLjV6bTcuOC0xLjMtMy40IDMtNC40LTEuNXptLTguNCAxLjYtMy41IDMtNC4z'
    b'LTEuNXptLTUtNi40IDQuMyAxLjQuOCA0LjZ6bTUuNSA2LjQgNC40IDEuNS45IDQuNXptNS4x'
    b'IDYuMS00LjMtMS41LS45LTQuNXptLTUuNi02LjQtNC4zLTEuNS0uOS00LjV6bTMtNy43IDEg'
    b'NC42LTMuNSAzem0tMi43IDguMS44IDQuNi0zLjQgM3ptLTIuOCA3LjUtLjktNC41IDMuNS0z'
    b'em0yLjgtOC0uOS00LjYgMy41LTN6Ii8+Cjwvc3ZnPgo=', 'HR')

HR = b64_HR
index.append("HR")
index.append("HRV")
index.append("Croatia")
catalog["HR"] = HR
catalog["HRV"] = HR
catalog["Croatia"] = HR
country["Croatia"] = ('HR', 'HRV', 0)
lookup["HR"] = ('HR', 'HRV', 'Croatia', 0)
lookup["Zagreb Croatia"] = ('HR', 'HRV', 'Croatia', 0)
lookup["HRV"] = ('HR', 'HRV', 'Croatia', 0)
lookup["Croatia"] = ('HR', 'HRV', 'Croatia', 0)
details["HR"] = {"continent":"Europe","capital":"Zagreb","currency":"Kuna","web":".hr","lang":"hr-HR | sr","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_HT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1odCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNkMjEwMzQiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiMwMDIwOWYiIGQ9Ik0wIDBoNjQwdjI0MEgweiIvPgog'
    b'IDxnIGZpbGw9IiNmMWI1MTciIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMiI+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9Im5vbmUiIGQ9Ik0yNDQuMyAxNzkuN2gxNTEu'
    b'NHYxMjAuNUgyNDQuM3oiLz4KICAgIDxwYXRoIGZpbGw9IiMwMTZhMTYiIHN0cm9rZT0iIzAx'
    b'NmExNiIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTM1MC41IDI2Ni44LTMxIDEtMzAuNy4zcy0x'
    b'NS44IDUuOC0yMi4zIDcuMWMtNi40IDEuMy01LjYgMy40LTEwLjUgNC42LTQgLjktNC41IDEu'
    b'MS02LjggMS4zLTEuNSAwLTMuMiAxLjItNSAyLjR2MTYuN2gxNTEuNXYtMTUuOWMtMS42LS45'
    b'LTMuMi0xLjUtNC44LTItMi4yLS44LTMuNy0xLjYtNy43LTIuNS01LTEuMS00LjItMy4zLTEw'
    b'LjYtNC42LTYuNS0xLjMtMjIuMS04LjQtMjIuMS04LjR6Ii8+CiAgICA8ZyB0cmFuc2Zvcm09'
    b'InRyYW5zbGF0ZSgtODApIHNjYWxlKDEuNikiPgogICAgICA8ZyBpZD0iaHQtYSI+CiAgICAg'
    b'ICAgPHBhdGggZD0iTTI0NC41IDE0My41aDEuNGwyLjYgMTAuNy0uNiAzLjQtMy40LTE0eiIv'
    b'PgogICAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im0yNDMgMTM2LjMgMSA4LjNoMWwtMi04'
    b'LjJ6Ii8+CiAgICAgICAgPHBhdGggZD0ibTI0NS43IDE1NC42LTQuMy0xMS41IDEuNi0uMSA1'
    b'IDE0LTIuMy0yLjR6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTIzOS40IDEz'
    b'Ni41IDEuOCA4aDEuNGwtMy4yLTh6Ii8+CiAgICAgICAgPHBhdGggZD0ibTI0MS45IDE1MC42'
    b'LTIuNS01LjUgMS0uMiA0LjcgOS0zLjItMy4zeiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNm'
    b'ZmYiIGQ9Im0yMzYgMTM4LjggMi45IDcuNmgxLjRsLTQuMi03LjZ6Ii8+CiAgICAgICAgPHBh'
    b'dGggZmlsbD0iIzBhMzI4YyIgZD0ibTI0Mi4zIDE1MS40LTExLjUtMTIuNWMtMy42IDIuOC0y'
    b'LjkgOC0yLjkgOGwxMyAxMC4yIDEuMy01Ljd6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2Qy'
    b'MDAxNCIgZD0ibTI0OC45IDE1OC4yLTguNS04LjZjLTMuNi4yLS44IDUuNS0uNiA2LjJsOSA3'
    b'Ljd2LTUuM3oiLz4KICAgICAgICA8cGF0aCBkPSJNMjQ4LjEgMTU2LjggMjMwLjYgMTM4bC0u'
    b'Ny41IDE4LjYgMjAuNi0uNC0yLjN6bS0xOC41LTIwLS40LS41di0uOWwtMy42LTIuMyAxLjYg'
    b'My43IDEuMy4yLjMuNC44LS42eiIvPgogICAgICAgIDxwYXRoIGQ9Ik0yMjcuNyAxMzguMWE4'
    b'LjQgOC40IDAgMCAxIDIuNy0yLjJsMSAxLjUtMi4yIDEuOC0xLjUtMXoiLz4KICAgICAgICA8'
    b'cGF0aCBmaWxsPSIjMGEzMjhjIiBzdHJva2U9IiMwYTMyOGMiIGQ9Im0yMjUuOCAxNDEuMy42'
    b'IDFjLjQtLjEgNC0zLjUgNC0zLjVoMi43bC43LS45Yy0yLTItMy43LjMtMy43LjNsLTQuMyAz'
    b'eiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNkMjAwMTQiIHN0cm9rZT0iI2QyMDAxNCIgZD0i'
    b'TTIyOCAxNDNjMC0xIDEuOC0zLjIgMi0zLjMgMS4zLjQgMi41IDEuMiAzLjktMS44LTEuMiAx'
    b'LjQtMy41IDAtMy41IDBsLTEgLjh2LjRsLTMgMi44IDEuNSAxLjF6Ii8+CiAgICAgICAgPHBh'
    b'dGggZmlsbD0iIzBhMzI4YyIgZD0ibTIzNy4zIDE1NC43LTE0LjQtMTEuNGMtMi41IDIuNS0u'
    b'NCAxMC4yLS40IDEwLjJsMTQgNy42LjctNi40eiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNk'
    b'MjAwMTQiIGQ9Im0yNDkuMiAxNjQtMTEuOS05LjZjLTQgLjYtLjggNi41LS42IDcuMmwxMi41'
    b'IDYuOHYtNC41eiIvPgogICAgICAgIDxwYXRoIGQ9Im0yNDguNyAxNjItMjUuNi0xOS4yLS41'
    b'LjYgMjYuOCAyMS0uNy0yLjR6bS0yNi44LTIwLjItLjQtLjQtLjItLjgtNC0xLjcgMi4zIDMu'
    b'M2gxLjNsLjQuNC42LS44eiIvPgogICAgICAgIDxwYXRoIGQ9Ik0yMjAuMyAxNDMuNGE4LjIg'
    b'OC4yIDAgMCAxIDIuMy0yLjZsMS4yIDEuMy0xLjggMi4xLTEuNy0uOHoiLz4KICAgICAgICA8'
    b'cGF0aCBmaWxsPSIjMGEzMjhjIiBzdHJva2U9IiMwYTMyOGMiIGQ9Ik0yMTkgMTQ2LjZ2MS4x'
    b'Yy40LS4yIDMuNy0zLjcgMy43LTMuN2wyLjUtLjUuNi0uOGMtMS44LTIuMS0zLjcuNy0zLjcu'
    b'N2wtMy4yIDMuMnoiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjZDIwMDE0IiBzdHJva2U9IiNk'
    b'MjAwMTQiIGQ9Ik0yMjEgMTQ4LjVjLS4yLTEgMS4yLTMuOCAxLjQtNCAxLjYuNSAzIDEuMiAz'
    b'LjUtMi0xIDEuNi0zLjUuNC0zLjUuNGwtLjggMXYuNWwtMi41IDMuMyAxLjkuOHoiLz4KICAg'
    b'ICAgICA8cGF0aCBmaWxsPSIjMGEzMjhjIiBkPSJNMjM2LjIgMTYxLjdhMjc4My4zIDI3ODMu'
    b'MyAwIDAgMS0xOC41LTEwLjVjLTEuMyAyLjMtLjEgNS41LjUgNiAwIDEuNS0uNiAyLjMuNyA1'
    b'LjUuNCAyIDEuMyAzLjkgMi43IDUgMS42IDYuNCA4LjIgNi45IDEwLjcgMS42bDQtNy42eiIv'
    b'PgogICAgICAgIDxwYXRoIGZpbGw9IiNkMjAwMTQiIGQ9Im0yNDguMyAxNjguNS0xMi41LTcu'
    b'M2MtNCAuNSAwIDggLjMgOC43bDEyLjIgNC4zdi01Ljd6Ii8+CiAgICAgICAgPHBhdGggZD0i'
    b'bTI0Ni4yIDE2NS44LTI4LjMtMTUtLjUuNiAzMCAxNi43LTEuMi0yLjN6TTIxNi41IDE1MGwt'
    b'LjUtLjMtLjMtLjgtNC4xLTEgMi43IDIuOSAxLjItLjIuNi4zLjQtLjl6Ii8+CiAgICAgICAg'
    b'PHBhdGggZD0iTTIxNS4yIDE1MS44Yy40LTEgLjgtMS45IDEuOC0zbDEuNCAxLjEtMS40IDIu'
    b'NC0xLjgtLjV6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iIzBhMzI4YyIgc3Ryb2tlPSIjMGEz'
    b'MjhjIiBkPSJtMjE0LjEgMTU1LjIuNiAxLjIgMy00LjYgMi41LS45LjUtMWMtMi0xLjgtMy41'
    b'IDEuNC0zLjUgMS40bC0zLjEgMy45eiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNkMjAwMTQi'
    b'IHN0cm9rZT0iI2QyMDAxNCIgZD0iTTIxNi44IDE1Ni44Yy0uMi0xIC41LTQuMi43LTQuMyAx'
    b'LjUuNSAyLjguNiAzLjItMi42LTEgMS41LTMuMyAxLTMuMyAxbC0uNyAxIC4xLjQtMiA0IDIg'
    b'LjV6Ii8+CiAgICAgIDwvZz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjaHQtYSIgd2lkdGg9'
    b'IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEgNDk5Ljkg'
    b'MCkiLz4KICAgIDwvZz4KICAgIDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKC04MCkgc2NhbGUo'
    b'MS42KSI+CiAgICAgIDxwYXRoIGZpbGw9IiMwMTZhMTYiIHN0cm9rZT0iIzAxNmExNiIgZD0i'
    b'bTI0OC44IDEyNS42LS41IDloMi45bC0uNC05IDMtLjMtLjMtMy42LTcuNS4zdjMuMmwyLjgu'
    b'NHoiLz4KICAgICAgPGcgaWQ9Imh0LWIiIGZpbGw9IiMwMTZhMTYiPgogICAgICAgIDxwYXRo'
    b'IGQ9Ik0yNDkuOCAxMjEuOWMtNy44LTcuOC0xMy45LTQtMTUuMy0yLjkgMSAuMiAxLjgtLjQg'
    b'Mi4zLS41bC0xIDEuMnMyLjUtMSAyLjgtMWMtLjQuMy0uOCAxLS44IDEgLjIgMCAxLjYtMS4x'
    b'IDEuOC0xLjEtLjQuNC0uNSAxLjUtLjUgMS41bDEuMi0uNWMuMy4yLS4xLjYuMS42IDItLjIg'
    b'NC43IDEuNyA1IDIuMyIvPgogICAgICAgIDxwYXRoIGQ9Ik0yNDcuOSAxMjMuM2MtLjgtMS44'
    b'LTE1LjYtNS0xOC42LjMgMS4yLjMgMi4zLTEgMi4zLTF2MS4ybDEuOS0xLjYtLjcgMS42IDEu'
    b'NS0xLjN2MS4zbDItMi0uMyAxLjEgMS43LS43LS4yIDEiLz4KICAgICAgICA8cGF0aCBkPSJN'
    b'MjQ3LjIgMTIzLjZjLTMuOC0yLjUtOS42LS44LTkuNi0uOC0zLjggMi01LjggMS43LTYuMiA1'
    b'LjYuMy0uMSAxLjMtMS40IDEuMy0xLjRsLjggMS41LjItMi4xLjYgMS43IDEtMi44LjIgMS45'
    b'IDEuNC0xLjkuNi42LjYtMS41LjYgMXMxLS42IDEuNS0uM2wxLTEuMi4zLjkgMS0xIC4zLjcu'
    b'OS0uOHYuNmgzIi8+CiAgICAgICAgPHBhdGggZD0iTTI0Ni40IDEyNGMtMi43IDAtMTAuMyAy'
    b'LjktMTIuMiA1LjhhMTMuMyAxMy4zIDAgMCAxIDEuMy0uNmwuMyAxLjIuNS0xLjIuMSAxYy4z'
    b'LS44LjYtLjggMS4yLS4xbC4yLTEuMS4zIDEgLjUtMS4xcy4zIDEuMi41IDEuMmMwIDAgLjgt'
    b'Mi4yIDEuMi0yLjNsLjEgMS40LjUtMS40LjUgMXYtMS40bC42IDFzLjItMSAuNi0xLjJsLjgu'
    b'NyAzLjQtMi41Ii8+CiAgICAgICAgPHBhdGggZD0iTTI0Ni45IDEyNC43Yy0zLjUgMS4zLTYu'
    b'NyA2LjItNi40IDguMiAxLjUtMiAxLjItMS43IDEuOS42IDAgMCAuMi0yIC41LTIuMmwuNSAx'
    b'LjQuMS0xLjloLjVsLS4xLTEuMS43LjVjLS4yLS43LS4zLS45LjQtMS41IDAgMC0xIC4xLS4y'
    b'LTEuNWwuNy42cy0uMi0uNyAwLTFsMi42LS44Ii8+CiAgICAgICAgPHBhdGggZD0ibTI0Ny4y'
    b'IDEyNS0xLjMgMi42LjcuMi0xLjYgMS4xIDEuMy0uMXMtMiAuNy0yLjIgMi43bDItMXMtMS43'
    b'IDEuOC0yIDIuOWwxLjMtMXMtMS4yIDEuMi0xIDNsLjktMWMtLjIgMi4zLS4yIDIuNS44IDQu'
    b'MiAwIDAtLjItMi42IDAtM2wyLjMgMi40LTEuMi0zLjNzMS40IDIgMi4yIDEuOWwtMS44LTIu'
    b'NyAxLjggMS40LTItMyAxLjguNnMtMS4zLTEuNy0xLjItMi44bDEuMyAxLjRzLS41LTEuNS0u'
    b'NC0ybC43LjEtMS4zLTEuNC45LS4yLS4xLTEgLjYtLjF2LTEuMW0tMS4xIDBjLTIuMiAzLTEu'
    b'MSA3LjUtMi40IDkuOSIvPgogICAgICA8L2c+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI2h0'
    b'LWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAg'
    b'MCAxIDQ5OS45IDApIi8+CiAgICAgIDxwYXRoIGQ9Ik0yNTEgMTY2LjVzMS4xLTEwIDEuMS0x'
    b'NC4yYzAtMy40LS44LTEwLjgtLjgtMTAuOEgyNDhzLS41IDcuNC0uNCAxMC44YzAgNC4yIDEu'
    b'MSAxNC4yIDEuMSAxNC4yaDIuM3oiLz4KICAgICAgPHBhdGggZD0iTTI0Ny43IDE0Mmg0bC0u'
    b'NS0yLjdoLTIuOWwtLjYgMi42eiIvPgogICAgICA8cGF0aCBkPSJNMjQ4IDEzOS44aDMuNWwt'
    b'LjctMi43aC0yLjJsLS43IDIuN3oiLz4KICAgICAgPHBhdGggZD0iTTI0OC4yIDEzNy43aDNs'
    b'LS42LTIuN2gtMS45bC0uNSAyLjd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNTAuNyAxMzQuN2gt'
    b'MmwtLjMgMWgyLjVsLS4yLTF6bS40IDI5LjdoLTIuNm0yLjgtMmgtM20zLjQtMmgtMy44bTQt'
    b'Mi4xaC00bTQtMi4yaC00LjFtNC4yLTJoLTQuNG00LjQtMS43aC00LjZtNC42LTIuMmgtNC42'
    b'bTQuNS0yLjFoLTQuNW00LjMtMi4yaC00LjFtMy45LTJoLTMuNyIvPgogICAgICA8cGF0aCBm'
    b'aWxsPSIjMGEzMjhjIiBzdHJva2U9IiMwYTMyOGMiIGQ9Ik0yNTAgMTE5Yy0uOC0uMy0yLjMt'
    b'MS4zLTEuOS0xLjlsLjctMS4yYzEtMi4yIDAtMS40IDAtMi0uMi0uOCAzLjgtLjIgMy44IDEu'
    b'MyAwIC41LS4zLjItLjIgMi42bC0uOCAxLjVhMy41IDMuNSAwIDAgMS0xLjctLjJ6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Im0yNTAuNCAxMjUtMS0uOS4zLTcuMSAxIC4zLS4zIDcuNnoiLz4KICAg'
    b'ICAgPHBhdGggZmlsbD0iI2QyMDAxNCIgc3Ryb2tlPSIjZDIwMDE0IiBkPSJNMjUxLjcgMTE5'
    b'LjNjLjYtLjQgMS0xLjUuNi0yLjEtMS0xLjMtMS43LS44LTMuNC0xLjQtLjMuNC0xIDEtLjkg'
    b'MS42IDIuMyAxIDEuNC4yIDIuMi4zLjQgMCAuNi41IDEuNSAxLjV6Ii8+CiAgICA8L2c+CiAg'
    b'ICA8ZyB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtODApIHNjYWxlKDEuNikiPgogICAgICA8dXNl'
    b'IHhsaW5rOmhyZWY9IiNodC1jIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxIDAgMCAtMSAwIDMyMC40KSIvPgogICAgICA8cGF0aCBmaWxsPSIjMDE2'
    b'YTE2IiBzdHJva2U9IiNmZmYiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0iTTIzOC40IDE2'
    b'MS44YzAgMS4yLS45IDIuMy0xLjkgMi4zcy0xLjgtMS0xLjgtMi40di0xLjJoMy43djEuMnoi'
    b'Lz4KICAgICAgPGVsbGlwc2UgY3g9IjIzNi41IiBjeT0iMTYwLjEiIGZpbGw9IiNmZmYiIHN0'
    b'cm9rZT0ibm9uZSIgcng9IjEuOCIgcnk9Ii45Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiMwMTZh'
    b'MTYiIHN0cm9rZT0iI2YxYjUxNyIgZD0ibTIzNi4xIDE2MS0uMy0zLjJoMS40bC0uMiAzLjNo'
    b'LS45eiIvPgogICAgICA8cGF0aCBpZD0iaHQtYyIgZmlsbD0iIzAxNmExNiIgc3Ryb2tlPSIj'
    b'ZmZmIiBzdHJva2UtbGluZWNhcD0icm91bmQiIGQ9Ik0yMzguNSAxNjAuMWMtLjIuNS0xIC45'
    b'LTIgLjlzLTEuNy0uNC0yLS45YS44LjggMCAwIDAgMCAuNGMwIC43LjkgMS4yIDIgMS4yIDEu'
    b'MiAwIDIuMS0uNSAyLjEtMS4yYS44LjggMCAwIDAgMC0uNHoiLz4KICAgICAgPGcgaWQ9Imh0'
    b'LWQiPgogICAgICAgIDxwYXRoIGQ9Im0yNDYgMTcyLjgtNy0yLjItMy4xLTUuMy0xMC45LS41'
    b'LjQgNCA5LjMgMS43LjggMS42IDEwLjcgMy0uMi0yLjN6Ii8+CiAgICAgICAgPHBhdGggZmls'
    b'bD0iIzUwMzIwMCIgZD0ibTIzOC43IDE3NC4zLTExLjItMTYuNS0uNS41IDExIDE2LjQuNy0u'
    b'NHoiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMjI4LjYgMTU4LjUtMS4yLTJj'
    b'LS4zLS40LS42LS41LTEuMS0uMi0uNS4yLS40LjctLjIgMS4xbDEgMS45IDEuNS0uOHoiLz4K'
    b'ICAgICAgICA8cGF0aCBkPSJtMjQwIDE2NC4xLTIyLjUtMi4zLS42IDMuMyAyMi40IDIuMy43'
    b'LTMuM3oiLz4KICAgICAgICA8cGF0aCBkPSJtMjE3IDE2MS0uNSA0LjVoMWwuNi00LjEtMS0u'
    b'NHptMy44LjctLjIgNC4xaC42bC41LTMuNS0uOC0uNnptMTUuMyAxLjgtLjYgMy44aDEuMWwu'
    b'NS0zLjhoLTF6bTMuMy4xLS43IDQuNCAxLjIuMi40LTIuM2MwIC41LjUuOCAxIC44LjYgMCAx'
    b'LS41IDEtMSAwLS42LS40LTEtMS0xYTEgMSAwIDAgMC0xIC42bC4zLTEuNi0xLjItLjF6bS04'
    b'IC43LTMuMiAzLjUuNC40IDQtMi43LTEuMy0xLjJ6TTIyNCAxNzNsMy4xLTMuNS0uMy0uNC00'
    b'IDIuNyAxLjIgMS4yem04LjEtLjktMy43LTIuOS0uNC4zIDMgMy44IDEuMS0xLjJ6bS05LjMt'
    b'Ni43IDMuOSAyLjguNC0uMy0zLTMuOC0xLjMgMS4zem00LjItMi4zLjQgNC42aC41bDEuMi00'
    b'LjUtMi4xLS4xem0xLjIgMTEtLjMtNC41aC0uNmwtLjcgNC42aDEuNnptNS4xLTYtNC44LjR2'
    b'LjVsNC44LjZWMTY4em0tMTEuNCAxLjUgNC43LS43di0uNGwtNC44LS41djEuNnoiLz4KICAg'
    b'ICAgICA8ZWxsaXBzZSBjeD0iMjI3LjciIGN5PSIxNjguNiIgcng9IjEuMyIgcnk9IjEuMiIv'
    b'PgogICAgICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLWxpbmVjYXA9InJv'
    b'dW5kIiBkPSJNMjM0LjQgMTY4LjZjMCAzLjUtMyA2LjUtNi43IDYuNWE2LjYgNi42IDAgMCAx'
    b'LTYuNy02LjVjMC0zLjYgMy02LjUgNi43LTYuNWE2LjYgNi42IDAgMCAxIDYuNyA2LjV6bS0x'
    b'LjMgMGE1LjMgNS4zIDAgMCAxLTUuNCA1LjIgNS4zIDUuMyAwIDAgMS01LjQtNS4zIDUuMyA1'
    b'LjMgMCAwIDEgNS40LTUuMSA1LjMgNS4zIDAgMCAxIDUuNCA1LjJ6Ii8+CiAgICAgICAgPHBh'
    b'dGggZD0ibTIyMy41IDE2NS4zLTEtLjhtOC41IDAgMS0xbTEgOS4yLTEuMS0uOW0tOC40IDEu'
    b'OSAxLTFtMjEuNy0xMC42IDEuMSA2LS45LjQtMS02LjNoLjh6Ii8+CiAgICAgICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZiIgZD0iTTI0NS42IDE2MS40Yy0uNS0uMy0xLjIuMS0yLjQtMS4zLTEuOSAx'
    b'LjcgMCAyIC4yIDMuNy41LjIuOS0xLjQgMi4zLTEuNWwyLjMtLjItLjUtLjdoLTJ6Ii8+CiAg'
    b'ICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTI0Ni40IDE2Mi41LS4yLTEuN2MtLjMtLjct'
    b'MS0uMS0xIC4ybC4yIDEuNyAxLS4yeiIvPgogICAgICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgZD0iTTI0MC44IDE2Ny40djEuNmMtLjYuMi0uNS42LS41IDEuMnY0LjdjLS4xLjQt'
    b'LjcuNC0xIC42LS4zLjMtLjIuOCAxIDFsMSAuMWMxLjUtLjMgMS44LS44IDEtMS0uMy0uMi0u'
    b'OS0uNC0xLS42di0xLjJoMWMuMiAwIC43LS42LjctMS4xdi0yLjVjMC0xLjQtMS0xLjYtMS40'
    b'LTEuNXYtMS4zaC0uOHptMS42IDIuN2MwLS40LS42LS44LS44LS44LS4yIDAtLjcuNS0uNy45'
    b'djFjMCAuNC4zIDEuNi45IDEuNy4yIDAgLjYtLjQuNi0uOHYtMnoiLz4KICAgICAgICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNMjM0LjMgMTcyLjNjLS43LS4yLS43IDEuMi0uNyAxLjJoMWMu'
    b'NS4yLjguOC42IDEuMi0uMy4yLTIuMi0uNS0yLjMgMCAuMyAxLjkgMi45IDIuNiAzLjggMS44'
    b'LjktLjkgMS4xLTMtMS44LTMuN2wtLjYtLjV6bS42LjYtLjMuNiIvPgogICAgICAgIDxwYXRo'
    b'IGQ9Im0yMTUgMTczLTEtNG0yLjEgMy44LTEuNS0zLjFtNCAyLjMtMy4zLTEuOG00LjggMS40'
    b'LTYuMi0yLjciLz4KICAgICAgICA8cGF0aCBmaWxsPSIjZDIwMDE0IiBzdHJva2U9IiNkMjAw'
    b'MTQiIGQ9Im0yMTAuMiAxNjYtMi42LjFjLS4yLjEuNS45LjQgMS4xLS42IDEuMS00LjQgMS00'
    b'LjcuOC0uNS0uNSAzLjUtLjggMy42LTEgMC0uNC0uNi0xLjItLjUtMS43IDAtLjcgMS43LTEg'
    b'MS43LTFsMi4xIDEuN3oiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjNTAzMjAwIiBkPSJtMjEz'
    b'LjIgMTY4LTUtNC4ycy0uMy0uMi0uNSAwIDAgLjQgMCAuNGw1LjQgNC40LjEtLjV6Ii8+CiAg'
    b'ICAgICAgPHBhdGggZD0ibTIxOC4yIDE3Mi4yLTQuMi0zLjYtLjMtMS0uOC42Yy0uMy4yLS42'
    b'LjgtLjYuOGgxLjFsMy42IDMuNCAxLjEtLjJ6Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjMy'
    b'LjUiIGN5PSIxNzcuMSIgcj0iLjciLz4KICAgICAgICA8Y2lyY2xlIGN4PSIyMzAuNiIgY3k9'
    b'IjE3NS43IiByPSIuNyIvPgogICAgICAgIDxjaXJjbGUgY3g9IjIyOC4xIiBjeT0iMTc2LjYi'
    b'IHI9Ii43Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjI0LjIiIGN5PSIxNzcuNCIgcj0iLjci'
    b'Lz4KICAgICAgICA8Y2lyY2xlIGN4PSIyMjIuNSIgY3k9IjE3Ny42IiByPSIuNyIvPgogICAg'
    b'ICAgIDxjaXJjbGUgY3g9IjIyMC44IiBjeT0iMTc3LjYiIHI9Ii43Ii8+CiAgICAgICAgPGNp'
    b'cmNsZSBjeD0iMjE5LjIiIGN5PSIxNzcuNiIgcj0iLjciLz4KICAgICAgICA8Y2lyY2xlIGN4'
    b'PSIyMjAiIGN5PSIxNzYuMyIgcj0iLjciLz4KICAgICAgICA8Y2lyY2xlIGN4PSIyMjEuNiIg'
    b'Y3k9IjE3Ni40IiByPSIuNyIvPgogICAgICAgIDxjaXJjbGUgY3g9IjIyMy4xIiBjeT0iMTc2'
    b'LjIiIHI9Ii43Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjIyLjQiIGN5PSIxNzUiIHI9Ii43'
    b'Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjIwLjgiIGN5PSIxNzQuOSIgcj0iLjciLz4KICAg'
    b'ICAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yMzYuNSAxNzhjMC0uMy0uOC0u'
    b'Mi0uOC0uNiAwLS40IDEuMiAwIDEuMy4zLjctLjYgMS0uMiAxLjQgMCAuNi0uOCAxLjMtLjgg'
    b'Mi0uMi40LS40IDEuNC0uMyAxLjcuMi43LS42IDEuMy0uNSAxLjcgMCAuMi0uMy41LS4zLjcg'
    b'MCAuMy0uNyAxLjItLjUgMS42IDAgLjMtLjQuNy0uMSAxLjEuMS4zLS4yLjgtLjIuOCAwIDAg'
    b'LjQtLjYuMy0uNi42IDAgLjIuNCAwIC40LjQgMCAuMy0uNi40LS43IDAtLjMuNC0xLjEuMi0x'
    b'LjItLjJhLjguOCAwIDAgMS0xLjIgMGMtLjMuMi0uNy4yLS44IDAtLjUuNS0xLjQuNC0xLjct'
    b'LjJoLS4zYTEgMSAwIDAgMS0xLjUgMGMtLjkuNi0xLjQuNC0xLjkgMC0uNS43LTEuNC43LTEu'
    b'NSAwLS40LjMtMS4yLjQtMS4yIDAgMC0uMi43LS4xLjctLjR6bTEuNi4xYzAgLjItLjIuMy0u'
    b'NC4zcy0uNC0uMS0uNC0uMy4xLS4yLjQtLjIuNC4xLjQuMnptMS45LS4yYzAgLjItLjMuMy0u'
    b'Ni4zcy0uNS0uMS0uNS0uM2MwLS4xLjItLjMuNS0uM3MuNS4yLjUuM3ptMy41LjJjMCAuMi0u'
    b'Mi4zLS41LjNzLS40LS4xLS40LS4zYzAtLjEuMi0uMy40LS4zcy41LjEuNS4zem0tMS45IDBj'
    b'MCAuMi0uMi4zLS41LjNzLS40LS4xLS40LS40YzAtLjIuMi0uNC40LS40cy41LjIuNS40em00'
    b'IDBjMCAuMS0uMS4zLS4zLjMtLjMgMC0uNS0uMi0uNS0uNHMuMi0uMy41LS4zYy4yIDAgLjQu'
    b'MS40LjN6bS0xLjIgMGMwIC4yIDAgLjMtLjIuM3MtLjMtLjEtLjMtLjMuMS0uMi4zLS4ybC4y'
    b'LjJ6bTIuNC4xYzAgLjIgMCAuNC0uMy40LS4xIDAtLjMtLjItLjMtLjRzLjItLjMuMy0uM2Mu'
    b'MiAwIC4zLjEuMy4zeiIvPgogICAgICA8L2c+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI2h0'
    b'LWQiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAg'
    b'MCAxIDQ5OS45IDApIi8+CiAgICAgIDxwYXRoIGZpbGw9IiMwYTMyOGMiIHN0cm9rZT0iIzBh'
    b'MzI4YyIgZD0iTTI0OS44IDE2NS43Yy0yLjUgMC00LjUgMS00LjUgMi4xIDAgLjIgMCAuNC4y'
    b'LjYuNS42IDIuMyAxIDQuNCAxIDIgMCAzLjYtLjMgNC4yLS45LjItLjIuMy0uNC4zLS43IDAt'
    b'MS4xLTItMi00LjYtMnoiLz4KICAgICAgPHBhdGggZD0iTTI1NC40IDE2OHY3YzAgLjktMiAx'
    b'LjUtNC41IDEuNXMtNC42LS42LTQuNi0xLjV2LTdjMCAuOCAyIDEuNSA0LjUgMS41IDIuNiAw'
    b'IDQuNi0uNyA0LjYtMS41eiIvPgogICAgICA8cGF0aCBmaWxsPSIjZDIwMDE0IiBzdHJva2U9'
    b'IiNkMjAwMTQiIGQ9Ik0yNDUuMyAxNjh2MWwyLjIgNyAxLjgtNS40IDIgNS41IDEuMy01LjIg'
    b'MS44IDMuNXYtMS45bC0xLjYtMy40YTguMyA4LjMgMCAwIDEtLjYuMmwtMSAzLjgtMS41LTMu'
    b'NmExNC41IDE0LjUgMCAwIDEtLjcgMGwtMS41IDMuNi0xLjYtNC40Yy0uNC0uMi0uNi0uNS0u'
    b'Ni0uN3oiLz4KICAgICAgPHBhdGggZmlsbD0iIzBhMzI4YyIgc3Ryb2tlPSIjMGEzMjhjIiBk'
    b'PSJNMjU0LjQgMTczLjd2MS4zYzAgLjktMiAxLjUtNC41IDEuNXMtNC42LS42LTQuNi0xLjV2'
    b'LTEuM2MwIC45IDIgMS41IDQuNSAxLjUgMi42IDAgNC42LS42IDQuNi0xLjV6Ii8+CiAgICAg'
    b'IDxwYXRoIGQ9Im0yNTEuNyAxNzUtMS4xLjJ2MS4zbDEuMi0uMXYtMS4zem0tNC44LS4xdjEu'
    b'M2wxLjEuMnYtMS4zYTguOSA4LjkgMCAwIDEtMS4xLS4yem0tMS42LTEuMnYxLjNjMCAuMy4y'
    b'LjUuNS43di0xLjNjLS4zLS4yLS41LS40LS41LS43em05LjEuMmMwIC4yLS40LjUtLjguN3Yx'
    b'LjNjLjUtLjIuOC0uNS44LS45di0xeiIvPgogICAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJN'
    b'MjU0LjQgMTY4djdjMCAuOS0yIDEuNS00LjUgMS41cy00LjYtLjYtNC42LTEuNXYtNyIvPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiNmZmYiIGQ9Ik0yNTMuNCAxNjcuNWMw'
    b'IC41LTEuNiAxLTMuNSAxLTIgMC0zLjYtLjUtMy42LTFzMS42LS45IDMuNS0uOWMyIDAgMy42'
    b'LjQgMy42IDF6Ii8+CiAgICAgIDxwYXRoIGQ9Im0yNDguNyAxNjguMi4yIDEuMmgxbC4xLTEu'
    b'MmgtMS4zem00LjEtLjMtMSAuMi4xIDEuMiAxLS4yVjE2OHptLTUuNC0yLS43LjMuMSAxIC42'
    b'LS4ydi0xem0yLjQtLjNoLS4zbC4yIDEuMmguNmwuMi0xLjJhOS43IDkuNyAwIDAgMC0uNyAw'
    b'em0yLjcuNC0uMSAxIC43LjN2LTFhNS4zIDUuMyAwIDAgMC0uNi0uM3ptLTYuNSAyLjguMi0x'
    b'LjMtMS0uNXYxLjVsLjguM3ptOC40LS4zdi0xLjNsLS44LjMuOCAxem05LjMtOC41Yy44IDAg'
    b'MiAxIDIuMSAyLjUgMCAxLTEuNyAxLTEuNyAxIDAgLjUtMSAuOS0xLjggMS0uOCAwIC4yLTEu'
    b'NS4yLTEuNS0uNS0xLjMuMi0yLjcuMi0yLjdsMS0uM3oiLz4KICAgICAgPHBhdGggZD0iTTI2'
    b'Mi41IDE2M2guOHMwIC4zLjIuMy4zLS40LjMtLjRoMS4yIi8+CiAgICAgIDxwYXRoIGZpbGw9'
    b'IiNkMjAwMTQiIHN0cm9rZT0iI2YxYjUxNyIgZD0iTTI2NC4xIDE2MC45Yy43LS41LjEtMS41'
    b'LS40LTEuNWgtMWMtLjYgMC0xLjQuNi0xLjMgMSAwIC41LjQuNy44LjYuMiAwIC42LS42Ljgt'
    b'LjYuMyAwIDEgLjYgMS4xLjV6Ii8+CiAgICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'ZD0iTTIxNC4yIDE3NC44Yy0uNi4xLS43LjgtLjUgMS41LTIuNi43LTUgMS43LTcuNCAyLjQt'
    b'LjEtLjUgMS4yLTEuOCAxLjItMS44LjMuMS42LjkuNi45IDAtMS42IDEuNi0yLjYgMS42LTIu'
    b'Ni0xLS4yLTMuNyAxLTQgMS40IDAgMCAxLS4yIDEuMiAwIDAgMC0yLjIgMi4zLTIuMyAzIC40'
    b'LjcgNCAxLjMgNCAxLjMgMCAuMi0xIDEtMSAxIDEuNS4yIDMuNy0uOCA0LjMtMS40IDAgMC0x'
    b'LjctLjItMy0xLjMgMCAwIC4yLjcgMCAxIDAgMC0yLS42LTIuMy0xIDAgMCA1LTEuMiA3LjQt'
    b'MiAuMS41LjYgMS4zIDEuMiAxLjEuMy0uMS4yLS44IDAtMS40YS44LjggMCAwIDAgLjYuMmMu'
    b'NCAwIC43LS4zLjctLjcgMC0uNC0uMy0uNy0uNy0uN2EuOC44IDAgMCAwLS43LjVjLS4xLS41'
    b'LS40LTEuNC0uOC0xLjN6bTIgMS42YzAgLjItLjIuMy0uNC4zYS4zLjMgMCAwIDEtLjQtLjNj'
    b'MC0uMi4yLS40LjQtLjRzLjMuMi4zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yOTMgMTc3Ljlj'
    b'LjItLjQgMC0yLjIgMC0yLjItLjUgMC0xIC43LTEgLjcuNS0xLjYtLjgtNC0uOC00IC45LjEg'
    b'My45IDMgNCAzLjYgMCAwLTEuMy0uNS0xLjUtLjQuMyAxLjUgMS4zIDIuMiAxLjcgMyAwIDAt'
    b'MS43LjMtMS42IDEuOGgtMS4xYy0uNC0uNS4xLTEuMy4xLTEuM2wtNy43LTMuMmMtLjUtLjIt'
    b'MS42LS44LTEuNC0xLjQuMS0uNSAyIC4zIDIuNC41bDcgMi45eiIvPgogICAgICA8cGF0aCBk'
    b'PSJtMjg1LjYgMTc2LjUgMS0xLjZjLjMtLjUtLjQtMS0uOS0uNGwtMSAxLjVjLS40LjkuNSAx'
    b'LjEgMSAuNXoiLz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0aD0i'
    b'LjMiPgogICAgICA8cGF0aCBkPSJtMjkwLjIgMjg4LjYtLjEtMy0zLjUuMy0uMiAzLjEgMy44'
    b'LS40eiIvPgogICAgICA8cGF0aCBkPSJtMjY0LjQgMjkyLjctNC43LTIuN2MxOS40IDEuOCAy'
    b'My40LTUgMjguMS01LjMgMy0uMyAzLjMgMy4yLTIuMyAxLjVsMS41IDMuNnMtMTMuOCA3Ljgt'
    b'MjcuNCA0LjZsNC44LTEuN3ptODQuOC00LjEuMS0zIDQuMy4yLjIgMy4xLTQuNi0uM3oiLz4K'
    b'ICAgICAgPHBhdGggZD0ibTM3NS45IDI5MiA0LjUtMi41Yy0yMi40LjctMTcuMy0zLjYtMjgu'
    b'NC00LjgtMy0uNC01IDMuNCAyLjIgMS41bC0xLjQgMy42aDMuNWM3LjYgNSAxNy44IDUuNSAy'
    b'NC42IDMuOWwtNS0xLjd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yODUuNSAyODYuM3Y1czEyLjMg'
    b'NC42IDM0LjQgNC42YzIyLjIgMCAzNC40LTQuNiAzNC40LTQuNnYtNXMtOS4zIDQuMy0zNC40'
    b'IDQuM2MtMjUgMC0zNC40LTQuMy0zNC40LTQuM3oiLz4KICAgIDwvZz4KICAgIDxwYXRoIGZp'
    b'bGw9IiMwMDAiIHN0cm9rZT0ibm9uZSIgZD0ibTI4Ny4zIDI5MS4zIDEuMS0zLjcuNS4yLTEg'
    b'My4yIDIgLjUtLjIuNS0yLjQtLjd6bTMuNi0xLjZ2LS43bC4yLS43LjYuMi0uMi42LS4zLjct'
    b'LjMtLjF6bTUuMy0uMy41LjItLjQgMi4xLS40IDFhMS4yIDEuMiAwIDAgMS0uNS40aC0xYTIg'
    b'MiAwIDAgMS0uOS0uNCAxIDEgMCAwIDEtLjQtLjZsLjEtMSAuNS0yLjIuNS4xLS41IDIuMmEy'
    b'LjEgMi4xIDAgMCAwIDAgLjguNy43IDAgMCAwIC4yLjRsLjUuMmgxbC40LTEgLjQtMi4yem0u'
    b'NiA0IC42LTMuN2guNmwxLjUgMy40LjUtM2guNWwtLjYgMy45LS41LS4xLTEuNi0zLjMtLjUg'
    b'My0uNS0uMXptNCAuNy42LTMuOGguNWwtLjUgMy44aC0uNXptMS42LTEuN2MwLS42LjMtMS4x'
    b'LjctMS40YTIgMiAwIDAgMSAxLjQtLjRjLjQgMCAuNy4xIDEgLjNsLjUuOGMuMi4zLjIuNy4x'
    b'IDFhMi4yIDIuMiAwIDAgMS0uMyAxIDEuNyAxLjcgMCAwIDEtLjguNyAyIDIgMCAwIDEtMSAu'
    b'MSAyIDIgMCAwIDEtMS0uMyAxLjcgMS43IDAgMCAxLS41LS44IDIuMSAyLjEgMCAwIDEtLjEt'
    b'MXptLjUgMGMwIC41IDAgMSAuMyAxLjIuMi4zLjUuNS45LjVzLjcgMCAxLS4zYy4zLS4yLjQt'
    b'LjYuNS0xYTEuOSAxLjkgMCAwIDAgMC0xIDEuMiAxLjIgMCAwIDAtLjUtLjUgMS4zIDEuMyAw'
    b'IDAgMC0uNy0uM2MtLjMgMC0uNyAwLTEgLjMtLjIuMi0uNC42LS41IDEuMnptMy43IDIuMy4z'
    b'LTMuOGguNmwxLjggMy4yLjItM2guNWwtLjMgMy45aC0uNWwtMS45LTMuMi0uMiAzaC0uNXpt'
    b'NS42LjQuMS0zLjggMi43LjF2LjVsLTIuMS0uMS0uMSAxLjEgMS45LjF2LjVsLTItLjF2MS44'
    b'aC0uNXptMyAuMSAxLjUtMy44aC42bDEuNSA0aC0uNmwtLjQtMS4zaC0xLjdsLS40IDEuMmgt'
    b'LjZ6bTEtMS41aDEuNGwtLjQtMWE5LjggOS44IDAgMCAxLS4yLS45bC0uMi44LS41IDEuMXpt'
    b'My4xIDEuNnYtMy44aC42djMuOGgtLjZ6bTIuNSAwVjI5MmgtMS4zdi0uNGgzLjF2LjRoLTEu'
    b'M3YzLjRoLS41em00IDAtLjMtNGguNmwuMSAzLjRoMnYuNGwtMi41LjF6bTIuNi0uMiAxLjIt'
    b'NGguNmwyIDMuN2gtLjdsLS41LTFoLTEuN2wtLjMgMS4zaC0uNnptMS0xLjdoMS40bC0uNS0x'
    b'LS40LS45YTQuOCA0LjggMCAwIDEtLjEuOGwtLjQgMS4xem00LjcgMS4yLS40LTMuOCAyLjYt'
    b'LjMuMS41LTIuMS4ydjEuMmwyLS4ydi41bC0xLjkuMi4yIDEuN2gtLjV6bTMtMi4xYTIgMiAw'
    b'IDAgMSAuMi0xLjYgMiAyIDAgMCAxIDEuMy0uN2wxIC4xYy40LjEuNi4zLjguNmwuNCAxLS4x'
    b'IDFhMS42IDEuNiAwIDAgMS0uNi44IDIgMiAwIDAgMS0uOS40IDIgMiAwIDAgMS0xLS4xIDEu'
    b'NyAxLjcgMCAwIDEtLjgtLjYgMi4xIDIuMSAwIDAgMS0uNC0xem0uNS0uMWMwIC40LjIuOC41'
    b'IDEgLjMuMy42LjMgMSAuM3MuNy0uMiAxLS41Yy4yLS4zLjItLjcuMi0xLjJhMiAyIDAgMCAw'
    b'LS4zLS44IDEuMyAxLjMgMCAwIDAtLjYtLjUgMS40IDEuNCAwIDAgMC0uNyAwYy0uNCAwLS43'
    b'LjEtMSAuNC0uMS4zLS4yLjctLjEgMS4zem00LjEgMS4zLS42LTMuOCAxLjctLjNoLjhjLjIg'
    b'MCAuNCAwIC41LjJsLjMuNmMwIC4zIDAgLjUtLjIuNy0uMS4yLS40LjQtLjcuNWExLjQgMS40'
    b'IDAgMCAxIC4zLjFsLjUuNSAxIC45aC0uN2wtLjctLjZhNy40IDcuNCAwIDAgMC0uNS0uNSAx'
    b'LjIgMS4yIDAgMCAwLS4zLS4yLjguOCAwIDAgMC0uMyAwaC0uM2wtLjYuMS40IDEuN2gtLjZ6'
    b'bS4yLTIuMiAxLS4yYTEuNyAxLjcgMCAwIDAgLjYtLjIuNi42IDAgMCAwIC4zLS42LjYuNiAw'
    b'IDAgMC0uMi0uNGgtLjdsLTEuMy4xLjMgMS4zem02LjMtLjRoLjVjMCAuNC0uMS44LS4zIDFh'
    b'MiAyIDAgMCAxLTEgLjYgMiAyIDAgMCAxLTEgMCAxLjYgMS42IDAgMCAxLS44LS42IDIuNiAy'
    b'LjYgMCAwIDEtLjUtMSAyLjIgMi4yIDAgMCAxIDAtMWMwLS40LjMtLjcuNS0uOWwuOS0uNGgx'
    b'Yy40LjIuNi40LjguOGwtLjUuMmExLjIgMS4yIDAgMCAwLS41LS41IDEuMSAxLjEgMCAwIDAt'
    b'LjcgMCAxIDEgMCAwIDAtLjcuMyAxLjEgMS4xIDAgMCAwLS4zLjd2LjdhMi4zIDIuMyAwIDAg'
    b'MCAuNC44Yy4xLjIuMy40LjYuNGguN2ExLjEgMS4xIDAgMCAwIC42LS4zYy4yLS4yLjMtLjUu'
    b'My0uOHptMS40IDEtMS0zLjcgMi43LS43LjIuNC0yLjMuNi4zIDEuMSAyLjEtLjUuMi40LTIu'
    b'Mi42LjQgMS4yIDIuNC0uNnYuNGwtMi44Ljh6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'HT')

HT = b64_HT
index.append("HT")
index.append("HTI")
index.append("Haiti")
catalog["HT"] = HT
catalog["HTI"] = HT
catalog["Haiti"] = HT
country["Haiti"] = ('HT', 'HTI', 0)
lookup["HT"] = ('HT', 'HTI', 'Haiti', 0)
lookup["Port-au-Prince Haiti"] = ('HT', 'HTI', 'Haiti', 0)
lookup["HTI"] = ('HT', 'HTI', 'Haiti', 0)
lookup["Haiti"] = ('HT', 'HTI', 'Haiti', 0)
details["HT"] = {"continent":"Americas","capital":"Port-au-Prince","currency":"Gourde | US Dollar","web":".ht","lang":"ht | fr-HT","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_HU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWh1IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik02NDAgNDgwSDBWMGg2NDB6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjMzg4ZDAwIiBkPSJNNjQwIDQ4MEgwVjMyMGg2NDB6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZDQzNTE2IiBkPSJNNjQwIDE2MC4xSDBWLjFoNjQweiIvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'HU')

HU = b64_HU
index.append("HU")
index.append("HUN")
index.append("Hungary")
catalog["HU"] = HU
catalog["HUN"] = HU
catalog["Hungary"] = HU
country["Hungary"] = ('HU', 'HUN', 0)
lookup["HU"] = ('HU', 'HUN', 'Hungary', 0)
lookup["Budapest Hungary"] = ('HU', 'HUN', 'Hungary', 0)
lookup["HUN"] = ('HU', 'HUN', 'Hungary', 0)
lookup["Hungary"] = ('HU', 'HUN', 'Hungary', 0)
details["HU"] = {"continent":"Europe","capital":"Budapest","currency":"Forint","web":".hu","lang":"hu-HU","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_ID = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWlkIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2U3MDAxMSIgZD0i'
    b'TTAgMGg2NDB2MjQwSDBaIi8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMjQwaDY0MHYy'
    b'NDBIMFoiLz4KPC9zdmc+Cg==', 'ID')

ID = b64_ID
index.append("ID")
index.append("IDN")
index.append("Indonesia")
catalog["ID"] = ID
catalog["IDN"] = ID
catalog["Indonesia"] = ID
country["Indonesia"] = ('ID', 'IDN', 0)
lookup["ID"] = ('ID', 'IDN', 'Indonesia', 0)
lookup["Jakarta Indonesia"] = ('ID', 'IDN', 'Indonesia', 0)
lookup["IDN"] = ('ID', 'IDN', 'Indonesia', 0)
lookup["Indonesia"] = ('ID', 'IDN', 'Indonesia', 0)
details["ID"] = {"continent":"Asia","capital":"Jakarta","currency":"Rupiah","web":".id","lang":"id | en | nl | jv","tz":"+07:00 | +09:00","altname":""}
#----------------------------------------------------------------------
b64_IE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWllIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0'
    b'ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDlBNDkiIGQ9Ik0wIDBoMjEzLjN2NDgwSDB6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjRkY3OTAwIiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQyNi43'
    b'eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'IE')

IE = b64_IE
index.append("IE")
index.append("IRL")
index.append("Ireland")
catalog["IE"] = IE
catalog["IRL"] = IE
catalog["Ireland"] = IE
country["Ireland"] = ('IE', 'IRL', 0)
lookup["IE"] = ('IE', 'IRL', 'Ireland', 0)
lookup["Dublin Ireland"] = ('IE', 'IRL', 'Ireland', 0)
lookup["IRL"] = ('IE', 'IRL', 'Ireland', 0)
lookup["Ireland"] = ('IE', 'IRL', 'Ireland', 0)
details["IE"] = {"continent":"Europe","capital":"Dublin","currency":"Euro","web":".ie","lang":"en-IE | ga-IE","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_IL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWlsIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImlsLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg3LjYgMEg1OTV2'
    b'NTEySC04Ny42eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBjbGlwLXBhdGg9InVybCgjaWwtYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRl'
    b'KDgyLjEpIHNjYWxlKC45NCkiPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTYxOS40IDUx'
    b'MkgtMTEyVjBoNzMxLjR6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDAzOGI4IiBkPSJNNjE5LjQg'
    b'MTE1LjJILTExMlY0OGg3MzEuNHptMCAzNTAuNUgtMTEydi02Ny4yaDczMS40em0tNDgzLTI3'
    b'NSAxMTAuMSAxOTEuNkwzNTkgMTkxLjZsLTIyMi42LS44eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZD0ibTIyNS44IDMxNy44IDIwLjkgMzUuNSAyMS40LTM1LjMtNDIuNC0uMnoiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMDM4YjgiIGQ9Ik0xMzYgMzIwLjYgMjQ2LjIgMTI5bDExMi40'
    b'IDE5MC44LTIyMi42Ljh6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMjI1LjggMTkx'
    b'LjYgMjAuOS0zNS41IDIxLjQgMzUuNC00Mi40LjF6TTE4MiAyNzEuMWwtMjEuNyAzNiA0MS0u'
    b'MS0xOS4zLTM2em0tMjEuMy02Ni41IDQxLjIuMy0xOS44IDM2LjMtMjEuNC0zNi42em0xNTEu'
    b'MiA2NyAyMC45IDM1LjUtNDEuNy0uNSAyMC44LTM1em0yMC41LTY3LTQxLjIuMyAxOS44IDM2'
    b'LjMgMjEuNC0zNi42em0tMTE0LjMgMEwxODkuNyAyNTZsMjguOCA1MC4zIDUyLjggMS4yIDMy'
    b'LTUxLjUtMjkuNi01Mi01NS42LjV6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'IL')

IL = b64_IL
index.append("IL")
index.append("ISR")
index.append("Israel")
catalog["IL"] = IL
catalog["ISR"] = IL
catalog["Israel"] = IL
country["Israel"] = ('IL', 'ISR', 0)
lookup["IL"] = ('IL', 'ISR', 'Israel', 0)
lookup["Jerusalem Israel"] = ('IL', 'ISR', 'Israel', 0)
lookup["ISR"] = ('IL', 'ISR', 'Israel', 0)
lookup["Israel"] = ('IL', 'ISR', 'Israel', 0)
details["IL"] = {"continent":"Asia","capital":"Jerusalem","currency":"New Israeli Sheqel","web":".il","lang":"he | ar-IL | en-IL | ","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_IM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWltIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImltLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTc3LjYgMEg2MDV2'
    b'NTEySC03Ny42eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgY2xpcC1wYXRo'
    b'PSJ1cmwoI2ltLWEpIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSg3Mi44KSBzY2FsZSguOTQpIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNiYTAwMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTYyOS40'
    b'IDUxMkgtMTAyVjBoNzMxLjR6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZlZjAwIiBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0yODEg'
    b'Mzc2Yy4yLS42LjYtNi44LjQtNi44cy05LjQtMTAuOS05LjItMTAuOWMuMiAwIDExLjggMi42'
    b'IDExLjggMi4yIDAtLjQgNC43LTExLjUgNC43LTExLjdsNS42IDEzLjUgMTEuNSA1LTggNi43'
    b'IDEuNyAxM2MwIC4zLTgtNy42LTgtNy42bC04LjkgMXMtMS4yLTQtMS42LTQuNHoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9IjIuNiIgZD0iTTIxOC43IDIwNi45Yy03LjcgNC0zNyAzNy41LTQxIDQy'
    b'LjdhNzcuMyA3Ny4zIDAgMCAxLTE2LjggMjMuNGMtNy4zIDUuNS0xMS4zIDEzLTEwLjMgMjAg'
    b'MCA5IDQuOSAxNSA4LjggMjEuMSAyLjMgMi45IDUuNSA0LjcgOC44IDUgNi45LjggNy41IDMg'
    b'MTEgNC4yIDEzLjQgMTguNCAzMy42IDMyIDQ4IDQyLjdhNjguNCA2OC40IDAgMCAxIDE4IDEy'
    b'LjRjNC4yIDguMiAzLjQgMTYgMi44IDIwTDIzNy4zIDQzOWMtMS45IDExIDcuOCA4LjYgOC4z'
    b'IDYuNCA0LjMtNS43IDEwLjgtMS43IDIwLTM0LjNsMTIuOC0xNy4xczQuOS0yIDQuOS0yLjVj'
    b'Ny41LTkgMS44LTE0LTIuNS0xNS43bC05LjItMy40cy0xMC44LTEwLjgtMTEuMy0xMC44Yy01'
    b'LjEtMTQuOS0zMC4zLTQ2LjYtMzYuMS01MS00LTQuMy02LTYtOS44LTguNC01LjktMi44LTcu'
    b'OC0zLjgtMTEuNC01LjItMy0xLjItLjktNC41IDEtNiAyMC0xMC45IDM1LjctMjIuOSA1NC44'
    b'LTM1LjFsMy0yLTYuOS0zOS4yLTMxLjgtMTEuMmMtMS43IDEuMS0zIDIuMy00LjQgMy40eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZWMwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjQ1'
    b'LjMgNDEzLjFjMC0uNCAyMC00IDIwLTRsLTIuNSA3LjQtMTkuNyA2IDIuMi05LjN6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMi4yIiBk'
    b'PSJNMTkzLjYgMzM4LjVhMzcuOSAzNy45IDAgMCAxIDIxLjYtMjAuNCIvPgogICAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIuNCIgZD0iTTI0NC42'
    b'IDQxMy4zYzEuMy0uMyA3LTIgOC42LTIuMyAxLjgtLjQgMy41LS44IDUuMi0xLjQgMi0uNCAz'
    b'LjItLjggNS4yLTEuMWEzOSAzOSAwIDAgMSA1LTEuNE0yNDEgNDI1LjZhMTQuNiAxNC42IDAg'
    b'MCAxIDIuNS0yYzEuMS0uNCA1LTIgNi41LTIuM2E1NCA1NCAwIDAgMCA0LjctMS40bDQuNi0x'
    b'LjJjMS41LS42IDIuOS0xIDQuNC0xLjQiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0yNDkgMzQxLjRoLS4yYy44IDAgLjMg'
    b'MC0uOSAxLjQtLjQgMS4xLTQgMy43LTYuOCAzLjdhNTMgNTMgMCAwIDEtNC43LjNsLTEuMy0u'
    b'M20xMy43IDUzLjVoMS40YzEuNSAwIDMgLjMgNC4yLjMgMS41IDAgMi45LjQgNC4zLjQgMS41'
    b'LjIgMy4yLjEgNC43LjQgMS42IDAgMyAuMyA0LjcuMyAxLjQuMSAyLjIuMyAzLjcuM2wtMy43'
    b'LS4zYzEuNC4xIDIuMi4zIDMuNy4zbS0zMi43IDMzYTEzLjYgMTMuNiAwIDAgMSAyLjMtMmMx'
    b'LS4zIDQuNi0yIDYtMi4yYTQ2LjcgNDYuNyAwIDAgMCA0LjItMS41bDQuMy0xYzEuMy0uNyAy'
    b'LjYtMS4xIDQtMS41bTUuOC00MS4yYy0uOCAyLjMuMyAyLjkuNyAzLjlhMTIgMTIgMCAwIDAg'
    b'NS43IDMuNGMxLjIuMyAyIC42IDMuNCAxLjIuOSAwIDEuMy4zIDIgLjVtLTEyNC40LTk0Ljho'
    b'LjNjLS45IDAtLjMuMSAxLjEtMSAxLTEuMSAxLjctMS42IDIuNi0yLjdtMTQuNCAyNGMuMiAw'
    b'IDE2LjYtOC4yIDE4LjMtMTBsMy43LTIuOWMxLS41IDEuNy0xLjEgMi42LTEuNy43LTEgMS43'
    b'LTEuNyAyLjMtMi43IDEtLjkuNS0xLjggMS40LTIuOWwxLjMtMy44bTIwLjggMTIuMmMuMS42'
    b'LS4yIDIuNC0uMiAzLjggMCAxLjYtMi4xIDYuNS00LjYgOCIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIuMiIgZD0ibTE5Mi42IDMwNy44'
    b'IDYuNyAyLjFjNSAxLjggMTUuNCA4LjQgMTYuNSA5LjMgMSAuOCAzIDEuNiAzLjYgMi41IDEu'
    b'MiAxIDIgMi4xIDIuOSAzLjIgMSAxLjIgMiAyLjMgMi41IDMuNGExMTMuMiAxMTMuMiAwIDAg'
    b'MSAxMy40IDI0LjVjLjcuNyAxIDEuNyAxLjcgMi44LjYgMS40IDEuMyAyIDIgMy4xIDEgLjcg'
    b'Mi4yIDIgMy40IDIuNiAxLjMgMS4xIDIuNSAxLjUgMy41IDIuMyAxLjMuNiAxNi4zIDEwIDE3'
    b'IDEwLjUgMS40IDEuMSA1LjUgNS40IDIuNiA4LjYtMS4yIDEtMi40IDIuNS0zLjQgMy0xLjEg'
    b'MS4yLTIuNiAxLjctMy45IDIuMi02LjcgMi0xMC4yIDEuMy0xMS41IDEuM2gtMS40bS04OC44'
    b'LTExNC45YzIgLjggMS4yLjIgMi45IDEgMS4yLjUgMiAuNSAzIDEgMS4zLjMgNC43IDEgNi4z'
    b'IDIuNiAxLjIgMSAyIDIgMy40IDIuN2EyMS44IDIxLjggMCAwIDAgNC42IDIuNGMxLjYuNiAz'
    b'LjQgMS4zIDUgMS4zaDcuOC00IDQiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmU2MDYiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIuMiIgZD0iTTE1'
    b'OSAyOTMuM2M0LjItLjMgMTEuMyAxIDExLjUgMWw5LjQtLjJjNS0uNCA2LTIuMyA2LjgtMy43'
    b'IDEuOS0yLjggMy4xLTMuOCA0LjYtNiAyLjItMS42IDUuNCAyLjMgNS41IDIuMyA4IDcuNiAx'
    b'LjYgMTYuOCAxLjIgMTcuMS00IDMuNy00LjkgMy45LTcuMyAxLjYtMi40LTIuOS0zLjEtNC4y'
    b'LTUuMS01LjItMy45LTEuOC0xMS44LS40LTEyLS40bC00LjEgMS42Yy0yIC43LTMuMiAyLjQt'
    b'Ni41IDMtMy41LjItNC42LS4xLTYuMy0yLjktMi4zLTMuNS0xLjItNy44IDIuMy04LjJ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZlZjAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0zODEuOCAxMjAuN2MtLjYgMC02LjMgMi44'
    b'LTYuMiAzIC4xLjEtNC44IDEzLjUtNC45IDEzLjQtLjEtLjItMy41LTExLjctMy45LTExLjUt'
    b'LjMuMi0xMi4zIDEuNi0xMi40IDEuN2w5LTExLjUtMS4zLTEyLjUgOS44IDMuOCAxMC41LThj'
    b'LjItLjEtMi43IDEwLjgtMi43IDEwLjhsNS4yIDcuMnMtMyAzLTMuMSAzLjZ6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIyLjYiIGQ9Ik0yNjUgMjU3LjljNy4xIDQuNyA1MC43IDEzLjkgNTcuMyAx'
    b'NC44YTc3IDc3IDAgMCAxIDI4LjYgMy4yYzguMyAzLjYgMTYuOCAzLjQgMjIuNS0xIDcuOC00'
    b'LjIgMTAuNi0xMS40IDE0LTE4YTEyIDEyIDAgMCAwIDAtMTBjLTIuNi02LjQtMS04LTEuNi0x'
    b'MS42IDkuNC0yMC44IDExLjQtNDUgMTMuNi02Mi45LS4yLTEwLjUuOS0xOC41IDItMjEuN2Ez'
    b'MiAzMiAwIDAgMSAxNi0xMi4ybDQwLjctMTAuNmMxMC42LTMuOCAzLjctMTEgMS41LTEwLjQt'
    b'Ny0xLTYuOC04LjYtMzkuNy0uN2wtMjEuMi0yLjdzLTQtMy4zLTQuNS0zYy0xMS41LTIuMS0x'
    b'My4xIDUuMy0xMi41IDkuOGwxLjYgOS44cy00LjEgMTQuNi0zLjkgMTVjLTEwLjUgMTEuOC0y'
    b'NiA0OS42LTI3IDU2LjktLjUgNi44LTMgNS41LTIuNCAxMi4yIDAgNS4yLS42IDIgMS4xIDEy'
    b'LjYuNSAzLjItMy41IDMtNS43IDItMTkuMi0xMi0zNy40LTE5LjktNTcuNS0zMC41bC0zLjEt'
    b'MS42LTMwLjggMjUuMiA1LjggMzMuMmMxLjggMSAzLjQgMS41IDUuMSAyLjJ6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZmZlYzAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik00MzEuNyAxMzMu'
    b'NmEzNzUgMzc1IDAgMCAxLTEzLjMtMTUuNGw3LjYtMS41IDE0LjggMTQuMy05LjEgMi42eiIv'
    b'PgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIu'
    b'MiIgZD0iTTM5MiAyMTUuMmEzNy45IDM3LjkgMCAwIDEtMjguNC04LjgiLz4KICAgIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjQiIGQ9Ik00MzIu'
    b'MiAxMzQuMWMtMS0uOS01LjItNS02LjItNi40YTY2LjUgNjYuNSAwIDAgMC0zLjgtMy44Yy0x'
    b'LjMtMS41LTIuMy0yLjQtMy42LTRhMzcuMSAzNy4xIDAgMCAxLTMuNi0zLjZtMjkuNiAxNWMt'
    b'LjMgMC0yLS43LTMtMS4yLS44LS45LTQuMi0zLjQtNS4xLTQuNmE1NC4yIDU0LjIgMCAwIDAt'
    b'My41LTMuNGMtMS4yLTEuMy0yLjEtMi0zLjMtMy41YTMwLjMgMzAuMyAwIDAgMS0zLjQtMyIv'
    b'PgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIu'
    b'MiIgZD0ibTM2Ny4zIDE2NS41LjEuM2MtLjQtLjgtLjItLjMgMS43IDAgMS4yLS4yIDUuMiAx'
    b'LjcgNi41IDQuMS44IDEuMSAyIDIuOCAyLjYgNCAuMi4zLjIgMSAuNCAxLjNtNDAtMzguMi0u'
    b'Mi0uMi0uNi0xLTEuOC0zLjljLS43LTEuMi0xLTIuNy0xLjctMy45LS42LTEuNC0xLjUtMi44'
    b'LTItNC4yLS44LTEuNS0xLjItMi44LTItNC40LS43LTEuMi0uOC0yLTEuNi0zLjNsMS42IDMu'
    b'M2MtLjctMS4yLS44LTItMS42LTMuM200NC44IDEyLjNhMTIgMTIgMCAwIDEtMi44LTFjLS44'
    b'LS43LTQtMy01LTRhNDcgNDcgMCAwIDAtMy4zLTNjLTEtMS4zLTEuOS0yLTMtMy4zYTI2LjIg'
    b'MjYuMiAwIDAgMS0zLjItMi43bS0zOC45IDE1YzIuNS0uNCAyLjUtMS42IDMuMS0yLjUuNS0x'
    b'IC45LTMuNS4yLTYuNmwtLjYtMy41Yy0uNC0uOS0uNC0xLjQtLjUtMm0tMjEuNyAxNTQuOC0u'
    b'MS0uMmMuNC44LjIuMy0xLjYtLjVsLTMuNS0xbTEzLjktMjQuM2MtLjEtLjItMTUuMy0xMC40'
    b'LTE3LjctMTEtMS40LS43LTIuNy0xLTQuMy0xLjhsLTIuOC0xLjRjLTEuMy0uMi0yLjQtLjct'
    b'My41LS43LTEuMi0uNC0xLjkuNC0zLjIuMmwtNCAuN20uNS0yNC4xYy40LS40IDIuMi0xIDMu'
    b'NC0xLjcgMS40LS43IDYuNy0xLjMgOS4yLjEiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Im0zNjUuNyAyMzEuMi0xLjUtN2Ex'
    b'MDAgMTAwIDAgMCAxIDAtMTguOGMuMi0xLjMgMC0zLjQuNS00LjUuMy0xLjQuOC0yLjcgMS4z'
    b'LTQgLjYtMS41IDEuMS0yLjggMS43LTMuOS43LTQgMTItMjAuMSAxMi44LTIwLjlhNDMgNDMg'
    b'MCAwIDEgMi0yLjdjLjMtMSAxLTEuOCAxLjYtMyAxLTEuMSAxLjItMiAxLjgtMy4yLjEtMS4x'
    b'LjYtMi45LjYtNC4yLjMtMS43IDAtMyAuMy00LjEtLjItMS41LjctMTkuMi44LTIwIC4zLTEu'
    b'OCAyLTcuNSA2LjItNi41IDEuNS41IDMuMy44IDQuNCAxLjUgMS40LjQgMi42IDEuNSAzLjcg'
    b'Mi4zIDUgNC45IDYuMSA4LjIgNi44IDkuNGwuNyAxLjJNMzUyLjYgMjc2bC0uMS0uMmMuNC43'
    b'LjIuMy0uMy0xLjEtLjEtMS4zLS41LTMtLjctNC4yLS4zLTEuMy0uOS0yLjctLjctMy41LS41'
    b'LTEuMy0uMi0yLjMgMC0zLjYuMy0xLjYuNS0yLjcuNS00LjIuMi0yIDAtMy4yLjEtNS0uNS0x'
    b'LjUtLjYtMi43LTEuMy00LjJsLTItNC0yLTMuNSAyIDMuNC0yLTMuNCIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZTYwNiIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iMi4yIiBkPSJNMzY5LjUgMjY3LjZjLTIuMy0zLjYtNC43LTEwLjQtNC44LTEw'
    b'LjVsLTQuNy04LjJjLTIuOC00LTUtNC02LjYtNC0zLjQtLjMtNC45LTEtNy40LTEuMS0yLjYt'
    b'MS4yLS43LTUuOS0uOC02IDIuNy0xMC42IDE0LTkuNiAxNC40LTkuNCA1LjEgMS43IDUuNyAy'
    b'LjQgNC45IDUuNi0xLjMgMy41LTIgNC44LTIgNyAuMyA0LjIgNS41IDEwLjUgNS41IDEwLjZs'
    b'My40IDIuOGMxLjYgMS40IDMuNyAxLjYgNS44IDQuMyAxLjkgMi45IDIuMiA0IC42IDYuOC0y'
    b'IDMuOC02LjIgNC45LTguMyAyLjF6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZlZjAwIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0x'
    b'MDUuMiAxNjguN2MuNS40IDUuOCAzLjcgNiAzLjVzMTQtMy40IDEzLjgtMy4yLTcuOCA5LjMt'
    b'Ny40IDkuNWMuNC4yIDggOS40IDguMiA5LjVsLTE0LjUtMS4yLTkuOCA3LjgtMi4yLTEwLjJM'
    b'ODcgMTgwYy0uMi0uMSAxMC41LTMuNiAxMC41LTMuNmwzLjItOC4zczQuMS43IDQuNy42eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMi42IiBkPSJNMjg0IDE5MS4zYzAtOC43LTE2LjItNTAuMi0x'
    b'OS01Ni4xYTc3LjIgNzcuMiAwIDAgMS0xMy0yNS43Yy0xLjUtOS02LjMtMTYtMTMtMTguNC03'
    b'LjktNC4xLTE1LjUtMi41LTIyLjgtMS44LTMuNi43LTYuNyAyLjctOC40IDUuNS00IDUuNy02'
    b'LjEgNS4yLTguOSA3LjctMjIuNSAzLjUtNDMuOCAxNS4xLTYwIDIzYTY4IDY4IDAgMCAxLTE5'
    b'LjMgMTAuMiAzMiAzMiAwIDAgMS0xOS02LjZsLTMxLjEtMjguM2MtOS02LjctMTEuMiAzLTku'
    b'NSA0LjUgMyA2LjQtMy41IDEwLjMgMjEuMiAzMy42bDkuMyAxOS4ycy0uNSA1LjIgMCA1LjRj'
    b'NC40IDEwLjggMTEuNiA4LjEgMTUgNS4xbDcuMy02LjdzMTQuNS00LjYgMTQuNy01YzE1LjYg'
    b'Mi4zIDU1LjgtNS4zIDYyLjQtOC41IDYtMy4zIDYuMy0uNSAxMS41LTQuNyA0LjMtMi45IDIt'
    b'LjYgMTAtNy45IDIuNC0yIDQuMyAxLjMgNC44IDMuNy40IDIyLjcgMy44IDQyLjIgNS45IDY0'
    b'LjhsLjQgMy41IDM4IDEyIDI0LjYtMjMtMS01LjZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZl'
    b'YzAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik04OC43IDExOS44Yy4zLjMtNS42IDE5LjYt'
    b'NS42IDE5LjZsLTUuNC01LjUgMy44LTIwLjMgNy4yIDYuMnoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0xNzguOCAxMDgu'
    b'NGM3LjIgOCA5LjUgMjEuMiA4LjIgMjguNiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIuNCIgZD0iTTg5IDExOS4xYy0uMyAxLjMtMS41'
    b'IDcuMi0yIDguN2E2Ni44IDY2LjggMCAwIDAtMS4yIDUuM2wtMS40IDUuMmMtLjIgMS43LS41'
    b'IDMuMy0xIDVtLTMuNy0zM2MuMS4zLjUgMiAuNiAzLjEtLjIgMS4yLS41IDUuNC0xIDYuOWE1'
    b'NC40IDU0LjQgMCAwIDAtLjkgNC44bC0xIDQuNmEzMC42IDMwLjYgMCAwIDEtLjggNC42Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMi4y'
    b'IiBkPSJtMTUwLjcgMTU2LjMuMS0uM2MtLjQuOCAwIC4zLS44LTEuNC0uOS0xLTEuNC01LjMt'
    b'LjItNy44YTU1IDU1IDAgMCAxIDItNC4zYy4xLS4zLjYtLjcuOC0xTTk4LjggMTI5bC0uMS4y'
    b'LS42IDFjLS42IDEuNC0xLjYgMi42LTIuMiAzLjctLjYgMS4zLTEuNyAyLjMtMi4zIDMuNmwt'
    b'Mi40IDRjLS45IDEuNC0xLjggMi41LTIuNiA0bC0yIDMuMiAyLTMuMi0yIDMuMm0tMTQuMi00'
    b'NC4zYy4yLjIuNyAxLjkuOCAzLS4yIDEtLjQgNS0uOCA2LjNsLS43IDQuNGMtLjQgMS42LS41'
    b'IDIuNy0xIDQuM2EyNi4yIDI2LjIgMCAwIDEtLjUgNC4yTTEwNCAxNTFjLTEuNy0xLjktMi43'
    b'LTEuMi0zLjgtMS4zYTEyIDEyIDAgMCAwLTUuNyAzLjVjLS44LjktMS41IDEuNi0yLjYgMi41'
    b'LS41LjgtLjkgMS0xLjQgMS41TTIzMiA5MC40bC0uMS4zYy40LS44LjEtLjQuNSAxLjUuNSAx'
    b'LjMuNSAyLjIgMSAzLjRtLTI3LjkgMS44YzAgLjItLjMgMTguNS41IDIwLjkuMiAxLjUuNiAy'
    b'LjcuOCA0LjYgMCAxIC4zIDIgLjQgMyAuNiAxLjIuNyAyLjQgMS40IDMuMy4zIDEuMyAxLjMg'
    b'MS40IDEuOSAyLjUuNy45IDIgMi40IDIuOCAzbS0yMC41IDEyLjljLS42LS4yLTItMS40LTMu'
    b'Mi0yLTEuNC0uOC00LjktNC45LTUtNy44Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMi4yIiBkPSJtMjA2LjUgMTIxLjYtNSA1YTk0LjMg'
    b'OTQuMyAwIDAgMS0xNS44IDEwLjNjLTEuMi42LTIuNyAyLTQgMi4xLTEuMy42LTIuNy44LTQg'
    b'MS4xYTExMy40IDExMy40IDAgMCAxLTI4LjcgMS41IDQzLjIgNDMuMiAwIDAgMS0zLjQtLjJj'
    b'LTEgLjItMiAuMS0zLjMuMi0xLjYtLjEtMi40LjItMy43LjMtMSAuNi0yLjcgMS4xLTMuOSAx'
    b'LjktMS41LjYtMi41IDEuNS0zLjYgMi0xIC45LTE2LjQgOS44LTE3LjIgMTAuMi0xLjYuNy03'
    b'LjMgMi41LTguOC0xLjYtLjQtMS42LTEtMy4zLTEuMS00LjUtLjUtMS40LS4yLTMtLjItNC40'
    b'IDEuNC02LjkgMy42LTkuNiA0LjItMTAuOGwuNy0xLjJNMjUxIDEwOGwtLjEuM2MuMy0uNy4y'
    b'LS40LS44LjgtMSAuOC0yLjIgMi0zLjEgMy0xIC44LTEuOCAyLTIuNiAyLjQtLjggMS0xLjgg'
    b'MS40LTMgMmEyMCAyMCAwIDAgMC0zLjggMS45Yy0xLjcuOC0yLjcgMS43LTQuMiAyLjYtMSAx'
    b'LjItMiAyLTIuOCAzLjQtLjggMS4zLTEuNiAyLjQtMi4zIDMuOWwtMS44IDMuNSAxLjgtMy41'
    b'LTEuOCAzLjVtMTEuNyA3My4xLjMtLjVjLS41IDEtLjQuNy4xLS45IDAtMS44LjUtNC4xLjUt'
    b'NS44LjMtMS44LjYtMy43LjYtNS41LS4xLTItLjEtNC0uNC02IDAtMS44LS4zLTMuNy0uMy01'
    b'LjYgMC0xLjgtLjItMy4zLS42LTVhMjkuNSAyOS41IDAgMCAwLS40LTQuOGMuMS0xLjItLjIt'
    b'Mi40LS41LTMuNGwtMS4yLTUuMS0xLTQuMWMtLjItMS42LTEtMy42LTEuNC00LjlhMTMuNiAx'
    b'My42IDAgMCAxLTEuMS0zLjRjLS41LTEuMS0xLjItMi40LTEuMy0zLjZsLTEuNi0zLjctMS40'
    b'LTMuNmMtLjUtMS40LTEuMS0yLjYtMS41LTQtLjUtLjUtLjYtMS0uOC0xLjQiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmU2MDYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9IjIuMiIgZD0iTTIzNC45IDk4LjVhNTkgNTkgMCAwIDEtNi4yIDkuN2wt'
    b'NC4yIDguNGMtMS44IDQuNi0uNyA2LjUuMSA3LjggMS43IDMgMiA0LjYgMy4yIDYuOC41IDIu'
    b'OC00LjUgMy44LTQuNSAzLjktMTAuNCAzLjYtMTUuNy02LjQtMTUuNy02LjktMS40LTUuMi0x'
    b'LjItNiAyLTcuMSAzLjYtLjkgNS0xIDYuOC0yLjIgMy41LTIuNiA1LjktMTAuMyA2LTEwLjRs'
    b'LjQtNC40Yy4zLTItLjYtNCAuNC03LjIgMS40LTMuMiAyLjItNCA1LjQtNC4zIDQuMi0uMyA3'
    b'LjUgMi42IDYuMyA1Ljl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZlZjAwIiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0yMjEuMyAx'
    b'OTkuN2MtMS42LTEuNSAyOS40IDExLjIgMzMuNyAxMS4zIDUuOC0yLjEgMjkuOS0yMi40IDI5'
    b'LjktMjIuNC4yIDIgMS4xIDcuMSAzLjQgOC4yLTkuMyA3LjUtMTcuNyAxNC44LTI3IDIyLjMu'
    b'NiAxMi0xLjUgMjQuNyA0LjUgMzggMCAwLTcuMi4yLTcuMiAwLTYuNC02LjQtOC43LTM3LjIt'
    b'OC43LTM3LjJsLTMwLjYtMTMuNmMxLjUtMSAyLjYtMy45IDItNi43eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIuMiIgZD0iTTI1MC44'
    b'IDIzMS4zYy41LS40LTUuNiAyLjgtNy4yIDMuNi0yOC4xIDE1LTQyLjYgMzctNDMuNSAzNy44'
    b'bC0yLjIgMy40LTIuMyAzYTYwLjYgNjAuNiAwIDAgMS0zLjYgNC43Yy0uMi42LjQtLjMuMi4y'
    b'bTc3LjktNzAuNmE3OSA3OSAwIDAgMCA2LjUgNC43YzI2LjIgMTguMiA1Mi4zIDIxLjEgNTMu'
    b'NSAyMS41IDEgMCAyLjUuMyA0IC41IDEuMiAwIDIuNi40IDMuOC41IDEuNC4yIDQuNC44IDUu'
    b'OCAxLjIuNi0uMi0uNS0uMyAwLS40Ii8+CiAgPC9nPgo8L3N2Zz4K', 'IM')

IM = b64_IM
index.append("IM")
index.append("IMN")
index.append("Isle of Man")
catalog["IM"] = IM
catalog["IMN"] = IM
catalog["Isle of Man"] = IM
country["Isle of Man"] = ('IM', 'IMN', 0)
lookup["IM"] = ('IM', 'IMN', 'Isle of Man', 0)
lookup["Douglas Isle of Man"] = ('IM', 'IMN', 'Isle of Man', 0)
lookup["IMN"] = ('IM', 'IMN', 'Isle of Man', 0)
lookup["Isle of Man"] = ('IM', 'IMN', 'Isle of Man', 0)
details["IM"] = {"continent":"Europe","capital":"Douglas","currency":"Pound Sterling","web":".im","lang":"en | gv","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_IN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1pbiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmOTMiIGQ9Ik0wIDBoNjQwdjE2MEgw'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDE2MGg2NDB2MTYwSDB6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzEyODgwNyIgZD0iTTAgMzIwaDY0MHYxNjBIMHoiLz4KICA8ZyB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgzLjIgMCAwIDMuMiAzMjAgMjQwKSI+CiAgICA8Y2lyY2xlIHI9IjIwIiBm'
    b'aWxsPSIjMDA4Ii8+CiAgICA8Y2lyY2xlIHI9IjE3LjUiIGZpbGw9IiNmZmYiLz4KICAgIDxj'
    b'aXJjbGUgcj0iMy41IiBmaWxsPSIjMDA4Ii8+CiAgICA8ZyBpZD0iaW4tZCI+CiAgICAgIDxn'
    b'IGlkPSJpbi1jIj4KICAgICAgICA8ZyBpZD0iaW4tYiI+CiAgICAgICAgICA8ZyBpZD0iaW4t'
    b'YSIgZmlsbD0iIzAwOCI+CiAgICAgICAgICAgIDxjaXJjbGUgcj0iLjkiIHRyYW5zZm9ybT0i'
    b'cm90YXRlKDcuNSAtOC44IDEzMy41KSIvPgogICAgICAgICAgICA8cGF0aCBkPSJNMCAxNy41'
    b'LjYgNyAwIDJsLS42IDVMMCAxNy41eiIvPgogICAgICAgICAgPC9nPgogICAgICAgICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjaW4tYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNm'
    b'b3JtPSJyb3RhdGUoMTUpIi8+CiAgICAgICAgPC9nPgogICAgICAgIDx1c2UgeGxpbms6aHJl'
    b'Zj0iI2luLWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0icm90YXRl'
    b'KDMwKSIvPgogICAgICA8L2c+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI2luLWMiIHdpZHRo'
    b'PSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0icm90YXRlKDYwKSIvPgogICAgPC9n'
    b'PgogICAgPHVzZSB4bGluazpocmVmPSIjaW4tZCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAw'
    b'JSIgdHJhbnNmb3JtPSJyb3RhdGUoMTIwKSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjaW4t'
    b'ZCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoLTEyMCki'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'IN')

IN = b64_IN
index.append("IN")
index.append("IND")
index.append("India")
catalog["IN"] = IN
catalog["IND"] = IN
catalog["India"] = IN
country["India"] = ('IN', 'IND', 0)
lookup["IN"] = ('IN', 'IND', 'India', 0)
lookup["New Delhi India"] = ('IN', 'IND', 'India', 0)
lookup["IND"] = ('IN', 'IND', 'India', 0)
lookup["India"] = ('IN', 'IND', 'India', 0)
details["IN"] = {"continent":"Asia","capital":"New Delhi","currency":"Indian Rupee","web":".in","lang":"en-IN | hi | bn | te | mr | ta | ur | gu | kn | ml | or | pa | as | bh | sat | ks | ne | sd | kok | doi | mni | sit | sa | fr | lus | inc","tz":"+05:30","altname":""}
#----------------------------------------------------------------------
b64_IO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWlvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMDA2MyIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNNjQwIDQxNi4yYy03LjIgNi43LTEzLjMgMjItMzIuNCAyMi0zOC4xIDAtNDcu'
    b'Ni0zMi41LTc2LjItMzIuNS0xOSAwLTI4LjUgMzIuNS00Ny42IDMyLjUtMzguMSAwLTQ3LjYt'
    b'MzIuNS03Ni4yLTMyLjUtMTkgMC0yOC41IDMyLjUtNDcuNSAzMi41LTM4LjIgMC00Ny43LTMy'
    b'LjUtNzYuMy0zMi41LTE5IDAtMjguNiAzMi41LTQ3LjYgMzIuNS0zOC4xIDAtNDcuNi0zMi41'
    b'LTc2LjItMzIuNS0xOSAwLTI4LjYgMzIuNS00Ny42IDMyLjUtMzguMiAwLTQ3LjctMzIuNS03'
    b'Ni4yLTMyLjUtMTkgMC0yNC44IDIzLjItMzYuMiAyMy4ydjQxLjdjMTEuNCAwIDE3LjEtMjMg'
    b'MzYuMy0yMyAyOC41IDAgMzggMzIuNCA3NiAzMi40IDE5LjEgMCAyOC42LTMyLjUgNDcuNy0z'
    b'Mi41IDI4LjYgMCAzOC4xIDMyLjUgNzYuMyAzMi41IDE5IDAgMjguNC0zMi41IDQ3LjUtMzIu'
    b'NSAyOC42IDAgMzguMSAzMi41IDc2LjIgMzIuNSAxOSAwIDI4LjYtMzIuNSA0Ny42LTMyLjUg'
    b'MjguNiAwIDM4LjEgMzIuNSA3Ni4yIDMyLjUgMTkgMCAyOC42LTMyLjUgNDcuNi0zMi41IDI4'
    b'LjYgMCAzOC4yIDMyLjUgNzYuMiAzMi41IDE5IDAgMjUuMi05LjIgMzIuNC0xNS44em0wLTgx'
    b'LjJjLTcuMiA2LjctMTMuMyAyMi0zMi40IDIyLTM4LjEgMC00Ny42LTMyLjUtNzYuMi0zMi41'
    b'LTE5IDAtMjguNSAzMi41LTQ3LjYgMzIuNS0zOC4xIDAtNDcuNi0zMi41LTc2LjItMzIuNS0x'
    b'OSAwLTI4LjUgMzIuNS00Ny41IDMyLjUtMzguMiAwLTQ3LjctMzIuNS03Ni4zLTMyLjUtMTkg'
    b'MC0yOC42IDMyLjUtNDcuNiAzMi41LTM4LjEgMC00Ny42LTMyLjUtNzYuMi0zMi41LTE5IDAt'
    b'MjguNiAzMi41LTQ3LjYgMzIuNS0zOC4yIDAtNDcuNy0zMi41LTc2LjItMzIuNS0xOSAwLTI0'
    b'LjggMjMuMi0zNi4yIDIzLjJ2NDEuOGMxMS40IDAgMTcuMS0yMy4xIDM2LjMtMjMuMSAyOC41'
    b'IDAgMzggMzIuNSA3NiAzMi41IDE5LjEgMCAyOC42LTMyLjUgNDcuNy0zMi41IDI4LjYgMCAz'
    b'OC4xIDMyLjUgNzYuMyAzMi41IDE5IDAgMjguNC0zMi41IDQ3LjUtMzIuNSAyOC42IDAgMzgu'
    b'MSAzMi41IDc2LjMgMzIuNSAxOSAwIDI4LjUtMzIuNSA0Ny41LTMyLjUgMjguNiAwIDM4LjEg'
    b'MzIuNSA3Ni4yIDMyLjUgMTkgMCAyOC42LTMyLjUgNDcuNi0zMi41IDI4LjYgMCAzOC4yIDMy'
    b'LjUgNzYuMiAzMi41IDE5IDAgMjUuMi05LjIgMzIuNC0xNS44em0wLTgxLjFjLTcuMiA2Ljct'
    b'MTMuMyAyMi0zMi40IDIyLTM4LjEgMC00Ny42LTMyLjUtNzYuMi0zMi41LTE5IDAtMjguNSAz'
    b'Mi41LTQ3LjYgMzIuNS0zOC4xIDAtNDcuNi0zMi41LTc2LjItMzIuNS0xOSAwLTI4LjUgMzIu'
    b'NS00Ny41IDMyLjUtMzguMiAwLTQ3LjctMzIuNS03Ni4zLTMyLjUtMTkgMC0yOC42IDMyLjUt'
    b'NDcuNiAzMi41LTM4LjEgMC00Ny42LTMyLjUtNzYuMi0zMi41LTE5IDAtMjguNiAzMi41LTQ3'
    b'LjYgMzIuNS0zOC4yIDAtNDcuNy0zMi41LTc2LjItMzIuNS0xOSAwLTI0LjggMjMuMi0zNi4y'
    b'IDIzLjJ2NDEuOGMxMS40IDAgMTcuMS0yMy4yIDM2LjMtMjMuMiAyOC41IDAgMzggMzIuNSA3'
    b'NiAzMi41IDE5LjEgMCAyOC42LTMyLjUgNDcuNy0zMi41IDI4LjYgMCAzOC4xIDMyLjUgNzYu'
    b'MyAzMi41IDE5IDAgMjguNC0zMi41IDQ3LjUtMzIuNSAyOC42IDAgMzguMSAzMi41IDc2LjMg'
    b'MzIuNSAxOSAwIDI4LjUtMzIuNSA0Ny41LTMyLjUgMjguNiAwIDM4LjEgMzIuNSA3Ni4yIDMy'
    b'LjUgMTkgMCAyOC42LTMyLjUgNDcuNi0zMi41IDI4LjYgMCAzOC4yIDMyLjUgNzYuMiAzMi41'
    b'IDE5IDAgMjUuMi05LjIgMzIuNC0xNS44em0wLTgxLjFjLTcuMiA2LjYtMTMuMyAyMi0zMi40'
    b'IDIyLTM4LjEgMC00Ny42LTMyLjUtNzYuMi0zMi41LTE5IDAtMjguNSAzMi41LTQ3LjYgMzIu'
    b'NS0zOC4xIDAtNDcuNi0zMi41LTc2LjItMzIuNS0xOSAwLTI4LjUgMzIuNS00Ny41IDMyLjUt'
    b'MzguMiAwLTQ3LjctMzIuNS03Ni4zLTMyLjUtMTkgMC0yOC42IDMyLjUtNDcuNiAzMi41LTM4'
    b'LjEgMC00Ny42LTMyLjUtNzYuMi0zMi41LTE5IDAtMjguNiAzMi41LTQ3LjYgMzIuNS0zOC4y'
    b'IDAtNDcuNy0zMi41LTc2LjItMzIuNS0xOSAwLTI0LjggMjMuMi0zNi4yIDIzLjJ2NDEuN2Mx'
    b'MS40IDAgMTcuMS0yMyAzNi4zLTIzIDI4LjUgMCAzOCAzMi40IDc2IDMyLjQgMTkuMSAwIDI4'
    b'LjYtMzIuNSA0Ny43LTMyLjUgMjguNiAwIDM4LjEgMzIuNSA3Ni4zIDMyLjUgMTkgMCAyOC40'
    b'LTMyLjUgNDcuNS0zMi41IDI4LjYgMCAzOC4xIDMyLjUgNzYuMyAzMi41IDE5IDAgMjguNS0z'
    b'Mi41IDQ3LjUtMzIuNSAyOC42IDAgMzguMSAzMi41IDc2LjIgMzIuNSAxOSAwIDI4LjYtMzIu'
    b'NSA0Ny42LTMyLjUgMjguNiAwIDM4LjIgMzIuNSA3Ni4yIDMyLjUgMTkgMCAyNS4yLTkuMyAz'
    b'Mi40LTE1Ljl6bTAtODEuM2MtNy4yIDYuNy0xMy4zIDIyLjEtMzIuNCAyMi4xLTM4LjEgMC00'
    b'Ny42LTMyLjUtNzYuMi0zMi41LTE5IDAtMjguNSAzMi41LTQ3LjYgMzIuNS0zOC4xIDAtNDcu'
    b'Ni0zMi41LTc2LjItMzIuNS0xOSAwLTI4LjUgMzIuNS00Ny41IDMyLjUtMzguMiAwLTQ3Ljct'
    b'MzIuNS03Ni4zLTMyLjUtMTkgMC0yOC42IDMyLjUtNDcuNiAzMi41LTM4LjEgMC00Ny42LTMy'
    b'LjUtNzYuMi0zMi41LTE5IDAtMjguNiAzMi41LTQ3LjYgMzIuNS0zOC4yIDAtNDcuNy0zMi41'
    b'LTc2LjItMzIuNS0xOSAuMS0yNC44IDIzLjMtMzYuMiAyMy4zdjQxLjhjMTEuNCAwIDE3LjEt'
    b'MjMuMSAzNi4yLTIzLjEgMjguNSAwIDM4LjEgMzIuNSA3Ni4yIDMyLjUgMTkgMCAyOC41LTMy'
    b'LjUgNDcuNi0zMi41IDI4LjYgMCAzOC4xIDMyLjUgNzYuMyAzMi41IDE5IDAgMjguNC0zMi41'
    b'IDQ3LjQtMzIuNSAyOC43IDAgMzguMiAzMi41IDc2LjMgMzIuNSAxOSAwIDI4LjYtMzIuNSA0'
    b'Ny42LTMyLjUgMjguNiAwIDM4LjEgMzIuNSA3Ni4yIDMyLjUgMTkgMCAyOC42LTMyLjUgNDcu'
    b'Ni0zMi41IDI4LjYgMCAzOC4yIDMyLjUgNzYuMiAzMi41IDE5IDAgMjUuMi05LjMgMzIuNC0x'
    b'NS45di00OFptMC04MWMtNy4yIDYuNi0xMy4zIDIyLTMyLjQgMjJDNTY5LjUgMzIuNSA1NjAg'
    b'MCA1MzEuNCAwYy0xOSAwLTI4LjUgMzIuNS00Ny42IDMyLjUtMzguMSAwLTQ3LjYtMzIuNS03'
    b'Ni4yLTMyLjUtMTkgMC0yOC41IDMyLjUtNDcuNSAzMi41LTM4LjIgMC00Ny43LTMyLjUtNzYu'
    b'My0zMi41LTE5IDAtMjguNiAzMi41LTQ3LjYgMzIuNUMxOTggMzIuNSAxODguNiAwIDE2MCAw'
    b'Yy0xOSAwLTI4LjYgMzIuNS00Ny42IDMyLjVDNzQuMiAzMi41IDY0LjcgMCAzNi4yIDAgMTcu'
    b'MiAwIDExLjQgMjMuMiAwIDIzLjJ2NDEuOUMxMS40IDY1IDE3LjEgNDIgMzYuMiA0MmMyOC41'
    b'IDAgMzguMSAzMi40IDc2LjIgMzIuNCAxOSAwIDI4LjUtMzIuNCA0Ny42LTMyLjQgMjguNiAw'
    b'IDM4LjEgMzIuNCA3Ni4zIDMyLjQgMTkgMCAyOC40LTMyLjQgNDcuNC0zMi40IDI4LjcgMCAz'
    b'OC4yIDMyLjQgNzYuMyAzMi40IDE5IDAgMjguNi0zMi40IDQ3LjYtMzIuNCAyOC42IDAgMzgu'
    b'MSAzMi40IDc2LjIgMzIuNCAxOSAwIDI4LjYtMzIuNCA0Ny42LTMyLjQgMjguNiAwIDM4LjIg'
    b'MzIuNCA3Ni4yIDMyLjQgMTkgMCAyNS4yLTkuMiAzMi40LTE1Ljh6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2EyNDMwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNmZmYiIHN0cm9rZS13'
    b'aWR0aD0iMi4xIiBkPSJtNDc0LjggMTMxLjctMy41IDMyOWMwIDE3LjMgMTUuNyAxNy4zIDE3'
    b'LjQgMGwtMy41LTMyOVoiLz4KICA8cGF0aCBmaWxsPSIjMDA2ZDAwIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxLjgiIGQ9Im01MTAuNyAyNTQt'
    b'MTEtMTEuOS0yLjYgMTIuMS00LjctMTcuNS00LjUgOC44LS44LTE4LjYtNC40IDguOC0uOC0x'
    b'OC42LTQuNCA4LjhMNDc1IDIwNGwtNC40IDguOEw0NjggMTkxbC00LjUgOC44LTIuNS0yMS45'
    b'LTEuMy0xMSAyLjItNC4zIDUuOCAyLjEgOS4xIDguNyAxOC4zIDE3LjQtMTEuMy00LjMgMTgu'
    b'MyAxNy40LTExLjQtNC4zIDE4LjMgMTcuMy0xMS40LTQuMiAxNi42IDE0LTExLjMtNC4yIDE2'
    b'LjUgMTQtMTEuMy00LjIgMTIuNiAxNS4yLTEzLjEtNy42IDMgMTQuM3oiLz4KICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik01MTAuNyAy'
    b'NTQgNDYyIDE2Mi42bTMzLjEgMjguMkw0NjkgMTc1LjZsLTUuNCAyNC4xIi8+CiAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNTAyLjIg'
    b'MjAzLjgtMjYuMy0xNS4xLTUuMyAyNC4xIi8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNTA5LjEgMjE2LjgtMjYuMi0xNS01LjQg'
    b'MjQiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0i'
    b'LjMiIGQ9Im01MTQuMyAyMjYuNy0yNC41LTExLjktNyAyMSIvPgogIDxwYXRoIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTUxOS41IDIzNi41IDQ5'
    b'NSAyMjQuNmwtNyAyMSIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIuMyIgZD0ibTUyMC44IDI0Ny40LTIyLjMtMTYuMi0xLjQgMjMiLz4KICA8'
    b'cGF0aCBmaWxsPSIjMDA2ZDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2ZmZiIg'
    b'c3Ryb2tlLXdpZHRoPSIyIiBkPSJtMzgzIDk3LjkgMTcuOCA2LjgtNS4yLTEzLjUgMTUuNiAx'
    b'NS4zLTEuNS0xMSAxMi42IDE4LjQtMS41LTExIDEyLjYgMTguNC0xLjUtMTEgMTYuMyAyMC44'
    b'LTEuNS0xMSAxNi4zIDIwLjgtMS40LTExIDE2LjIgMjAuOCA4LjIgMTAuNC43IDUuNS02Ljcu'
    b'Ni0xNC00LjMtMjguMi04LjcgMTMuMy0xLjEtMjguMS04LjcgMTMuMy0xLjEtMjguMS04Ljcg'
    b'MTMuMy0xLjItMjQuNC02LjIgMTMuMy0xLjEtMjQuNC02LjIgMTMuMy0xLjItMjEuNS05LjMg'
    b'MTcuMSAxLjNMMzgzLjEgOTh6Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtMzgzIDk3LjkgMTAzLjcgNjguN20tNDguOS0xMi40'
    b'IDM0LjEgMi42LTEwLjMtMjYuOSIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTQyMyAxNDQuNCAzNCAyLjYtMTAuMy0yNyIvPgog'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0i'
    b'bTQwOC4yIDEzNC42IDM0IDIuNi0xMC4zLTI3Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtMzk3IDEyNy4yIDMwLjUuMS02Ljct'
    b'MjQuNCIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIuMyIgZD0ibTM4NiAxMTkuOCAzMC40LjItNi43LTI0LjUiLz4KICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0zNzcuOCAxMDkuNCAz'
    b'MS4xIDUuNy0xMy4yLTIzLjkiLz4KICA8cGF0aCBmaWxsPSIjMDA2ZDAwIiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIyIiBkPSJNNTg5LjggMTIw'
    b'LjggNTc1IDEzMS43bDE2LjQgMS44LTIyLjkgNS40IDEyLjIgMy42LTI0LjcgMS44IDEyLjIg'
    b'My42LTI0LjcgMS44IDEyLjEgMy43LTI4LjkgMy42IDEyLjIgMy42LTI4LjkgMy42IDEyLjIg'
    b'My42LTI4LjkgMy42LTE0LjUgMS44LTYtMS44IDIuMi01LjQgMTAuNy05IDIxLjMtMTguMS00'
    b'LjYgMTAuOCAyMS4zLTE4LTQuNiAxMC44IDIxLjMtMTgtNC42IDEwLjhMNTUzIDExOWwtNC41'
    b'IDEwLjkgMTctMTYuMy00LjUgMTAuOCAxOS0xMi42LTguNyAxMi43IDE4LjYtMy42eiIvPgog'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0i'
    b'bTU4OS44IDEyMC44LTExNyA1MC42bTM0LjEtMzIuNS0xNy40IDI1LjMgMzIuNyAzLjYiLz4K'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9'
    b'Ik01MjMuNyAxMzEuNyA1MDYuMiAxNTdsMzIuNyAzLjYiLz4KICA8cGF0aCBmaWxsPSJub25l'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im01NDAuNCAxMjQuNC0xNy41'
    b'IDI1LjMgMzIuNyAzLjciLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iLjMiIGQ9Im01NTMgMTE5LTEzLjMgMjMuNSAyOC41IDUuNCIvPgogIDxw'
    b'YXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTU2'
    b'NS41IDExMy42LTEzLjMgMjMuNSAyOC41IDUuNCIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTU4MCAxMTEuOC0xOS40IDIxLjdo'
    b'MzAuNyIvPgogIDxwYXRoIGZpbGw9IiMwMDZkMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlPSIjZmZmIiBzdHJva2Utd2lkdGg9IjIiIGQ9Ik01ODcuNCAyMzAuMyA1NjkgMjI1bDYu'
    b'NiAxMy0xNy4xLTE0IDIuNiAxMC43LTE0LjUtMTcuMiAyLjcgMTAuOC0xNC41LTE3LjMgMi42'
    b'IDEwLjgtMTguNS0xOS40IDIuNyAxMC44LTE4LjUtMTkuNCAyLjcgMTAuOC0xOC41LTE5LjQt'
    b'OS4yLTkuNy0xLjMtNS40IDYuNi0xLjIgMTQuNSAzLjIgMjkgNi40LTEzLjIgMi4yIDI5IDYu'
    b'NC0xMy4yIDIuMiAyOSA2LjQtMTMuMiAyLjMgMjUgNC4yLTEzLjIgMi4yIDI1IDQuMkw1Njkg'
    b'MjExbDIyLjMgNy41aC0xN2wxMyAxMnoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im01ODcuNCAyMzAuMy0xMTAuNi02MC4ybTUw'
    b'IDguNC0zNC4yLjIgMTMuMiAyNiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTU0Mi42IDE4Ny4xLTM0LjIuMiAxMy4yIDI2Ii8+'
    b'CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBk'
    b'PSJtNTU4LjQgMTk1LjctMzQuMi4yIDEzLjIgMjYiLz4KICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im01NzAuMyAyMDIuMi0zMC4zIDIu'
    b'MyA5LjMgMjMuOCIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIuMyIgZD0ibTU4Mi4yIDIwOC43LTMwLjMgMi4yIDkuMiAyMy44Ii8+CiAgPHBh'
    b'dGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNTkx'
    b'LjMgMjE4LjQtMzEuNS0zLjIgMTUuOCAyMi44Ii8+CiAgPHBhdGggZmlsbD0iIzAwNmQwMCIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0iMS44IiBk'
    b'PSJtMzk1LjIgMjM2LjYgOS4zLTEzLTE0LjEgMi4xIDE3LjQtOS45LTExLjEtLjUgMjAtNy0x'
    b'MS4xLS42IDIwLTctMTEuMS0uNiAyMy05LjYtMTEuMi0uNSAyMy05LjctMTEuMS0uNSAyMy05'
    b'LjYgMTEuNS00LjkgNS42LjMtLjQgNS4zLTYuMyAxMC40LTEyLjYgMjAuOC44LTEwLjYtMTIu'
    b'NiAyMC44LjctMTAuNy0xMi42IDIwLjguNy0xMC42LTkuNiAxOC4yLjctMTAuNi05LjYgMTgu'
    b'Mi43LTEwLjYtMTIuMiAxNS40IDMuNy0xMy4yLTE0LjUgNy40eiIvPgogIDxwYXRoIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTM5NS4yIDIzNi42'
    b'IDgzLTcxbS0xOS4xIDM2LjUgNy4zLTI2LjQtMjguMiA0LjEiLz4KICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im00NDcuMiAyMTIuMyA3'
    b'LjMtMjYuNC0yOC4yIDQiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iLjMiIGQ9Im00MzUuMyAyMjIuNCA3LjQtMjYuNC0yOC4yIDQuMSIvPgog'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0i'
    b'bTQyNi40IDIzMCA0LjQtMjMuOC0yNS4yIDEuNSIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTQxNy41IDIzNy42IDQuNC0yMy44'
    b'LTI1LjIgMS41Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'd2lkdGg9Ii4zIiBkPSJtNDA2IDI0Mi40IDEwLTIzLjUtMjUuNiA2LjgiLz4KICA8cGF0aCBm'
    b'aWxsPSIjMDA2ZDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tl'
    b'LXdpZHRoPSIyIiBkPSJtNTYzIDY2LjItMTcuOSAxMi0yLjktMTIuOS0xMC41IDE3LjgtMi04'
    b'LjUtOC42IDE4LjItMS4yLTguNC02LjcgMTguNy0zLjgtOS02LjcgMjIuNy0zLjgtOS02Ljcg'
    b'MjIuNy0zLjktOS02LjcgMjIuNy0zLjMgMTEuNCAxLjkgNC41IDcuMi0yLjQgMTIuNC05LjIg'
    b'MjUtMTguNC0xNC40IDQuNyAyNC45LTE4LjUtMTQuNCA0LjggMjQuOS0xOC41LTE0LjQgNC44'
    b'IDI1LTE0LjQtMTcgNEw1NjYgODMuM2wtMTYuMyA0LjIgMTkuNy0xNS42LTE3IDguMXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9'
    b'Im01NTYgNzIuNy0yNS44IDIyLjItNTAgNjUuMiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTUxOS4zIDEzMi44LTI4LjYgMTMu'
    b'NS0yLjQtMjAuOCIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIuMyIgZD0ibTUzMC4yIDExOS4yLTI5IDEzLjQtMi4zLTIwLjgiLz4KICA8cGF0'
    b'aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im01NDAu'
    b'NSAxMDUuNS0yOC43IDEzLjQtMi4yLTIwLjciLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im01NDkuMSA5NS4zLTI2LjggOS45LTMt'
    b'MTciLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0i'
    b'LjMiIGQ9Ik01NTkgODUuNSA1MzAuMiA5NWwtMS0xNi40Ii8+CiAgPHBhdGggZmlsbD0ibm9u'
    b'ZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNTYyLjggNzYuMi0yNi42'
    b'IDEzLjYgNS4yLTIwLjYiLz4KICA8cGF0aCBmaWxsPSIjMDA2ZDAwIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIyIiBkPSJtNDY2LjEgNDMuOCA4'
    b'IDE4LjIgMTAuMy05LjYtMS43IDE5LjggNi44LTYuNC0zLjcgMTkuNCA2LTYuNi01LjUgMTkg'
    b'OC43LTYtOCAyMi4zIDguNi02LTggMjIuNSA4LjctNi04IDIyLjQtNCAxMS4yLTQuNCAzLTQu'
    b'OC01LjMtNS0xMy40LTEwLTI2LjkgOS40IDEwLjUtMTAuMS0yNyA5LjQgMTAuNi0xMC0yN0w0'
    b'NjggOTNsLTEyLjUtMjMuNCAxMiAxMS4xLTE0LjQtMjMuOSAxMS4zIDExLTcuMy0yMi4yIDku'
    b'NiAxNC42eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIuMyIgZD0ibTQ2OC4yIDUyLjQgOC41IDMwLjUgMy4yIDc4Ii8+CiAgPHBhdGggZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNDYzIDEyMC4y'
    b'IDE2LjIgMjQuMyAxNC43LTE2LjciLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im00NjIgMTAzLjcgMTYuNSAyNC40IDE0LjctMTYu'
    b'NyIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIu'
    b'MyIgZD0ibTQ2MS41IDg3LjMgMTYuNCAyNC40TDQ5Mi4zIDk1Ii8+CiAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNDYwLjQgNzQuOSAx'
    b'Ni44IDIwLjQgMTMtMTMiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iLjMiIGQ9Im00NTggNjIgMTguNyAyMSAxMS0xMy42Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNDYwLjMg'
    b'NTIuNCAxNC40IDIzLjUgOC4xLTE5LjkiLz4KICA8cGF0aCBmaWxsPSIjMDA2ZDAwIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxLjkiIGQ9Im0z'
    b'NTkgMTc4IDIzLjMtMTYuMi0xMS43LTYgMjAuNSAzLjQtNy05LjMgMTkuOCA3LjUtNy05LjMg'
    b'MTkuOSA3LjQtNy05LjIgMjQgOC4xLTctOS4zIDIzLjMgMTIuMS03LTkuMyAyNCA4LjIgMTEu'
    b'NyA2IDMuNSA0LjYtNC43IDMuMy0xMi45IDEuOC0yMC43IDguNiAzLjgtNy40LTI1LjcgMy42'
    b'IDkuMy02LjQtMjYuMyA3LjYgOS40LTYuNS0yMi4yIDguMyA5LjktMTAuNC0yMi44IDEyLjIg'
    b'MTAtMTAuNC0xOC44IDEzIDEwLjUtMTQuNHoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0zNjYuMyAxNzMuNiAyNC4yLTEwLjUg'
    b'MTIuOS0xLjggMTAuNy0uMiAxOC41IDEuMiAxNi43LjcgMzMgMy43Ii8+CiAgPHBhdGggZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNDQ3LjIgMTc2'
    b'LjkgMTguNS0xMS40LTE4LjgtMTQuNyIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTQyNi41IDE3NS4yIDIyLjctMTIuMi0xOC43'
    b'LTE0LjgiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iLjMiIGQ9Im00MTEuNyAxNzQuOCAyMC45LTEyLjUtMTktMTMuN20tMjkuNSAyOS42IDE5'
    b'LjMtMTYuOS0xNS42LTguNSIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTM3NS41IDE3OS4zIDE1LTE2LjEtMTItNC41bTE4LjQg'
    b'MTcuNyAxOS0xNS4yLTE1LjItMTAuNCIvPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9kZCI+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjYzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBk'
    b'PSJtNTQxLjUgMTE3My4zLTEuNy0yMjkuMS02MS4xLTEwN2MtMTUuMy01Mi42LTcuOC03OCAx'
    b'Ny03OS44IDI0LjctMS42IDQ5LjIgMTMuNiA4NC44IDE1LjMgMzUuNiAxLjcgMjguOS01OS40'
    b'IDgxLjUtNTcuNyA1Mi42IDEuNyAxNDQuMyAzMi4zIDIyMi4zIDM3LjQgNzguMSA1IDExOC44'
    b'LTI3LjIgMjA4LjgtMzAuNiA5MC0zLjQgMTEzLjcgNDIuNCAxMTguOCA0Mi40IDUuMSAwIDMw'
    b'LjYtMTguNiA1Ni0yMiAyNS41LTMuNCAzNCAxMC4yIDM0IDEwLjJzLTEuNyA1Ny43LTEzLjYg'
    b'OTEuNmMtMTEuOSAzNC01NC4zIDkwLTU2IDkwLTEuNyAwLTE1LjMgMjQ5LjUtMTUuMyAyNTEu'
    b'MiAwIDEuNy02NzUuNS02LjgtNjc1LjUtMTEuOXoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkz'
    b'NCAwIDAgLjExOTA2IDM2Ny41IDIxNS41KSIvPgogICAgPGcgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYxMDAiIGQ9Ik01MzEuNSA1'
    b'ODQuNnMtNjgtNTItNjkuOC0xNzcuMWMtMS03MiAzNC40LTEyNCAxMjMtMTI0IDEyNCAwIDMw'
    b'MS4xIDUzLjEgMzAxLjEgNTMuMXYxNy43cy0xNDEuNy01My4xLTMwMS4yLTUzLjFjLTcwLjgg'
    b'MC0xMDYuMyA1Mi0xMDYuMyAxMDUuMiAwIDg4LjYgNzEgMTc4LjMgNzEgMTc4LjN2MTQxLjdo'
    b'LTE3Ljh6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjEyOTM0IDAgMCAuMTE5MDYgNTk2LjYgMjU3'
    b'LjYpIi8+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00NzguNCA1NDkuMmExNy44IDE3'
    b'LjggMCAxIDEtMzUuNSAwIDE3LjggMTcuOCAwIDAgMSAzNS41IDB6IiB0cmFuc2Zvcm09Im1h'
    b'dHJpeCgtLjEyOTM0IDAgMCAuMTE5MDYgNTk0LjUgMjU3LjQpIi8+CiAgICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIGQ9Ik00NzguNCA1NDkuMmExNy44IDE3LjggMCAxIDEtMzUuNSAwIDE3Ljgg'
    b'MTcuOCAwIDAgMSAzNS41IDB6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjEyOTM0IDAgMCAuMTE5'
    b'MDYgNTk2LjggMjUyLjYpIi8+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00NzguNCA1'
    b'NDkuMmExNy44IDE3LjggMCAxIDEtMzUuNSAwIDE3LjggMTcuOCAwIDAgMSAzNS41IDB6IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgtLjEyOTM0IDAgMCAuMTE5MDYgNTk4IDI0Ny42KSIvPgogICAg'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1'
    b'LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4xMjkz'
    b'NCAwIDAgLjExOTA2IDU5OC45IDI0Mi40KSIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBk'
    b'PSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44IDE3LjggMCAwIDEg'
    b'MzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4xMjkzNCAwIDAgLjExOTA2IDU5OC43IDIz'
    b'Ni44KSIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAx'
    b'Ny44IDAgMSAxLTM1LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoLS4xMjkzNCAwIDAgLjExOTA2IDU5MS4yIDI2MS43KSIvPgogICAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44'
    b'IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4xMjkzNCAwIDAgLjEx'
    b'OTA2IDU5Ni43IDIzMS40KSIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDc4LjQg'
    b'NTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLS4xMjkzNCAwIDAgLjExOTA2IDU5Mi41IDIyNy4xKSIvPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAx'
    b'LTM1LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4x'
    b'MjkzNCAwIDAgLjExOTA2IDU4Ni44IDIyNC4zKSIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZm'
    b'IiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44IDE3LjggMCAw'
    b'IDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4xMjkzNCAwIDAgLjExOTA2IDU4MSAy'
    b'MjMuOSkiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQ3OC40IDU0OS4yYTE3Ljgg'
    b'MTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0i'
    b'bWF0cml4KC0uMTI5MzQgMCAwIC4xMTkwNiA1NzUgMjI0KSIvPgogICAgICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44IDE3'
    b'LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4xMjkzNCAwIDAgLjExOTA2'
    b'IDU2OC44IDIyNSkiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQ3OC40IDU0OS4y'
    b'YTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KC0uMTI5MzQgMCAwIC4xMTkwNiA1NjIuNyAyMjUuNykiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0zNS41'
    b'IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC0uMTI5MzQg'
    b'MCAwIC4xMTkwNiA1NTYgMjI2LjYpIi8+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00'
    b'NzguNCA1NDkuMmExNy44IDE3LjggMCAxIDEtMzUuNSAwIDE3LjggMTcuOCAwIDAgMSAzNS41'
    b'IDB6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjEyOTM0IDAgMCAuMTE5MDYgNTUwLjQgMjI4LjEp'
    b'Ii8+CiAgICA8L2c+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iMXB0IiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAx'
    b'Ny44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEyOTM0IDAgMCAu'
    b'MTE5MDYgMzY5LjUgMjU3LjQpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAx'
    b'LTM1LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEy'
    b'OTM0IDAgMCAuMTE5MDYgMzY3LjIgMjUyLjYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAx'
    b'Ny44IDAgMSAxLTM1LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoLjEyOTM0IDAgMCAuMTE5MDYgMzY2IDI0Ny42KSIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQ3OC40IDU0OS4y'
    b'YTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDM2NS4yIDI0Mi40KSIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQ3'
    b'OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUg'
    b'MHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDM2NS40IDIzNi44KSIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFw'
    b'dCIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAg'
    b'MCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDM2Ny4z'
    b'IDIzMS40KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'd2lkdGg9IjFwdCIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcu'
    b'OCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjEx'
    b'OTA2IDM3MS40IDIyNy4xKSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0z'
    b'NS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkz'
    b'NCAwIDAgLjExOTA2IDM3Ny4yIDIyNC4zKSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcu'
    b'OCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC4xMjkzNCAwIDAgLjExOTA2IDM4Mi45IDIyMy45KSIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQ3OC40IDU0OS4y'
    b'YTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDM4OSAyMjQpIi8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNDc4LjQg'
    b'NTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLjEyOTM0IDAgMCAuMTE5MDYgMzk1LjIgMjI1KSIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0i'
    b'TTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1'
    b'LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDQwMS40IDIyNS43'
    b'KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'IjFwdCIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0zNS41IDAgMTcuOCAxNy44'
    b'IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDQw'
    b'Ny45IDIyNi42KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9IjFwdCIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEgMS0zNS41IDAg'
    b'MTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAg'
    b'LjExOTA2IDQxMy42IDIyOC4xKSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTQ3OC40IDU0OS4yYTE3LjggMTcuOCAwIDEg'
    b'MS0zNS41IDAgMTcuOCAxNy44IDAgMCAxIDM1LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC4x'
    b'MjkzNCAwIDAgLjExOTA2IDM3Mi44IDI2MS43KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZjEw'
    b'MCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTUzMS41IDU4NC42cy02'
    b'OC01Mi02OS44LTE3Ny4xYy0xLTcyIDM0LjQtMTI0IDEyMy0xMjQgMTI0IDAgMzAxLjEgNTMu'
    b'MSAzMDEuMSA1My4xdjE3LjdzLTE0MS43LTUzLjEtMzAxLjItNTMuMWMtNzAuOCAwLTEwNi4z'
    b'IDUyLTEwNi4zIDEwNS4yIDAgODguNiA3MSAxNzguMyA3MSAxNzguM3YxNDEuN2gtMTcuOHoi'
    b'IHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDM2Ny41IDI1Ny42KSIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZmZjEwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjMi'
    b'IGQ9Ik0xMjQwLjIgNTMxLjVzMTUuMy0zNS40IDcwLjktMzUuNGMzNy44IDAgNzAuOCAzNS40'
    b'IDcwLjggNzAuOHY3MC45aDM1LjV2LTcwLjljMC0zNS40IDM1LjQtNzAuOCA3MC44LTcwLjgg'
    b'NTMuMiAwIDcwLjkgMzUuNCA3MC45IDM1LjRzMC0xMDYuMy03MC45LTEwNi4zYy01My4xIDAt'
    b'NzAuOCAzNS40LTcwLjggMzUuNHMxNy43LTUzLjEgMTcuNy0xMDYuM2MwLTUzLjItMzUuNC04'
    b'OC42LTM1LjQtODguNiAwIDYuOC0zNS41IDM1LjUtMzUuNSA4OC42IDAgNTMuMSAxNy43IDEw'
    b'Ni4zIDE3LjcgMTA2LjNzLTE3LjctMzUuNC03MC44LTM1LjRjLTcwLjkgMC03MC45IDEwNi4z'
    b'LTcwLjkgMTA2LjN6IiB0cmFuc2Zvcm09Im1hdHJpeCguMDQzMTEgMCAwIC4wNDUzNiAzOTgu'
    b'NyAzMTAuOSkiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYxMDAiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIzIiBkPSJNMTI0MC4yIDUzMS41czE1LjMtMzUuNCA3MC45LTM1LjRjMzcu'
    b'OCAwIDcwLjggMzUuNCA3MC44IDcwLjh2NzAuOWgzNS41di03MC45YzAtMzUuNCAzNS40LTcw'
    b'LjggNzAuOC03MC44IDUzLjIgMCA3MC45IDM1LjQgNzAuOSAzNS40czAtMTA2LjMtNzAuOS0x'
    b'MDYuM2MtNTMuMSAwLTcwLjggMzUuNC03MC44IDM1LjRzMTcuNy01My4xIDE3LjctMTA2LjNj'
    b'MC01My4yLTM1LjQtODguNi0zNS40LTg4LjYgMCA2LjgtMzUuNSAzNS41LTM1LjUgODguNiAw'
    b'IDUzLjEgMTcuNyAxMDYuMyAxNy43IDEwNi4zcy0xNy43LTM1LjQtNzAuOC0zNS40Yy03MC45'
    b'IDAtNzAuOSAxMDYuMy03MC45IDEwNi4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoLjA0MzExIDAg'
    b'MCAuMDQ1MzYgNDQ0LjUgMzEwLjkpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmMTAwIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNTMxLjUgODMyLjdWNjczLjJzMzUu'
    b'NCA1My4yIDg4LjYgNTMuMmM0My41IDAgODguNi03MC45IDg4LjYtNzAuOXM0MS41IDUzLjIg'
    b'ODguNiA1My4yYzQyIDAgODguNS02OC42IDg4LjUtNjguNnM0My4yIDY4LjYgODguNiA2OC42'
    b'YzQ1LjUgMCA4OC42LTUzLjIgODguNi01My4yczQ2LjMgNzAuOSAxMDYuMyA3MC45YzUzLjEg'
    b'MCA3MC45LTUzLjIgNzAuOS01My4ydjE1OS41eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEyOTM0'
    b'IDAgMCAuMTE5MDYgMzY3LjUgMjU3LjYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmMTAwIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNzA4LjcgODMyLjd2LTEyNFM4'
    b'MTUgNzQ0IDgxNSA4MzIuN3oiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2'
    b'IDM0NC41IDI1Ny42KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZjEwMCIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTcwOC43IDgzMi43di0xMjRTODE1IDc0NCA4MTUg'
    b'ODMyLjd6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjEyOTM0IDAgMCAuMTE5MDYgNjE5LjQgMjU3'
    b'LjYpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmMTAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iMXB0IiBkPSJNNjAyLjQgODMyLjdDNjAyLjQgNzQ0IDcwOC43IDY4OCA3MDguNyA2'
    b'ODhTODE1IDc0NCA4MTUgODMyLjd6IiB0cmFuc2Zvcm09Im1hdHJpeCguMTI5MzQgMCAwIC4x'
    b'MTkwNiAzNjcuNSAyNTcuNikiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYxMDAiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik02MDIuNCA4MzIuN0M2MDIuNCA3NDQgNzA4'
    b'LjcgNjg4IDcwOC43IDY4OFM4MTUgNzQ0IDgxNSA4MzIuN3oiIHRyYW5zZm9ybT0ibWF0cml4'
    b'KC4xMjkzNCAwIDAgLjExOTA2IDQxMy4zIDI1Ny42KSIvPgogICAgPHBhdGggZmlsbD0iI2Zm'
    b'ZjEwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTU4NC42IDg0Ny41'
    b'YzAtODguNiAxMjQuMS0xNTkuNCAxMjQuMS0xNTkuNHMxMjQgNzAuOCAxMjQgMTU5LjRoLTI0'
    b'OHoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2IDM5MC40IDI1NS45KSIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjFw'
    b'dCIgZD0iTTEyNzUuNiA2NTUuNWMtMzUuNC0xNy43LTE2Ni0zNS40LTM3Ni4zLTM1LjRzLTM1'
    b'MCAxNy43LTM4NS41IDM1LjRjLTM1LjQgMTcuNy0zNS40IDUzLjIgMCA3MC45IDM1LjQgMTcu'
    b'NyAxNzUuMyAzNS40IDM4NS41IDM1LjRzMzQwLjktMTcuNyAzNzYuMy0zNS40YzM1LjQtMTcu'
    b'NyAzNS40LTUzLjIgMC03MC45eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEyNzg4IDAgMCAuMTE5'
    b'MDYgMzY3IDI3OC43KSIvPgogICAgPHBhdGggZmlsbD0iZ3JheSIgZD0iTTUyNy45IDM2NS4y'
    b'YzAgNC4yLTM4LjIgNC4yLTQ1LjkgNC4yLTguMyAwLTQ1LjggMS4yLTQ1LjgtNC4yIDAtNC4y'
    b'IDM3LjgtNC4yIDQ1LjgtNC4yczQ1LjkuOCA0NS45IDQuMnoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNjMDAiIGQ9Ik00NDAuOCAzNTBjMCAxLjQtMSAyLjYtMi4zIDIuNnMtMi4zLTEuMi0yLjMt'
    b'Mi42YzAtMS40IDEtMi41IDIuMy0yLjUgMS4yIDAgMi4zIDEuMiAyLjMgMi41em04NyAwYzAg'
    b'MS40LTEgMi42LTIuMyAyLjYtMS4yIDAtMi4zLTEuMi0yLjMtMi42IDAtMS40IDEtMi41IDIu'
    b'My0yLjUgMS4zIDAgMi4zIDEuMiAyLjMgMi41eiIvPgogICAgPHBhdGggZD0iTTQ4Ni42IDM0'
    b'OC44YzAgMS4zLTIuMSAyLjQtNC42IDIuNC0yLjQgMC00LjYtMS4xLTQuNi0yLjVzMi0yLjUg'
    b'NC42LTIuNSA0LjYgMS4yIDQuNiAyLjV6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDA2MzAwIiBk'
    b'PSJNNTA4LjYgMzQ4LjhjMCAxLjMtMS42IDIuNC0zLjUgMi40cy0zLjQtMS4xLTMuNC0yLjUg'
    b'MS42LTIuNSAzLjQtMi41IDMuNSAxLjIgMy41IDIuNXptLTQ3LjIgMGMwIDEuMy0xLjUgMi40'
    b'LTMuNCAyLjRzLTMuNS0xLjEtMy41LTIuNSAxLjUtMi41IDMuNS0yLjVjMS45IDAgMy40IDEu'
    b'MiAzLjQgMi41eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZjEwMCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9IjIuMiIgZD0iTTEyNTcuOSA0OTZzMzUuNC01MyA3MC45LTUzaDM1LjR2'
    b'MzUuM2MwIDUzLjItNTMuMSA3MS01My4xIDcxaDE0MS43cy01My4yLTE3LjgtNTMuMi03MVY0'
    b'NDNoMzUuNWMzNS40IDAgNzAuOCA1My4yIDcwLjggNTMuMlYzNTQuM3MtMzUuNCA1My4yLTcw'
    b'LjggNTMuMmgtMzUuNVYzNzJjMC01My4xIDUzLjItNzAuOCA1My4yLTcwLjhIMTMxMXM1My4x'
    b'IDE3LjcgNTMuMSA3MC44djM1LjVoLTM1LjRjLTM1LjUgMC03MC45LTUzLjItNzAuOS01My4y'
    b'djE0MS44eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjA3MzkgMCAwIC4wNjgwNCAzNzkuOSAzMDAu'
    b'NSkiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYxMDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIzLjMiIGQ9Ik0xMzgxLjkgNTQ5LjJoNzAuOXMtNTMuMi0xNy43LTUzLjItNzAuOVY0'
    b'NDNoMzUuNGMzNS41IDAgNzEgNTMuMiA3MSA1My4yVjM1NC4zcy0zNS41IDUzLjItNzEgNTMu'
    b'MmgtMzUuNFYzNzJjMC01My4xIDUzLjItNzAuOCA1My4yLTcwLjhoLTcwLjl6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCguMDM2OTYgMCAwIC4wNTk1MyAzODUgMzA5LjMpIi8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmMTAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMy4zIiBkPSJNMTM4'
    b'MS45IDU0OS4yaDcwLjlzLTUzLjItMTcuNy01My4yLTcwLjlWNDQzaDM1LjRjMzUuNSAwIDcx'
    b'IDUzLjIgNzEgNTMuMlYzNTQuM3MtMzUuNSA1My4yLTcxIDUzLjJoLTM1LjRWMzcyYzAtNTMu'
    b'MSA1My4yLTcwLjggNTMuMi03MC44aC03MC45eiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4wMzY5'
    b'NiAwIDAgLjA1OTUzIDU3OSAzMDkuMykiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxcHQiIGQ9Ik05MDMuNSA2MDIuNGExNy43IDE3Ljcg'
    b'MCAxIDEtMzUuNCAwIDE3LjcgMTcuNyAwIDAgMSAzNS40IDB6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCguMTI5MzQgMCAwIC4xMTkwNiAzNjcuNSAyNTcuNikiLz4KICAgIDxwYXRoIGZpbGw9IiNm'
    b'ZmYxMDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0xMjU3LjkgNDk2'
    b'czM1LjQtNTMgNzAuOS01M2gzNS40djM1LjNjMCA1My4yLTUzLjEgNzEtNTMuMSA3MWgxNDEu'
    b'N3MtNTMuMi0xNy44LTUzLjItNzFWNDQzaDM1LjVjMzUuNCAwIDcwLjggNTMuMiA3MC44IDUz'
    b'LjJWMzU0LjNzLTM1LjQgNTMuMi03MC44IDUzLjJoLTM1LjVWMzcyYzAtNTMuMSA1My4yLTcw'
    b'LjggNTMuMi03MC44SDEzMTFzNTMuMSAxNy43IDUzLjEgNzAuOHYzNS41aC0zNS40Yy0zNS41'
    b'IDAtNzAuOS01My4yLTcwLjktNTMuMnYxNDEuOHoiIHRyYW5zZm9ybT0ibWF0cml4KC4wNzM5'
    b'IDAgMCAuMDY4MDQgMzc5LjkgMjU2LjIpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNOTAzLjUgNjAyLjRhMTcuNyAxNy43'
    b'IDAgMSAxLTM1LjQgMCAxNy43IDE3LjcgMCAwIDEgMzUuNCAweiIgdHJhbnNmb3JtPSJtYXRy'
    b'aXgoLjEyOTM0IDAgMCAuMTE5MDYgMzY3LjcgMjEzLjcpIi8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZmMTAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNODUwLjQgNjU1'
    b'LjVoNzAuOXY1My4yaC03MXoiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjkzNCAwIDAgLjExOTA2'
    b'IDM2Ny41IDIxNS41KSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZjEwMCIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9IjFwdCIgZD0iTTg1MC40IDY4My4zaDcwLjl2MjAyLjVoLTcxeiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLjEyOTM0IDAgMCAuMTE5MDYgMzY3LjUgMjE1LjUpIi8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBk'
    b'PSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44IDE3LjggMCAwIDEg'
    b'MzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEyOTM0IDAgMCAuMTE5MDYgNDIyLjQgMjUx'
    b'LjIpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iMXB0IiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUgMCAxNy44IDE3'
    b'LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEyOTM0IDAgMCAuMTE5MDYg'
    b'NDIyLjQgMjQ1LjgpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iMXB0IiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAgMSAxLTM1LjUg'
    b'MCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEyOTM0IDAg'
    b'MCAuMTE5MDYgNDIyLjQgMjQwLjgpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNNDc4LjQgNTQ5LjJhMTcuOCAxNy44IDAg'
    b'MSAxLTM1LjUgMCAxNy44IDE3LjggMCAwIDEgMzUuNSAweiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'LjEyOTM0IDAgMCAuMTE5MDYgNDIyLjQgMjM1LjUpIi8+CiAgICA8cGF0aCBkPSJNNDg2Ljkg'
    b'MzU2LjhjMCAxLTIuMSAxLjctNC44IDEuN3MtNC41LS43LTQuNS0xLjcgMi0xLjcgNC42LTEu'
    b'NyA0LjcuOCA0LjcgMS43ek01MjkgMzYxYy0uMy43LTIuNi44LTUuMSAwLTIuNi0uNS00LjQt'
    b'MS40LTQuMi0yIC4zLS44IDIuNi0uOCA1LjEtLjIgMi42LjYgNC40IDEuNSA0LjIgMi4yem0t'
    b'MTcuNy0yLjhjMCAuOC0yLjMgMS4zLTUgMS4yLTIuNS0uMi00LjYtMS00LjUtMiAuMS0uOCAy'
    b'LjQtMS4yIDUtMSAyLjYuMSA0LjcuOSA0LjUgMS44em0tNzcuNSAyLjhjLjIuNyAyLjUuOCA1'
    b'IDAgMi42LS41IDQuNS0xLjQgNC4yLTItLjMtLjgtMi41LS44LTUtLjItMi42LjYtNC40IDEu'
    b'NS00LjIgMi4yem0xOC41LTMuMmMuMS44IDIuNCAxLjMgNSAxLjEgMi42LS4yIDQuNy0xIDQu'
    b'NS0xLjkgMC0uNy0yLjMtMS4zLTUtMS4xLTIuNS4yLTQuNiAxLTQuNSAxLjl6Ii8+CiAgPC9n'
    b'PgogIDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9Ik0wIDBoMzIwdjI0MEgwWiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNmZmYiIGQ9Im0zNy41IDAgMTIyIDkwLjVMMjgxIDBoMzl2MzFsLTEyMCA4OS41'
    b'IDEyMCA4OVYyNDBoLTQwbC0xMjAtODkuNUw0MC41IDI0MEgwdi0zMGwxMTkuNS04OUwwIDMy'
    b'VjBaIi8+CiAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0iTTIxMiAxNDAuNSAzMjAgMjIwdjIw'
    b'bC0xMzUuNS05OS41Wm0tOTIgMTAgMyAxNy41LTk2IDcySDBaTTMyMCAwdjEuNWwtMTI0LjUg'
    b'OTQgMS0yMkwyOTUgMFpNMCAwbDExOS41IDg4aC0zMEwwIDIxWiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Ik0xMjAuNSAwdjI0MGg4MFYwWk0wIDgwdjgwaDMyMFY4MFoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjYzgxMDJlIiBkPSJNMCA5Ni41djQ4aDMyMHYtNDh6TTEzNi41IDB2MjQwaDQ4'
    b'VjBaIi8+Cjwvc3ZnPgo=', 'IO')

IO = b64_IO
index.append("IO")
index.append("IOT")
index.append("British Indian Ocean Territory")
catalog["IO"] = IO
catalog["IOT"] = IO
catalog["British Indian Ocean Territory"] = IO
country["British Indian Ocean Territory"] = ('IO', 'IOT', 0)
lookup["IO"] = ('IO', 'IOT', 'British Indian Ocean Territory', 0)
lookup["Diego Garcia British Indian Ocean Territory"] = ('IO', 'IOT', 'British Indian Ocean Territory', 0)
lookup["IOT"] = ('IO', 'IOT', 'British Indian Ocean Territory', 0)
lookup["British Indian Ocean Territory"] = ('IO', 'IOT', 'British Indian Ocean Territory', 0)
details["IO"] = {"continent":"Africa","capital":"Diego Garcia","currency":"US Dollar","web":".io","lang":"en-IO","tz":"+06:00","altname":""}
#----------------------------------------------------------------------
b64_IQ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWlxIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MTYwaDY0MHYxNjBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNMCAwaDY0MHYx'
    b'NjBIMHoiLz4KICA8cGF0aCBkPSJNMCAzMjBoNjQwdjE2MEgweiIvPgogIDxnIGZpbGw9IiMw'
    b'MDdhM2QiIHRyYW5zZm9ybT0idHJhbnNsYXRlKC0xNzkuMyAtOTIuOCkgc2NhbGUoMS43NTE4'
    b'MikiPgogICAgPHBhdGggZD0iTTMyNS41IDE3My4yYTUgNSAwIDAgMS0xLjQtMWMtLjMtLjUt'
    b'LjEtLjUgMS4yLS4yIDIuMy43IDMuOC40IDUuMy0uOGwxLjMtMS4xIDEuNS43Yy45LjUgMS44'
    b'LjggMiAuNy43LS4yIDIuMS0yIDItMi42IDAtLjcuNi0uNSAxIC4zLjYgMS42LS4zIDMuNS0y'
    b'IDMuOS0uNy4yLTEuNC4xLTIuNi0uMy0xLjQtLjUtMS43LS41LTIuNCAwYTUuNCA1LjQgMCAw'
    b'IDEtNS45LjR6bTUuOC01LjNhOCA4IDAgMCAxLTEtNGMuMS0uNi4zLS44LjgtLjYgMSAuMyAx'
    b'LjIgMSAxIDMgMCAxLjgtLjMgMi4zLS44IDEuNnptLTY3LjYtMS45Yy0uMSAxLjMgMi40IDQu'
    b'NiAzLjUgNS4yLS44LjMtMS43LjItMi40LjUtNCA0LTE4LjQgMTgtMjEgMjEuNCA3LjguMiAx'
    b'Ni40LS4xIDIzLjctLjQgMC01LjMgNS01LjYgOC40LTcuNSAxLjcgMi43IDYgMi41IDYuNiA2'
    b'LjZ2MTcuNkgyMTZhOS43IDkuNyAwIDAgMS0xMi4zIDcuNWMyLTIgNS40LTIuOCA2LjYtNS43'
    b'IDEtNi40LTItMTAuMy00LTE0YTI0IDI0IDAgMCAwIDctMy42Yy0yLjMgNyA2LjIgNi4zIDEy'
    b'LjQgNi4xLjItMi40LjEtNS4yLTEuNy01LjYgMi4zLS45IDIuNy0xLjIgNi42LTQuNHY5LjZs'
    b'NDYuMS0uMWMwLTMgLjgtNy45LTEuNi03LjktMi4yIDAgMCA2LjItMS44IDYuMmgtMzUuN3Yt'
    b'NmMxLjUtMS42IDEuMy0xLjUgMTEuNi0xMS44IDEtMSA4LjMtNy42IDE0LjYtMTMuN3ptODku'
    b'MS0uM2MyLjUgMS40IDQuNSAzLjIgNy41IDQtLjMgMS4zLTEuNSAxLjgtMS44IDMuMXYyN2Mz'
    b'LjQuNyA0LjItMS4zIDUuOC0yLjMuNCA0LjMgMy4yIDguNSAzIDEyaC0xNC41di00My43em0t'
    b'MTkuNCAxNC41czUuMy00LjUgNS4zLTQuN1YxOTloMy44bC0uMS0yNi4zYzEuNS0xLjYgNC42'
    b'LTMuOCA1LjMtNS40djQyaC0zMy40Yy0uNS04LjctLjYtMTcuNyA5LjYtMTUuOFYxOTBjLS4z'
    b'LS42LS45LjEtMS0uNyAxLjYtMS42IDIuMS0yIDYuNS01LjhsLjEgMTUuNWgzLjl2LTE4Ljh6'
    b'bS0xMi42IDE4LjZjLjcgMSAzLjIgMSAzLS44LS4zLTEuNS0zLjUtMS0zIC44eiIvPgogICAg'
    b'PGNpcmNsZSBjeD0iMjI0IiBjeT0iMjE0LjQiIHI9IjIiLz4KICAgIDxwYXRoIGQ9Ik0yODcg'
    b'MTY1LjhjMi41IDEuMyA0LjUgMy4yIDcuNiA0LS40IDEuMi0xLjUgMS43LTEuOCAzdjI3YzMu'
    b'NC43IDQuMS0xLjIgNS43LTIuMy41IDQuMyAzLjIgOC42IDMuMSAxMkgyODd2LTQzLjd6Ii8+'
    b'CiAgPC9nPgo8L3N2Zz4K', 'IQ')

IQ = b64_IQ
index.append("IQ")
index.append("IRQ")
index.append("Iraq")
catalog["IQ"] = IQ
catalog["IRQ"] = IQ
catalog["Iraq"] = IQ
country["Iraq"] = ('IQ', 'IRQ', 0)
lookup["IQ"] = ('IQ', 'IRQ', 'Iraq', 0)
lookup["Baghdad Iraq"] = ('IQ', 'IRQ', 'Iraq', 0)
lookup["IRQ"] = ('IQ', 'IRQ', 'Iraq', 0)
lookup["Iraq"] = ('IQ', 'IRQ', 'Iraq', 0)
details["IQ"] = {"continent":"Asia","capital":"Baghdad","currency":"Iraqi Dinar","web":".iq","lang":"ar-IQ | ku | hy","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_IR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWlyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImlyLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1LjMgMGg2ODIu'
    b'N3Y1MTJILTg1LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNpci1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoODApIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLTE5MiAw'
    b'aDg5NnY1MTJoLTg5NnoiLz4KICAgIDxwYXRoIGZpbGw9IiNkYTAwMDAiIGQ9Ik0tMTkyIDM0'
    b'My44aDg5NlY1MTJoLTg5NnoiLz4KICAgIDxnIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0aD0i'
    b'MXB0Ij4KICAgICAgPHBhdGggZD0iTS0yMS42IDM1MWg0OXYzLjNoLTQ5em03LjMgMTYuOGgz'
    b'LjR2My4zaC0zLjR6bTQxLjkgMHYzLjNoLTkuOHYtMy40em01LjItMTYuOGgzLjR2MjBoLTMu'
    b'NHoiLz4KICAgICAgPHBhdGggZD0iTTUyLjQgMzY3Ljd2My40SDMzLjh2LTMuNHptLTM0LjYt'
    b'Ny45SDIxdjExLjNoLTMuM3oiLz4KICAgICAgPHBhdGggZD0iTTQ5LjYgMzUxSDUzdjIwaC0z'
    b'LjR6bS04LjQgMGgzLjN2MjBoLTMuM3ptLTQ0LjggOHYzLjRoLTE4VjM1OXptMzkuMyAwdjMu'
    b'NGgtMThWMzU5eiIvPgogICAgICA8cGF0aCBkPSJNMTcuOCAzNTkuOUgyMVYzNzFoLTMuM3oi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTE3LjggMzU5LjlIMjFWMzcxaC0zLjN6Ii8+CiAgICAgIDxw'
    b'YXRoIGQ9Ik0xNy44IDM1OS45SDIxVjM3MWgtMy4zem0tMzkuMyAwaDMuM1YzNzFoLTMuM3pt'
    b'MjguOCAwaDMuNFYzNzFINy4zem0tMTQuMyAwaDMuNFYzNzFILTd6Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik05LjYgMzY3Ljd2My40SC01LjV2LTMuNHptMS04Ljd2My40SDFWMzU5eiIvPgogICAg'
    b'PC9nPgogICAgPGcgZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAgICA8cGF0'
    b'aCBkPSJNLTEwMi4yIDM1MWg0OXYzLjNoLTQ5em03LjMgMTYuOGgzLjR2My4zSC05NXptNDEu'
    b'OSAwdjMuM2gtOS44di0zLjR6bTUuMi0xNi44aDMuNHYyMGgtMy40eiIvPgogICAgICA8cGF0'
    b'aCBkPSJNLTI4LjIgMzY3Ljd2My40aC0xOC42di0zLjR6bS0zNC42LTcuOWgzLjN2MTEuM2gt'
    b'My4zeiIvPgogICAgICA8cGF0aCBkPSJNLTMxIDM1MWgzLjR2MjBILTMxem0tOC40IDBoMy4z'
    b'djIwaC0zLjN6bS00NC44IDh2My40aC0xOFYzNTl6bTM5LjMgMHYzLjRoLTE4VjM1OXoiLz4K'
    b'ICAgICAgPHBhdGggZD0iTS02Mi44IDM1OS45aDMuM1YzNzFoLTMuM3oiLz4KICAgICAgPHBh'
    b'dGggZD0iTS02Mi44IDM1OS45aDMuM1YzNzFoLTMuM3oiLz4KICAgICAgPHBhdGggZD0iTS02'
    b'Mi44IDM1OS45aDMuM1YzNzFoLTMuM3ptLTM5LjMgMGgzLjNWMzcxaC0zLjN6bTI4LjggMGgz'
    b'LjNWMzcxaC0zLjN6bS0xNC4zIDBoMy40VjM3MWgtMy40eiIvPgogICAgICA8cGF0aCBkPSJN'
    b'LTcxIDM2Ny43djMuNGgtMTV2LTMuNHptMS04Ljd2My40aC05LjZWMzU5eiIvPgogICAgPC9n'
    b'PgogICAgPGcgZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAgICA8cGF0aCBk'
    b'PSJNNTguMyAzNTFoNDl2My4zaC00OXptNy4zIDE2LjhINjl2My4zaC0zLjR6bTQxLjkgMHYz'
    b'LjNoLTkuOHYtMy40em01LjMtMTYuOGgzLjR2MjBoLTMuNHoiLz4KICAgICAgPHBhdGggZD0i'
    b'TTEzMi4zIDM2Ny43djMuNGgtMTguNnYtMy40em0tMzQuNi03LjloMy40djExLjNoLTMuNHoi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTEyOS41IDM1MWgzLjR2MjBoLTMuNHptLTguNCAwaDMuNHYy'
    b'MEgxMjF6bS00NC44IDh2My40aC0xOFYzNTl6bTM5LjMgMHYzLjRoLTE4VjM1OXoiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTk3LjcgMzU5LjloMy40VjM3MWgtMy40eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNOTcuNyAzNTkuOWgzLjRWMzcxaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik05Ny43IDM1'
    b'OS45aDMuNFYzNzFoLTMuNHptLTM5LjMgMGgzLjRWMzcxaC0zLjR6bTI4LjggMGgzLjRWMzcx'
    b'aC0zLjR6bS0xNC4zIDBoMy40VjM3MWgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNODkuNiAz'
    b'NjcuN3YzLjRINzQuNHYtMy40em0xLTguN3YzLjRIODFWMzU5eiIvPgogICAgPC9nPgogICAg'
    b'PGcgZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAgICA8cGF0aCBkPSJNNjIy'
    b'LjcgMzUxaDQ5djMuM2gtNDl6bTcuMyAxNi44aDMuNHYzLjNINjMwem00MS45IDB2My4zSDY2'
    b'MnYtMy40em01LjMtMTYuOGgzLjN2MjBoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTY5Ni43'
    b'IDM2Ny43djMuNEg2Nzh2LTMuNHptLTM0LjYtNy45aDMuNHYxMS4zSDY2MnoiLz4KICAgICAg'
    b'PHBhdGggZD0iTTY5NCAzNTFoMy4zdjIwaC0zLjR6bS04LjUgMGgzLjR2MjBoLTMuNHptLTQ0'
    b'LjggOHYzLjRoLTE4VjM1OXptMzkuMyAwdjMuNGgtMThWMzU5eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNNjYyIDM1OS45aDMuNVYzNzFINjYyeiIvPgogICAgICA8cGF0aCBkPSJNNjYyIDM1OS45'
    b'aDMuNVYzNzFINjYyeiIvPgogICAgICA8cGF0aCBkPSJNNjYyIDM1OS45aDMuNVYzNzFINjYy'
    b'em0tMzkuMiAwaDMuNFYzNzFoLTMuNHptMjguOCAwaDMuNFYzNzFoLTMuNHptLTE0LjMgMGgz'
    b'LjRWMzcxaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik02NTQgMzY3Ljd2My40aC0xNS4ydi0z'
    b'LjR6bTEtOC43djMuNGgtOS42VjM1OXoiLz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiNmZmYi'
    b'IHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0iTTEzOC43IDM1MWg0OS4xdjMu'
    b'M2gtNDl6bTcuNCAxNi44aDMuM3YzLjNoLTMuM3ptNDEuOCAwdjMuM2gtOS44di0zLjR6bTUu'
    b'My0xNi44aDMuNHYyMGgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNMjEyLjggMzY3Ljd2My40'
    b'aC0xOC42di0zLjR6bS0zNC43LTcuOWgzLjR2MTEuM2gtMy40eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNMjEwIDM1MWgzLjR2MjBIMjEwem0tOC41IDBoMy40djIwaC0zLjR6bS00NC44IDh2My40'
    b'aC0xNy45VjM1OXptMzkuMyAwdjMuNGgtMTcuOVYzNTl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0x'
    b'NzguMSAzNTkuOWgzLjRWMzcxaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xNzguMSAzNTku'
    b'OWgzLjRWMzcxaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xNzguMSAzNTkuOWgzLjRWMzcx'
    b'aC0zLjR6bS0zOS4zIDBoMy40VjM3MWgtMy40em0yOC44IDBoMy40VjM3MWgtMy40em0tMTQu'
    b'MiAwaDMuM1YzNzFoLTMuM3oiLz4KICAgICAgPHBhdGggZD0iTTE3MCAzNjcuN3YzLjRoLTE1'
    b'LjF2LTMuNHptMS04Ljd2My40aC05LjZWMzU5eiIvPgogICAgPC9nPgogICAgPGcgZmlsbD0i'
    b'I2ZmZiIgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAgICA8cGF0aCBkPSJNMjE5LjUgMzUxaDQ5'
    b'djMuM2gtNDl6bTcuMyAxNi44aDMuNHYzLjNoLTMuNHptNDEuOSAwdjMuM2gtOS44di0zLjR6'
    b'TTI3NCAzNTFoMy4zdjIwSDI3NHoiLz4KICAgICAgPHBhdGggZD0iTTI5My41IDM2Ny43djMu'
    b'NGgtMTguNnYtMy40em0tMzQuNi03LjloMy40djExLjNoLTMuNHoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTTI5MC43IDM1MWgzLjR2MjBoLTMuNHptLTguNCAwaDMuNHYyMGgtMy40em0tNDQuOCA4'
    b'djMuNGgtMThWMzU5em0zOS4zIDB2My40aC0xOFYzNTl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0y'
    b'NTguOSAzNTkuOWgzLjRWMzcxaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNTguOSAzNTku'
    b'OWgzLjRWMzcxaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0yNTguOSAzNTkuOWgzLjRWMzcx'
    b'aC0zLjR6bS0zOS4zIDBoMy4zVjM3MWgtMy4zem0yOC44IDBoMy40VjM3MWgtMy40em0tMTQu'
    b'MyAwaDMuNFYzNzFIMjM0eiIvPgogICAgICA8cGF0aCBkPSJNMjUwLjggMzY3Ljd2My40aC0x'
    b'NS4ydi0zLjR6bTEtOC43djMuNEgyNDJWMzU5eiIvPgogICAgPC9nPgogICAgPHBhdGggZmls'
    b'bD0iIzIzOWY0MCIgZD0iTS0xOTIgMGg4OTZ2MTY4LjJoLTg5NnoiLz4KICAgIDxnIGZpbGw9'
    b'IiNmZmYiIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0iTTMwMC43IDM1MWg0'
    b'OXYzLjNoLTQ5em03LjMgMTYuOGgzLjR2My4zSDMwOHptNDEuOSAwdjMuM0gzNDB2LTMuNHpt'
    b'NS4zLTE2LjhoMy4zdjIwaC0zLjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNzQuNyAzNjcuN3Yz'
    b'LjRoLTE4LjZ2LTMuNHptLTM0LjYtNy45aDMuNHYxMS4zSDM0MHoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTTM3MiAzNTFoMy4zdjIwSDM3MnptLTguNSAwaDMuNHYyMGgtMy40em0tNDQuOCA4djMu'
    b'NGgtMThWMzU5em0zOS4zIDB2My40aC0xOFYzNTl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNDAg'
    b'MzU5LjloMy41VjM3MUgzNDB6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNDAgMzU5LjloMy41VjM3'
    b'MUgzNDB6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNDAgMzU5LjloMy41VjM3MUgzNDB6bS0zOS4y'
    b'IDBoMy40VjM3MWgtMy40em0yOC44IDBoMy40VjM3MWgtMy40em0tMTQuMyAwaDMuNFYzNzFo'
    b'LTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTMzMiAzNjcuN3YzLjRoLTE1LjJ2LTMuNHptMS04'
    b'Ljd2My40aC05LjZWMzU5eiIvPgogICAgPC9nPgogICAgPGcgZmlsbD0iI2ZmZiIgc3Ryb2tl'
    b'LXdpZHRoPSIxcHQiPgogICAgICA8cGF0aCBkPSJNMzgxLjQgMzUxaDQ5djMuM2gtNDl6bTcu'
    b'MyAxNi44aDMuNHYzLjNoLTMuNHptNDIgMHYzLjNoLTkuOXYtMy40em01LjItMTYuOGgzLjR2'
    b'MjBoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTQ1NS40IDM2Ny43djMuNGgtMTguNnYtMy40'
    b'em0tMzQuNi03LjloMy40djExLjNoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTQ1Mi43IDM1'
    b'MWgzLjN2MjBoLTMuM3ptLTguNSAwaDMuNHYyMGgtMy40em0tNDQuOCA4djMuNGgtMTcuOVYz'
    b'NTl6bTM5LjMgMHYzLjRoLTE3LjlWMzU5eiIvPgogICAgICA8cGF0aCBkPSJNNDIwLjggMzU5'
    b'LjloMy40VjM3MWgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNNDIwLjggMzU5LjloMy40VjM3'
    b'MWgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNNDIwLjggMzU5LjloMy40VjM3MWgtMy40em0t'
    b'MzkuMyAwaDMuNFYzNzFoLTMuNHptMjguOCAwaDMuNFYzNzFoLTMuNHptLTE0LjMgMGgzLjRW'
    b'MzcxaC0zLjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00MTIuNyAzNjcuN3YzLjRoLTE1LjF2LTMu'
    b'NHptMS04Ljd2My40SDQwNFYzNTl6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSIjZmZmIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Ik00NjIuMiAzNTFoNDl2My4zaC00'
    b'OXptNy4zIDE2LjhoMy40djMuM2gtMy40em00MS45IDB2My4zaC05Ljh2LTMuNHptNS4yLTE2'
    b'LjhoMy40djIwaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MzYuMiAzNjcuN3YzLjRoLTE4'
    b'LjZ2LTMuNHptLTM0LjctNy45aDMuNHYxMS4zaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01'
    b'MzMuNCAzNTFoMy40djIwaC0zLjR6bS04LjQgMGgzLjN2MjBINTI1em0tNDQuOCA4djMuNGgt'
    b'MThWMzU5em0zOS4zIDB2My40aC0xOFYzNTl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MDEuNiAz'
    b'NTkuOWgzLjNWMzcxaC0zLjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MDEuNiAzNTkuOWgzLjNW'
    b'MzcxaC0zLjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01MDEuNiAzNTkuOWgzLjNWMzcxaC0zLjN6'
    b'bS0zOS40IDBoMy40VjM3MWgtMy40em0yOC45IDBoMy4zVjM3MWgtMy4zem0tMTQuMyAwaDMu'
    b'NFYzNzFoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTQ5My40IDM2Ny43djMuNGgtMTUuMXYt'
    b'My40em0xLTguN3YzLjRoLTkuNlYzNTl6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSIjZmZm'
    b'IiBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Ik01NDMuNCAzNTFoNDl2My4z'
    b'aC00OXptNy4zIDE2LjhoMy40djMuM2gtMy40em00MS45IDB2My4zaC05Ljh2LTMuNHptNS4y'
    b'LTE2LjhoMy40djIwaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik02MTcuNCAzNjcuN3YzLjRo'
    b'LTE4LjZ2LTMuNHptLTM0LjYtNy45aDMuM3YxMS4zaC0zLjN6Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik02MTQuNiAzNTFoMy40djIwaC0zLjR6bS04LjQgMGgzLjN2MjBoLTMuM3ptLTQ0LjggOHYz'
    b'LjRoLTE4VjM1OXptMzkuMyAwdjMuNGgtMThWMzU5eiIvPgogICAgICA8cGF0aCBkPSJNNTgy'
    b'LjggMzU5LjloMy4zVjM3MWgtMy4zeiIvPgogICAgICA8cGF0aCBkPSJNNTgyLjggMzU5Ljlo'
    b'My4zVjM3MWgtMy4zeiIvPgogICAgICA8cGF0aCBkPSJNNTgyLjggMzU5LjloMy4zVjM3MWgt'
    b'My4zem0tMzkuMyAwaDMuM1YzNzFoLTMuM3ptMjguOCAwaDMuNFYzNzFoLTMuNHptLTE0LjMg'
    b'MGgzLjRWMzcxSDU1OHoiLz4KICAgICAgPHBhdGggZD0iTTU3NC42IDM2Ny43djMuNGgtMTUu'
    b'MXYtMy40em0xLTguN3YzLjRINTY2VjM1OXoiLz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiNm'
    b'ZmYiIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0iTS0xODMuOCAzNTFoNDl2'
    b'My4zaC00OXptNy4zIDE2LjhoMy40djMuM2gtMy40em00MiAwdjMuM2gtOS45di0zLjR6bTUu'
    b'Mi0xNi44aDMuNHYyMGgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNLTEwOS44IDM2Ny43djMu'
    b'NGgtMTguNnYtMy40em0tMzQuNi03LjloMy40djExLjNoLTMuNHoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTS0xMTIuNSAzNTFoMy4zdjIwaC0zLjN6bS04LjUgMGgzLjR2MjBoLTMuNHptLTQ0Ljgg'
    b'OHYzLjRoLTE3LjlWMzU5em0zOS4zIDB2My40aC0xNy45VjM1OXoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTS0xNDQuNCAzNTkuOWgzLjRWMzcxaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0tMTQ0'
    b'LjQgMzU5LjloMy40VjM3MWgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNLTE0NC40IDM1OS45'
    b'aDMuNFYzNzFoLTMuNHptLTM5LjMgMGgzLjRWMzcxaC0zLjR6bTI4LjggMGgzLjRWMzcxaC0z'
    b'LjR6bS0xNC4zIDBoMy40VjM3MWgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNLTE1Mi41IDM2'
    b'Ny43djMuNGgtMTUuMnYtMy40em0xLTguN3YzLjRoLTkuNlYzNTl6Ii8+CiAgICA8L2c+CiAg'
    b'ICA8ZyBmaWxsPSIjZmZmIiBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Ik0t'
    b'MjEuNiAxNDMuNGg0OXYzLjRoLTQ5em03LjMgMTdoMy40djMuMmgtMy40em00MS45LS4ydjMu'
    b'NGgtOS44di0zLjR6bTUuMi0xNi44aDMuNHYyMC4yaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik01Mi40IDE2MC4ydjMuNEgzMy44di0zLjR6bS0zNC42LTcuOUgyMXYxMS4zaC0zLjN6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik00OS42IDE0My40SDUzdjIwLjJoLTMuNHptLTguNCAwaDMuM3Yy'
    b'MC4yaC0zLjN6bS00NC44IDh2My40aC0xOHYtMy4zem0zOS4zIDB2My40aC0xOHYtMy4zeiIv'
    b'PgogICAgICA8cGF0aCBkPSJNMTcuOCAxNTIuM0gyMXYxMS4zaC0zLjN6Ii8+CiAgICAgIDxw'
    b'YXRoIGQ9Ik0xNy44IDE1Mi4zSDIxdjExLjNoLTMuM3oiLz4KICAgICAgPHBhdGggZD0iTTE3'
    b'LjggMTUyLjNIMjF2MTEuM2gtMy4zem0tMzkuMyAwaDMuM3YxMS4zaC0zLjN6bTI4LjggMGgz'
    b'LjR2MTEuM0g3LjN6bS0xNC4zIDBoMy40djExLjNILTd6Ii8+CiAgICAgIDxwYXRoIGQ9Ik05'
    b'LjYgMTYwLjJ2My40SC01LjV2LTMuNHptMS04Ljd2My4zSDF2LTMuM3oiLz4KICAgIDwvZz4K'
    b'ICAgIDxnIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0i'
    b'TS0xMDIuMiAxNDMuNGg0OXYzLjRoLTQ5em03LjMgMTdoMy40djMuMkgtOTV6bTQxLjktLjJ2'
    b'My40aC05Ljh2LTMuNHptNS4yLTE2LjhoMy40djIwLjJoLTMuNHoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTS0yOC4yIDE2MC4ydjMuNGgtMTguNnYtMy40em0tMzQuNi03LjloMy4zdjExLjNoLTMu'
    b'M3oiLz4KICAgICAgPHBhdGggZD0iTS0zMSAxNDMuNGgzLjR2MjAuMkgtMzF6bS04LjQgMGgz'
    b'LjN2MjAuMmgtMy4zem0tNDQuOCA4djMuNGgtMTh2LTMuM3ptMzkuMyAwdjMuNGgtMTh2LTMu'
    b'M3oiLz4KICAgICAgPHBhdGggZD0iTS02Mi44IDE1Mi4zaDMuM3YxMS4zaC0zLjN6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik0tNjIuOCAxNTIuM2gzLjN2MTEuM2gtMy4zeiIvPgogICAgICA8cGF0'
    b'aCBkPSJNLTYyLjggMTUyLjNoMy4zdjExLjNoLTMuM3ptLTM5LjMgMGgzLjN2MTEuM2gtMy4z'
    b'em0yOC44IDBoMy4zdjExLjNoLTMuM3ptLTE0LjMgMGgzLjR2MTEuM2gtMy40eiIvPgogICAg'
    b'ICA8cGF0aCBkPSJNLTcxIDE2MC4ydjMuNGgtMTV2LTMuNHptMS04Ljd2My4zaC05LjZ2LTMu'
    b'M3oiLz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0aD0iMXB0Ij4K'
    b'ICAgICAgPHBhdGggZD0iTTU4LjMgMTQzLjRoNDl2My40aC00OXptNy4zIDE3SDY5djMuMmgt'
    b'My40em00MS45LS4ydjMuNGgtOS44di0zLjR6bTUuMy0xNi44aDMuNHYyMC4yaC0zLjR6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik0xMzIuMyAxNjAuMnYzLjRoLTE4LjZ2LTMuNHptLTM0LjYtNy45'
    b'aDMuNHYxMS4zaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xMjkuNSAxNDMuNGgzLjR2MjAu'
    b'MmgtMy40em0tOC40IDBoMy40djIwLjJIMTIxem0tNDQuOCA4djMuNGgtMTh2LTMuM3ptMzku'
    b'MyAwdjMuNGgtMTh2LTMuM3oiLz4KICAgICAgPHBhdGggZD0iTTk3LjcgMTUyLjNoMy40djEx'
    b'LjNoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTk3LjcgMTUyLjNoMy40djExLjNoLTMuNHoi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTk3LjcgMTUyLjNoMy40djExLjNoLTMuNHptLTM5LjMgMGgz'
    b'LjR2MTEuM2gtMy40em0yOC44IDBoMy40djExLjNoLTMuNHptLTE0LjMgMGgzLjR2MTEuM2gt'
    b'My40eiIvPgogICAgICA8cGF0aCBkPSJNODkuNiAxNjAuMnYzLjRINzQuNHYtMy40em0xLTgu'
    b'N3YzLjNIODF2LTMuM3oiLz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiNmZmYiIHN0cm9rZS13'
    b'aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0iTTYyMi43IDE0My40aDQ5djMuNGgtNDl6bTcu'
    b'MyAxN2gzLjR2My4ySDYzMHptNDEuOS0uMnYzLjRINjYydi0zLjR6bTUuMy0xNi44aDMuM3Yy'
    b'MC4yaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik02OTYuNyAxNjAuMnYzLjRINjc4di0zLjR6'
    b'bS0zNC42LTcuOWgzLjR2MTEuM0g2NjJ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik02OTQgMTQzLjRo'
    b'My4zdjIwLjJoLTMuNHptLTguNSAwaDMuNHYyMC4yaC0zLjR6bS00NC44IDh2My40aC0xOHYt'
    b'My4zem0zOS4zIDB2My40aC0xOHYtMy4zeiIvPgogICAgICA8cGF0aCBkPSJNNjYyIDE1Mi4z'
    b'aDMuNXYxMS4zSDY2MnoiLz4KICAgICAgPHBhdGggZD0iTTY2MiAxNTIuM2gzLjV2MTEuM0g2'
    b'NjJ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik02NjIgMTUyLjNoMy41djExLjNINjYyem0tMzkuMiAw'
    b'aDMuNHYxMS4zaC0zLjR6bTI4LjggMGgzLjR2MTEuM2gtMy40em0tMTQuMyAwaDMuNHYxMS4z'
    b'aC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik02NTQgMTYwLjJ2My40aC0xNS4ydi0zLjR6bTEt'
    b'OC43djMuM2gtOS42di0zLjN6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSIjZmZmIiBzdHJv'
    b'a2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Ik0xMzguNyAxNDMuNGg0OS4xdjMuNGgt'
    b'NDl6bTcuNCAxN2gzLjN2My4yaC0zLjN6bTQxLjgtLjJ2My40aC05Ljh2LTMuNHptNS4zLTE2'
    b'LjhoMy40djIwLjJoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTIxMi44IDE2MC4ydjMuNGgt'
    b'MTguNnYtMy40em0tMzQuNy03LjloMy40djExLjNoLTMuNHoiLz4KICAgICAgPHBhdGggZD0i'
    b'TTIxMCAxNDMuNGgzLjR2MjAuMkgyMTB6bS04LjUgMGgzLjR2MjAuMmgtMy40em0tNDQuOCA4'
    b'djMuNGgtMTcuOXYtMy4zem0zOS4zIDB2My40aC0xNy45di0zLjN6Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0xNzguMSAxNTIuM2gzLjR2MTEuM2gtMy40eiIvPgogICAgICA8cGF0aCBkPSJNMTc4'
    b'LjEgMTUyLjNoMy40djExLjNoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTE3OC4xIDE1Mi4z'
    b'aDMuNHYxMS4zaC0zLjR6bS0zOS4zIDBoMy40djExLjNoLTMuNHptMjguOCAwaDMuNHYxMS4z'
    b'aC0zLjR6bS0xNC4yIDBoMy4zdjExLjNoLTMuM3oiLz4KICAgICAgPHBhdGggZD0iTTE3MCAx'
    b'NjAuMnYzLjRoLTE1LjF2LTMuNHptMS04Ljd2My4zaC05LjZ2LTMuM3oiLz4KICAgIDwvZz4K'
    b'ICAgIDxnIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0aD0iMXB0Ij4KICAgICAgPHBhdGggZD0i'
    b'TTIxOS41IDE0My40aDQ5djMuNGgtNDl6bTcuMyAxN2gzLjR2My4yaC0zLjR6bTQxLjktLjJ2'
    b'My40aC05Ljh2LTMuNHptNS4zLTE2LjhoMy4zdjIwLjJIMjc0eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNMjkzLjUgMTYwLjJ2My40aC0xOC42di0zLjR6bS0zNC42LTcuOWgzLjR2MTEuM2gtMy40'
    b'eiIvPgogICAgICA8cGF0aCBkPSJNMjkwLjcgMTQzLjRoMy40djIwLjJoLTMuNHptLTguNCAw'
    b'aDMuNHYyMC4yaC0zLjR6bS00NC44IDh2My40aC0xOHYtMy4zem0zOS4zIDB2My40aC0xOHYt'
    b'My4zeiIvPgogICAgICA8cGF0aCBkPSJNMjU4LjkgMTUyLjNoMy40djExLjNoLTMuNHoiLz4K'
    b'ICAgICAgPHBhdGggZD0iTTI1OC45IDE1Mi4zaDMuNHYxMS4zaC0zLjR6Ii8+CiAgICAgIDxw'
    b'YXRoIGQ9Ik0yNTguOSAxNTIuM2gzLjR2MTEuM2gtMy40em0tMzkuMyAwaDMuM3YxMS4zaC0z'
    b'LjN6bTI4LjggMGgzLjR2MTEuM2gtMy40em0tMTQuMyAwaDMuNHYxMS4zSDIzNHoiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTI1MC44IDE2MC4ydjMuNGgtMTUuMnYtMy40em0xLTguN3YzLjNIMjQy'
    b'di0zLjN6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSIjZmZmIiBzdHJva2Utd2lkdGg9IjFw'
    b'dCI+CiAgICAgIDxwYXRoIGQ9Ik0zMDAuNyAxNDMuNGg0OXYzLjRoLTQ5em03LjMgMTdoMy40'
    b'djMuMkgzMDh6bTQxLjktLjJ2My40SDM0MHYtMy40em01LjMtMTYuOGgzLjN2MjAuMmgtMy4z'
    b'eiIvPgogICAgICA8cGF0aCBkPSJNMzc0LjcgMTYwLjJ2My40aC0xOC42di0zLjR6bS0zNC42'
    b'LTcuOWgzLjR2MTEuM0gzNDB6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNzIgMTQzLjRoMy4zdjIw'
    b'LjJIMzcyem0tOC41IDBoMy40djIwLjJoLTMuNHptLTQ0LjggOHYzLjRoLTE4di0zLjN6bTM5'
    b'LjMgMHYzLjRoLTE4di0zLjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zNDAgMTUyLjNoMy41djEx'
    b'LjNIMzQweiIvPgogICAgICA8cGF0aCBkPSJNMzQwIDE1Mi4zaDMuNXYxMS4zSDM0MHoiLz4K'
    b'ICAgICAgPHBhdGggZD0iTTM0MCAxNTIuM2gzLjV2MTEuM0gzNDB6bS0zOS4yIDBoMy40djEx'
    b'LjNoLTMuNHptMjguOCAwaDMuNHYxMS4zaC0zLjR6bS0xNC4zIDBoMy40djExLjNoLTMuNHoi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTMzMiAxNjAuMnYzLjRoLTE1LjJ2LTMuNHptMS04Ljd2My4z'
    b'aC05LjZ2LTMuM3oiLz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0'
    b'aD0iMXB0Ij4KICAgICAgPHBhdGggZD0iTTM4MS40IDE0My40aDQ5djMuNGgtNDl6bTcuMyAx'
    b'N2gzLjR2My4yaC0zLjR6bTQyLS4ydjMuNGgtOS45di0zLjR6bTUuMi0xNi44aDMuNHYyMC4y'
    b'aC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00NTUuNCAxNjAuMnYzLjRoLTE4LjZ2LTMuNHpt'
    b'LTM0LjYtNy45aDMuNHYxMS4zaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00NTIuNyAxNDMu'
    b'NGgzLjN2MjAuMmgtMy4zem0tOC41IDBoMy40djIwLjJoLTMuNHptLTQ0LjggOHYzLjRoLTE3'
    b'Ljl2LTMuM3ptMzkuMyAwdjMuNGgtMTcuOXYtMy4zeiIvPgogICAgICA8cGF0aCBkPSJNNDIw'
    b'LjggMTUyLjNoMy40djExLjNoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTTQyMC44IDE1Mi4z'
    b'aDMuNHYxMS4zaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00MjAuOCAxNTIuM2gzLjR2MTEu'
    b'M2gtMy40em0tMzkuMyAwaDMuNHYxMS4zaC0zLjR6bTI4LjggMGgzLjR2MTEuM2gtMy40em0t'
    b'MTQuMyAwaDMuNHYxMS4zaC0zLjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00MTIuNyAxNjAuMnYz'
    b'LjRoLTE1LjF2LTMuNHptMS04Ljd2My4zSDQwNHYtMy4zeiIvPgogICAgPC9nPgogICAgPGcg'
    b'ZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAgICA8cGF0aCBkPSJNNDYyLjIg'
    b'MTQzLjRoNDl2My40aC00OXptNy4zIDE3aDMuNHYzLjJoLTMuNHptNDEuOS0uMnYzLjRoLTku'
    b'OHYtMy40em01LjItMTYuOGgzLjR2MjAuMmgtMy40eiIvPgogICAgICA8cGF0aCBkPSJNNTM2'
    b'LjIgMTYwLjJ2My40aC0xOC42di0zLjR6bS0zNC43LTcuOWgzLjR2MTEuM2gtMy40eiIvPgog'
    b'ICAgICA8cGF0aCBkPSJNNTMzLjQgMTQzLjRoMy40djIwLjJoLTMuNHptLTguNCAwaDMuM3Yy'
    b'MC4ySDUyNXptLTQ0LjggOHYzLjRoLTE4di0zLjN6bTM5LjMgMHYzLjRoLTE4di0zLjN6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik01MDEuNiAxNTIuM2gzLjN2MTEuM2gtMy4zeiIvPgogICAgICA8'
    b'cGF0aCBkPSJNNTAxLjYgMTUyLjNoMy4zdjExLjNoLTMuM3oiLz4KICAgICAgPHBhdGggZD0i'
    b'TTUwMS42IDE1Mi4zaDMuM3YxMS4zaC0zLjN6bS0zOS40IDBoMy40djExLjNoLTMuNHptMjgu'
    b'OSAwaDMuM3YxMS4zaC0zLjN6bS0xNC4zIDBoMy40djExLjNoLTMuNHoiLz4KICAgICAgPHBh'
    b'dGggZD0iTTQ5My40IDE2MC4ydjMuNGgtMTUuMXYtMy40em0xLTguN3YzLjNoLTkuNnYtMy4z'
    b'eiIvPgogICAgPC9nPgogICAgPGcgZmlsbD0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxcHQiPgog'
    b'ICAgICA8cGF0aCBkPSJNNTQzLjQgMTQzLjRoNDl2My40aC00OXptNy4zIDE3aDMuNHYzLjJo'
    b'LTMuNHptNDEuOS0uMnYzLjRoLTkuOHYtMy40em01LjItMTYuOGgzLjR2MjAuMmgtMy40eiIv'
    b'PgogICAgICA8cGF0aCBkPSJNNjE3LjQgMTYwLjJ2My40aC0xOC42di0zLjR6bS0zNC42LTcu'
    b'OWgzLjN2MTEuM2gtMy4zeiIvPgogICAgICA8cGF0aCBkPSJNNjE0LjYgMTQzLjRoMy40djIw'
    b'LjJoLTMuNHptLTguNCAwaDMuM3YyMC4yaC0zLjN6bS00NC44IDh2My40aC0xOHYtMy4zem0z'
    b'OS4zIDB2My40aC0xOHYtMy4zeiIvPgogICAgICA8cGF0aCBkPSJNNTgyLjggMTUyLjNoMy4z'
    b'djExLjNoLTMuM3oiLz4KICAgICAgPHBhdGggZD0iTTU4Mi44IDE1Mi4zaDMuM3YxMS4zaC0z'
    b'LjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik01ODIuOCAxNTIuM2gzLjN2MTEuM2gtMy4zem0tMzku'
    b'MyAwaDMuM3YxMS4zaC0zLjN6bTI4LjggMGgzLjR2MTEuM2gtMy40em0tMTQuMyAwaDMuNHYx'
    b'MS4zSDU1OHoiLz4KICAgICAgPHBhdGggZD0iTTU3NC42IDE2MC4ydjMuNGgtMTUuMXYtMy40'
    b'em0xLTguN3YzLjNINTY2di0zLjN6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSIjZmZmIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICAgIDxwYXRoIGQ9Ik0tMTgzLjggMTQzLjRoNDl2My40'
    b'aC00OXptNy4zIDE3aDMuNHYzLjJoLTMuNHptNDItLjJ2My40aC05Ljl2LTMuNHptNS4yLTE2'
    b'LjhoMy40djIwLjJoLTMuNHoiLz4KICAgICAgPHBhdGggZD0iTS0xMDkuOCAxNjAuMnYzLjRo'
    b'LTE4LjZ2LTMuNHptLTM0LjYtNy45aDMuNHYxMS4zaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik0tMTEyLjUgMTQzLjRoMy4zdjIwLjJoLTMuM3ptLTguNSAwaDMuNHYyMC4yaC0zLjR6bS00'
    b'NC44IDh2My40aC0xNy45di0zLjN6bTM5LjMgMHYzLjRoLTE3Ljl2LTMuM3oiLz4KICAgICAg'
    b'PHBhdGggZD0iTS0xNDQuNCAxNTIuM2gzLjR2MTEuM2gtMy40eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNLTE0NC40IDE1Mi4zaDMuNHYxMS4zaC0zLjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0tMTQ0'
    b'LjQgMTUyLjNoMy40djExLjNoLTMuNHptLTM5LjMgMGgzLjR2MTEuM2gtMy40em0yOC44IDBo'
    b'My40djExLjNoLTMuNHptLTE0LjMgMGgzLjR2MTEuM2gtMy40eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNLTE1Mi41IDE2MC4ydjMuNGgtMTUuMnYtMy40em0xLTguN3YzLjNoLTkuNnYtMy4zeiIv'
    b'PgogICAgPC9nPgogICAgPHBhdGggZmlsbD0iI2Q5MDAwMCIgZD0iTS02OC44IDMzOS41aDZW'
    b'MzUwaC02em0xNjAuNSAwaDZWMzUwaC02em0tMjgzLjcgMGg2VjM1MGgtNnptODEuNSAwaDZW'
    b'MzUwaC02em04MC45IDBoNlYzNTBoLTZ6bTQwIDBoNlYzNTBoLTZ6bTQwLjkgMGg2VjM1MGgt'
    b'NnptODAuNCAwaDZWMzUwaC02em0yMDMgMGg2LjFWMzUwaC02em0tMTYyLjEgMGg2VjM1MGgt'
    b'NnptNDAgMGg2VjM1MGgtNnptNDAuNSAwaDZWMzUwaC02em00MC40IDBoNlYzNTBoLTZ6bTMy'
    b'My4yIDBoNlYzNTBoLTZ6bS0yNDIuNyAwaDZWMzUwaC02em00MC44IDBoNlYzNTBoLTZ6bTQx'
    b'LjMgMGg2VjM1MGgtNnptMzguOCAwaDZWMzUwaC02em00MS4zIDBoNlYzNTBoLTZ6bTQwLjQg'
    b'MGg2VjM1MGgtNnptMTE5LjcgMGg2VjM1MGgtNnptLTM4LjggMGg2VjM1MGgtNnptLTgwOC45'
    b'IDBoNlYzNTBoLTZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMjM5ZTNmIiBkPSJNLTY4LjggMTYy'
    b'LjZoNnYxMC41aC02em0xNjAuNSAwaDZ2MTAuNWgtNnptLTI4My43IDBoNnYxMC41aC02em04'
    b'MS41IDBoNnYxMC41aC02em04MC45IDBoNnYxMC41aC02em00MCAwaDZ2MTAuNWgtNnptNDAu'
    b'OSAwaDZ2MTAuNWgtNnptODAuNCAwaDZ2MTAuNWgtNnptMjAzIDBoNi4xdjEwLjVoLTZ6bS0x'
    b'NjIuMSAwaDZ2MTAuNWgtNnptNDAgMGg2djEwLjVoLTZ6bTQwLjUgMGg2djEwLjVoLTZ6bTQw'
    b'LjQgMGg2djEwLjVoLTZ6bTMyMy4yIDBoNnYxMC41aC02em0tMjQyLjcgMGg2djEwLjVoLTZ6'
    b'bTQwLjggMGg2djEwLjVoLTZ6bTQxLjMgMGg2djEwLjVoLTZ6bTM4LjggMGg2djEwLjVoLTZ6'
    b'bTQxLjMgMGg2djEwLjVoLTZ6bTQwLjQgMGg2djEwLjVoLTZ6bTExOS43IDBoNnYxMC41aC02'
    b'em0tMzguOCAwaDZ2MTAuNWgtNnptLTgwOC45IDBoNnYxMC41aC02eiIvPgogICAgPGcgZmls'
    b'bD0iI2RhMDAwMCI+CiAgICAgIDxwYXRoIGQ9Ik0yNzkuOCAxOTcuNWM4LjQgMTAuNCAzNC41'
    b'IDY3LjYtMTUuNyAxMDUuMi0yMy43IDE3LjgtOSAxOC42LTguMyAyMS42IDM4LTIwLjEgNTAu'
    b'My00Ny41IDUwLTcyLS4yLTI0LjQtMTMuMi00Ni0yNi01NC44eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNMjg0LjggMTk0LjhhNzMuMyA3My4zIDAgMCAxIDE1LjcgMTEyLjRjMjcuMi02IDYyLTg2'
    b'LjQtMTUuNy0xMTIuNHptLTU3LjYgMGE3My4zIDczLjMgMCAwIDAtMTUuNiAxMTIuNGMtMjcu'
    b'My02LTYyLTg2LjQgMTUuNi0xMTIuNHoiLz4KICAgICAgPHBhdGggZD0iTTIzMi4yIDE5Ny41'
    b'Yy04LjQgMTAuNC0zNC41IDY3LjYgMTUuNyAxMDUuMiAyMy42IDE3LjggOSAxOC42IDguMyAy'
    b'MS42LTM4LTIwLjEtNTAuMy00Ny41LTUwLTcyIC4yLTI0LjQgMTMuMi00NiAyNi01NC44eiIv'
    b'PgogICAgICA8cGF0aCBkPSJNMzA0LjIgMzE5LjFjLTE0LjkuMi0zMy42LTItNDcuNS05LjMg'
    b'Mi4zIDQuNSA0LjIgNy4zIDYuNSAxMS43IDEzLjIgMS4zIDMxLjUgMi44IDQxLTIuNHptLTk1'
    b'IDBjMTQuOS4yIDMzLjYtMiA0Ny41LTkuMy0yLjMgNC41LTQuMiA3LjMtNi41IDExLjctMTMu'
    b'MiAxLjMtMzEuNSAyLjgtNDEtMi40em0yNy4zLTEzOC43YzMgOCAxMC45IDkuMiAxOS4zIDQu'
    b'NSA2LjIgMy42IDE1LjcgMy45IDE5LTQuMSAyLjUgMTkuOC0xOC4zIDE1LTE5IDExLjItNy44'
    b'IDcuNS0yMi4yIDMuMi0xOS4zLTExLjZ6Ii8+CiAgICAgIDxwYXRoIGQ9Im0yNTYuNCAzMzEu'
    b'NiA3LjgtOSAxLjEtMTIwLjEtOS4zLTguMi05LjMgNy44IDEuOSAxMjEgNy44IDguNXoiLz4K'
    b'ICAgIDwvZz4KICA8L2c+Cjwvc3ZnPgo=', 'IR')

IR = b64_IR
index.append("IR")
index.append("IRN")
index.append("Iran")
catalog["IR"] = IR
catalog["IRN"] = IR
catalog["Iran"] = IR
country["Iran"] = ('IR', 'IRN', 0)
lookup["IR"] = ('IR', 'IRN', 'Iran', 0)
lookup["Tehran Iran"] = ('IR', 'IRN', 'Iran', 0)
lookup["IRN"] = ('IR', 'IRN', 'Iran', 0)
lookup["Iran"] = ('IR', 'IRN', 'Iran', 0)
details["IR"] = {"continent":"Asia","capital":"Tehran","currency":"Iranian Rial","web":".ir","lang":"fa-IR | ku","tz":"+03:30","altname":""}
#----------------------------------------------------------------------
b64_IS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWlzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImlzLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlLXdpZHRoPSIwIiBjbGlwLXBhdGg9InVybCgjaXMtYSkiPgogICAgPHBhdGgg'
    b'ZmlsbD0iIzAwMzg5NyIgZD0iTTAgMGg2NjYuN3Y0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Ik0wIDE4Ni43aDE4Ni43VjBoMTA2LjZ2MTg2LjdoMzczLjR2MTA2LjZIMjkz'
    b'LjNWNDgwSDE4Ni43VjI5My4zSDBWMTg2Ljd6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDcyODI4'
    b'IiBkPSJNMCAyMTMuM2gyMTMuM1YwaDUzLjR2MjEzLjNoNDAwdjUzLjRoLTQwMFY0ODBoLTUz'
    b'LjRWMjY2LjdIMHYtNTMuNHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'IS')

IS = b64_IS
index.append("IS")
index.append("ISL")
index.append("Iceland")
catalog["IS"] = IS
catalog["ISL"] = IS
catalog["Iceland"] = IS
country["Iceland"] = ('IS', 'ISL', 0)
lookup["IS"] = ('IS', 'ISL', 'Iceland', 0)
lookup["Reykjavik Iceland"] = ('IS', 'ISL', 'Iceland', 0)
lookup["ISL"] = ('IS', 'ISL', 'Iceland', 0)
lookup["Iceland"] = ('IS', 'ISL', 'Iceland', 0)
details["IS"] = {"continent":"Europe","capital":"Reykjavik","currency":"Iceland Krona","web":".is","lang":"is | en | de | da | sv | no","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_IT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWl0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0'
    b'ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDkyNDYiIGQ9Ik0wIDBoMjEzLjN2NDgwSDB6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjY2UyYjM3IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQyNi43'
    b'eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'IT')

IT = b64_IT
index.append("IT")
index.append("ITA")
index.append("Italy")
catalog["IT"] = IT
catalog["ITA"] = IT
catalog["Italy"] = IT
country["Italy"] = ('IT', 'ITA', 0)
lookup["IT"] = ('IT', 'ITA', 'Italy', 0)
lookup["Rome Italy"] = ('IT', 'ITA', 'Italy', 0)
lookup["ITA"] = ('IT', 'ITA', 'Italy', 0)
lookup["Italy"] = ('IT', 'ITA', 'Italy', 0)
details["IT"] = {"continent":"Europe","capital":"Rome","currency":"Euro","web":".it","lang":"it-IT | de-IT | fr-IT | sc | ca | co | sl","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_IT_21 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjQ4MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1BpZWRtb250LnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MjQ4NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEyNDg0'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEyNDg4Ij4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5DQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQTlsQk1WRVVCUVp3WU9vNUlLM0p6WFpPRgpjcUhWQUIz'
    b'enQ3Ly8vLy9KQkNSU2FLaFdnTDFNS20vUkFSK0dHRXlaRWtFL0xuZFFLVzNIQkNVR1A1a01Q'
    b'cFhOQWlLQ0dVOUNMWFZrCkkyRnllS3g0bXNvWlU2VTFhTEJuamNSaWNLcGVKV1ZZSm1pUUZV'
    b'YzZNSG94TW9EVUFCN1Y0TzhEUXAwMFo3QnFJVjFHTEhMREJTZ0UKUUpxT0ZrZFhnYjNIMWVu'
    b'RkJTY05QWlVJUDVqSUJDUjhHMUlkT1l6T0FpRmFnNzlpSTJJMU1YMXdIMWtHUlo3ajZ2VEFC'
    b'aWtKUHBjKwpMbmNMUHBaOW5jeGFKbWZEQmlkM0hWVlVLR3BZZ3I0V1VhVDMrZnk3Q0N3SFA1'
    b'bCtHMUVQUFpRUlBKS3lDeklRVEtJU1RxT3B2OTVmCkpHUUpQNWVHaXNtT0FBQUFBV0pMUjBR'
    b'SEZtR0k2d0FBQUFkMFNVMUZCK2NJQXdrSkxYNmN1UVlBQUFGVlNVUkJWR2plN2R2WFRzTXcK'
    b'RklCaE53MHRCY3JlZTQrd1o0RlF5aDVodi8vTElGd25WV0pMaUFTTFNQei83VGxLUDFseTFG'
    b'NVVDQ0xLVFFVbmJVWFhVREgxNHdveApsdE9XdGxMWlVDbjE0eHhZc0dCOVY3dmhSbGM2REZY'
    b'MHZjNHVhNnhxbGxkanR6VldUeFpXcnkxV1gzOFcxc0NnSmRhUVhCMGVpVFU2CjFteGNEaWNt'
    b'WlZQVHNaMFpPWnUxeEpxVHEvTUxwcHU0dUNTSHk4YWJ1Q0pucTNaWWExNXpkOTNFMmxBUDJq'
    b'U3d0cmJsYUdmWENtdFAKN2U0ZjZDeDFXRUljR2xoSGFsYTF3cXFGeThjNkt6d3NjWEtxc2Z3'
    b'ek5hdmJZUGxldUh6dUoxblJZUW5SMEZnWDRjaTd0TUM2YW0xZgpKMWszcmRudFhZSjEveERO'
    b'SGkydzZrSFUwM09jcFE3cjVmV3J0d1RyUFFnKzFLZlUrQVlCQ3hZc1dMQmd3ZnEzTExlY2sx'
    b'eFlzR0RCCmdnVUxGaXhZc0dEOWhNVXZIMWl3WU1HQ0JRc1dMRml3WU1HQ0JRc1dMRml3ZnAy'
    b'VjB6L1VFTkdmOWdudDR4VHpJUjNxRUFBQUFDVjAKUlZoMFpHRjBaVHBqY21WaGRHVUFNakF5'
    b'TXkwd09DMHdNMVF3T1Rvd09UbzBOU3N3TURvd01MaC9Zcm9BQUFBbGRFVllkR1JoZEdVNgpi'
    b'VzlrYVdaNUFESXdNak10TURndE1ETlVNRGs2TURrNk5EVXJNREE2TURESkl0b0dBQUFBQUVs'
    b'RlRrU3VRbUNDCiIKICAgICAgIGlkPSJpbWFnZTEyNDkwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'IT_21')

IT_21 = b64_IT_21
index.append("IT_21")
index.append("Italy Piedmont")
catalog["IT_21"] = IT_21
catalog["Italy Piedmont"] = IT_21
country["Italy Piedmont"] = ('IT_21', '', 1)
lookup["IT_21"] = ('IT_21', '', 'Italy Piedmont', 1)
lookup["Italy Piedmont"] = ('IT_21', '', 'Italy Piedmont', 1)
details["IT_21"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_21"] = ('IT_21', 'Italy Piedmont', 1)
regional["Italy Piedmont"] = ('IT_21', 'Italy Piedmont', 1)
#----------------------------------------------------------------------
b64_IT_23 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjEyNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1ZhbGxlX2QnQW9zdGEuc3ZnLnBuZyIKICAgeG1sbnM6'
    b'aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUi'
    b'CiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RU'
    b'RC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5'
    b'OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1s'
    b'bnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0i'
    b'ZGVmczE2MTMxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3'
    b'MTYxMjkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTYxMzMiPgogICAg'
    b'PGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBw'
    b'cmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmlu'
    b'ZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZzti'
    b'YXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtBZ01BQUFBWk5TRmpBQUFB'
    b'QkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFk'
    b'VEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQ1ZCTVZFVUFBQURFQUFELy8vOEpwSk53CkFB'
    b'QUFBV0pMUjBRQ1pndDhaQUFBQUFkMFNVMUZCK1VDRWdJTEYya3VaSWNBQUFBcVNVUkJWRWpI'
    b'N2NveEFRQUFDQU9nMmRESC9sVU0KWUFUaEpqbHFqbzZtYVpxbWFacW1hWnFtZlcwTFd0dDFh'
    b'NlZrQjA0QUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNakV0TURJdApNVGhVTURJNk1U'
    b'RTZNak1yTURBNk1EQ21hRXlhQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXhMVEF5'
    b'TFRFNFZEQXlPakV4Ck9qSXpLekF3T2pBdzF6WDBKZ0FBQUFCSlJVNUVya0pnZ2c9PQoiCiAg'
    b'ICAgICBpZD0iaW1hZ2UxNjEzNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_23')

IT_23 = b64_IT_23
index.append("IT_23")
index.append("Italy Aosta Valley")
catalog["IT_23"] = IT_23
catalog["Italy Aosta Valley"] = IT_23
country["Italy Aosta Valley"] = ('IT_23', '', 1)
lookup["IT_23"] = ('IT_23', '', 'Italy Aosta Valley', 1)
lookup["Italy Aosta Valley"] = ('IT_23', '', 'Italy Aosta Valley', 1)
details["IT_23"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_23"] = ('IT_23', 'Italy Aosta Valley', 1)
regional["Italy Aosta Valley"] = ('IT_23', 'Italy Aosta Valley', 1)
#----------------------------------------------------------------------
b64_IT_25 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5MTciCiAgIHdpZHRoPSIx'
    b'NTAiCiAgIGhlaWdodD0iMTAwIgogICB2aWV3Qm94PSIwIDAgMTUwIDEwMCIKICAgc29kaXBv'
    b'ZGk6ZG9jbmFtZT0iMTUwcHgtRmxhZ19vZl9Mb21iYXJkeS5zdmcucG5nIgogICB4bWxuczpp'
    b'bmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIK'
    b'ICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFRE'
    b'L3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5'
    b'OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxu'
    b'czpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJk'
    b'ZWZzOTIxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3OTE5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzkyMyI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUI3RkJNVkVVQW9FQUtwRWRNdkhsNnpadVgKMkxHWjJiT1Mx'
    b'cTFweDQ4MXRHZ3FzRitpM0xuMi9Qai8vLy9mOCtkMnpKZ0hvMFdKMDZmOC92M205dXhIdW5V'
    b'UXBrekc2dFQrLy81NQp6WnZNN05sM3pKbjkvdjFEdVhKR3VuVGg5T25ON05wc3lKRXpzMmJS'
    b'N3QyRjBxUWtyVnU2NWN0WXdZTGQ4dVorejU3cDkrK0QwYUluCnIxMVp3WU9DMEtHSTA2Wmh4'
    b'SWt5czJVQm9FSEQ2ZEpneElodnlaUFU3OS9rOWVzVXAwK08xYW93c21SRXVYUHkrdlZseG96'
    b'aTlPbWsKM2JzRm9rUURvVUxjOHVWOHpwMnQ0TUlDb1VIeCt2VVNwMDFKdTNjY3FsVmp4WW9M'
    b'cEVqNy92emc4K2lqM2JxcjRNRFY3K0NxMzc4RQpvVU1XcUZEditmUDYvZnQxekpnbXJseHJ5'
    b'SkRuOXUxMHk1ZWgzTGxhd29PZjI3ZWMyclVQcGt0cXg0K2QycmFhMmJPRzBxUS90Mjh4CnNt'
    b'WE83ZG9PcFVxRTBhTSt0MjRKbzBmMSsvZ3ByMTl0eVpMRTZkTm94NDVJdTNhUDFhdnE5Kys0'
    b'NWNxZzNManUrZktzNE1GRnVuVEwKN05qYjh1UWJxbFRXOE9BdnNtTzI1TWpCNk5HTTFLazBz'
    b'MmNzc0dHSDBxVjR6WnJsOWV5WTJiSm54bzJlMjdhUTFxd1hxVkhvOXU2dQo0Y0ovejUvZTgr'
    b'YXY0Y09tM3J3b3IxNGRxMVo5ejU0VnFGRHorL2FsM2J4QnVIR04xYW9UcDA3ajllclE3ZHlB'
    b'MEtCWHdJSGE4ZU8wCjQ4ZUIwS0hUNzk0dHNXTEs2OWNHb2tTUjFxMlcyTEQ3WUxjQUFBQUFB'
    b'V0pMUjBRTWdiTlJZd0FBQUFkMFNVMUZCK1FHQ3dBR0JxWjUKZ3lZQUFBTjJTVVJCVkdqZTda'
    b'cjVVeE14Rk1lM3JWQ09BQmF3bEt0aVZiUzBoZUpTUlVDT1ZrVVhGVUZ1UkRua0JnOU9SUlJR'
    b'RVJYRgorOEQ3K0VkbGhtdXptemZEL3BCa1o4ajN4ODJiZVo5Slh2SmU4bGFTaElTRWhJU0Vo'
    b'SGFWTEZiYm5xaG9lNHlwb0dMajR0RzZFaEl0ClpvRksydXRBMjBwT01RZFY2ajZFeVpsbWlx'
    b'aHlJYTNTVFlBVnA2TkNHWm5jcWJJUVFkbEp2TEhjSkN5MG56TlZEcEVLSGVDTTVTRmoKb1lO'
    b'OHNRNEJXSWY1WXVVQ1dFZjRZaDBGc0R4OHNiSUJMQzhMNTNrK2Y4Q2JYeERVanhRQ1dNZm9a'
    b'Mks1YU1OWHlITmNPM2dDd0NxbQpUWFZTdlU0bHBaclJGREpWV1pBeWxTMERkM2lxSEJ1dXFD'
    b'UmkrU2xUVmVrOGhpT1lnVXlpT24yR0x0VlpwOTVuRldaUlRiQkE1K2hTCm5VOG0rRlR5TUpz'
    b'YXZjVUZ5a3VZVGd5Y2k1ak5KZDE0N1dXNlZNRUVJcFpTcDdLSjFHdEdyOWhvNzhJWTRGQnFn'
    b'Q3NicGJhUitrSGEKQkdBMXF5NWRZV3lncFk1Qnpva0dzRkRyMWpxMXFUKzNzN2tqWG9Xd1VI'
    b'dkhlbUJkVTFRZnJ3ZVpVRW1kSUJaSzd1b3U3cEZ2cUQrRgplaGxWTFRaa1JIMnNpaW1ySWF4'
    b'K1ZsZ0RnMGF3WXBuVm5xMUdzSHFZWVEwNURHQU5zeXZWQXdhdzNCRjJUMWNqQnJoR0dUNWV1'
    b'WGFPCnBmZzJTOWFidHdyTGJsZmU2YU1YYnBZeC9FMHRvV2djQnBzb1dGdklhbm03a0haTjBy'
    b'dGpURzE1bVpidnJtV2NuZ2tZclA1ZURWNnUKanRITGt6UCsrOU9oM05rSGs1dEI3Vk4ydnJT'
    b'dVZIWWhaemV3RTBiWXZjRkYzQWE0QXV5bVN6YUE1UmhpaHZYUVNGcHFaWVkxWndRcgpubGxu'
    b'bzk5UXpXTmxoVFZ2Q0d1QkVWVUhkdDEyRDgvRWRuc2V3VmlQMlZBRjFSbEplYkoreXZZdWds'
    b'aWRUS2dzNm9hSzAwZUV4ZlNVCkFkUlN3elBnUmNMU0RHRFo2UmVzengxd3Jkd0FZQlhRVGpv'
    b'dnRFbDZYRjJUTHBGVCtETGxlMjM1UzUzTElzd2dUTVJLcEx3Qlh4Rm0KQXJOWUlVMVhpUElo'
    b'UDBydzZYeU5tYndoTkQwbjZWSzlmVWRhSVJrUHZqRHpGbkVYTVhBcUsvRHdlNitacXhiYVIz'
    b'dUl2UHV6TkhhbApKYXJCbWcrMFR5eWcwWW8rYWcwL2VUOXZESDFwb2w4dzV3TllzNFNKTGM3'
    b'M0IxYS9NbW5CZWdHc1pZbXJvQklyeEJkckZjRDZ4aGVyCkRjRDZ6aGVyRWNENndSZEwra25H'
    b'K3NVWmE1aEk5WnN6bFpSRWJPUHovL3NvTTBOUHRTanhsNzYvT0dXS1h3SFROQzNnd2c3SkZF'
    b'cFIKMzFzZDgzOGtrOGlTdU5tU0hXeGZrY3lrSFB2ZnFIOEwxZ0ZKU0VoSVNFaElhRmZwUDFD'
    b'bnpVZ2Z6eGFKQUFBQUpYUkZXSFJrWVhSbApPbU55WldGMFpRQXlNREl3TFRBMkxURXhWREF3'
    b'T2pBMk9qQTJLekF3T2pBdzFrQnlUZ0FBQUNWMFJWaDBaR0YwWlRwdGIyUnBabmtBCk1qQXlN'
    b'QzB3TmkweE1WUXdNRG93Tmpvd05pc3dNRG93TUtjZHl2SUFBQUFBU1VWT1JLNUNZSUk9CiIK'
    b'ICAgICAgIGlkPSJpbWFnZTkyNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_25')

IT_25 = b64_IT_25
index.append("IT_25")
index.append("Italy Lombardy")
catalog["IT_25"] = IT_25
catalog["Italy Lombardy"] = IT_25
country["Italy Lombardy"] = ('IT_25', '', 1)
lookup["IT_25"] = ('IT_25', '', 'Italy Lombardy', 1)
lookup["Italy Lombardy"] = ('IT_25', '', 'Italy Lombardy', 1)
details["IT_25"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_25"] = ('IT_25', 'Italy Lombardy', 1)
regional["Italy Lombardy"] = ('IT_25', 'Italy Lombardy', 1)
#----------------------------------------------------------------------
b64_IT_32 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTYyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IjE1MHB4LUZsYWdfb2ZfVHJlbnRpbm8tU291dGhfVHlyb2wuc3ZnLnBu'
    b'ZyIKICAgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFj'
    b'ZXMvaW5rc2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNl'
    b'Zm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93'
    b'd3cudzMub3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAw'
    b'L3N2ZyIKICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRl'
    b'ZnMKICAgICBpZD0iZGVmczE1NjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlk'
    b'PSJuYW1lZHZpZXcxNTY0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJj'
    b'b2xvcj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlu'
    b'a3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91'
    b'cG1vZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE1'
    b'NjgiPgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAi'
    b'CiAgICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdl'
    b'LXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmlt'
    b'YWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFE'
    b'ck9WNm5BQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9B'
    b'QUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3Zh'
    b'ZVRBQUFBCkIzUkpUVVVINGdRWkREc3p4YkhadGdBQUdGMUpSRUZVZU5ydG5YbGNWRlhmd0gv'
    b'bkxqUDN6Z3dNTUN6REpydWdnS0lHaXFKbWdxSkcKNGtJcXBhaVZabW8rbG1IMjlKaFphV1pw'
    b'aTgrVFpwaExtbnRxcnJtbDRZWUxvQ0tJeXI0TXl6RE12dHp0L1FQY2V5cnBlZDhYbnMvOQov'
    b'cVhYTXovUG5PK2NlNVo3enJsSUVBUVE2Y2hnWWhHSUNrVkVoU0tpUWxHaGlLaFFSRlFvSWlv'
    b'VUZZcUlDa1ZFaFNLaVFsR2hpS2hRClJGUW9JaW9VRllxSUNrWCtueURhWjdaU1VsSVNFaElB'
    b'Z0tacGdpQ01SdVB2cDVmTDVUelBXNjNXUjY2YlRDWUFVQ2dVajF5bmFSckQKTUxQWi9QdGhu'
    b'WnljV0padENadWRuZjNUVHorSkN2OHMvZnYzejh6TWJQbXp3TExBTUlpbS84d0hlYjJCTjVz'
    b'SkgrK1d2NTQ1Y3dZQQp1dnI0OGxhcmJ0K0IwTGZuUGY0UlFSRHF6NTVET083WnAvZmovMXJ5'
    b'eFNyTVB5QXdmVHhDU0x5UnRnVzJwbGJ6K3B0SFl2c1dEeC9KCkc0MEF3RnNzK2czZlc4OWRl'
    b'RHl4WWR2T280bkREaVVOMDM2NGpEZVo3bDEzRkJkWGYveXBIWGhUcmFiKzdQbnlaWjlaNmh0'
    b'YWxYTmMKMFV2VERjK2w2VWVNenBzNGxiSFpXcTdmV2ZtbDdrWmgzZWxzanVma0VlSHR1b3lF'
    b'ZHNteVpjc0VRZURNNXNvSkdTUGQ2T2dJYkVnNApVVFgvWFlIbnkxNmR2ZnhaMmFZRWxmbllD'
    b'ZnVOUW9Ibld6NWl5Ny82a2JkL1JBanE1SVBteVp6MVczY0lncENkbloyZG5kMlNnR1BaCnM2'
    b'UEhGYWw4Ynd3Y3d0cnRnaURVN0psZC9iM2ZxVlRYNi83ZXhXNCtCVEc5SzlhdGQxaXRqTU54'
    b'MVQvMGVsREVsYis5K1VpVzJpSHQKdWhaYVRwN2FmZkJBTm0vYi9JVkVMK05ycmhjQVF2TEVR'
    b'ZFFacVR6TjlPWGNVVnNUbnRaditQNXVjblN0U1RzbUdWODRoL3phYXF4ZQo5dG1Eb1c2dCtU'
    b'WjM3QVQzWDM3RkJBRVBDOEVsa3NiY1BlNWR2NlhDbXNJbVVYNGJ6WmlUUUZaVUdsZG5OZCs2'
    b'VFpDa2RPU3pFcjFCCmN1QkkyYVl0OVZkeXhSNXBHM0VVRkc0MkcrSjdZYU5lc2NlVTAyRXB3'
    b'd0ZBTlR3NU5pNHVOd2R5TzVuZXArdDNMLzZRS1NrRkFOek4KZFpSL3dKVUw4TzFXVnFxRTAy'
    b'VWxUR25adlZEQlV6UG84QkFBNEtRU2c5cFRFQVRLUGFqbWZPY3oxK2I5Y2sxWm1DY1hyQUFB'
    b'c2xlbQplRVJIQVFCUGtnQWcwVFl4ZHJ0bnp4Nml3cllxTEMydlJ4ekRRR01sV3ZqOFZPWFV5'
    b'UUNBYUxwWDFqcnVwR0wzWWE2a1dpZzJHWkJVCkNnQ0VuKytRekhsUDNYVEt5ZWVmZlFhN3li'
    b'RnNYZjM5TnRWdVZYcCtCd0Q0eUpTSUdkT3YvT085bWs4M2VpUWQ2ZGtsSXZubC9jNDUKaVFL'
    b'TEFFQ29ybW04ZExua215d3V0aWVMSVFDZ3lDWnhYTmgyY0NlRm15dG1zZ2g2Z2QrNFp3OWJV'
    b'OVBhQnpFYUhSYU01UUFBRkxTcwpSU0VBY1BVTkI2MW1RWUJPUHNqRXNpMjFzNFdtN00zcWtR'
    b'WTZua1VTVXVIajNldkR4VWloTU5mVStQYWR3TmNaMGJtY2xtVE1VejFyCmxpNTNUeG5oMTc4'
    b'L3hndnlSSWM4YUpGTjN5QXFiS3RDdFJlbmgyQi9CQUNMNjZxMmpoanBLQ3dDUVNoYms3WFIw'
    b'Rm81cnRWcDdQbFgKZ2VOTUJ3NTl1M2J0WmRhUk1oaS9VeUc0NERqaDUzc3ZsRDNQckYwdTgx'
    b'eGtRcGQyVkd6YUFnRGVjMmQ3OU94aDBHanFSbzBqREszagpUcG12ajBPalVYaDYxSDM0TVIz'
    b'TmVpeXdVSHJVOVBNQmNXamYxc3lwdmJxVHNzNGhsczVCZkhHcE1LVWdyNkRmZ05kR3BKUldW'
    b'K2w0CnZyV2Z3ckhXVzdlMVI0NTk5czJhVlhwdGJIZHNXam8rZXJwalRZQmEyaVVjaW90Yjc4'
    b'a05EYVpmZk8yM05UN3Y2dlE3WHIrK2NhTXkKTGMzU0xjcVVkNVUwM2g5K21BNGVKbnYyS0Jv'
    b'NlZCV2E1L2E1MWJCWHFsdERrWmxHVVdFYmtVWjI2ZWZpOXVhLzlHdVdTbzZmNFhZYwo0SmJw'
    b'R3RadVhpOUZpSUhXM1R3RkhEUGpqVGRPMkMzT3ZzSkhNOGdBSHpSeExzTXkwRXV0UmxLcXRX'
    b'ZGJWMit4V0NUaG5XM1pqZFZUCm5PVFBNT28rT2V5NVM5YjFCSGNiZjJqV1p2ZEtseWhXa3NT'
    b'eFpYaFZ1ak5iaDNFNGpqODI2U01xL05PWjgxYjM2eFJnclNwOVlZNWoKWUc5c1ZnWmh0VUZU'
    b'czNEaUxBK2F1NGxJUVRuU3RpS1dxS2tYdHYzRTVSYndBT0NGNGU3QklaaXpVMHVTMnEwN3ZJ'
    b'WWtOWDI1Q2dBRQpCcG1PU1A1OUJ3cDNsT0x3d0R5YWJkcFUvbFMyNFlYeG9zSTJ0WVVlSGg1'
    b'eHNUN25mNjNrdVZNWCtGTVgrTWZUa0FTY3ZzQjl1NVc5CmQwVUNpRVpJOGR5SWUxZEM1c3dF'
    b'Z1BwdnNqQ2FKcDZ3U3FtZjdtOXhWM0c2WnJFNzB4YnNWNi9WMzdsakZJUkF2UFduaGdNOE1s'
    b'TnAKc2tCeHFZQUJVQWdCZ0JKaHlSSkt5L01INXJ6Qk5Xb2ZUTWw0ZVVyU24zL2lUSkNTNEwv'
    b'TmR1M2VUVlRZRmd6WlovdnMvekdPbFBRbApXb2NOM1FqSlU4UkR0MEVFNEkvaENhUTBBQ01B'
    b'SUphVVJGRDBkRnBSeXJHSWtqNDBBODR5di8vZmNYY25zaDA0em9ZRU9hVFM1bDR4Cmx2TVh4'
    b'SEZoMjFGbHZIaGk4TEQxRXlkWDhXeExSUnhNeS94SkNZMlFLOEphS3VWSXFheVM1NUlsZEJo'
    b'T0FFQTBUdWJackhOSHByNXgKOUREMndET21XeXMrZDFXckFjQXVvMjBJMldkTk56L2QvNUg5'
    b'emJZUnlhYkFUanlBYVdBQy9md1kxa2xCUkVleU40dEZoWDhoY3dwRgo3S0c5eUZ1ZHh6SlRL'
    b'RGtBSkFTR0hIR1l1K0RrVUdkWEFPaFBVdU43OUFvUFJyOEtqalQvQUFDSVZUaGZaT3h6ZHU5'
    b'azdwUThHTW9wCk10S3Y1VW5UTzIreEpPbWtWc3ZTeDJsSHB6elU5UHI1S2lkUHROQzBMQ0dl'
    b'OVBaR05FWDE2TUdjeTJsdTN4YmIrOE1tM2ZwTkE1ZCsKK0JRaENmUDJpZW1LV1R5VWN5YVM2'
    b'UzZxa2M4OEF3Q3BJU0V5aFh4cW9HdjZNRzlwckwrTUJ0NWRkWHpLeTNNVEJ0QURFaDdxbFF4'
    b'TgpvdDNkQlo2WHVMa0tsQlR4Z3IyMFREVjQwRU1LOC9LdENJais4UklQVHlCd3dzdkx2VnVV'
    b'ZXNkbVJXQ0FxTER0T0k4WXRqTnQvTllsClM2OFo5RW9Mb1kzUFRrckVISDJOcHVwcUFLalNO'
    b'VGRMNnZrb1k2ZlIxVHJmTSs0TVhsUmYxemx0Yk4rZkQrQ3VMbzlINDdWTkxzRkIKam9qT3dQ'
    b'T2UvUk5Vc2JFUDlYZHVsMFRPZXMwaGt6bTd1b0FnRU9GaFRFbXBLaXFTa0VwRmhYOXBhTmps'
    b'ODgrT0hQMTVRMk5kZUEvZQoxeGZ1ckZmOTdlMWpQaFlyQUxnQXBIMlFOZUw2d0xvR29hR0dI'
    b'K0FoK2FGWnUzN1NaUGl0Sit6V3hrWnJYcjRzS0Vpd1dIaUhIZUVZCjREZ0FzQ1FCQUE2YUZs'
    b'Z0dBS1FDR0dwcUJMdERPV1pVM2JKUExUcWQyQmIrVmRqeWloMm5UazFXdUl5cWpyNXhFVDN0'
    b'TjV6dUV5ZWgKS0FCZ2VGNFNIQlM2ZUxHaEJpVlY5WjNkS3prenFudlNvb1cvcWRCMDY1YnI3'
    b'Qmx5bFVxdzJ3MG1yVkZ6WEtvZzBFc0VQdU1WQU1EZgpmcE1JNEJtTGlVN3R4VFUzOERhYjE4'
    b'RCtYWTRka3JtNnR2ZGZlZnRYU01VOXRmV1hrNWlNNW8ybXVxa1QvUGU4WVQxMzRjZGJ4UUN3'
    b'CnQ3bnBiL3YySzhlbEtkN3BYbk9uSkdubDhyam54LzY3T0I3eDhSQWZyNit2bHlQa002Szdx'
    b'ZWlkeG1OZlVqRmh1SE5QRTREN2tFUzcKMjdyeUhYMElsMnBCUG8yNXJRTUFTaTV2LytYVE1S'
    b'WWgwbjNpSkYyNzdKZytZMzFGUSs3Q3hZdkhUVmlyYndLQVBNWStmK2JNNjYvTwpBa1k2cnFZ'
    b'OC8rdTFmeGlxOXBzcytkQ2srdHpsZWpPNGROYXhUbGVhU25jQmdLbjZpb01sZy9xWEFBODBs'
    b'YTB2S2EyL1h0QWhDb2VBCkRnTENjUmVDekxGYlUzWnZTeVJwZHd4cjVIa3BndU5XODZYdk4r'
    b'U3lqZ1JTR2poaTJCL0dpWGgzQVFCVW5PMU1haStZaTBzOEJuNVMKZFRYVkM2RHF3bnNoTVJP'
    b'cXpsSXNoM0VDQksxWTZCclF0VU9VVE1kWkNvelFzTjNiYjc4dzVWTVh6MHVzUFFJbmU1S1Nj'
    b'SnhVSWt5Tgo0U1hKS1lkKzJ1ODNkL2FmRE5hcDc3am1oa0p0VFp6cFdrVlEwbG9BOEk5ZHFS'
    b'NjYwTW9QZGpCTStKUmpIY1ZmUjZxRkFFQUdCNm0vCldlWGFmL0RjU3Z6cnBub0pvRTQ0WVJU'
    b'NE1VbzM2YkNoOHFHSmZ6NlVwYm5aZUZMdEhpMXR6RnB2Y2pqY0FCby9YVzFhOWsrK1dTK2YK'
    b'bEE0ZENxSmpaUmZSZE1yRk0zbHZadmJJemM4OGMzcTRpNXVUazFQcXJtM1NidEZQRkVmbTRo'
    b'SzdjVjNEaFp6bW03Y0VuaE1BQkY5dgpOaWd3YXY0OHU5RW9LdnhmdjZQR3JGZ3VNT3l5akpl'
    b'aUo2WXJoZzF0YXhqa0ZCWFo5Yk9QU3laa0NBRFNvRUFYUDkrR2k1ZlY4YjFGCmhmOG5Ia2tp'
    b'ZnN1R3Y5clJWU2dhcmw1ei9jZUM1bE9ubmNNN2V5WVBrY3BrSGE4b2xtNHFiSWZadXJCM2NY'
    b'eHN6RitQVTE1ZURnQUIKQWYrQlNjN2NhMFhkaDJhMlI0WEtvVCsydzJ4TjZKTDc5Y3IzRzR0'
    b'dmNabzZXOEdOZ0JuVEhrL0QyR3phMDltRXU4cjlzYVc2ak0xVworZG5ua3Vpb2NwVXJBUFRy'
    b'MXc4QUJLdVZNeGdSanVNcU4vaWpQUzVNYVJsdk5FbWpJKytsbkRIM3ZSOEsyK09hNEhZOXFM'
    b'Q2VPZHQ4CjRGQnpRNlBOYUtyZGY3Qmt5Y2NjMjdyQXdxN1hGNmVNTVU3STBDWTltNS81VHV0'
    b'Rm83RjA2U2VtNnBycUg3WVJFZUh5em1IM2xaU1UKMWkvNmFFTmMzd094ZlUwSER3TUFiekRx'
    b'c3pab2wzd2kzTjBLMDRvZ21QYnUvekYxekxLa29UZUdwOXF2M3hEYndyYmpQeVZERUFSTApV'
    b'MU5lY29xcXFKaFBHWTRUQk0reHRUdEc0L2FMTmFRdGtLWXhLNUtjTzErMWJZZHYyaGh6cmNi'
    b'eDJaZmxtN2RCK3ZPUlV6SUFBTTQwCnRvVFMvV3ZON0ZWZm1lTHRDaHFrSHl4SmVucUFZY2V1'
    b'VDc2WkdSUWpKTC9UNkQ1MnRDUTBHUGYwQkFDQjQzYk9mSDJEWDduWkd3NmMKT2J4N2hkcDMz'
    b'UnB4YU45MkNqOWNXdlQ4aTZxaVlnQ1FobmNHZ0xvajc2bmpqbUZCeHNncFN2VmFFd0FRTjI0'
    b'YXQyd3oxbXJjT29keAo4WEdTV2czYWU2QTRhNzMrN3A0S3krbnM4L3YyNzNKWVhwbUE0d1JV'
    b'TmpVaEhIZEtHWjVZcHRKWmhLMU5YMlVtRHFtYU5iZTFFcHJNCk9nU2tCRDZhUitiWkhDZCsy'
    b'dThRSC9uK0ZjTGVlb1B5ZEFNQVZ1Vm1VTWdBZ1BhTHF6emI1OWY4akY4SzhkdFhuRnVTS1Yr'
    b'ZjZlenIKQXdBc1FRQUFlZnVPUERSWUdSVFlhc1ZxMjFWVlBqZ0JleW1USWJLbEtXUEhJcWtV'
    b'OS9UczhlR2k1anJzbG8wNzRXdWF0MytmY2ZzdQpBRUNVZEZqdjN1N2xrZ216SGIxN1lDZE5C'
    b'a2ZoVFZGaDJ6RlY1cmwxUGdJQTlMU3B2Z01INUM3NFIzM1dyMzVwaCtKNjlrMmVmSnc2CkZ0'
    b'a3FxVmFqT1hiODVoZGZFU09TQVFBUkFzYmVXMmtLYkZWMUU4ZEpTS1RUQytuaHZidythSDBh'
    b'NVpJeHNYZGoxTnB0ekkzYkFnY0MKRWRBSkFCQkZCYnd4WnlUdnJXMFdJb0t4T3h6RGFqU2l3'
    b'clpqemxudmtXNGxnM25BY1ZXMzZKZ2xpNjE2dmNOcTllLzNnaTMzR2lvbwpCQUFyVFhFcU4v'
    b'M2UvWjJtVEZhRmhnS0F5eFFibUdiZGUzOEQ1dXBDSUNBSkFJRGxWeTdxMW1RQnh3RUFielJx'
    b'NzI0R3hqRWM3dmFWCm1NcXE3ZHA2QVBEM1FUWkJZRXJMUllWdHgzSUsxLzhnOWY3S3lPNWFW'
    b'WHY0WjRSUTJJcGxNaGVYK3B5THhtbXpjSTREQUk3QVpiNisKUW4wRGhrQzNmS1ZpaU1ObHFs'
    b'M2VZSy9QYVYwL2lNbmxiaGloOWtBQWNOSmhlKzJ0dDNRN2YrU2I5WTA3ZjF4V2VxdDFKR28x'
    b'Tng4LwpDUnhuUG5aaTI5L2YzV00xOTR6Q1dBNDhjSndNQ1JJVlBqRWMzMXFCN0NaajdVWlA3'
    b'WEtaNzd1MTNOb1hienczcG1udi9yb3o1d3o3CjltTjNLdzNKY0piVHY5cVV6aVhKejdqM1BL'
    b'WEt0RFI5VHRjdFVQQ2ExazFsaE5xemo5cTdzbGFZTllrQWdLMFd3N0NKTHg0ZE5LUngKMzM3'
    b'OTNlMDFWaEFhQ290SzNsMzBkdXJvR1hkdTlvakdQbGxBZnJHTzdTcWxwVkdSQU1CeTdmU2RM'
    b'TzEwVU9GdzhBRFFlT2t5RVJqSQpGQlNhZnpGYUx4RHlKSWVuK2hmMnhDbmJha0s0YzM4N0M4'
    b'WFlZT2NpN3pDT2ZJNnpYeWNxUnlsNUkrSUluTCs3OXA3dzlZMzM4WjF4Cm92amxkR0xORXZM'
    b'N1BkeVpTL2JrdkJ3NkgxbnYzbXdiZVg3U3ptMjNPU1k4RXEwY1M3b3EwZmhaRHIxUjZPWHZp'
    b'bnQ2QUlEZHdZa0sKbjZRSnRMTUFvTjIxeDJOMGF1V1dyUURBVzVGeDMyK3ZKQk00c0Y4ajdO'
    b'Y2UraTYyVjEvQkRoMnhwWTJtWEYxd2xadDcxeTVkTDJTdgoyY0s0S3RHQU9PejF5WVRSREpl'
    b'dThmazM3dGV0UVpQNDF5UElvdHY4aW0vWnNxclc2eUdCQVdSZ0FBQlliS3lvOEFuUU50c0JJ'
    b'SHpwCkJ3QndSNmxrYlhhQ2ViSVM5SnVZYnRpK3E2WGJBZ2dwbmgwZXZISDlOWmJSNllXOVIz'
    b'KzdQbVZ0WTQwUG5DV2tRTWdrQ003ZG9sdE8KbkduVTI4VzI4QWxvMUR2NHU2MFUzaU1HSmZS'
    b'OTRpOG1sUWEvazBtNXF3Q0FLU3MvLzhWWEZSd2JjM2MvaGdRUThlZ0dHekNiQVFkUQpJQVFB'
    b'bmhnK2dLUlVHUGI1ZDkrWmo1M2tlVjVyWUVTRlQ0REc3cG1YbHc4QU5vT0JKUERmVDl4eXJn'
    b'RUFPQWpjM0RYQ0FZSTE3aW56Cm1iUDNFdkFXNjRmWnAyUUlqWmEySGlFVlJaQkpFdXJCSUZL'
    b'RU1FQ3YwSW9nbkFDQVBvVEVBc0k2TDM4MVJaR2h3WmN1WDZtemU0c0sKbndBN0hiNzF4NTg1'
    b'aGlsL1o2Rkx6eDRBWUZQSXJRR2R1TFRSNXNHREh1a2FHb2NQdFljR1d4Vnl2bmNjbVQ2T3d3'
    b'a3FPcEl0dm4xZgpUOWVJSFN0VzdzNmNYMHNRUGhqdWptRUJPQkd0VUFCQVo1eHNTVE9KVW5B'
    b'Z0VJQmFkbEYxSWNoOHhoSGR2ZnViVzMrUWhBUnYyWG5ZClRvZUtDcDhBaEZPWEM2b1JoamtQ'
    b'VC9hWm1nRUFhTUU4aktaSVp5ZkoyTlRtdEZFUHRlZSt2bWhTT2dmZ05HZ0FIUnhvSTNCWjdG'
    b'UFcKbnc1YW11NmZOK0l4ODFYQzNTUGJiSGlaVW5BQ0RBNEkyc3ZvZkRIOHBhQVFBT2lFRS9P'
    b'ZVN3MVFZMFYrdHRuUEpOSUl1Y2psMFlTawo5ODhIak9jdkFFRCt6VHFFVTZMQ0o2T29YbDU0'
    b'czloN2VESkpVU0FJdUpzYkpwVUtQTTlxbTF3ZlB1OU9VbGRQVUpRdE9oS1R5UlN1CnJweVRr'
    b'em8xeFhQZGFwbWIyNzAwMXJQbng4MS9TNDZ3NTBKQzFTR0NOWkI5TlFNZjdlU1VsRGlJQURU'
    b'VVNWbk9XMmM2KzA1NGhxencKNHdQOVVaWFZzdWZyMWRrdlpMaU5UeXNzdW5tclNTa083Wjk4'
    b'WENIcitlbXExc081N1BXTjZrRlBXMlMwd1BHZHhveHlldUEwRWdEQQphbXJEWDVvaThmUUFs'
    b'aE1FVUhZTzFSWGNjSStPZWpBTjNiZlB6bit0UHZqSnA0V3VTbk1GVG5Zdkd6QVVJbE9adW9w'
    b'cUFZVHJGck1YCkxhY0dONFFPNHFxY2p3VWFxZHNPQjFkVkZiSnl1U1FzZE5rWEcweFVkMUZo'
    b'RzdKR1psODMxdFhWNjI0VXNqYXI0TERMY1p5MVdVbEsKQ2pndTNOM09ZcGZMQllZQkFEQ1pi'
    b'VWFENExBN1BUKzJjdUZpbm50MDVPQTBmdXoyN2RzL1B2dHI5NzZBNDhMRkxNWEVqQU5kUTBN'
    b'OQpNVHdFSjhQZmZETTk4S09pSEZSZHdubDdDK2NaKzd5UGwvSjZ2VWFqT1Zka0JZd1VGYmFG'
    b'ZWtuOC9FVXJiZVVWdnUvOW5UZVo3VHh2CmRTT2JjMy9BWkkzNE5HOThaQXFIRVBIM1RGemRK'
    b'QWlDZkdRa1o3T0ExZVkvTVQxNisyWU14eDlyWDNHenBtNkNYTG5ZYjZLamlQRFYKK05FSi9Y'
    b'QU0wd2w4SGNjS1BLOThlUXJWUUhYVytIK1UrdGJSOUVudmZmRUZHUnowMXNLVkdxSmRyMmxy'
    b'MXdvUlFSKy9McFM1dWF1ZgpIYzQxTnRKT3pqN0RvempOQi9hSzJWVHZXR2xVVnl0TlIweC9X'
    b'WmxhYy9PN1NBcGZKY2pzanVMYkFFQlN2OUgxUUJUMSt0blRtYm1YCnV2NTl2bmV1T3ZITExM'
    b'YXFhdE9HalRaQk9NM1libnl3Rk9GNGRPRHJ0VGYxNXJLSzJPKy9DNXIyMHRsekYwOFhFKzIy'
    b'STlPdVoyZnUKRHhqa3ZlY3QrdnJrM24vVmJ0cmlramhRVzdTWVlhaVFPSTIyZkt0Qnp5Q2Fh'
    b'amkvaWJITGdoTEthdlBscE92bCtrTjMzSjRmcmZEMAovTzF2cS9ZQ2dMUHBHWE1xeTAwdlpo'
    b'UWFEZi9VTlFDQVhSQW03ZHM5UDc3UWhtQ0pUc3NlT1p6SnNnNk9tL2YrYWoyVjBzNkxxUDJ2'
    b'CkkwVUZqb1JYNXk1ZXQzcVZ6ZGhzcWdod1hQdkVXUGVDUy9Td21weUp0RVdveVZ2aUZUR2ov'
    b'dEphQi9ReXNlVlA3ZDcyeDNOdlhsNWgKT0xHcTVGWWNJWWtoeUR5V29SQXlDOEx1a2x0WFdh'
    b'WTNJVTFPRzRNSVl0ck1kd29jQ1VqUzNnc0lwMExIdC84OGx0Y2FNSE54LzRSNAptV2RRd2RH'
    b'djZhYmVoTXBmS3UyRzloNzBXbjVZMVNXeDRrUU81VUpGVHQ3OXlFY3JLeXNCb0ZPblRnOWVk'
    b'QjZZTUNZZ0tQUnkvbGZOCjJqQ2NVR0dZQzhKVUdKYlBNdHNqWSticzJ1NDdaZkxLMWVzMy9R'
    b'cXMxSy9kLzhRN2hFSUFobkMva2xmZ1FSa0NYQlRhTmVjVklTSGEKelZ2TVY2NWlqVTM2cXpl'
    b'MFg2MUd4U2Fud1M4N1A3RHE4SGNVSXBLa2VzYWc1dWJCT3VQbm1xb1lRdUtDWVJkWjVzZkFz'
    b'SURYcHJ1TgpIYlY1NTc0bEc0dE1WRFIwQkRxR1FnQndrRDQ1T2VmZFhkaVVKWXYwbFpVbWpZ'
    b'Wm5XS0t5aXUvYm0zaG1RTlRxZjVKZW5vLzNZbjVUCllRdXFRUVBkUW9KVGdhZ3NMM01WMEh2'
    b'Snc3djlZNEg3aStsWkc3Wi9rSFZaUjhWQ0I2RWo3YW5RU3Z1OHZ5NnZ1dWFydDkrWTd0cTkK'
    b'VzlXNEZ4R0dFZUZoRkU0MGw1VzdQUG5SSXNxa3djcWt3WE4zN0Jic2RzOFhKd0RBb2lWZnJq'
    b'dXFNMGc3MHM2WWRyb2cvL2QrZE5ieQp2dDYzVjd5Y0twZkxEVG1YcE1HQkFjK08rSGN2a1do'
    b'NVQwWExndnpmUjYvWFQzN3QzZXlhTUViYXFZTVZDSFEwV0RyZ1ZLTkgyc2ZiCjUyUWtUcDR6'
    b'Nno4Uzg5djFXMWQ5ZjdJVW5rWlN1c01WU0lkOFp4TWlaS1hFc1BsWlpVbWpYenQ2L05SZkNY'
    b'WGs2QytKbzJZc1dGOWQKUmd4REJOMGhTNlBEM1VnZmdiSmNqM0xYakJnVTg4cVU4WSsvbStu'
    b'ZjNVaU5SdU0zMzIwOWVESy9RT3R0azBWMjZCTG84QXBiRUd3TgpQdWhhc0pyc0d1THg3SkIr'
    b'VVpGZFZTclZJd3ExV3UzMWdocy9IVGxUV05KUW9tRnJJQXBKUGY0THZ2dC9pY0w3TGprYk1w'
    b'ZTU0ZzFLCnlrNUpNQUp4QU1BS3VNM0I2KzFTSGVzaHlBUGIrWnpuZjM5MzVnOStramdGemhF'
    b'NmlOQUJ3SU9QbTNBQUdjQmpod3IvRnlDK2dsSlUKS0NJcUZCRVZpZ3BGUklVaW9rSVJVYUdv'
    b'VUVSVUtDSXFGQkVWaWdwRlJJVWlva0lSVWFHb1VLVEQ4aitDQXJyb2ZEVDhRZ0FBQUNWMApS'
    b'VmgwWkdGMFpUcGpjbVZoZEdVQU1qQXhPQzB3TkMweU5WUXhNam8xT1RvMU1Tc3dNRG93TUJx'
    b'eDc1a0FBQUFsZEVWWWRHUmhkR1U2CmJXOWthV1o1QURJd01UZ3RNRFF0TWpWVU1USTZOVGs2'
    b'TlRFck1EQTZNREJyN0ZjbEFBQUFBRWxGVGtTdVFtQ0MKIgogICAgICAgaWQ9ImltYWdlMTU3'
    b'MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_32')

IT_32 = b64_IT_32
index.append("IT_32")
index.append("Italy Trentino-South Tyrol")
catalog["IT_32"] = IT_32
catalog["Italy Trentino-South Tyrol"] = IT_32
country["Italy Trentino-South Tyrol"] = ('IT_32', '', 1)
lookup["IT_32"] = ('IT_32', '', 'Italy Trentino-South Tyrol', 1)
lookup["Italy Trentino-South Tyrol"] = ('IT_32', '', 'Italy Trentino-South Tyrol', 1)
details["IT_32"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_32"] = ('IT_32', 'Italy Trentino-South Tyrol', 1)
regional["Italy Trentino-South Tyrol"] = ('IT_32', 'Italy Trentino-South Tyrol', 1)
#----------------------------------------------------------------------
b64_IT_34 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjE4NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1ZlbmV0by5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMTYx'
    b'OTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxNjE4OSIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNjE5MyI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBWUFBQUJrVzhud0FBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQTcKZ0VsRVFWUjQy'
    b'dTI5ZDVSZVYzM3YvZG1ubjZkTzFSUkpNNk0yNnBKVmJVbTJNY1hCWUVQQUdCSTdjSUdFY0FO'
    b'YzhwSkE3ZzJra0VyZQptNFEza09RTkpJRlFjc0VZSElveHhoU0RjWkZsOWQ3YnFFeHZUejk5'
    b'M3ovT2FFYWptWkZrTTJQc2hmZGFaODE2NWp6bG5PLzU3bC9mCnZ5M09mZXNleWN2ajVUSE5R'
    b'd1BvL3M4aTBuOXUvR3A4ZTRxZXI1ZUlLdEhMS0Y0K0JEUy9KMFBYbHdvUVByZVBOdjFtbXY3'
    b'dmxmRjcKd3BmdTdhdUN4bmVtWW1JUmdaWlZNSnJVY1c5U0RJWElHMDhjdnkvRTZ4MjdjYU5C'
    b'UmF0V1g3QUxkenA4b29wRXl5cTRUVHFoRk9PdgpHWW5kSCtBUGhBaERrSml2SVJFdnlMV0Zo'
    b'UkMzY3dTYlVLSmwxZXZEdERmRTY0cy9KeU9KVnEyZzE2a3ZPVklGZ3lIK1FEUW1zUUNNCkpw'
    b'VlNBUXBwaFZRbEpLRUt6RVlGcHp1aVhJd29wRFFTUXdGVkxkbzRZdmtESWZZQ0hhODd4TDBZ'
    b'ek95Vks1QmViZUowK0xoZElmNDgKd1VNVmc4OGZqaC9DbXhkR3ZLUE9RenNSb2RlcEpCYnJG'
    b'UGQ1ejFrYVA5ZGhOS2lZclRxVjAvNjQvNXROS3NXQ3BKQldTWlZERWhvVApNUjBld2JSdkRO'
    b'TXdGNUphWVpEZjVTSzlGNytsSWpSQlpvT0pjOFlmcndvdmpYeGE0UmxmNTA0MVJMVUV3MDg3'
    b'bUxOVlVobUZuWkZHCmMxcFF4ZmpacHRnSytXZGQ3SGtheWVVR3hUMHVpYVVHV3BWQ1dJcW1Y'
    b'Y3c2NTN5VXBFSnF0UVo3SGU2WkU5SzIzaUxuQzI0dE81ZzcKUE95Rk9tcFNvWHpjSjdGWVJ3'
    b'YlQrM0FVV3hCVm9MalBKYkZZUjBrbzVMZFdVSk1Ld1JVa3pxYzB0Z1VhZCtvaGluazVwaW83'
    b'SW8wNQpxWW1ZU2lISVBlT1EzbWhTZU5ZbHRjWWNPVEd6QkttNEljVmlUQTRoVkxSVUJyOHdC'
    b'QUpTS1IzYnVFeUtDb2xRQmJudEh0bDFCcm50CkRsSXlPYkhTNVpDN3RCRFRVc2dOUkhUZWxL'
    b'U3h3eVZUbHJ6QzlpaTRFdExLdUl0eEczU0dXd3pxZDVaUit5TXlteTJLZTExc1RTY3MKeWdt'
    b'eitPY2RsMGpqWHZDcHVzVWl2OVBqeGx3SmRJRW9SS1EzbVRqblFpRENiTllvN0hLblZ6ck4x'
    b'ckRtYUpSUHVHUnZzcWljOFFrdQpCQXh0VG1JUGg1Z0huWEh2ejFSQzd0SURkRk9RSDVReHBt'
    b'ZGRNdVdJMjJ5ZmdodEJhanltc2xYSE5RUmlsMGZtUnBQaUlZL0VJb1A4CmRtZEdpWlV2NW1u'
    b'czdRUkFiMnhpenQvOE1XZmVmUzhBT2NOa3VHRTJTZDBBQVprTkp1VmpQdG4xQnNVREhzNGNB'
    b'MTBENVpoM1NibU0KallRS2hpWElEVVQ4cU1ybXJkL1QrQW9XQlJTaWlpUnRUMzVCdjc5VjVk'
    b'SFpTU28xS29YdERxblZKdjVBU09STHNwdE1oRHA5Tms3bApwSTk3TVNDNXpLQ3d6eU85MmtC'
    b'UENOUlFrdDVvVWp6a1k3V29SSldJNHI3cEk1VVFrRnB0b0tVRWxWTSs2WFVXaFgwZWppYll2'
    b'U1RGCnU1L1NpU2F4NVd4Tm9wdUN3cURraDVrWTA2K0tTNWhHcEsySm4vR0JINm9tbGVaWWxT'
    b'ZVhHRGduZmRJYnpGK1l1c3Q2TG1FUUM0bjAKRFNiT3VRQjd2a2JwdUlkYnJmSXoyK1J5cmEx'
    b'Y2JsVGFMVHFWRXdGZDdSWi90aU1XZTU4OXFISjBsb0hYRzZKbFZaUkpnQWdqd2NkMwpxdncw'
    b'WXlGYWRISmJIUkpMREtLS3BISXlvT29XYTFwdjB1OFB5ZTl5cWJyWkpyL0RJYjNXb3VvMmkv'
    b'dzJoK3hOSnFYREFlN0Y2ZldzCk1qZGFCSU1SWG5kSWVwMUo3c2tLU28zQ3ZoYWIzM2xDb3h4'
    b'TXhFV1lBcXMxeHZUaUlvcy8zeGxqK3BtREtrY2J6QmpUYW9GaVQvenMKVjQrcW5KeGxJQU53'
    b'THdibzlRcCtYMFJpc1Q1ajVLbGF0NEdGRHo3TXdnY2ZwdTFmdjBoaTVlclIxd3NmZkpqNnU5'
    b'NkVOVThuS0VXbwpDWVZnS0NJcVNTNjBXdnpUUHVWS2N6Z2VrUmZoZEFYWWJScE5aMTArdERy'
    b'Vys3L1dMbGt3NUtOWEtZUmxTZVJNcHVnbEgxb1Zjb3ZyCkVYWDRwTmViVk00RUlDVDJRbzNo'
    b'cmRNcndyV01Fai9jcDJQcFdEcm9rdHZxa0xuUklyL05KYlhTUUs5WHBsZE43SERRNjFTMHJF'
    b'SnAKdjBkMmkwWFlGN0tpMStYdnQ0VG9rL3ljZENYdXhSalQ1ck11SDFvVmsvMis5b2oySVJl'
    b'OVdpRW9TcUxLUkV4dmI0bVlQeHhMQ0t0RgpvOXdSWU01V2NVN1BuSU0wdkdzSEorKzVpNVAz'
    b'M01YWi8vNHV5Z2YyamI0K2VjOWQ5SDMzV3pnZFBrYWRpdGNkb05lcENFUFFlTkhqCmJlMXlZ'
    b'aHhyVk0yVUkweGJJV05KM3VKV1dIbTd5Y0orajJ3cFJLOVZ5UTlFWkJvbUl2akpMU0VOKzh0'
    b'b3JpUjFvMFhwb0ljNVcwTkwKNnVTZW1WNGJ4MnJWTUJwVVNnYzhVcXNOQ25zOFpBQlNrUlIy'
    b'ZTJUV0c1U1BleGdOT3NZc1NlbVFOeTIvSzBNbzdIR3hGK29Zc3hRSwplN3pZempqaWMwdC9r'
    b'U1czSm1CNElrRXFaWWxsQ1RJV3ZNVnhXSG03eWFJQmowd3BSSzFSS2ZhSFpCclVDUS9sdmlv'
    b'UGE3OUxhb05KCmZxZExacTFKWWFkTDVQOWl2TVJBS0FoZGh3ankyK05KWE5qbGtWNXJJUGU2'
    b'M0xOUW9QbFRFQ3VYMGppQXhxdENqeXBUc3VwQUNiMUsKUWE5VmVTYlFxVTBHWks1d1Rhdytu'
    b'Nlp6SG1hVGl0bXVrZDhXZTBwNm5VcVFDMG10TnFiUHpsRUV3VkFjUjB1MDZ3dy81U0RxTkk2'
    b'MgpXUlFDd1pvZWgrR25IWkxMRFpDU1lEaFdXOVB1RlZxQ3hHS2QvRmFINUNvRDNaSFVieTJo'
    b'VlFtdWRGVnlTWTJuaE1wclFvOHFpeGpUCmFnVzFSdVhaUUtjMktTWmdxbDBNVU01NlpHKzBL'
    b'ZXgweUc2eElaU2tWcyt3alRVa0dPcU5TUzRNay9Lai8wbHh6VnhRQkdxVnplejYKeTR4c1JW'
    b'QjFxOFhRNDJVeUd5elk2U0pVTWVyZmp2Y0toMExhTTFDcFNOSUdwRmNaQkxtSVFsOUlRMGFo'
    b'YWlpYzRNR0VoWWprQ29PdwpLRWVsVSttd055UDNMUlJJcmpZSmhpUHkyMTNjZG90SEZJTy9m'
    b'VnhGU25qM1VwdDMzcURCbmtwTTlCYWQ0dTZabmVYRmZSN0diSTMwCmVwUENyb2txUHowYzBK'
    b'NlJsQ3VTcERXR2FYRUUwK3h3QUtueEVpdDBJcktiTFBLN0hDSkhNdlJZK1FXVFRDYkp5NExo'
    b'cDhkZUQwSCsKakRPRm1lQ1MzV2lSZjlhWktMSDgzcEJNaXhiUG5xUXlHallScGlEZHFKSW1n'
    b'b1NDMXpsZXg1dHpOUlJMUWJGNEFhTEZrdkpSbnlBZgpCMEQ5ck9DMU11QzF0d2FYZVc4Q28w'
    b'bkY3UW9KY2pLV21Nb0xFSG1YeEliNlplRVY3N293VmZHNnhtTnFOR3BJSDFJcmYzRmU0SE1k'
    b'CmtTY3hHdFhSek1Nb3NieStjRnowOS9wVExBRk9SL0NDMzRqZkg2TDNWNWpNUjdva0w4TnlS'
    b'SDZuKzhKZTJHVWNmcjZZZXAzQmhBbjgKVWhtWFFrdmkzTGZ1a2RLVDQ2S20xMlZuR0NKV01T'
    b'L1hSa3pFeGhSRXJueGVud3NLNGFQU2s0TXZ4SFhLQUd2YWlhVUlvVlVyN1JwQQo3emRLeVBD'
    b'NUFkRndiNHIrYjVlSm5KZXJHNjZVV0kzdlNOUDNZQkg1SElYVnJMZG5QS1ZLZTc5bFdyMHZj'
    b'UlNTR2tEa1Nvd0dCYTh2ClFrMElLazA2OG9xcWdVUy9SemdVcDBtY0N3SElXSzlHYnF4YmhS'
    b'Qy85Snp5dW9OUkFSNjVFcjFCdys4TlVCTUtsZVpKTU8zekNZWWoKekdZVjkwS0FVS1JST2VJ'
    b'OVhuWmM3eVVMZ29KSXJUQVdqTnBZV3JXS05VOG52ODJoMkdUd3dhMGFYaWhSaE9BZmJ3NHd6'
    b'N2l4dTZzUQpFK3V5VVhkbjRvVXhrRi9rbyt0TEJiak1BeldxRmV4NWNkQzIxS3p6Z2FjMC9J'
    b'aHhtS2JYeExrM2R3VFQ0bjZ2UmJVRWRydE9NUHpTCjBRWnFSc0h0aURNZXFSWEcrSENEMXgx'
    b'aUw5U3AzVm5pZlV1U2ZIaXJ4a2ZYaDlUdnIyQTBxb1NGQ0RVN2VVUzdaempnZ1NjTHY1U0UK'
    b'ZXNQR0ZQTWE5Q21rV0lnMVg2Tm1SNW4zTFV2eWthYzEvbWg5U1AzK01rYWpTcENQMEs3QTFP'
    b'MEtNUm8xdko0SXIvdkZiOFRyTlNyVwpBb0Z6TGhnMTNzY1J5KzBNU0xUcnFBYmNtSGY1eEMy'
    b'Q3pXVVh6WTB3NXVrVWRybWsxMDd1QW5jUGhYenkyN2xmU21JdGJ6R25KSmJiCkdaSllyS09h'
    b'RVRmbFlrdzNYY0swellneFhUOGVVNzFXb1hqUUpiM0dna0NTdXNGQVNrRlltRmtKZGpCdnM2'
    b'czBLNWEyaHMraTFnNE8KblZpSUtpSVdXSGsyVlkwOVh6VWhFS2FJUzZZVzZYSEtxMVloR01r'
    b'K2FCTUNmdnM5c3BzdGdoMHV0eU9KenZta3Qxamt0bDZIMnk2VQpYMHBpY1EzN3NyalBuWWpw'
    b'SnB2Y3RzcWs3Ni9VYUxncmRPU1RaYkkzbWVSM2VTU1g2aFFQdWtUbG1YUEREeXZWZkNXNURv'
    b'REd6QkIzCnJIcUNqKzM0dGZnV281QS9PZjQ5VmxGRUdIRmhYMm12UzJLWlFYNmJTM2x6RW0w'
    b'd3hCeDJSMHl0SzBacWhSbm5nTmFiaEdkOTBtdE4KQ25zOWtzdjE2OEJYK2VVOHJvRkxhcVV4'
    b'bWxzTXovcWsxNWtVOXJza2wwOHUvU1h3MTRkMTh1dHRjdHRjVXNzTlNvZDgwbXRNRkhQbQpi'
    b'RmxkOTJtcDdxT2x1by9aVlFOWXVqZjZlbTd0SUVWTFIyaVEzUmpuZzVNckRRbzdYSW8zMkh6'
    b'aXFENnVYSEdDeE5LcUJNbGxPczRwCm41cFgyNVJQQkZndEducWRkbG5vY1FvLys1ZFZZbDJE'
    b'V21wV0pibFVVRGtWakdEcXg1aldUbzFYUjA3UW95bFVXZUQxQmVqVklyYlgKNW1xVVQvb3pj'
    b'aGV6bW9mNTZPM2ZBTURTZkZwcSt2am9IZDhZUGQ5L3dNYnNUT0wzaDZocGhYQXdRaWd3YUtz'
    b'Y0dnQm1YWVZZWVVYaQpEMFNvdHFDdzIwVXhGV1FJUVM2OEpyWkNlVmtWVGphaVNvUS9HS0Zh'
    b'akdKS0lBbnlVOXRNSDc4cFpOSGhDa2E5aXRBRXdWQ0UwYVJPCmEvSGlsZU5pUnoxL2Z2L2JS'
    b'bFhocDkvNjc3enYvdmVQbnYrOTRnOXc1QUNKcFRwQ1FPaEt6RGthTFljcS9PMFdHd1l2anpw'
    b'TU1wd08KSDYxT0hTbFUweWdmOGE4ZjRGL0c0enFHYzhaSHI0OHhOVnRWU2tlbnh0UUtKUXRQ'
    b'bERIVTJJMzN1Z1BNRm0xR1NYWDEwRlRJZk84OAo3VkZzdkplUCtPaTFLbUV4UXVnQ013MExq'
    b'NVZKQk5IVUV1dlNLT3oycUxyWkl2OU01ZnJWd1MrdEtyeStNVnIxK3N6VkN4L0QwejVtCmpZ'
    b'STVMNjdPU0swekVRcGtObG96ZW4xdkRBWjVsZi9nMkhVOE5wK3Z0ajJJb1VMR1VFYm9Na1la'
    b'cTBVbnY5TWh0ZEpBOW9aNHg3M0oKd3czajViZGsrSW5LYzFBSHNmSCtzaXE4bWs3a3VqRFZx'
    b'bFN5TjF1VURycVliZnJvV3IyWmwweVFtZUtjTjhYcVc2dFZKOGhMTXVzcwpjdHNjZ3FIb0dz'
    b'UjZQZ2JzeThiN3ovOU51a0FHa04vdVh1WWp2Z1NrOFU0WFpIejkwMHlzWDJLSk5WMGprckxt'
    b'TnZ1TDBoY3Y0UlNHCkZOSm4yYlFTaTVlOXdwK1RXRVJHbGZLNUtKQjlMMWtvRkNuQ0lHeWRO'
    b'bUlKeEMrdHhKbzJSYWdKZFhpWCs5MndGTDFrdTRJSVZaRGQKYk5WcjA0cnV5OGI3enowcXAv'
    b'MGFOYUdRdXNIRTczdnA4RXV2VXlnZDluSFArMlEzVzlOdFk3MWNPak1kdzcwWW9HWVVvbEtF'
    b'ZXlGQQpTYjU0SjJ4WWlqRHFWYUtLaG5QV3Y0NXd3OHRlNFMvRUt3VFE2MVdjMDM2OG10eVgy'
    b'UFBqUE8xTWh4MTJCM040bUEwQVpPMFNHY3ZoCnduRE5hSUhpRFp6aWpkcitrWkNJUURYaktn'
    b'eHpqa1pwdjR2ZXFCTDBUWHU0NFdXdmNMcEd1VXJGV1dVam55aVJXbWxRUHU1ano5UHcKdWdL'
    b'QzNNeVI2MVFxeTRQTnIrVGpLNy9KN1UyUGdOdEhycHpoWitVMzg3ZUg3aVlhREhoTi8wN1Vw'
    b'RUN2TVNudWM3RVhHeFIyT3VSdgpUcUgzQmRoOVUxUTMvRnlUVmxGK09ZOFpNQUgrZEpmT3dQ'
    b'b0VoWDBlOW55ZHl2R0E1RElkTlRYejVrWnpuYUF5M0krVVBvMzFQbStzCisvTG9PZFVTcEc0'
    b'd0tSM3lTQ3d6S081d0tHeEk4dEhkNDJYVU5LdkM1My9UemRXd3RoVnFrcENyd0lIemNQcDVP'
    b'ZDF5MmxYVDlmM20KOUk0QlI1SVhnbm9kb21LRWtoTDRneEY2blVaWTlHZjBiaHJNWWN4STVm'
    b'dzVnNXIydTBub1AwSVJJK3NGYTFXQzRRakZFb1FsaWRRRQpPVlhRVXhFelJhem5wd29YTlVq'
    b'KzhFNjR1WDNpd3psNFFmRC9QZ0k3VGwrZEtNdGJNN3podGh0WVByK0pWTkltQ0VQeXhUSWRY'
    b'VU1jClA5UE4wL3RPY2I3Zm1USENDVEg5NnVsdk5vZk0yVm5HbktNUlZpS0VLdUxHYzJkbmZw'
    b'M0Z1UjRYVzQrd0V3WnpXK2R4NUdBemtWUkgKSFF2RjFsRXpDbjUvU0dLUnp0eTlKVDY5SlFW'
    b'OU0wU3M1MnE4djJKeHhLZnVreVNtYU8rd1lvN2tTKytCdjNoSThMVm5KLy91VjZ4dQo0aC8v'
    b'Nk4xbzJzUmJ1V25rYnhSRlBMUHJBSTl1UGN5UHQ1OGtYNUV6SUxHbTd6c3RUekpuYndteldn'
    b'RVZvckpFcTFVb0haaFpVaWt5CndneUsvTUdPdC9PYXRpM2NWbitBQzJkczdqOXlMMlpRUkVU'
    b'eDcxZE8raVNXR2lpNkpDckZLN2ZtN0NzaGFyWEplemY4Zklyd3VRVkkKRnpWRWZPcStpSVFC'
    b'MzkvV3piZWU2S0pRRHRGVWhib3FnL2xOQ1Y2OXZwNWxiV2srL3FzUm5VTXFUNTZZS0hHR0No'
    b'NFAvK1JaTWttYgpwS1hTTkt0bTNQbENzWWhoR0t4YnVaZ3RHMWJ6ZThQRGZPZkgyL25CMWlN'
    b'Y1BwY2prczlSeXNwb0VyVS92Zkdtc01QSGFOWlFVd3FsClF4N0paUVpDWVZvYnJFdzIzc29S'
    b'M2lJL0dyL29Iemw0aGxjQXBFQ2tCV0x1MkRWSVJhRjB4Q2Zacm1IVXFEaW52SmtJTnp5M1FP'
    b'RWYKM2hsUkxydDg0YnNYZWVUWkhreE5SVlhCOVNVTWVWem9jM2hzVno4cjVxZjVnL3NXOGtk'
    b'dkZOejFLWVBnQ3ExejRPd3dCLzd0Y1FEYQpaaVY0NEpPL1E5S091NkxrOG5sYTVzNk4zM2Zv'
    b'TUJkNmhwaFZWODA3NzM0Tjc3N25Wemg1NWp4N2ozYlExWjluSUZkQ3lnamZEekVNCkhWUFhT'
    b'Q2ROc2ltYjZreUNUTklrOEQwZWYvWWczOW5XT2I1YnN4RFRLckdNV1dyY2h2S1VOK05rbWlD'
    b'MW5zTXpGQnFrVnNhaGtQUXkKZzhpUm82M0Vwelh5UGxVRnFVS0VxVUlsak04M1pDU2JGMFQ4'
    b'NWVkUDAxcVg1b04zTGVhbUpRMUlKTi9aZGc3SDhUalQ2M0NxcDhUaApzMFgrMTJlTzhCdTN6'
    b'MmI5L0dhZVBYMlZjdDUraHdlLy96VHZ2UHMxOFl5U2tyTWRIWlJLSlFiekZiWnNXRVVxbWVU'
    b'TTJRNDYrd1lJClFwZ3pLOFBDbGpvc1E2ZXBvWDcwdS9yNmgrZ2Z6cE12bHJuWU84VGVJME04'
    b'cys4TTU0WUZDSldaaWdXcmFZV29ETG1uSEY1S3crdHkKNHJidVZlb0xFeUNkMTVEZ3I5Ny9l'
    b'cjd5eUhZZWVmWWNBR3ZiUWlJWnNlM1lJSGR0YkdWUmM5WElneExjczZXTnZ1RUtuL3pPVVhS'
    b'TgpKWW9FL2NNZW4vcjZhUll0RmdobUk2K2ljdmVmN0k1djFQTVlIQndrazhuUTF0b0tRRzlm'
    b'SDBkT25DYWRUTEJsdzFxVUt5WkNMcDhmCnUrN1dPU3ljcjFJc2xYaHExMkdPbkIyZ016OVZh'
    b'R0g2a3RCVnR5UStSaVNIWHFveE9BVWhSQ2pYYXBmYm4wS05EeWFSN0VJVmlHdXMKZHA3TXhu'
    b'cjNYZXRZdFdRQjl6KzZjL1I4YlRKRUVRcEJFSEg4UW82MmhqVEZTa0MrN0RHN05rbHYzaWRm'
    b'aWRCVmhVZ1JDQ0VJd29pagpSMDVTVDU0K1krV1UxN0MwclNGV0o0WkJNcG5FTWszT25UL1Bj'
    b'SzVBOCt4bWJseTdtaWlLNk96cUlvb2l5aFdIc3VNQ0FpOElLWlVjCkhDOGdYeXd6WEN5Unk1'
    b'WFpldkE4WndjRk1MbWtFbGNMZkZ3VjAxaWRYUDRCeFJLbkZDVzJibDZzd3grVzZTbnR3eWdT'
    b'aXNHcDBkdUsKT3dHYlZFNzVKSmNhNDVxbjJRdDB2SjZROURxRDB0WHEzNjhrbHBRc1d6Qjcx'
    b'TGkvZEQ1ZlVSQUNWRlhRMXBCbXFPQ1NLM20wTldRSQpvNGdmN3VsQlU1VVJqMDRpaEJoOW9G'
    b'VkJMMjU0bnJ6V090NHVVU1gzM0RLZmQ5Mzl5dGoySEJpZ0twdWxwN2VYS0lxb3FhNUNSWEw0'
    b'CjZERUtaWmRrTXNHU0JXMFR2RW5QOHpoNTlqekhPbm9aN0M3eXhJRWVlb1lrYTJZVjBWVTRO'
    b'eXpvZHRMajZUU0ZYcXljOUVtdE0zR3UKaHVsYWk5SVI3eExSbE9Fbnk5K1k2WVdwTTJ5a1VY'
    b'dEhZa3dWUnE2a2N0S1BtNmVKdVBtWDF4MmdaVlcwdEVKUWlQQjZ3NmxYNDRxSgpYcUVpWGVZ'
    b'MDFvMmNIanUvdnpNMitFeGQ1WHhmbVJWdE5TaUtpdXNIK0pFZ2tCSlZVUkJDSUJXSkVvbExQ'
    b'RVZLeWF6Z09KSFVLUmx6CkFGalZsdUwzMy81SzFpeGJPUHJiaVVTQzdwNGVITWVoWlc0TFFl'
    b'QnpzYk9MbXBvYWxpMnBKNG9pbm5obUI2Y3U5REdVZHhncWxCbk0KVlJndVZuQUNqYkxyMFYr'
    b'SUNLVEtlMWIxY2I1bzBaQU0rS2Q3VW54OVJ4K2YyajZMNkJxSmk4aVZPSmN3VlFSR2c0clhF'
    b'NkpWS2FncApoYkFRNGZVR281aEt3T3NKVVMyRjlIb0Q1OXhMcDBlV09WZW50TStkMkhoTnIx'
    b'WHgrMEwwZWhWL0lNSnUwd2hMRWFuVk9zWDlBWGFiClNtR3ZHM2ZTNncrdlMySkZpa2xQM3dE'
    b'emswbGE2NjNSOCtlR0ZQWmUwSmpYbk1EeGZMNzIrRW5ldkdVQmhpYllkWEtJc2h1aUtBSjEK'
    b'eEFZUzRSaXBwSlJFa2FRK09JaUN3MnRmOVVvKyt0NDNUWkE4bloyZHFLcks0dloyOWg4OHdw'
    b'dzVUU3haM0U2K1VHRFh2Z1BrQ2c3MQp0ZFZzMmJnV1hSOWJqRnNzbGRpKzd3VGZlZUlRangv'
    b'b285YklFNmtXUCt5bzRmTnZHa0FJK0xXTmFiYWV6N0d0dS9hcXluQWNwdjF4ClgvU3dMRWt1'
    b'TnlnZjhUQmJkWXA3Sm1McWRnV0lBd0xGRUZST2VHaTFMOTU5ZGZ6QkNHdXVTdVI0T09jbjZk'
    b'MVFidEFKV2cza25rcmMKSy8yZ1IvWm1pL3hXbDlScW5lR25YTnhsRnE0bE1Qc3JreHV3RTd4'
    b'Q2hZdDlPZWEzd2FyMnVid1huYzk5L3hnUkNuLzM0eFR2dWFXWgpuZnR5cEd5ViszOXlsTmZm'
    b'T0krVG5UbjZjdzY2Rmtzc1ZSMlRWcEZVaUNLSnFrcTBLS0xhUFViL01UaDlaaFh0aTlvQkNJ'
    b'S0FNeDBkCkxGcXdnTjYrUGg1L2Npc3JWaXpEYzEzMjdqOUVkVTAxNjFhdkhBMmNuanh6aHJQ'
    b'bnV1alBWOWg1NEJSUG5TampSaU5FVTFTU2xxQWMKcWlUVUNrdWJ4MWJKM0w0b1pGdXZjbFVq'
    b'cTl5Z0U3UVp5TjBWc3Bzc2lpT1k1cDZPVjdia24zRndsNW00dHNDOGpGaHFzNDdiRjVLWQpx'
    b'MkxPMDlHekNtak1lSmMvVjdGUXp2Y2lOQjJoQ0diOXQvZlM4N2wvQmwyRDJoU2FPcWF0OUZr'
    b'YWlnN0NDRkhUS3BWVFB0cHNqYkQ3CkNva1ZBdDhzbXJ5dE5hU3cweVc5MFdMbzBUTHBqWEhi'
    b'WlZtdjhpM1A1QzdMdzV6U2VKK0k4TEZ6L2R5eUFWUk40d1AzM2NIOE9iUDQKaHdlMnNlK2k0'
    b'S2QxODlIOG5ienZybVY0UWNTekp3WjUrdWdBa1lSSUNxU1VDQlJVVlNHTUlsUkZJVlFrcWhJ'
    b'UktncXFJamx4NGdnZgorTUJ2czZCMUxxKzc0M1hjL3JvM003K3RqUk1uVDlMVzJzb3JidDdF'
    b'VjcvekdGNFlzV2JwUE5JSmkyOS8vMGZzUGRGTElsVk5WZHJFCkN5Ukh6dlR5N0VtZlFCcmpU'
    b'S2J1c3MzY1pBOWw2dm1iSC9Ud3VtV3dwRkZueTN3Tlk2dUxqelVsczBJQjN5ekVtT1ozdW1S'
    b'dk5FY3gKTGU3eGlPbzF2dTFiM0hrRnBrNVNVRmlXUkR4Vkl0RWViK0JrekZLSlBJbmZONFAy'
    b'bDFLQlVzRGl2L2dydXY3dXIyamNkQ3ZESC90Zgo4YjJZRnFYV0JXaEJpRmF0WUpyZ25Ba3dt'
    b'alZLaHp3R3RpUko5QVRZM1pQRXNiNTJUREI3amNrcmgwUEt4M3hxWHAra3NOZEZTampVCll2'
    b'UHBueW5jZGZQVTBZYkp3ZzJIVHNmTjZTd3psZ0t2dTNVdEcxY3U0RDhmM3NhUGQ1Nm0zbHJG'
    b'VjM5MkVpa2pkcDhlb3VSRTZMcUsKRWdvQ0VZNEV1Y1hvb1NnQzVkTGZrVU5URld5SzFCYTNN'
    b'L2pVU1J5MUN0VkljN1JETWxnTVdKUk1VbkZEdnZldHJWd1lpc2g3R3YwVgpsWDYzajFCY0hv'
    b'QlVKM0RFSjRFWDZjeEpGUGh1UnhPRFRqOVZScGxOYlFydDFRNkhoaE5YZlZiM0h4UE11Y0hr'
    b'dHFHUTBtRXZ4blNQCml3UU90bGg4K21jS2QwNkM2VWUzcWZ6Rk9wdW03V1dTS3czY0N3SDJQ'
    b'QjBaK0tOTHJLWjlSQkhHa3VVVUh2OHhxVTAzb3lTUzFMenQKdmpFSHlmRW9keHdtdWRpZ2Nz'
    b'TEhtcTlSMk9NeHNESEI3ejJqOGEvemc2bHpoVUkrMy9ETTVDbWRaNC8xMHo4d1JOdmMyUXdN'
    b'RGxKYgpVNE9NQWo3MGp0ZnkvbC96dU5EWlEzZmZFRFhtTU5yVFArYVJuK3djSVpVWWxZQ0tF'
    b'S09ldWhpUmpNckllY3RRK2V0M2JLQzFJWFY1CklpYytiT0tEUGtqQ2phOGM3OXVmSHhqZzZU'
    b'UHdzek02ZTRmcXA3emhSMDRsdVc5RmdiL2ZXY1hXM2xrWUl1Q0hGeU15bWhmZjh6V2kKcFlx'
    b'NDdKdXZFOU5RUWlSaE5NQXZJU3pIN1lPQ0dZeHlDVU5IU2FYanpRS0VncHJKWG1aQ0YxRnRR'
    b'ZWhlMXJOV1NDUk0yRGR5SExIdQpYUkt4T2VjaVNpR0pqUmFEM3l1UjNtaFJHdlpZM2xIaFE2'
    b'dVR6emtKWFFrVmZ2RE1JWDdqcnBzNWQvNDg1eTljSUp2SjRQcyt2dTlUClU1MUJVNkdwY1Ns'
    b'bk93c0U0ZlpZT28xR0xPUm9JRk5LaWRBTTdya3A5dW9HOHk3dHM5TlhrT3I2eDl4YWsxK3Zo'
    b'VjliQjk4N2NKRXYKN3N0eTBjbE9lTitwVWowNTErRlhXcnI1d2ZuWmVNUlNiakN3cmttVWV4'
    b'ZEgzRFRzSWlzUnlSdk5jWml1T09mdy82eWUzREQvMzV0Qwo2cCt1a0ZpaWoreGpGRy9UTjkx'
    b'N0JGMDVuSVA3c1YvL0Jucis1VlBVdlBYWDZmdmNaMGFFdVVaaDBWSlVMMFRvOFY2TXp0bUEx'
    b'SElUCnNhdk1wellKNkoyRVdDcnc1cVNIZnR3amZaTkphYjlIOVIwSjhsdGQwdXNNaHA5eWVW'
    b'T2RPK1dVRTB4ZE52UFFVeWU0OS9XYktWVWMKcXJKWlNxVVNudWRoMnphRlFyeUVycnVuaDVx'
    b'YUdvSWdqTC9yTW1LcGloeUplK2w4OEk0MkZzOUpUM3VLODY1VkZ1dGJpL3pwandJTwpEdGRQ'
    b'ZU04WER6WHhQemRlNFBUd0VDZUx0ZGNWSWxVbDNKMzIwSGQ3WkRiRnU0VlYzNUdJamZjMXNm'
    b'SCtwbHBuZ3NTelNoSEdzeVdzClZvMndFQ0VNZ1ZxbDRCN3pVZE16VjZYckd4YnF4VHluLytY'
    b'VHlDQms0TWhobk1ZbXBLNFIxbFpqeUFCTWhTQXYwZXZpOXFKdWI0aTkKeUdEVzlqS2lUcDFZ'
    b'M1pEbzhRa0dReExMRENwblE1TExEWEpQT2FUWEdCVDNCNlJYR2JBMzNxaG9zaENwOElya2p2'
    b'MXcwZ3ZlZVF3ZQovbUVyamZVMUpDeVRWQ3BGRkVVRVFVQVlSVVJoaUczYkhEOStuQ0NNUmxX'
    b'Z0pGWUhrU0pSZFpWUDNMZVVUR0xtZHI5cXpPcDg4dlV1CmYveTFKM2pzYUdWQ005cS9PUThm'
    b'ZmwwZG4veitMb1l1Mnl3aUtzK0owLzlYakhHWW52WkpyWWd4VGEyS3d3M0oxU2J5VXJqaGNq'
    b'WFkKR1cvc0pFT0pjemJBWGhUdi9HSE8xbVpVV3BrRVVGODMrcXJ2NFU5anJhMmZWTUZGSXpM'
    b'RzZ3NVFkTERtcXBTUGpTMm1HS1cvUHhESApXNUJnMUNoVXp2aUVoWWppUGg5N25rcFFpTERh'
    b'dEtsaldJQ1U0WlRIdjkvL0VFc1dMZURZeWRQNHZvK2lLRlJscytpYWhsQVVlbnQ3CkVZcENF'
    b'SWI0UVRqK2J4anltbFd6WnBSVWwwWTZvZkhwMzJ6bkgrNXJKbVdNdjRmQlVzZ1hueHpnOSsr'
    b'b1IxT0MwZjlQVmRod09hWjYKWGV5U2g0V0kwa0VmczBVbnpFMk9xZG1ra1Z4cG9DWUV5VlVH'
    b'aWcySytTSThyTGlwbkZhbFlDOHlzT1pxRXltb21BSjdvVTdsVk55aQp4aHNwZndoeUlVRSs3'
    b'cEZseklxRHAxZExPZGhheEwxcis2bE9TZjdqbVZxR0t2RlBIRHB4bnY5NDROdG9pbURaNG5i'
    b'MkhqeklEU3RXClVDdzdoR0VJcWtveVhVVndXVjNNcGFDb3FpaHNhcTk5d1lKK3h5NFdhS294'
    b'K2RBZERmemxkM3JHblR2UkU3RGpUSkgzM2xiTC8vL1kKMWZ2OEs2YkFXaGczc2JzUzA3Q2dJ'
    b'Q09KTVVzYnhWUVE3eThkRmlJS3U5MXJxRy9oU2lGOVhpVERINHp2elp5akFLUzB5M05YeGYw'
    b'dQp5ZVhHWlEwcHh2S0ltUnN0Q2p0ZFVqY1lWOTBPOTdkdTdPV21lU1dTU1pYNnhFVWE2M1Rl'
    b'OWNWbUFQN2pnVWY1dzk5NUcxOTg0Q0dhCjZxc0lJOG0zdnZkRC91Y0gzOHMvL2Z1WHFNNW1t'
    b'VE8zbGZQbk8yQ0VWSkdVc1NwVUZYSWxEOXZVTUxTWlhRMmtxZkR1ejU3azM5KzcKa0Z2YWgz'
    b'bnkrUGo3ZlhoUGtYLzlyUmFXTitjNWRKV2dwYjFRcDdRL2JyTTVPYWJ4eGs2cEcrSXQ0MlJJ'
    b'bU4yUytIVkZrUy9xSlBUVgovVGRGRUVXcnRjdnRUeG5HeDJTaVhZWVNHVjI5bUcxSmZZVTdG'
    b'Zy9SNjlnSVR6Qy9RWExubWh4Ly9KMTZMZ3pwRk1zT1gvN21qNmhPClc2eGMram8rK1prdnNH'
    b'NzFjdjdoczE5bXhkS0ZkUFgwbzZmcVVaUnorR0dJWkNTRm8wZzZlZ3BzWEZ6UDJaNENqZFVK'
    b'ck1zMnZpNVcKZkx3Z29pWTk5YVpHcDd0eWFLcUNvZ2o4SUdKdWZXbzAwWDNsbUYyVG9PeEsv'
    b'dTZoOC96Slc5bzQrQy9IeDlsVW9ZVEhEZzZ6dVQzRApvYzdCcXdSZ3JvVXB5T0R5aHlLUmdp'
    b'WWs1a3VWV0RKQ3lFaTJUMk5wc3VUOVc3b1JBaklwd1ZBQjNyTFJRUkh3LzcyMWgzcy9ONGN3'
    b'Cmd1Tm51MmlvdHZqTFQzK1JONzVtSTZjUDdXQlpuY1Bjd2hteWlxVFNrdUtPaFN2NDJrK1BN'
    b'bER3UnFTVjVORmRGOW00dUo2MmhqU24KdS9MTWE4d2dCSlRkZ0lHOFEydkQ1SjdpcWE0U24z'
    b'ejRITCt4dVlhTmkrdlJOWVdPbmdKSHp3K3h2TFgycWlHbzdXYzhuamsyeklmdgpiT0xqRDQ2'
    b'dkdwVkEyWjFlMTE4S29RNytvUHlQVWZrbHV2WTNpczJYK3JzVDAxZm9sekJDRnRRNkJKRmcr'
    b'VnlYSHg4d3NZMTRtcjVoCmRZRi8rdlV1UG5CL0UxSkN6MUJjSFhsdzMzYis3TTNOMUdmVEdK'
    b'ckN4VUdIUFFkUDhDdHZidU8xNitid3BSK2ZJRklWSWluWmZyeVAKeC9aMTh1clZ6YlExcGpu'
    b'WFcyQk9mWXJ1b1RMekd5ZTJDenZUbGVlcC9UMThiM2NmK3dkczVqZVVtZDlVSVFnbGMrcFRL'
    b'RUp3cGp2UAovS2FKbnoxeUlZODNVbEh4enovcTVSL2YxY2FmM3QzRVozL1VRMWRlc3F4UjVY'
    b'V3JhL2pZQStlbS9kbUVoUWhGRjJSdnRxbWNldW5zCmZHSXZNT0xHYTlOZG1xeHJNWWtHWEpz'
    b'VHZaTDZyQ1NTOElqNkI5aXBESE5lRy9MZ2EwMkdobU9kWWhnYXFsdWkrL3c1QmdaOVVtbWIK'
    b'NHF3Vy9zY2ZibVNvV0dEZnc4Y0pnbkJFRlFwVVJmTEZINTdnNW1XTm1McENYOEhuVkZjbmpU'
    b'Vko5cDNxeDNGRGhnc2VmVU1sdXZvcgpYQmh3OFVMSjRZSFlrL3poZ1J6dmYrMWNFdWJZTFRm'
    b'V0pOaHplcEExODhjdndGalJrdVhlRzdOOGJYdU92Q1A0NEJmT2N2ZUdhdjdnCnJtWTZCMHA0'
    b'a2NhZi9kY0ZMczdRbGlSZWIwaHVtNE5lbzFJKzdHSzFhTWdYWTE4TUFXNkhqNzNJb0xqSHdl'
    b'c01wbjh4aFNCT1B5eWYKNjdQbnJNYTlteDM2Q3hyemIxeE1TMnNUcDArZm82NnVtdXJxTEdk'
    b'T24yZlY2aVVjT25TQzdDdlhJNEJJU2t6VFFFcUphZW84L05BZQp2SDBkYUhyc0ZVYUtwSHVv'
    b'eERlZlBzTzl0eTFnM1lJYVB2VFBUNVBXTkFhTERobGJJMkVZUkJKeVRzaUZYTUR4Z2tWSWJJ'
    b'dGRHSkk4CjhIUTM3MzdWbkxIcUF6Zmt3Ly9uTEgvMU50aThwT2F5U2FMd0oyOWR3T0xaWGZ6'
    b'OTk3b3B1UENscDRhQUY2WmlXSjJyNHhWRGxJTEEKWGhRbnhkV1VvSEoyWnFzYmxBWExhSGpk'
    b'bThmeWxmcy95Ymx5SnlCWVREM3YyaE9oaC9Ga3N1Wm9SS0hFYW92M2lYWUhJdFI1T3RGSQpE'
    b'ZG0wUnR6NktqWlJIbEkyREJSVmVnc3FrUnZuMDNSTm83dW5IMFZSS0paanFWVW9sR2hxcXFm'
    b'amJDZWU3NVBKSkNrV0t5eGMySUpNClZlRktuU2dJMEpTNFBpdGhhZHovMHhPOGZ1TmNzZ21E'
    b'Yk1yQ0tmbTRJZmloeEFrazUvTUJ3NjdnVk42ZVlLaDgrY2tCZm1WMUxiTnIKNDFVOG4vL3BS'
    b'YnJ6Z2cvOVp3ZDNyeC9tSGJjMmpaNERlTnZtSnViTnN2bmpCem80UC9UQ1ZYVTZscUJ2VVpM'
    b'WjI0dllqUnBSSkpFbApnV29MblBNelJ5Njd2WXFtRFZ0R1grL2I4ei9ZTzdRWGdKOEM2K3Jm'
    b'eHNxRHd4aXo0cTJTZzhFSXJVcWhmTnFuODhZVTFiMCtOc0g0CkFPbjBwRVlFdzhNaHBXTEU4'
    b'VzRWTnhENFFZQ2lRTFlxellKNWM5RTBsVVVMV3duRGtIbno1aEpGa29iR2V0cm16YUcrdnBZ'
    b'TkcxYkcKTTlUUWNiUTZ5cUtLa2t6aFJnb3Q5Um5XTGFybml6ODhIcnZzWGtRUVNpcUJ4QXNp'
    b'amc3NE1ha0sxcVRXYjA4aDRtOGZpdTJpWE5ubgp2N1lQeDE2bEMxOStPc2NiLys0SUgvbnlj'
    b'YmFkR1BQME5peXM0Z3Z2YTJmanZCZDJHZGJIbnRIb1dKWEVPUitnMmdwaFFhTFZxUml6CmZu'
    b'RkZmK2VxSS9SYUZiTWxyaTdXNjFUS0ozdzYxeWI1MEZQalpkUTBFa3RTYjVhcHRqMU1TK1VW'
    b'UzF3VUFaNGZZRmtHeFdLWm50NEIKenAzdjR2RGhVMGdwT1hlK2swSytTRmRYRDczZEEzUjFq'
    b'cTNSTmd3TnFSZ0VhZ1pYcmFGRUhiMk96ZnZmc0p5NmpNVlEwYVBzU1hKTwpRTTZCY3dVNGxy'
    b'TmlVbDNOT0I1eDVMSUpuYmE2OFpIOFNpQjRaSCtKMy82M0RqN3d1U1BzT3h2M05XK3VzZm5Y'
    b'OXk3aGJSdlRMOWhEClRPbVN4RWlZUjBuRnhCS0M1N3dUN25NWlB4YXRiUGpYTTl6N2Z4N2xL'
    b'LzkxTzU5c3o5QzVCZVN2eGtkMlZteXFDQ1hlRmxsTkNrUW8KU1VRUjFmYjRDNXRXRzZ1cllM'
    b'QjRMaVJseFBZekZvWXFDZjBBVlZXWlB6K3VPL2U4a0V0Rk1QUGE1aEFFUHZWYUxjbWtqWHBa'
    b'WEVsVAp4OC9NU0RFNTNnYy9PVGpJYjd3cXJtMzNGWTN6QlllY3AxTndiSzZuSnVXV3BXUGsy'
    b'REEvemNHTEUrMm1VTUpQanpvOGUvbzBmL3lyClRienB4a1pNWGVVamIyamx2M2JzSjVRekh3'
    b'djR4SWFBcWllS0pGZVpWRTU2V0sxeEc2T1o3dkwzdHBZU2VWY25vWVlvVWxLVmhtSVoKL3Zw'
    b'emtHd29FQXhHVk03RXZidEtCejFTNnkzazlncC9kN015TTcwYk5GV3dwaDJPZGtDVjRWRHdk'
    b'T3JyTkR3dnBGQW9zWGZmVWFxegpHYnA3KzZqS1pxaXJyU2FTRWVXeWc2b29KQk1XeDQrZlpl'
    b'UEdWVEdScGdqRy90dFArbmpGOGhvYXF5d2E2akk4ZFFhdXQ4aHBSYlBPClcyNXFHbjJkVFZ4'
    b'ZHJaUTkrSnVIdXJocGNSV05WZFpJekd2bTIyUGIrUkRyNlJMMk1oTzNLOEJvMEJDNklQTGpu'
    b'T05NalNyWno5WmgKalZtYXkyQzVnZUdnUkNGL0E0YWhzdkIxOVN6L3ZveC9YNEowd1pxdlV6'
    b'bmhrYnJCZ0dkS2FMVUt3WFFUeXpJa0I3bzBxb3pZTUU4YgpQcm1oQ0lJUVRWTlp2V29KK1Z5'
    b'T2hxWTZ3aUFnbVV4U0tCU3Bxc29RaGlHYXJ0UFNNdmJRd3luNnUzYmxJdjczdHp2NGgzY3Q1'
    b'dFhMCnEvam16dngxcVFkYmg0KzllUzZhS3RoMWFwaG5UeFo0NnVpMXUxNFhYUGpCM243ZWVk'
    b'c2NFcVpPbGEwd1VKNVpZZ1U5SVlrbEJzRlEKaU44ZHhpdWdjaEpsaHVQeGF6dCt4TnFPSDEz'
    b'eDMvaVpOQUNvSVNOT052NUFUQ0YvV0NJdUJDUVhHeFFQdURNUmJwRDg2dG95VHh5egpLZVk5'
    b'TERYRVZFUEtZVWlwVkVGVlZmb0hjcXhkTytidWwwcGx6blZjUk5WVUFqL0FUdHI0WGtBNmt5'
    b'QmorQ1NOaUpRWjBsYnRraXNwCjVDb2FRNjZHNDRjRVljUnRLK3BZTmJ1VGZSZXVvaDVHZHZ6'
    b'K3pWdnJ1V0ZlbGlQbkMvenVsODZNUzlGY2F4enRySXc0SnpDbjFtQ2cKUExPNVgzTzJpcjFB'
    b'eCsrTGQxcDlNUTl6OWtpSXBrNGh5R3U0RjZZNVFCcEVBbFM0ZFhHRmpnR2QvU2NGU1QwZ0NP'
    b'TDZxaWlLVUlRUwpHMzhqd1Q3SGNiRnRpMUs1d3Z6NWN5bVZLdmgrWEp1MXBMN0UxOTl4YlBU'
    b'NzkxK3dPVE0waHhYdHMzbmxxZ1pVUlhEOGZCOS84cW9qCjlKYzF2cjYzbGgyZEtkSjJTRG9S'
    b'c3FCZTRWZFhMMkQxdkxnaU5KTXdpS1Rrcjc5OTdwcWtxazBFTkdjOXF1d0FLVUZockhKMlRv'
    b'M0IKdnZNelJ5eDd2ajRZbHFMd09VWGRWVXEvYUlJRnBSQWxKVWd1MVFVd2ZYM2VLeTU4YjQr'
    b'R0d5cWdhZkd5Y2dJNlRwMWtUOXBFSHdsKwovdXlKblFnZ0RFTVNTUnV2NG9KUWVlckozZkZh'
    b'UXRWZzc5N2poS1ZCeW9HR0h5bWtkUi9UdFBuQTNldlFSeW9iOG1XUDB1Qk9xb3lRCnVkbVFE'
    b'Nytpa3c3SG9tWmVTSDJWVDdGL0JZdnF4bGVDZnUycFRuWjNlRmZZaHBMNU5RNUxabFZZMFZo'
    b'bVJXT1pyQlhpUjRJdjc3dUIKOXVZTU55K3BIbjMvc2xrbEhqY2lTdDRNR1BDQkRLdldtVzk0'
    b'YVc4Z0VJblFuOFlOQkFCc0xjRFc0UElOTTFjT2ZnVit3cmdLU1NsZwoyRFZKNmhKRHhPKzlG'
    b'Q1FZREd4V3RJUzhkckdQQUI3YWJhQUlqOWJxWWI3K2s4Tzg0ZWJGNkpyZ21UM2JhSzhaNzlH'
    b'MVdnN09CWVhkCkhRbHFhN3VJdWpPb0pJZ2tCTExJaGpWNytPNUduejBua29SZGtvYWtUM1BH'
    b'UTFjbkdtbkgrbXY1eTN1WGprdFM3engrZ2MzTngxajMKVnNIOSsrcjQvcEZxdkhBYVV5MktF'
    b'SDRoZXJ1SXhMVTMxOWJ4VUpRWFh5TjRLUlRGVWphOFlBcTg1R3NnSUtrRkNBbUpoTXFpUnA4'
    b'OQpweTFxakxHV1BhWW1XTkxvMFZkUWVlS2dUbzBaNnkxTGk5Zzhkeis3OTE3RTBnUGFheWJI'
    b'M2xJamxxbGxLSlFwQk05U0NsVkNDUjRLCmhvUUZzeU8yckNqQWlySFArS0VZSmRmaFV6Ynov'
    b'QXBOeVJ6REpZL3FsREdTL2drUXhkMFlkb1Nod1h0djdPSFhWL2Z6eEprTVZmYnMKYVNJV3lz'
    b'QmpsZmZKQUJUanBkY3pYL3FTc0NScGZFZUtGNHhZcGhveGI2N0c2YjRFd25FUW5rUENWTGpu'
    b'Sm9kSER5VEFkZWowRGZ3RQpmUFdreGVDUVNnMCt4VUFscFkxTnpOYnFnUkd2VVZDTVZQd0lF'
    b'bXBFNHJKVnVzT0JSbWRvb0ZsZ3BpTlN5WWc1VlI2R0ZqRlUwQmpPCnExUWNCZDhUUkNPMVVx'
    b'b09kZlUreXhaVTJIc293WkprbWFQSG55UTBXaENLd2xDaGwyWjdmTStxakJWeTE5SWhhdFBl'
    b'dEQ0Y3BDQ3oKMGFSMDBKMVFkLzlpSGFubGNYV0Q5T1UxakhkRmpHNkVHZjJjdG1vb0Jmbklw'
    b'Qzd0c2FqQjQ4QUZrNHZkUHR1UEN0THBCSzlaVnVIcgpSMjJXTEIrenF0c3VFd0plSUJqS2F6'
    b'Z2pkazNDaXFqSkJDU1ZzYnhaMlZVWXpHdUVvV0JXalUralVVWktPSGJXeHJzb0tIUUxVaHJZ'
    b'CkJLUDVMSURCVUtOSEdpU3FJcHBxNGh1OVlYbVp2WHNTTExGN09PYmtXYjFtcktWQXo1Qk9U'
    b'NjlPNklBV1NWUXB5Vnp2dzFjWTNRZ3oKOHFlT2tRUzVrTnhURmF4NU9vVmRMbmE3ZnMwV1Vy'
    b'OFlFU1VwbndqaWRnRzdIUHlCY1BRNnB5UldlcTFCK2JoSGVtU0R3K2N6Q3A1TwpiWTNHRGEw'
    b'dUtYUHM0YXljNDNJaG4wQXRPZUQ0UExKVG83bEtjdVpNZ3JhMjhvVGlPME9UTk5SY25kMEpN'
    b'eUpSNzVFdnF4dzdaS0hKCmlEbzlvRTJyY0dVOXBoTXBuQWt0YW1jRnREUjZORE14c2J0NHFV'
    b'UHhoTW9DMDhIeEZDd2psb2dOMVQ0TjFmNFYwdmo2Z3FicGRTYmwKWXg2cGRRYjViVk9YZHl2'
    b'ekRMeFNoTGdRa0ZwcEV1UkQxQ3FGOHRHWnI4OEtOQU4xOHkxazVpOGsvOUMzbVBYQjM2Tnc0'
    b'amlGeDM2QQozdE01Wms4djFJbGNTQ3pXQ1laQ1BCL0VRZ05PKzFNVHkyclZDZnBEcENlcG5J'
    b'NDc1RjZUdkpORjQyMmRtOXZMbEgzQnlVR05pd1dOCnpySkNwRWUwdHBaeFBZV2paeElZUVlR'
    b'NzVPT0VKcWMxbXdWeks4OGJtRnhCWllsMTlYaENKTUdPSWdwZEtzYzlpL2FXaVJQSHRpSk8K'
    b'bWpiVkZSKzd3aWl4SnZlRXJpZU1vQkgwaFVoZjRwd09TQzZaR2xOWGhmTkxFeXpZWDBJTWhX'
    b'aVplTEdxMmFKUk9URnpvUTRmcVB2dgo3MmZKYSsvQVBYdWFydTkraTdiVmEyRDFHb1p1ZlNX'
    b'SC8veFAwYzZld1dyVlJ4KzRkQ084WE1TWmxVbWFCbjNzcVNMdnFpMmdWc0c5CkdKQmVhMUkr'
    b'RVNCVTBMTHFOWWdsT0NvVENBVTBUV0lhRWpzUjhJTUJsWFFpcEtjaTZCMVNpQ1FJVitISTZm'
    b'Z1NrcW1JcXFhUStxcUEKMmZ4OEpTRm51MHhLM1FyMTE5ZzZ1UmlvVkRRRlJZVzVkVk5MZ1pY'
    b'dGxldlVjRmVYV0lxdG9GV0RlekVjd2RRSERiVE0xSXo4azYwSwpmN0hlWnRHZUVtcFNRQ0JS'
    b'RWdyV1hHM0dTbWZDaGtiU1czL0d4YTAvSXl3VWNFNGU1K0xIUHpvbW1UTXAxQ1lWclVxSmw3'
    b'WmxGY29uCkF6bzJwUGp3Vm8ydkxoa2ovUVJpQmNPUzhnbWYxRnFEd2NjcVpOYWJsSTc1STNH'
    b'cHEzbVpndnE2Z041ZURhbUNZVVFJQ2FjN1RDd24Kb3NWMnlGNWFyU1JoZE1tc0R4U2gvN3hL'
    b'WDZEaktBcDZRdExjNEZPVENTWlQ2MXpvTlJnYzFBaDlVQ0tKRVVucWRaOUd6UjJMVzF4bAp6'
    b'REo5cXFLUVFWZWo0NWhCYUFqbXozUEpKR2JHZXc5ekllV1RBZWsxVjJJNnRkMDBOd3V6WklU'
    b'MDR0MGdTbnM5a3F0VTNBc3pWeGNXCnVBN3AyKzlBVVZYODdpNjg4eDFrNzdoejlIejNrMDhS'
    b'bnBZbzh3VEJpUWhybm9hVVVPdUVMS3dhVDVBSnhDb2VkTWx1dHNqdmNGSGIKZEFxN1hiSmJM'
    b'SEpiM1d2WmNSUXJDa2svWkpid3NVWUs0MnJ3d0lyYm93OEhHb1ZRSlVKZ2lvaUVFcEZVUTFS'
    b'Rmt0TENNZTh2QUM1Qwo5MW1Od1VEREc5RTFPaEVObWsrOTVsR1BCL3I0MkZoSHhhSWtGRlFU'
    b'TER2Q3NpU1dFZUg1Z2tnS3doQjhYK0Q3Z2lBUVNHMkU1RUU4CkFXNVkrdnlTZ05FMWt1REZB'
    b'OTVFVERmWjVMWk5MUkgvZUVWQTZtZGxNamRabEE3NUpKYnFWRTRHQlBtWkkxWnFlSmg5UDMy'
    b'Y0RiLy8KRWZTbVpuS1BmSmZVcHJnVnp0R2ZQRVpsMnpQb2JrVDVrRWR5cFVGeHQwZDJvd25Q'
    b'bFBuNFpvRVl1QXF4VXFzTXlrYzkvTms2VDFSYgpiRFlWbE4zZU5kY1RTZ1JMMmp4b3U4d0Z1'
    b'dExBSnFLSks0RVJoSkZDeFZQd2ZVRytxRktxS1BqT3lJTWY2ZFFpSWdnVWhZdG9YSzR4CnBZ'
    b'aERCVTJOUGt1cWZsN2o5dmxGMDJWMGRXS2xWcHVVai9tam1HNHlGWlM5WStzSkorQTBGR0tl'
    b'TFpGYUgzL09idGRRVklHYVZtYTAKZHdPQTFiT0QzWC8yWHF6V3BZUjFXWEpmK1JmSzUwNWlY'
    b'amhPdWptZTNwY00xZVJxZytKK2ovUjZDN2FXMFdyRTVOVU5ack5HVklIUQpnMmN6Smg5N1V1'
    b'V2o2MDNlYUlaNHZTR0pCVk12Y1crWmxRVHU1dVZ4UmZ5dVdTVXNSWVN1Wk51Y0dOTS9XbTl5'
    b'bHhuZzlZYllpeVppCjZ2ZUhwTmVZT0IwQndWQ0ljK2FGdldhck1BUzlXMUdCc1BQVXFGTjl1'
    b'YUZRR1ZrTkg1WWlLaU9tVTJISEZOVU5ScU5LZnB2RDRLMXAKUHJOVm95VXJ1ZitreXFhYmJS'
    b'cWVMcEphUHJrbjQxd01YNXh4bGhjOHJqUHhYekdtTGtPdlNQS1pwMVJhc3BLdm5GUzU4ZVpF'
    b'ak9uSwppWmlhVFNwcVJtQkVLa2FqK3VLZU9MUGo2MU1zZ2RXaWpiWlpHaVZXTUJSU1B1Nmpw'
    b'aFJTWFI3LzBYYVpXOXNKYWxwUTNPZGlOaytNClVBdytXbjZaVkdPYWZTeXdPeFRoSC9OUWt3'
    b'ckpUcDh2ekF2R1k1cFNLT3p4TUp2SHlKTmNhZlpJSndxaWlrUXhYenFUVmJvU28xSEYKYU5J'
    b'RUVMTkVNUVgrUUlSUUlISWs1aGx2RWdNVmhDN3crc0w0aHNWSVBpdDZXVkpOUml4aENvS0JF'
    b'S0VLSW5kcVRCVWQvRXVZaGpLdwpseG1iTE5QcWZZbWprQlRudm5XUGxKNTh6a1g2aWlIaXRJ'
    b'UjhtVXNUc0RGak1qMmZ6d1dGOEZIcHljR1g3c1FTUXE5U2xta0FQZmVYCmlMem41c1kydlRO'
    b'Tjc5ZExSSlhvWlNaZEliR2EzNU9oNXl1RlM4V3IxNC9wYjJjWWV0eTV3KzhPWDdxM3J3cWFm'
    b'ak05Wm1NWjlmRjYKc1hFenlCSkV6dmlaNTNVRm83c1BBQmhOTCt4YU4rZE1ITXZScWhSeUxR'
    b'WlhLaGdOcUxubzRROUVxQWxseE90NlljUnFNQmpoWEJpegpvNTQzcHZVcVJyUDZraU9WMXhP'
    b'TnJpSWEyNWxpbGtxK0s2SS9vMUpiQ1VrYm9Gb3EwcFVVaHlMNk1qcFZnd0UxYzdWeElQZzlJ'
    b'VWE5ClNsaU04NG96T2hzVVNLNDJDWVlqbkRNK1dvUGtjYzNrcjNiRUszUGZ2U3prblRVKy9r'
    b'Q0UyYVJpdHVnVWQ3dFhyU1NZam1ITTFyRG0KYUxoZDQybHVYSVpwWFNVa2FVM0VORHZvVXp0'
    b'blBLYmVRSWpkSGdkU284cUwzOVlRaGlDNzBhSjhlSXFVVHFGYTVUZ2FyMDVFSUtHdwozME92'
    b'VWtqWHF4d01WSUpxU2MwVnMxOU5LNVNPK3BoTkt0bE5Kdm50SG9uRk9ucWRTcEFMcDVsWWdt'
    b'QW8vczdNUnBQOFRwZTc2a0lXCjNtWlJDQVJyZWh6VXZUN0pGUVpJY0MvNEpGY1p5R0I2SDQ2'
    b'V1ZnaEtrdEplbCtTcWVBUEl3azQzenFFTmpqY05DbFVheDRWS1N5cEMKZWpMR3RGb2hlUW5U'
    b'S2tudGxaaGFDdm50RHBtTkZzVmRMcGt0Tm9TU3NEeXpKTHRRVG5Qa2dvNldMNkRiQ3RtVmd1'
    b'NnV1SDZweFI1aQpjV2JNOUJPbVFFc0lCbjlhSnJQQkpML0RRZWdDNlU1U2o1VXRCcnphamxD'
    b'Qm5BdkhWaWFaMys5UlBSQ3lxUmJ5dVFoUzR5Ty9UcjFPCi8xeURodjFsL0FNK21aSHRVaTdw'
    b'MitJQmQzcURkNjBhUm9OSytiaFAxYzBXaFQwZVN3K1VrWXBFaElMTUZvdnljUjk5bG9aV3BW'
    b'NDEKVy9COGhyMVFSOUVsNVdNK21jMFc1U00rUVNqcDI1d2tPUnhnRDQ2dmxNaVdBbDZURE1H'
    b'WEZBTEJzWlVwNWcrNFZBK0czRlFqS0F3SAprQnF2OW9MWkdtNUdoUjBPbVEwbXVhMFYwbXRO'
    b'aXZ2YzUrVVVYTy9ZR2M3ajJLazhjeTQreWx3cnkreDNOZkdoZi9qZG1PeUUvSzMyCldlWXJB'
    b'd2dOTWpkYURQM01KYlBlb3JESHBkSnVvWVVTN1ZpTTl6aVcyQWtGRmNnNzhLQnE4MXMvMHZo'
    b'c3lXWW9xZUVQaEtTckowOG4KZlBocGxRZXFraFRuR3VTZmRiQVg2WVNPeE8zMnlXNHlFZE5Z'
    b'WnV0MEJKU1Arbkd1YXA5UFlwR09VYWVnSlFUcHRYR0tJZEZ1NFBYNApsQTVOWC8yU1VDRzl4'
    b'a1I2TXE1U1dHT1EzK0ZTcmxaNWNsNktkejJoTTluQ1dUc3R3SmNVZmNHRGlzVnYvVWpsczBX'
    b'Ym9ZUkdNQkNRCnJwNW9Td1hBVjNJbTVZVW1oZDB1NmJVbStkMHU2ZlVtaWo2ejRaM09URHRK'
    b'eGFRblBYZmMvME5VZXNtQ1FpeEo5N2lrYnpBb0h2QW8KTnhwOHd6SEdyV3RReHNJSENsYVRS'
    b'dVZzUUZlYnlhZjJ4YWNlT0M0NFZhM2pEMGVvQ1lGaVRiN0Q2S2YycXp4cEdpaXRPb1dkTHZZ'
    b'OApEYVNnY2pLZ2FyTTFyVGNmNUNNS3UrTGtlSEdmUzNLRkdTZDVuM1hJM0dSU1BPQk4rNTR6'
    b'bVEwV2ZuOUlrSXRJcmpMSVBlMmcxcXNjCm5HWHlrYWZqRXVrSnFKZ0NzMUhEUFIvUzJXYnlx'
    b'ZjNxR0tZMVJveHBDaFI3SXFhUG5ST2N5Y2FWbys2RmdFUnJITlcyNXM5Y05YbkwKNG5QOC9k'
    b'OS9pUnMvbE9TdFh4aGdkZXRSSHYzWWUwYVB4dHRPWTdYcDhkNCtUUnJlUUZ5ejF6M2I0SUhq'
    b'VjJ3cE9CcXM4eUlxSGJFRQphRHJ1OElsTnNTM3p2aFVoUzNvOWpGa3FRUzZhNE5FQXFJcmt6'
    b'OWVIdkRMdklNLzVaRGRibEk5NktMYkFYcWd4L09UMDdtK3MxNmxrCjFwa01QMVVoczhHaXNO'
    b'dGgrSEdIekUwV3VXMHV5V1hhYUtwaHVrYitXUWV0UnNGb2pOVnI5aGFiYURCaTlia0tuNzAx'
    b'SUtISlNhUFIKVG9lUHZVaWorYmpEbjIyNEROTWVKOFowU0U1cW9OKzNKR1JobjRkUVIvYU83'
    b'STNRNnhYS3gyYk9RVHAzcklXUGZQaS84ZmluaHZueAoyMjMyZFN6aGprOThidlRvKzJrcnpt'
    b'a2ZMYTBRbGlWNmRienY0cHl6THIrN0pweWNXQURsQ0Z3bklsdXI4SXIrQ3QrNE0rQStITkpF'
    b'CktMWkNZUW9QNWRPYlErNjRXTVFlRE9PZHJmYTU2TFVxaWk3SVBlTWl3K216Qyt5Rk91WnNq'
    b'ZEpoai9ScWc4SStENzhzQ1ZWQllidEwKYXJtT2N5NUVzUlZTcTZkdlRicVVVTnpuRVJRbDln'
    b'S2R3aTZIOUdvREs1Q3NQVnJrOHpmN2t4YjhWUUtCNzBveXRZTGJjeU9ZU29lMApJbEZzUVdH'
    b'U2lhb0R0d2NlZHFkUGFuVmNJbTR2MGluc2NKbnBNUyszQjBOS1pHVjg0K1phK21rVjhYTEh3'
    b'bTRYYzdaSzVYUkFZckdPCmxROTVSY25CdkN6S1B0NHJUS2c4NCt2YzZUaGtheFgwYlNYTTJT'
    b'cHFRdUdua2M1c015UjdSZG1MMmVPam4vR3c1Mm1vR1lYOFZvZkUKVWdNMXBZQ0lTSzJldnI1'
    b'U1FoVjQzWEdjeUp5ak0veWtRemhIWjFlOVJjNFgzRnAyaUo1eHNSZnFxRWtGdHpNZ3ZjNmNk'
    b'cThRSVVrcwppbGVsSkJickdNMGF0VnRMcUVsbFFnMXMzbGJaRm1yYzZUcGtha1NNYVlzS3F1'
    b'QXhhZEE2Q2FhaXc4Y1drTnBva24vV0piWEdIUEdFCnJSa2wxYXY5OC9TdVRBQnZRZ2hKZVp2'
    b'RHY5M3dXVlFralZZUlM1T01WbElLU2FKZEo3ZmRJN3ZSUU83MWlJSXBpSlVwUkd4TysvZ1YK'
    b'MEIxSjFSWUxwenVnbUE5WmtoSWtDZ0drcjJndlZJbkkzR2poZFllVURua0lRMUE1TlVQaVdv'
    b'SDBhaE9udzZkeTBzZTV3ZWFoaXNIbgpkOGFDOTlSQ20zZXNWMkczZzE2amtGaXNVOXpualM1'
    b'Sm1vblVqWE0yd0doUXlXeTJ5VDg3VWVWbmlnR2IwaEt2REpvY3c3UmNqRmllCkNrZ1VKM3FG'
    b'UWtxeW0yM3l1MXdRVU53Nzg1SXF0cFJkR2lhczFpK09PaFRGeVRCUVkwbWUyV2lTZThZWmxk'
    b'bmFXUFEzSk5ta2tpU0MKRVdQU0g0eHJJNU1wSmY1L3RZSjd4VDdGZXEwYXY4OFFXUE5tZmt1'
    b'U3dyNDRhS2hsRlhRbjRrMjR2R25aWlRkYWlIVy8zeCtTejBjawo1bXRJWmo1Ujd2ZUZHUFhL'
    b'dUVDbmV6bW1pU2t3clpxSXFacFZjYnZER2Q4N1p6cUgyeDN2VU9ZUFJHUEVFcW9jRG5KUkhO'
    b'QVVRa09TCnVwWktHZ3ZqaDZOYmVieVFJOGhGcURtWHlVejBTL0pTZXBMUzBSZDRWNUJMMEtp'
    b'Q0dOUHI4MDR2WVNvVWdUOFV6dHhtbHpOOSs1ZnUKNDl5MzdubTVQdUhsTWUzai93S0lZcDdy'
    b'RERZWWN3QUFBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUFNakF5TXkwd09DMHdNMVF3TURveQpP'
    b'VG96T0Nzd01Eb3dNQXlVdVVvQUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNak10TURn'
    b'dE1ETlVNREE2TWprNk16Z3JNREE2Ck1EQjl5UUgyQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAg'
    b'ICBpZD0iaW1hZ2UxNjE5NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_34')

IT_34 = b64_IT_34
index.append("IT_34")
index.append("Italy Veneto")
catalog["IT_34"] = IT_34
catalog["Italy Veneto"] = IT_34
country["Italy Veneto"] = ('IT_34', '', 1)
lookup["IT_34"] = ('IT_34', '', 'Italy Veneto', 1)
lookup["Italy Veneto"] = ('IT_34', '', 'Italy Veneto', 1)
details["IT_34"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_34"] = ('IT_34', 'Italy Veneto', 1)
regional["Italy Veneto"] = ('IT_34', 'Italy Veneto', 1)
#----------------------------------------------------------------------
b64_IT_36 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3NDQyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRnJpdWxpLVZlbmV6aWFfR2l1bGlhLnN2Zy5wbmciCiAg'
    b'IHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lu'
    b'a3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdl'
    b'Lm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'CiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAg'
    b'ICAgaWQ9ImRlZnM3NDQ2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFt'
    b'ZWR2aWV3NzQ0NCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc3NDQ4Ij4K'
    b'ICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAg'
    b'ICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5k'
    b'ZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9w'
    b'bmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJPVjZu'
    b'QUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2'
    b'QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFB'
    b'WAoyRWxFUVZSNDJ1MmRlM2diNVozdnZ6TWpqVWIzaXlYYmttVmJ2dHZ4SlJlY2hFQUNDWUZB'
    b'U0xrdFdhQXRYYUIwMjFJb0ZIcGhhYmZuCmJNdlNMbjJnN1JZQzNWSm9LYVJBS1lYQ29VQ0Ew'
    b'SVNRTzRrVHgzZExsbXpyWXV0K0hjMTkvNGhKdCtmMDdKWStYS3c4OC9sRGp4OUoKbzVsNVAz'
    b'cC92L2MzN3pzV2dSdWpVS2xrU0xVSlZJVXFxa0lWVmFHcVVFVlZxS0lxVkZFVnFncFYvaCtx'
    b'aVhHOWtsUVZWakMzdHYzZwp4OHR1aEN5cUNpdVNkbkxYcld0ZiszVC9nWG9jVWhWV0pGL29m'
    b'R1EySnNvU1JFV3JLcXc4K2pTdjNuejJXMlVPKzZkOGMwUVBGRWxWCldGRW84czA5ajh5bDVF'
    b'WTN0bzlkdXJYcXdkdnE3MVFWVmhJYlRFOThiczNlUkFhQmRPMmV5TXJ2clAvNStvYkRxc0tL'
    b'Z1pIVDN6N3oKcDZFb2ZHN2N2LytxcnkxL09KL092aDFlcFNxc0dENVQ5Ky9yTzRLWlBNYmlI'
    b'bzJRN1hmc05WbHNyNGZPUE5md2hLcXdBdkFRZzk4Ngo1OWVIaDlIYmh1MzdsdHk1OW1tUEMv'
    b'ZnR1ZVN1NVQvYzFMaExWVmdCbzVqYnUzNWdvUEpWTmh5Y3JMcHd5YmpJYy90bXVwdXM0WGE3'
    b'ClAxSndyNkNlVVJVdWFpNjBQUHFWZFcvTXpLSEpBM0I1QnpYdGRkTzdoeHhYOSt6VTZDM0Zk'
    b'T3FSVGQ4bFpFRlYrRCtqa1VzYnJVOTMKYWQ2RUlxM1ZQOVdsMmZrUjdMU2FHTDl2NHdPSFI3'
    b'Q3NIWWVIWVRmekhUNzhibC90di83ZE82VXl0dS9wK09xNkY4ZVNYb1hVTEU2RgpGRlo4N2VN'
    b'OUFrSVc3dTI0OXJiT0g3bUl5VUM2OXZiZWJkc3UzcWJMajJuWm1kOWVjeStaODU5SWRvdlFl'
    b'WlIzYy9DQUlEN3dFSHAzCjkyM3Q1cUdHV21UeTRFVm9LZVFLV05lVE96Nmh4RXZWWjdUTTBl'
    b'QytmZWl1V2JGSFZmai9jMGlWV09ueTl0My9lT2JiRjllLytzU1IKdFN5blhORzV1Nk1tK2Rp'
    b'YnZzK2Z2V2V6KzRWZ2hMci8zUHRXbU40WW5HdTZ0R1o3bWpYbGxOb1BaT2ZYVlAzZ3B1VlBH'
    b'UmhRSkpJNQo4QUpNQnBnTVNHWmdOY0ZpNU1VeSs1ei9za3lCbXVCWGdWaU1lWWRZSk90SXJj'
    b'cjBWMXJ2K2RiR2w3UmE1YUdkZldhcTBPVUt1RjBJCnhoZ3RXWGJaeUYvdTZiN3I4c0ZqQWIx'
    b'Unk5SkcyNWQyZkgxdmRzc045USs4Rk5zNkl5LzcyM2E2U3ZmOFl4dHZZN1JDZlEzR1FpaXkK'
    b'V05XTk1vOUVCaXlIRWd0ZUJFODMzTGY3MHFldTNWYi8wemRTMmlXcXd2K0JkWVpmLytpOCs4'
    b'eUl4b3RXZzRhMUdubVNRQ1lQUVlURAppbGdDTmpNWUhYSUZkTGVRWDNyaCtoWnJaRXZYa2V0'
    b'ZSs3Y0JidlA3M1ZjUC9jYnpsMzY1MXB3eG1Vakk4bWdRSGhjc1JrVGlTR1pSClpNSFFxS3Vs'
    b'YnZyTnArNVk4OXU4N05xOCt4MkZXSXpwY0hGRmhyZExuOXJ5OHEvZmlhNWlpR3lOblo5UGdh'
    b'SmdOY0dvUnpZUHR3dloKQXZKRm1Bd1lEOG4vY2VWajQxSGpmRkorYU0wdDV4aWZlbDg3Nmla'
    b'Zi91ZTIyMXJyaWlhWEdRUXhPd2RhQzRzUjBRUnlSWmdOc0pyUQpVSXNuZHJmZXN2cEZ0NTE5'
    b'NFBqMWk5UGY0c2lGZjA0UnpwZkRsNXJsY0NNejRuTWpHSUhaQUQwRFhrQ1pRMjBWVWptUUpQ'
    b'UTZaUEw0CjlKbGoyMTd2TzdkamFrdnpyc1BUdnJEWStkZnNZcVB4Rjl2V2Y3UE9uZ3ZINUxr'
    b'WUg1MVhBTFExd0QrTE1vY09INklKMk15SXhOSHAKVHRzTTVlZUcxdktjZEt5NFZpRm9WZUZm'
    b'aFV6UWU5T2JyUEowSXpQaXE0Ti9CZ3dOaHhYSkxHUVpIaGZTT2VTSzBETWdvSnpYT3o4YQpO'
    b'bW1VNHNhbTQ4K01YVlJIRFdkUS85K01Qei90dXVmSnJmZnBTRzVnSFAxTFVGT0ZSQVk5clVo'
    b'a1FCTHdlVEFlZ3NPQ2FCd09LOHFjClF0TzZUSkhjM0RYeTZQZ05NcWxURmY3MU9acmNuNzJn'
    b'aHBpb284ZGJ2SmhQSVYvQzBuYUU0OGptMFZRSFdVRytpRlFPelhXU2x1QjAKTkpiNmNzWFFz'
    b'WWN2KzQ5ZEU4MVJxZjB2NVF6aGpvYmJIN3I2S1phVmdtRmxaVGZHUWxDQXFURGNUdGljT3JO'
    b'T0F1Q3dZbkFTVGh2eQpKZGpOWU11U1haZSsrOEJ0SS93NWFpQjlud1VicUwzSkRmMk9BeVFi'
    b'Ym5SRGxoR0tvdGtMU2NKOEdpWURqSHEwZW5Gc0hFdWE0WitGCnh3V1hMa3dvZ2xjL05SQnB5'
    b'aENOLzlmbi9aUHY1bnUzdnBMTENqUWwrendJejhOVGpjRUpYSFFXaHZ4dzEra2g4Q3lIUTBQ'
    b'd1ZJTXQKdzJvQ3h5T1p3YnVwczU0TS9hT2V6SmRnVjRjejd3K0JOSC9qM2Z0bFEzMWdGam90'
    b'ckNZazBwQmtMR2xHaXhmeE5IUTBHbW9SbmtkYgpBd0poMk15Z3RWanFQTEhubWs5MjQ2VS91'
    b'NFJtZXZUdXkxNVJCSUZsWlFNREFDMWUwQnJZTGNpWG9BRGd5dk1sL1hnSUhoZElBbTRuCkJB'
    b'SHhORFNtNmwrZXVQeTNGMzUyYy9WejZnVzJ2NFVFV3Irdzgvc2VqeW1lUnE2SVVoa2RQZ3dI'
    b'QUtCL0NVNzRVVk9GYUFKV0UzSUYKTk5RaVZ3Q0FSRnA2OEt5YjE1dTJuK3FDWCtqOU5hWFZq'
    b'UHFsMmlwa0M1Z0tRMUV3UG8yVjNYaG5BTEtNWFFkRlVxZXRyMW40V3RCYQp4Skp3Vlp0K3Vh'
    b'ZnZoK3Z2YnJBbmQ4WXZWQVBwMzBoY2JoNEpHVDYzZW5lWlV3Z0NzUVFjRmtneWpIcmtTeEFs'
    b'ZUZ6STVNRnlzRnRRCjVzQ0w2RzNGc0YrdU5lVU9KdnBaT0J6aXlFK3YyQ1lMUXExZEh2SkRr'
    b'c0hRbUV1aHV3VUFtdXNBZ09YUTFtblFvMncyb016RFB3dVQKQVpFa3M2RnRoQ0NvbTk3ODdp'
    b'Qi92dG9MLzNaMkZENzN6UjNYT1N4d1dFQnJVVk9GZUJvQVd1c1hxc1pxQjdxYWtjNmhxUTVt'
    b'QXdnQwpEYlZZMzdEL21YVmI5ZEs4blpyWEdhaFVTZ3lFd2VpZzE0RWdjWFFVUjBZUmpJQWtr'
    b'UzFBVmdCRkFhVlJGSXhPUVpMZ2RzSnB6Q1ZaCis5ZGZ2WEZYNFpwRjJ6Z1ZNOW4wNk56LzNu'
    b'NzhnbXdCUzVwUktNSHR4SWxKbE1vNFBvR2pvM2gzQkVOK3BIUEk1SkV0b0ZDQ3d3S08KeDdM'
    b'R3VTN3lWVjZpb1NpMUxyTGFqa0lKMVE0VVNqaHZGWncyNUlvTG45OWNCLzhFQzRZaENDenJn'
    b'SVpDS0FwZVJMVTU5NHRySHRPTApNVlhoQjFBc2ZtZjAvckY4RDBHZzJvRmdCQzQ3WG40Yloz'
    b'VEJab2JaQUpNQitSS0dBM0RhTUJWQlhUV2NOaGdZYk52d2JVYkRIaDAxCndXZ0t6eU9Xd0Zn'
    b'SUxWNUlFZ3dNVEFZQVdOS01lQm91aXdTS0FzQUw0QVVJSWhyZDBOUFNGMS81QnF2MXFBby9B'
    b'RXFFNjh0N2YzaDAKdWhhQTJ3a2RqVFY5T09HSHd3cUtRcjRJand2ZExYRFpNVG1EUTBQd2VS'
    b'Qk53TzNnYTQzeGh3OWZDb3J5MW1rNmZIRFpNVEFHQTRNZAorOUJRQ3dCLzJBTmVoTVVnQThn'
    b'V01CeEFaeE1vRXROUnpNYUlaWlo5aTdsWkttQTQ4MS9KbytaQXlIZFJ3MXRlTDhGUVlpQ01h'
    b'Z2NPCkQ4UHRoRkdQMFNCNEFmRTBlbHRCRUNCSnVKMmd0U2pQVHo0eTg4M3hDWGxULzR4Qmoz'
    b'QllzSnBCYTlIaHc4Z1UzRTRZR09TSzhIaTAKa0JXR0ZNczgvRE1nU1hBQ1Z2WGdnU09mSHVk'
    b'V3Fnby9NR0pTNjM2LzkyTGZXMllYWTJVRW0wbHBiU0NzRGxyTDBOVldpZGFneUtMUgpBNHBF'
    b'TUFLZEZpUUpqeVdkS1RJL2kzeDNZcng4N2RwamNvbE5adUh6TEZRcE5WVVlDWUNpNEdrd3BH'
    b'S2w4UkFVQlpJTUVKQXB5MjA3CjduZ3hlek5BcUlIMGcrUkErWW9Mbm43NDJWMk5qTjFNT0J4'
    b'RVZWV1pNQVRpWm11TnllUFZBVGc0aUd3QlZUWkU0cGhMb2NXTHYrOTQKblpKTFpVa1BLS2tj'
    b'cWgySUpSRUl3NmhIa1VWWE16UVVvTURJS0V2YjRhMkdSSmllRFY1OXljNy84MEwyMXNYc0Q0'
    b'dHR2dkQ5SGJvcwpkRkM3V3F4QlR0SU41WHBpNlAyRTlhR25yLzJ4VG1HUGphUGFqb0Z4TEd1'
    b'SHR3WXNoMUlaMzNqdHMrM2U3TTFyWG5sbmY2bk9oWjVXClJCT1lTMkpaQjRKUmFEVkVYUzFa'
    b'eUV2QkNBU1JHTTkyaUtUcDhFempqNk1QTHZKMnFLUkFhaFJDZGVRSnIyYTQwelJRTCsyNTF2'
    b'T1QKZFEwRGIwZFc3aXRmVlNEY0lNaHhicldTREZ6UVBxVFhJWmxGcHc5c0diS0MyVGtrczdq'
    b'eDdLTmFKRnZzV1lzQnNnS1RIdU1oR0ExdwoyaURMaUNXUVRDdVpQRWdTQklFZWI2SWs2Qjcz'
    b'WHhjV09oWjVzMmdXdnptTlhGaG1lS3RkZitUZkxuaHNOc2JydExDWkljdUlaekNiCjh6Ulk0'
    b'M1Y0SWxXa1pWSi9rTDEwZjN3bDhCc0FoUkxhRzVFcmdBQmNka3pITUJyRXlxVmNiRnJoZVpR'
    b'NTBOcUZhMm5KTE1MeldOb08KVVVJaWcyUUdvb2c3WDc3cWljejNKZEpRQWUyenlJK1BWTGhu'
    b'TDdyMjhyT0NJYjlBY3VMOXY4S3pQd0JCWUdJYTlkVXc2U1AzMUh4YgpVZUIyNHFhWDd6akln'
    b'cFFsQURZekZBV0NDQVZ3V0hGa0ZQVTFtQzh4VXFFVW1BWExZZU1xSEIwRnJVVWlBNTBXc2d4'
    b'QnhPNGpzSm14Cm9oUEp2RzZRdjdBaS9GVkFJSzNINFg3N29aL3RYTjFobWZUUDI3NzFEM21D'
    b'UUxZQVhnQUlPQ3hvOGlDZFJ5U084enNEZG5Hc1UvT20KUVptZmlhR3ZIWG9kN0JZQWNOa3hO'
    b'RVd1V0txTFI4c0dCaG9LTlZYSTVOSFZCRWtHcllYZGdwRXBrQ1RDQmMrem8rZmY4ZmEzQnZr'
    b'TApLaVcvTFBZUmFWWjJqNmNhTG0zYmRmdXJOMmxJK2VpWU5sOGtzZ1ZvTlpBa21Bd0VUSmE2'
    b'UmlOSndtZWYrOTVGVDMveHZFRkJSS01ICjR5RWNuOEJvRUxraTloMG5WcTgyQ2RsQ3RvQkR3'
    b'Nmh4QUlBZ2dpQlFaTUZ5TU9waFlGQmZnd3VYengySnRZNks2eXRwV0xmb1I2VEsKSnl3UEgw'
    b'djMzYlA2bm5PYXh1YlRtbXBMeVdXWHlod2tHUm9LZGd0Z3M2UE03WHk3WkRaQXI0T3NvSzl0'
    b'WWVOUUJHT3o1S1lOaHZ4OApZWHdhZGpPU1dWVFp3SlpoMU1ObFI2NElBMFB1RHpUT3NVNUJw'
    b'Zy9OOVR3eDgrVVNXYVVxL01CamhlQ1dEczByWFczMG9Rc2JkK1hMCldpdFQydHE1czhNWkRr'
    b'V2hvZERUcFlVZ0hEaUIxZTh0dVo2WVJwa25YTFU2bTBtaFpXNThHaHdQbndkR1BjYUM2UEJo'
    b'eUk4V0wzZ0IKQlJZVHFjYkQwNDMvNUg4R0ZVZ0YxNFVtSmZienMyNjRlc1ZBcnJod1BVeFIw'
    b'T0dEL3RRYUpacWVpL0t5Z3BrWWREUUVFV2QwWWNpUApiQUdyZWpBY3dFek9PVnhhUjBvbGd0'
    b'SStGOWl5cjNoNUpiYURCaFZMZ2FoOWZHVHIxU3NHVWxrc1g2b0R6eDhlVWs3NkM4K0RvaUNJ'
    b'ClBBQ0xFVWI5d3V6dThZay94Vmk3QlE1NzRjNFgvbjZZMzRCS3BySnZUaXVLQmxsR0pnL1F1'
    b'bUcvMHYvZWV2bFlFbFlUMGpud0FzWkQKNkd4Q01vdkJTY2p5bjdabDlMcUJHYWViRHFIQ3FY'
    b'Q0ZuTzVmWGpqVDU4SFlTTkZpcHFLSmhlZjcyakFXaE0rREZpOVdkaU5YZ0ZhRAozbFlzNjRB'
    b'a284aWV6Q0hrazZOWHY1bi9qS3J3NCtSZC9ySnRzL2NLc2phWGxSaGFMa3ZVaVVrQTBHcXdy'
    b'QU95akxFZ0FJeFB3L3hlCm1VNlJHQTZneUNJMHd6NSs1ZjMzZG4zV3JFUlVoUi9qYUl4S1Vl'
    b'MlBIdDZvMVlEamxLWldvL3plck1LaElkak1zRnR3WWhKTG1rQVEKVUJRY1BBRUFLN3R4d28v'
    b'ZU5veFA0N05uN0hqeGdpdjc2WmRVaFI4blB4bTl3Mlpqa2xtZ1dDQnBXcFJRS0dGSk0vWVB3'
    b'bUZGVHl2TQpSaFJLMkhjY0s3cVF6a0V3TzFiM2tTTUIxTmNpUEk5YVhmQ3R6M3pwOXZxdjZw'
    b'VlVKWjUrNVUzNS9vV2hLV29NaFdHR0p1UlNvck5OCmMyeEVBa0NTYUd2QWtCOXpLU1F5S0pX'
    b'eHJBT2t3NjdYeXZ2M0Z6MWVYWjFEUEQ2Qm5oYlVWb0hXeUd1OGcrdXFYcHVJbVdmRmJyVXUK'
    b'L0RpUVJUc3grNGVMdDFacHdnWUd2QUJPQUVtZ3ZSR0tBbEdDOW1UMVpMTWpreTZVd0Ftb3Nt'
    b'STBpSTVHakFUUVVvOWdCS1V5cWgzRQprNE9iL24zc2ExR2xSKzJGSC9GWGtTd1R0cm00ZE11'
    b'NlhjRW9vVEFHWDdYSTBNaVhZTlJqLzNIb3RLQW9hTVV5Z0NFL21yMExwZUZ3CkFDWWpaQVZU'
    b'RVdnMEtKVFFaUEovWmZYellqWTJtbW5uQ0t1cThDTmxxdFMrdWZyWjVTMkZlRnhNOGNhR1Zw'
    b'T1JGcWRtNU81V0RFL0IKYklRb1FVY2pWNERGaUlrWjJNMHdHeFlXWWZBaW9FQkRnU0FoOFB5'
    b'V3JvR3JXbDRvWmpLVCtUYUJNS2tLUDZwb1NqSmNNaHJKMjR5MAowT3RPdkh1VWRicU5zU2hm'
    b'V3dXUDg4ODYzNUFmUGEyZ1NCUkswR3FSeVlNWFFCRFFVS0JJQ0NJS0pVQXNmWEhkZ1UvVS9R'
    b'N0ZtRC9qCkt4UDJSUnFBVHMrZjNaTEZ0Y1puSHRuOHZXSTJRMEplM3Jsd0QxczBBWk1lRGl0'
    b'bTUxQmdRZXJzc3ptN21BNDR6SEM3TUo5YXVIODQKbFlQSkFJb0VMOERBb0swQlUvUG1YdzVz'
    b'ZWlid2QyUFNoc1cyR3VxMDZvWC9OVFZPaTMwajA4WlArTjZvcXdZdklGZUV4d1dXdzFRWQox'
    b'UTdZTFlpbG1jMi8vOVdiMDJ1dTczMHBrVkhLUE5vYlVTaUJJR0Mzb01UQ3dLQlVodDJDaVdu'
    b'WVRmd2x2U09mWC9xQ2xCamZrNzFFCnJRcy9JbmJucnREcXpTZHZYVHRKUEkxVlBUZzBCQURK'
    b'c3NPcXpReEptMTZmWG04eGdxRXg1SWZiQ1k1ZldGWkRrVERwRi81N2dpVGgKM1JGd3ZGeHZT'
    b'NnVsL1VlWkpDQ0lKRWxnWUd6aEdiYThrQXNGa2JqeDlYc24rSlVBZmo1MlhXTXRKQWxXTTZZ'
    b'aWFLM0hkQXh1SnlabgpVT3RFS29zcUcrWlM2R2pFNCs4cytmclJuNmdLUHpvKzZYbW9wekhi'
    b'M1lJcUcxZ09aUjQ5clNqejZHcUNWcU5jMmZZS1N6b0JqRWpuCi96RzRWSlRCMERBYkVZcGll'
    b'UWRHcG5EV1V2aG5zYndUTXpHNG5kaSt0KzNCNEhlTFpLMnE4S05qMy96S3ZZUDZQNzZycTZ1'
    b'R2djSEEKR0xRYTR0aU1COEM5THkyejY3S251dXVPNlhPWHRpT1RJOWt5REF3Q1lhenBRMkFX'
    b'YmlmR2d1QVUwL2Zldk9TdTBWK05DV2N2d3RQVQpuSzcrS0puOXl2SkhTTDMxcWVGems4U0pV'
    b'Tkp5OC9wOVpSNlhQZitqaDgvOXh2ZjhEMWJwNHFmZS9GVDRpNUhmMU03bFRTOWRkVmMyClUx'
    b'UVVESXhoV1FlZTJOMzBZdVRxRitadkVDbkxvbDJWZjVvV0ZWRHVxTDk5Uy92QmEzZitQS3Fj'
    b'bkFoV25sL2VONVJzL2VmUWMzYkYKbnliYi91Sm1TM1U3cm05L2NtK29iU0N6MHFZdmo3SDlP'
    b'ZEs3NkZQKzZhandtcXA3LzllNng4Ly8vZE1ScGU5VXA5eDdVZitXUHp5ZAowUFNlWmlkN0d1'
    b'YkN6ZGFmUGZhcFIvNWw5NDJuL0FHNG92WlJoMVZNb3VYME85L1RKQmQyMDMvYzZud2dxMjF6'
    b'MlVxM3JuOXovd25ICmM0a3ZrUVIvUi9XTkszMmhnTEQ4SC9yL1dFM2xIbGh4UFpmUFpoVHYz'
    b'Y0ZIVllXTEt2RkphM1RiZmRaSWgyZDRUV2NHSXJwcWlxK2MKZGNZUEQxODdWM2FQWkl4WDkr'
    b'enc2REt2RGJXOE5Ydk9VdE9lb2FqcnRCcTRWZUlGdGg1bFR4T0dmY3hjYmo3RUdScEJrTG1D'
    b'MVQvZgp0Tnc5T2htenk3THkyMzE5eCtiNlZ6a1BoVFNmVjdMVFczcVAvdUwxempPYUlzOE9Y'
    b'amxlMnBBdDF6Um9abWRGRDBnTm9Dd3R2K1NqCnBuek1YSllqT2RLaUt2d28rdHd0SGNkVzFM'
    b'TG50QnNHOXYrZU1EZVlrUG1xNzlidlgvbTcwZGxlM25KbklzVzIydzhjbU9yUDhtMCsKN1o3'
    b'dlhQSE1iL2F0U1JGWFdZbkJSdTNnZWYyYjZuWHhUVXNkN3d4TTZUVkNqejV3UVd0cHRidDQ4'
    b'WExIaVZBcXFqU29Dajkwek96RQpaUzFKanVjbVp1YnpiUG5XY3cyZlhFR0daaWVPVEszTEUr'
    b'c3NGaHVINXVISnFaelNmdDJuUGltbGR4eWJXZTVxdXlXY0VZdHNuVUV6CkdVcDQzVzczOU14'
    b'MG96Rnp3eXFOblNucmRkb2FtejR3RmNnSnVuRys4c1k3bFpjTHZVeUs0emlUMFpTWkxSR1Vy'
    b'bGdzSEQ4eGwrRFgKVnBrSWh0SkVJbUdMeFRyT2J1WDQ0dWpvYUt5OGtTQ0lYQ0FneXpSdGFV'
    b'K1c2aVNSalVZakdrb1RtNHVOYTdpeW92TXRXVUp3ZVoyTwpkbEpwVkNDVlYxUzQ5WVVTV3pJ'
    b'WWpMbFMwY2d3akk3SlpqSlZOajBCd21xMWxsaVdKRW1TSkFHVXkyV0tJZ1dCWHpoVmtnUkJN'
    b'QXhUCllsbXoyYXlBSWdDUHcwaFQwa3drUW1tMDFVd1JFcWYyd2crZEZwZTJxc3JwZHJ1TGhi'
    b'MUxPanJiMnRwUGpFNXNXTm8zTXpQdDlkWjcKdmZVQWpCR1JwRWlUeWJSczJiTEp5VW1yMVRZ'
    b'd0VUdjUwa21tcGdJV2g3T2pzOUZaNVp6SklTOXFuSXgrdzlsZFA5c2VTRk5kcXNJUApkekRE'
    b'bElQNXZHN3YzbmZ5eVZDRHZlZkkwU01sa1loRXdoekhUVStIMHVtMDNXNHY1TktpeUdrMG1r'
    b'TUhEN3FxcTJPeG1DRHdwMTRGCndIRWNYeTVGbzlGQ3ZoQ1g3VVZXbkoyWmxrVFJRenNxTHBo'
    b'V1dDQmxpZ0dQVld2UUcwS3hKTUhZdEJUQmMxeXB4QVBRNi9XaUtQSTgKTDRvaUFGRVU0dkc0'
    b'SkV2eGVMeFFLSnpjbkdWTEFFUlJOQmdNT2tySlpiTXNXOG9rNDA2WGk5Um9SRkgwL0duNlFs'
    b'WDQ0VkJueU5udAp0cmEyZGt0MUM4WFlUU2F6dytHZ0RWYWZyNm0rdmtHbjA2MWVmU1pKVVdh'
    b'clE2UFJDZ0pmWDk4Z0NMekpaTkpxYVordnFkYnQ4Zm1hClNJcnkrWm9hNnR3MFRkdHNkcTFj'
    b'YXF5dldYdldXaDNEdEhwTUZhZXd3Z0twVzVzb0ZZdjc5KytkRHVkc3RxcFVLdEhZNk5QNjA4'
    b'SGcKVkR3ZXQxZ3NodzhmTXB2TitXeUIwbWg3ZS9zQ2dVQnZiMThpa1JSU3FXQndLaGFOa2dS'
    b'eDhwRVVpL1lxWnlxVjZHN3hFQXA3OE5BeApsaTB4aWg2S0JJSlNlK0dIaGNkUU5wcE1CcU9S'
    b'WlFzT1BhblRNZFBUTXhBRmp1TUlndERwL3ZRakJKSW9CSU5UT3AwdUdKdzZGVWhQClF0TTB4'
    b'M0VPdTJWd2RJSmxPVkVReW9ScExsczJHbzFMZkxWbWRsSU5wQjhpYlc2ZG9pZzkzYjJaWkZR'
    b'aG1WQk9PeHpPdXoxdUxVMzMKOTYvMCtacjYrMWRxYWRwc3RlZEsvTmhzY2E2a0g1c3RocEtp'
    b'SkJFK1gxT3QyMzNxUGMxTnpja3lFMHhMdzFGdVlpWnRycXB6dWFxOQpYbStkb1ZCWmJWSmg4'
    b'NFYxNVlPa0lvQWtvNEpiTlBrV29pdDNWQ09YQ0lwKzd3SWNMOGhVVEg4R1NPMnBEVzM4bEFV'
    b'SlJlSlB2dTNrCkgzR3lrZFZVQTRBczFuQkhhUWdFcFUyVGRYbU5SMVdvb2daU0ZWV2hxbEJG'
    b'VmFpaUtsUlJGYW9LVlZTRktxcENGVldocWxCRlZhaWkKS2xUNUsvaFBadHlyNDZNeTB0UUFB'
    b'QUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpFdE1EUXRNRFZVTURRNk5EQTZNRE1yTURB'
    b'NgpNRERKRGRGUEFBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl4TFRBMExUQTFWREEw'
    b'T2pRd09qQXpLekF3T2pBd3VGQnA4d0FBCkFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9'
    b'ImltYWdlNzQ1MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_36')

IT_36 = b64_IT_36
index.append("IT_36")
index.append("Italy Friuli Venezia Giulia")
catalog["IT_36"] = IT_36
catalog["Italy Friuli Venezia Giulia"] = IT_36
country["Italy Friuli Venezia Giulia"] = ('IT_36', '', 1)
lookup["IT_36"] = ('IT_36', '', 'Italy Friuli Venezia Giulia', 1)
lookup["Italy Friuli Venezia Giulia"] = ('IT_36', '', 'Italy Friuli Venezia Giulia', 1)
details["IT_36"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_36"] = ('IT_36', 'Italy Friuli Venezia Giulia', 1)
regional["Italy Friuli Venezia Giulia"] = ('IT_36', 'Italy Friuli Venezia Giulia', 1)
#----------------------------------------------------------------------
b64_IT_42 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4ODciCiAgIHdpZHRoPSIx'
    b'NTAiCiAgIGhlaWdodD0iMTAwIgogICB2aWV3Qm94PSIwIDAgMTUwIDEwMCIKICAgc29kaXBv'
    b'ZGk6ZG9jbmFtZT0iMTUwcHgtRmxhZ19vZl9MaWd1cmlhLnN2Zy5wbmciCiAgIHhtbG5zOmlu'
    b'a3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgog'
    b'ICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQv'
    b'c29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5'
    b'L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5z'
    b'OnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRl'
    b'ZnM4OTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc4ODki'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnODkzIj4KICAgIDxpbWFnZQog'
    b'ICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1p'
    b'emVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlW'
    b'Qk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJUVUVB'
    b'QUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdB'
    b'QUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBQQpCM1JKVFVVSDRR'
    b'Z0lBZ3dEMGpETGNRQUFDMDlKUkVGVWVOcnRuVjlRVzFVZXg4LzlrL3NuWEJJSTVCOS9FaElJ'
    b'SlZnSUZFdGIyMXJhClFkMHVPcmJhbWRVZGRYWmRkVWNmZk52Um1UNVk5MUZIWng5MjF0bFpu'
    b'WEgweGZHaDIrNldjYlphbDFacUs2VXAxRUtnL0FrcFFnaEoKa3dENWQvL3ZRMXltRGJTOWhG'
    b'Q1NlcjVQbDhPZDN6M2N6NzIvOHp2My9INEhCSHpjQ3ZKUDhpdFg4ckJYeU1mdVBPd1ZDcUFL'
    b'WEJBaApSQWdGRVVKQmhCQWhGRVFJQlJGQ1FZUVFJUlJFQ0FVUlFrR0VFQ0ZVQVF0L1FQNE9C'
    b'R0hMeXBJbUU2L1ZDbXExak9NQ1RjczRMcWpWClB6K3FQSThsa3dBQVZTeUdzaXdaRGxQejgw'
    b'UWtnbkljUkxnSmtqRnN5ZUdJTmpVdDdOd1p0OXRUT3AxQWtxUWswUmhHVWhTQ1laaEsKaGVJ'
    b'NGxrb2g3NytQaXFLMGM2ZjB6RE5jSWdFQWlIR2N3SEVzeTdLQ3dLS29MTXQwTkZvOE1sSjg1'
    b'VXJ4NktobVpJUllXSUFJTjBvcAp2ZDUvOEdEZzBLRzQyY3dnU0lsZXI5ZnBiQlJGRXdTR3Jq'
    b'WWl6TXlBVHo4RkFBQ1NCRys4c2ZyVEFFQ1NaWmQyN1ZwNjl0a2J3ZUFDCngxSHo4NGJ1YnVP'
    b'Wk04ekVCRVNZTXljNTE5bnBlL1hWcE1WaTF1c2J6ZVppbWtaeVpSc0FOVW1xU2RLbzFZTHFh'
    b'Z0RBWWpJNTM5SXkKK1BMTHFOOWYrK0dIaHQ1ZUlNc1FZZllLYjlzMjhzNDdxdXJxZW9lamxH'
    b'SHV3eFUxTksyeFdPb3NsbkFzTm1HeFhQZjdtOTU2U3pzMApCQkZtTStCNWpoNE5kM1U1R3h2'
    b'TDdndThET2tZUnJkdFd6Z1d1L0xKSjNYdnZWZDEvRGhFdURibmVmV0REK1RPemtjYUcxRUUy'
    b'Y1NPCjZCaG1WMXRiMzl0djQ0dUxjRjY0QnQxNC9ubCszejdYWGZsTlRVM2w2bkt4V0N3VUN0'
    b'M3B0eVNPdHpVM2U0NGRVNk1Rb1VMUGdHQVQKcjcrKzlhR0hrRHZ6aTBhalhxODNrVWprNUly'
    b'VDA5TStuKzh1SjZoSjBtUTBkcFpEUjZwTWRlb2FoaVFwbFdybHJ3S0JBQUNBSk1ucAo2V2xa'
    b'bG4wK1gxVlZWU3FWUWhDa3ZIeHRONWpqdUZBb1JCQ0VTcVVLQkFLU0pJVkNJUXpEV0piVmFE'
    b'VHEvMzhUV0piZWFOd1RTUHhyClhvUUk3NjF5b3BSZWNRZlR3akRzNnRXcnl6LzYvWDYvMzQ4'
    b'Z1NGdGIyMXF2UWhCRU9CeWVuNTlmYmtsYjFtZzBxMXFqVktwU0ZaS0gKdHd2Tnl6NGhDTHA2'
    b'eDhyTHk2MVdhMGFqM1c3WGFEUlpYTWpwZEdhOGJSaUdOVFkycnVyQUVRUkJnUXdSNXNKdjRK'
    b'bWVnOGwyeW9FZwpDSHI3czBJUUJFbVNoWFZEQ2d6aDR1TGk1T1JrUnVQdzhERExzbGxZR3g4'
    b'Zmo4Vml0N1lrazhtUmtaRUNlNllMcTd2UmFOUm1zMUVVCk5UMDl2YlMwVkY1ZXJ0UHBXSllO'
    b'aDhObXMzbXQ0UXlDSUE2SEE4T3dOTGJhMnRwMGV5S1JVTjloTUlZSTF5dUx4WExyeTJlMzI3'
    b'UDIKb2dSQk9CeU81VUJYRUlTVm95eEV1SUV5R28yUlNJVEowWWMzcTlYS0ZlekNZYUVpUkJD'
    b'a29hRWhWOVowT3AyYzM4c1JEMVJFZWl2Rgp2TFVHRVVJOUFJN1U0d0ZmZnJuK0tjalBCMjQz'
    b'ZVBmZDlWcGpHR0xIWGdCVUVLRXlEUStEWThkeVpzM3RCdTUxbDhuWDFKQXQyL01RCklYU2sw'
    b'SkZ1a0E0Y0FFODhzVjRqd1NEbzZnSUFnS2VmQmtlUHJqL2dTZkFZUktoWXBhWEE2Vnl2a1pt'
    b'Wm53LzBlckI5KzNxdHNhdzQKT0FwQTNpMDJRVWRhOENwZ2hKSWs1YTAxaVBEZWttWFo0L0hr'
    b'eWxvNEhQYjcvUkRoZlZVd0dBd0VBdEZvTkNmV3BxZW4wNWtjTUNMZApjUGw4UHA3blNaSk1K'
    b'OUY0dlY2RHdaQktwV2lhcnFpb1dKTXBqdU84WGk5QkVEaU9oOE5oV1phbnBxWXdERXVsVXBX'
    b'VmxVVkZSUkRoCmhxaXNyS3kvdjM5NTNJcEVJcEZJQk1meDl2YjJ0WnBLSno1NXZkN2xsdlN4'
    b'd1dBb0lINkY1MGdaaHFtdnI4OW9kRHFkRkVWbFljMW0KczVXVWxOemFRbEZVRGhkQUlNTFZ0'
    b'YkNpZUN5N3JBc0FBTS96R1ptb2dpRHdQQThSYnFBQ2djREswSEY4Zkh4cGFTa0xheDZQSjJP'
    b'bApWeENFb2FHaHdvcHJDbXdzUkZIVTVYTFJORDAyTm5iejVzM3E2bXFEd2NCeFhCWnI3aHpI'
    b'R1kxR3E5V0tZVmgvZjc4c3k2MnRyZWwzCk9oMGZRWVFiSXIxZW56Nm9ycTRPaDhQVjFkWFpq'
    b'WUxwY01aa01xV1BqVVlqeDNHbHBhVndVbkgvcE5QcDdIWjcxdnd5WkxGWXNoNVEKSWNMc2xj'
    b'T0VNNFpobU0wb1lmeUZScVJRRU9HRHBueDBwRW1KQ3dZQ1BjSGdlZzNKc3Z6Tk56S09vNklJ'
    b'enAxYmY4ZG1nUllpVk5hbgowWVhvWDQ4VnhXSVV5MUk4VDNJY3hmTVV5OUljUjNFY3hmTXFR'
    b'VkJvS3JwMTY5aHJyMjEvODgyY2RHeC9YdjZmaW54RTZBcFhoRjc0Cjlad2dTS21VbUVvSnFa'
    b'VEFjUUxQOHp6UFM1SWdTUUlBc2l4VG9rankvT0V6WjdiZXRVQVhPdExOR0o4bHhHNjMzL00w'
    b'UVJBR3o1N2QKb0FUZVdaMk9FSVMwRDFDSklrUzROa21vTElvaWh0MGoxd2pIY1lIamluTlVi'
    b'cCtodng4K2pEQ01LRW04SklrQXlKSkVTOUp6NDkxZgoxSFZCaEFvUVlySWdDUGRFbUk1WDBJ'
    b'MzVuaW5pK042REIxVzMxUHNuRW9uNWM5L0RTWVVpc1NveGxVb3BPWk1naU9UR0ZPV3lLSnBS'
    b'ClRpeUtJb3ZURUtFaTNTVGpHY1czZHhKZFZqYXZ6WDJndjBUVEZJWmxGTXJFNC9FRlZSRkVx'
    b'RWd6cW1oTVdWSk1pY25rMllBVjJySEsKU3QyS0xWQ2lvZEFOV2c4Uktvc0dpeFlXcHFlVm5H'
    b'a3dHTWFOUmhITGNaSzF1Nm5KVUZlWCtXck96czVSWlJDaElnV0w0cEY0WE1tNgpLNFpodXBJ'
    b'U1QxVlZEcS9PcVZUakpwUEJZTGd0d3BLa3lOSlNnREZBaE1vaVVpRGJnc0c1dVRrbEo5ZTB0'
    b'UHg3Ly80Y1JxVmZQL3h3CnBkV2FFUThIZzhHYVlGQkVNSWhRcVI2NWZObXZiUE9ROHZKeXhH'
    b'eDJyOGlKeWpxUTZXMXRkYmhjbWNPeng5TStNSkNmOXlwUEVUN2sKODkwTWhSUk9MUnJhMjQ4'
    b'Zk9CQmQ5NEtmakNDZlBmbGtiV01qUVJDM1RUQllOaHdLdVZic2R3TVIzbldRRThWSEJ3Y25s'
    b'ZTNGcTlGbwp0clMzZjNUa0NJZXY2MHZGUHg5OU5ObllhRnNSNGs0T0QrKzZkZzNMMTg5cyti'
    b'dGUySEg1OG96WHF6QWZvc3BxMVRZMWZYVGtTSFl6CmZSbUE3dDI3cjdhMXVYYnZ6cGdPc2l6'
    b'NzA4UkVaMTlmM3Q2by9FVkljMXhuWDUvbjBpV0Y1emUwdEtqMzdIbnZ4UmNEdDJmM0tnbEIK'
    b'LzNIbzBMV09qbDJQUDc3eXE1Nm52Ny9EN2Fiek9MTW1yM05uOWwrNThuMXo4M3g5ZlVhSWZ5'
    b'ZlZPcDFNYWVsZlNMSjlhT2hYRnk3Ywo4NzdMQ1BLRDA5bTlkMjlGZmYzMmxwWlZwamZCWU56'
    b'cjdWVDhHRUdFSzF5RUpQMysxS20vcWRWN3U3b1VibEJvTkprNm5ucHFzcmIyCnowNW42L1hy'
    b'RHBaZGRYNDVWMW82NkhEODBOeE1tMHp0N2UyckZsR3dMSHUxdC9lUDNkMVlmcGNlNW5zR1cx'
    b'VXcrTVQ1ODcwTXM2T3oKRTBVVnVYMlZTclhGNWFwcGFQRFB6djVuY3ZMbTFOUzVsMTdTTFM2'
    b'cU9FN0M4V2hSVVZDclZaR2swVzUzV2EzRnhjV3J2NkN5N0Q1Nwo5dkhlWHNzdGU4NUNoRmxx'
    b'MzhEQWpORTRTTk10ZS9ZbzM2T0pKTWthbTYzR1pwTWtLUmFMSlpOSlFSQndGSzBreVMwTWt6'
    b'RnRXTWx2CjRQejU2aDkvM0pldmM4RUNRd2dBZU83MDZZL1Y2aDl4dkdubnpyWHV0SVdpcUVh'
    b'aldkTzJ3ZGY2K3BqQndSZSsrcW9nYms1aEpDR2kKc3Z5SGt5ZTFGeTllN3VrUk4zSitKb3Jp'
    b'cFo0ZSt0S2xWMDZlUkF1a09LWmdzcmt4U2ZyZHFWTW5ZckhlZUx5dG8yTWprcS9qOGZqbApu'
    b'cDVtdC92dzJiTkk0UlEzRlZKQ1BnTEE0WjZlMmhzM3ZraWxhbDJ1bXJxNkhHNWZPRFV4TWVa'
    b'Mi8rYnJyMXNLNUIrbUZTVEN0Sm9uCko2MmZmZmJsWTQ5OVo3TTVkK3hZcm5YS1dxRlFhUGpp'
    b'eFFxZjc2M1RwMHVVWlF0QWhPdVZOaDUvOWNTSjY1V1ZKME9oNndaRGpjdGwKTnBzVlRqbVdK'
    b'VW5TM055Y2QyQ0FDQVovKysyMzlULzlCQXBUQlZ6WlZEOHo4NmZQUHgrcnFQaXYxL3VOMld3'
    b'Mm1YUldxOEZnVUtudQp0bGtoei9QQllERGs4ODM1L1RXQndITVhMamlXOS9tQ0NEZEZqdGxa'
    b'eC9IalNZSzRack1OYmRueVhVV0ZqT1BGTkYyazAyRVVoZEcwCkxNdnByUEJFSkxLWVNNZzhY'
    b'emMzdDJ0MHRObnJwUXUycHZDQlFwZ1d6WEhiUjBlM2o0NENBQklrR1NncENXbTFMRUVrQ1FJ'
    b'QVFIRWMKeWZQNmhRVjlOTW9vVzRPRUNEZFRhcGExQlFLMlFBRDhNZ1RyQ3lGQ0tJZ1FDaUtF'
    b'Q0tFZ1FpaUlFQW9paEFpaElFSW9pQkFLSW9RSQpvU0JDcU0zVC93QmlpM3J2YUNibk5nQUFB'
    b'Q1YwUlZoMFpHRjBaVHBqY21WaGRHVUFNakF4Tnkwd09DMHdPRlF3TWpveE1qb3dNeXN3Ck1E'
    b'b3dNUEhkUTI0QUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNVGN0TURndE1EaFVNREk2'
    b'TVRJNk1ETXJNREE2TURDQWdQdlMKQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1h'
    b'Z2U4OTUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'IT_42')

IT_42 = b64_IT_42
index.append("IT_42")
index.append("Italy Liguria")
catalog["IT_42"] = IT_42
catalog["Italy Liguria"] = IT_42
country["Italy Liguria"] = ('IT_42', '', 1)
lookup["IT_42"] = ('IT_42', '', 'Italy Liguria', 1)
lookup["Italy Liguria"] = ('IT_42', '', 'Italy Liguria', 1)
details["IT_42"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_42"] = ('IT_42', 'Italy Liguria', 1)
regional["Italy Liguria"] = ('IT_42', 'Italy Liguria', 1)
#----------------------------------------------------------------------
b64_IT_45 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3MTg3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRW1pbGlhLVJvbWFnbmFfKGRlX2ZhY3RvKS5zdmcucG5n'
    b'IgogICB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNl'
    b'cy9pbmtzY2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vm'
    b'b3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3'
    b'dy53My5vcmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAv'
    b'c3ZnIgogICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVm'
    b'cwogICAgIGlkPSJkZWZzNzE5MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9'
    b'Im5hbWVkdmlldzcxODkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNv'
    b'bG9yPSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlc2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5r'
    b'c2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3Vw'
    b'bW9kZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNzE5'
    b'MyI+CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIK'
    b'ICAgICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2Ut'
    b'cmVuZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1h'
    b'Z2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJU'
    b'aFRuQ0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FB'
    b'QUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNiVkJNVkVYLy8vL3krdllpcDJI'
    b'dytmUUEKbWttczNzUzc1TTdxOS9EeCtmWDgvdjNpOU9xMDRjbVAwNjl1eHBoTnVJQXRyR2ti'
    b'cFZ3UG9GUUpuazhXbzFranFHSS9zM1pqd1pDSQowS3JhOE9Wd3hwbEJ0SGNTb1ZZVG9sZEp0'
    b'MzJBemFURTZOWDcvZnpoOCtwU3VvU1MxTEhQN04ybTNMOVJ1b01JblU4T29GTkN0SGhuCnc1'
    b'T00wYTJ5NE1qSjZ0amU4dWY0L1BycjkvSFY3dUcyNHN1WDFyVXVyR29EbTBzZHBWNzUvZnVa'
    b'MTdZYXBGejErL2lRMDdBWG8xbnoKK3ZZUW9GVHQrUEovektSM3laN2o5T3NIblU1bXdwSUVu'
    b'RXpVN3VCVnZJWUJta3JSN2Q3RzZOYkQ1OVErczNVenJtMysvLzR2cld2OQovdjZxM2NJbHFX'
    b'UDYvZnVoMnJ3Um9WVUNtMHJNNjl2Lyt2cjVuS0wrOHZQektEZi8rL3V2MzhiczkvRzY1TTVI'
    b'dG55YTE3YzZzWExICjZkZGt3cEE4c25TbzNjRm93NVBZOE9PRHpxWnF4SlYxeUozbTllMHhy'
    b'V3l0MzhRcHFtWlp2WW0vNXRGK3pLTjR5cDlhdm9tQnphV0gKejZteDRNZkI1dE9yM3NQMy9Q'
    b'bE11SCtqMjcxcHhKU2cyYnVOMHE2ODVNK2UyYnFjMkxoMnlaM2M4ZWFDemFaQXMzY3dyV3VS'
    b'MDdCcgp4SldiMTdpWTFyVjZ5cUJidm9xR3o2bHh4NXJLNnRtdzRNZmc4K2xGdFhvNHNIR1Ux'
    b'Yk5VdTRXTDBhd3FxMmRJdDN5bjNNQTNzSERJCjZkaFl2WWg3eTZGRHRYbGN2b3Rsd3BGV3ZJ'
    b'YXAzY0kwcjI0MnIzQk91WUdGejZnbnFXVjh5NkZmd0kwN3NYTmR2NHV6NGNtVjFiTnoKeUp2'
    b'VDd1REM1OVBGNk5ZaHAyRjB5SnpRN04wc3EyZzVzWEszNHN5ZDJMbGl3WThrcUdPVzFiUW9x'
    b'bWFFenFkeXg1cHZ4cGhzeFpiQQo1dElycTJoZXY0eTQ0OHlKMEt1SzBhdnUrUE91MzhXaTJy'
    b'M3YrZlJHdG51VDFMTE42OXYvaVRzckFBQUFBV0pMUjBRQWlBVWRTQUFBCkFBZDBTVTFGQitj'
    b'SEdRazRLK3hXTzZzQUFBTWhTVVJCVkdqZTdkbjdOOU54SE1meDk2WXZsa21vZlZPUkVtSEw1'
    b'UHJOSWttV2ExT0sKbEVzSUl4UEdNTmVWTFdXS3FDbE5TRlF1MFkyaVVLcnA4amRGNTNTaGNj'
    b'ck90MzJPODNuK3RPczVqek1jcjMyK0FEZ2NEb2ZENFZaSgpES1pCTVdoaW1hd3hLQlBNUW9W'
    b'Rm1LNGdnbmFXMlVyZWFZWlptSVZabUlWWnk3SE1XU2l4MWxxd0xkZFpyYmVldTJ0anUyRWpo'
    b'eVEyCkdadkZ0dHU4UmMvLzRhMzJEdHNjbDN6bmRtTXVDT3NkVGp2MS9GVE5uVjEyR1h2WXVM'
    b'cTVjM203UGN6blg4LzMzT1BsN2U3amk5YmUKOHNVekVMTXdDN013QzdOV05ZdjBRNUpsNWsv'
    b'dFJaRUZFQ0RZaHlJTElKQU1RcEVGc0QvWUZVVVdnT2NCR3hSWkFDR1dCMUZrelgyagpDVDJF'
    b'SWd2QUk5UVhSUlpBbVBBd2lpeUFjQ0dTTElBSU55UlpBSkZSU0xJQVRLT1JaRUVNN3dpS0xB'
    b'QlI3RkVVV1FESDRwZ29zZ0NXCm5tTkdQanRkYW80Wi9VaFgveHhENEtSWjN4eEQ0Z0Q4enpt'
    b'R3lMbjg0am1Hek9XQ2hYTU1vYXNZdjg4eHBDNnUvSnBqaUYzeitUSEgKYUdVRkhmLzNUdUFU'
    b'Rzh4YVBsYThRYkZvWWlXY05LZ0VtbGlKcHd3cWtTWVduRFlvdWxSOGtreGEvQmlESkVuUEJZ'
    b'OGtrMlFLL005aQpVcytrcFg5ZjdBRVpQLzhNem1abWhjM2Z5QmJuY0hQUHpUK1pKOG4zV0xE'
    b'dldUUzd6aWZaRnhDRnlVWFM0cExJREZseFVXbFpZYm5jCnVhU0NYVmxWWFZPcjRGNjRXRjBI'
    b'b0V4WFpWK3lxeERVWDc0UzVpQXJiMURYTlY2OTFwVGJUQi9MNnJxb3BmWEd6V2lScHUyVzJv'
    b'L0kKdWUxRXlEWGU3YW1WaXJ4d29ZSjdwMWJiMFF4S243dUIwVVdkWGRMdWU0MFcwVW5pSGtm'
    b'YmlvYjdpbDRhUDYwK2h1MkR1b2VQUU5NVAoyYVpwNzdmVmxzb0hCSU9jSVZQVjR6bVdkTmd5'
    b'M3psTE9mSWtKS3BSK0pRVHIzcFcrYnhkK2dJMG8wTmo5c0YwcVVUSzFvNlMvRkhoClM2L0FW'
    b'L0x4Zm1hTnRNK0w2RkZ3ZXRYMXNva0llZXRybHplZHFreStsVVF6bmpmWk9hV2VudWdhZkt0'
    b'OU54REFKQ3FaV2lHZkpwWS8KeFp2cExuaGZsdG95U1EwN2pGQVNSY0dIanhSRjZXWXpaWlNP'
    b'NGttb0diRnUraE5WRXp1cTQ2WjB4OGtvQzIrcTZuUGFGQ1daSFd2NgpRdk12UGlGbWgvLzlx'
    b'MlhGZ3ErQXcrRndPQnh1ZGZVTnQ2WkRra3d4T3RVQUFBQWxkRVZZZEdSaGRHVTZZM0psWVhS'
    b'bEFESXdNak10Ck1EY3RNalZVTURrNk5UWTZORE1yTURBNk1EQ2Z3YytpQUFBQUpYUkZXSFJr'
    b'WVhSbE9tMXZaR2xtZVFBeU1ESXpMVEEzTFRJMVZEQTUKT2pVMk9qUXpLekF3T2pBdzdweDNI'
    b'Z0FBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBpZD0iaW1hZ2U3MTk1IiAvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'IT_45')

IT_45 = b64_IT_45
index.append("IT_45")
index.append("Italy Emilia-Romagna")
catalog["IT_45"] = IT_45
catalog["Italy Emilia-Romagna"] = IT_45
country["Italy Emilia-Romagna"] = ('IT_45', '', 1)
lookup["IT_45"] = ('IT_45', '', 'Italy Emilia-Romagna', 1)
lookup["Italy Emilia-Romagna"] = ('IT_45', '', 'Italy Emilia-Romagna', 1)
details["IT_45"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_45"] = ('IT_45', 'Italy Emilia-Romagna', 1)
regional["Italy Emilia-Romagna"] = ('IT_45', 'Italy Emilia-Romagna', 1)
#----------------------------------------------------------------------
b64_IT_52 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTg1NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1R1c2Nhbnkuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczE1'
    b'ODYxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTU4NTki'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTU4NjMiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFEck9WNm5BQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFKCmdVbEVRVlI0'
    b'MnUzZFMyemI5aDNBY1pLaUtGR1VaT3RwNisyMzdDaFNFcnVKNVRoTjdTSnBMbWw2YW9xaUtK'
    b'QjJwL1hXblplaDZDN3QKRHUwQ2JFT1hiY0E2ck9paFFJQm1EZEEyYVoxWEU3dVNuZFJSTGR1'
    b'eVpldGxTNVpGaVpUNGtFUktPeGdvaWgyNkhkSWxVbjZmbzJ4RApBTC9tWC96OVNjTm9zOWxF'
    b'UUN2RDRCQkFRZ0FKQVNTRWhBQVNBa2dJSUNFa0JKQVFRRUlBQ1NFaGdJVGdrY0c1aTMrSG85'
    b'RFMwQlJoCmdxTUFDeW1BaEFBU1FrSUFDUUVrQkpBUUVvS1doUk5IeHVBb3REUVVudWFHaFJS'
    b'QVFnQUpJU0dBaEkrOVpyUFp4bGR0VDBUQ3I2NWQKQzRkQ2JUc1hQZ2tKVStsVUtCU2lpOFZU'
    b'cDA3dHZUSTdPeHVOUnUxMjI3UFR6eW9KQXViQ3g5Mzc3NzFYb0drZHBUR1l6QVJCNlBYNgph'
    b'MWV2MW1xMXcwZU84RHozNXB1L2dvWDBzZmJkL2ZzRm1rNmxrcEdscFhzTDgxYUxPUnFOTWd5'
    b'alVxdFdWbGI4L2dBc3BJKzFYQzczCjZlVlBWUVNCTkp1MVdvMlJwRXVYTGxGYVhibk1TcExr'
    b'Y0RoMmRuS1E4TEgycjh1WGVZNm50SlRGYXEyVUs5bGNUaEJFUXFWKzZ2QmgKaFFJL2ZmcjBn'
    b'UU1ISU9Fam14TlFGUDJ2MzhZd0pVcExGUXFGb1NFdnl6SnF0WXFtYVNXT256Ly9tLy9seHlI'
    b'aHp5Z2NEcU1vNm5hNwpEUWFEVXFuY2U3RlNxV2kxV2xFVTFXcjEzaXVycTdIaGtlSHQ3VzJq'
    b'd2VCd09IbzhQVnF0dG45Z29HMzZ0WERDUUNEd2p3OC9qQzR0CjJSME9CRUVvaXBKbGVXTmp3'
    b'K1B4UkJZWDNSN1Bmci9mNC9ISXNsd3FsbGlHeVdhems4ZU9kWFoyS3BWS3VsQmdXVmF2MTdk'
    b'SFFzVmIKYjczVmtyOTZPSTRneU1ibUpvYWgxV28xazA1bnM5bmQzZDFrS2preXNvK202WFE2'
    b'eVpTWWJEWXJpS0lreTd3ZzdPWjNYQzZYeVdRaQpOWnFWbFdXMzI5TWVDVnR2THVRNURrRlJG'
    b'RVZGVVV4c2JvWkNJWXFpcXJWYU9wVVNSSEZ3Y0RDUjJLVHBJczl6aHc0ZU1ocU5pdzhXCk1S'
    b'VFQ2YlFGdW9qamlyTXZublc2WEN6RFNKTGtIUjZHaEkvQTdPeHNQQjRYQmFIQ2NRMVpydFpx'
    b'Z3NCclNCSkZzVlFxU1dtMXpXWVQKUTdIWTJwb29DRlBUMDdKVWJ5SklPcFVPSEFnVUNvVjhQ'
    b'bi91M0dzbWt5a2VYejkyN09rMlNOaDZvMzB3R0RRWURGdmIyOTFkbG82TwpEclBKMU5uUlda'
    b'ZmtjcVZpTkprUkJMRmFySGFIYldDZzMyZ3lSU0lQTE5ZdUZNWE1Ga3MwdWt3UXFwTW5ud3VI'
    b'dzhWaU1iR1pLTE1zCm5JV1BUQ3FWK3ZLTEx3UlJWQ3FWQkVISXNvUTBtd29GempBbG1xWnhY'
    b'TG5QNTh2bGN1dHJhMksxZXVMRUNaWmhiSFpiTXBIc0h4alkKdDI5Zm85RzQ4ODAzTHJkN2ZI'
    b'd2NMbWNlalk2T2p0SFJVUXpEMW1JeGdlZFZoQXJGVUoxV2F6WmI5cTVSbDVhV3VITFo3bkQw'
    b'OWZhbQpra21qeWRTUTVWQW9WQlZGRkVWSVV0UFIyUmtPaDMwK0g0N2puMy8rT2N1eUZFWDlN'
    b'STNBV2ZoL25mRm52djQ2bTkzTzUzZHp1UnlHCllaNGVEMGxxVklReW1Vd1ZkbmVOWmhPdVVK'
    b'UVkxbTZ6WmJhMktJb0tCb01iRzNHSzBrcVNwRmFyVlFTUlNHemlPRzUzT0VaSHg0eEcKSTlG'
    b'Uzl5N2E2azdGOXZiMjlabVo2UEp5bzlIbzcrOHZsVW84enlrd1RCQ3JqWWFNb1NqSGNXeTVi'
    b'TFZZK3ZyNm5qNytETS96YzNPegplcDBlUVZGWmxoME9COGR4Rm92RjcvZVRKQWtKZjVZVGJt'
    b'NXVybDZyOVE4TTJPMzIvL2hxbzlIWTJ0b3FGWXVDSU55NmZidGNaakVNCjR6aE9vOUhnQ3J4'
    b'UUtCQXFaYlZhSHh6b001dXRtVXlhMGxKV2EvZkN3c0pUWTJNb2h1VnlPWS9IWTdQWjdpMHNT'
    b'SkowNHNRSmg5UFoKRXBzNHJiUTdjLzc4cjFtMnJGYXBCb2VHdkY3djhlUEg5MTdQWkRJZmZm'
    b'VFBlcjJPSUlpV290UnEwdS8zZDNkM204MW1TWkl1WGJyVQpiRFl4aFNLWHk5YnI5VzlEWVly'
    b'U3VsMU91OTdoOVhyMzFreURvZlBHamV1Ym14dFNYVHIzMm12ejRWQXFuY2FWeXU3dWJyaWNl'
    b'V2h1ClhMKyt2THhNYVNpTzQ5YlcxblE2M2NqSUNJN2o4L1B6djMzN2JUV3BIaG9ZUERRNkdn'
    b'eE83UFA1Q0lMUWtLU2FKRlVxbGMvbjArdjEKWlpadHlES3VKSHA3ZWc0ZFBKamYyWW5ITjJ3'
    b'Mm0xNnZKMG4xek16TTlQU3pyNy8rQzU3bkwxKytmUExrYzVGSVJLbFVPcDFPbUFzZgptblE2'
    b'dlpYSmFDaHljR2hJRklSWWJCVkZVWTdqZnZmdXV6Uk5OK1RHNGZIeFpyUEpNTXpxeWdxTzR5'
    b'V0dZUmltV3EyV1dWYW4wdzE1CnZkYXViZ1dHcFRPWkd6ZHZPbDJ1YWxYTTVuSjM3OXk1Y2VP'
    b'bTNlNllucDVHRU9UTW1UTW9nbHk1Y21WeWN0THI5Y0pvL3pDZGVlRUYKVWF5eWJPWFZWMS9s'
    b'ZWI2am8wT2xVbDM0L2Z2MWVrMlNKRUVVbTgxbWJIVTF1NzN0OW5pU2lRVFA4enF0dHRGb3BO'
    b'UHA3eU9SVERvdAppcUxENFRDYnpWeWxjdis3eFZLSlNhV1NDSXBhTGVaWFhubmxoemY2NVJ0'
    b'dlJLUFI2ek16S3BXcUpZNU1hM3dXRm92RldxMDJjZlRvCmc4VkZYS0V3R0kwdXAzTXRGaXNV'
    b'Q2thREVVSFFmQzRYalVhUFRrN2V1bm1UNC9tKzN0NzE5ZlZ3T096eGVMeGVyOGxzRmdTQjQv'
    b'bFUKS3FWU0VUYWJEVk5nTHBkVGxtV0wyZnppMmJON20rWjdQQjZQeStXeTJlMXpjM05UVTFP'
    b'UThPRzRkdTNxYm42WG9paHJsNVhTYXJWYQppcWFMOC9Qem1FSlJMQlU1anR2WjJibDY5VXRE'
    b'WitmVTFGUXVsK041M2g4SXlMSVVqUzdkdW5WVHI5Y1BEZ3c2N0hhQjV6R0ZvbGFyCjlmYjI1'
    b'WGQyam95UC8zQk45R1BkM2QxTFMwc1RFeE13VkR4TU5FM2Z2WHRuZUhpa3Y3K2ZaWm0vL2VX'
    b'dkdJNHJsY3JvMHZlUlNFU3YKMTlmcVVqQVlEQWFETHBlTHExUnVmM003RUFqRVZsZHBtdVk0'
    b'SHNjVlNvSlFxMG1qd2ZETTFGUi9mLzlQdjkwbm4zenkvUFBQdDhSbQpUY3VQOWhjdVhManky'
    b'V2M0am91aVFKS2twNmVucDZkbmFtcDY5dTVkaGlteGJGbXNpZ1JCeUxMc2RybUNFMGNuSmli'
    b'YTZaWTkwZ2FQClA3Mzg4c3NMQ3d2eCtIcUh2a09qSVhQWlhFTnU2SFc2QWwyUUpBbkg4ZUVl'
    b'NzM3Zi92R0ppVmJjLzN4U050aGtXVDUzN3B3b0NDUkoKbXN3bXFWNDNHQXdIRGh6Y1RDUmVl'
    b'dW1sbHBqdG5vaWg0cWUySnhTS0R6NzRvS3ZMV2l3VzgvbDhzVmo4OXR0UWZHTWpuOCszZlQr'
    b'awpiWjRqcFNqcUQzLzhVK1RCZzJ0ZmZiVWVpNjNHWXJ2NW5hT1R4NUFuUUZzOUNyemY3OS92'
    b'OTMvODhjZVpyUzJUeVJ3SUJKNkVoRzM0Ck54VWI4YmpkWVdkS3hYQW9KSXBpMnlkczFidjJQ'
    b'MEZKRVBmdTNhdHdYR0YzdDdQVElBcEN2VjdIY2Z6SFd6QndSZG9DNHZINHhZc1gKYVpvZUd4'
    b'dnorWHhTdlc1M09JYUdoaUJoSzRiOHM5WGE1WFE2clZiTDFOUTBmQmEybUw2K3ZuZmVlZGZw'
    b'ZEg1My96NkNvTWxFQXM3QwpWcFZLcFpyTnB0dnRob1FBRmxJQUNRRWtoSVFBRW9LSEM2L05o'
    b'ZUVvdFBaUUFmK3pDUlpTQUFrQkpJU0VBQklDU0FnZ0lTUUVyUXhICjFTbzRDaTBOYnZuQ1Fn'
    b'b2dJWUNFa0JCQVFnQUpBU1NFaEFBU0FrZ0lJQ0VrQkpBUVBEci9CcndpVzZtSEgxNklBQUFB'
    b'SlhSRldIUmsKWVhSbE9tTnlaV0YwWlFBeU1ESXpMVEF4TFRNeFZERXdPakl5T2pNMUt6QXdP'
    b'akF3QXRVaE1RQUFBQ1YwUlZoMFpHRjBaVHB0YjJScApabmtBTWpBeU15MHdNUzB6TVZReE1E'
    b'b3lNam96TlNzd01Eb3dNSE9JbVkwQUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAgaWQ9Imlt'
    b'YWdlMTU4NjUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'IT_52')

IT_52 = b64_IT_52
index.append("IT_52")
index.append("Italy Tuscany")
catalog["IT_52"] = IT_52
catalog["Italy Tuscany"] = IT_52
country["Italy Tuscany"] = ('IT_52', '', 1)
lookup["IT_52"] = ('IT_52', '', 'Italy Tuscany', 1)
lookup["Italy Tuscany"] = ('IT_52', '', 'Italy Tuscany', 1)
details["IT_52"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_52"] = ('IT_52', 'Italy Tuscany', 1)
regional["Italy Tuscany"] = ('IT_52', 'Italy Tuscany', 1)
#----------------------------------------------------------------------
b64_IT_55 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTk3NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1VtYnJpYS5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMTU5'
    b'ODEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxNTk3OSIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNTk4MyI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBWUFBQUJrVzhud0FBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQUoKajBsRVFWUjQy'
    b'dTJkZTJ4YlZ4M0h2OWYzK3RxTzQyZjhqbDlwa3JWcCtraVRObTA2K2xqU0RmNUFUSkJxQlNR'
    b'RUU2dFdKQkIvOEI5Qwptb1o0U0VnSUljRWZiRURGbnp5R2hpZ0MxdlUxdWpLMVRaTnNYY3BJ'
    b'MnNTUFBPdzBjV0luc1dQSDEvd1JlcTl2enkxQ3FCT0wvZnRJCi91T2MrL1B4OGMwbjU1eDdy'
    b'cys1bk9QYm4wd1dHdkptRU1SandyaG1XaFVLeG54ajNwaTMwZWtnSGhzU09CMmRCZUxEZ01R'
    b'aVNDeUMKeENKSUxJSWdzUWdTaXlDeENJTEVJa2dzZ3NRaUNCS0xJTEVJRW9zZ1NDeUN4Q0pJ'
    b'TElKNFBBZzErOFYwUFBZMnRYMms2emk2TUlFTgpxVXhpYlNXc29obC9QUHBkeEdKeHplTStu'
    b'dys2MTgraHRMQW81emxQZndrZnpNeW80dHBhVzdIOGs1OEJrcVNVL2JVWGNmZmVwQ3F1Ckl4'
    b'ckYvWisrSXFmNVJqTndhaEJ6YzNPYW54K0poTkY1N25sazFuTWsxbFlqazFuQytNUzQ1akZl'
    b'NEtINzAxOVFxQkxQT1Bnc0UrL3gKZUpENjdlOVIyZGhRTXIvNGVTWXU0bkJpN3RlL2s5T2l5'
    b'd1VNSEgzazUxdXRWaHBqRVFTSjlWK1N5K1hnK2ZTbmxHN3dxYU5ZTXhvMAo0ckx3Zk9aWnBR'
    b'czlkUks1RmJiN1dnSGdISGhLYWVsT0RTS1h5NUZZOWNiOC9Ed2dLQ01CVGhDUXVqL1B4S1ZT'
    b'S2VoRVVUbGhSaU5TCnFSUVRsNzQvRDA3Z2xhN1daTno4REJLcnZnZ0dnMWk2ZEVVWmoxMjlo'
    b'ckRIeHc2eVEyRXNYcmdrcHhmT1gwQWtGR2Jpd2dFL2xxNysKWFU0dlhyaUNZSE9ReEtvN3NT'
    b'dzI1RVpHNWJTVUw2QmhLZ2E5WHErMFlod0gxK29hMW1lVks3djFtVm00QzBWd0hDZm42ZlY2'
    b'bUNhbQpVRjVkVmJyUTBYY1J0RmhJckhwQ3I5ZERmUDhPS21WSmZSVjU2UXFhbTV2bHROdnR4'
    b'bXBWSy9TQTFhdlg0SEs1NUhRb0dNVFN4Y3ZxCklFbUMvdllkbGFna1ZvM0E4enhFVVdSZWtV'
    b'Z0V1UnRERUt4VzFTdDNjeGpSVUVpT2kwYWlXTDUrazRuTFhyK0psbWhVS1M4Y1J2YlcKQ0Z2'
    b'ZWpTRkVJaEhOT3ZBOFg5TmkxZlE4bHRmcndmN3VIaWJmMmVTRTlNd0oyUHNPTXNmTU5ydjhI'
    b'by9YZy94emcwRDFIQllBQ0FJYQpBczBRK00zVDU3VGFJSjUrbmhXN3NSR2U3ZHZoY2JtWlk5'
    b'VXRIb20xeFppWm1jWFFyU0VtdjJ2dlhwUisrR1BrcDJMTXNXaG5CNjROCjNRQUFITzQ3alBT'
    b'M1hvWlVMS3FiZWFNQjNqMmR1UGJPWmpjNWNQQVFKci81RWxPV01SeUMrS1B2WTJSMGxEbTJ2'
    b'NmVIdWtLQ0lMRUkKRW9zZ3NRaUN4Q0pJTElMRUlnZ1NpeUN4NnBjS0tpUVdRWkJZeFArZG1y'
    b'NVhhRzVvZ01mdDBjZzNZMk4zSi9STlR1YVlXUFVlazlFSQpTODgrVkI2K1YyZ3d3R1Ewd3VQ'
    b'WmpCTk5SbGg3OXJGbCtielFONWcxNjlCZ2FpQ3h0aXFpUVlUTnhqNTBRNmZUd2R5eEEzeUQr'
    b'by9MCkNRSTRvMUYrajQ3bllkbXpDeHRMeStxVDVyQ2pBc0JtdFQzNElKZzdkcUJTS3FuaWpP'
    b'RVFObmhlc3c2aVFTU3h0aXFQV3Y2VlNxZlEKWFNpb2xtc0JnT1BJazVpN040RzdkKzhDQVBM'
    b'NVBFTDNGNUI2N1hWVm5QZTVRWXpmR2NQczdDd0FRS3BJc01maXlQenRiVlZjNkt0bgpNUHJl'
    b'dTFoZVhtYnFZTFBSOHErYUk1dk5RampVeStRN254bEFNcEdRMHpPek03QU9IR2VsNkQrbVdv'
    b'aWFTQ1RnZUxxZmJaV09IdGFVCmlnYnZOY3djejhIVXVrM3BCbmtkMWpzN3NGNDFucElrQ2Rs'
    b'UUFFTFY0bExCYWtIRzUwYWxva3dWRkl0RmxQWjBncXY2VmFncEdrR0sKbzZ2Q3VtTXFOZ1hY'
    b'eDA4b3JkREJYaVNYbDlpNFpCTE8vbU5LcTNhaUg3SHBhU1l1c1pTQjdlQUJPZDMwaWFjUmk4'
    b'ZEpySHFENHpqbwpmVjZsMjNLN1ZDdHZxbHN0UThBdnB3MEJ2NnExZWtCRmttRHdLOHZIOUg0'
    b'L09IQWtWcjNSM055TTJWLzhTazZuLzNBT1VidURpV3RyCmJVUHkxYk55ZXZyVnMyaHRaWGV4'
    b'YVhGNVZJUDgyWitmUlV0TGxNUWlBT2orOTlQQmNYVDZTS3gvWDhrRlh2eXluUFovNFhPWVNM'
    b'TkwKNThjbnhoSDZ5bWs1SFR6ekFpWTBwakR1cGxQd2ZmYWtuQTZjZVFIM0ppZEpySHBETCtp'
    b'eFhyVktaMjNpSHZSNmRscVA1M25rcS9iQwpLa3pGb05OWUU3Z1pONlZjS1U3Vjc4Qzlyc1dL'
    b'Uk1KWU9IOVJUbWV2MzBEUXdzNlFoLzBCTEY1K1MwNHZYTHlNU0NEQXhBWHREbVNICmh1WDAv'
    b'VC8vRlpGd21NU3FON3pGRGVRbmxSYW1VcGFndnowR1E5WE9NaHpId1JwTG9yeWk3TWxRenEz'
    b'QU5qT251b0lVUlJINmtkdW8KbEpWdEh3dkphWGdsYXJIcUNwdlZpdlczMzJIeUY5NTRFOEZR'
    b'U0U3N2ZEN2txbHFyQitRdXZnV3ZWNW1xQ0lkQ1dEeC9nWWtyWHJrSwp1ODFlbDJMVjlMMUNo'
    b'OE9POXJaMkp0L244NEpQWitBN2RWSjlaU2NJOEd4cmc0N2IvSDhMaDBNb0RkOW00Z1M3RFRz'
    b'N2RzTFN1TG1iClRGdkxObVNqRVJpRHplcHhsN2tCZTNidnhxekdQcVIydTUzRTJxb1VpMFVz'
    b'YWN5bXU5MXVGTWZ1b0RBOXl4eXpGZ3JLL2IxS0NMblIKOXlBVjFiOWEwQmxFT0U0TkttVVgx'
    b'N0V5OWcrbXJJMXNGa0wvTWMwNitOZDlKTlpXSmIrVzE5eFZyemtRUU9uMm1PYmVEY1ZDSHVu'
    b'NQo5T2I3Q3dYa2hrYzE5MjR3RmdweTJjVjhIcm5oRWFhc1VqZ0VjVzFWc3c2MVByQ25DVktD'
    b'eEtvMUtoVVNpeUJJTElMRUlrZ3NnaUN4CkNCS0xJTEVJZ3NRaVNDeWk1cWpwZTRWK3Z4K0hE'
    b'L1V4K2M0bUo2UnZmQjFsamNlK05mcDg4bnM4SGpjczMzbEo4d0VDSm85SGpyTzcKM1dqLzNz'
    b'dE1XWHhqSTNUQm9PWStEZlFBZ1MxTUtwM0M4TWdJa3g4SmgrRjg0MDFrcmx4VjVlc2RkdGoy'
    b'N3NMTjRWc0FnSTRkSGVCKwo4eHJXL2ptaGlqUHZlQUpvamVMOU8yTUFnSjY5WGNpKzhrdVVG'
    b'ak9xT1B2SCtyRHN0R0Z5aXYzdCs3NnVmZFFWYmxYSzVUS0t4U0x6Cm1vckYwTml6RHh2WnJP'
    b'cGw2ZTVDUEptUTQrTHhPS3o3dTVrNDY0RWVUTVZqY3R4a0lnNUxkeGNiMTNzQThVUmNzdzVT'
    b'dVV4aTFScWwKVWdrYnUzWXlhN1pzeDQ1Z3J1b2hsNW1sREV3YXo5c3g5ZlVpazFGYXAxUXFC'
    b'Y3VSSjlWQkhBZXBldy95K1R3TjN1dUo1RW9PamJzNwpsUk1oaXNodmkyRGpvZkhVb3QwQzBh'
    b'dnNieVY2M0Zob05LdGlLcFVLc3VGbTZFeEdaYXpXdVJPcHRUVzZLcXczRXNrRUhNZVBLcTFW'
    b'CjMwRk1MeTZ5QWs3UHdISHNpREx3N3orT3hIU1NMUytkVXUzZDRCdzRqa1F5UVdMVkc4VmlF'
    b'ZHpPN1lwWXZUMllTODFwWGdCWWUvZkwKYVd2dmZxUTFmaEU2bDByQjJxdUlaZWp1UWphYkpi'
    b'SHFFYWxxNFNrbmlwQWtkcjJXSkVtcWg0MURMend5anF0ZThDb0k5WHhxYVlLVQorSENvNlg4'
    b'cnUxMTcrWmM4d0hZNDVhVmQ1aWZhMFNJS0tEMjBqeWdBR0J1dGNwd3BHRVM3VGZzaDR1WUtw'
    b'OFM1bXRCZWJ2K1BkYXRsCk9OTVBCcGJ5RFhsYnJYMHhudE9oeTlYK2thN2p5UDF4bEN1MXQx'
    b'emF0R1phcnRrV3ExeVJNRFQvQWZWSk5NWWlTQ3lDSUxFSUVvc2cKc1FpQ3hDSklMSUxFSWdn'
    b'U2l5Q3hDQktMSUVnc2dzUWlTQ3lDSUxFSUVvc2dzUWppWVFSandiUUNIU3AwS29qSGhiRmdX'
    b'djBYWVZ4SApIV052dFZVQUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNakl0TURRdE1q'
    b'SlVNVE02TURJNk5UY3JNREE2TURBeFQzcGJBQUFBCkpYUkZXSFJrWVhSbE9tMXZaR2xtZVFB'
    b'eU1ESXlMVEEwTFRJeVZERXpPakF5T2pVM0t6QXdPakF3UUJMQzV3QUFBQUJKUlU1RXJrSmcK'
    b'Z2c9PQoiCiAgICAgICBpZD0iaW1hZ2UxNTk4NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_55')

IT_55 = b64_IT_55
index.append("IT_55")
index.append("Italy Umbria")
catalog["IT_55"] = IT_55
catalog["Italy Umbria"] = IT_55
country["Italy Umbria"] = ('IT_55', '', 1)
lookup["IT_55"] = ('IT_55', '', 'Italy Umbria', 1)
lookup["Italy Umbria"] = ('IT_55', '', 'Italy Umbria', 1)
details["IT_55"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_55"] = ('IT_55', 'Italy Umbria', 1)
regional["Italy Umbria"] = ('IT_55', 'Italy Umbria', 1)
#----------------------------------------------------------------------
b64_IT_57 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDI2MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01hcmNoZS5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMTAy'
    b'NjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxMDI2NCIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMDI2OCI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUM4VkJNVkVYLy8vL0EyODREYnpxUndLbGUKbzRHcno3MTl0'
    b'Sm1MdmFXNTE4amc0T0JTVWxJY0hCd1VGQlFvS0NpQWdJQ0RnNE1CQVFFQUFBQVJFUkhaMmRt'
    b'MXRiVWVIaDRFQkFRLwpQei9yNit1WW1KZ1FFQkJuWjJlRmhZVkdSa1lDQWdJTEN3dno4L09D'
    b'Z29JSUNBZ0pDUWt2THkvOS9mM1IwZEVGQlFWUlVWRWZIeDhHCmNUeXoxTVNJaUlqeDhmRjVl'
    b'WGtLQ2dxR2hvYk16TXdMZEVDcXpyMndzTER0N2UwV2VrbkYzdEdMaTRzYUdocm82T2lVbEpS'
    b'b2FHZ20KZzFYWjZ1Sm1abVlURXhQcDZlbHNiR3pnN2VmczlQRDcrL3YzOS9lK3ZyNE5EUTJW'
    b'bFpYMTlmVW1KaVlHQmdaTlRVMXBhV2t5TWpJagpJeU9YbDVmbTV1WU1EQXplM3Q2N3U3dHFh'
    b'bW90TFMwZ0lDQTdPenVlbnA0VkZSWHkrUFhONHRqbzh1M2s1T1MzdDdlYW1wclQwOU9iCm01'
    b'czNOemNTRWhLcXFxb1lHQmk2dXJxdXJxNnJxNnNYRnhjT0RnNXpjM01kSFIyb3FLakR3OE90'
    b'cmEzQndjRlhWMWRpWW1KY1hGeVIKa1pGM2QzY0hCd2M0T0RoT1RrNWRYVjNCMjg2Q3VKNmdv'
    b'S0ExTlRXdjBjQ1N3YXJMNGRaMnNaUkNRa0l3TUREdjcrK2h5YmFkeDdQVwo2TjlYbjN4a1pH'
    b'UURBd05VVkZRaUlpS0J0NXp0OWZFdmlGMXhjWEZib1g4WGVrbnc5L01pZ1ZMbjhleEFrbXEw'
    b'MU1URnhjVlFVRkFxCktpb2tKQ1IxZFhYZDdPVVZlVWhocFlNUER3OFdGaGF5c3JLSnZLTlNu'
    b'SGkrMnN3UWRrUlZWVlhQejgvSHg4ZisvdjR1aUZ6Ny9md2EKZkV5TXZhWDUrZmxaV1ZtMjFj'
    b'WUZjRHppNytsd3JZOGNmVTBwS1Nsd2NIRDkvdjA0aldSRGxHelY1OTlQVDAvSXlNaWZ5TFJV'
    b'blhuago3K2tyaGxuVDV0d0hjVDMzK3ZrN2oyWnpyNUUyakdMeitQYjgvZjFIbG04bmcxWTVq'
    b'bVQ1L1BwWW9Id1JkMFhiNitQTzQ5Z0tjejhxCmhWalU1dDNtOGV5b3pidWl5cllFY0RzT2RV'
    b'SWJmVTE0c3BVeWlsK3kwOFBIMzlNdGgxcmU3T2JwOCs2YXhiQThrR2RxcW9vUGRrTWwKZ2xS'
    b'YW9YNkJ0NTJieHJHZXlMT0l1NkppcFlUWTZlRXhpbDRlZmsveDkvUUljajd1OWZLWXhLK3Qw'
    b'TDlPbW5VVWVVY29oRmR1ckkybwpNbkM5QUFBQUFXSkxSMFFBaUFVZFNBQUFBQWQwU1UxRkIr'
    b'WU1HZ1lXQjNEc1ZBTUFBQVFGU1VSQlZHamU3ZGw1WEJWVkZBZndVL1FpCnlXVE9DNTZnOEtp'
    b'UUFHTVZhSEVqRVNvTHpLQ05lSUZKUlVrN0pLVzBFRXFGVmxpbVZHWlNXUkJnVmtTSmFhbHBD'
    b'NVMycDZXdFJodFIKYVl2KzFUMTM1aTN6M3NPd1ArNU1IKy92bi9lNWM4N25jNzZmWWQ1OU13'
    b'eUFqSXlNakl5TWpJeU1qTXhCa2tNT1BjQUVTSlprL2Y5WgpoMWtHbGNNRnN3SUgxM3VFWkVu'
    b'V2YySU5DVHB5NkZIRHpNWUtWcEJpUGRxN0l5UlVRZHZ3TUdOWTRZZ2pSa1pFMmpIcUdIM0Rz'
    b'U3IzCnVDR0dzS0p4VkF4YkhoK0xjYnA2TUdxSkY4NGFmUUlrb0QyUnI1TXcyYk9jZ3E2a0Nt'
    b'YU5TWU4wQlVQVmRRWmlqTHVhNEZaaHNGalcKaVNmQnllejZPVVZkajBWMEY4ZDVxSEM4VU5h'
    b'RWlaQ0plQ29xay9nNkMrMXVsV0lZYTNJMnhDR095bUhYOUdsc2VicUNaemhMVTNRcQpzU3c0'
    b'OHl3MlVpRkJidDdVczlubk5LMXdqbDRsbHBVL1ZEKzh3TW55Vm9sbEpaNnJSc0h6enIvZ3dz'
    b'S0xpalJXdUxkS0xNdHhNVXN4CmdJSWx0SXhFdEU5bm41ZjRxQVIvRTdWZFhtWE5RSXdtVjZt'
    b'dnlraldwUmdhWm1XdWVEUVZLeFpMSWVNeXRGOWVaaWJXRlh3dnBmTjEKWlptSldDbFlCQU82'
    b'akdPTjFIWUhjczBzSjB2c1ZTWmdYWTNYYVBjUjdQcTZscDB2MjNXaEptQk5jZjRnenFEemRY'
    b'Mlo3UVl3QTZzRQpjYXo2STEzQnoxY3FtSUlGVnF5a1p5QjJUM0VqbmE4UWs3Q3lNRGNSWmls'
    b'VmVTNlhLVmc1TitITlVJaFlOUnR4RG5jWnhLcW1VYmU0CmZxcHZSYXlBMnp4Y1JSNnMyNm0z'
    b'UmdqckRocFY2MkxCWE1SNWRTNVhyRzQ3dlpONjd4TEN1cHRHMWJ0Wjh4bGd3VDMzcXE1b2Rz'
    b'dnEKd2JxUGV0T0VzQnBvMUVKUFZrR3l5cUFQMi8yZTE5WUQxRnN0NWw1K0VUMi9QdWpCbXBa'
    b'VHBWMVExb282M1RkeE1iR1dpR0UxMHF5SAp3STRQOCtVanVKU2VPMlltUktUbjAvcFJGMnZa'
    b'WTlTNVhJd0srRDlFbStCeHZwRUNQSUZCdW5La2kvWGtDdXA4U2hEcmFSclc3S2hrCjl3eHMx'
    b'WUw0aks3YzZsUkZ0YldMMng4QVZqNUwwMVk5eHg3TXlwZXl5L3g1cjNxTHFsTFNYNkMramhj'
    b'RnNhQ1R4cjNreUhpWlQ4LzAKcWErMnNlTWpRcnJXVU44cm9sU3d0a1BiVVZzejF5Vk44dE9R'
    b'a3o3clZZRFgrTXNDaXpBV3JPZC9uWC9aanpZc3A2Nk5YZUpZcjIraQppWXVMOTlleitRM1JK'
    b'd3ZnVFQ3eXJiY0g3dWl1NXkwOUlsWGdlSWNQZmJkaG9JWXRXM25EZSs4TFpjRUhIL0t4SDMz'
    b'c3YveEpvL3B5CjdGTVFuRzNiK2R6UEFycjlGQzJmcTZvZElEeXJ0TGVGTzc5bzg2cDgyYU9W'
    b'bXRyRXM2Q21RNXYrVmVEWDdxUGZmTHZMK1hyenUyNHcKSW1tOXJoZXMzLy93NDA4V3k4OTl2'
    b'eXpjN2p3MHVnOE1Tdit2QTc4Si9xMGFETXZLZ0diL3FFMmR2NE9SV1ZMYjY0dmEzZFFQUm1m'
    b'UApIN3M2ZEtqMkZSdkFGTW4rcy9hdmpZdkc3UDU3YjgrK2JTWXh5Y2pJeU1qSXlNakl5TWdZ'
    b'a1g4QS9VTCt3cFRqZHZzQUFBQWxkRVZZCmRHUmhkR1U2WTNKbFlYUmxBREl3TWpJdE1USXRN'
    b'alpVTURZNk1qSTZNRGNyTURBNk1EQ05hZU5KQUFBQUpYUkZXSFJrWVhSbE9tMXYKWkdsbWVR'
    b'QXlNREl5TFRFeUxUSTJWREEyT2pJeU9qQTNLekF3T2pBdy9EUmI5UUFBQUFCSlJVNUVya0pn'
    b'Z2c9PQoiCiAgICAgICBpZD0iaW1hZ2UxMDI3MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_57')

IT_57 = b64_IT_57
index.append("IT_57")
index.append("Italy Marche")
catalog["IT_57"] = IT_57
catalog["Italy Marche"] = IT_57
country["Italy Marche"] = ('IT_57', '', 1)
lookup["IT_57"] = ('IT_57', '', 'Italy Marche', 1)
lookup["Italy Marche"] = ('IT_57', '', 'Italy Marche', 1)
details["IT_57"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_57"] = ('IT_57', 'Italy Marche', 1)
regional["Italy Marche"] = ('IT_57', 'Italy Marche', 1)
#----------------------------------------------------------------------
b64_IT_62 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5NzM3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfTGF6aW8uc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2NhcGU9'
    b'Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHhtbG5z'
    b'OnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9k'
    b'aS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsi'
    b'CiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3ZnPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczk3NDEi'
    b'IC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc5NzM5IgogICAg'
    b'IHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBi'
    b'b3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAgICBp'
    b'bmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9h'
    b'cmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlu'
    b'a3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzk3NDMiPgogICAgPGltYWdlCiAgICAg'
    b'ICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFzcGVj'
    b'dFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1'
    b'YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3'
    b'MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFEck9WNm5BQUFBQkdkQlRVRUFBTEdQ'
    b'Qy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZt'
    b'QUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFsCm1VbEVRVlI0MnUyZGQz'
    b'd1ZSZGZIZjdQbDlwNU9Ha21vU2VndE5LVTNLMklGR3lqRkN0WUg5YkZnd1E2Q2oxMFVzVk1F'
    b'S1VhS2lJTFMKSVJBSU5hVFhtM3RUYnIrN08vUCtjVU9BVUJRZlh3dzhPWi84a1R0N2RtWjJ2'
    b'M3ZPekptWm5TWFg1empRTEJlemNNMjNvQmxoc3pRagpiSlptaFAvaklqVE5hcVVGdHRidzRl'
    b'VkNnZ0x4OUtNaUM4VEt1ZUZLZVpHUVVzbkhNM0tHQjFGTFBiSHlVUk4xRm9qdEhIek1HVXN4'
    b'CjBKb0U2YkRBZ3ZsaSt6bys3SXc2VnNXZUtPZnNVVi9HUUpvUm5vZU14V3V4dmx5SDNHS2Q2'
    b'dVpNL2UwTjZRVHNGdGNidmVRMVZxRkMKemZ2Y1BvdGRqdjFPZTg4MnpmQUdIUlVMVEtpYmtj'
    b'NSt0d2hWQWkrNVBPWXlKV21CL3Q5SFZSMGFkTXlLWTZMcjN5a2syeXc0Q0dGMQpIbHMrYmYr'
    b'eFlZWmRpR3ZRaVpXUDN1VitQbzQ3WXVTZHQ2cjJLNlNKM2l2U05JT0taNVJiMDloV0FJR0Fi'
    b'Z1c3YTVIaHdWRDZoTG9aCmc4VnZCRkUrV2RubHM4NFRuOXVzR1JWaS9Gak5sSzY2bnduSFRt'
    b'Z3cyRDF4THhrK0tST1NRa1k4bythV0ZFUDJLWGJGVU9ScTg2ejEKYXc4eEFiQlErN00xdDdV'
    b'dzVZWU8zc0lmcElSdmJndi9pcWpWM3I3eUNoNXl5S2YxWXFzYjhRTmcxRlpmNmZzazlIOEgv'
    b'KzhkaE45UAo0UWVBSU1KUWZMdDdadWpYVlo1NXlkcnN4bjZSSU41dytHYlhyTkN2VzEydnRq'
    b'RG1OcmVGZjEwaVBDVkVxc2NRSVpjOTRIdzBDSTJaClZsbW9uY2pzZFAwNDZlaTl6dWtBRXVV'
    b'RGFzNkh3Qm55YkMzdERlbWtTbHM1Z1oyeDNPN1NUMnJaRDZDRHRQbmtnb2lOTlZtRVRkU1IK'
    b'Zmw2WHJsYjhUYWMrNDh6N0pVN2RiSVhuSVpKT3BUckpsRHd1dW1lTGxOQ0tqMHM2YTRXUEha'
    b'RHQ1VXJuREpWYWUrYXVJMlBJMlNVRgovS3hUaG9vL1M3dFc3YUE1dTZUVzZVSmt6Q2thVGJZ'
    b'NzJuUVJjcFNHbW1uR3NQdjM0THBsUHArSEVZSXVmVlJEUm11MXVsTnVxS3VXClpuN3JPNUFs'
    b'QWZoOWJXREVqZHIyblJ1SElwVmx5cXF2ZklXNU1vQ3Q2d05Yak5VbXBKeHk3WXFDeld2OXYy'
    b'WUdKSW45dkJ5OWgyb3UKRzZrV1JkTFFFMjRPN2M5UFNrbFM2QjlubGJKNnNjL25ZU0djdTM0'
    b'TDd0b1ViS1M4K2FkQWlCK0F1aHE2L0hPdng5MzRqcTliVnM4dgpoSFA1QWgranB5Z1U1OGti'
    b'VnZrbGlZVncvcmJhZjJqUGlYNVRrKzJPQXVCVDcvdFhFNnhXWDZ5SVJBa0FuWjdyM0Z0Vlcw'
    b'M3RaZFJvCjVxNjVUZGV0bjZxUmNrcDdzVVdDVUhoVUR2aFo2dzdDdVBzTVJsUGpSek85bThw'
    b'bzRRcU95SlNpVzEvVkRaUDBnbmlLS1Z0c1hGb1AKMFY1R2F4dzBMSUsvL201OTI0NG5USGt4'
    b'OThBWkJ4Q2F1elBuaUF2SHBiRnRKNmM0N2RSa0lZM3UreW5OWjVDNVhjd2FkcTRiN2ZNeQpX'
    b'V0pHODFsMUdJUFRybGpEZWU1VWxhWWNGemJSdHREbXRqUDVsTHRvVlhId25xdEZFZ0NMQUZa'
    b'N3JtdzFJVTduMUxHcE9iaE9LeWlzCk9TNDhUMWtoM0JXTndxWlRIOWFFeDBCSTg2ejl4UzdO'
    b'azAzTkNKdWxHV0d6TkNOc1J0Z3NGN2tJRjJXbFdYQmM4VE94L2tOdTN2cGYKWnFWVGFoMUM5'
    b'SUxFMXdPY3JobmhoZU4zLzdIeG5XdldjcUJiYWtobDRLL1BJZGhFMXRWS0FZUzdEc3hLWDNt'
    b'UlVyekk0a0tlU1E4Ywp1ek85ZXYzMStYTnVzMzUvblhuTnVMMWladVZmR2ZycVlxSXJ1L3Fk'
    b'TW5ZRXlVZ0RDdFZwczlKWCtYaERjMXQ0SWZoZGwvLzJPbGZ2CkNVVXp2NnNkOW1WSGFXU2s4'
    b'aGY0WlhZUDFDckk5SkRTSUphN2tPRGYvL0QrSzdTS3V4bmgvNlAvYk9DMzN0VUxnTUs0djBh'
    b'eGw0WCsKMEQxWTQ5V3M5OWF2N3JCTFdPNUdvbS8vby9zdVBvb1hoeU1OdFg5cE5UK1B5WnNi'
    b'NG5mQ05BbWRuL0R2NjYxcmc3MFdLTkVqL3RpVQpuZHVGVGRkbGw4YnNyVFFIVyt6MFVnQmdE'
    b'SVFnM0tHOW9qVXRVYmVlbmI3eUl2S28zRVhFNzdwampmbUZiUEhPd2hjWFZ3OVZiYjNEClhM'
    b'UFJxcmVjNDgvaU95QnVHcE5kR2pObDJXU0YxVjg3cFNqT1FuVVo3RjV1VXNsTDBmN2NoL1pk'
    b'ZVJIWkl0ZjArVDJRVzgvdlozZXYKV09Yb2RjRjNNZ0xMT3lpYkdsRmNWRDAwK012MXRHVEYy'
    b'YkppVlp2OWE0ZnZLbzZidkhTS1Q2cWZOMllNWmRsZ2xZellHUmdPK3BOSAo1WDl5Y1ZFVW1q'
    b'Ni8xTnA2ZnRmU3owYkw3eDF5UjZVUityNzFnMGEyT0w3d0JUQjJ3OCtqNVp3aDFKSFkrRkUx'
    b'VmZEcG1UdkxrdTVmCmViZGZGZ0ZBa2dHNFMrRXJaV0VHcUtKSmFMMVZscmZkeUx4UE01UEdQ'
    b'N1R2eW92Q293cE5tdC9STzFQck5seDNiTzZtdW82VFhBOE0KcyszMitmMXA0WFczMGJYMHRP'
    b'WHhDdVBHRjcwSXhtNW90OW96aDBxN1RzcXFOWFQvNG5hV3RycC8xYVI2ZmdEMWVnQUV5cGxH'
    b'QUdlRApMaElvcnZkSmUzeHRMeUtLWE5Qbjk3TzcxeERmL0pIR2pYVTE3cDZ0Y013YjJaN3Rp'
    b'Rk1PQ3l4d0JvckZMeTJxSGE2ZnlvbGRUK0czCnE3TFYvYXNtTi9BREVKcVkxNFNUc0ZRaUpo'
    b'SktvUlpWeDI4S2RaTGtrWG1mWGhRZWxXdksvRVlmZS90bmR5OEFmZFZiU3oyNnppM0oKaHdV'
    b'RFhoWC9FeXZhdjArODl3bjI4Q2oydFZrcUJUQ2F6Ui9BVnB4TzhhejhBQUNCYXFoTVlBYVVi'
    b'bUhWUitzWGkvS0UzZDlOdlhScwpsSjIxcktlWTNhUXBjazJSWCs0ZElYNGIzRDFEaVFlVnRs'
    b'bmlvT25IN3ByRHZUeGU4M0ZkbGFPVjJTbFJqcThyN3M1dnNiR0tPOFgzCnJsWG1uV3lMQzJ0'
    b'SEdLWnkraWZKem9yRy9CS05SNjVKWGloeXN0b0t6b0R5M2N6SVFaQ1lXakFPRHF0WmMyZUxP'
    b'VGVsTHM1MjEwbEMKeUtOR0IzSWZPbWU4U0JvdGFMekFJeDRYZmhGaVpMREF3MXZPZHZSeXg5'
    b'ZFhWcjd6ZXVWZG56bXZiVWpjSi9USjR6dVdxTnBIYytXSwpGQnhsM2loNVBlUGFIRGFLQWJY'
    b'aThsR3hvL3g3Z3NhK0pkREx5Y2NBWUNCMnhYWnIyQXFlWTdNM1gzMjRLaFpBeDdEZnEveFJE'
    b'SHovCnVNMlIrc3BJUTUzWDRxN01nYnNDRVdFUVd4TUxJcWVNblh5b29QcTNZbm42QmsrUWNn'
    b'QXE1SEFQTmR4cVdCcmtOUWNOZlJyVmRveHoKMXNqYVQ4WjYzbEJKM2tQYW52OFRWaGdmT1BC'
    b'QzNnaUJCYy9hOVNlTUF2K0svSGlzZFZWRElnWHZKSkVCcGgydFhwSW01SWdxMVFldQpDY3ZM'
    b'TzYveFhSNm5jZTZuWFovbFAxU0pYQ1JmR2RMdnJkdXpNdWtlT1FmTEhRTmZIYlpnUUZJMmdB'
    b'UjlscHIzOW9uNVJjdFhmNW85CndlRTJBUkI0Rm1hQ041eG85QUNqRnFNdXhtYmNlNlNnaTlr'
    b'YnltcUljZk1yTWE5TGpJQTF2bGNtdVdxazlGVnY3Y1pvWFZWbi95OHEKNnIvMEVXb1YxMFBs'
    b'azdRbUxzNS84QndEUmd4a1hqSC9jZnpUSjFNRTRPWE5id2IvUFUrWityNXo3RHA1Wkkycy85'
    b'dzlicW1qdjRvRQpMOGRxeHFzUEl5M0U3NGZreWR4QnlmZW04c0RSSnhmVkRaODE4cE1CU2Rt'
    b'MWNxdG4rN3g2YmRxMnhVZkhVWWdBcUFKQlQ4SXVJNHpBClZRdklDcy96eVMzQ1hybWx4OEJF'
    b'VllqZmtwYjNyNmtrZFZTZ3B5MEZWak9mU0NSUUJvV21pbnNlcnB4NDZTTWNWL1ZDbkxGU0l3'
    b'VFQKZlp2T3JmbklRZkdNRkFHNGVkc1JUVyszRVA1cDFkVSszcHlwdXJNU0xRWnIxcS94RC9V'
    b'UVN4OTlWZ00vRm9UQ3VMdUtYZ3hSRkRReAo3KzI2STdmSzB0NnloUkFLSU9pQ0pocjJYSGdP'
    b'TWxySUFOVFYxWEVjNTNRNmF3TktpTi9xQ3U3T2ZlTHA2MWZiK3JZKzRwaWlFbVR3CkhIUDdD'
    b'RmdVU2k1eGhBUXNOYkNGRUJDZVMvRm5uVnVaTVR4eVVKeFh4TTlMYUV4UllNR095cWFYNmUy'
    b'NVFtZVIrZE93NDNwdXdhLysKUHE5SXozY3hIRjJWTktXQm45dHN0b2xCaFpFUXhUZEhmSklV'
    b'S2UyclNHNWhLQ2RNQWFDeElPaUY2eGl6NlVIMUJJU1lUQ1lBVnF1MQpqMzdIZHkwZkRQR1R6'
    b'clFBdVk5blJZcjJtTUFwWUFBaFJNWHpURFlvMVpjeXdzaGdnVWx3TTBtR3dLbFk0QS8xR2NN'
    b'amg4UjgwOUI1CkNjK2NUTEcxc3ZzL3hnYzY4SHVmWXRPbTgwKzlZWjRleVZWOFFCL3ZvOCtx'
    b'NS9lR0VwVElsc21UUFo5Kyt1WTE0WThuRlFpeXY0R2kKU2h1NXJ1ZzZlbndYaHJvalRHVHdx'
    b'bUJKQWtjUUNBUnNOcHRVc3ZwRzZTR0h2dnZaK0FFNG9PNHBLeHdMeXRSUkI3VUlrQmlkZlV6'
    b'MQpXNWN5UWhYMThad2NDcWc1SnYrWlV4aERWdmg0c2MyVWVRblBqTE91RENVZTVUdlA5RXpm'
    b'elhxbUdndVROY1hmT0liUFZaN0tNT3hiCmxUU0ZPeUQ1M2xDWUJKR3htSW9LSlRJeTNNQlZL'
    b'b1lBcnd0NTFJVzFJOTRjOGNuQTVPeUdJdlRoeEpxQThIUkNDQWpoWkZsV1NuOVUKYmIrRlJR'
    b'L1BiZjJjZFBZWEFMWWFyOG9OdENZYWtUUHJtVGNBeGtCWjZEMzlTM2FBelNXRUJSV1ZubmVE'
    b'Z1NkL1BwQWlmSSszQVh5TQpad0I4V1gybFJOUS80cVlmY1JPODlWZFFiMzhISk4rYkNwT09C'
    b'My9MbHNuTGxtVk0rYjdFbU5nUUw5NWQvQUtBTjBkODhzaVBFd0RJClh2QmFhSk5PTE4zUWVu'
    b'Y0h0dHhMSTBjWUJpMWhPUnZQOVhpQkxEZE12TS8vcEU0ZEJBaHorKzE4N09xSThaZXNGUkt3'
    b'R2lIU1JZM2cKQ0NqMWtmTmFwVUw0SG05ejJxcytqbis2d1JaUHRFbW44dk5wdGRrOWVraWlX'
    b'TkdpUmM3MDZUL2VsM0pGV0RrQjdjYm5Hb2t2UkRGawppeTNEM1pSQUczMGlxeFlHWDNETHZV'
    b'RzVvMkh3RW5EaUg5U0owYXRkSDJpRlFIMG9aTkI0cUQ1SU5KY3N3b0UxWDdiemJpN2hVMEFJ'
    b'CkM4cFZZdng1UHdQbSs0UHJXQ09LSVg1OFRqMC9oZU5LWG50dDZMWnRoWTgrZWxoUllvWVBU'
    b'MDlQNjJEeWpZOHAzRDV6OUhzRHFCckIKQm9xRDJwZTJPY250SmFyUU43ckVzNXRwMUEvOUlU'
    b'OEFLZ1JzbklNUXNJQVVtakpPMGhXT3JwNTdhU0xrSVkrcS9manE2bmRXV3FkNApBaG9tS3k3'
    b'T090Vis3eVQ3WXlJTi9IbUszZ1U0bVdKZi9lNFFQKytzZXY5NTZMYmIrdHg3THdCRFdscVAy'
    b'bHJGNFFBdy9vcU02ZGQxCko0U01IZEg3M3BTcUJvLzZyWFBvUUNOTFVkWHp1OUxJQXJ1WS9K'
    b'WU0vS25GVkFHaTNjZjFBQUZraGFpRVVOUHQ0bXlYWmx1WTR0MFoKcGJhckpYK3B1bldsRWgx'
    b'RmkxTEVmUm1hVFdETVgyTmNZSHZtejJiRTRGMEFnSDA4NU9rMjZ2d0h3Ny9nVHVLWE8yaFEz'
    b'UFRwWldWbApWVlZWMnZidFM1OTl0cytZTVFEYUpFUkxrclIzNzE2THhmTGc4UFo1aXc0dXM4'
    b'Y29qTHVyOUJWR3lFM1cxVHU4cEp1VytYY2grQi9nCmZCWlN6UTk3dmxWbGRyeStsTlo0Q0pE'
    b'blQxb2JkZnVsYVlXZHZMOW9WRktreGpuSytXR1c1bkpWd09YbDZsMlljcjRWWVBBdWdMd1QK'
    b'MDZNK1ZwVUZmTWY1YmV6ZnYzaklrTFZmZmJWdjM3N1kyRmcxeDdVY002YStDRVZ4dTkyOFNw'
    b'T1RrL1Bsb21VWkp1ZGxRazY5TFphOAovS3VyYXk4RGs0K2ROejhBWHQ2MFREL1pKNmtBNWcy'
    b'cXZ6UGNHK1F1MGJhUVl4UUVoQ3Jkdkd0K3RkNXM1MXBzMHd5cjgycCtEUTViClpIbjBmSE1U'
    b'MjBCTVo5UUJJWmFwanErazZiOXg0MlZQUGFVUEJGb21KbFptWlJWT25HaUtydStveUxMODVK'
    b'd0ZjeGYvMHFaTjI1YkoKeVcvbHRmaFZUZzBkR216WTNOK3doMVpCa3d4VjU3OXlhYithYnR3'
    b'cVh3NkY1VWdkdHhpdnZtUkhad28wN2VVZ2dVSWpCTHRKc3ZOVQp1czR4KzMzanpMY2o1cDd2'
    b'WXl1MmhlRXh5SWRSK3hpVWZPZ25RZDJ2L3RDV2J0MW9XZG5HR1RPQ0V5YTRKMDh1TGlueCtY'
    b'eUJRS0NrCnBPVGhPNjliYUk5LzRLMkZhN05MT3BOaklmMWh4dCtXSmo1SWR5ZzFqMEU2SEdh'
    b'WXhxbTYvWldyK3lqaU5iK2YvOHI2QlA0aHVSQnQKNFY3ZFFFZU5KVktvTktsOUErb1dXb2xq'
    b'cmVudTdmcVI1MjEveC9tNVo0Tko4UDhHc1JqNlNRQkJZQ082N04vdnljdXpPcDBjWXo2dgpO'
    b'ems1V1JBRVFraDhmUHpDbjNiVXFxTXlNU3pTNDVRcEIvNEVQL2U3RUR0MzB6NzhJejM0c0dI'
    b'cUYrNjU1N0cvekxEYXo3eWNZWk54CmpCdW1XaUhpVWtibzVVMTVmR3FVcXBvRnBaYnlQaXJS'
    b'NzYwUE5FUlhmM1l6RUdtZjRURXdkejAvQU15QlFENllEL3BKQUlDTlBvM1AKVng0UnNmZkdH'
    b'MjArMzlidnYwL3QzMS9VNjVldjMycDNCUjZOY1M0c2l5Z2dNWTM1ZGV4aVhiT0dzOW1vYlhw'
    b'dzBXTERBejdHdGdNMwpuN3N1WnRrZUdTeTZYWHF0bW9XcjRUZlFHbzlnK2FjUVhxQzRjRUhF'
    b'OCtWZUd4VEZ4anNaNFVJN0d5YjU5Z3lzL2ZKUGRXTHNtMkIvClhENE1hUmVZQkJuWURsQUhp'
    b'QTJlenhGWUMvMGtxUHNEUUxUZGJqcHdJS3BORy92MzN4ZHQzWnB6Skg5eFZsVmlsR1YvTlZl'
    b'QW1KUDkKWnoyL2RlczRtMDArZE1nNWFJam5mUjkxRTlDM2FOSFNjd2YxenhTUG1WQTFmVGZ0'
    b'WStNY3R3Wm1nU1A5NnhhL1dubkZ0TXA3TGxtRQpkakYrcmY0Mkg5R1ptQk1jcDZKK2dRWHZx'
    b'WHlvclgvSEgvT3IzQ2l0SFNibnlDSDdxK0F4QjFnTTVEdkJoUUdzTWNXTTllc3JYbm9wCjdQ'
    b'RGg5aU5HOU9xUzdoZU5NMWNYL3VCUEJ6RGN0R2xaMGpSU0dldCtGMktYN3RhZmZ1SnNOamtu'
    b'eDNuNTVjeFJwbnVFOCtvMHExMTkKZ3h0dk9nZkZLS25BckhMRmlPV0xUUTl1a1FlSUxNQ0ov'
    b'QVRwbFFSVmdZOHpYTElJKzljdEpvUnQ1UVpUQ1lSakFndGU1WHczUVZkcQpVcXJPZldLNC82'
    b'QzBicmlVSFhTOVNaa0VXb01ZQy9vQS93YmlhbEVmbTRRb3JqbEJzZnZPblhKNCtQNnNyTnpj'
    b'WTNyRnZaTkxEZkZiCm1qaE5UTGhHTysydzRlbm5yR3ZYY2xhcm5KUGpIRFNJVlZmb0h1T2tW'
    b'dW9SK1IrTlBqYm5LK2ZJNE1hYndtdlBNS2taSVJVOVhuYTcKUWVYWHEvMy9xaGhmSXFUTVVi'
    b'OUdDYitIOVp3anZQeEIrT3VYWmx2WTE3WDBYdVZaZ1ZQV0NOZmtjTjFUNlVZRlFvWm5KVzht'
    b'dXNDNQpWb2IxdGRLK0pTOUoreFgzOGZGcjZnQWZodDZPZW5JbjlpZGs4SHdCb0w1ZERHeEVt'
    b'N1ZyZisvV3JiSjF0L1d1MkJDLzd4S21LanNaCk1kNHNDR3JEczg4Q2tBOGVkQTRaY2pLL2cz'
    b'V1I0T25Fd3VjQTNNSmV1RHFLWDE1eHltQk5WQ0F2VWwzRmN3cVQ1QWlycDFYZDdnbysKZnJ0'
    b'NnlIL0MzNytVMjhKa0tWdmdLUWlKWWlXdnhIOHBRVzFWS215Q2t3V2xVS040Tm43TE92dnBQ'
    b'dGw5MHZ3RGRZTFl6aHIxZTc0NApZWXVpTENldFdyWDJHR3BnSEc3YTlGMzhWTHBEY2YrSGV0'
    b'K1lEVmJmN2ZTKyt5NXpsT2tlNDZUV21oSDVINVc0TlUrcC93M0dLTGlKCmhjOTlYVDN5ODQ3'
    b'QjYyTk9DZmozNi91VittUEFjWkFwOVFadFVtbDBNSzlDYklsL1RpNkVGYTR5VFV4eTdFOGd1'
    b'WWFnWFdSQlVDWE8KZDhnazFJR3lzKzJxRk9MSEhZQjdGajE1YnBFNklMUkZEYkFlMEFKanpr'
    b'U3h3UllUTnU3ZTNNYzhQSHJUZC9GVDZVN0YvUzdFcmowcwpLMWVDRU9iM0U0M0c5UHBMZkt0'
    b'RmZuUGR5THdQdDN2VGIxUXRhTWtYaHZtTDdWd1NCVGV4Y0FZRDVxV3ZCRTVzM0NleW9KWjRR'
    b'QWc0ClFnamlkU1dWdm4yN1RVTUJxS2cveVovbEo0YVdnZXh0eGl0OXZQSFNRZWdVWXA2UCts'
    b'YXJ1UHE1djN1eFlJUWs2Q0xrUWtJSTJKa1IKRWlERXp6c0xqZWFHYVMwNE0vWUJGWUFNUUFZ'
    b'UlR0VTVpU0lSTWRDeWJYNzhVL1g4T25XMS92Z2paN0hJQnc5V0R4OXVmT3MxYU43eAptMTBo'
    b'ZmdBeWcxYzZCTXZOZVA5dHZBcUFncHRVT0lOVEF2UFMxM3BvdlRzVldKRGpHQWpBR0JINWFv'
    b'L1pLbFVVcTlzS0xQaHM4YlV0ClZma0JxaktJM2g0VnE5OW9NZi9TUVJnU0gyOWNhNzdqVitN'
    b'Tkx4YU1ORW9PeG9Fd0ZrRGozWklGSm5GZ1hBNjhzM0dHdVgwS2NPZ0gKaE1aa0ZDZUlEYXp5'
    b'ekxhb0c0OEY3QWw1TzNPL0M3RmJUK3ZxMVp6Rkl1L2Y3eHcwaU5WVVNydHZEYWFvUitaOUVP'
    b'SUhZTFJxNGZqdwpGZTRndDkzNTB4WU1CZ0Fsc0RUZjMwSERkekRJYXVvTHhialpRdThCbmxV'
    b'Y0NBanhTZW9Xd1NQRm12YURhcjVLMHVZTFVFUzRpYWd5CkI2b3VLVWQ2c2dRNDNZS0lHWGVY'
    b'UE9vMWFmV3NybEpzL0FyU0FVTWZIOU1TdlE4QzhFZkxNNWdUdkEyMDhnenRZbkFmMUVQQmNV'
    b'dysKQ0xGVFYydG1ac2orbkVPR3NOcEszZU44TUVVMUl1L0RIZDYwMEJtdDZKNjMybnlrRnhV'
    b'QXlZWVptNnEvbnVPNHZTMzVvbC9DZGoxUApna3pJTWcrdDc1UXFKYnhCWkI0WmhKaTRXcWNZ'
    b'bzZiZVB1NmxvcGt3bDBRTUdnQVNWQmZzbHY0RHE3a3JWUzA1MEU3dTlSeUhWZnE3CkJjaFgx'
    b'NzBmSnBmbXFUc0FjQW5oZTZ6RCtpcUwxZWxCZWVzWktJb2RJZTFGT1pBTHhLakJSMEVwT2sy'
    b'bk13eFRJZTJBZkFEYTBkQk4KZm94dk9VamV0ODg1Y0NDcnFkQSt6a3V0MUNQeVB0SzVjelBZ'
    b'VDlkb1Y3V1R0cnphOHNNNHZidklnWHc3N0xKMWVVWG5LM1JmSmNRZQpHbTRnY1ZyK3pUWkxE'
    b'aGt5UXBuWDhKSHRhallhakFyekJWeXlYb1hnaU1CWE50NmhVbEVvQ2tEc1h1c3E0OFFDVGZx'
    b'bFpvVVBsTjRUClJRdHJFYmJhTXY2SDhDbWpxK2ZRUUNETE1PaVpxckhKMnJ5QUpGWjVXdXpW'
    b'RDRnTkhDblVwczFNWGZVa3J0Qk9kL3RlQWZPZG1wRUMKajRBdlpaUUIxSW5lNldmaHR4UHU5'
    b'd0FGekE4TmVZVFYxanB2L0lEVlZtb2Y1NlVVOVlpOGo2cmRiRUdydDZqYkdXRUd6OEdvUWI0'
    b'ZApNcWYrdkhxRXpPczRiR2NSWlNQMEpGN0x2OWxtY1k2eDM0a2hYLzJBbDRVdkhpbWZFTXZ5'
    b'cllGeUVtWVVxQVRHV0swTXJkb1QwTHhqCm1aVmo2SHVwaGZZQTFwdkhocU84cDNIN0krNEhY'
    b'eTRZdHRsd3RSajBtaFdIUUNRQWFsNUtsSElBZEhPdmZyejQxa0pONnN6VVZYS3kKUVRzZFJI'
    b'dHFhMWdOcndVcHdETkFsenB3eG5QeEErRDlGdjRWakJiTVVIY3FiK0NYNVU2K1YvczJ2TTdF'
    b'Q1BnQzhQakJHRlFpLzNEaApJMXQ4SFRxcFZuZE95aDFoUEFPL2tKU29XNjh3VFZhOFFlaDFB'
    b'cE5CS1ZHSkxtWXE4c1Zta3g1SGROMHZwRmU3Y0k3VXJrcXNSa1NyCnVxMG1sZHNtVnNjbytY'
    b'WFUzTnU1ZEx0MkdKRWxNZUQrMHZ5VW03ZHFhTjBZMy9zdDNWay8yaWJ1dFE3dEt5OVdwNTNp'
    b'VVRrcmpEemEKT09vN1FtSW5TSHZQeXE5K2hIdy9pQXJhR3lCWlZZT1BmYnJMbDBxSmFBa1cz'
    b'cEc4NjNDRklQTFVva2R1bFZqSllxbzhMRVc5UkJWVwpNOExRbUovQWdqZFd2MUV1dGd6TlYv'
    b'ZW9XNVVhMkNyb2VLSVNpRVlGb0N3US9XakN6NXVOMTlBTCszV25DN29nL3pmVGRiUEQzaTN5'
    b'CnhqSUZlcmlqTEc2OTF0L0Z2YzdtUEZvWDFQTlVBbEFwSnZsNFl4ZlZqdHNxbnl2UXBwOXVp'
    b'dzNSdlFKSXA5cWY4U0dPVDduUk1GZUsKbGxrME8rWFA5QTNqMDZacitHQlBmZjBpMHBYazl0'
    b'RzdIeDlYTW5kRzJhVGxGZDFjMURnaFozSi8zVS9SMGJVampOenA5cGZoV2pHRworL1RXbXBr'
    b'QXdxVFNxNXp2RldnNzdLWVp1NzFkdDdwNnJnbGM5WGJrUDdEMjZSL296ampFMkY5TU4ybTlE'
    b'cVBrME1HbDVRTkdycTZXCmk0aVVDbXVGeUlPNkREOXZHRmp6bFZYdmpRbms1bkh0RCt0Nlps'
    b'dUg5cFVYYXpvRmxhMWdFaGdndHNHNkkxZ0ZIQU82ZFlTMHQ1NGYKbDNTRDBPOUxuTVVJdU9n'
    b'aGhQcUgrMSt4SzdhZDNqU0pxSFA1RGxWQy9GN1dZNW4vbXRiQnpSWmxneEJaUGRMRXhXdTUy'
    b'VzIrYmFFYwoweWdldXlyaCtNUE8rdnBYT0JDVnBSN3dkTjdvcFJFUGZ4Z3phNVBwK28ybTYz'
    b'ODNqZDVsR0ZZclJQNVBJQVNnRURITE1IaUQ4U2EzCnJPZURQaWlLaFZXTHNpL1Z2ZWwzMDdW'
    b'MVFrUVBWMmFVV0tFVzVmaWFySjlNdDlhSVVYdXR3L29HRjZrN0JwV3RZQzZvZXFBbUc0WEEK'
    b'RFlDaFBZZ0d4bWtoZmwvZ25FNnNFY1VUNmJLdmRYQmg2OFJqbzh4Y25JYjd1dVhMZyt1K0hF'
    b'R1c5UFJtbG5QeEphcTJBR3FFeUJqdgo0Y1RBZ1o2T1pTb05rM250WHUxbFRXSGIvSDkrNnlE'
    b'Q2FJUlVGQkVzNkZmN1hmZTZIeFpHVFJlSWNxZjhPcUZ5QU5xM2RMTjJHb2NEClNQRHRmeXBu'
    b'bEZqbzlzMkVaalM4WDlTZnJoc1AxUUN5WFU3NHdOOVBZWDlxUzcwYk5GbFhhUFpQTFhuaWc2'
    b'b2JBWWpCcWhGNFprREwKemNNTkpGN0R6MnJ6N1dUbjlHaWRIUXBsSEwrUW03SWsvSkhRaWQx'
    b'ZHE2ZFVQY3pUb05ZaU1NcW1HeGNWYURyODR3ai8rUjB2R09FcQpWWW1WcXNUOWhzdVdSangw'
    b'WC9FOVBzNVl5ZHVpeEVxTldobGM5MFVJWWFFMjdhWFVINTdDS08yVGJodzkwZjZKQTdEY3p0'
    b'MjV6eTdUCnBYK3l4Q1hBYzYyRk9TMW5BdmlvL01waDdKa0JTZlg4M21penBGemJpb0NHM3Yz'
    b'd3VraFJaTnVHUjIyd1kzNDVpWHMrYVdsczRLaU8KMWhWZXFNaXZ5VG5TYzRpSHQveHF1VGxT'
    b'S3V4UTk3Tm9FQ0RKUGtYN2svblcwTkZhTVhLWDdZcSswbUpOZUVEYUFMRXo5Tk93ckpJZgp2'
    b'MCt0bk9jbmxUWTRlVFdQNStOL2lmQ3RUNHphTjl4WXorK2dzYytNb3F2alRYYWlFaENRMUNa'
    b'QjdhNzV6WFFkQVp0WStyQk5LdU5FCmt1VGZlNWw3Y1MvUEQ5bmEvaTdCMW15RnB3MkNFbjVK'
    b'NUtOSHRWMytWWDZIWUJBMTlTKy8xRXVwcHMzTDdWYzhuVE5DTjhNclJ1TG4KYXY2elV1RXlt'
    b'L0lYQ3ZyRnliWFNDNU5TOHFxQ25GNFVYbXUzOUpBK1E4MThPczREbmdPbEFGeGU5VWJqYUI3'
    b'eS9VV1Rrd1BaVEJCagpUYzRVejJIQkpIbzh2RkZ4QUsyYUVaNVo5aGdITC9mZGM2M25BdzNx'
    b'R2gwcTFLYTlrUHJqMDJTa0NwNUJZY3FnTU9XL0xNdW80bDlyCnUvU1FQZ05BZ0dpcmFYZ1Vx'
    b'MlcrSURGb1hRN2ROdU9WRHhiZTNTNjR3MklPY0FKaEV1TUZCa3BWQWtzTTVCelM5V3BHZUpw'
    b'bmg1enMKMzVPdlN2OG04cWsyQmR2YmV6YnpURktJMklqaS9aMFBDU3p3dDVRb0U5WEord0VU'
    b'RHFBaHY4eHErTWduODYvWFU1ZEhaYk9wN1dBTQpIaTh4NmtDWndGT1QwaVEya1d4eUNCK3Ft'
    b'TnhUMkZoUW0vSzJkZllMQ2QrOWRhVFgxT0s3NThaOUpCUFZxVE1lMmdDMC95OE9RRHNnClNj'
    b'b1hTYkNtVHFzTjFKaEp0ZFhpVjJTd0FJT3NFSk1lalBrRGZINHdhWG5jL1UzaGpqVzUvVWpu'
    b'VkE1b29ha0FVRndYSVV1Y1c3QXEKbEJkbDMvd1dNL08wblM1TWtET2o2Sm8yeUpaOHRGUk1q'
    b'dEk2OU9vQUMwcEVvMkl5SlFJdlNWakc3bHdVOFhnVCtSeGVrN1BDUFh3LwpvLzhISnlJV1cr'
    b'N2ZZcmdLQUFFYlVQM2wvVVZUMU5SYm9Fa3ZWYmQyQzFZdmI5eGdHZmYvOFgxZFJyaDhWV3By'
    b'NXpiR2E2TGtRdDVICkdCU2kxMUpQc0NnUUd4QU1NaFBXUjQ5ck9wOHpiSXE3QWh0bGgxY3dL'
    b'NmM5WHVGU2Niei9RSXZBVVoxU3E2Sys3NkllKysvWGJhcVoKTHp4WVZLV0tEeEF0QUxOc0gx'
    b'VDl4V0RuWnd1am52alZjcFBJQWkwQ1I3cTUxNlQ3ZjlOUzE2eVllZmJ6ZnJuMWZ4TGhoWlJr'
    b'YjlhVQowZ2ZEZ2lWNnBRYUFVNHpKTmx6K1ZjeU1Xajc4WXJtRTVvL2ZYZlRTL01HZlpvVE4w'
    b'b3l3V1pvUi9xL0wzeE1YOW1EcmVyTk1ua2tCCm90SEE2MksyMzdsUiswa0dnRFlzYXhEOVZn'
    b'dFBnN0lQK3ZmNWwrdmpCSlFPb1Y4blkzOE53bFVzVUlQdytmelRBb0pYMFU5YXNod0cKa3NW'
    b'ZHRvR01BVUJBTDZQZmQyZnJBdENaNEdRZ0c3anJOcE5SQUNKUU1vck90N0dLMzdncnQ1RmhB'
    b'SGhJVjlPUEUzQjRLeGwybEhRYQpSZWVIc2ZLVEsvd1o5NVNUUklYK3Q3TEthOWlIVmxicGgy'
    b'NHRQKzRvR2s4QjltYXJUS3g2TlZjL1lhS0ZlNHJ5WkNPZG43a3hsVWdZCnlSYVltTU5Mak92'
    b'SUxia2tIWUNKT1VheCtRazQ0b1k1aWhXV0lXa2xQNkg0YngwYy8zdXNjRHNaWW1HVkdTenpl'
    b'Mjd5ZTl5cnlkajcKdEhKN0Y3WUJ3R0hTMlVQTUdTeHpGeGs0bTUvN0h2OUs1UEZQWlhkbDY5'
    b'K1VSNXJoZkoxNzcxM3V0Uy81eDF2aUFBQVpxaCs1V3pOWQpaZ3F5Ry9oTlU2YU5vNi9PNTU3'
    b'K0QvLzZUSDdlVGpKZ21qTDFEdm9TQUR0aUQ1SnVHU3p6ZnVXUmxzZ0JvRUJjeTkwU3pvcTNr'
    b'SkZWCmFIR0E5TXhnbVI1aW1zM1BuYzNQdGFLaWpwejRhbDQxaVR4RXVtYXdUSWxvVHVjSDRC'
    b'cjYwVWcyditHbkgvcFlIQTFsOVMzM1VBKzIKcmdQN0xaZDBMQ1ZKQmFSTkJzdXNoUzNFTDRv'
    b'VnZrcXZpVUx4RytTZGQ3bFhYK1EvQzBmcHk4cTFxV3hiVTNTazlQaU9PejdvOTVEKwpCS3c5'
    b'MjlIb0VBQS9kQXU1aDBQUC9qUmxXZ0NhK2R6VEV0UWhFbXZJMlBvaEVuQUEyUEdOZUFmUlJS'
    b'a3Njd04zZzRQVTcyT3hsaHRyCkozR2o2UHhXYkcrb2lDTFNXZzMvbzhwOVJsUURvSXlueDMw'
    b'TVBmVXl2K0llbDA5ZGJSM2FXSjNpREpQK2JkbXVlSFlraGhXa3NIME4KeXA5eTlYdmwzTXBl'
    b'NVNFdDVhYTRZRzJvY01QMVRxWlAybGpGVWpJbHRENURnbW94OTRDS0JTWXJUeERRSm9md2xH'
    b'RVVWZ2JnTU9seQorcUgrYk5sQjBnMUFQL2E5R3I3ZFpHQUFKemE5K0oyNzhvd1o5bU1yQUJ3'
    b'bEhVNjY2ZHdCMGgxQWQ3YnV1Q2NZdXBZYkY4R0tweXJUCk9IYldHYWlHQ3Z4SkdjeStXY0xk'
    b'QjZBdlc5NlFHR29qVXRtMmJ2UW5PNG43a1R2RGprRldWcG5HdGtwUUY1SzJEWW1IU0ZjWnFt'
    b'Z1UKeHJIY0pvcHdNRjA0VVhrbUhadmY1MmZ1SUlOUFBqU01mdjZ3OGtELzR6Y2lkQTBPRXZO'
    b'bnNvMWloUURjTUorY1dJc0lBQloyNGdXVQpUN21uY2tpdkR1ejNzZlNOMHpOSlo1c2ZVaDY4'
    b'V1psOUhrTjl6R2xBWFNaM3V3UlZIN3J5NUNlRGdONUdad0w0aWp3aTRReER0VkVvCkJPQW01'
    b'a2JtWG9zd0FCYllteWpDUStqYWx5MVhzVUFXR2REbzBCcnV0bG44MjZVczZXUlgyVEFwMzVj'
    b'dW42NU1mSkpPdUpuT092MjkKVVptSUFMVHNsRmVDUmVadnhGV0JPSWQveTBtaXJtSWY5MmFO'
    b'ZDRUZVIzclA1dWR1SjBQKy9PVU1aSXNyRU4rSzdTMGlyYXl3cDJIcgpDV3VteTVQWi9xT2s0'
    b'MmJ1aXJPMExNTHBkUVlna2lBQUR5eE5GR0V4MTJvSmQ1OGV0WGNvTDU1UjRRditYMnI0QkFT'
    b'UGNoMEF4T0ZJCktQMDM3bW9Wdkozb3hwL0o5YWNQY09lVDlnQ2lqL2VEUWhLR2NnRDd1Vk0r'
    b'TFZDRDhGbmNPeExVNCtrTFo2c0FBZFV4MXptdVFrVFEKQ2pzQnpXQ1p4VWlKWklXSFNBOEEv'
    b'ZG4zSVFVVkM5eE1ad0g0bkhzaTFJNDJxaHVBSXRKYWhrb0Ryd1VuL0lTS0JZeXMyZ1ZyQVdu'
    b'ZApCQkhXcjBESzVPNG9JNG05MlErZDJLL0hmYzZKeFVreVZHT1YxN1hNdlpHTUxrZENSL3Bi'
    b'UER0eXdqa2Q3MWtjVDZnLzhRY3luaEwrCk1ycXNvUmVnaGFjRCsrMHc2WkpGTGc4VjBWREtF'
    b'ZEpwSHYrc2lNYmZVUWdweUZCbHNNeFViRHZISlF5aWkxcXkvUjNacGx6UytTZnUKNXArNG03'
    b'L21IdlZEMTVPdUNXMUpmUVg3SkF4bFc3bmhCMGwzQUVsc2Z6LzZmYU9DZk5Ddkl6Y0J1Snd1'
    b'UGluNldrMUFsM0QzS1JELwpydnYrOTZ4Z2kySDVROWczSmxRZklaM3pTVm9oYWRlUHJleklO'
    b'aDBoWFNnUkJ0SWxNY2lqNENOUjFJN3RHTVhtTCthblNsRHQ0SVltCnNvUEQ2UmMrWXVCQmU3'
    b'TFZObFJtY25kNGliRWoyOVNQclNUQVh0SzNoa1JXa1JaMnhQVm55eE53MUExekxISW4wcWNy'
    b'U2NKYi9OdCsKNkxUdzlHVS94TEtqKzdrK29hbjhmSkptZ2RNTXh3YnVlZzI4ZmRuSzltd0hC'
    b'VEdndGgzYk9Zck4zMHFHMjBsY3FQSnErUHV4bFczWgpUZ3JlaE9wMmJPY1Y5Tk5EWFBkcmxm'
    b'ZVBrUTZIU1JjR3pzU2MzYkErRE9VaWduWXUvajdsTVJIQlE2UjdIRHZTanUwY3lUN0xJK2xs'
    b'CkpLay9YWjZDYkRmTW9acnM1M3BIc0pLaDdKc2cxQVNrSXphT282OHY1eWF0NE80R3lOK0Y4'
    b'TytacVloaCtRM0IrekdTQnFBRnk0dG4KaC8xRVc0dzJaalFxZ2h3anFRMC9ZdG14RkxaWEMw'
    b'ODFpWENnUlQ1cHh4aHBpWVBIclZabzZOSHBtQ3NOVzIyc3dnOXRIa2t2SkcxQwo2WHJVUnJG'
    b'aUFOV0lxQ2FSeDhjc2duRTRtby9VaHFNblN3bEpibGkzb1dPdTA5MGdCYzlCQVZCRVdrbFFo'
    b'NkhNekp5aFF5NllqYWh0CnBHOUhEQUVMUjNtRFAyOFlPb2hHWVZ1NlV3TnZEUWs3Z0I1MUpP'
    b'enZiYnlhSjV1YXgwaWJwUmxoc3pRai9GK1gvd015dkZzTTl6MDUKK1FBQUFDVjBSVmgwWkdG'
    b'MFpUcGpjbVZoZEdVQU1qQXlNeTB3T0Mwd01sUXdORG8xTWpvMU9Dc3dNRG93TUhYeHBiNEFB'
    b'QUFsZEVWWQpkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNRGd0TURKVU1EUTZOVEk2TlRnck1E'
    b'QTZNREFFckIwQ0FBQUFBRWxGVGtTdVFtQ0MKIgogICAgICAgaWQ9ImltYWdlOTc0NSIgLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'IT_62')

IT_62 = b64_IT_62
index.append("IT_62")
index.append("Italy Lazio")
catalog["IT_62"] = IT_62
catalog["Italy Lazio"] = IT_62
country["Italy Lazio"] = ('IT_62', '', 1)
lookup["IT_62"] = ('IT_62', '', 'Italy Lazio', 1)
lookup["Italy Lazio"] = ('IT_62', '', 'Italy Lazio', 1)
details["IT_62"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_62"] = ('IT_62', 'Italy Lazio', 1)
regional["Italy Lazio"] = ('IT_62', 'Italy Lazio', 1)
#----------------------------------------------------------------------
b64_IT_65 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmczNzgyIgogICB3aWR0aD0i'
    b'MTQ1IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0NSAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQWJydXp6by5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMzc4'
    b'NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzM3ODQiCiAg'
    b'ICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAg'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAg'
    b'IGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJi'
    b'b2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAg'
    b'aW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMzc4OCI+CiAgICA8aW1hZ2UKICAg'
    b'ICAgIHdpZHRoPSIxNDUiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZlQXNw'
    b'ZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXpl'
    b'UXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJP'
    b'UncwS0dnb0FBQUFOU1VoRVVnQUFBSkVBQUFCa0NBWUFBQUNHaDlLSkFBQUFCR2RCVFVFQUFM'
    b'R1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFB'
    b'Nm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQU0KTFVsRVFWUjQydTJk'
    b'ejQ5bHgxWEhQNmVxN24ydlgvZDRaanhnWXltMlNCUXBaakZTMkZrc1dQQmpBVmtFaElUa3NH'
    b'SFBpdkNuc0VnawpoRkNrS0xBQkFSSWJJT01FczBBQ0tRRkI3QWdXUUNDMlp6eS8zTlB2dlh1'
    b'cnpqa3M3dnZSUFo3eHpMeWU2Y0czNjd1OTNYVmVmZXRiCnA4NnBuL0lQZi83ckg3Vk5qTG1v'
    b'eEJna3BZQUVYTlVsWnlNR01SeE1QTFFwSUVIY0RlbXpJbUFoQ0VWZG1pWktETGdia3RWd00w'
    b'OHgKZWxHVkdLT2tSaHlnRkJjdDVpbUtxem1JaEdabDA4Mmw2NDBZTUFBekNXMGpHNXRaRGR3'
    b'dGlLRG1FbE9RbEladnFvNnFla3JSYzFZSgpNVWpiQm5kRHpKdytLMDBLWnVZNGhEYkZ3YWE3'
    b'OU1VSWpqR1VHNW9tRU9OUWJpbUdiZXBpa21LUTJCeXpXZFJURXp4bms1UUNNUVNSCmVEOS9q'
    b'Z2tQNWsrRWJCN2FKaEJFQUNocWFERnZtdUFsbThRVUpTVnhaT0RQaW5xTXdkVU1KR3o1VTVj'
    b'K08wSGNRREFJYlNPQWdFTlcKQTNNTEFZb2hUUW9TMDZwZHNvdXFQckROdExpVVloNkR1TG9o'
    b'RXNKMEdxVnRvdDI1czV5bi9mMjJiVktZTER0b1VxU2RKTlk0T3VwcAptb0NwNHc1N3MyYnpM'
    b'UzR6WnRBMGdhNHI3TzgzeUlxRW5KV3VLK3p0TlN3V01KMDJwQlFZaE9ITTV6M1RhVVBYRjFL'
    b'TVRDWnhVNjVJCkpzYWhIRlZuZHN4bTF5bEZsVW1iV0M0enMxbExDQ3ZpaTdGY3NyRTVtU1Nh'
    b'WmlqWDNUazY2cGxNRWprYklReS9hWTB3ejRoQWlFTE8KeHY1K3UvbldkNFZjbE9ta1liSE16'
    b'UFphd3ViM0dZc0Y3RTBiRnBKcDIwVGJ4bVA4ZFRRcG91YkE4TnMyL0MweTdoQlRJUFNGZzRQ'
    b'Sgo1bHZ1bGE0dm0zTDNwZzF4elo4Njg4V0t2NjdRTklHMjNiWVo4NTRVSSs2R0dTZjRXeTRM'
    b'cGtiVHhxSE5aaTJ5NXE4NXlkL3hObk56Cmp1WmIvbUlVM09HanUwdmN2Y2piWC90U3R4K2Ix'
    b'bkJDaEpVT05vMklCeHhIQXNTdy9XWU9Ya0JFOEdBRWljQkFGZzdtUnZDQWlSR0MKYk1wMWwr'
    b'R2JCUlFuM20vVFlQQkRRR0RUTzljRnEwSkVzR0FFQ2NqUVdYQWZCUHBRbSthSUMrNE9VVmh4'
    b'aDRpakJrUGZGUkRiaUhoVApya0pBaG5LaklKdGZNelJxOElCaFNBeklxc3o3K1F1UmpjME5m'
    b'K29JZ2d2RXlFbWJKK29TTnIvMXBNMEh0Sms1V0JoKzNiRTJjeDhhCjN0V1B0ZGtUOE9lRzJH'
    b'QXpSdkRMa2JTZjZQdHlOelYvc1lndmZidWpvdUpKY1AwUEw5QmVqcFNpRWlvZEZic2d4TUNr'
    b'alNRSlZVUVYKdThITTZIckZNS3FJS2s3dmxTb0ZGYWVDVnhGVm5FSThBSVo0RlZIRmppSWFW'
    b'Q1M0cGNwR3hTNG9PUGNPbDZoNXJKNm9ZcmRnV29SMgowaEJyaWwreEs5b1V1Zkxpak9tc3NT'
    b'cWlpcHJpVnp5bm1FaU53M3NkSlJlcGdYWEZUc2hxNk9FU2M2K2VxR0kzSkFrY1hKaVNZcXd4'
    b'ClVjVnVpTUNralFTaFRqWlc3QmdUaVhONHIwZlZVNDJKS25iTHlFUm8yNGlyVlU5VWNWbzRv'
    b'L0JFK1VDNCtXdXZQTmZmWU9MY3U3QjQKNU45ZGVlczJWOTZSVDc4bkNzT210TklGSDRXSStp'
    b'dVIyNy95azN6KzZxOCtId0c1OHZmLytRMys1Nk4vLzhTL0V4T3VkcGU1OGs0YwpqUjlTWnp6'
    b'elJDKzgrQm8vL2Zvdm5EMkpsdm5XUDMrVmQ4TDM0TklqZXEvS2VnZkZwNy9qOXBtYk53MDFy'
    b'ekhSMHhEUUQ2NWZlL3gvCmtuSFVQY1JBTzJsSUtWS3pzN01VMEloRXBPWjRsMUh6dW9xL3U0'
    b'Qis3OGtGQktNWnp2YmF4Q3V2WEdSL05xbkQyZTRDK3ZhNTVtRzkKQUt1bFZFOTA1Z0lTSHgw'
    b'dlZVUm43SUhHSWlGenArK1ZYS3g2b3JNZXdrb1lDZVhyM2lDaHJ1S2ZkUXhrSThuTzJyRGFI'
    b'dHRFclNsKwpEYUozd2tJTDc3MTNGek5TOVVSbkxhQ1JlS0s0T3UwUmd0VEp4Z2NLeUV2MVFJ'
    b'L0t5TUo2SzRoV0VUMVFRTi8vNmpNVGtJL0VFNlVZCnVIQXdRWXZXeWNhekZOQzRrdnhWYmF3'
    b'T1oyY3NvUEY0b2tXL0NhenJQTkZaQ21oTWlEQWNvNDVTNTRuVU10LzYvdStlaVlBK3ZQRXEK'
    b'N1hJa0c5SzJkN3llNzJXUGJSWjI3Wm5idW5Iak5kNSsremVRa2N3MnBqWng0YUNsaVNHa2N5'
    b'MmdNeHJDYnR4NGpiZXV2VWswWVN4Ugo2UHJPUnVlY25vQTlXd0c5eWx2WDNxU1V5U2k1Rk9U'
    b'OGllanNCZlNWMFFwb2pWQUZWQVcwb3dzYUF1dnpkS0ZERmRCVFRzNTBGUnM1CjV5UEZyd0o2'
    b'QmlKeW8rOFZVeC8vakhVVjBEUEt6Z1Q2TG1QT3VDLytyQUo2ZGtoaHVKK29iVVp5akxvSzZE'
    b'bUlhTFdLYjJOZHhhOEMKZXZaWUh4bktlWVJQVmFrWC92aU1OcFNkVndFTldkbHcycU1VSDlm'
    b'Rm4yc0IvZHNIZjFzRmRCWWlHbzVSajJjNGM2d0s2QXpSU3VUSwpsWDBtYlJySGFROUw4TzZO'
    b'ditQZDhzTm5idXY2OWRmNDduZStRaWt0NXhtR0Q0L21EZTh5Zi9weGVLVndjLzdmWitLQnZ2'
    b'UFdtK1I4CnZnVzBGbEhmSzJZVzZ2YllPb1R0aE8zRm55Tko4Wi8xSFFsVlFJOFExRWlpNmlx'
    b'Z004WjZzakdtTkk0WjYyZmxpYXFBSG80dUt6ZHYKemVtN1hEMVJGZEN1SFhkRnVzZzRQSkUv'
    b'NVFQdVZVQ1BrWjJ0Smh2TnhuSS8wVk04RVZnRjlIaG8yMmFZYkp5MDlmRGljWHg0NHpOVgpR'
    b'SStkNGtQYkpsSWF5WlBtWWs5SFFOZXUvVllWMEdOaSsvTGlTRmJ4VDV1ZFZRSHRFRUdzT0Rk'
    b'R0VsaWZKaWFxQXRvTjZzYTl3eVU2CmxyVXpxUUk2KzhDYXNGckZqK1hjemhOVkFaM1NFOEZx'
    b'Rlg4a205TGtDWWV6S3FDbklhTE5jRGFPMHg3cE1EOTJobmJqeHF2UFRVQkoKbExnc294RFIr'
    b'clRIcEEzalNQRXYvbGhvam1hUEphRG5PUS8wYzYvYzR2TC82dWk4MGloRUZBcTgvQjh2Y1BI'
    b'RHlmOWJBUjIwaFY4cwpmOE5uL3JFWmh5ZGFyZUkzWTFuRkIzampEenBLK3hQOCtIT1plejkx'
    b'RzhKMmZMdDkrMlhlL2FkZjVxVjA1eFB2QjhxZXVKdGZvTGVQCk4vUXNMYmlRam9nOG1TZHBV'
    b'K1JuTDkvbGplNjdYUDJ6UWpNZlJ5N1RsMkVWUDNkbFBEc2JnOEhQLzc1ejU5WEF6YzlmNU9U'
    b'dThaNHYKODVlUExLTzB3b2VmMitjSEI1L2xULzdyRFhwcitPekZPYjk5OEZlOCtONU5EdDQz'
    b'WklmUmFQOTd3c3YvbWtqZGVGYVp0Z3V3UHI0VApzSmQrRkxqMG85UHNnZTU1L1F2djhNSnYz'
    b'dUZQMy84bGZpZDlreS8rRWN4dTFaM0VKenF0UXpOcHlIMnh5c3dEOE5JUEExZi9wZWZGCkwz'
    b'NlRxMStIMmEyNlR2MHhFWVZBMjBaS2ZhcnE0Zmladjc3RndaM0NoUThxUlE4VVVReE0ya2dL'
    b'OVI3cmgyY2ZDK0dOcnplVmlJZkYKUkt1TFA4Mjl2cno0aVVMcUtnZVBnbENmNzZ3NEpkU3Jp'
    b'Q3AyeFdhZmZuMldvV0puRWExM3BiblhGTDlpSnhSYnIrSmJxSjZvWXVjVQp2NTAweEJDcWlD'
    b'cDJRNXVHMTZobmUwMk5pU3FlZ2xlcUZGVHNGQk90amd6MVdhVUcxaFU3SWF1aGg4czZZMTJ4'
    b'TzliUGR3WkNqWWtxCmRrT1N3SVdEZGp6SHFDdWVRMHdrenVHOUhsVlBOU2FxMkMwajI5elph'
    b'TlVUVlp3V05iQ3UyTlVUaFdGVFdneWhlcUtLMDBITjZ6eFIKeFc3bys4ek5tNGFhZThwZm11'
    b'cjdYMjZpWXNRWWtHUEgyb3Y2OXZoV2hCQzJIOTBjVTBjUUxFQVNPZkc0ckprVFBLRGl4QWl5'
    b'S3RnZAoxSnhvWUVCSWNzS21xUTNQK2dFRTUvanluZ05XaGpGWUE4U3cvVjkzUnhXaUN5Wkdp'
    b'TEt4aVVPeG9TNk9FNElnNjdvSW1EbnI0MlFXCklNVmo5WFJRTlNLcnVweXdDYW8rMk1TUUtJ'
    b'UmpQQlIxb2dubWhqU3JiK3Q2dXVQRkNRUTArQW1iWm83cjhNM0VDR0hWTG5LU3Y0SGIKOEFu'
    b'OFFZaGJEdHhXN1lLZ0FWSzRyODEwYUxPSDhiZHBzd2h5TWRKT0duSlcwcVhYTDNpVEFzc3Uw'
    b'NlJJTzlrNnA2T2pucVlKbURydQpzRGZiN2psZUxqTm0wRFNCcml2czc3Y2JvemtyWFZmWTIy'
    b'dFlMRExUYVVOS1lVUFFmTjR6blRaMGZTSEZ5R1FTTitYTzU1bTRxcmlxCk16dG1zK3VVb3Nx'
    b'a1RTeVhtZG1zM1FpN0ZHTzV6QnViazBtaWFlS0dvS09qbnNra2tmTndvYzUwdWkxM01jK0lE'
    b'SVRuYk96dmI0OGMKOVYwaEYyVTZhVmdzTTdPOWR0TXdxc1ppa2RtYkR0L2FOdEcyOFJoL0hV'
    b'MktxQTE3Yi9iMmp2RzN5TGhEVElHK0x4d2NiRS9tNWw3cAorcklwZDIvYUVOZjhxVE5mclBq'
    b'ckNrMFRhTnRqYlRidlNUSGlicGh4Z3IvbHNtQnFORzBjMm16V2JqclQvZndkYnpNMzUyaSs1'
    b'UzlHCndSMldpMzRZenVienZwL3NKVk4xY1ZkUk13VEJBUzJLdWJzNzRDNCtIKzVwOVpWUndO'
    b'ME1VNWZsTW0vSFNUVk04V1ZmM015bDY3TGsKTElQWGNzZlU2UHRpcFpoWWNUR3p6U2FubkpX'
    b'aXdWZmRWUmFMZFRjYTFtdk1jS0c0cVlmbE1oTkVjSVplWklwM1hYRlZsNjRyVW9xdAoveFZW'
    b'cGU5d2RVY0s0dWFyWGlqa29pRGlvdURxc2xqa1ZUMGRWVWZOdmV1SGNoZkxQUEF1Z3FxaWlu'
    b'ZXJldlpkRVZVRkJIZW5GTU1jCmR3ZHhsNFU3SXR0dmpuZ3h3MVZsc2VpSHk3b0VTbEhNVitV'
    b'cXN1eXloQ3lyY3Rud3Aycmk3cUs2cWlST3lZcXBPdzdtSm91NUR5Nk0KclUwNmRWTVBpMlhl'
    b'ZEh4VlJVMjJiYmJNa21QNEdIL0ZuRktRZy8yV3k1Y3Y2ZlVQRHBmL0J3aWFSOEZFdVRiV0FB'
    b'QUFKWFJGV0hSawpZWFJsT21OeVpXRjBaUUF5TURJekxUQTRMVEF6VkRFeE9qRXpPak0yS3pB'
    b'd09qQXdrdklNTEFBQUFDVjBSVmgwWkdGMFpUcHRiMlJwClpua0FNakF5TXkwd09DMHdNMVF4'
    b'TVRveE16b3pOaXN3TURvd01PT3Z0SkFBQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0i'
    b'aW1hZ2UzNzkwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'IT_65')

IT_65 = b64_IT_65
index.append("IT_65")
index.append("Italy Abruzzo")
catalog["IT_65"] = IT_65
catalog["Italy Abruzzo"] = IT_65
country["Italy Abruzzo"] = ('IT_65', '', 1)
lookup["IT_65"] = ('IT_65', '', 'Italy Abruzzo', 1)
lookup["Italy Abruzzo"] = ('IT_65', '', 'Italy Abruzzo', 1)
details["IT_65"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_65"] = ('IT_65', 'Italy Abruzzo', 1)
regional["Italy Abruzzo"] = ('IT_65', 'Italy Abruzzo', 1)
#----------------------------------------------------------------------
b64_IT_67 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDc4NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01vbGlzZS5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMTA3'
    b'OTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxMDc4OSIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMDc5MyI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQU4KN0VsRVFWUjQy'
    b'dTJkZTNRVTFSM0hmM2RtZHZhOTJkMXNGa0plSklFa0pEbEZZcU5BRUhsRUVBb29La3BhVUJR'
    b'ZjBVcXQ0a0VVSzhVZwpCaXdIS2dXMVBTMVFLNlRLUVJRUWZJQ1ZvQVdESUFXVEVFS2U1TUVt'
    b'KzhpK2QyWm5idjlZRE9SRmRoZmFzOXZlNzMrWjNKbDc5MzdtCmQrL3YvdVozWnhDOGRoS0lv'
    b'bGtVNlFLQ2tJZ2dKQ0lJQ1VJaWdwQ0lJQ1FpQ0FsQ0lvS1FpQ0FrSWdnSlFpS0NrSWdnSkNJ'
    b'SUNVSWkKZ3BDSUlDUUtUMHpFdHV6Wk5NOTRIUmNoalRuallGNnRVUktFb1NsRDZZOWxjWVEw'
    b'WnFSU0pGWVlzdndZQVFCdE1zbkx5LytiOVFwRApobkFaR1FDQWVCNHdGblE2ckZUeUlpWUlR'
    b'NWJKaDNMVVFIZDBxSGZ2L3E5VjZzdkxzODZaZ3lXU0s0Y3dCZ0FMSDdsT1E3UzZNMXg2Ck9x'
    b'WnVjT085NDhaWm5ubW1CejhBUUloNHBQOEJJV1JmdE1oNzY2MDM4SktlQ1JPc1R6NEpEQk4x'
    b'blJGTkxlYlQwbHpUcDh1T0hjTlMKS1orVzVwdzdWM0xoZ2pjL1h6UWFOVnUzWHMrVlhZV0Zq'
    b'a1dMSXQvZ29oNGhVMS92eThueFRKaHcyZDlKU09qWXNBRUExRHQzWGhlLwoyYlB0OCtlVHBm'
    b'Mk5sd2dJQU9DcUNROWhMRHZaenc0UVdVWEZmNXFmSHhPRVlUZ3NJZ0JBdDNNaHhzYmFIM3pR'
    b'TTNGaTM1TFc1Y3ZkClU2WUFUWWM4b1M1WUVLVDljU0lpQ01OQWlMb1JZb1JjVTZlNkowM3E3'
    b'UzRHVE1Sb2RCVVc4cW1wd1Y4Y0kyUmJ2TmcxWTBZUVJYSDMKL1VUbXdoQ2RsOERZSlpFRWhs'
    b'RDErKzhyRGg3c0tpNzJqUjdkcTZSMjB5YjU4ZU9Cdmc2S0gwVjFQZlpZdndiZDIxQUZnVGFa'
    b'L1BIeAp4QXF2d3dwWnR2c0liYmRqaGFLZmp1YjVFUGpSdE8xWHZ3cUtIOGZwMXE4SGpnTUFI'
    b'aE9Fb2N2T0F3Q0lHazMzRVVHdjU5UFQyWFBuCnBLZFBBd0R5K3hXSERsRTJXL0FMUk15eTF1'
    b'ZWY5K2JuRDg3UDU5UC83bmZTMDZkeFRBd0FkUEZrSUExZFpwNEtkTHFvVUZCdWQyQmEKaWx1'
    b'eWhMYlpCSTJtWStORytWZGZ4V3pmcnRtMnpaK1NFaFEvcWRTeWRDbVhrek00UDdkYnYzWXRX'
    b'MXVMRVJMVWFnQ3c4RFJCR0NaQwpBQkIxdWdCQzJtcnRIbEZWQnc3SUR4MENBQ1NLa3ZyNndm'
    b'a3BGT1pseS9pUkl3Y3RTZHZ0K3RKU3ByRVJBSEJNVE1EUjdlUVFRUml5Ck9uMlhlMDNVYXFH'
    b'bHBkZC9sYnQyb2FEblAwR2pzYjc0SXArY1BQaThZclBwUzB1WjV1YkxKMnExbCs4bmppSUl3'
    b'N2RDUWFmclo2d0wKbXArbzFWcVdML2NuSlExdWY1MmRzV3ZXMEpjdVhUbFhyKy9WR0lJd0JI'
    b'a0U1QktRa3NiQ2ovMFloZ1NEd2Z6U1M4S1FJWU4zUkZ0Ygo3T3V2VTJaemp4V25UZ2NBR0pD'
    b'Rmk5aCtpdXduRlJjOUZBRDRodzBMNzNSL2ZMeDU1Y3FnK0xXMDZGZXY3c1VQQUlURVJBQm84'
    b'eUkvCldWU0VwMFlQRFFEK2hJUncrQ1VrbUZlc0NNYUNKZlgxc1NVbHRNM1c3MFVBb01GRFIz'
    b'SXZNVkdBTURFUmFCb0VJWVRJVG1xcVpmbHkKVWFVYXRDUjc3cHp1alRjb2o2Zi82eVFsQVVD'
    b'RE82SVJSclFWMXJqb3dOSXdHR2ZrU2xnbk05T3lZa1ZRL0NvcjlldldEY1RQYnpRRwpBZ3Zu'
    b'bkFSaHVLcHkwQmdRQVBqUzA0TTh4WmVkYlZtMlRKVExCeTBwUFhWS3YyNGQ4bm9ITk9VZks2'
    b'MGlDTU9XVzBDTmJnb0ErSXlNCm9Qamw1Vm1YTGNNeTJhQWxaY2VPNlRkdVJQeTE0bWFCU3Mw'
    b'ODFjbFJCR0g0T20xbkFNQ1htenRvVmtUL3lVdjlTWDcwcUc3TEZ2RDcKQjdraGNuTUI0UHV1'
    b'U0U5c2lIU0VGVFltc0R6bkV4T3Z0WWdNT25sSitjVVhNVysvUGFoekpPajFnY1ZNb0FFRVlm'
    b'ajYzczRFa2g1OApOOTAwVUJsWFlXRlhjWEV3VCsyVmUvZHF0bTROSnJMakhUTUdBRERBZDEw'
    b'U2d2QjZwOE5UWFF3QWVNYU42NS9mN05uMmh4L0dRU1NmCktmZnUxWlNWQmVzV2pSMExBT2Vj'
    b'akpramVhVFhyUy9OTEFENFUxTDhmY1pTeHozM0JKWDhnckhtdmZlQzV5ZnFkRnhXRmdBYzdw'
    b'UkUKZnY5RUFjSnlzeVNRdXVJcEtMaHlGQ0g3Z2dYT2UrOE5pdC8yN2NwUFBnbStScy80OFpp'
    b'aU1LQ3Z6QVRoalpCTFFGOWJKQURRbmY0VQpmUElTRWtYdEgvK28vUHp6NEt2REZPVXVMQVNB'
    b'a3phNmc2TUl3aHVqRDl1bEFDQnFOSjV4NHpCRmRUMyt1R2Z5NU1INUNZSjIweWI1CmtTTWgx'
    b'Y1hsNWZtTlJnRFkzUzZMaXM2SmptenVzdzZteGtWbktBWG5qQm0rdkx5Z2tsODRUcmR4WXlE'
    b'TEppUTVaODRFZ0ZZdmRjeEsKUjBYblJNMjJtUGRicFFBZ0pDY0gzUDFCK0hrOCtuWHJ3dURu'
    b'R3pPR3k4d0VnQS9hcElIWUhrRjQ0L3pTVHZhOGl3WUFORmhVQmJuZAordEpTdHFvcTFDb3dR'
    b'dlo1OHdDZ3pVdnR2OFJHUzg5RURVSU04T2NtR1FCZ21ld2FzUlhhYmplc1hzM1cxb1pSaGFl'
    b'd01KQU05NWRtCjJkWFBlRk5qcEo4V2pTQUlRNUNVUmkrT0gzTDJpVkVwbWg2bThLMU5jam5j'
    b'TmNCQ25yTFo5R3ZXQkpMUFFwVmdOQWFXbUZWT3V0ZHkKc0dSeWZHV25kMGwrM01yYjRwVVNT'
    b'aXVqQ2NJQnBXS3AxeVlOcXlyT25wZXRxekg3MWt6cG5YS3gvb0xDTFNDZ3FMNUJhcnFqSTNi'
    b'VgpxdTdrczFDSDBLNUhIOFV5R1kvUnVsckYxYk5nbklLNUxVbFZjclR0eVp2ai90SGtXRGt4'
    b'ZnN1ZFNRVGhnTnA4WjFMZVVIbFpwZFV2CjRvYytiaWhJVXJGMEQ0TXpjZFE3alhJQTZCWFJa'
    b'dHJhRENVbGpNa1VYcjJPQng3dzVlUUF3TFptV1dQUE5JdjhZUXBCeEo4V2pmVDYKeGVNdDdu'
    b'bWp0SzhjYVNNSUI5VERleHRubEYzNFo0c3IyeUI3OTY3aGdvaXBQbVBtdmt0c3VhWEhRTWMw'
    b'TmNXV2xQUk5YZ3AyQ2l3bwpjTTJhQlFBbnU1aUEzM3UxUHFtMTU3eFQ5WEdOVGM1UXB4N05x'
    b'dXIwMWxwOEVkVnBLTkkrdTBVamRQemh6SDIxWFN5TjlweXpuVEY1ClUyTFlhbk9QWitzeUNy'
    b'K1o2eHloRkVBVTZjNU93eXV2VUE1SGVOWDVSbysyUHZzc2xrZ3VlcWhmbmxVNS9OVFZVL0tI'
    b'ODlJU05XeisKbjZ0RkRCamdxWnNOUjVwZDM3ZTdpUlZlUzJrNmxxS2dwTHo5cFM5YjFWTDZ4'
    b'T0xNdlEra0t5VTkydWtWMGN2VlNndVBnS0lFZzhHWApseGRlWGQ3OGZPdlNwVmdpY2ZyUmIy'
    b'cDY4QU9BMzk0ZTd4ZmhxUVBOSnhabjFmNHlaM3FhNXMyS2prampGNGxXR1BBZzdENWh3N1RF'
    b'CitkbTZ2NTZ4eENrWUJQRHpQUTI5aXFVb3hEZEdPUTJzQ0JocnlzcVUrL2NIdjBVTkFGeFRw'
    b'OW9mZWdob3VvdEhMMVNwQXFsV1YydkgKM2NQbEVpckhJSHZ2ckZWQ28zZ1ZzM2hmRTFsVUJL'
    b'VU90LytqKzlOdmlWZVdsTGZma2FwKyttRHpMUW5LMFVONlp6UTF1cWtsWjFXdApYZ29Rc2hj'
    b'Vm1aY3ZGMy9jQW5GdGlYSzU3ZW1uN1k4OEFqUnQ1YW1sVmVwZS9GUXNCUUF2ZmRucTVzVzNU'
    b'blorMitxNkt5UG1VTDBECklsSTBUSDBpQXB0bGN2UDNqdElWSDJpZW1LeEswVW9mMjkvWVlP'
    b'c25KOTRsb0NNV3lTaTFZSlNLZ3RIb0xTaWd6R1pKYSt1MUpyKzgKUE90enp3VWVCNTUzMGNz'
    b'cVZjMmUzdmZ4Wno4Zk1UMWRVL2FEdGF6U0ttVlE2ZVJodTZ0dG03L3JqRXlFS0dLL0l2cW5u'
    b'eVViNU13dgpQbXJnQkh4M3B2YlpXK05ZQ3IxYTNyNzNmRmZma1dSaG9uZGhramVBZ3EyclUr'
    b'L1kwVGZBeHFlbE9ZcUtmTm5aM1o3dHBucDV2OXQzCk5WSjY2K3lVSElQc21jK2JQNzBRb2NZ'
    b'WDZWWUlBSi9WMmRQMTBpL3FIWStNTnF5NlBmN05pbzdQNnUwYnBpVWV1R0EzZTRSZXNiZlQK'
    b'ZHVaZmRqcFRKV29sV05EcFBCTW5jcm01Q0lCcGJ3ZUs4bzRkNjFpNDBISC8vWUxSQ0FBdFhx'
    b'cTBWdkZCbTB3Y0lKRHRFL0Q3bFZaQQo4UHJrQkRWTEhXbHlSakpDRlBuZjhqMjhZT1JITmJi'
    b'akxlNDZxNjkwU2tLcmszLzVINjBEVGV3empMNUZ5YjVZeWVVM1ZDQ1BCMFFSCkt5Ky9TclNM'
    b'UisrMnlENXVaL3R1YzZFUTdKeWJ1dnBvK3huVGxlVHVkSjAwSllZOTNCRFJoaGdGWVc0bkoy'
    b'cWx6T3lSTVFlS1JyaDUKc2F6U0NnRDlCaXBGZ1AwbTZjS1Q2ZzExOG1vbkF3QllMZy93cTNQ'
    b'VG14dmtDMDVwZHJkSis5Mm1KR0k0MWU3ZU15K3RNRlVOQUhsRApGVy9QVEw1ZzlVVTR2K2l3'
    b'd3A4WTVYdm1wVlcwdVFzU2xmTS9iRGphN053MFBUSFhLSi84N3Zscm41aXFFTzZNNHlRVVBt'
    b'aVM5bDB6CmRHdGlzdXJsQ1VNWkNxMC9ab3FWMDY5T0dyYmxoT214TVhHcnl0ditkc1lTK2Jj'
    b'NGlvcVBvaWVxMmVmR0duZFYyNzVwZHE0dlRKdzUKUW5QSGU3VVhIVnhtck16azRxMWVJZXdy'
    b'SjZuWjhrVVpwViszc3pUNjlhM0d1Ui9VeFNtWXY4eEsyWHlpWSswL0wwRTBDRVhYZCsxWApU'
    b'eHAyWDVaMjJvNWFYc0Q3NXFjcldVck9VSCtvTUwxeExMUUF0NFJDWXhPVjVVM09YOThTTnps'
    b'RmZkY0hkUUN3WlVhU2xFYUw5elhwCjViVEZJMFJMbjBUVCswaFROT3ljakpocE8ycWI3TnlX'
    b'bVVsblRKNnN0eXB2MjE3emRMN1JvR0NrZEFoNUVzK1BHN0xybnRRRXRlVHIKaSs1Y296d1F3'
    b'SFB4SWtNaEFJZ2lmbEdHc05ITzNmU25xaVk3QndCamhpcVdIVzRCZ0hZWGp3RlBTRkxWTDht'
    b'TmxUTWFLYjEyU2dJQQp4RWhwbll6V3llaXJIWjhYeGczWmZWK2FsRVoxVmgvTG9KVVQ0eXRh'
    b'WGNkYlhVY2V6UGpybkpUN3NyUnZWblJBdENuSzNncmMvWmJ6ClZnZGZuQmVua0ZEdnpFeHVj'
    b'ZmhIeFVwWkNxMllNUFNuOFlwcGFXb0ErUGFSekpPUFpsVXN6anJ5NEpXTmJYNk1iMDlSSFN3'
    b'YWNkN2kKNjNEN3A2ZHBZcVQwZ2owTnYvL1dkTjdxSzloVzgxMmJPK29RUnRsY2VHVlFqV0Yz'
    b'emgyZXFHSFBXM3dMOXpTOE9pbGVLNlh6NGhWbApQMWhUdGRLaUQrdHJuc3BlOUhGalZhZlhM'
    b'MkxIank4eVpHbFVXWnp0NHNRdXIyQlVNVldkM2hxejc0WERMUkROWXFLMDNZMWQzUGh0Ck5k'
    b'MS9adWxsbTA1MEdCVE12Rkc2WGRWV0FNQVl0czhaamhCVWQzcG4vZjFDb0JnbjRKMC9XRzhl'
    b'S3FjUWlwVXp2L21xTGRjZ2d5Z1gKQS84VGlsTXkzMXgwY1FMZWNmZndZeGRkQUlBUXpDaXI3'
    b'ZnVFZmUwMzdaWEYyUVhiYWxLMTdGbVQ1NnpKRSsyL1BWb0gwajQvQXdLego1TnFwQ2V1K3VX'
    b'VDIrS3VmekZhek5BWk1JNVN5NlN3blhIbVVHRjFyaHY4WGhQL1BJbDlPSXdpSkNFSWlncEFn'
    b'SkNJSWlRaENJb0tRCklDUWlDSWtJUWlLQ2tDQWtJZ2lKQ0VJaWdwQWdKQ0lJaVFoQ29qRDFi'
    b'MnovbW8wdVNRbkNBQUFBSlhSRldIUmtZWFJsT21OeVpXRjAKWlFBeU1ESXlMVEF6TFRFeVZE'
    b'QXdPak0yT2pFMkt6QXdPakF3dWhya0dRQUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0FNakF5'
    b'TWkwdwpNeTB4TWxRd01Eb3pOam94Tmlzd01Eb3dNTXRIWEtVQUFBQUFTVVZPUks1Q1lJST0K'
    b'IgogICAgICAgaWQ9ImltYWdlMTA3OTUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'IT_67')

IT_67 = b64_IT_67
index.append("IT_67")
index.append("Italy Molise")
catalog["IT_67"] = IT_67
catalog["Italy Molise"] = IT_67
country["Italy Molise"] = ('IT_67', '', 1)
lookup["IT_67"] = ('IT_67', '', 'Italy Molise', 1)
lookup["Italy Molise"] = ('IT_67', '', 'Italy Molise', 1)
details["IT_67"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_67"] = ('IT_67', 'Italy Molise', 1)
regional["Italy Molise"] = ('IT_67', 'Italy Molise', 1)
#----------------------------------------------------------------------
b64_IT_72 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc1NjEyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQ2FtcGFuaWEuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczU2'
    b'MTYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc1NjE0Igog'
    b'ICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAg'
    b'ICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2Vy'
    b'Ym9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAg'
    b'IGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzU2MTgiPgogICAgPGltYWdlCiAg'
    b'ICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6'
    b'ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZC'
    b'T1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQVlBQUFCa1c4bndBQUFBQkdkQlRVRUFB'
    b'TEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FB'
    b'QTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFICjFVbEVRVlI0MnUz'
    b'ZGEzQlU1UUhHOGVmc25yMGxtd3ZaaEtRSlNkeGNHaVFFSEN3eVZVb3JPb1dSZHFUVmpoMFo3'
    b'VXdkWlhDQUNpZ1gKWVpDUXNJRkNTR0tidGtoYkxkT2hZc1hwVkZyVHRDaU9wb1VPQWxKQWM4'
    b'ZGN6VDJidlo3ZGMra0haenI5c01lZTdXU2FkSG4rWC9JaApPVE5uMy96bTNiTnZ6bnNpNUMy'
    b'dURZR3hhVTRFWU9jd3NPbk94Q0ZnaE1VSWl4RVdZNFRGQ0lzUkZtT0V4UWlMRVJaamhNVUlp'
    b'eEVXClk0VEZDSXNSRm1PRXhRaUwzV0tKaWZSaVh2MzZxN0IvN05QOXZyekVCZlBTYjBPd3Bz'
    b'KzZjKzlwdTRMTngyOGpyTm1ZclZlQzdVMnYKN3ZldFo2Y2dWelZqOGNiVE1GdVRaOVc1RDQv'
    b'VUFkRDRWdmovbUJEVVlLcTlqbzZtdlh5dklxenB6VHlnSUZEMUJnYXUvSnEvZmNLYQozaXdY'
    b'SmZRZHJJYTMvd01LSUt6cHpmRzZEKzJObXhBSkRGTUJZWDErU2xaU0hEK3N3ZnJUSHJTK3Ro'
    b'V2FHcVVFd3RKUFhyb0k4Z0tyCjhZdjVTUlhLd1JiY2ZMK0JFZ2hMUHkyMUFvN0tCNkc2ek1Z'
    b'djV0c2tURlQvSENOdGY2UUd3dEtkZzFENllBM1ViZVdBVlRCK01mK1gKS2ZUVzcwVmdySTBp'
    b'Q0V0bkJySWtZZjZHWTVEV1pjWXgxUUhpTHo5Rnh5dGJJVXRUVkVGWU9wLzQwZ3ZoM2xPUHlO'
    b'ME80M09kcEVJNAovQTkwTmxVQ21rWVpoQlU3VjlHOWNIbWVobHhrTVk1cktJcHc1WnNZK0pD'
    b'THA0VDFPUld1MkFMcjdwWFFuTVpmcHVteUgwTTFkZkQyCi81MDZDRXRuQmhKTUtIdTBIc3Ft'
    b'RXNCay9HSmVmSDBJTjMreUM1Si9rRUlJU3dlSlBRMmx6elFpdWpiRCtFR3FCdUhGTm5TYzJn'
    b'RlYKbHFpRXNHTG5uRnVPdlAzN29Dd3hmcXVNNEZlZ2VGcnd5WHRIcUlTdzlNc3Vmd2lwbnNl'
    b'ZzVzYXhNdDhWZ3JmcUpFYmF6bEFLWWVsMwoyLzA3SWU2K0c1ckQrTXMydnpPQi9oL3VoMy80'
    b'R3JVUWxzNkxOVnRSOG5nZDFBM0ZnQkRIY1NmNjBmWHlEc2poU1lvaHJOalpuTmtvCjJuWVV5'
    b'bXJqSy9OQ1ZBTU9YMFBINzNkRFV4V3FJYXpZcGViZWliblYyNkRlSHNmRi9GZ1VVdVdmMEhm'
    b'eE9OVVFsbjY1U3g1SHN1ZGgKYUJuR1YrWk5ONElZclc3RWVQYzV5aUVzM1RrSTdqVjdZZHB4'
    b'SnlER3NYaDZaZ3lmTk94Q2FQSW05UkNXemljK2l3UEZUOVpDV1RmUAorRUVhWUQ3V2k0NFRX'
    b'NkZFQXhSRVdMRnp6SEdqNElVYUtNdlRqTTkxWVJYYTRjdm9icTVDSXUwRkpLeHBMc085RWht'
    b'ZXA2QVZHdjkvClZVS2ZCSC9WRy9qMDJtc2NRTUxTTC8rZVRiRHV1dythTTQ3Ym1pLzRNVmh6'
    b'RUZNREZ6bUFoS1V6QTVsRUZEOXlDTm9QNXNkM0o4U3AKWVhRZDI0bElZSVNEU0ZpeHN6Z3lV'
    b'THk1RHZJMzQ3aXRXZEZnYW1oRCsra2QwQlJ1SXlNc25aeHpGeUszNm5rb0ZjYjNLQXBlR2ZM'
    b'KwpjK2o5NjQ4NWdJU2xYM2JGSTBqeFBBb3RLNDdGMDg0d3hxdC9nZEdPSmc0Z1llbm5YdjA4'
    b'aEYxZmltc2JtYmw1SEwxSFhrQ1EyOGdJClMzZGdSRHRLbjJpQS9QMzh1STRUWCtsSHg0bnRr'
    b'Q1V2WWJIWTJWUG53YjJyRnNxOXhoZFBJYW5Bb1N2b2Vxc1NtcVlTRm90ZGVzRTkKeVBSc2hs'
    b'b2F4K0xwVUFUaC9YL0E0QzI4all5d0REUnYyWG80cWg2QWxtYjh5WnJDWlIrR0R0VEQyM2VC'
    b'c0ppZUVoT0sxbm9nUExzUQpNTWV4ZUhwNkNOMC8yZ25KTjBCWVRBZUpMUlhGVDc4STVUdlp4'
    b'Zy9TTkpnYU85QitjaHRVT1V4WUxIWkpHU1hJcjZxQmNsZXE4Y2t1Cm9FRHhuRWZuV1E5aE1m'
    b'MWNKYXVRN3ZrZXREeWI4VUh1a2VDdlBJV2hHNmNKaStsWCtMVm5JZTVkQVRpTTN3a2gvczJI'
    b'dmtOVm1CcTgKUWxoTTUrM05iRUhKdWlOUU41Ykd0WTNNY25JRUhTODljMHZjQ1VGWS8yWFc1'
    b'Q3dVYlQwSzlZRXM0eUJsRFdKREoxcC91d1dhS2hNVwppMTFLemgzSTl1eUVWdUUwam10Qytl'
    b'eUJ1aTMxaE1YMHkxbjBYU1FkZUJoYXB2RTdJY3l0RXNhcWY0YlI5bWJDWXJwekVOeXI5MEI0'
    b'CkxyNXRaTFkvQjlGOTVEa0V4enNKaStuTVFKWWtsSzV2Z1BKWWZOdkliTDhheGNmSE4wQ08r'
    b'QWxyTmplVHo2UzFwK1VqZjA4TjVPVXAKeHVjNlNZUDU2RWRvKzkxMmFBbjJRTjJFZ3VVTHpP'
    b'elQ5MXhGSzVGUnZSNXFZUnlMcDhNS3dvZmVndXE5UVZpenRkR3htZCtaWFBDVgp6VER2V1FF'
    b'dDJmalFXaTVKMEhxR0NHdTI5dTRIUVFRbWVtYjJVdDRrb214ZEhlU05SWWEza2NsbFZ2eW10'
    b'WXl3Wm10bnIyYWk2ZFJMCndBemZ1V2x4WktCMFN5T2tiL3puUDFackZtQnNqUnZ2ZGVjbTFn'
    b'ZWExSnhWK3hMbTRoMENMclVCYmxzTDNPWExJSmpNTTNZdU5tYzIKaEFVdVRMMS9EcWJoMkE5'
    b'cjAyd0NmRS9tWS8zNU5ZZ3FJbUhONWdLU0JXOWZVcERzYTBibUhBdlNzZ3BuN0Z4U2Npcmd6'
    b'ZW1EL001MQpDTUYvKzlRbkFKRXZPekR3cmZsNHFtVU5RbEVyRWkwaGIzRnR3ajR1WlhIQkpO'
    b'WXVWMUYrZXk2K3VPZ3VaT1F0aEVtMC8wL1BRWlhECnVGcjdFRXdIUG9TU2IwSDBqaFNNWk9X'
    b'aXNYVUpyZzVtSnVyUUp6YXNmMDNMSmhYRmN5ZXhyQ3dNVjdvVjZTa1cyQjFXT093V09Pd2kK'
    b'SEk3UHZpWTUwNUNTN2tMNm5FellrdE5oYytiQWJJMzlPRWxabWtMRVA0eWdid0sreVZGTVRZ'
    b'MGg2UE1oRkk0aUhKWVJDa2NSREVVUgpDa2NROHZzaGpVK2k2VVlPT3NkY1VEUWgwWWY4MW9C'
    b'bHRDUkxGTWsyQ1U2N2hNeFVCY1ZmVUxHZzJJYjdWdDJQd3ZLdkFnQmFMNTdCCnUyK2Z4L1d1'
    b'Q0xxSHpCajNtdUdYckFoRWJBaEZMUnhFd2pMZTB1SUpiSCtpQU9HZ0g1Nlh2ZmlvUDVXRFFs'
    b'alQwN0xTTVV6NlJiUU8KcG5Fd0RDUnlDSXgxb2QzRlFZZ2ozdDNBQ0lzUkZpTXN4Z2lMRVJZ'
    b'akxNWUlpeEVXSXl6R0NJc1JGaU1zeGdpTEVSWWpMTVlJaXhFVwp1OVVTQVlRNURHeTYreWNa'
    b'Q1lqdW1UMlZnZ0FBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VBTWpBeU15MHdOQzB4TmxReE9U'
    b'b3hNam93Ck5Tc3dNRG93TUlWaXJ6TUFBQUFsZEVWWWRHUmhkR1U2Ylc5a2FXWjVBREl3TWpN'
    b'dE1EUXRNVFpVTVRrNk1USTZNRFVyTURBNk1ERDAKUHhlUEFBQUFBRWxGVGtTdVFtQ0MKIgog'
    b'ICAgICAgaWQ9ImltYWdlNTYyMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_72')

IT_72 = b64_IT_72
index.append("IT_72")
index.append("Italy Campania")
catalog["IT_72"] = IT_72
catalog["Italy Campania"] = IT_72
country["Italy Campania"] = ('IT_72', '', 1)
lookup["IT_72"] = ('IT_72', '', 'Italy Campania', 1)
lookup["Italy Campania"] = ('IT_72', '', 'Italy Campania', 1)
details["IT_72"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_72"] = ('IT_72', 'Italy Campania', 1)
regional["Italy Campania"] = ('IT_72', 'Italy Campania', 1)
#----------------------------------------------------------------------
b64_IT_75 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc0Mjc3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQXB1bGlhLnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBl'
    b'PSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxu'
    b'czpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBv'
    b'ZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5r'
    b'IgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0i'
    b'aHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnM0Mjgx'
    b'IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3NDI3OSIKICAg'
    b'ICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAgICAg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAgICAg'
    b'aW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tlcmJv'
    b'YXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAgICBp'
    b'bmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc0MjgzIj4KICAgIDxpbWFnZQogICAg'
    b'ICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVBc3Bl'
    b'Y3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVR'
    b'dWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9S'
    b'dzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJUVUVBQUxH'
    b'UEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2'
    b'bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBUApCRWxFUVZSNDJ1MmRl'
    b'V0FVVlo3SHY2K3E3eVAzMmJrVFFtNkNNSUVrb0VMQzRTaHhCSFIxeFVFWkZZUmhablRkbmQx'
    b'Ulp4MTF4Qk1aCmJzVVI1SWdEUmxoWFZFQlVJbXFBMFFBaElYY0ltTE1Ua2s1M3ArK3Vldk5I'
    b'eHhDdURPNllaanZ6UG4vMXIrclZlMVgxcWZmcTFhdWoKQ2FVVUl3TlpjK3N3YyttdlA4Ym9v'
    b'b1ZFRFRNM2hyYU5VTGtjR0Q0T1U4Z1VNcTQza3V0Y3Zzc2dkcjhQMFU2MDJjUS9IMjZ6Mkww'
    b'YgpnaDNnaWY5UGlQWUdVRkhzS3FHV0dpS1A1U0x1Rm5zT3dHM2lnbWRESGttTlIwVERJYUxP'
    b'NGtLTDRPZ1VEUWU1OEFVZ0hEVWZwK1pLCnlIVndka0MwQVlBNmt3dVlBa0RzZWc5T0E2VCtY'
    b'Tmg4c2U4dzdHMUVrMG0wNDhYT2JhQUNGem9QRW4vYTg0bG9QRUxrWVZ6SVhMSC8KRkp4Nm9o'
    b'bEh0Tm5VWEU3N3E0a2lsZ1RlRElDYVR4THRlRllMQVlrZnpOOFNlYlNvM3kyMmJ3YXZvdjJW'
    b'bEZNU2JhYll2Z1h1UHFINgpmcUtJNHhOK0Q4RW9uditRU1B4ZytCeXlFT0hNMDlUYXdNYytC'
    b'bGVQVVAwQVpLSFVkRnlvV3c2QXFOTm96d2VjTmhPT2RnZzI0amVKCnRtOGRLRTUwVTNzekpF'
    b'RkM1WjJjT2t2czNFYlVxUUNJUElhYVRvSlRDelVQVStyZ0U1NkFMRnBzMzh4cE1zWE9ZcUpL'
    b'QmtCVVk4WE8KSFVTZDRjbEpxUHNsTlI5bkNnSENVMGtRcEVFa2NCcDF0SUh3a0lad0NoMFZY'
    b'VnprQThKM2EwbElFZkhQQmVHNTJFZTV3T2xRcDFKTwpEVWNIYkdlNXlJWGdsSnp1QVhCcXNl'
    b'Y2dwTUdRK0luTks4QXBvWWlITEJLeWNFaUR3U2xKMkx5QjBwUnhJQndYUElNS2RzaENpQ1FZ'
    b'Cm5BSUEwZDRBV1pEWVhRSmxJaGRTQkNMbFFvdTRxQWNoMXhGSklIZ1ZBUEJhSWdtQ0xBU0Fl'
    b'SDQvQ1o0akRoNFo3RndvdHI1Qlc5YnkKOGY4MUVMYXNweTFySU5yZ2FJTTBHQUFjSFVMalUy'
    b'Slh5VUFDU3cxNDdZWGxsV1BnN0FEQXgvMEhkYlNKbmRzQmZpQ2x2a1E4OXhMYwp2UmNTbThx'
    b'RnVsOXprUXM4ODc5ZkF3ZUlpdHBhaVNRUUFFUzdjT2EvaGRaTlYxM2g5amZoNnFMR282QWlV'
    b'd2dBWFBRU2FNYUorZ0ZEClhNd3YrYXhkY0J0SjRJM28vUlFBNUpGRWt3b2lCMEFJNFFKdXBK'
    b'WXFVTmZBOHJZR0xxZ0FsSUlLZk1wYTJ2MFJ0ZFlPWkJWK0Y1KysKbWNqQ0lOb0hFdnY5aEU5'
    b'WncwWGNOMkJPZEFBUWUvWnpBZmxjNEkzVVdBWUFuSUlMblF2QkRBQ0VBSUNqbmZaWER2eTJ0'
    b'eEpWS2o5MgpGUW1iSzNaLzhFL2ZuWEYyd2xJamluWSsrVVdoZXBIbzdJWDVoR2lwZytFTFdC'
    b'djRyRjNDbWVlRmhzZkIrOEYrbG9UY0pyWnZocU1WCjdoNHUvZ25oOUNLb3hnQWdRVFBBYWRC'
    b'L1NqajNDcC84Q3AreFJhaTZIMEkvN1MwRlhJSzFBZVlUZk5BTUFHTFhIdGpPVUdzajhTeW8K'
    b'V3lSVTNnVlpPR1JoWE9UOUFJaWxTcWhkRG5rWUhIcWlTcUQ2RXVwb0ZacWVoUGtrRi9VSWRi'
    b'UlNmWW5ZdlFmeVdBRGdaR0w3bTBSNwpBMUhHWGM5emtXK016bEEzeUpXT05pcUE4RC8rcWwr'
    b'dE9EWTY4dzhjRHBLcjlZYThXaHk3dEdjd2hReW1rQ2xrTUlVTXBwREJGREtGCmpQOTNTRWJI'
    b'WnJqZDdycktyOXo5RFlLbGliTTNpZllXSXZSQnNMamNWQ0VqbENnRVBwaFhoRkkra01yQ09H'
    b'VXlyeDJibko0dmw4dVoKd3V2TW1mcHlZOHQrbUw0aHBtK0l1OTNwaHI0WFpoc0FTSGlJSXJw'
    b'NjRhZUdoSWRNMXVnV1FBQUNnQ0E4RUQxbGZuNmg0NmhmcmwvYwp2REZwZVV5aHQ5RzMxcDhy'
    b'ZXpUQStZbXBSMmpyQnNjaEpneEtHU2FuNGN0VEtNcUh6WUhOeHlMZk42WUhPMnlMVWs3TXpy'
    b'WUIyRnVHCm9ud0lJcG83Y0U1dmF1djRTcXY2U3RXOStxK1ZzeEp2V2hzU2tjQVVlby82WTZz'
    b'NnEvZDF5NkZSSWlNZUdpV2VQQlpta0NxWDlIY1UKNVRzQmZGN0J2Mis0V1crMU5BWVZPT3Rr'
    b'T3IvU3JBUVU1ZVBUYXVtZnprYjZ1WjNQVE5USGh0RitHeHBiWEZiblIvMTJXY0hDUFV5aAo5'
    b'eUJCczVXSzE5VUtaQ1pDSWNOM1hjVEdTZVRVN1NjVGoxWWpVWWVDYkNFemJ1ZldJNkZxY3Zq'
    b'ZVFxTy9CaVlyeXV2aHB4R1ZvdHNoCjRSMENVblJ3dW1HeFF5RkRxeW1DTmFSZTVidnRXelFs'
    b'd1hWeis2WmtDc1VIa1pWRW4wcHQ3elRBYklCZGd0UE5rTXNnbFdCT1JyZVUKUjBzM3p1cmhj'
    b'TUV0b05jZzNCL1NIaDRJMFkzLy9ScnpiOExaR2k3ZzNRQXk0elNXTTRWZUpMcndsbU05WDZl'
    b'bkN4OGZSYUlPb29ndQpzellvUEVhdGpZQThRcFJHU09SYThGcVhJT0VsTWkyMWlXNno0TEpL'
    b'aVYxMGRBbTJkbjFubTlqZm9RdXg3djhyNHRMRWI2YTVjbWJOClliWFFxMHo4MlgyMm5wVlJJ'
    b'VktuMzIxRU0wNmlUWjJXT2tXdFZsOTdEaVpqWDNQdElhMnB3bkR1WU5JVS9ZMkxIbVdYOWw1'
    b'RnBkWUUKSlArOHk1WklaYkc4SmlVbGE5b1A4aWNJUWxkSEUxd0dxNm5MZ2FBeHVVOUlwVkpm'
    b'N1JiNDlHc3hnaURVVkh4dTd6blcwZG9NU3FWUwpYaVpYYU5SYThFcTFSbXR6RUpWYUs0cWkz'
    b'V2FXOG02WDNXQXhtK3gycTlQcEZBVlh1QzVKRVRRdWFzeE5vV0c2SDJWN3I5ZURGNzU5CmFj'
    b'L3pmT2FFbWNETXdTbE9wN09qdmNWcE01aU01eFVxSWppTm5JVElBNkljVGhJVUZaMFJuYVJV'
    b'S2pHNmtJeXk3WkhKWkhIeFNmaG4KZ2cxenMxcm96UkdaeHZyYXVpb3ZGSlNVa0p5Um5zVVUv'
    b'dmg4dk8vbGg4YTg1WVdDL256Z3pvejBFcVp3SlBxNGtIdWw1MDg4RDk2egpjK0hJVnBTYXdG'
    b'bGxhUnVyQWozaFd6VUJzOHJTMWxjRmVjSXRGNGR2MXdiTUtrdGJWemtRYnEzeG4xV1d0dVpV'
    b'c0NmY1h1Yy91eXh0CjlmY2g2ODU0aWVlN2trb0Q0di9ZTTlZdEFNQUt2U2RNZHJrQjRIbDlV'
    b'bWxBL0hPOVl4MHVBRmpSbVZRYUVQK3NJZFh1QklBWHVwTksKQStLZjdVdXhPUURnaGM3RVF3'
    b'SHh6eHBUTFhhbTBJdGtvQTlBSnUyVjhBQ1FRWXdBTXFsQkt2R0VmUUF5QklPbjRjM2crZ0Jr'
    b'aWowSwoyWkJsaGQ2QmtQUUJ5SFQzcUh6ekhyNnZYaGVXNURjZFB0TnlZNzdURTc2YjMvakYw'
    b'SEJLVTJsVDY5VHZ3NTM1VGFWTnJWUHpCc0ozCjhzK1VOclhsNXpzOXA3emkvT1pEVGUyRElW'
    b'UG9KWlJTT2p2Rk1SZ3FwQmdheWlVL0lKUmRIREtGSTRoWkNIdnA1TlNyelZWWXpTcWIKK1Jx'
    b'enNpclZkcFgvMWVZNkVNRVVqa3hmUCthVzN6ZmRjY1Zaa2VlcU4rNTRkWUx4V2pza3pRb3N2'
    b'dnNYZFJuNVY1ejdlSFEvNjg1NApsWWh6TlJ0M3ZEckJhTGoyUlJMczlnMGxHNUpxdnhrRm0r'
    b'L3pDaU9hcTlidGVQa0grZk9RYkxWczJybDZGRmowN1RzVkVXZXIxdjNsCnRVbkd2c0VwTGVO'
    b'VEZMcndZUmF4ZGZmR2ZsTTExT0xpZTM3VGxKckRGRjZYOXJOcTNUdXZUZXE3VVA5cUN5Zmx2'
    b'YmRGRXhBd3pGSXUKcC9QVGV4L08zUDNwb01VTk8xY3Z2WHY1bWJSYzFwQjYyOS9hNHBYRCsr'
    b'c3pHVDAvVGpaVWYxWDVyZWUzVkNZckxONVVOYTl3TUZtYQoxYkp4MTdyRW1xTk1vVmY5clNs'
    b'K2JYTGZoZmF6Ym9nL3Q5c05vTEgxN0lvM1Y3ZDNkdHoxOUxKVEZSVlZEVFVYTGdUbDhzSjMz'
    b'cnpjCllrTE5FYWJRRzRTZk83Mm0rTFhjSWZXdnJuQlM3cEQ2OTd2MUw3UjJ0Rzgvc01kb01P'
    b'd3AzYWV3d3U1MFRKdDQwVnNUVjdiNDd2b0UKSDZ5TG5LLzVxMTVUdkhLb3Y5cUNTWk5MTG1v'
    b'L0ZVVHl6SVpYR3B2UEdBVHI3Z01mL3V2czI3ODlkZUs5L1h1ZFR1Y1ZMTTY5WURIZApZdG40'
    b'cnUvVlJWOVM2R3FvWDFlOE1tK292K2s1azBzMmF3TUgvTDM3K1lkMVp4dGxja1ZpU05TZEV3'
    b'dnZMYnhkSnBldTI3TXRJU0xtCnZMSG4rUEhqcis1NHZYamZub3NzL3VWeWl4dG9WUVZUT0NL'
    b'b0trNU83cnZ3UWJ5ek0zSnpkNy90RnhRNE9HVkNVdnFHclc5SmxMTGMKbk1sN0R4L2s1TEtI'
    b'NWkvSVM1M3dZVzBaei9OV3E5VjEzcnpncC9NdXJZdVhXdXdQcVRqRkZJNDR6ZG5KMmJ2K1BG'
    b'ai9CcVIydEFTRQpCaldWViswKzlGRjJlbFovajdHNnNUNHBNdWJXY1ZObVpVODlXRmJxSHhW'
    b'MmVWWXl1YnlnK0kyR3FlTlpqOVM3Uk91RzFqOEEyL2Z0CjVuanB4TXp4eWRrWk1qdlZkM2Q5'
    b'ZnVKcnE5RklIYzdDM0p1T1ZwYlRVTldkQmJjZE9GcjZ3VmNITDhsTXJsVEtZNk9ad3V0TWJ1'
    b'cjQKTjRxM2ZQRFIzcHlrakR2dnVUdEs2Ukl0M1RwSmZiT3BjL3ZPOVRsak0zcTd6Ni9hdktI'
    b'dHpIY0ZFL0l4aXZDdDBabmg3c2ttSnlSdAplMm5kaTV2WDdmcmtmL3dFWXljMDJ2N21hRTNF'
    b'YVgwRmNmWWNxNitLa1BwcnRmNEw1dDg5T2w2eEg0VzFFTURydTdiT3pNNVRxalJCCllicEVk'
    b'OU9zS2RNRFNXMktzbkxPdENKSFUzRkZ6V0dUMC9MRnlhTVlYWXlxQi9KL3MzQXhnUHo4L01h'
    b'MmN4WmpUL05uaitVa1ZidDEKT083cSt0MExaUjNudTFJVHhtRFVJY0ZvWkV4VUhLTGlhTmZQ'
    b'Rk83RFZkMVpCZmM4VFFqeDEvcU55bzBkemU5VUVIa2tBS0pLdjZaSAplNGVrSVV6aENFRi82'
    b'SzdsbEFBZ2o4Q29abFMvMmVUNVBqT25ZQXA5bkJGN2paa3AvSWR3OVZ2Ky9pdm1uait5RUs3'
    b'cGNUUm52NFVwCjlDcEpYM3k3LzVISGhyZm83QzBIQUtmKzcrYjIyWlBQeGV3OXhCU09PRGFk'
    b'VGk4ZHVBcmlnYlJOSmFYTGYzdEZpNVRTOHRLTi9uM3IKS1lYS2RieTVmcmpIMU1xZWVUbjJ4'
    b'VGZrNGtBK1JwNHo2Q0tad2hGQm1qZmxrVHNlN0JwaU1XSERPNlcvK3M5TGtuVzJOcXgvNVZj'
    b'Tgp0UlcxSFVIN1d4K3BhK1hxdi83alo4VVBDSUp3ZVo1SFhsd1YrdHhheGZmK3pCeFpObU8r'
    b'TUgwR1V6aFNsT2Zjc3VRU2krdUxEeTMvCjdkQTBuM3k4YzltL3J3a01UNC9JWEhyN29vM3lp'
    b'RG45WWtLN0tmaXpmZHN1eWUzb1M2dERubnBOSVlpRC9wYk9uUDlsNGIyK3RVOTgKYjNTbVBP'
    b'ZVdod1hYcHIzYndsM3VDeGFCNmV0ZTlpUlk4T0FUSE1jRlJrNllsRHNWd0Uxelg2Z3NQNUNZ'
    b'a2hjY2N0SHpwWWVmWHhuKwpoOVdEL3ZvNXNtekd2TU9GQzlpNTBCdWN5QzFhTW1kaGw0Uy9x'
    b'RVY5L0ttQmtPY0JlUHdCVUNpVU9WUHV1TlRmaXBYaGYxaXRjZ3VECi9wWVd6djFpeG4yc08r'
    b'TTlqdWNWTFM2Ni80SkZTdU5YdlQxb2NYZ09yMWdaOXZSbC9tYiszRWQzaFE4UGN4L1BLMW9N'
    b'Yk5xN05jd3QKZUN6R3JkcHlzS3RiTWV6OWQyZDNUOHptM2NxaDdXZmhIYjdyejhjVUtpVmtl'
    b'SXNTaXRRZEgxNTdoaDUvcFRNWFhqSmRKZkdseHNtWAoxblZpZEtERWJiL2M0cEtpQytmRmE4'
    b'ZHlGWDlFY04wUXFXVUtSNFJwRXpKL0VXb2tndnZTUG1yZTdVdUtGbmIvRUl0V1FwWVZYTUVm'
    b'CnFQZ3ZxczY1VXlleWhuU2tlT09ob3NtZkhQbXl0YzlrdS9qdCtNTEpyeXNzV2ZVTkF5SkF6'
    b'QzVxSW5MUFhVQk9GQUk0bDJxSTR0clkKbU1EQzJmTncwZGliUmltYkZLWmFldXRjMzlvbnZ2'
    b'MDkwdUh5cDNUVis0ZWVxQ0VSbk9QMXdxaGJja2I4bTJyc2U2US85Z0ZFeUwvTgpMYWpwM1Rk'
    b'SnAvV0NQOWFRamhRM1IwaUxwbVNQN20wYzVRcnZ1MjBHUmp2c2s3Sk1JWU1wWkRDRlRDR0RL'
    b'V1F3aFF5bWtDbGtNSVVNCnBwREJGREtGREthUXdSUXltRUtta01FVU1waEN4ditSdndIN1JG'
    b'OUthb0owTGdBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXkKTWkwd015MHhORlF3T0Rv'
    b'eU5EbzFNaXN3TURvd01BYjJlNFFBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qSXRN'
    b'RE10TVRSVQpNRGc2TWpRNk5USXJNREE2TURCM3E4TTRBQUFBQUVsRlRrU3VRbUNDCiIKICAg'
    b'ICAgIGlkPSJpbWFnZTQyODUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'IT_75')

IT_75 = b64_IT_75
index.append("IT_75")
index.append("Italy Apulia")
catalog["IT_75"] = IT_75
catalog["Italy Apulia"] = IT_75
country["Italy Apulia"] = ('IT_75', '', 1)
lookup["IT_75"] = ('IT_75', '', 'Italy Apulia', 1)
lookup["Italy Apulia"] = ('IT_75', '', 'Italy Apulia', 1)
details["IT_75"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_75"] = ('IT_75', 'Italy Apulia', 1)
regional["Italy Apulia"] = ('IT_75', 'Italy Apulia', 1)
#----------------------------------------------------------------------
b64_IT_77 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc0ODQ3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQmFzaWxpY2F0YS5zdmcucG5nIgogICB4bWxuczppbmtz'
    b'Y2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAg'
    b'eG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3Nv'
    b'ZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94'
    b'bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpz'
    b'dmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZz'
    b'NDg1MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzQ4NDki'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNDg1MyI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUNRRkJNVkVVc1NIZ3VTbnBCV0lLU202dEYKWElSS1lJZkZ4'
    b'Y1ZTWjR1MHQ3eW5yYmE4dnNHM3ViNm5yTGE2dkwrbXJMVzR1cjQ5VllHOHZjQ2ZwckpQWllv'
    b'd1MzcHFlNWUxdUwxWAphNDR1U1hsaWRaU3ZzN3BnY3BKWmJZK29ycmRwZXBjdlMzcFFaWXFn'
    b'cDdKUFpJa3pUWHMyVUgxb2VaWk1Zb2c0VW41SFhvWXhUSHN5ClRYdFliSTVwZVpaUVpvb3RT'
    b'WGszVVg0MFRueFZhbzFxZTVoVWFZd3VTbmsxVDN4UlpvczRVWDVOWTRsYmJvOC9XSUV6VG52'
    b'QXdjT0QKajZRNVUzK1duNjdFeE1URHc4U01sNmsvV0lKQVdJS05sNm1VbmF4R1hZVTdWSUNG'
    b'a0tYQndzT2NvN0F2UzNrdFNubTV1NytNbDZpaApxTE91c3JtK3Y4S2RwTEhEeE1TdHNibVlv'
    b'SzZFa0tTYW9xL0F3Y0tWbnEyK3Y4R1NuS3cvVm9LL3dNS2xxN1ZXYW8xeGdadXNzYmhmCmNa'
    b'R3p0cnhuZUpXNXZMOXdnSm91U1hvelRueHdmNW8vVjRFMVVIMWZjcEp2ZjVwZGNKRmNiNUF4'
    b'VEhwVGFJc3ZTbnBKWDRhWG42NjkKdjhGOGlhQkNXb09QbWFvOFZZQ0ZrYVZCV1lOOWlxQ0dr'
    b'cVYraTZLT21LbCtpNkdXbnEzQ3dzTjlpcUc3dmNDWm9hK0xsYWc5Vm9DcgpzTGhkY0pCNGhw'
    b'Nnl0YnRsZDVWM2haNnNzYmt5VFh4M2hwNWFiWTluZUpaa2RwUkRXNFNSbTZ0MGc1dzlWb0dI'
    b'a3FWL2pLSjJoSjB1ClNYaVVuYTIydWI2SGtxYUtsYWlLbGFleHRidGxkcFdBaktLMnViMXNm'
    b'Wml5dGJ4Ulo0dGlkSk51ZnBsbWVKVkFXWUkrVjRHd3RMcHQKZlptQmphTXRTbnFDanFPeXRy'
    b'eEZYSVV0U0hoU1o0eGVjSkZ1ZnBxYW83QlZhWTBzU1hsZWNaRXRTWGd0U0huLy8vLyt4TEQr'
    b'QUFBQQpBV0pMUjBTLzA5dXpWUUFBQUFkMFNVMUZCK1lERGdnek0rNGVDa0lBQUFNMFNVUkJW'
    b'R2plN1piclZ3eHhHSUJmMGx0V3lXWnNXOUVXClc3czdNWVhOcFpTSm9wMVl5a2E1ckd0Rk5P'
    b'UVNsbEt1VVRZcmw5cVFlK1Irdi92YnZMUDZoQzk5OE5OeDN1ZkRuT2VjK1REUE9mUCsKM2hr'
    b'QWhtRVlobUVZaG1HWVB6SkcxSVBHUm8yQWNjS3lvbkVFeEhBV1ozRVdaM0VXWjNFV1ozSFcv'
    b'NVVWTzk0MC9PZ0pjZkhERmo4eApZZGhNNDJNRlowMHkwK01TSndOSVV5eGtjVWtBMXVRVXNw'
    b'UlVLOERVYVVaeW1nMGdQWU5zdXJDc0dmYlV6Q3dBaDlNRmN2Yk1XUXJrCk9IUEJObnZPWERm'
    b'a09lMWduWmVXNUFLWGN6N0Fnc3lGYnF1b3JQd0N1cVFuSWk0cUxDSnpMbGF4ZU1sU3NwSlNG'
    b'ZFZseThuS1BCcGkKT2JYRGlwWENac3U3eXJPYXBxZEN3OHBsbmpVK3JLeGFoTnJhZGRVYTFs'
    b'UlZvbHJ1V2I4QnRRb1RxaG5yTnFZTGU0bWIvRFF6bTdjQQp5RnU5Wk51MksyQ2JhUXo0amxv'
    b'M1dGTXJ5T3JxWFFCSmNXU3pkb3JLMmxWVzJ4Q2pnTHhiZ1QyTmVwSUNVcjROWEh2MWZVMWd5'
    b'NWZBCm5hMDM1b0d5V3dabHY1NThRTmhzYldxaXk4RkRLallmemlNN2NsUkZ6Vk5HRmppbW9W'
    b'cDZuTXplVWprOFpWWnhlOHZTZXFMYWg1cEYKeGZpMjlwT244QlRaaHFqVFVYNVVMY1dvclc5'
    b'cE8wTkdpV2RQbkJPM0lEcm9sT0g1Q3dyWU80MkYyblZSQWxrM3BpeEJsMEdxM1dFcwowNkFk'
    b'M051N3llWUpPNG1YbHVxaHl3cTRhVEU1ZW9LTkVsaHBUK1JlNmJ4Q2k2UElDazJOblQwT3V1'
    b'VUdaV0VvVFJJMld4MjB3ZUhxCk5RMFRyc3RrdlgwMWFHN0pJWE9FVGVodkRaQVY5SHRSS3kw'
    b'aHV5SHNKRWFuaEVNM2k5SFhqSGhySUhpMEJwRytSbWR1QisrWUkrWnYKQy9aTlFHeW1neEFW'
    b'OGl3UU5sdE9ZN2J1M3BPaDl6NGw0WU9IdVRBL1pId25UZjBPeU5NcENmM2hBTWdYQjhrZUNj'
    b'dnF2VnJmL2xnQwpvSTNaTVJSK0lrZk1NZVgrbkp5SUZmU0Vod0lSazVMYnQ3cUV6ZFpUWTdh'
    b'ZTNUYmg4eGVTTVZFdnZXZ0pHdC9KM0tBRjY4SjBFa0RTCkI5RWNtVExsbGJEWjZnNDJMTkVp'
    b'ZjFOZFliMnYrZWMvMTJ1OTBCc3g4NEFlZmhNeC83bUdsaXorTytVc3p1SXN6dUlzenVJc3p1'
    b'S3MKdjhuYmtXUmx2Uk9WQmU4Ly9NckhLaVBoVSsxdk56NS9nWC9LUHArbEJFWWhYd013S3Zr'
    b'Mk9yTytBOE13RE1Nd0RNTXd6R2prQitEVQo0aXVPTTBtTkFBQUFKWFJGV0hSa1lYUmxPbU55'
    b'WldGMFpRQXlNREl5TFRBekxURTBWREE0T2pVeE9qVXhLekF3T2pBdytBeS8zZ0FBCkFDVjBS'
    b'VmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNaTB3TXkweE5GUXdPRG8xTVRvMU1Tc3dNRG93TUls'
    b'UkIySUFBQUFBU1VWT1JLNUMKWUlJPQoiCiAgICAgICBpZD0iaW1hZ2U0ODU1IiAvPgogIDwv'
    b'Zz4KPC9zdmc+Cg==', 'IT_77')

IT_77 = b64_IT_77
index.append("IT_77")
index.append("Italy Basilicata")
catalog["IT_77"] = IT_77
catalog["Italy Basilicata"] = IT_77
country["Italy Basilicata"] = ('IT_77', '', 1)
lookup["IT_77"] = ('IT_77', '', 'Italy Basilicata', 1)
lookup["Italy Basilicata"] = ('IT_77', '', 'Italy Basilicata', 1)
details["IT_77"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_77"] = ('IT_77', 'Italy Basilicata', 1)
regional["Italy Basilicata"] = ('IT_77', 'Italy Basilicata', 1)
#----------------------------------------------------------------------
b64_IT_78 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc1NTY3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQ2FsYWJyaWEuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczU1'
    b'NzEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc1NTY5Igog'
    b'ICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAg'
    b'ICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2Vy'
    b'Ym9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAg'
    b'IGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzU1NzMiPgogICAgPGltYWdlCiAg'
    b'ICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6'
    b'ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZC'
    b'T1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQVlBQUFCa1c4bndBQUFBQkdkQlRVRUFB'
    b'TEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FB'
    b'QTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFWCjBrbEVRVlI0MnUy'
    b'ZGVXQVU1ZDJBbjVtOXNydTU3NFNFSXlFY09TRGhSZ1RrUGhRNVZOU0tWbTI5dGJiYTZ1ZlIx'
    b'a0t0VnR0cTFXS3QKZU9CWkJleW5WQlFvY2dpWUFFbUFIQkFDU1VqSWZSK2JQV2ZtK3lPd3la'
    b'S0RZUDNRSlBQOGs1MlpkMmJldlB2czd6M21uUm5CdFBRZApCUldWN3hoUkxRSVZWU3dWVlN3'
    b'VlZTd1ZGVlVzRlZVc0ZWVXNGUlZWTEJWVkxCVlZMQlVWVlN3VlZTd1ZWU3dWbGU4S2JWL051'
    b'RmxuCjQ5NXhueEZvYk1IbTBxRVZaU29zQVd3OGZqbVZsa0Ewb3NTOTR6WVQ1TlZNamRVWHA2'
    b'eEJralVFZUxYd2ZOcDE3dU9FbWh1NE9pNFYKazhhT1hkWmcwanFwc2ZyeVdmNFVHdTFtVmlY'
    b'c0lNeGNqeVJyeUt1UDRvdFRFd0h3TnJSeXc2aXZVUVFaUVFGL0x3c242eVBabkQ4RgpTUkdK'
    b'Q3l6bHp1UXRXRjE2MXV5N0NhZlVWdFNocGtidVNONkN0ODdLaHJ6cERQY3ZKeVhzSkkxMk02'
    b'MU9Bd29DUG5vcmh5cmkyRlk0ClhvMVlseHFMMDR1L0hMeUdsTENUSEs2SzVibTBheGtWVk1K'
    b'enM5NEFRSkkxdko2NW1FV3hCM256Nkh4ZXk3eUtkVWNXWWRUYTNjZVkKT2lpWFYrYjlqZHpx'
    b'YUY1S1g4cHJtVmZ4MHFHbERQYXRZc253VkFEZXk1bURTV2RIRVhCTE5TS3dsSDhzK0N2ZmxJ'
    b'M2tqY09MV0hkawpFWDgrY0EwUjN2VThOMnNkQnRGSmZ0MGdYankwZ3FWeHFmelA1SS9jNTZ4'
    b'cTllUHAvVGRTYmZVam95S09qNC9QSU1Dcm1kTk5ZYnlVCnZveVgwNWV5S2U5eUJ2dFVxMVho'
    b'OTRVa2E3QTR2ZENLRXMxMk01dnpwNUlVWElSSjF5YVBROUpobDNSSVNsdTBFQVNGRDQ3TkFp'
    b'REUKMk1DYW1ldDVOMmNPKzBzVDJvK3BpUHc1N1ZyT3RBUzUxN2xralR2aWlDaXNucjZlcllV'
    b'VHlLa2U2azZqS0FKL3oxeE1zTEdKMjVPMwpBbERYNnNPWEJST1lOeXlEbStLL09pL3Y3VVh2'
    b'bExWSWl1QmVMbTRLWld2UmVGV3NId29KSVlVY3FoeE9xOU1BZ0l5QUFHaVFBQmdmCm1rK1lx'
    b'UUdBSzRjZndDV0pmSjQvdWROeGJKS09YYWVUM2N1Q29BQnQ4eUV2aThvbVBxaUVyWVVUT3Uy'
    b'bktBSVpWYkZNajg0Nks2UkkKYVhNd3o2WmV6MzBUUHVXeXFCeDNXbGtSTzN3VzBBanQ4eTF2'
    b'VGRwS1NWT0kyc2I2UGxFUW1CVjlsTVV4QjlCckpPN2JlbCtuRkhlawpmSUdraUl3TVBNTjcy'
    b'WE1BR09wWFNaM1ZENW4yU0tFVFhSaDFEa1JCUmxaRVhMTEdMYWtvdG4zeFllWUdHdXdtS2xv'
    b'Q3VzeFBsU1dBCmNITzlXMnlOS0xIbDFDU0crVmV3ZXNZNzNQWDV6em5WR0lHQTBrRmNtQmll'
    b'UjVpNUhwY3NFaHRRcmpiZXYvK1FLN1BqZERJMVZsK2UKdmVKTi9JMFdtaHptRGlrRS9wRjVK'
    b'VmFYbnZGaCtaZ05OZ0JhbkVaQ3pBMElnb0p5dGhxSzhxbGg3dEFNYm96ZnhhbkdTRFlkbjhh'
    b'WApCUk9SRkJIeHJBaVZGbi84REJiQ3ZldTdsTXRiMTBxOXpiczlmMmNqMGRxTUpVVDVWUEhN'
    b'ckRmNDZaWmZlTlFWaWdJSEtrYnl6OXdyCkFMaHYzR2ZxY01QM3pia3E1ZXVTSkRJcWhuUFgy'
    b'SCtmVnoyMWY4Nm9HazVHWlN6and2UFpkWG9NUWNaR2xnei94cjI5c0RHYzE0OHMKSnI4dWtx'
    b'eXFvWHhaTU5GZHhTbG5JOXZCc2xIazEwY3lmMGg2bC9rWkcxTEFudUl4N3J5Smd1USt4cHE5'
    b'TjJOejZWazk4eDMwb3FzOQpqMExIK0FYcnMrY1M2VjFMbEcrMUt0YjNoVTdUL2dXOWNXUVI4'
    b'Mk16bVJtZDdkRStFZ1RaL2VVTzhhbGhja1FlaHlwRzhNYmhSVHc0CjRWTW1SSjd3U085anNO'
    b'SHFNcmpYbVhRMnQ2RjJXY2R6YVN0Wk1Xb3ZpY0hGSG5tNWVuZ3FMa0hMNjRjWG5hMWFKYlJu'
    b'enczUTZqTHcKK083YmlRc29JOGJmczdvVDIydGtXaHdtN2tuNW5HYTdxYzkrTHhyZHFPVlA5'
    b'Y1dNZSt0YnVYM3NWcUs4YXdrMk5kRmtOM093WWdUaAo1a2JtRDAwbjBOekVqT2hzZlBRMlFr'
    b'Mk54SWVlWnViZ2JPYkZIQ0t0YkRTbkdpSTVXRDZTS2tzQVMrSlNtUkIrZ3JHaGhjd2Rsa2wr'
    b'CmZTUWJqczNBNmpKd1M5SjJra0pQRTJSc3dTbHBPZFVRU1dsek1JY3FSckJzeEQ3aWcwOHpO'
    b'cXlReTZPeWNTZzZYanl3QW9lc0k4elUKd04wcC95YmF0NGFSZ2FXa2xvMEdvTWxoSXF0cUdQ'
    b'SEJ4V3d2SE0rTjhUdUpDeWpEcUhNUUcxREdwUEE4Rmd4TEo4cW5tZzE1TS9xcwpXSUo2KzVl'
    b'S1doV3FxR0twREd5MGFoRjB4dGVvWldLc0w2TWl6UXdOOHlMWVI4Zi9aaGRqayt6Y21CeEhi'
    b'Yk9Mb2lvcmVXV3RIRGpWClNJUEZwUmFhS2xiWEdIUWlzeE1DV1RZcG1MRkRmTkNJQWloMkJF'
    b'Y0JncXVhRFg3cFNLSkVnbjh6WW5Bd3lxZ1lGQ0VDV1ZISU90M0MKcDRlcTJYNjBEcHRUVmd0'
    b'VGJieURWaFJZTWlHWU8rWkVFZUtyUTNUa29XbmVodGk2RjlGNUVwUzJjYWlmTVFlN29PVlZa'
    b'VnZiWUtrZwpvdWhpY0ptbUkzdlBSVFlrME5qcTRwMDk1WHkwdnhMN0FCZHNRSXNWRjI3aXFa'
    b'WERHQkZoUm1QWmc3YmhMVVJiWnFkMGVVSWdUekFkCmdOOG8reGxENTRGTDJaQ0l5LzgySk84'
    b'NWxOYlpXYk94Z1BUQzVnRXJWcDhkeC9wdldUVTluR2R2aWlQTXF4Ujk1YU5vRzlZaHVDcTYK'
    b'VEx0UkdFa0Iva0RiS1Bsa09sL0xFNlFxTkpadGFLeHBlUHNuc1hEaVNCVGdjTkhBbEd2QTlR'
    b'bzFJangxYlF3UExoNk1vV1VUK2pNMwpJbG9QZEp2ZWlZWnZpSFF2cHhKQks3cnVDOVNXaWFI'
    b'MFpnek5IM0QzdkNoK2YwTXNPbzJnaXRXL3BSTDQ3YlV4WERrK0NGM3RDK2lxCjF5QW90aDcz'
    b'U1JQQ3NYUVF5WUdHVkNKNlBwRmlSMWZ6UExxcVh6Ti9qQi9QM3h5SFhpdXFZdlZYZm5uMUVC'
    b'WWxCNkt2ZkFKdHcvcGUKN1JPbHREQkphYS82VXFoa21ORFl1NDVCODJiMEZZOHdiYVFQVDZ3'
    b'WXFvclZIN2x1YWhqWFRnNUZWL2NDbXBZdHZkNXZNRTJjRXRxbgp4K1FUU0pUUyszYVR4dklW'
    b'dXVvL3NEZ2xtRnRtUktoaTlTZUdoaGg1Y0ZGMFcrL05lQmtJaGw3dmU1UVFhdkZ5TDdlZ0k1'
    b'UFFpK2gzCmE1QzkycWJmM0xzZ212Z29zeXBXdi9nSEJZSFZLMk13Nk5yK1ZjazBGVWY0aXlC'
    b'NjlXci9nNFIzc1M2aTExSTVRcDVHOGxubzdqajgKOXRvWXRHTC9iOHozKytHR0pSTkN1R2FL'
    b'WjRSUmRORW9oZ1EwclR0QTZmbHlUQVFXcGdybEtBaEUwY0lkeWxHU3FNWVB4MFZKZFk0QQpi'
    b'eDBORmhjNVp5eHF4T3FyNkxVaWQ4MGQxT1UyeVRRVlI5Z0xGNHhjTlJqWlJUUXQ2TENnWXll'
    b'RHFjYjRyYVE2eDAvbVJHTFVpNnBZCmZaWDVZd01KOWROM3U3MDNjbzJobWx1VWJId1ZPMmJG'
    b'eWMxa000NnFieTBWUUlCWngxWGpRMVN4K2lvcnA0UmRNSTFrbW9vOXJPYzIKbHpkT1JsQlBI'
    b'UFg0NE94WnF0Q2VwVHJIOVZOQ1ZiSDZJa09DdlJqZHl4NlliSnB5UWJsNjFWQVBmUnJKZTJI'
    b'djhoZHFaTlFna3lwVwpYMk4yWXNCRnBmK3Y1THBJcWM0eEp5RklGYXV2TVdtNFg3ZmJ0bXo1'
    b'SEVscW13NlRtNXRMUWNHcC8wSXVMWTZ3NXp0SnRXM2JWcjc4CjhndjNlYnBpd25DZmZpdFd2'
    b'NXpvcHhFaFB0cTcyKzB1cDR2VnE1OUNFQVNDZ29KWnZteDVwOGhscVB3NXlMWUxTeFgrSEpK'
    b'NWRpZXAKSG43b0Y4aXl6Tk5QUDhPeTVjdTczSHYwSUc5TWVwRldSLytidTlVdkkxWjBrQkZU'
    b'RDkzNVJZc1g4OW1ubjdMaDQ0OEJpSXFPN3JKYQpkSW9tWGhQRzhwb3dsdjNDSUE0SzRlNWxL'
    b'MTVkU2dYd3lhWk55SEtiTEJzMmZOempEMkJvcUZHTldIMUdyT0NlTDlub2REcEdqUnJOCjBh'
    b'TkhTRXBNNnJiTlJjVEwzRmwyUDRKaTdWV2tPc2Nmbm5tR0syYk9RSklrbm4vK1R4ZjRFUmpJ'
    b'N1llRHBmMHlZb1g3WC9oYVlGSlMKbTFBSmlZbmROK2k5eHVPSWZBVkZNUFphS29EQXdQWkdl'
    b'V0JRenczMDhBQ3YvdmdWOUUreFRBYU4rL09ISDM1QWFXbHBwelNKU1VtRQpoMGNRRXRKNW9Q'
    b'S3R0OTZrdHJhMkM3bTZsbXJYenAzczNyWHJndm5hdDNjdi85bSszVE92L1hRRXZsOVdoVVpk'
    b'KzBYZXVYUG44Y1RqCmo5RnFiU1VoUG9INGhBUVNFaEpKVEV3aWFVd1NGb3VGdkx6ajVPVGtr'
    b'SnVUUTA1T0RuZmZmUS8rL3Y2ZWtTdjhPUVRKMGttcWQ5YS8KemF1dnZvb2d3R1dYVFd2ZjUy'
    b'd2I2N0gvZVJTTnBrMzBBd2ZTc05sc0ZCUVdjT2VkZDNYNkVhaGkvY0J4ZGVoa2hZU0VZTFBa'
    b'eU16SQpJRE1qb3kxTWl5TEp5U2swTlRjeGU5Wk1XbHBhUFBiMzgvTnp5M0QyaUdpYlBrR1Ft'
    b'cEM5WjNwVWpla1o2VFExdFUzOCsrS0x6dk84CnRtM2IybW5kd1FOcGJyRmNrcUtLMVZld090'
    b'ckhqdkx5amhNY0hNeTgrZk5KU2hwRFVtSVNDWW1KRkJTYzRxOHZ2c2kvL3ZVcGhZVUYKWkdk'
    b'bms1T2RUVTVPTnVYbFpUZ2NEdlI2UGVCQ1gvRXJOSmFkQU9qTDdzY2U4VEtJYmFQbXExYmRR'
    b'bTVPTHFJb2NPOTk5N3ZQKytRVApqeVBMTXI5YnZRYWRybTFxOHh2cjF0SFEyTUR0UC9scGUx'
    b'N3RraXBXWDZHaHRYMHFURkZSRVk4OS9rU250bFIyZGpiWjJWa0lna0JzCjdIQmlZNGV6ZE9r'
    b'eUFEWnYvZ3lyMVlwZUwzcElCU0RhMGpHVVArQ1dhK0xFaVd6YzlJazcwcDNqMTA4K0FjQlZW'
    b'eTNCeTZ1dGdUNTcKOW13a1NmYW9aaHVzVHJYeDNsY29yV2wvTXZLQ0JRdTdiS0RuWkdmVDNO'
    b'eE1TVWxKcDIxTGxseU5uNSs1azFUbnk0WGM2aGFxbzFUZAo0ZVBqNnlFVlFFbUh2S3BpL2NB'
    b'NVhXTzdZSnJzN0N5UHZ4NG96bTZsNms2dWp1elpzeHZsN0lQYWRsMmd0MWpjaTd5cVl2MUFx'
    b'TGM0CkthbnRQaExZYkRZS0NncmFJbGRPZG1lcEtoL3BVU3BQdWU3dkpOY0g3Ny92N2hXKysw'
    b'NzNkd1BWdGJnb3JWTWpWcC9pU0E5M0lIL3cKd2ZzODhNRFBlT2loaC9IMThlUFlzZHlMbHFw'
    b'ZHJveE9jdjNtdDA4aGltMUZ1M3JObW03M3pTeHE2cS9GMzMrZk5yUG5XQU5YalEvdQpjbHR5'
    b'Y2pJcEtlTVFCSUV6SlNYbzlQcHZKZFg1Y3RralhnSFJSR1JrSkFjT3BxTW9DaVpUOTNPdWR1'
    b'YzBxR0wxTmI0NTBVQ3JYZXB5CkFITGN1UGEzUGtSRlI3dWxraXo3K1VpKzVWdWRiNkgxYy93'
    b'N3lHVTA5bnh4MmVHUytmcDR2U3BXWDhQbWxQbmljQzNYVEw3QUZPQU8Ka2FwWjhlZEo2WS9m'
    b'Nm55SjJxTUVuaGU1ZW1KSFZoMHROa2tWcXkveTRkNEtsazhLUVJTRUMwb0Y0Q2MwOHBYMk1y'
    b'YktpeS9xUExPRQo3Y1JRMkdXMTJCMy8zRi9abjR1K2Y0dDF1c2JHZjdMcW1EOG02SUpTQVFn'
    b'b1JBcGx2Q1EvakpYZXpaUFM0T0lHM1h0b085eGtjU0c1CnZqN1cwQytueWd5SVh1RTUxbTQ5'
    b'ZzhNbDkzcElRWStkTzhXMXZUNyt6ZUxiK05IWXE5NGlnQ1REeTErVzlQZGlIeGhQOUx0OVZp'
    b'VDMKekkrNnFDR0ZWT1V5MHBTcDJPbDZ2cFJCc1pNaXBETkQ3UGs0c3RjNGo4ajExcTV5MW03'
    b'dC8ySU5pSWZicnQ5ZHh1V2pBa2dhYkVaZgovZnRlRFNsTUVmYXpUNTdCRm1WSmw5c25rY3FE'
    b'bWovMWFpaENYL1VranZDL2tGL1J5dXYvT1RNUWlueGdQRzFHa3VHUjkwNVExZWpBCjZiOEtS'
    b'ZXpkM1RIMUJCQkhIdVZLQkFsQ0ZpTTVScWtTUllLUVJiWFF1eHRPRmNFTGwvL05ORmxkUFBw'
    b'ZVBrNUpVY1hxVDlRME8zbmsKdlpOWWxCZ2NFV3RSTkg2OTJpOU1xRUNEVElSUVRyaFFqaUMw'
    b'ZmU1ZDZmcmdqSGlaVnMxWWZ2WHV5UjR2TTZsaTlXRnl6clR3d0p0NQpOQk9QUFhJOWltN3cv'
    b'OXU1RkcwNDlzZzNzR2pIODlENkUyUVVOZzJrb2g1NEQ3YzlXdHpDVDEvTDVVeExCTGFvRDNI'
    b'NVh0MXQydHZFCjExa21ma0t5a0hGeFZhLzNBdXpSSDFOcEg4YmQvempPd1ZOTkE2MllCK2E3'
    b'ZEU1V1dMbHRiUzU3OHB3NFExYmppRnlIYkJqVktWMnMKY0pJSlFocnZhbGVTSWh5NmNKVFN4'
    b'K0tJV0lzajdJL3NQNmx3OHl2WjVKeHBHWWhGUEhCZmVWSnZjZkx3T3lkWW1CekVBd3ZIRUJy'
    b'MQpJWnJXVkRTTkg2R3g3Z2VsL2NGcUdpUVdDNXZ4RlJyWnJyUzk1TkxiL1J4U0xaSnBDcEx2'
    b'U2lUVDVkUzBTS3pkV01EbTlCb0dNdXI3CkNnRXZuY2lLeWFHc25CckdvRUFEeUJZMDFqUUVX'
    b'eFlheDBtUXFrRnVRVUJCRWJ4Uk5ING9odEhJaGdRazAxUVFmU2h2Y0xBeHRaSU4KMzFSaWRh'
    b'anYwMUhGNnRndUVBVEd4L2d3SXo2QXFjTjlHUnhpcE52TGpBb1UxOW80a04vSW51TU5ITWh2'
    b'UWxiVW9sVEY2Z1ZHdmNqUQpVQ05CM2pyTUJoRUVBWXROb3E3RlNWR1Z0VjgrekVOdFkxMENy'
    b'QTZaWS8zOFlySGFLMVJSeFJvb21MUTJERnJuZC95RktPakV2di9HCjFqNWJGVVo2MTNKcjBq'
    b'YWNzZ2FyeTBDWXVRR1hyT0YzZTFkNXBMczFhUnM1TlVNNFdEN1N2UzRwdEpBYlJ1OGl4citD'
    b'SFVWaldYZWsKNjRsOVA0cmZSV0ZqS04rVXhydlhYVEg0S05PanM3a3lOcFVkcDhkUjBSSklt'
    b'TGtPazliT3MyblhVOTNxeDhPVE5qSWpLcHRTU3hBTgpObStpZmFyWlVqQ0pEM0ptRVdHdVor'
    b'WG8zY3dkbHM3aGlqamV6NTNGOGRyMjUzTXRpRG5FaE1nVHJObDdreHF4TGpXRGZHcDRZZDdm'
    b'CjJWMlN4UE5wSzNrbGZTbS8zdk5qTklMYzl2YlRjejBUUVdITzBFeVdqOWp2c1g5VzFUQytQ'
    b'cE5JdmMzY3JWUUFzNGRrY25WY3FzZTYKWGNWamVEdHJIdDU2RzV0UFR1Ymw5S3Q1Y3MrdGVP'
    b'a2MzREYyQzRvaThLZTA2eWl6QkpKYk00VEhkdDNPeDhkbThNamtqeGdWVkVLNQpKWUMvSGxx'
    b'R2w4YkpwaFBUUEtRQ0dCTld5SXhCV2VnMVRsV3NTODM5NHovalpGMGsrODU0UHR2cU4xL2Zn'
    b'a3o3K01ETXFLTnN6SnZCCnRLZ2Nna3puWFZaUmVuN3RTRkpJSVR1THh6SjUwREg4REo2ajU1'
    b'TGNkb09HMHVGY1hsb0hpdEplbkpLaVFSVGFKTjlYbW9DSVFLaloKOCtZSlNmRXNmcVBXUVUy'
    b'ckw2ZWJ3NWc3NUxBcTFxVkVJMHJNakQ1S1ptWHNCZFBHaHhUejZZbXBIS21NWWZHd3ppKzdG'
    b'SHB3YTJwVQpMaC9tekNLcmNoZ0xZdEk5dHRsZGJRLzVHQk5TeElLWVE2eWV2cDRXdTVFWER5'
    b'NC83L2d5QWNabWZqSjJLMm5sY2V6dlVLVXFDSngvCitvVXhoOWhhT0o1ZHhXT1lNZmlvS3Rh'
    b'bEpOallqSStobFNhN2Q0L3B6Rm9ibzRPTHVTdGxDeElpYzRhZDk2NW5RV2tiNWV3Q1FWQ0kK'
    b'RHlyaHgwbmJjU2thWmcwNTRySGRwV2hRRkFGUmtIQktXdkxxb3huaVY4bWpVejlDRU5xUG1S'
    b'UlV5TlBUMzJiZXNIUWUzSFlmTGtuYgpRU3dRQmM5eHNPVFFVNnlJMjArMGR3MVRJby9ocmJl'
    b'cVlsMHFxbHI5cUxUNDQydm8rZUx1a3JoVTNqeThrQTl6citEcHZUOGkycWVhCitPQmlqNnF3'
    b'b3dRZG1UWW9oNjJGNDloMDRuS2UrK1o2NGdKS0dlVGIvb0p4V1FFWmdkemF3WHgxT3BuM3My'
    b'ZnoxTjViV0RGaUg5TUcKdGQreWY2UTZsbDk5ZFFkT1NjZDFvL2Q0bkVOV1JJK0lhZGJacUxi'
    b'NjhWTDZVcDVKdlo1anRZT1pNelJURmV0U29TZ0NPNHRTbUJ4eApvdE8yb2Y2VlJQdTJ2ZWRt'
    b'WkZBSm1WV3hOTmxOMU5oODJWMDhob1V4QnoycVZPVzhkdGFLa2ZzQW1ERTRpMjJGNDJteW02'
    b'aHM5U2V0CmRCU0xoaDd5YUJzcGlPakU5dnNDaTV0Q2NTa2FSRkZwRDBtQXhlWEYrem16V1pX'
    b'NGcwQmplenRQUVBZSW1GY09UeU8xZExSN2VXOUoKSXRPanNsV3hMaVYveTF5Q1NXZm54MG5i'
    b'MFp5dFRvYjZWZkxyYWU5VGIvTWhNYVNJQnF1dnh6NTdTcEtZTStRd09rM2JHSkZPbER3YQoz'
    b'ek1IWnpFaXNCUS9Rd3M2MGVWdW9BUHNMNHYzcUE1OTlWYTBnb3NRcndiMzJOTTlLWnZaVjVM'
    b'QS9qTUpiY2ZYT04yU2ZYUjhPZzBPCk03K2N0TUVkSlgzMFZuZmVBY2FGNTVOZU9keTl2TE5r'
    b'TEJNalRuVHFPUFFWK3V5MVFrRlFtRFg0S0NPRGloRVVNT3JzNU5ZTXdlcjAKWWx6NENSeXlq'
    b'cnphS0xZWGpTUFd2NXlGc1FjSjltckNwWWg4WFpMSWxFSEgwWW95NVpZQTlJS0xVSE1EcGMz'
    b'QitCcGE4ZExhT1ZnKwpraDFGS1F6eksrZjYrRDBFRzVzb2FRcG01K2xrbG8vY1M3aTVIcXZM'
    b'aXpOTlFlZzBMZ29hSS9qaytPVUEzRFptSzdFQkZhQW83QzlOCllQUEp5Vnd4NUFpTFl3OWdk'
    b'ZXF4dWd3RUdadXBiZlhoaTZJSlRBZzdTWmlwZ2JLV1FON09tbzlaYTJOVjRnN0N6WFVvZ3NB'
    b'cjZVdXAKcy9xb1lxbW9xSmQwVkZTeFZGU3hWRlN4VkZSVXNWUlVzVlJVc1ZSVVZMRlVWTEZV'
    b'VkxGVVZGU3hWRlN4VkFZbVdnV2ExV0pRK2E3NQpQL3lscVpvSEcxM2dBQUFBSlhSRldIUmtZ'
    b'WFJsT21OeVpXRjBaUUF5TURJeUxUQTBMVEl5VkRFMk9qUTVPakEyS3pBd09qQXdpczVFCjdR'
    b'QUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0FNakF5TWkwd05DMHlNbFF4TmpvME9Ub3dOaXN3'
    b'TURvd01QdVQvRkVBQUFBQVNVVk8KUks1Q1lJST0KIgogICAgICAgaWQ9ImltYWdlNTU3NSIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'IT_78')

IT_78 = b64_IT_78
index.append("IT_78")
index.append("Italy Calabria")
catalog["IT_78"] = IT_78
catalog["Italy Calabria"] = IT_78
country["Italy Calabria"] = ('IT_78', '', 1)
lookup["IT_78"] = ('IT_78', '', 'Italy Calabria', 1)
lookup["Italy Calabria"] = ('IT_78', '', 'Italy Calabria', 1)
details["IT_78"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_78"] = ('IT_78', 'Italy Calabria', 1)
regional["Italy Calabria"] = ('IT_78', 'Italy Calabria', 1)
#----------------------------------------------------------------------
b64_IT_82 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNzg2NyIKICAgd2lkdGg9'
    b'IjE1NCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTQgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJTaWNpbGlhbl9GbGFnLnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBl'
    b'PSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxu'
    b'czpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBv'
    b'ZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5r'
    b'IgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0i'
    b'aHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMxNzg3'
    b'MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzE3ODY5Igog'
    b'ICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAg'
    b'ICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2Vy'
    b'Ym9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAg'
    b'IGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE3ODczIj4KICAgIDxpbWFnZQog'
    b'ICAgICAgd2lkdGg9IjE1NCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1p'
    b'emVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlW'
    b'Qk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKb0FBQUJrQ0FZQUFBQitaeWwrQUFBQUJHZEJUVUVB'
    b'QUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdB'
    b'QUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBYQpERWxFUVZSNDJ1'
    b'MmRaM2hVMVJhRzMrbVRUQ2FUbmhEU2dCUktJRlFCUTFFQjZTQ0lpcUtJb21CRnJpZ2lBb0xv'
    b'eFlLaWdCU0ZDeWdJClNMa0lTSmNpS0VVSW5RUkNDWVQwbmt4djUvNFlpakdoaUk0a3VlZjl3'
    b'OE01Kzh6czJlZkwybVd0dGJmRXNrWWpHTjRMd0pralIwVEUKWFVpRUVnU2hUSXB4cWovbWxk'
    b'NGdpSTBpNGlhaFhmMlA3VGNQREJNQ2NWeFVpQzBqNGo2aEFRaG1DYVl2L1RBdDlBR0gyRUFp'
    b'YmhMYQpWZXhIMU9nbkJPSTRxeFJiU2NSOVFuT3BUWUpwa1E3amREK3dTY1RXRW5HVDBLN2dP'
    b'S05FUHk0SSt3bVYyR0lpN2hQYVZldG1YdXFOCjhYTS9CSk5VYkRrUk53bnRxblZMVjJDWUVJ'
    b'aHR2NGZZZWlMdUU1cHJhZ3JtbGQ0WVAvRkgwSXZXVGNSZFFydUNNMWVPNGYwQXJOczAKWWt1'
    b'S3VFOW9WN0Z1OWtML1hnQkNrVXhzVVJIM0NRM0FXU0REK0lrL2xyVmFzVlZGM0NlMGE5WnRs'
    b'eWVHaVlHaWsxN0V2VUlERVBSUwpqSitJVG5vUk53dnRLcmFEYWd3VGduQ2tpVTU2VVdnbDdy'
    b'VTVvcE5lNUI4UjJsWHN5U29NNHdLeEo0dHVMRkZvYmxlYnkwbHZtdUdICllCV2Q5S0xRM0l3'
    b'ajlZcVQvbmoxc1c3SGJSYStNSlZTNktQQm85UklUNm1LZ1o1YVJMOUlGUllhQUU0d3IvTEcr'
    b'SkUvZ3JGcXY2NTkKVmpOem8vMVpNSEVZL2pvdmJIWUhueTNkUlBxaXJVelMrWXNxcXRKQ3Uy'
    b'cmRMbDl4MHUrcm1rNzZQS2VENXpRT3Rzd2JqNmU2ZkJCbwo3MzlOWTlLRklpSmw0cXo2VnR4'
    b'MVV5SUxzK0U5UHhPdktibElkTTRxMVRoMkJGN1ZGekpqd25NVlJBWXdjWGcvcHBjVml5cXFE'
    b'a0p6CjJWVlE5UzNEWiswbGxKME5WYUpLVmtIZ2hkSjhobzE1aW1heGtaV1dhVkUvaXN1eHRT'
    b'aHlPa1VsVlF1aFhhMU1vQVB0OUd5MDAzS1EKK3QyOVJUZTk0T1RKMGp3R3YvTTBqM1JxZGRP'
    b'eVEvcDJaS1d4VEZSU2RSTGFWWlJkOWZoc3VJVDZrZEovL0x2em5RNEdXMHFZOU9tcgo5THV2'
    b'eFMzTEQzaWdGUnNWdDdab0oyd1dVV2hWY3BiaTdVUXpLUS90bkN5a0lmWi81RHN2Mm0wOEl6'
    b'RXlhOFlvMmlYRVZyai95N0ZVClRCWnJ1V3RxcFlMb3RvMDRaYk5XTnJHK05xRllaektJUXF2'
    b'S0tEc1k4Vm1ianZySkVyZlc5cmpOd210YWdlV3p4OUNvYnUwSzkwMFcKSzg5TW5vZE1XckVT'
    b'ZmRvM1k2TzVvcEF1Mlczc3RKaVlWbFpFbnRNaENxMnFJL0Z5b2htYmoyNVJCckk2dHIvOTgv'
    b'ZGFUSXp6VmJCNgo1bWpDZy8wcUxUTm45UTVpd29OUktpcUdQM1c1SjU2ZnNWZXdac1ZPSnpQ'
    b'S2lyalVDS3lONVp5eVdURUlUbEZvVlIxNUN6TzZWZWw0CkRDMkd2eW1ZZDZmRnhHZWhHdGJQ'
    b'ZkpOQW44cUROdk9MeS9qM292VjBhdFd3MHZ1ZWFpVitUZXBTOWpzUjVUcnNEQzNNWVpmRlJI'
    b'aXcKaWc2SjNqeFprRVdaVXhSYXRVQ2lGdkFjVllCdXhXWGtEZi9hQUh1cjJjamNTQjAvZkQ0'
    b'S0g2M25EY3U5TVgwWlBub3pYZTZKdjJHWgp4SVFZamx1djF5Zkw0U0E0VHNYd3ZrR2NPRy9r'
    b'MjAzNUdMVWdRU0lLclZwWnQvb1dkTXN5OEJ4VmdFUXAzSkhJbHRZUFl1MjAxOUY2CnFtOVk3'
    b'dnVmRHVDMSt4UkJmdDdFVnpKMnUwcnp1Q2lPL0c1bU9ib2tqNjlHUjZGU1NPaldXa2VIWmxy'
    b'VUNpbGY2b3RGb1ZVM0JKbkEKbnJyRjVFMUxSNTVndnUzbk5wb05MR3NRelBjZnZvcGFlV1Az'
    b'MFlMMXUvbjJveVVNMDNnVDFTd0dpZVRHMWlndUlvUlUrL1h4WTQ3TQp5WWpQTDVGMHhzaU1W'
    b'Ym5NK1c4T1UxNElaNm14OVA5U2FOVTZzSC9uSGxnd3F3MVNxVUJJOUg3ZTdxbEY4bm5BVFoz'
    b'MEN3MmxIRzBkCnpmZmpobFk2c0JjRWdVMzdqdlBKL0hVa1hpcGdudGFmZFNZREhadlZ2Mmxk'
    b'YWdmNWt2MjdNVnFyT0EwUGRmZWpXRzluZjdKclJub3cKeFVBRGhRcm5IZnlGRnpnZGFDVlNs'
    b'QktKS0xSL21vUjRTTXMveDd3My8wVjZUanY2TDFqS3ZmZGRwRm15RDNWU3ZRaVV5ZEJLcEZn'
    b'RgpnYk4yRzlPTXBUUjdvaE9MbnVsZHdUclpIUTZXYnp2QVY5OXQ0dDZzTXI3UzZQRFYrZ0t3'
    b'eDJKaVRMTzRtOVpGSnBWaTg3aHVIUjFwCmR0YnNMdVJBaWhHZFJvYlI3R1J3TjM5U2JWWktu'
    b'RTU4cFRlVzJubTdqVzhOcFp5Vk9LbnRsSEJCTGFWMjY0YWs3VTltdGRwWEZOby8Kalo4dkxG'
    b'K2N4ME9QZk16QmVkTjRzUFVISEVwSjQ2QnZHZ2NpY3NncUtNWm1kNjFmaFFmNTgyNlBSQkpp'
    b'd2lzSWJNbW12WHo5elFiNgpsRmhaNHVtTmg3Yjh5enl2VVJBWEVYTEwrc2prMTZmQ2ZhVWFk'
    b'QTlxVVNpS0FJRWdIemxTcVlTM3ZQMXVLcktaK21JT053NW4vSFBQCjBxSitGQmV6Qy9EWGFm'
    b'anZ6aVJXN1RrSmFySHJ2Q3VFMTRaZXZZcjU0ZWZEUE5TeE9TMGIxS0ZsZ3pxMzlleXV3eW1N'
    b'KzNRSnZmSk4KclBEMFJxbXBQRlJKSGhwdzAvSFpOU3YydTZXTFBoNWU5SjZUU1owR0h0Z2Rz'
    b'UGU0bmpGRk9qcHB2Q3QvRmhoZGtrLzhNOTFZTTZoNwp1WHVQajVsSmsrUk01bXI5eERIYTNl'
    b'U2ROMkRZaUMvWmNxQURRM3QzcEVYOXFGcys4OG5palJ4ZHVKRkZXbjkwR3QyTkp4eUFRblY3'
    b'CjhXYUN5UVpYb29sa1FHK0xKMTBIQnVOMENCejZ0SUJPYWsreUhIYk8yVzIwVTEwWGRhYkR6'
    b'amg5RVErLy9oaURleVJldDZRWmVReDYKNVdPbU96Mm9xL1d0MXUrb1JnaE5xWVNGY3h3a245'
    b'N0I3UGs3K05lTU1EbzNiOFh6ZlR0U0s4Q25RdmwxZTQ1d1l1RW12dEFGM25yZApEbkRhYisw'
    b'KzBwdk02QnpsbDFucW9jQmtjYkp1Zmo1ampONFVPWjBNdCtjeFV4NUlrdFhDVEZNcGx0cCtS'
    b'RFdzeS9nK0hjcFo0Z3VaCmVUdzFZaXF6QlUvQzVkWC9OZFdvZFBJR2NURDlZM0E0THJQcmw4'
    b'c01uSGlBTlZQRzRxdTl2Z21OMVdabnlwZmZzOXo3OXJzaG04SE0KK1l3OHZ0dXlGNFZDeGhO'
    b'ZDJyTDd5Qmx5aTBvWjNDTVJQMjhONlRtRmhNakt1eXVPYXExMGlmSmdveDV5SFE3bUo1aG9s'
    b'T0ZCUkpHYwpGMlJtdGl6OUNKMVh4ZTQ2UGFlUVFTT21Nc3VoSmx4V00xNVJqZHkzUUNhREJ6'
    b'cUF6MmNaOUhwdE1sK01HRTdMQm5Xd094eThPV001Ckw0L093ai9MRDlNQ24rc2hGamNoKzFJ'
    b'T3owNStuNmt2aDZGUVNMai9wWFVNNlI1QTE5WTYrcjIxbWM0dFk3aVE2U1JRY24yUWJ4VUUK'
    b'a2l3V2NncHQ2TE50TE81aUliNitob0JEWmxDQnpPSEVvNUl1dWRSZzRyRi9UV09hVFZVakxO'
    b'bTFudUZ1NXd5NG02eHMrT2h6T0h2YQpEN3ZUeXFNRDlEejcxSlVaWjVJYS9ZUWdIT2NydnZC'
    b'RFZqTXJnb3lFTnZkZ2MxSUpNMGRHTVgxVkRucURrM3BoS2lLQ2xldzVxc2Z1CkVHaWY0RVhi'
    b'ZUMwRDNqN0x5MDR0ejJ0MHZHY29KQzBlYkhZbkxlSTA5RTcwNVQ4VE12bEE1bmR0UFU4MnBB'
    b'c2pCejVZN252Zlg3Q1cKT2l0L3BadTZabTBGVnVPRmRzMHE1WUMvSHlqK29DbkJJc0Uwenhm'
    b'VFZ6N1hOb1ErWWJPd3FKbVpYaDE4V2ZOeklXODhIc3Fic3k3UwpJVUhIYjhsbFRCc1J5YWZM'
    b'c21rWnAwSGpLZVhwOTgvelpOY0FQRlZTc2d1c3RFbVM0WGhDVFVxNmhVWlJhaDVvb1dQY3VE'
    b'Um1Pd05SClg1bTlPb0dCK256bXpCdExUSGp3dGZxOE1YMFozYmVlb0tteVppVmExOGl1MCtt'
    b'RW4zOEZsUkthSjRCS0JjbG5ZT1g4UUdLamxKU1kKckJqTURrd1dBWnNkTko1T1BPN1BRN2xY'
    b'UnAwOE5mT01wVXpzR2NucW5RV01lN28yTDA2OXlMOGVDMkgybWx6NmQvQmw5S3gwanA0MQpF'
    b'dXdycDFhQWtyMXpHL0xCb2t5S3l5QTJYTTI4QzBXMHk1VFFzNjJPcUZvcTVuNlFVVTVrNFBJ'
    b'TWpGTnBtZnlmSC9qbTNXSFhya2VFCitKUGhzTk1VVVdoVmxxU2o4Tk5PT0pFTUlWb05lL1lM'
    b'cEZ3MDBidXJsQmJOd0t6Slo4ZEJIK3JVVXFGVXlGRUlBZ2FqQTIrRm5OaTYKbmpBQXRoMHFJ'
    b'VWF1SWNCSFRrcTZoWDVqVXdrTlZMTHZsSjVtTVo0VWxOcEpUak94YUZ4ZDdBNkJ6ZnRMT0po'
    b'aW9NemtvS0RZUmxTbwppdFlOdmNqSXM1S2NhaUxucTFJbTJYeXBiQm11aVVMRnVhUXo1YTdk'
    b'MnppYXVaYjE5UFRRaUVLcmFwak5zRzBuYk5rTzJSZTh1SmdPCmRlL1ZvVlByV1RnbWpBbnpM'
    b'ek9tZHpRTjFWYWtyV0RYMFZLSzlYWUtpaDI4OG5BSWdUNXllcjkxQnBsTVFwOUVId1FCUGwy'
    b'YXpmdlAKaHlFSThNTFVDOHhibTBkaUV5L0NBNVVNZXRDZlJSdnlXZlpUQVFuUm5zaWtFalNl'
    b'VW55OUZSdytiV0JZM3lDV2JDbkFhQllJTllIawpKcTNzVTJMQ2FMWmVTK2RySGhmRkNXM055'
    b'eE90RVJuOUthbGdNa1B5WVMwdjlRckg3blRpZEFoa0ZWazVkTVpBd3lnUGZrb3E1WFNHCmdY'
    b'VGxhVjU4T3hOQjRxUi9SejhXLzVURC9TT1NlZi81TU5iOE80YTFlNHFadno2WFRpMjllV2pz'
    b'R2RiOVVzUlRYUU1ZK1dnSWRXdHIKMFhrM3BYbkR4NURKdlhpcVd3REh6eHRwR3V0SmJxRWRo'
    b'd1BVQ2luLytUR2ZRWjM5ZVcxUU1QNnY2MWpoME4rdzduNVNHVVZsMThQQQpwVklKclRzMjUz'
    b'Z05TMmFwOWhidCtFbVlPQVY4QkgvaUl4Vjh1anlMMEFBbG9RRktJb004K1BWWUdlOCtHOGJn'
    b'eWVmNGZwbUZGazNoCnVWY2x5T1I2L0p2bDQxTU1iendlU2ZzRUxaZnpyTlFOVlJLZ2t6UDNo'
    b'MXc2Tk5FaWw4bUppZXBQMi9oNkJQd3VBcmRUcTRic09acEsKL1RvWm5EaTdtdzVOSmRTUFVM'
    b'TjZWeEV2UFJTRXhlWmFOMm5UeUl2RkQ1czV1OUpHdEx5aXBWSkl3TzRvdjhieVdPZDdXUHJq'
    b'QVJycgpWS0pGcXlvMGJnVHQyMGl4V09EWWVTTUIzbkpheG1sWTlsTWgzVnA3bzVSTEdmZjFa'
    b'VnEwZG9uTTZZUlJyd2pNbldVbUxnWVdmYXRnCndIMStiTmhYd3VRRkdYUnFxY05QSjhkREpX'
    b'WHZTVDB4VWQzcDNhNXBPWkVCeUdVeTdtdGVuNWNIZEdMQ2N5TTVlbGFHQU5RSlZaRloKWUdY'
    b'L0tRTld1MEIyb1kxQjNRSlk0bStzZk9KU3liVTI4Zlg0VFZ1enp1Q1NUWHliaWRXeDRqWWJy'
    b'Rm9MdzE2RGgrSmo4TlhLTVpxZApGSlU1VU1vbGhQZ3JNVnVkZUhxQ3BsWVI0MGREZ0Q5SUpC'
    b'QVk0UHFNT1Y5THFhY0w0c2Q5eGJSdXFFR3RrR0syQ2dpQ0t5N040WVJSClR3eGczdHBkSEV4'
    b'SlkvdkJaUHgxWG5oN2VmREo0ZzBrblU1ais4RlR5S1JTWWlPaldMWGpJQkZCS2s2bG1lalNT'
    b'c2VlWTJVY1NUWFMKb3I2R2ZMa1QvMk5PdlA0UXVmR2p5VUNQZ1ozeCtsMlVyMFFpNFZoR0Ry'
    b'VXU1QklnbFlrVzdXNXk0QkQ0K2tCa09DeFBPc01QUjlJbwpzUm1SK1JhejlVZ2h3UTJ6K1ha'
    b'N0prTkg1akhqRTRpTEtmLzh5V1JJUGFKanhJQVFBcnpsN0RwY2hrSWh3V2h4NHFlVDg5cWpJ'
    b'VnpJCnNwSmRXRXhvZ0EvLzNYbUk3SUlTNm9RR3NPM0FTWnJHUnBLV2xVOU9ZU2tKTVJFRStt'
    b'aDVxSjB2VGtFZ05FREp6c05sNkUwT2VyYjEKWWZPQkVycTIxckhOYnFvNGtSR0VTZ013KzNa'
    b'b3pqYXpVUnlqM1cwUzI3ais3WEkvT0J5dzl3QWt0akZ3S2dWcWg5cTRuQUhQRGI1dQp2YTV5'
    b'N0NTTW42ekVVaFJILy9aNk5oOG9vVzk3WDM3Y1cweE9rUTJqeVluR1E4cStrM3JheG10b1dL'
    b'YzJVYUdCRkpZWnlTc3FwYWpNCmlOVm1aL3ZCVXdUNzYzQUtBcW5wMmVRVmw3RjRTejVkNy9F'
    b'aHI4U0duN2VNVnZXOXVKQnQ0VnlHaFI1dGZMZ1VMVUI2K2ZwWUVDcDEKUlNVbXhQQ2hZT2Rs'
    b'Y1l4V2hmcC9HYlJyNitvV0d6VUFIeDNFTnl3dk1yTVpSb3lXOFBGN2JaZ3hmQXA5MnpXaGMw'
    b'dHZ6bVdha1FEMQpRdFVrblRaVFpvbkMxN3NkaDFKc1JBWXJPWExtRWxLSkJLMkhpb2M2Tmlj'
    b'MHdJZGdmeDMzdDJ4SWJFUUlDZEhoSkRhSjVWQktHdkYxCk5TemZia0lpYmN6UnN6SXk4cTJj'
    b'ejdEZ29aTGljQXBvNHhUWWhQS09HS3NnVkpxVXJGWXFrTWJWeGlvSW90Q3FDMmZQUTQ5K1du'
    b'bzIKZUozRkUxOGdJc1NmaTltbjhkYklLQ2l4OCsxbVBYbWxMZmhtNGlTK2Z2c0ZYaC9VZy9C'
    b'YUNaU1puS3pjL2h1QlBscWU3dGtPbFVMQgpGOHUzMEtoT2JYNCtmSnBITzkxRDN3N05jUXBP'
    b'enFhZjRJSG1XbnEzYjhIVUVZTlkvZkY3eE5WNW5NeUNNSTZrbXJpUWFTRWhWc05pClkxazVu'
    b'NThDeWJVbzREOXliMEpzdWN3cXNldXN3cXhlQzNPL2pPR2JzUzhTRm5ROU5FaHZncysrVjlD'
    b'ci9TQzZ0MjJDVkZwKzZiNVAKKzVhY1QwOWxlOUl4TXZON0VocmdRLzNJV3VRVmw3Sm93eDVH'
    b'UDlYald0bjVhMyttUVlRVFQ3V1UzdTFiWHJ2ZXZta3M3WnZHVWxSbQpZTVZQKzBsSk80RzhW'
    b'elFETnUvblBZbUdSZ29sTVFvRnlXbVpsVVlGdDQ2dng0RVZ1N2xIcWE3Mjc2RkdPOVduejRH'
    b'amU5b3o1NjBoCktPUi9mdlkyWlBKMDJzVVg4ZXNKTDc0YU81S1V0Q3dLU3cyY3o4eWpZWjFR'
    b'Z255OU1acXR2RHAxS3NONis3SGxrQy96MzduMXFDcTMKcUpUaC8xNUFrNk9YYUsveVlIWDdX'
    b'R2FOSGx5aFhFR0puaUg5eHJEUU4xanNPcXNpZ2dCajNvWGM1TjdNRy92c0hZa3N1NkNFVW9Q'
    b'QQpvbTBaMVBJdlpQaUhzNmtYRnNUWnk3bVU2STBvNURKeWkwcDU2dDFQR1BsSUFFdTJTdmpp'
    b'OWFHMzlkbEJ2dDZzL25nRXdjTjc4Sm01CmxQMGI5NUZ5TWF0Q09YK2RGNFhCdWhyeFRtcWNS'
    b'Uk1FZU9VTkNmVjFnM2oxa2M1MzhMekExei9zWXNtT0ZYejJzWUVtamVEekdYSisKMisxRlZy'
    b'NkdvWDI3RXhjUndzcnRCemlZZklCbnV2dXg2bWNQVmt3WmVkTms1QnV4NzhRNUJydzlrNmhh'
    b'QWV5WU5hYkNIOFdReWZONAovVkE2dGF0NXBHMjFYYkM5RWErUGhXak5JRVk4MnVWUEMyekRy'
    b'OGQ0K2JPdmlZamZ3YXpQYllTRnVtYTBpVzJkQklhWlNkb25JeW5sCkJJdCszTTJ3UGdJZVN2'
    b'QnBjSW1zd2tKT3BVaG9seENEVlBybk9vbXdJRCtlNk5xV0ZkdC80K2paZEhyYzI2UkM5M2x4'
    b'M3lrYUthcTMKTzZwR2RaMXZ2UXRoOG9GL1NtUUdrNFZ2TnZ4Q2g1ZkdzemRyR3N1WG5XUFVx'
    b'L0RIS09xTGw2QnByQ2NPSjN6eFdpU2ZMTW5pMFFmOApDQTZDYjc5MkVIM1BHcnFQK2pjbnoy'
    b'Zjg2WHFIK092WS91VmJlS2dVWE1vdUtIZXYvLzB0V0M1WXEzMjNVeU82VHFjVFJvNlJFS0Y4'
    b'CmxEZitrQk5aR1RhN2c2MEhUckoweTE0S2JFa002R2Zoc1lkQmMrTU5oZGl6RjZaLzVJZlpL'
    b'cUNRUzlCcFpQeHlvb3lGODgyMHZjZFYKSmljWDNuaEhScGk2RytPZjdWdnBUdDUzd2djTDF4'
    b'SDgvUjc2ZVhpSlFydGJPQnp3eklzeTdvOFp3ak85MnQrd1hFNWhLUnQrUGNxRwpYNDlSYkQ5'
    b'QjF5NG1CZzZBc05EYi82NWhRL3hRUzVWY3lESWprMG9ZMml1UWpXZFNtVFd0ZkJOdTJnWlRQ'
    b'Z3hrYVBlSGVLSnJHK1N5CnYrYXYxSnZNZEIzd05tdlZmcUxRN2hZejVvSWs1MGxldWNIQS96'
    b'L3JkdlBWbXAyVTZJMzQ2N3p3VUNsUktKellwRGswYlY3SWlCZGMKMmU2M1E5UFdDbFJTRmZG'
    b'Ukh2anA1T1FVMmppZGJtVGVQQ09ORzVVdmE3SEFvcVd3YkprdkxldTFvVmRpVSs1cFZQZU9K'
    b'Z3dBL2NmTQo0T1BUaFRmZFRrRVVtaHZwL3lRc2VHMTJwZm1SQUhuRlplZzBIcFU2cmcrbHBQ'
    b'SCt3dFUwYW5tTXQwZmR2T3NFYUpFb1k4S2d1bVFWCjJKaS9Qby9PTGIwWjBqMlFYZWZUNmRT'
    b'cmlIcDFLMy91OERIWXVCVjI3NUZqMDllbGRjTTRXaldvUTVQb2NLSnFCVlJZTEs1c29wTDQK'
    b'OUVSVzYyVW9xdWx1UXRWZWFHK09oLzZOeDlHMmNmUWRmOGJtZmNlWnN1UTduaCtXeFJPUHdJ'
    b'M2U1Y1Fwa0hwR3htOEhaVXg3SllvbgpKcDNqcFg1QlBOQkNSN0hlem82VHVTUzBLV1h3UVBD'
    b'NHdZbERkanVjVElHRFNYRDhGSnc5cThSdURNWkxHVVM5c0dEaTY0YlJzVmtjCkVTSFh6NWo2'
    b'OUx0TkZDemN3cWhxdkMxQ3RSZmFoWXZ3L0hQUnJKNHlDbS9Oblo4blpiTTdtTEZpS3h1UzFq'
    b'RnVqSUg3MnQxNG5hNXoKSDJnVzZVL1RLQjltcnNyQktRaTA3V2hnOE9PZ1ZybENrdjVzN3Ev'
    b'RjR2b3RTV3NWYlA1S3hXVXZYMEpqd3NrdEtDWStKWXN4M243Vgplb21nUnN3Njl4NkE4Wk4w'
    b'MUE5cFNVSk1CTFg4ZGRRTzhxVnh2YkEvUFJBdkxEWHc0VGZyU2M3ZHhvaVhiSFMrcjd5RmN6'
    b'cEJiNEM4CmZGajlkUmhHczBDaktBOEVBVkpMczJoeHI0RTZrYTRVdjhBQThMd0Q3Vjg5dFRs'
    b'L2dUY0toNlRhYnI1WDQ0UjJiYTByM1JYUW1KUHIKaXRoSU9xeEdKMnRNcjhSbTlFeE1LTGNI'
    b'eDYzSUtTeGwzdHBkYkV2YWkxOXdKaklaRkJXRGw1Y3JCbTc0TTdCK294Uy9vamdlbjNpTwpG'
    b'ZTlIRXhPbTV0ZzVJMmFMa3hLRGcvY1daTktxc1lLSUJxV01mTWtWNGZ0bnFFbW5OdGY0VFBY'
    b'Q0lsaS9DZFp0bEdISWo2VmI2K2IwCjdkQ2N5SkRiZit0V214MjVUSVpVS3NGcXMvUHBkNXZ3'
    b'cjcrU1lVUGcvZkUrR08xVzhnc0VKajVlbjJYYkNrakxjc1dnSloweFVEZFUKemU1alpSUVp6'
    b'WHc5UTZCWHR6LzVBMnJJcWMzL04xc2lBSmhNc0hXSGF3YVljaktZeUlBWUVwdkVjRy9qYU9J'
    b'aVEyNjdtMTI1L1RjSwpQTDlrK0RPdXBPWE5XMlIwNmV4Zzl0UUFNdk5zUkFTcjhOWEt5Q3F3'
    b'a1ZWZ3cySjE3ZGZoRTVYUEc2OUNhSzA3V0Mrc2hxYzIvOThLCjdZK2tYWExsSGh3NkFpbW41'
    b'VmoxSWZpb2E5TWtPcHhPclJyU3NuNmRTcGNlSG4xbkJwOS9lZWlhWUU2bnVpWUFDeGJEd1cz'
    b'QitHcGwKbUt4T3ptZFlTSWoyNUpmalpkemYzSnMxUHhlUm5tL2gwdy90UFBISUhWUzRHcDNh'
    b'TEFydEZ1Z05jUFM0Syt0OTE0NWdYbjlrSUgzYQpOeXUzcHRWNTlIQitXbC94a0RHckZUcDBo'
    b'MWovQUp3Q3BGNDJFeFdpSkNKSVNVNlJIYlZLUWxHWmd3ZjdGZkpZZi9EVzNsa2RxL3FwCnpa'
    b'VWhuajMvQjd3MHJzU1hTV05oNjRZYzFwMll6cW9kQjhzTHlsTDU2cjVTQ1Z2V2dNS3ZtRUFm'
    b'T1hWcnFVQWl3U0ZBV0tBU1h5ODUKZmxvNXMrZkJEeis2aEhrblZPVlRtMFdoM1FFS0JjeitU'
    b'R0RhcWtXVUdWMEhaa2drRXBwR3R1WGc0Y3FmOGRiQy9EbDJXbmJKeHFZcApRTkFXY0RBOW02'
    b'U0xCYXplWFlBNk5CZU54cFVxZUNMNXIvUkZWZS9VWnJIci9JdDgvMSs0ZVBBeDNuelNGUm15'
    b'NzhRNTFpVlA1b01KCk4zL09ZSFM1dGM2Y2haaDZydlUrVDA5bzBzaTFRT3Z4Ti9aODFzMWVH'
    b'Q1lINEN5c21nbkhva1c3RFI3dUE2dC8yWXJkNGNwV1NvZ0oKSi9uTXJaKzc2anVOalhZdCt0'
    b'N2JHcG8yQnFuMDd4VVozTjFUbTBXaC9VM0laRERnNFVMVzdFb0NJQ092aUtDQUt0ZzkzWVZU'
    b'bTBXaAovYzEwZVFEMkhqOEh3SHZ6ZitDcGdWVzNydi9VcWMyaTBOeEFVUkg0NnpRcy9IRVBF'
    b'WTErdmJZbFE1VWRmTHY1MUdaUmFHNUNid0NOCmg0cjU2emN6NGEzcVUyOTNuTm9zempyZFNH'
    b'a1pQRGxVUWZldU5sNGNXajEvZ3ozbGlwUCtsRW9VbW9pNzFYWjNuUFNpMFA1UGNaeFYKb2g4'
    b'ZmlQMm9XaFNhaUp2NUI1MzBvdEJFY0Y1V29KOFlpTzFYRDFGb0l1N0h1dGtML2FRQWhHS1pL'
    b'RFFSTjF1M2ZCbUd5WUZZdDJwRQpvWW44QTladGh3YkRwQUNjdVhKUmFDTHVSU2lUWXB6cWoz'
    b'bUZ0eWcwRWZkajIrT0ovdDFBbkZseVVXZ2liclp1VjNKTmIvZlVabEZvCkluK0ptNTNhTEFw'
    b'TjVPKzFicFdjMml3S1RjUnRPTTRvMGI4VGhQMmtTaFNhaUx2NzBpdE8rcGwrQ0JhSktEUVJO'
    b'MXUzU3dvTTR3T3gKL2VZaENrM0UzWU0zTUsvMHh2aXhQNEpCS2dwTnhMMDRNK1F1Si8wdm5x'
    b'TFFSTnpQNzUzMEVxRUVoOWdrSW02emJnVXlETzhGU3Y0SApYWVBEcUxHOTNka0FBQUFsZEVW'
    b'WWRHUmhkR1U2WTNKbFlYUmxBREl3TWpNdE1EZ3RNRFpVTVRjNk1qWTZNellyTURBNk1EQTNo'
    b'YU9pCkFBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl6TFRBNExUQTJWREUzT2pJMk9q'
    b'TTJLekF3T2pBd1J0Z2JIZ0FBQUFCSlJVNUUKcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdl'
    b'MTc4NzUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'IT_82')

IT_82 = b64_IT_82
index.append("IT_82")
index.append("Italy Sicily")
catalog["IT_82"] = IT_82
catalog["Italy Sicily"] = IT_82
country["Italy Sicily"] = ('IT_82', '', 1)
lookup["IT_82"] = ('IT_82', '', 'Italy Sicily', 1)
lookup["Italy Sicily"] = ('IT_82', '', 'Italy Sicily', 1)
details["IT_82"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_82"] = ('IT_82', 'Italy Sicily', 1)
regional["Italy Sicily"] = ('IT_82', 'Italy Sicily', 1)
#----------------------------------------------------------------------
b64_IT_88 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMzY1MiIKICAgd2lkdGg9'
    b'IjE0OSIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDkgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NhcmRpbmlhLF9JdGFseS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMTM2NTYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXcxMzY1NCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMzY1OCI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNDkiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSlVBQUFCa0NBTUFBQUM0c29MQkFB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUMrbEJNVkVYLy8vL3ZvYVRZR1NHL3Y3LzEK'
    b'OWZYVTFOUjdlM3RQVDA4c0xDd25KeWNURXhOTlRVMkxpNHVQajQvMzkvZloyZG1CZ1lGUVVG'
    b'QXZMeThsSlNVVkZSVkZSVVdJaUlpSgppWW45L2YyWW1KaCtmbjc3Ky92NCtQaWNuSndBQUFB'
    b'QkFRRkpTVW16czdPZW5wN241K2Y4L1B5a3BLUTRPRGhCUVVHcHFhbjUrZm1GCmhZVjVlWG5S'
    b'MGRFZkh4OEZCUVZsWldYNit2cisvdjZNakl5RGc0T0dob1lqSXlNQ0FnSldWbGJvNk9obloy'
    b'ZXNyS3lnb0tDQWdJREUKeE1TdnI2OE1EQXdLQ2dyRHc4UHo4L05zYkd6dDdlMmhvYUYvZjMv'
    b'SHg4ZkF3TUFSRVJFRUJBU3lzckxnNE9CMWRYV25wNmVXbHBaMwpkM2ZUMDlNa0pDUXVMaTV6'
    b'YzNQdTd1NXhjWEdxcXFwNmVucXdzTENabVpuZTN0NW9hR2pYMTlldHJhM3g4ZkcxdGJVd01E'
    b'QnBhV25WCjFkV2FtcHJhMnRvL1B6OEdCZ1pnWUdETXpNeTZ1cnJKeWNrSUNBZ0hCd2R1Ym03'
    b'azVPVGQzZDBQRHc5alkyUGYzOS8wOVBUbTV1WncKY0hBSkNRbWJtNXZ5OHZKZVhsNm1wcWFO'
    b'alkzRnhjWDI5dlpoWVdHb3FLakt5c3BMUzBzTkRRMWNYRnpwNmVtdXJxNVZWVlhRME5Edgo3'
    b'Ky9Cd2NGWldWbkN3c0xjM053ZUhoNjB0TFJyYTJzREF3Tzl2YjNiMjlzWEZ4Y2dJQ0JFUkVU'
    b'bDVlWEd4c1lwS1NrNk9qcVZsWldYCmw1ZnE2dXBBUUVBYUdob0xDd3VRa0pESXlNZ3lNaktp'
    b'b3FKdGJXMmxwYVYwZEhRN096czhQRHhIUjBlSGg0ZFhWMWRmWDE5YVdscSsKdnI2VGs1UHI2'
    b'K3RJU0VoeWNuSWJHeHRxYW1xOHZMd1lHQmlDZ29LS2lvcDRlSGhNVEV3b0tDaDJkblpDUWtL'
    b'NHVMaDhmSHcwTkRSOQpmWDF2YjI4Mk5qWkRRMFBoNGVFbUppWVpHUmtXRmhham82T2ZuNS9M'
    b'eTh0U1VsTHc4UEMydHJaS1NrcFlXRmlycTZ2czdPeWRuWjA5ClBUMHRMUzB6TXpNY0hCeGlZ'
    b'bUxPenM2U2twSTFOVFd4c2JIVzF0WVFFQkNSa1pGVFUxT0VoSVJtWm1ZM056ZllHaUxqNCtP'
    b'T2pvNjMKdDdjVUZCUU9EZzRoSVNIUHo4L2k0dUxZMk5oR1JrWXJLeXU1dWJrNU9Ua3hNVEZr'
    b'WkdUUzB0S1VsSlJVVkZSUlVWSE56YzBTRWhKTwpUazRpSWlLN3U3dnRVMWJKQUFBQUFXSkxS'
    b'MFFBaUFVZFNBQUFBQWQwU1UxRkIrY0lIUTBsQmx6ZW81Z0FBQWlsU1VSQlZHamU3WnQ3ClZG'
    b'TkhIb0NuQmF3b0wxMExDWlNMeUkwbVFpRUJpeGdrRlFSeFJRSXFHZ0lhcUVBMThsTGtaYU1R'
    b'cWtaZGFBTUlLeVZpZ1FWcXJUeTAKaWlBaUZsc2ZvRkNEZEl0ZHJWMTJiZXRhZHJkdXQvdW81'
    b'K3pjRzVCTHN2L01KTHZIM1pQNUk4TzU1OXp2ZkhmdW5kL00vR1lBd0JUbAp1ZWNueW5QZzJT'
    b'bG1LN09WMmVvL1hDeE1hMlZockkrbDFiUVhwbHZQbUdsamF4SXJPM3VIV2JOL051ZEZSeWNX'
    b'aGd6YjJZV3FYbktkClRZd1h0N251K0ZiemJEeW9pdVRNbjhBUkM3aUlTandBRm5wNndUODhY'
    b'eVlZeGRzSHo0b3ZBTDUrRmdJQUZyM0N4UGt2UnBJS1dNSVMKQmk0TmNnU2lWNGtwWlZrd2ps'
    b'WEk4bEQzc0JYaERvS1ZQNStLV3hXQllyVTZVaGdwam9pS1hyTjJLb1ZZRjROanRYNkRKRFpN'
    b'R2hjVApQMXNQWjcwUnFiRTRyRTB5Y1VMaWExTWJhbk1TU0VyR2VZTWNRWXFJNHlKOGZRcHV5'
    b'MVk1V08yTFlyVXRZQk5JZFdlbk1TRHBHWm54CmRtQjdOSTVWcWozRUJidnVZTDY4ckozeDJT'
    b'QW5GOFdLSmM0QnFkeEZERXBlZnBBYzlvRmRiMkQxUVFXRmkySTIxTzQ5cVFVd1RCVGEKb1dn'
    b'cFNWREVmWE1jc1hlZmREK2ZmbVpWaEFNTHgwcGtDWW9rK3lZZThJQWtoMGRkUFNoVCtSNUNz'
    b'Zkw0QmZCdzEyRzJGRWVVQkFFZwpUNVFwM3JMS2Zkc094eXBiRGRiTFNtbGMyU3hKZURrQWF4'
    b'SmxZcXZEbmhVNVNOODdGNUNpdUVwSStTVTdOaitKdm5Ra2pvcUFWVmhSCkZBWk1JZWNkZUh1'
    b'MVp1bFJPWDJwSnV5WUcwRkVvRmtKUUdETnUwU3R6d1pGWFc2a0xhditWOVNubnpZL1BSVExT'
    b'c1VERFpacmlmVEMKeGlaTjQzdCtMSy9qeTZoMmU1L3dRckxLTFBjbzBzU2MrQ0JaZmVSa2M2'
    b'WFBYcm9idHJUbUVXMVlWZ25TVTNMMmh0TTJtc1Q0NGcvUApuS1Z4WlNmYnp4RWRhSU5PcTFq'
    b'ZTJybHgrZTZvdWVlN2lzZDdjMHNIUVZ3b3dCb0hxeFQxNGM3ZGpVNXhYYkVYbDQrUHF3Y1cr'
    b'aE5uCmFoREh3cDVMYkQvcTdzcll5SThZbmRvSmI4NUFsdmZtKzNuRCt5czZMbGN6Y09mUnJE'
    b'em01WERhL2FrYlAvNWtEZ1B6aWd1V1ZXalkKRlpsRkxRVzQrc0kxQnU3NmVnU25oTDUyUVdi'
    b'L2pTNzZ6cHV6SmlscFZ3Y3dyT3c0ZzJTTnE5VmlHdkhwTGJmSklhUHlNSUtWRmtiTApJYlZM'
    b'RjZGZld2RDZJSXpDSVVKd3l3QTNGK245eVVBQ1Z5UUFuZ2FZc2lBY0t4bXdGRXBJWUdPQUkx'
    b'UW9WdDNKdDBsWXpUZWdEQXR3CnJIcWo1bEdEekZ3RDNHY2tpbFgveVFScS9QTFhwMWg3WXIx'
    b'QlJmRXArRnVTcG8rcmJFUjZnMG92T0ZnTi9OcmcyWHJ4NXUzSzdTSVkKYTQ0WjRFclI0a0o1'
    b'emNHbWtFdUduOEZaUEN2NVlmdUcwTjF1QnJoYmFGYWtDdkE3c3pVVmVwUzBNTXcxamhhdzJ2'
    b'YUhWZXJodkcwUgpsemxLUGxBQ0VQVDVKR0tFMjlDWGhMdnkwaFpRdUlOWEozRUh0QTBOZDFE'
    b'WGc0RmZXUG5CS2lKdmd2S2JIR05XcVhjWDNhTUc0dUF2CkozRFQ3YkhXek1reDk2V3djaHov'
    b'R0w1S01HNUYzN1QwdDJLS1dxYkRuUWpBWE1vWGh3ZXZoTlVvVGZtWVoyeWVZY1NpYWhCVzBU'
    b'VHUKUWdKdWdpRWd1bzVhaFpNK0ZLYk42T3pIcnNpMkZGZ0ozcU1hdndOZ2wxTkRkQ1hRL082'
    b'NmRZcnhPWmxENHk4dGNMaGliWlU1cTJhMgpNbHVacmRETDcwMVNubHFaQmdlZWZ4YUwyY3Bz'
    b'WmJZeVcvMGJxMmN6aXBySFFiT1YyZXAvd1lvMHJSVnB2RkVST3pMM2VOU0RGQk5aCmVTV2Z6'
    b'eGorT2o0RlIrVWJ0dTU1Qm5LSDAzVjdYOS9lejhhM2FwMm4yM096akQxV3E4TTlkQXhGdCty'
    b'b3BMWUVWVDdYR1Vtd2R4VFkKVms3c1RQamJVM3FHZ2Z0RE1wTFJTd3RCdUkyelZnWU9YNWlh'
    b'bS91OEJzZUs5TTIrWTlzckVRczg5UEtzWDI1SHNiSXFGZmVxT0xHNQo1RXo5UE9aU0hLdWN6'
    b'WUdYVklwcFp3WDc5SEdYVWF3RVRTN3RIRFlwMFV1UG4rdTlGMWFDOHdZNWdwS3dMNEJTYjJk'
    b'aVJ1UWpVU0phClV2UTdVRi9WUHVVNHc5dkpQRDc0emhuSFNwb0FjZHNIMXpGeEZiWUZmRkFU'
    b'aVdKMUtIRU1wSEtuYkplTXR0NFlJd0VaaldQRkUxSTQKSnlhdXVMM29IaCtRemtoSGVKcGds'
    b'T0plbmtEc0xXNlRVVjFJY0tVcUMydVBuaU9BT0llbnB4QytxdU91cGk0L1NOMkl0R2twVHdI'
    b'MgpvZ1U2eU1QUlhWUytsL1ZBS0M2U25zYUtERHZyd1Z1eThlMjhaZnVHeHFnbnpCRXB3dFYv'
    b'NUNGOTd4TEFjOCtnNHQzRFhqWlhBcCtvClNGVi94UFpQaE5zYXJIakZCVURXKzVCcXArNmpZ'
    b'aVZzZHkvWm5vQ2pIeEhFbjlFMkFRQVFrekJhSGJkVjI1YU9XQUdlWS9Pd04rdzMKM2p0eHJj'
    b'VGdlNEo0M0ttK24xRllCRnphQ2hmQUlXTUdnWllnRFk5UHNPZzdzV1BKWnVtMmtZN0dtQkZy'
    b'cXZIbnhLMHJzOEN5c3BkYgpCaXU3YXY4eUtsTXY3eHoxelBxTURxS2Fha0tDTnVMYy9pRlZm'
    b'YlM3YjFDbzJaZzFyTnVRcSszbkVzU2JlQ01PNTA1UjR2MFZDclhxCnJ4bFpYVHJjcW54dEhs'
    b'RXRRTk1La3F6d2pDYnl2SW1aUC9aTzdPdDlTeEQrN25oemhodVNoZWVuRWVucHhDY3REbm1U'
    b'T0tJZmNYd08KM2lhOFN6L1Yxb3ZNamIyTG1ETVorVGRTZC9xczA5OWUvSlNCZTR3VXNVbzRZ'
    b'eUhKYXZwY1dGbmtMT1locFNFY3E5UW1MMTcrU3QyNQppRnpHSGozaDluY0VxUjdZMXc0cFhi'
    b'NDMyR2ZzR3NScHErQWtPRk1UZzlNR3VBVlNsS2FTQWJEYWRRajRHbUN1YmNLeGdyaWMvZ2Zn'
    b'CnRnSHVIL1VvVnBvcXlSNVkvZE1BTTMwL2pwVW1WVVNkek54cWdQc3BIc1ZxV2pNMUxOanYw'
    b'S2RzT1lZVkdUNW8rUUgrZWx6VHgzay8KUnVxQTJqaHFPRGFZcGhFZjRzMlF0VTNVaTI4MHdC'
    b'V2loUVV0WHpFR292eE5aUld4Uy9RSWlMMk50UnA0QXVwZDY3c005dnE3OGF6NApkOEdqMnpk'
    b'T2x1bmpSaEZqcUJBQXVLSnhXRFZKcUc2K3VkaXZBSE9OQTNFU0YxREhPUHp4ZU9UbWo4Nm9p'
    b'NitvSndXQnNPcCtTbm0xCjNKaFZhcGlReGprK2JmeDBMYzRxMWVQUzExbXcxN0ltWXNOUFQ0'
    b'eGEwUS9FSmpkVGh5SGVHTWU5cXdKWUplVDBKaUdjZzlibzFuRG4Kdkl6TU0vQnZoa2NjaEZU'
    b'ZFllUWRRYmpwaFo0NkpYVTJ3NTVlbW5nYW5mMEkzeTJoRGlKazBvUFlFdnlzaDZTSHJxNTB3'
    b'YTVqZ3YrYgp1S3M3c1ZxemVBdEJjSUh4UmQ2blpwa3dVN1NtU2NvRC80MWl6dldacmN4Vy8x'
    b'OVcvd0lYOXRxQk1HTTNuZ0FBQUNWMFJWaDBaR0YwClpUcGpjbVZoZEdVQU1qQXlNeTB3T0Mw'
    b'eU9WUXhNem96Tnpvd05pc3dNRG93TUEwcGpkUUFBQUFsZEVWWWRHUmhkR1U2Ylc5a2FXWjUK'
    b'QURJd01qTXRNRGd0TWpsVU1UTTZNemM2TURZck1EQTZNREI4ZERWb0FBQUFBRWxGVGtTdVFt'
    b'Q0MKIgogICAgICAgaWQ9ImltYWdlMTM2NjAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'IT_88')

IT_88 = b64_IT_88
index.append("IT_88")
index.append("Italy Sardinia")
catalog["IT_88"] = IT_88
catalog["Italy Sardinia"] = IT_88
country["Italy Sardinia"] = ('IT_88', '', 1)
lookup["IT_88"] = ('IT_88', '', 'Italy Sardinia', 1)
lookup["Italy Sardinia"] = ('IT_88', '', 'Italy Sardinia', 1)
details["IT_88"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+01:00","altname":""}
regional["IT_88"] = ('IT_88', 'Italy Sardinia', 1)
regional["Italy Sardinia"] = ('IT_88', 'Italy Sardinia', 1)
#----------------------------------------------------------------------
b64_JE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWplIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImplLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTUuMy02aDQwdjMw'
    b'aC00MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGNsaXAtcGF0aD0idXJs'
    b'KCNqZS1hKSIgdHJhbnNmb3JtPSJtYXRyaXgoMTYgMCAwIDE2IDg0LjggOTYpIj4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Ik0tNS4zLTZoNDB2MzBoLTQweiIvPgogICAgPHBhdGggZmls'
    b'bD0iI2RmMTEyZCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNLTEwLjMtNnYyTDExLjYgOWwt'
    b'MjEuOCAxM3YySC03bDIxLjgtMTMgMjEuNyAxM2gzLjJ2LTJMMTggOSAzOS44LTR2LTJoLTMu'
    b'M0wxNC43IDctNy02aC0zLjJ6Ii8+CiAgICA8ZyBzdHJva2U9IiMwMDAiPgogICAgICA8cGF0'
    b'aCBmaWxsPSIjZTgxMTJkIiBzdHJva2U9Im5vbmUiIGQ9Ik0xNy4zLTEuNWMuNyAyLjYuMyA1'
    b'LjgtMi42IDcuNi0yLjktMS44LTMuMy01LTIuNi03LjYuNy0uNiAzLjgtMSA1LjIgMHoiLz4K'
    b'ICAgICAgPHBhdGggZmlsbD0iI2Y5ZGQxNiIgc3Ryb2tlPSJub25lIiBkPSJNMTQuNy0yYzEg'
    b'MCAxLjguMiAyLjYuNmE1LjcgNS43IDAgMCAxIDEtMi40Yy0uNSAwLS43LjItLjcuNS0uMS0u'
    b'My0uNi0uMy0uOC0uMS42LjMuMiAxLS4zLjktLjMtLjEtLjQtLjMtLjQtLjVhLjMuMyAwIDEg'
    b'MC0uMSAwIDEgMSAwIDAgMS0uNy4zLjcuNyAwIDAgMS0uNC0uNmMwLS41LjYtLjYuNy0uNSAw'
    b'LS4zLS42LS43LS43LS4zYTEgMSAwIDAgMC0uMi0xLjIgMSAxIDAgMCAwLS4yIDEuMWMtLjIt'
    b'LjMtLjcgMC0uNy40LjEtLjEuNiAwIC42LjUgMCAuMiAwIC41LS4zLjVhLjYuNiAwIDAgMS0u'
    b'Ny0uMmwuMi0uMWEuMy4zIDAgMSAwLS4zIDBjMCAuMy0uMi41LS40LjVhLjUuNSAwIDAgMS0u'
    b'My0uOWMtLjItLjItLjctLjItLjguMiAwLS4zLS4yLS41LS44LS41YTUuNyA1LjcgMCAwIDEg'
    b'MSAyLjQgNS4zIDUuMyAwIDAgMSAyLjctLjZ6Ii8+CiAgICAgIDxnIGZpbGw9IiNmOWRkMTYi'
    b'IHN0cm9rZT0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIuMSI+CiAgICAgICAgPHBhdGggZD0iTTE3'
    b'IC42aC0uMi4zYy4xIDAgLjItLjEuMS0uMmguMmwtLjItLjJoLjJsLS4yLS4yaC4xYS4yLjIg'
    b'MCAwIDEgMC0uMmgtLjdsLS41LS4xLjYtLjNjMC0uMi0uMy0uNS0uOC0uM0wxNC44LTFsLjct'
    b'LjIuOC0uMWgtLjdjLS4zIDAtMS0uMS0xIC4zcy43LjMgMS40LjJsLjYuMS0uNi4yYTIgMiAw'
    b'IDAgMC0uOSAwaC0uN2MtLjIgMC0uNSAwLS43LS4yIDAgMC0uNC4yLS40LjRWMGMuMi4yIDAg'
    b'LjEtLjIuMWwtLjUtLjFjLS4xLS4yLS4yLS4zLS40LS4yVjBoLjJhLjIuMiAwIDAgMC0uMiAw'
    b'di4yaC4zLS4ydi4xaC40YS4yLjIgMCAwIDAtLjIuMmMuMS0uMS4yIDAgLjQgMGwtLjIuMWMu'
    b'MSAwIC43LjEuNy0uMXYuMXMuMyAwIC4zLS4ydi4ycy4yIDAgLjMtLjJWLjJoLjVjLjItLjIu'
    b'MyAwIC40LS4xaC4yYy4xIDAgLjIgMCAuMy0uMi4yLjEuNS4yIDEuMS4xLjMgMCAuNS4xLjUu'
    b'M2gtLjVzLS4xLjEgMCAuMiAwIDAgLjEgMGMwIDAtLjEuMSAwIC4ybC4zLS4xem0tNC0xLjd2'
    b'LjFsLjEuMi4xLS4zeiIvPgogICAgICAgIDxwYXRoIGQ9Ik0xMy43LTFjLjEtLjEuMi0uMS4y'
    b'IDBsLS4xLjItLjEtLjN6Ii8+CiAgICAgICAgPHBhdGggZD0iTTEzLjQtMS4yYy4zIDAgLjQu'
    b'Mi40LjRsLS4yLjQtLjIuMS0uMi0uMWMwLS4zLS4yLS4yLS4yLS40czAtLjQuNC0uNHoiLz4K'
    b'ICAgICAgICA8cGF0aCBkPSJNMTIuNi0uNGgtLjJjLjEgMCAuMS4yLjQuMmgtLjJjLjEgMCAu'
    b'Mi4yLjUuMi4xIDAgMCAwIDAgMCAwIC4xLjIgMCAuMy4yIDAtLjEtLjItLjMgMC0uNS0uNCAw'
    b'LS41LS4yLS42LS4zLS4yLS4xLS4yLS4zLS4zLS41IDAgMC0uMS0uMi0uMi0uMXYuMmgtLjFj'
    b'LjEgMCAwIC4yLjIuMy0uMS0uMS0uMi0uMi0uMy0uMWguMWwuNC40em0yLjYgMWguNWwuMi0u'
    b'MVYuM2MtLjEgMC0uMi0uMS0uMS0uMi0uMy0uNC0uOS0uMi0uOSAwbC40LjJoLjEtLjdsLjEu'
    b'MS0uMi4xYzAgLjIuMiAwIC4yIDB2LjFzMCAuMS4xIDBhLjMuMyAwIDAgMSAuMiAweiIvPgog'
    b'ICAgICA8L2c+CiAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0ibm9uZSIgZD0ibTE1'
    b'LjQgMC0uMi0uMU0xNC0uMXYuM20tLjgtMS4xaC4xbS4zIDBoLS4xbTAgMC0uMS4zYy0uMSAw'
    b'IDAgMCAwLS4yIi8+CiAgICAgIDxwYXRoIGZpbGw9IiNmZjAwMTYiIHN0cm9rZT0ibm9uZSIg'
    b'ZD0iTTEzLjQtLjRoLjF2LS4yaC0uM3YuMWwuMi4xeiIvPgogICAgICA8cGF0aCBzdHJva2U9'
    b'Im5vbmUiIGQ9Ik0xMy4zLS42aC0uMm0uMiAwaC0uMm0uMiAwaC0uMm0uNCAwaC4ybS0uMiAw'
    b'aC4ybS0uMiAwaC4yIi8+CiAgICAgIDxwYXRoIGZpbGw9IiMwMDUxYmEiIHN0cm9rZT0ibm9u'
    b'ZSIgZD0iTTEyLjMtMS4yYzAtLjEtLjIgMC0uMiAwaC4yem0wIC4xTDEyLTFoLjJ6bTAgLjNI'
    b'MTJoLjJ6bTAgLjdjLS4xIDAtLjIgMC0uMi4yIDAtLjEuMSAwIC4yIDB2LS4yem0wIC4yLS4y'
    b'LjIuMi0uMVYwem0wIC4xcy0uMS4xIDAgLjJWLjF6bTIuNS4zYy0uMSAwLS4yIDAtLjIuMmwu'
    b'Mi0uMVYuNXptLjEgMGMtLjEgMC0uMi4yLS4xLjNsLjEtLjFWLjZ6bTAtLjJjLS4yIDAtLjMg'
    b'MC0uMy4ybC4yLS4xem0xLjYuMnMtLjIuMS0uMS4ybC4xLS4xVi41em0wLS4xLS4yLjFoLjJW'
    b'LjJ6bTAgLjJzLS4xLjIgMCAuMmguMVYuNXptLTMtMVYwYy0uMiAwLS4yIDAtLjItLjJ2LS4y'
    b'aC4xeiIvPgogICAgICA8ZyBmaWxsPSIjZjlkZDE2IiBzdHJva2U9Im5vbmUiIHN0cm9rZS13'
    b'aWR0aD0iLjEiPgogICAgICAgIDxwYXRoIGQ9Ik0xNi42IDIuN2guMnMuMSAwIDAtLjFoLjJs'
    b'LS4xLS4yaC4xbC0uMS0uMmEuMi4yIDAgMCAxIDAtLjJoLS41bC0uNS0uMWMuMy4xLjYtLjEu'
    b'Ni0uMyAwLS4yLS4zLS40LS43LS4ybC0xLjEtLjEuNi0uMmguOGwtLjctLjFjLS4zLS4xLS45'
    b'IDAtLjkuM3MuNy4zIDEuMy4yaC41bC0uNS4yYTEuOCAxLjggMCAwIDAtLjggMGwtLjcuMWMt'
    b'LjEgMC0uNCAwLS42LS4ybC0uNC4zLjEuNGMuMS4xIDAgMC0uMiAwaC0uNWMwLS4yLS4yLS4z'
    b'LS4zLS4ydi4xaC4yYS4yLjIgMCAwIDAtLjIgMHYuMmguMi0uMWMuMiAwIC4yLjIuMy4xYS4y'
    b'LjIgMCAwIDAtLjEgMHMuMi4yLjMuMWwtLjEuMmMwLS4xLjYgMCAuNi0uMnYuMnMuMiAwIC4z'
    b'LS4yaC4ydi0uMmguMmwuMy0uMWguNWMuMSAwIC4yIDAgLjMtLjIuMi4xLjQuMiAxIC4xLjIg'
    b'MCAuMyAwIC4zLjJ2LjFoLS40di4yYzAgLjEuMSAwIC4yIDAtLjEgMC0uMiAwLS4xLjFoLjFs'
    b'LjItLjF6bS0zLjQtMS41SDEzbC4xLjMuMS0uM3oiLz4KICAgICAgICA8cGF0aCBkPSJNMTMu'
    b'NyAxLjJoLjJsLS4xLjMtLjEtLjN6Ii8+CiAgICAgICAgPHBhdGggZD0iTTEzLjUgMS4xYy4z'
    b'IDAgLjMuMi4zLjRzLS4xIDAtLjIuM2wtLjIuMWgtLjFjMC0uMy0uMi0uMy0uMi0uNHMwLS40'
    b'LjQtLjR6Ii8+CiAgICAgICAgPHBhdGggZD0iTTEyLjcgMS44aC0uMXMwIC4yLjMuMmgtLjJs'
    b'LjQuMmMuMiAwIDAgMCAwIDBsLjQuMmMwLS4yLS4yLS4zLS4xLS41LS4zIDAtLjQtLjItLjUt'
    b'LjMtLjIgMC0uMi0uMi0uMi0uNGwtLjItLjFzLS4xIDAgMCAwdi4yaC0uMWwuMS4yaC0uMmMu'
    b'MiAwIC4zLjMuNC4zem0yLjQuOUgxNWguOHYtLjJjLS4xIDAtLjItLjEtLjEtLjMtLjMtLjMt'
    b'LjgtLjEtLjggMGwuNC4ycy4yIDAgMCAuMWgtLjJjLS4yIDAtLjMtLjEtLjQgMHYuMmguMXMw'
    b'IC4xLjEgMGEuMy4zIDAgMCAxIC4yIDB6Ii8+CiAgICAgIDwvZz4KICAgICAgPHBhdGggZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSJub25lIiBkPSJNMTUuMyAyLjFhLjQuNCAwIDAgMC0uMyAwbS0x'
    b'IDB2LjNtLS43LTFoLjEtLjFtLjQgMGgtLjIuMW0tLjEgMHYuM3MtLjEtLjEgMC0uMiIvPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjZmYwMDE2IiBzdHJva2U9Im5vbmUiIGQ9Ik0xMy41IDEuOXYt'
    b'LjFzLjEtLjEgMC0uMmMuMS4xIDAgLjEgMCAwIDAgLjEtLjIuMS0uMiAwdi4yaC4yeiIvPgog'
    b'ICAgICA8cGF0aCBzdHJva2U9Im5vbmUiIGQ9Im0xMy40IDEuNy0uMi0uMW0uMiAwaC0uMm0u'
    b'MiAwLS4yLjFtLjMgMCAuMi0uMW0tLjIgMGguMm0tLjIgMCAuMi4xIi8+CiAgICAgIDxwYXRo'
    b'IGZpbGw9IiMwMDUxYmEiIHN0cm9rZT0ibm9uZSIgZD0ibTEyLjUgMS0uMi4xaC4yem0wIC4y'
    b'LS4zLjFoLjJ6bS0uMS4zYzAtLjEtLjIgMC0uMiAwaC4yem0wIC42LS4yLjFoLjN6bTAgLjJz'
    b'LS4yIDAgMCAuMnYtLjJ6bS4yIDAtLjIuMy4yLS4xdi0uMXptMiAuM3MtLjEgMCAwIC4ybC4x'
    b'LS4xdi0uMXptLjIuMXMtLjIuMS0uMS4ybC4xLS4xem0wLS4zYy0uMSAwLS4zLjEtLjIuMmgu'
    b'MXYtLjF6bTEuNC4zcy0uMSAwIDAgLjF2LS4yem0wLS4yLS4xLjFoLjJ2LS4xem0uMS4zcy0u'
    b'MSAwIDAgLjF2LS4xem0tMi44LTF2LjRWMmMwLS4xIDAtLjItLjEtLjF2LS4xeiIvPgogICAg'
    b'ICA8ZyBmaWxsPSIjZjlkZDE2IiBzdHJva2Utd2lkdGg9Ii4xIj4KICAgICAgICA8cGF0aCBk'
    b'PSJNMTMwLjcgMzIuMmMtLjQgMC0uNC41LS41LjUuOCAwIDEuMi0uMyAxLjQtLjd2LjZjLjYt'
    b'LjIuOC0uNy42LTFsLjcuMmMtLjQtLjMtLjEtMS0uOC0xLjQuMiAwIC42LjIuOC41LS4xLS43'
    b'LS4yLTEuMS0uOC0xLjVoLjVhLjkuOSAwIDAgMS0uNC0uOGMwLS40LS4yLS40LS42LS4zbC0x'
    b'LjguMWMtMSAwLTIgMC0yLjgtLjYgMS4zLjYgMy0uNiAzLTEuNSAwLTEtMS40LTItNC0xLjQt'
    b'Mi42LjYtNS44LjQtNS44LS41czIuMy0xIDMuNS0uOGMxLjIuMiAyIC4zIDQuMi0uNS0uNS4y'
    b'LTIuMy4zLTMuNy0uMXMtNC44LS40LTQuOCAxLjRjMCAxLjkgMy42IDEuNyA2LjggMS4yIDEu'
    b'OC0uMiAyLjggMCAyLjguNSAwIC42LTEuNy44LTMgLjdhMTAgMTAgMCAwIDAtNC4xLjNjLTEu'
    b'My40LTIuMiAwLTMuNi4zLS43IDAtMi40IDAtMy4yLTEuNC0uNS40LTIgMS4xLTIuMyAxLjkt'
    b'LjMuNiAwIDEuMy40IDIgLjYuOC0uMy43LTEgLjctLjggMC0yIDAtMi42LS44LS42LS42LTEu'
    b'My0xLjEtMS45LS43LS4zLjMgMCAuNi4yLjVsLjguMmExIDEgMCAwIDAtMSAuMWMtLjMuMiAw'
    b'IC42LjMuNS4yLS4xLjctLjIgMSAwLS4zIDAtLjcgMC0uOC4yczAgLjQuMy40Yy42IDAgLjcu'
    b'NCAxLjMuM2EuOS45IDAgMCAwLS43LjRjLjYtLjMgMS4xLjQgMS44LjItLjIuMS0uNy40LS43'
    b'LjYuNC0uNSAzLjIuNCAzLjItLjdsLS4xLjhjLjMtLjIgMS40LS4zIDEuOC0xIDAgLjIgMCAu'
    b'NS0uMi42LjMgMCAuOC0uMiAxLjMtLjkuMi0uMy4yLS41LjItLjcuNSAwIC44LS4xIDEuMi0u'
    b'NC40LS4zLjguMyAxLjUtLjIuNi0uNCAxLjIgMCAxLjYtLjIuMy0uMi44IDAgMS4yLS4yczEg'
    b'LjEgMS42LS40YzEgLjQgMi4zIDEgNS4yLjUgMS42LS4zIDIuMi4zIDIuMiAxIDAgLjYtLjQu'
    b'Ni0uNi42LTEgLjEtMS4zLS4zLTEuNy0uMi0uMi4xLS40LjUgMCAuNy0uMy4xLS4zLjQtLjEu'
    b'NXMuNSAwIC44LS4xYy0uNC4xLS43LjQtLjUuNy4xLjIuNC4zLjcgMCAuMy0uNC44LS43IDEu'
    b'Mi0uN3ptLTE4LjYtOGMtLjgtLjMtMS0uMy0uOS40IDAgLjMuMy43LjUuOSAwLS4zLjEtMSAu'
    b'NC0xLjJ6IiB0cmFuc2Zvcm09Im1hdHJpeCguMTQgMCAwIC4xNSAtMS43IC0uNCkiLz4KICAg'
    b'ICAgICA8cGF0aCBkPSJNMTE0LjggMjQuM2MuOC0uNCAxLjEtLjQuOS4zIDAgLjMtLjMuNy0u'
    b'NS45IDAtLjMgMC0xLS40LTEuMnoiIHRyYW5zZm9ybT0ibWF0cml4KC4xNCAwIDAgLjE1IC0x'
    b'LjcgLS40KSIvPgogICAgICAgIDxwYXRoIGQ9Ik0xMTMuNSAyMy44YzEuNiAwIDEuOC44IDEu'
    b'NyAxLjcgMCAxLS41LjYtLjggMi0uMS40LS41LjUtMSAuNS0uMyAwLS43IDAtLjktLjYtLjMt'
    b'MS4zLS44LTEtLjgtMiAwLS44LjItMS42IDEuOC0xLjZ6IiB0cmFuc2Zvcm09Im1hdHJpeCgu'
    b'MTQgMCAwIC4xNSAtMS43IC0uNCkiLz4KICAgICAgICA8cGF0aCBkPSJNMTA5LjQgMjcuNWMt'
    b'LjQtLjItLjcgMC0uOSAwIC42LjEuNi44IDEuOCAxLS4zIDAtLjQuMi0uNyAwIC41LjQgMSAu'
    b'OSAyLjIuOS43IDAgLjIuMy0uMi4xLjQuNSAxLjMuMSAxLjkgMSAwLS43LTEtMS43LS41LTIu'
    b'NC0xLjctLjEtMS44LTEtMi43LTEuNy0uOC0uNi0uOS0xLjItMS4yLTIuMy0uMS0uNS0uNy0u'
    b'OC0xLS43LS4zIDAtLjUuMy0uMi41LjIuMi42LjIuNi43LS4zLS40LS44LS41LTEtLjMtLjEu'
    b'MiAwIC41LjIuNS41IDAgLjIuNi43IDEtLjUtLjUtLjktLjYtMS4yLS4zLS4xLjIgMCAuNS40'
    b'LjUuNSAwIDEgMS4yIDEuOCAxLjV6bTEzIDQuNmMtLjIgMC0uMS41LS41LjUuOCAwIDEuMy0u'
    b'MiAxLjYtLjVsLS4yLjVjLjQtLjMgMS41LS40IDItLjNzLjYtLjEuOC0uNGMuMi0uNCAwLS42'
    b'LS4zLS44LS4zLS4zLS40LS43LS4zLTEuMy0xLjQtMi00LTEtNC0uMi45IDEuMSAxIDEgMS44'
    b'IDEuMS43LjIgMS4yLjIuNy42LS4yLjItMSAwLTEuNS4xLTEuMyAwLTItLjktMi4zLS40LS4z'
    b'LjQgMCAuNi42LjYtLjQgMC0xIDAtLjkuNC4yLjcuOC0uMSAxLjEuMS0uMiAwLS42LjEtLjYu'
    b'MyAwIC4yLjUuNSAxIDBhMS42IDEuNiAwIDAgMSAxLS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'LjE0IDAgMCAuMTUgLTEuNyAtLjQpIi8+CiAgICAgIDwvZz4KICAgICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlLXdpZHRoPSIuMSIgZD0iTTEyMy41IDI5LjJjLS40LS4yLS45LS4zLTEu'
    b'NC0uMm0tNS42IDBjLS40LjgtLjIgMS4yLS4xIDEuNm0tNC01LjZjLjIuMi40LS4yLjguMi0u'
    b'MS0uMS0uMy4zLS42IDBtMi0uMWMtLjMgMC0uNS0uMy0uOS4xLjEtLjEuMy4zLjYgMG0tLjYg'
    b'MHYuM2MuMS43LjMgMS0uMyAxLS41IDAtLjMtLjMtLjItMXYtLjMiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC4xNCAwIDAgLjE1IC0xLjcgLS40KSIvPgogICAgICA8cGF0aCBmaWxsPSIjZmYwMDE2'
    b'IiBzdHJva2Utd2lkdGg9Ii4xIiBkPSJNMTEzLjUgMjcuN2MuNCAwIC42IDAgLjYtLjYgMC0u'
    b'Mi4zLS4zLjEtLjcuMi40LS43LjQtLjcuMiAwIC4yLTEgLjItLjgtLjItLjEuNC4yLjUuMS43'
    b'IDAgLjYuMi42LjcuNnoiIHRyYW5zZm9ybT0ibWF0cml4KC4xNCAwIDAgLjE1IC0xLjcgLS40'
    b'KSIvPgogICAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii4xIiBkPSJtMTEzIDI2LjUtMS0uM20x'
    b'IC4zaC0xbTEgLjEtLjkuM20xLjctLjQgMS0uM20tMSAuM2gxLjJtLTEuMi4xIDEgLjMiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC4xNCAwIDAgLjE1IC0xLjcgLS40KSIvPgogICAgICA8cGF0aCBm'
    b'aWxsPSIjMDA1MWJhIiBzdHJva2U9Im5vbmUiIGQ9Ik0xMyAzLjJoLjF6bTAgLjFoLS4yLjJ6'
    b'bTAgLjJoLS4yLjF6bTAgLjZjMC0uMS0uMSAwLS4xIDBoLjF6bTAgMHMtLjEuMiAwIC4ydi0u'
    b'MXptMCAuMnptMS43LjFzLS4yLjEtLjEuMnYtLjJ6bTAgLjF2LjItLjF6bTAtLjItLjEuMWgu'
    b'MXptMS4xLjJ2LjEtLjF6bTAtLjFzLS4xIDAgMCAwem0wIC4ydi4xaC4xdi0uMXptLTItLjh2'
    b'LjMtLjN6Ii8+CiAgICA8L2c+CiAgPC9nPgo8L3N2Zz4K', 'JE')

JE = b64_JE
index.append("JE")
index.append("JEY")
index.append("Jersey")
catalog["JE"] = JE
catalog["JEY"] = JE
catalog["Jersey"] = JE
country["Jersey"] = ('JE', 'JEY', 0)
lookup["JE"] = ('JE', 'JEY', 'Jersey', 0)
lookup["Saint Helier Jersey"] = ('JE', 'JEY', 'Jersey', 0)
lookup["JEY"] = ('JE', 'JEY', 'Jersey', 0)
lookup["Jersey"] = ('JE', 'JEY', 'Jersey', 0)
details["JE"] = {"continent":"Europe","capital":"Saint Helier","currency":"Pound Sterling","web":".je","lang":"en | fr | nrf","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_JM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWptIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGQ9Im0wIDAgMzIwIDI0MEwwIDQ4MHptNjQwIDBMMzIwIDI0MGwzMjAgMjQw'
    b'eiIvPgogICAgPHBhdGggZmlsbD0iIzA5MCIgZD0ibTAgMCAzMjAgMjQwTDY0MCAwem0wIDQ4'
    b'MCAzMjAtMjQwIDMyMCAyNDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmMwIiBkPSJNNjQwIDBo'
    b'LTU5LjZMMCA0MzUuM1Y0ODBoNTkuNkw2NDAgNDQuN3oiLz4KICAgIDxwYXRoIGZpbGw9IiNm'
    b'YzAiIGQ9Ik0wIDB2NDQuN0w1ODAuNCA0ODBINjQwdi00NC43TDU5LjYgMHoiLz4KICA8L2c+'
    b'Cjwvc3ZnPgo=', 'JM')

JM = b64_JM
index.append("JM")
index.append("JAM")
index.append("Jamaica")
catalog["JM"] = JM
catalog["JAM"] = JM
catalog["Jamaica"] = JM
country["Jamaica"] = ('JM', 'JAM', 0)
lookup["JM"] = ('JM', 'JAM', 'Jamaica', 0)
lookup["Kingston Jamaica"] = ('JM', 'JAM', 'Jamaica', 0)
lookup["JAM"] = ('JM', 'JAM', 'Jamaica', 0)
lookup["Jamaica"] = ('JM', 'JAM', 'Jamaica', 0)
details["JM"] = {"continent":"Americas","capital":"Kingston","currency":"Jamaican Dollar","web":".jm","lang":"en-JM","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_JO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWpvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImpvLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTExNy44IDBoNjgy'
    b'LjZ2NTEyaC02ODIuNnoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGNsaXAt'
    b'cGF0aD0idXJsKCNqby1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTEwLjUpIHNjYWxlKC45'
    b'Mzc1KSI+CiAgICA8ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0Ij4K'
    b'ICAgICAgPHBhdGggZD0iTS0xMTcuOCAwaDEwMjR2MTcwLjdoLTEwMjR6Ii8+CiAgICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Ik0tMTE3LjggMTcwLjdoMTAyNHYxNzAuNmgtMTAyNHoiLz4K'
    b'ICAgICAgPHBhdGggZmlsbD0iIzA5MCIgZD0iTS0xMTcuOCAzNDEuM2gxMDI0VjUxMmgtMTAy'
    b'NHoiLz4KICAgICAgPHBhdGggZmlsbD0icmVkIiBkPSJtLTExNy44IDUxMiA1MTItMjU2LTUx'
    b'Mi0yNTZ2NTEyeiIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMjQuNSAyODkgNS43'
    b'LTI0LjlINC43bDIzLTExLTE1LjktMTkuOSAyMyAxMSA1LjYtMjQuOCA1LjcgMjQuOUw2OSAy'
    b'MzMuMmwtMTYgMTkuOSAyMyAxMUg1MC42bDUuNyAyNC45LTE1LjktMjB6Ii8+CiAgICA8L2c+'
    b'CiAgPC9nPgo8L3N2Zz4K', 'JO')

JO = b64_JO
index.append("JO")
index.append("JOR")
index.append("Jordan")
catalog["JO"] = JO
catalog["JOR"] = JO
catalog["Jordan"] = JO
country["Jordan"] = ('JO', 'JOR', 0)
lookup["JO"] = ('JO', 'JOR', 'Jordan', 0)
lookup["Amman Jordan"] = ('JO', 'JOR', 'Jordan', 0)
lookup["JOR"] = ('JO', 'JOR', 'Jordan', 0)
lookup["Jordan"] = ('JO', 'JOR', 'Jordan', 0)
details["JO"] = {"continent":"Asia","capital":"Amman","currency":"Jordanian Dinar","web":".jo","lang":"ar-JO | en","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_JP = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWpwIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImpwLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg4IDMyaDY0MHY0'
    b'ODBILTg4eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI2pwLWEpIiB0cmFu'
    b'c2Zvcm09InRyYW5zbGF0ZSg4OCAtMzIpIj4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0t'
    b'MTI4IDMyaDcyMHY0ODBoLTcyMHoiLz4KICAgIDxjaXJjbGUgY3g9IjUyMy4xIiBjeT0iMzQ0'
    b'LjEiIHI9IjE5NC45IiBmaWxsPSIjYmMwMDJkIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtMTY4'
    b'LjQgOC42KSBzY2FsZSguNzY1NTQpIi8+CiAgPC9nPgo8L3N2Zz4K', 'JP')

JP = b64_JP
index.append("JP")
index.append("JPN")
index.append("Japan")
catalog["JP"] = JP
catalog["JPN"] = JP
catalog["Japan"] = JP
country["Japan"] = ('JP', 'JPN', 0)
lookup["JP"] = ('JP', 'JPN', 'Japan', 0)
lookup["Tokyo Japan"] = ('JP', 'JPN', 'Japan', 0)
lookup["JPN"] = ('JP', 'JPN', 'Japan', 0)
lookup["Japan"] = ('JP', 'JPN', 'Japan', 0)
details["JP"] = {"continent":"Asia","capital":"Tokyo","currency":"Yen","web":".jp","lang":"ja","tz":"+09:00","altname":""}
#----------------------------------------------------------------------
b64_JP_01 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4MTMyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSG9ra2FpZG9fUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzODEzNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzgxMzQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnODEzOCI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVEK'
    b'NjBsRVFWUjQydTJkZDF4VDUvN0hueXdTTWdpUU1KUzlDVE5oS0RLRlNzdXJwYld0WFZjNzNH'
    b'MS9QMzllcTNXMWVudnJhT3VsRHJ6Mwo1YjZ0QzBldDlpcmlxQk5sSXhDcUpHeGt5VWhDQmlG'
    b'azUvZEhNQ1FuQVJPMGx3RG44MWZ5bk9lY0pPZWQ1L21PWnh4RUpQME5BR3NpCkN3bmZBaGdo'
    b'TEJnaExCZ2hqQkFXakJBV2pCQVdqQkJHQ0F0R0NBdEdDQXRHQ0NPRUJTT0VCU044Ym5tNHUr'
    b'N04zaFFlSGpoNnRjQkEKbjIzYlZybTd1MDZhSDQ2ZU5MOEVnVVFtSjhjbUo4Y3ltZXo5QjA2'
    b'WGxsWkRLakFZSVlzV3ZwMlVGSU5BSUE0ZCtnVkdhTDJpMDJrSApEMnhoTXRrL0h6MS83OTRE'
    b'alVhamhaZWNIRHNwTzFJMG1LU2kwMm5aZXpheEh0WUJBRUxDZ3lheExVU0RTUzEvaWgxQUlH'
    b'QjNaZ0pMCjN0MGo3KzZCRVU1a2hGM2RpcTV1R09HNGFkbzA1K2U4Z3FLNzkvbGI0Zk4valNt'
    b'SzBObVo4dXU1N05UVXVPZnVTSHVmNXdxSkNkRm4Keit4MmRhWENDQzFXRkNPRVFNRHYycm5o'
    b'cnlzL1JpTEg2SklvbnFNalJTQVFpeGJOMjd0M3M1MGRNVEl5R0Vab3NTSWlnM1gzY2MvdQpy'
    b'NGxFL0JoYjRaZ1E0dkc0ckt4MXVuOVBSQVNNY0V5Qm5lNTFjbkpzenNtZHZyNGVGbDFCbzFZ'
    b'ck9Gd0ZoNnRScXkwNjBkTnorb25qCldYTmVpdGVWTVBTK0RJelFMTm5hNG9JQ3ZmVkx2THlt'
    b'bnppZWxaWm1nV2xVY3JnYXBWS2pWQ3E1UEF1TVgySjB6c2tmL2Z3ODlRdUQKZ256d2VCeU0w'
    b'QUtGaFFXZ1VDaElJWUZndS9OSEMweWpyZ3Mxc3k4ZE1uN1ptMGtrQXVRUUNvVUtDZkdIRVk2'
    b'eEZ6Vyt5OWw3TmhuZgpaVk1JZTh4SFNDRFkvcGkxZnBUL0I5MWErMUpyUkJnWFIzOHRNVW8x'
    b'SUJtcFFsSlN6SW5qV1Q3ZTdzLzBaWFRSNGVnMWZiemRjMDd1CmZPbWxXU05WVUExSU1wT2k0'
    b'K0xvTU1KbjlHTXBLYkhIai8vandQNXZ2U05vZ21zMytGZHZqRlRaMjlzdEoyZW52c2RoS3E3'
    b'dmdiQTAKcWVUazJCTW5zcnk5M1VhcUlDb3M1bCs1N2gxQk83RC8yN05uOXJ5ZW1Ucm1JR2ZT'
    b'SWtRaUVTa3BzVGs1TzdQM2JJcDRPcXBBbVRkWAoxdHJXdkdLTjdIR2JPWDYvcVZiWURYbGhz'
    b'bHNlSldLUmR6NXBXYk5SWE1Ha3Z2dVd6cS9adW5YVkwyZXpYODlNTmJiV1V4UmhXbHJjCmYz'
    b'N2JsNzFuVXdqTkQzTEk5Yk1sdGlIQjlaOHM3OXAvUkNPWFcyb2FkWGtaaGFsV1NDSVI5bVp2'
    b'R3VrZm9GRXFPU2ZQMUgyNEZPdnAKTVgzbDU1Q2ovdjVlVzdldSt1M0N2eXp5a0NjdHdvY1A2'
    b'd1hDL3BHT1R2dDhxZVBjVE8zZDdDOHBIOGswbnNyWjZlVTEzYUJVclZIMAo5QTUzcEdxTi9r'
    b'RTNONWZqeC82UmxCUmo4b0xpU21iOXg4dTY5aDl4eUpoanpFK25nWUZCTnJ0NTNHOGd5dFYx'
    b'bklkREpaTEJ2THk3CkZJbzl6YWdWYWh1YVhWeXNraThRbDFVSWZyODFXRmRQaUF4SEVhQnRq'
    b'a3dtcGFYR29kSER3NThLTG85ejZ1bnNDclhhOGMxTUZINjQKdDB4TG5lbnNUREZoUG5sOVQz'
    b'YnU3ZnJuQVpWUTVKaVo0YjV1TlJpaGw3NmNkMmYxNnU4RkFoR01FQUFBVkNwMS9yMXlEcGNm'
    b'UDR1QgpRaUZOVUp3MVU5bkhINnl0bDdWMzlGM01RNkNRK0xBUWhPRllyajQvQUlDMHFabWZk'
    b'MDMzMW41MkVzWmxlTUFCZzhGQVAwV3Q2YnQwCnBYWDlaZ203RGdEZzhPb3JIaHUrTk1sUHBW'
    b'TDk4MThuZCszNldhVlNXWU10dEFxRVdySFpUV1ZsZnlRbHh1RHh0aVlweXJ1NnBZM04KR3FW'
    b'Uy9LQlNkTC9JTnNBUDQrdzBZdU91ZmlUTXY2OTdTNHlKd3ZuNWpGUjVzSzZoOWF0dmVQKzVy'
    b'RkVvQUFEMmFTa2VtOWNqa0NhcwpESjh2WFBuWGJWZXU1RnVQUjJwRkNBRUFQVDNjM010M3dr'
    b'SURwazkzTmtFeEtWN2UrVVRhMUFJQVVQYngrL0t1eVR1N0NQUndKQTVuCk1oSVFWMVFOWit5'
    b'Q0F3bVI0U2FhbEZqY3ZlOXc1NDVkaWw3T1VKK2NtdXo1N2RjSVU5NW1kWFh0c3VXYkd4dGJy'
    b'U291dEM2RUFBQ3AKVkpaM0pkOEdnMll3UW96OVQ3dmtCSGw3aDdUNThWRGx4dWErM0t0b0Vz'
    b'azJLQUF5UjRaLy9lWmdYWVB1TGRiZHpTNEI2ajBLYitlMwpmUG0xdUtJS2FJYWNIWEpLb3Vl'
    b'V1RTYjVuVDkvZmQzNnJQNytBV3NMN2EwT0lRQkFvOUdVbGxaM2RQUWtKRVNoMFNnb3hhUjRh'
    b'WE9MCnJMVjlxTEpNTGlvc0VWZFc0ME9DMEE3MnVwcThYeS9LTzU4TVcwcXluY01yYzNSdlpl'
    b'MmRiZDlzNTV3OG94NlVEb2NaY1RPOHR2OE4KZ1laT0NaUExGZHUvTzNEdzRCbTFoU01lVXhl'
    b'aFZ2VU5qd3NMS3hNVG9vaEVBLzhUZ1VTU1U1S2tEVTJ5OWc3OVJFemZwU3Nxb1pBUQpHWTdB'
    b'WUFBQXZjZHlWTUpoZHhHQlJsSG52UWtBVU10a3ZjZE90ZjM5TzduZTZRQUEwc3dZN3gxYkVF'
    b'WnVEb2ZUdDJMRmxydjVaY0JhClpiMElBUUJjTGovdlNuNW9pTCtibTRzQlJSU1NQRHRaV3Q4'
    b'Z2ErL1VjeW5WRWxZdC85cE5HMWNYbkpkbjk3N0RHajJQVVNPVk9YODgKWDFSYzluanQxNkw3'
    b'aGNDd1BSRmpvMzEyYkVYWTJFQytBSlBKL3ZTenY3VTg3Z0JXTEt0R3FEV05WMHlaUmdRS1NV'
    b'NU5IcXh0a0hkMApHb1FHQXhMaDdYekpRNWFzcmQyZ2MxYXBaQzF0M1lkK1VvbkZrSThneGta'
    b'NTc5aUt4R0tOamQvNkRWbGlzUVJZdDZ3ZG9jNDBkdmR3Clo4VXowSHFPQmdLRklxY2tTaDZ4'
    b'ak1lUzVFKzZUUHdiSHB2d0pBa1JvVDVaMnlFK3JVd3UzN1p0MzZGRFo2M1QrRTA4aEZyVjFq'
    b'WVgKRkZRa0pFVHBwME1SYURRNUxXWGc0U1BGYUdNUkdnQk1aMWp3NGFHK3U3NUg0ZzF5M0wy'
    b'OXZCVXJ0dHk3Vnc0bWlDWU1RaXJGd2NmWApYYWxVK2ZpNDJlZ1pMUVFhYlQ4N1NWekpWSEM0'
    b'STV3NkFyOVFtdS91SHlEOHBGSlpRVUdGV0N3Uml5VldHRCtZL25sV3U1a2xFb24wCjhYRVBv'
    b'Zm5SNlRRR0kyVDB1VThxOFVETEYrc2xyRm96TDI0YjZPKzdOd3RGSW8zdVRGVlZzWmhNTm92'
    b'ZDlPaFJ2VUtodE00YlpWM0wKWXZCNFhGQ1FMNTFPWTlCcGREck56bzVvL3JrT3I3MGliVzFU'
    b'RHp6YiswQmdzZVRVNUdkT2E2TlNIZExURTlMVEV3QUFnNFBTdXJxVwpxaW9XczVyTlpMS0ZR'
    b'akhjQ29mbDVPU29iV2QwT2kwNHlOZWlBWEdOV2oxUXdlUmZ1eUc4ZTA4dGxWbjJ5ekVZMG94'
    b'b2g0eDB1NlFFCkJNYXl2M0pIUnplem1sMVZ4V1l5MmMzTjdScU5ac29oOVBQempJOW5NT2do'
    b'RVpGQlZJckRHSzR3V0ZmUHYzcERjUE9Pa2k5NEp1aVIKek9HUU8wQWsyaVhPY3NoSUo4WXd4'
    b'ckNTamN2ai8xRmRWOFZrRlJWVk5UVzFUUldFUVVFK3g0N3V3T0d3bHA2bzZPa1YzTGpkZC9t'
    b'cQpRVkQvZ29SeGNiWlBUM1BNek1CNnVGdDZya3d1WDdSb0k0dlZPSVU2MGxkZlRmbHUrMm96'
    b'SzZ2NiswVUZKZnpyTjhRUGhsUFNmNTVzCmd3SWRNdWJZcDZmcEoxMUgxemQvMzN2eDRxMHBa'
    b'd3ZYclZzMi95K1pvL1dBY3Jtb3NJUi83V1ovYVpubXYrNFFJakJvMHN3WkRobHoKN0JMaWpI'
    b'TnYrc281bFp1VmRXUXF1ak1vRk9yZ2dTMHhNV0VqbXJyZmJ5dUZ3bWY4QUJzYk5JbUlwbEp0'
    b'M0taaEtJNlNHcGFFVlRkSwpmVUprT0RHYW9lRHg1RSs2bEJ5ZWdzc3pUcmtaR1V1Q1hXSzhR'
    b'MFk2TVpwaFBJN1BaTEtYTGQ4MGppSEhPSHVrWkRMcFZNNU9YUlpiCjF0b3V1SG1IZi8ybS9q'
    b'Z1JBb05HMjltaHFWUU0xUkZOcFdBb0ZBeVZncVk2WXFnVU5JV0NvUTVQZ2RHb1ZPdzMzbE1L'
    b'UnFPT0pwTnAKdWIvb2p3aXFaVElscjAvQjVTbTVQQVdYcCtEMUtiazhCWStuNVBEa3ZSeTFa'
    b'RGhLd1RnN2tWTVNIVjdMc0EwWW11YlQzYzJkdjJCMQpYNTl3U2djVm9hRUJSM1p2a0Q5aWFU'
    b'TXNHR2NudElPRGpZc1QydEVSNCt5RXBqaWd5V1F6TDlWZitxQmw5WVpuVnZQWi9RTnBSb3la'
    b'CjExUUtoVW9lWDlITFVmYjF5WHM0U2o1ZjBjdkJPRkdKVVhTYnNKQ2xYL3hRVTlNdzFVUDdt'
    b'cG9HdmtJOVBUV1puSnI4bkpjUzNMb0wKelJXRWhTQ1FxSUUvSHVvWENtL2ROUjhobWt4R2s4'
    b'azRYMi9qUTUyZFBlUE9EMWpEUEZJbkowY1RNMlVzbDBhcEZOMHZoQVR2N2h2WAp1SCsxQnVL'
    b'TUNPOFd2QkRueU0zTnhlUk14aW1IOEVXdEdPb3ZxMUNKREtZVXV5ejZFT2Z0aGZWd2QvbGtn'
    b'VUdJSWhhTEgxUzhrQStOCmpBaUNFUUs2aGN2WXVWeitqUnVGZTdLUFFVWVNoTGNOZWxHY240'
    b'L1RndmVIR3ZwSEg5Z0craHQydVFhekNQdjdCN1p0MjNmKy9IVkwKczJXUmtlTy9ZbTM4YmVF'
    b'ejc0SktwYXFyZjh4a3N0bXN4Z2NWTlYxZHZRQ0FSWXZtNlE4Y2FoUUswZjBpdlg4bXduM2RG'
    b'N3FKVEFnVQp5bTNkRjAzTC8wK1gyaGJkSzlESVYrazZXQktKUUNRUnRtN2JCd0NnVU96RHdn'
    b'Sm9OSDhHblVabjBMQ2pSb1RXc0kzQ09DUEVZbTJDCmdrek0wQldMSlRVMURWVk10bmE0UnlZ'
    b'eldCT0R0YkZaTVA5MWcyWlVVcTRTRHpkS3AvZm00Y01NSm1yZ2FVR1VkOS9pbmowLzlMY1kK'
    b'a1BTWFBiQkxIRjdiOXRHSGMwK2Z2aXlUeVhrOFFYNStlWDUrdVRaeURRcjAxcWJnbzZQREhC'
    b'Mmh2akdONW9mRFlhVVdadGduRmNLdwpzRURNMDFFQzg5UC9iNy85TXBWcWtCd1g2UFdpTnRO'
    b'Y1haWitZbnlXNi9MRm9vSmlYY1FwdUpXdmo1QkNzWC9ycmZRelovSWdIUUNMCjNjUmlOK1dj'
    b'eWdXbUJsWFFhRlJvaUg5RlpjM1VqUXRUVW1MRFFnT3IvNml0cnE0MWM1UWNqVWJsWGpxZ3Z5'
    b'T1RSaTVuWmI2ald4VTgKU3RnbnJtUTJyMXlyemJJaThmaVF5K2YwWnoxMWQzTmZmK05UTS9N'
    b'c0pCSWhNakk0TWlMNFVVMjl0c21PVzVKcmZDZGV0TFkrS1M5LwoyTmJXSlpjcnpEemx6Ymx6'
    b'TWpOVDlVdEU5NHY0MTI1cVh6dTgrb3JUWDk0ZDZWeWJhYTd5SjkzU3hpYXQrYlFOQ3NSNUQr'
    b'OXNRU1RpCnU1NXdhbXZOV204bWx5dmEycnJLeXgrMnRqNlo2aDZwWlY4WGlWeTQ4RzFJb2ZC'
    b'cFJJOG1rNmV0V0c1QVZ5UVdHaTVlbkw3eWM3U2oKQStSRW5SWXZlY2RLMXU1T1dvUVpHVW1l'
    b'bmdaTFFkVlNtYWlvZEFqUGx5c2gyYmhUcDNKUEc1bzNsQjFwK3FyL0hRSmNXS3cvSVI4QQo0'
    b'T0h1K3ZMTENURENQODF1SXhDTEY4MkRGSXFLU3RSU0tRREFMbjZtZlZxSy9pR0pSSHJtN0pY'
    b'VHAzTUhCZ2IxeSsxZm1tMlhuS0RGCjMxOWNDcm5nOG1Ydlc5VnVDSk1LWVdycVRIOS9MNU85'
    b'S0lxQWQxdTdDbkxvN05rOGdVQWtGSXJQbmJzS3pZMnRXWWtpRWdFQWd0dlEKbFlJK1B1NHBL'
    b'VE5oaEgrS2xpeCtCMUtpSGh6c0x5NERBTGorenpMSWNsR1pYSzZOQkFBQUowNWVoRVNXR0Ny'
    b'RjliTWxBQUJSWVlueApCamVmTG44Zk1YRzJnNTR3Q0JQaW8wSkRBNkM5NlAxaXRVeUdEd3Vo'
    b'dkFFZC9iOXc0WGN1bDY5OXplTUpmdnNOdW9VTlpXNG1JVEpjCkk1ZjNGNVZBRGdVSCs4NmFS'
    b'WWNSdnVnbXVNUkVxQ0M0ZlJlQndYaHNoQzZLVnlwVng0OWYxQzg1ZXV3Q05PQkRJdHczcmtI'
    b'WTJCajMKcFFDQXp6NzlBRWI0SWhVZEZSb1ZCVjMwcXhxUTlKYytjRm44RWRiYkUzTG9VdTV0'
    b'YlNwVlAyeS9uSGNIVWczcjRlNnljRUYvY1psKwpjazZyaUloZzQwK0VFWTVkUzVlYWFJS2ll'
    b'NFZZVDNlbitlOUJEYVJhZmZUb0JlUDZQLzM3VitNOUtwdysvQURuNHlVcUtETHhvVXZlCmd4'
    b'RytHTkZvZmliM3J4UGV2ZSt4OFV2amRkWFhyeGUwdFpuSW1MUjNkUDkrb3hBYXFLQlE3bCt0'
    b'RmVZWEdOZVBqMmNZVzE4WTRWaGsKMGo5VWljVTRIeS9iWU9oRHRqUWF6VTgvL3pyU3BRNGYv'
    b'a1d0aG1iUGJRUDhjRjRla09IaXB3M3hIUmpoODhyWDF5TTVlWVp4K1dCOQpvL01uODQzTDc5'
    b'd3BiV2dZY1ZPUjV1YjIvUHhTNDNMbmhSOUpXeDRibDgrZVBUTWd3TXZLYjVHMVAvQUhoOE51'
    b'LzI2L2NYbFNYT1JzClcxdmo4aVAvUGpmNkJROGZPV2Y4NEFRa0Rsdk9FZDNmdHMrNHZvbDlv'
    b'bUNFRm9uRmFqUzVVT0Z5N3AyZnBqbERiRlZSVWRVelZ6V3cKV0kzRnhWV3paakgwQyt2cVdq'
    b'WnN6aDdma2RzcGtaMkJKRi9XZkxtRHp4Y2FOa0d6bmtwNDRPQVpnK0JTMkw5NnpmY1RsQitZ'
    b'ME05cwo2dTdtckY3emcxSTVGQ2RVVk5aVVZyTE1PYkc2dWxaWFU2VlNyVjI3bzdOekFqK2Fh'
    b'MkkvZHF1cWlyVW4rK2hRRXp4eXp2d1RkZTExCjErNmo1ZVVQSi9STm1QRFBMeng1OGxKZ2dI'
    b'ZGdvRTlKQ2RQOHM0cUtxbXBxR3RyYXVuSnlMazMwTzJDOTJ5V1lMeXpXSmlEQTY5RWoKeSti'
    b'R2g0VUZORFMwUWtZd1lJU3dZRnNJQzBZSUk0UUZJNFFGSTRRRkk0UVJ3b0lSd29JUndvSVJ3'
    b'Z2hod1FoaHdRaGh3UWlubFA0ZgpWUlFKcURWVE0rY0FBQUFsZEVWWWRHUmhkR1U2WTNKbFlY'
    b'UmxBREl3TWpNdE1Ea3RNREpVTVRBNk1UVTZNVEVyTURBNk1EQzhjbzNVCkFBQUFKWFJGV0hS'
    b'a1lYUmxPbTF2WkdsbWVRQXlNREl6TFRBNUxUQXlWREV3T2pFMU9qRXhLekF3T2pBd3pTODFh'
    b'QUFBQUFCSlJVNUUKcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlODE0MCIgLz4KICA8L2c+'
    b'Cjwvc3ZnPgo=', 'JP_01')

JP_01 = b64_JP_01
index.append("JP_01")
index.append("Japan Hokkaido")
catalog["JP_01"] = JP_01
catalog["Japan Hokkaido"] = JP_01
country["Japan Hokkaido"] = ('JP_01', '', 1)
lookup["JP_01"] = ('JP_01', '', 'Japan Hokkaido', 1)
lookup["Japan Hokkaido"] = ('JP_01', '', 'Japan Hokkaido', 1)
details["JP_01"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_01"] = ('JP_01', 'Japan Hokkaido', 1)
regional["Japan Hokkaido"] = ('JP_01', 'Japan Hokkaido', 1)
#----------------------------------------------------------------------
b64_JP_02 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc0MjYyIgogICB3aWR0aD0i'
    b'MTQzIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0MyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQW9tb3JpX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAgeG1s'
    b'bnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2Nh'
    b'cGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0'
    b'L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAg'
    b'eG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBp'
    b'ZD0iZGVmczQyNjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXc0MjY0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2'
    b'NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRv'
    b'dz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBh'
    b'Z2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9Imxh'
    b'eWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzQyNjgiPgogICAg'
    b'PGltYWdlCiAgICAgICB3aWR0aD0iMTQzIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBw'
    b'cmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmlu'
    b'ZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZzti'
    b'YXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUk4QUFBQmtDQUlBQUFBd2d2U0ZBQUFB'
    b'QkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFk'
    b'VEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFICjIw'
    b'bEVRVlI0MnUyZGExUVRWeDdBYnlDRWw2aEFhVUdsVmw1S0syclY5ZEU5MG9lMnJoNWI2OWx0'
    b'cGEzdWVtcHI2NGZxdG52YXJWMWwKMis3U3JtZFBDeC82Vkx1K3NQaEFlN1JXUlJFNDhZRmd3'
    b'aU1CVEVnQ0pBUXlTY2o3TlhsTVpqL3NPZFpGRWpLQmtFem0vL3VZekgvdQp6ZjNOZmM2ZENZ'
    b'c2tTUVRRaEJnb0FyQUZnQzJ3QlVVQXRnQ3dCYmFnQ01BV0FMYkFGaFFCMkFMQUZ0aUNJZ0Ji'
    b'QU5nS2dBR3pkdHZwCnZWN1NDN1pvQUVtaWFrSDl1b01mbUhBYjJLSURMSFNsdTNuTmdYZEZH'
    b'am5Zb2dlM2xhSU5SejZxRnRhRExYb2dIZXAvODlTL3RwLzUKdDR0d2orK1pNWXNlYkkwL1Zw'
    b'ZmpRUFBQejN5L28wYmNOQzRuRkdEU1B4Ny9aT3Vwc3JEOEhEWVRCcjVOaXM3WHFqNWVPMmY1'
    b'eDg5dQp6VW1mSHR4Skd1VWQ1ZGVPTjhoYWpiajEydzN2ZzYwUVlzSnRWVzIxZFRMKzZvS2xP'
    b'MWRzbkplWkczanNWUW52cTV2VjNONTJNMjVECkNCVmtaRzlhdUJwc2hSeTF4WENFZittbkR1'
    b'NXZzdWNzbjFuMCs3bFBGV1g1MUNaVXlVNjBYMjFVZFBDVklwc0x2L3Y1c29mbnhyUGoKd05Z'
    b'RVlYSGE2NlF0ZGRLV0w3bFZzOUttVDB0SlQwMmFuSnFVUW5pOUxzTGxKZ2kxUlk5WjlIMEds'
    b'Y1B0SEJZYno0NTc5ZkZudzVWegpKdHE2aThQdDZsTDNkcWw3QXcrWmw1bjNUTzRpR01IVGd5'
    b'ZG1GYkZZTExCRkE2WW1USHA3MlFhWUhkT0RlVm01ZWNGT0FNRFdSTE00CnV6QzhHUUJiZ1RJ'
    b'cFBuSHp3dCtCTFhwUWxKazdOek1IYk5HRGhkTm5oejBQWUNzZzRtUGpOczVmQ2Jib1FVNzY5'
    b'S1VQUHdxMjZFSGgKZzQvRXNHTEFGajBvZUNBN0VySUJ0Z0ppVWZhY1NNaEdtRmQxcXdVTnV5'
    b'NSt3d3Fza1hscjJmcS9GTDh5eGhRbkp5UXZ5UzRzeXN4OQpLQ1ZkWXpYY2tndWIrdThRWHNM'
    b'L1RPdnhhZmxnQzVsd2E1OEJDL0JnekdJWVMxcFRFeWM5bDcva3ZlS1NSVE4rclNna1NaYlZI'
    b'UzduCm5qQTdmZTVvUzJRbnBDYWxnQzNrSkZ5QkgyeHhCcmxGa0lWWXhUbno5Nng2L2NtY0Jj'
    b'Ty9ZckYycjl3aU4yQ0hlQmQ4aFNmRWNWSTQKU2RCdm9mdHY5L20xWlE4aWlmU2t5ZThXbDlT'
    b'OFVYRy9xcnQ4dFBKUGFiNXJUeEluSVl4M1NTS29icG1wQ0RCVDMzNjdZRnIrNTJ1MgpyOHBm'
    b'N1Ard1dhbFplZW5aemZhdWtldFdtTzdyUjV3dG05TVJvcm9WR3hPenZuREZnWmQzcGNRSDFJ'
    b'aGxKS2Y2Yks0OWJyQ0ZFRUxXCjBOU3RwTGo0TFl2WFZyenc1OEJic0dST3ZNOUx5b1Y3U1c4'
    b'a3pJN0RiRXRuTjFPcVd5UkpqaW9nSVpienpwTXY3WHA2TTZXY0pITVMKZlhldXVORmhUVXVh'
    b'elBSUnhwRGRSS0haZERsR2ZYSWtMamIySDZ1M1VWV0ZFT0t3T2I2dkVzZVF6UWhqUXFTbFVn'
    b'b1dwMTAzbXQySApKcVZ0WGJJdWlKeTRQQzdmL1phclRTVmx1cTFCOHhCbTFnVitQTzV4S1l5'
    b'YVVNMGxQUDdtRXBSMnNVV25yVm9KejRSYktZVjBZckpRCjlhQTJmN1cyVDY5aXVpMEJScmw1'
    b'R1RBUGhheE45bWVyRjJ4Smg1UlVRL1JVeHBCVXhpKzQydXF2VGU0MVlQZHVoV2VjTGNMckZX'
    b'djYKcVVhcExMcFFaS1pleWxmNWZZQk9aUm02SUdwa3JxMmI4ZzY1Z1hMem9qQmlvY2pNdGI1'
    b'MjVQOXQwQ1I1VmNwajd1ejR0TERlN2ZWUQpqVklhdFNxTExpc2wzYmRPOWZNSDN4KzI3akEv'
    b'SysvUXh0MStUaXRVOVl5YWRBZld3MXhicllQZFFVU1pjT3Y1cmh0dkxuM0Ixd0ZxCnExNnNs'
    b'UlBlLzZzb09Xbit0a01iSEJaaEFFTk5zVVl1TjJJenAyWXlyaVdVYVBzN3NTQm5NUFd5Vmov'
    b'Zk5zaGFoNmxDQ0dsdC9tNWoKN204Nmh3WFFIUnB4NnhIK0pTYjJXOS9jK29ucVRPdWVTaW4y'
    b'ODR4KzY0QmtwSXREcVRDcWZZV2M3N29SWU5MWGU5c1paNHNreVJ0OQp3cUREWmJxQjd4clBq'
    b'dmlWMWVYZ0tlL2MvL21RM2ZnRjk4Y1JReXBiTDdjTWlnSk1tcThVZDJzVXpMSlZMYXdYam1I'
    b'WmpTVEpJL3lMCkk4NSt5bW9QOStvSFI0dzZJK1Rldk84U3NibndjbTZWMHhQb1lNZUVXNzly'
    b'T3Nzc1c1VXROUjYvZTR4R3BWMGxlZjFrMmJCWGIvR1UKb2hPQ1dsOGhtRVczN2N6ZWkrSmY1'
    b'MHgyTjE1eXJGU2dvcmFVMVNnWGhQR2ZYMWdUbkhiYllQZXFmVHZIL3Nxc0dGYk1xdnpGbjYx'
    b'NQplMzVXSGtMb1hOZjEwc3Y3UngyNVRFMUkvdTBqQ3dveXN0a3hiRzVQUzFOL0Y5VjBPYkhz'
    b'RTV2K3VhN3dDVWJZZXVYSDBtcEJ3M2lkCmJVcEM4dXdIWnhKZW9sdXJzRkRaTkRBV1hueHN4'
    b'YW5OREhnWERVOHBxcFB5eC9HRUp0eldyT2lhNENKcjZHa1RhZVZ6TW1aR2ViLzEKV2QxaHZk'
    b'MkNhSTdSWWRsYlh4bmxvNHpUSGZWWEpYd1VGVnp1YnU3VzlrZXRMVGZoK2JMaHVOMk5SNGN0'
    b'amRYd2FlM0JxTFcxcDJiLwo3UUVSaWlJdWloc2IvSzZCMGRYV0xVWG4wWmFhS1B1RFNqTnVL'
    b'NnM3UE1FL0t1UzJuQjczQjc5OHJiSHFVZFJ4dmErOS9OckpxTEsxCjgxeEZvN3dEUlNNZWd2'
    b'aTY4YlJNTnhBbHR2N0RPMys4N1FxS1hoUUdiTWZaOGdsNy9Yd0liWEY3Mmo2OWNpZ1NOcCtF'
    b'bEZvSjc4TUwKMzlMYlZwOUJ0ZU5zeFlCSmc2SWRMK245b2ZsOFZWc3RYVzJaY091cngvN2Vx'
    b'ZTVCek1Ec3RPMjV0Tzk2WHp2OWJMa0pUOG14MHR0SwpFV0lTY2lQMnhxbTliVUZ0TmdtYkxU'
    b'ZmhlYTNxazFvSkR6RVBtVTY1NVdTWklKVFBONHpuSFJNWDRTNnBMUDM1emczRVlQTFNaMVNz'
    b'CjM3bTZZR2xFMjdLNzhaZVA3cTdwYmthTVo5cVVqQStmMnJSOStZWUl0V1Z6NFM4ZC9kc1Z5'
    b'VzFROVQ4NGJNN2EyY3YyL2VHdnFZa3AKRVdlcnN1VVNUeWxteDhhQ3AzdFhPbVpNeVhpdnVH'
    b'UWNIMWhtUmRsaWEzUURiK1VDV3dEWUFzQVcyQUxBRmdDMndCWUF0Z0N3QmJZQQpzQVdBTGJB'
    b'RmdDMEFiSUV0QUd3Qi93V0MzSFJINEQ3NlhBQUFBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUFN'
    b'akF5TXkwd055MHhNMVF3Ck9Ub3hNam96TXlzd01Eb3dNQ3c5SnlNQUFBQWxkRVZZZEdSaGRH'
    b'VTZiVzlrYVdaNUFESXdNak10TURjdE1UTlVNRGs2TVRJNk16TXIKTURBNk1EQmRZSitmQUFB'
    b'QUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2U0MjcwIiAvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'JP_02')

JP_02 = b64_JP_02
index.append("JP_02")
index.append("Japan Aomori")
catalog["JP_02"] = JP_02
catalog["Japan Aomori"] = JP_02
country["Japan Aomori"] = ('JP_02', '', 1)
lookup["JP_02"] = ('JP_02', '', 'Japan Aomori', 1)
lookup["Japan Aomori"] = ('JP_02', '', 'Japan Aomori', 1)
details["JP_02"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_02"] = ('JP_02', 'Japan Aomori', 1)
regional["Japan Aomori"] = ('JP_02', 'Japan Aomori', 1)
#----------------------------------------------------------------------
b64_JP_03 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4NDc3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSXdhdGVfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzODQ4MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzg0NzkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnODQ4MyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUJibEJNVkVVVVhuQWFZbk4rcDdCOXByQW8KYkh6'
    b'dzlmYnk5dmNxYlgyaXY4Yi8vLytodjhaQWZJdjgvZjM5L3Y1RWY0M0YxOXpKMnQ0VlgzRmps'
    b'S0JpbEtBY1pIWGk2KzNrN2U4ZApaSGFJcnJlSHJiWXRiMy8xK1BuMytmb3djWUdzeHMycnhz'
    b'eEpncEQrL3Y3Mitma1dYM0hOM2VHSnJyZUtyN2pSMytOdG02Ymw3ZThlClpYYmk2KzVzbTZa'
    b'WmpacXh5YythdXNFZ1puZm83L0ZsbHFHUnRMeksydDdHMk55UXM3eGtsYUhxOFBJaVozaHVu'
    b'S2N6YzRQNSsvdEYKZjQ1QmZZdjUrL3cyZFlYUTMrSkdnSTc0K3ZzeGNvR3B4TXV3eWMrb3hN'
    b'cE1oWkt0eDgxT2hwTktnNUgwOS9nc2JuOHVjSUJMaEpLRgpyTFhUNGVRWFlIS0VxN1FhWW5U'
    b'ZTZPdHhucWx5bnFuaDZ1d2JZM1RqN082Z3ZzV0NxYk83ME5YcjhmT2t3TWVqd01jaGFIbXF4'
    b'czIwCnpOS3N4ODBqYVhxbHdjaG1scUp3bmFpR3JMYlAzdUpJZ1krdXg4NnF4Y3RKZzVHdnlN'
    b'NU5oWk52bmFqSzI5L0gyTjJQczd0c21xVmgKazU5RGZvMG5hM3g4cGE5TXpOdUVBQUFBQVdK'
    b'TFIwUUo4ZG1sN0FBQUFBZDBTVTFGQitjRERnc2lEaXkxQ0w4QUFBSnRTVVJCVkdqZQo3WnJa'
    b'VzlOUUVNVXZndUFGSzdUc29FQmJxTWhPV1VWUm9XVzFLcUN5VS9aOVZYRDc3KzA5dVpFYkg5'
    b'byszY3pEL0I2YW1TVGZsL05sCk9abVpWQWlHWVJpR1lSaUdZUmdtYndvS1NNcDZVRWhSVmRI'
    b'RDRoS0NzaDVKV1VwUFZkbGpLUU5QeU1rcWx4a3Fnc1JVaFNTb3BLV3EKcXRxUlZWTkxTbGFk'
    b'MU5SVFV0WFE2TXA2K295UXJDYjVqMlk2cWxyQ1NsQWtvbjdETFZSVVJWdHhudHBpV0R5UEVw'
    b'SFZEamt2T3FvNgpFWFQ1SktPN1I5SHJwbjM5VUJNWElvNmd2OC9kMG9zZHV5M0owanBDT2gx'
    b'QU5xZ01mZ2poc040d2dtejBwYTNUTldaYTU2dlhLZ21NCnEvaE5RTVZ2MzVrVzIyN3ZIcDh3'
    b'ckhNU2oyRWlxZUprQWcvakpEYlVZNmVKcUcxSDBOWTVoY05QcTdBSDRZeGhzZUZabTNmOW5H'
    b'R2QKSmNWSTVvVjREN1dwRDRiRk5sbDlHRDg2cCtJVGtnVUlXRnpTMS9hemVVS1RkazJpemJE'
    b'T0wxK1JMSzlnc2JwbVdHeWRaZStxWGNkaApOellWVzRqVGFTeTJzR29EOGJyMU9pY3U4MkRF'
    b'dnRjUDVWWTE2RU1ON1Zobk52enBPTFp6eWRyeDVZMjl1N2VmbFlORGxuWFBVYTZMCnVPMkhx'
    b'anh1K1hIQkJ1RnduSStkeG0yckl2cnlpUmsxbm41Vm55d2JyK3FnN29ic3F2SVVOcWR1WVhP'
    b'R1lBRXJ6LzBvYkM0ZzROSXAKUTFQZU1qRGlGSzNOV0R0blU5V1ZlZnhMSFA5YWhkTUlwOHk1'
    b'eEkzRk5wcG1pL0hOMDVBbHNqZGtZN1pVNmZiVm5md05JL3Vlc2M3ZwpMY0k3ejRRd2JhdDlK'
    b'ZHJzLzArWGR6VHlnOGpFUmx0bmpOZ2dpZWpZemJWT3cySnBjRC9TalZBYTZXcnJ6SEJLU1pW'
    b'WW8vbTVRRlE2CnNuNEtZdEQ4Rk9WOHVQc2x5RkdhS2FIcHFSSy9hWDRVRm9WL0tLcWkrb2NE'
    b'aG1FWWhtRVlobUVZb3Z3RmZ2bCsza3ozQjlJQUFBQWwKZEVWWWRHUmhkR1U2WTNKbFlYUmxB'
    b'REl3TWpNdE1ETXRNVFJVTVRFNk16UTZNVFFyTURBNk1EQXRVQkRhQUFBQUpYUkZXSFJrWVhS'
    b'bApPbTF2WkdsbWVRQXlNREl6TFRBekxURTBWREV4T2pNME9qRTBLekF3T2pBd1hBMm9aZ0FB'
    b'QUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBpZD0iaW1hZ2U4NDg1IiAvPgogIDwvZz4KPC9z'
    b'dmc+Cg==', 'JP_03')

JP_03 = b64_JP_03
index.append("JP_03")
index.append("Japan Iwate")
catalog["JP_03"] = JP_03
catalog["Japan Iwate"] = JP_03
country["Japan Iwate"] = ('JP_03', '', 1)
lookup["JP_03"] = ('JP_03', '', 'Japan Iwate', 1)
lookup["Japan Iwate"] = ('JP_03', '', 'Japan Iwate', 1)
details["JP_03"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_03"] = ('JP_03', 'Japan Iwate', 1)
regional["Japan Iwate"] = ('JP_03', 'Japan Iwate', 1)
#----------------------------------------------------------------------
b64_JP_04 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDcxMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01peWFnaV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAgIHht'
    b'bG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3Nj'
    b'YXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5l'
    b'dC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAg'
    b'IHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAg'
    b'aWQ9ImRlZnMxMDcxNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzEwNzE0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0i'
    b'IzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNo'
    b'YWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9'
    b'ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwNzE4Ij4K'
    b'ICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAg'
    b'ICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5k'
    b'ZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9w'
    b'bmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5D'
    b'QUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2'
    b'QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ3IxQk1WRVVBV1V3ZmJXSjZxS0s1MGM3'
    b'bQo3KzM1Ky91MzBNeDVxS0VkYkdDcXlNUDkvdjcvLy8vOC9mMm54c0ZhbEl2MStQano5L2RW'
    b'a0loM3BxRCsvdjV3b3B0ZGxvMVlrb3J5CjkvYng5dldpd3I0Z2JtTDcvUHo2L1B0N3FhSjJw'
    b'cC9NM3R2MitmbG5uSlFMWUZScW5wYjQrdnJIMjlnYWFsNXBuWlp0b0prVloxc00KWVZUMyt2'
    b'bE9qSU9OdGErdXlzYTB6c3FHc0twdW9abXd6TWpaNXVRN2YzVkFnM25SNGQ4V1oxdnY5ZlFG'
    b'WEZBRFcwNFFZMWNIWGxFUApZMWZ3OWZRSlgxSUVYRThCV2swWWFWM3Q4L0xYNWVNOGdIWkZo'
    b'bnpQNE4yMno4eHlvNXg5cXFTcnlNU0tzNjJ4ek1pNzA4K0NycWN0CmRteEVoWHd3ZUc1Umpv'
    b'VVNaVmxJaUg4c2Rtc0dYVkJpbVpISTI5aC9yS1dmd0x3T1lsWWliMlRDMTlSaG1KQlRqNGJq'
    b'N2V2TjN0d0kKWGxMSzNOcXl6Y2tYYUZ6VTQrSEExdE5tbTVUUTRON2k3T3VadmJmbzhPOXpw'
    b'SjJmd2J4Q2hIcVl2TGNDV2syc3ljWGM2T1pMaW9FYwphMkM0MGMwWmFWNVBqSU9weDhPRHJx'
    b'aVd1N1dYdTdhZ3dieUJyYWN5ZW0vYTUrVXJkV3ErMWRFOWdYZTkxTkZLaVlDRnNLbE5pNEs4'
    b'CjA5QW9jMmhXa1lqNi9Qd1RaVm5oNitwZmw0OG1jbWZGMmRidTlQUHI4dkUxZTNHTHM2NXJu'
    b'NWZrN2V5dHlzVzF6OHZlNnVoU2pvWWgKYm1PZHY3b3plbkFiYTE4WmFWMmJ2cmtqY0dWVWtJ'
    b'ZnM4L0xTNHQ4cGRHa3ZlRzBuY21mTzM5M3E4ZkRsN3UwdWQyeU10SzZQdHJEVgo1T0l4ZVc3'
    b'TDNkcHhvNXVteGNGa21wS1Z1clUvZ25oOHFxT1N1TEpaazRwK3E2U0hzYXRqbVpGY2xZMWds'
    b'NCtPdGJBS1lGT0FyS1pzCm41aWN2N3Fod3IzRzJ0ZVR1Yk1rY0dYcDhmQkhoMzVlbG82NjBz'
    b'K1J0N0treEwvMCtQYzVmblEzZlhOUWpZUkdobjExcFo0TllWV2sKdzc5b25aVTBlM0NFcjZr'
    b'NmYzVlhrb2xKaVgrVXViUTRmWFBKM05uVDR1QXFkR25XNU9LenpzcHZvWnJiNk9aSm5tVElB'
    b'QUFBQVdKTApSMFFMSDlmRXdBQUFBQWQwU1UxRkIrY0ZFUkk2TDNZS3FpNEFBQVRnU1VSQlZH'
    b'amU3Wm41WDVSRkhNY2ZFd1QyZVVDSXpISlhaV0VSCjNOVk9KQ1ZZV0hDOVJaQmlQWUJZZ1Vp'
    b'cENNekNvbFM4RDFSRVJhM1dneTd5UVBOVzFEektvTHNzdTlQcUQybWZmZlk3TS92c3M5VkwK'
    b'WjUzbmgvbjh0Si92UFBQTW01bDVacjR6Q0FJWEZ4Y1hGeGNYRnhmWHJhcmZYZjBqSWlNakJr'
    b'UkY2d2txeGlENkpjWHFCaXh1b0VnbwpQa0VmVkhlTGdVcThSdzlVZ3hKRk5kZTlPcGhYZzhV'
    b'ZzNjZCtmc1dLR3JxZk5kVVFveGFXaVhWM0RSVTFOWXd4MW5BQVNUSW5KNmRZCndLV3lwUnFC'
    b'UHNNMDJhYURNNHhraXBVQUhBT1RaV3UxZ1IvRkZHczBZRHlnK0FmQlA4UVVhd0JnUEt6NFll'
    b'QWZZWXIxS0dCa0tINE0KK0V5bVdHZ3VQYWI0YVBCaldWS05RK3VuUDVDRkVoeVdXSThIZFE1'
    b'YXViSVpZdVVBaEQxb1ZITVpZdVdoUVhTb1J0WElkTW9uQVVhKwpmK2NHWDhBVWF6eGdPQlUv'
    b'QWZ4RXBsaVRBR095NHFlQW44b1VheHBnVEZkOElmZ1pkNDRodTZpNGVHYmdGMWFDOGhxcmJK'
    b'OHdnWDh5CjRMSGNtY1hGcFdGWk1seXpDbjF0R21iUEtjTFJmSlRZekpWdEdscE55L0F6NVpN'
    b'ckpOL1hXdmlVaXpaVnBadklQZWVacXlCZWpZSTEKK1U4N2FzRThnLzZhK1F1SWluVWxWS0d5'
    b'bmxVbHhjODk3d28rSk5hL2dINm0rd2N2M2EycTJKQkZqNnB4WVhDMi91SWlYOUZMRm55dQpL'
    b'SDhaL1d6eUZTNk9DSzczU2lNMXJGYzFqeEgxT1hKWk0vS3ZaYUNmTWI0TjgzWE5ha3RvVVMw'
    b'MWFCOXZsclhJcVl6ZDd5elJ5MUhKCkNtK0IwNjFkeTdDVUV0WktNWVRpNVdWZ2xhU1kxV2l4'
    b'RUJkNHcydVNRdFZhUzRkcW5SaFNrZXZsNDQ3Y21Sdkd0MjVFWVc5MGt6RmsKcGNUTlZMRG1v'
    b'QmNhMnlwVWZXQmNJL2ZYRmxGczM3b05CVE1iaGUycSt4SmJSWnVFekJTNng0Z083MXpLSGJV'
    b'am9CK1M1R2tVM1d4cApIb01uWUlsUUdUQWJqVEVKM2oyZ3FBUDhUaXBZdStCMWJ5ait6YmZJ'
    b'UnUwZU9iWjdUeDJLdERtY05uS2c5KzVUNm5XaXRZVUsxdHZ3CnVsYUllTjRobW0xL1YxNXZk'
    b'K0srZWUvOUFxSzRxeFJxallUUUIxU3c5c1ByRHVCTnU0Rm9PTUw3eFIvRTlwQzFtNWplcThl'
    b'aFNvY2gKNkthQ2RVUXJoL3FRbU5QeGk4elliQ3c3aW8xMEROZHc3SURvYkNwWXgwVlZydWRU'
    b'Q3RGZkVwNXNoaFBiaWJsZVNWUTRpY0tucUdBdAp4bTJlSnNKbk5CZWxzd2Z3SmluMkVJK2Z3'
    b'OTFMNTlva3J3UC8rZWVKK0FVTnF0U1B1ckM1U0R4c3hoMWFsMGRubWI5RVRPR3orSjJPCnkw'
    b'RlU3cWFMMkZ4eDRCenlJREVWMDJobFcwZUlsajl1d2ZHajZpdFR6MkVUM2hoeGVsMUt2cUNh'
    b'V3NaVlRpNUVwazlHb0R4c200cXIKRzY4TjlxdndWRk9EUkR6eTZSQjZlV0J2d0lZVEdkdXI1'
    b'S1pYVDBraE4yVC9SK2pxbldvaXc1WU1tbGx6bnlybHNuL1cvUGtYdGFGVApDN0hXNmZFNE55'
    b'Mlo5S1VxMlJwRTk0aGhOb2dVWklxamZmVHB0TjArbFMwTUY3MWYxZDB1MWE2dnczR0FiWjBl'
    b'c3NGNUUvOEhWV3hPCm1FNzduZnUxRzd4YzFSaFgvVjlkdFQ1OHR4RFdxSUxnQmp1KzhaVjlL'
    b'LzBMMU5qdndudHBXWmJlSGRoZ2U5UTFwZVQ3MEZCZFAxd0wKLzhYTjlSOHpvV1BhRjNiQ2JZ'
    b'VFZwSTBrcGM2NGZxZXVsS3cvL1p3eXYrZVh6WGd6Rm43RjF3eS85UTA5WHZQNzhOVENta09Y'
    b'ZW5NRQpsc3JHeTNtTG9CLzFJYXFWT3FJUy9rQllDVHFpdW9IL3ExK2xJeXg4SVhCRlQyTjRF'
    b'Mkd0MGhIVlBrUTEyS1VqckI2RTlhZWV4ckFlCllmMmxKNnkvZ1dwRHFjREZ4Y1hGeGNYRnhj'
    b'VjFxL29INWVBaXg3T2RhaVFBQUFBbGRFVllkR1JoZEdVNlkzSmxZWFJsQURJd01qTXQKTURV'
    b'dE1UZFVNVGc2TlRnNk5EY3JNREE2TURDVlVKdm5BQUFBSlhSRldIUmtZWFJsT20xdlpHbG1l'
    b'UUF5TURJekxUQTFMVEUzVkRFNApPalU0T2pRM0t6QXdPakF3NUEwald3QUFBQUJKUlU1RXJr'
    b'SmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTEwNzIwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_04')

JP_04 = b64_JP_04
index.append("JP_04")
index.append("Japan Miyagi")
catalog["JP_04"] = JP_04
catalog["Japan Miyagi"] = JP_04
country["Japan Miyagi"] = ('JP_04', '', 1)
lookup["JP_04"] = ('JP_04', '', 'Japan Miyagi', 1)
lookup["Japan Miyagi"] = ('JP_04', '', 'Japan Miyagi', 1)
details["JP_04"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_04"] = ('JP_04', 'Japan Miyagi', 1)
regional["Japan Miyagi"] = ('JP_04', 'Japan Miyagi', 1)
#----------------------------------------------------------------------
b64_JP_05 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmczOTMyIgogICB3aWR0aD0i'
    b'MTQzIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0MyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQWtpdGFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMzkzNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzM5MzQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMzkzOCI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNDMiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSThBQUFCa0NBTUFBQUNJUHBQZ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNBVkJNVkVXWkFBQ2FBZ0tiQkFTdE16TzQKVFUy'
    b'YkJRV25JeVBZbnA3UGlJankzOS9rdTd1N1ZWV2RDZ3JNZ0lEOStmbjI2T2lyTGk3bnhNVC8v'
    b'Ly8rL2YyWkFRRy9YbDczNnVxZwpFUkhUa1pILy92NmJCZ2JxeXNyRmIyLzU4ZkdqR1JuYW9x'
    b'S3pRVUh2MXRicnpNekNabWFjQ0FqSmQzZjg5L2Y0N3U3V21abXFLeXZpCnRyYWRDUW56NGVH'
    b'ckxDejU3Ky8wNU9UanVycTFSa2J0MGRIMTUrZWZFQkRCWTJQMzdPejc5ZldpRnhmNzlQU2tH'
    b'eHZkcXFySmVYbTEKUjBmeTN0NzE1ZVh2Mk5qMDQrT3pRa0tnRWhMZnNMRGdzckttSUNER2NY'
    b'SDkrL3ZJZFhXMlNFaXRNakw3OXZiQVlXR3ZOemY2OC9QWQpuWjI4V0Zqbnc4T2ZEZzdjcDZm'
    b'cHg4ZW9KU1hweWNuZXJhM0RhV21zTURDbUlTR29KaWJkcWFuKy9QeW5JaUxOZ1lITGZYMmFB'
    b'd1B4CjNOem13Y0d2TmpiSGMzTy9ZR0RUa3BMMzYrdThWMWY2OHZLbEhoNmRDd3ZWbDVmMjZl'
    b'bXRNVEdoRlJYaHM3UE5nb0wxNXVhbEh4KzMKUzB2RmJtN2p1Ym1oRXhQb3hzYTNURXpBWW1M'
    b'U2pvN2x2Ny96NHVMOSt2cktlbnJpdDdleFBUM3QwdExzME5DZURRM2NxS2lsSFIzdgoxOWUr'
    b'WEZ6Wm41KzFSVVcwUTBQVWxKVFJqWTJ1TkRUcnpjM3UxZFhFYTJ2TGZIeTVVRkR6NE9EUWlZ'
    b'bStYVjJjQndlMFJFU2lGaGJiCnBhWEplSGlmRHcvZXJLejQ3ZTNQaG9ieDI5dlRrSkN3T2px'
    b'OVdsclpvYUhmcnE2cEtDaTlXMXV1TlRYa1R2azVBQUFBQVdKTFIwUVMKZTd4c0FBQUFBQWQw'
    b'U1UxRkIrY0REaEl0S29UWmFGNEFBQU5JU1VSQlZHamU3Wm5wTzF0QkZNYXZTRFFTZ2hOS0xB'
    b'bUNvSlphMHFDbApSYlcwMGxxcXVxRW9yYlphdFhYUkRkMVhkRlhkOS9hdkxCSlhranYzSmgv'
    b'R25mUDBtZmZybmVmTTcza3pNKytaaVNCd2NYRnhjWEg5Ckx3cER4cU1KMStwd0VVVnMwa2Zn'
    b'SXRKR0dveW9USXFLTnNYZ01pazJEc3lvVElwUDJBeUF5cVRFSkRPQXhXQk1Sa01VbmdLQXlp'
    b'Uk4KYXRvS0VTS1RyRFlBWENhbFozaUlJTk9laFFKSWw1M2pKWExrNXVGSWtId0EwYVF0S0JL'
    b'a1FDVENZZEp5Z2dBdWs1WVRCRkNadEpvZwpxRXhhVFJCVUpua1NCSkZKM2dUeE5ha1FSNExn'
    b'TVVsTUVGRkZiRTFhVHhBc0p2a2tDQktUak1WU0lzdldFaVFKSXFvMGdkMGR3QzlCClJKVkZs'
    b'ek5MRU9jMkVsR1Izb29rUWRaa3ltVkdGSmdnWHJtU0tyQWtpRmVWK2tSR1JGWGJpVUJRdENP'
    b'S0VWRjFEWmxvcDEzRDZEQksKc3BDSmRobmoyUkNWMUpLQklLV09EVkQ5YmhrZ2FOakQ1blRj'
    b'MnlnRDVHcGlzNHoycGNsWlZCckxCR2kvUXc2bzJjMEU2TUJCT1NCbwpZZEt2dGNyeVFGczdD'
    b'NkJEOGtBZExCcVJ3NDN5UUowc0hwQ095UE5BQ3dPZW93bzhZRmVmNTVnU1Q4NXgxWGxPS1BG'
    b'QWwrbzhkWW84CjNUMXE4NXhVNUlGZWxYSDYrcFY1VHRHN3RRODRzd2UxVlVGR25WYkdnV0ph'
    b'enl4bmhqeDM0cml6U2gyZmRTZ0l6emxLcDBybGVzbTQKODdMRGhqdUM0RUFObFZicmdsL05p'
    b'eU15NHk2MUJjT0JVUm84WXdGRnh5ZUl3eVpyZytMQVpRbzRBOTJCVmE4UVJsWFlndE5BODFV'
    b'SwpQTmVrZGFja1ArbDFSd2c0Y0lOR0YwcW9teC9ZWnR3TWhRWnUwZWpKb2dtRmIvdGRoWFhU'
    b'T1NIaHVNSnByT1laVXVsWjM2NzVUa2cwCjRKaWxjdmJjSmRVMmlwL3ZrZCtBcEpiZWYwRG5M'
    b'SHhJcXY1bzdldFVRUWk3S3ZQeDRKTjZXc0ZGWEtwUFE5ems0NlA2aEx3K3FwSDkKakRDTnBj'
    b'cnpnS2l3eWNzTXo5MXpHL0VDTkVtWWJIN2xRNFNCVEdKYXNHVnJOKzRGVVJjcG5mSUZlWk0z'
    b'Wm5TOWZOV3owVTgrVHNtOApyN01rbTd4MjVzM2JrVVYxWGxJYUFuRE02Vkg2OVV4THk3U2x2'
    b'bHRTc3drdDcvVEhjWHYvL3phVnZ2OHdPY0hna3ZmeGt3L081OTdsCkV6dXk0VXRySWJ2L0tw'
    b'YStpa3MyWmZxYi9YdTd3RkpoUDJKV2I1ZnpQNXVxclFKckRic1h6UDIveG95L05RSjdKYy85'
    b'R1hQK0hSYXcKYUZIZzR1TGk0dUxpa3RjLzA1RGRNYk50LzR3QUFBQWxkRVZZZEdSaGRHVTZZ'
    b'M0psWVhSbEFESXdNak10TURNdE1UUlVNVGc2TkRVNgpORElyTURBNk1EQkhERi9SQUFBQUpY'
    b'UkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEF6TFRFMFZERTRPalExT2pReUt6QXdPakF3'
    b'Ck5sSG5iUUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBpZD0iaW1hZ2UzOTQwIiAvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'JP_05')

JP_05 = b64_JP_05
index.append("JP_05")
index.append("Japan Akita")
catalog["JP_05"] = JP_05
catalog["Japan Akita"] = JP_05
country["Japan Akita"] = ('JP_05', '', 1)
lookup["JP_05"] = ('JP_05', '', 'Japan Akita', 1)
lookup["Japan Akita"] = ('JP_05', '', 'Japan Akita', 1)
details["JP_05"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_05"] = ('JP_05', 'Japan Akita', 1)
regional["Japan Akita"] = ('JP_05', 'Japan Akita', 1)
#----------------------------------------------------------------------
b64_JP_06 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjgwMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1lhbWFnYXRhX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczE2ODA2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFt'
    b'ZWR2aWV3MTY4MDQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9y'
    b'PSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'c2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2Nh'
    b'cGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9k'
    b'ZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTY4MDgi'
    b'PgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAg'
    b'ICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJl'
    b'bmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdl'
    b'L3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhU'
    b'bkNBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFD'
    b'QTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDS0ZCTVZFVUFhNzBRZE1FSWNMKzMx'
    b'ZXd2CmhzbHhyZHB3ck5vcmhNaTExT3c4anMzLy8vK3UwT29MY2NEbzh2bnI4L29OYzhDdjBl'
    b'by9rTTIvMnU0M2k4dDdzdDE2c3QwMGljcisKL3YvRDNPOUdsTSs1MXUwUGRNSHQ5ZnJ2OXZz'
    b'UmRjRzYxKzFGazgvSTMvRkJrYzZFdU4rRHQ5ODlqczNMNGZJQmJMMVBtZEhFM2ZBVQpkOEx5'
    b'OS96eitQd1dlTVBCMis5T21OSFA0L05LbHRDTnZlR012T0ZMbDlEUzVmTUNiTDVZbnRUUjVQ'
    b'TVplc1AxK2Z6Myt2MGNlOFRPCjQvSlhuZFFEYmI3VzUvUlZuTk9Xd3VTVndlUlduZFBaNmZV'
    b'RWJiNWdvOVlmZmNYNS9QMzYvUDRpZjhaZm90WUZicjdkNi9hZ3lPYWYKeCtiZzdmY0dicjlw'
    b'cU5nSGI3OG1nY2Y3L2Y3OC9mNHBnOGhvcDlqajcvaHFxZGlwemVtb3plaHJxZG5sOFBnSmNM'
    b'OXlyZHZtOFBrSwpjY0F0aGNuOS92NHdoOG5rNy9oMXI5dXkwdXV4MHV0MnI5enM5UG9PYzhF'
    b'MWlzczRpOHZxOC9xQXRkNjgyTzY3Mk8yQnR0N3g5L3VDCnR0K0x2T0ZKbGRDS3UrSEs0UEhO'
    b'NHZLWHcrUWJlOFNVd2VOVG05TDQrLzFucDlpaHlPZW15K2dzaGNqVTV2U2l5ZWZoN3ZmaTd2'
    b'Y2gKZnNhZHh1YmY3UGNxZzhoZG9kVW9nc2Rjb05VbmdzZGlwTlptcHRlY3h1VWxnTWRlb3RX'
    b'cnp1bmM2L2FzeityYTZ2WFg2UFUyaXN0bApwdGN6aWNwYW45U2x5K2kyMWV3ZWZNV1R3T052'
    b'cTlwUm10S3R6K3BNbDlFWWVjUE00ZkxIM3ZGSGxNOTVzZHg0c2R4SWxkQkVrcy9RCjVQTVRk'
    b'c0srMmU3QzNPOFNkY0x1OWZzN2pjeDNzTnl6MCt2VEVHWlJBQUFBQVdKTFIwUUthTkQwVmdB'
    b'QUFBZDBTVTFGQitjRERnbzYKTHBRQzJoa0FBQU5RU1VSQlZHamU3WmhuVjlSQUZJWWpWUzRn'
    b'Rm5CUlFWR2FZRVVVVU5SVlZLVFl3STZLaUs2S2lvSU5zUUNLQmNFQwoyRHYyaWlpMnYrZk1K'
    b'bUV6TThuQVNjSW43dk9Cc3puUDhPNmJKZVJPVmxFUUJFRVFCRUVRQkVFUUJFRVFaRVF3YWhB'
    b'ZkZPUXd3QjdCCklYSWZHaWIzNGFPSG8xVUVSRXA5VlBTWUdPbUNzVEJ1R0dxTkI1Z2c4N0VB'
    b'Y1RJLzBRUHg3cmVhQkFDVEpYNUtBa0RpVk1tQ2FTUWcKeWZWYTAwa3F6TEQyeWRTbldQdFU2'
    b'dFBTWFc0MWs2WkNocVhQbkVYOTdEbVdDK2I2QSthNTJ5cDl2ajhWc3F3V0xGQjl0cFZmcVBw'
    b'RgpPYTdXeWxWVEljOGlkdkVTMWVjdnRUaXRaVnJBY2pkYmVWZG9xYkRTZkVHQjdsZVorOVc2'
    b'WDFQb1lxMjFJSTh0S3RaOVNhbjh0R0NkCmU2M1did0I1N01hQTN5US9MU2dyZDYzV1pqREVi'
    b'aEg5MW0wQnYzMkgvTFJncDF1dGdpb01xYkJMWExEYjZQZUl2dExvOTFhNVZHdWYKTVJXcTkv'
    b'UCtnTS9vUFFkNVgzV0lDUWgxcDFWVU5KTUtoL2tGTmF3L3d2dWpyQjlrb2crVldEWVZqdFd5'
    b'L3JpSFczQ0M5VEYxbkk5egpveFdkd1N6MTdJS1R2RC9GK3RPOGwwNzBvWkxDcDNLVEwxWHc3'
    b'RVRQUENQNHM4NWJxVE9ZcFVHY3dRek1STStHUWM3TEZnMWlLalA1CnNrdzhuQk9uSlVPajAx'
    b'YW1xVkFRbU1IbnpmeUZ3TDdxb3BuUHYrU3dWaE1KcWFqbVl3T1RyNWtjK2RLRTkyM1dmV2tK'
    b'T1JLck56bHIKVmRSQ01pNVhDckZYTkorVFJ3NWFyL3A0ZjgyckxiaE9EbTdVdHZHKytLYWpX'
    b'dTBrb3FPY21XbnE1THVsK3R2MDlSMmxWZWg5Vi9XZApkRnAyS2QyQ3YrZWsxWDJhK2tCUnVv'
    b'VFloK29NZmtSZXRtdnJHRHJVamNKajh2SkpvYnFPUGE5T0I3VmF0UjJXOXlrZjYzbEdmYmQr'
    b'Cm5iVUx2WjlULzRJT2dKZmFwOHJ5eW42cmNKKytIODBWWW52bzFxSk4zNCsrYnVHOWY2TVFU'
    b'Qyt6SFAwYVpQQ0YySzRWT2ZCUW9EOWkKR0NDUHlHR0JlOWdid2IrbEQrS0Vkd1Avc1N6djdi'
    b'Ynkvd2srR0IvSWpNU3JXd3Z0V2VlamNIK3JpNkVQNHZBcDNlTCtwbDRHZHI0TApvYmNjL2Ni'
    b'NFdlajE1YXR4ampRSy9sc3YvZGxyT1ExNjdINFhRdml1SHlVSnNYMTBhNUdzK3gvQ1JFN284'
    b'MyttT2hsQ1FJU3RXai9KCmIvWXpYNDJJSlA0YThQVm0zckNaRUhjYS9iWStyTitFUDl3eHo5'
    b'K0FyeTB6OFRXR3dIK0NqVkFRQkVFUUJFRVFCRUVRQkVFUUJCbnAKL0FkQTI4cFJaSnRiMWdB'
    b'QUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TXkweE5GUXhNRG8xT0RvME5pc3dN'
    b'RG93TU4wdwovTjhBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNRE10TVRSVU1U'
    b'QTZOVGc2TkRZck1EQTZNRENzYlVSakFBQUFBRWxGClRrU3VRbUNDCiIKICAgICAgIGlkPSJp'
    b'bWFnZTE2ODEwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_06')

JP_06 = b64_JP_06
index.append("JP_06")
index.append("Japan Yamagata")
catalog["JP_06"] = JP_06
catalog["Japan Yamagata"] = JP_06
country["Japan Yamagata"] = ('JP_06', '', 1)
lookup["JP_06"] = ('JP_06', '', 'Japan Yamagata', 1)
lookup["Japan Yamagata"] = ('JP_06', '', 'Japan Yamagata', 1)
details["JP_06"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_06"] = ('JP_06', 'Japan Yamagata', 1)
regional["Japan Yamagata"] = ('JP_06', 'Japan Yamagata', 1)
#----------------------------------------------------------------------
b64_JP_07 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3NTAyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRnVrdXNoaW1hX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczc1MDYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXc3NTA0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0i'
    b'IzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNo'
    b'YWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9'
    b'ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzc1MDgiPgog'
    b'ICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAg'
    b'ICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRl'
    b'cmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3Bu'
    b'ZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhUbkNB'
    b'QUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZB'
    b'QUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDWVZCTVZFWFlTeVRvbG4veXc3Ym1pM0h1'
    b'CnI1Ny8vLy84OC9EYldEVHJvSXp3dWFybmozZm9rM3pmYVVuWVRDWDc3K3ZycFpIeXdyVDQz'
    b'TlhqZjJUbGgyMzU0OTc5OXZUaGMxVG8KbFg3KysvdnNxSlhjWFRyY1hEbmVaMFhaVHlqNDN0'
    b'Zi8vZnoxME1icG1JTGNYanZpZWw3eng3cjQ0ZHJnYjFEKy9Qenl4Ym5pZWwzMgoxY3ZwbTRi'
    b'c3A1VDIxY3poZFZqeXdyWDk5L1h4dnJEeXhMZm1pM0w5OWZQYVZURDB6Y0w4OHZEWlVTdnZ0'
    b'NmYweTcvWlVDcnZzNlBaClR5bmFWakwyMDhyMHlyL29sSDMrKy9yYVZqSDQ0Tm4xME1YYldU'
    b'WGVaa1gzM05UYldqYjc2K2JoYzFYaWVGdjB5OEQvL3YzMjE4N3MKcVpibGhXcmNXempwbVlQ'
    b'MjE4Ly8vdjd2dHFicW5vanFvSXZ2dGFYbWpIUDg4TzM4Nyt6bGlHN2NYVG54djdMYldEUDk5'
    b'UEh5eExqbgprbnZvbEh6aGQxbisrZmZqZkYvamZtTDIxczNqZldIMTA4bmllMTdpZVZ6eng3'
    b'dmNYejM4OHUvcG1vVG9sNEQ2NmVUWlRpZjc3ZW5xCm5vbnJwSkQzMk5EdHFwanh2N0gzMmRI'
    b'a2cyamxobXoyMU12ZmFrcjY2T1Q5K1BiOTlQTDc3T2plYUVmZmEwejY1K0xraEdyeHZhL3QK'
    b'ckpyd3ZLM3JvbzdhVXk3cW40cisrdm5aVVN6NzYrZnBtWUxwbDRIY1h6ejg4ZTdiV3pmaGRW'
    b'ZmpnR1Ryb1kzYVVpM2hkbGorK2ZqagpmMlBkWWtEeHdMUGRZVC9saG12eXdiUHp5YjNkWkVM'
    b'a2dXYmRZMEhmYlUzWVRTZjF6OFhkWUQ3dnRLVGZiRXo3N2VyMzI5UHNwcFBZClRDYjQzOWph'
    b'VkMvdXNhRGJWelB1c2FINzd1cm5rbnJ2dHFmbWpYVGxpWER6eWI3cG00WDB6TUhua1huZ2NW'
    b'TGZiazc2NXVId3VLbnoKeUx6dHJKdjEwY2Z3dXF2NjZPUDU1dUR4dmE3amZHRHd1NndhY2RM'
    b'N0FBQUFBV0pMUjBRRitHL3B4d0FBQUFkMFNVMUZCK2NERGdzcwpOUU05ekJVQUFBU0xTVVJC'
    b'VkdqZTdacjVWMU5IRk1jdjZJQmFRRkNRQ0FZUnFBUVVxUWlDcGdFQlJYRWhZSTAxWWlGVXNJ'
    b'aFFYSkJpCnJkaUNpTGl6dWxCUnRMVzF0YVZXVzdlNmR1OWZWV2gwbHBlWFpOTHo1dkYrbU84'
    b'dm5EUHYzdHpQbVhselorNTlBRWhKU2ZsV1VEQ3QKS1ViQm1vb29oWVFhQldzYWpUWGRNSXM0'
    b'ZzhaNnd6QllZVFNXWVY0dENJK2dzR1lhWnl0R1VsaFJ4c0dhUmEvaWJPT3NZalNGRlRQSApN'
    b'Rnl4OUhTWjVzWVpnU2wrSHBnVGFDNDBQM0ZCMGlSREphZVkzalREd2xURUt0V1NOb2xRYWVr'
    b'VERJc0FGaU1QWlN5WkpLaTRURGZBClcyRVF2dFNUQzJYRlR3YlZzdXpYOGFOendMeGNoU3RY'
    b'LzV5ZnQ0S0t2OUlLMXVrcVhPaHRtNzVVK1FWTStGVldnTUlpRmE2Q1lsMnoKd21wRitEVWxB'
    b'R3RUVkxqV2xlbzRWd2tlNGRkdkdCL2Z1Q25WNDBGQ2psNVUxblJGNkRKN2VjVzgveDV0Zm1l'
    b'TFEvRXdVYS8zYTZ0aQpvdDVsa25yU3R2WHNjNmMrVk51Wm9KV0ZIck5oRHRyQm1MeW5CMVZW'
    b'Q0IyeU9sL054bFZOMjlUb2tWZmZwNjhMTzcxWjFacG9kdkZVCmRWUzRYUjk0dDZ2ZlJSbldD'
    b'Y2ZhVFlJVk5mZ3lyS2ZtYTQ5b3FrYis2cXVRTW0wU2pQVWhDYlhVbjIwbXNiV0lwV3FlanlO'
    b'RnVQd1oKaCs0bGUwUHNadHhISnFEUXYvVitZcjFQS0JZNWRnNjBjSnhTQjhrUkpKSXFoNnho'
    b'YTJCdEU1UElFN3VCbk01Y1pWZFNHWFpJRm9qMQpFYWtnK0J6YUFwdmQveWx5MUpYek9SekNE'
    b'aDhMeERxTW8zekM1M0FFTzdRTHhDSTdLNHpQNFNoMitGUWdGcTdCRUdmcFVFcHVOd0o3Ck15'
    b'US9jTjZFYmRqaE00R3pSU3FJRmo2SFBKSzRCR0oxNENndVBnY1hhWTBMeE9yRVVZN3hPWFJo'
    b'aCtPNjNBRzcrUndxc0VPYlFLd1QKZ2FiVEh1eHdVaURXS1J6RkhtaitGWG40cEpHam1xc1Ay'
    b'VXhLN0VhQldLZEpoamdUMk95ZVBTZnl3dFdPNDV6blNLaTJUcDFxbjE1eQpEWTROeUxwUEtG'
    b'WS9PWDRHL0diVWtrclNlaDdVclNDTDlHY2JUR3hUQk5lSlRWUk5XdXZidEk4eUhSSmRWdHVw'
    b'andMMXZnd3ZVSjNCCjNXS1pMbDZDeTlRY0RIL3UzWFRXTUxGekRNRTVnZW4weXZENGoxdm9S'
    b'bEtRTjlOWXVvczZBbkJtK0tvb0tyTWQ1WlpDVlM3ZFVzc3MKVWQyRFdiVE5RQlVNaHFDTUZq'
    b'RlVOb3U3Z0ZuR2RDQUgrc3dleFhRZlE0NnVBWXlPLzdsdUZVRjF3MzJydVFEZ1pGdTI1NmYx'
    b'TStmZwp4WU9LVHhrQVg3aHJ5eTgxdjhYZmRMN3E3bFUyZzdsZDBlTjJ0UFZVZElYYXZpbzVl'
    b'dVRRNFRMRnc2OWI0TmJBcSs3aE45K0dhNGFVClo4a3F1RTNDMkcyUUg0VzQ5VjArV0VsdGpX'
    b'NFhCRnZ5dE9INm5nMDBPZ2FsUC9CU1JibGdMSklkMHVxZkV1NUVzTC83STBCeEloL1YKbXJz'
    b'QTk5aWhuMDVydFl6czNuUDhQTEV0Ny9OUU9TZDI2UVAyYlh1bzNSdi9pUDdkeCs2eDJSMytv'
    b'UFplYzFzRzBZTy9hTGdScjlhUQpBK2ZKNjhHcUVaOVFqaEhjQXR0SkRxS2FXMW9tQ054NU9m'
    b'Q1VHdDNZN3AySytZVCs3TG1BSlp6UUMzZmk2VkcwUkpwU1RHcE1xUzh2CnMzYkZ2N3JUM24y'
    b'Tjg2azFBNkZzcDBxNUUvODRVZkUxK094dnZTcDMwYVN0MlFpbGEvNXRjZkQzYm05cDhFNWph'
    b'M1g2SHlFeEtPYlAKTFgrMS9uM0pXMXJ1L2tmdzFWbEtTa3BLU2twS1NrcEtTa3BLU3NwRC93'
    b'SnZ3OHdUVFB3V1JnQUFBQ1YwUlZoMFpHRjBaVHBqY21WaApkR1VBTWpBeU15MHdNeTB4TkZR'
    b'eE1UbzBORG8xTXlzd01Eb3dNRVdHTlMwQUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdN'
    b'ak10Ck1ETXRNVFJVTVRFNk5EUTZOVE1yTURBNk1EQTAyNDJSQUFBQUFFbEZUa1N1UW1DQwoi'
    b'CiAgICAgICBpZD0iaW1hZ2U3NTEwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_07')

JP_07 = b64_JP_07
index.append("JP_07")
index.append("Japan Fukushima")
catalog["JP_07"] = JP_07
catalog["Japan Fukushima"] = JP_07
country["Japan Fukushima"] = ('JP_07', '', 1)
lookup["JP_07"] = ('JP_07', '', 'Japan Fukushima', 1)
lookup["Japan Fukushima"] = ('JP_07', '', 'Japan Fukushima', 1)
details["JP_07"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_07"] = ('JP_07', 'Japan Fukushima', 1)
regional["Japan Fukushima"] = ('JP_07', 'Japan Fukushima', 1)
#----------------------------------------------------------------------
b64_JP_08 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4Mjk3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSWJhcmFraV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAgIHht'
    b'bG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3Nj'
    b'YXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5l'
    b'dC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAg'
    b'IHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAg'
    b'aWQ9ImRlZnM4MzAxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2'
    b'aWV3ODI5OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc4MzAzIj4KICAg'
    b'IDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAg'
    b'cHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJp'
    b'bmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7'
    b'YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5DQUFB'
    b'QUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFB'
    b'ZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ1ExQk1WRVU3U3FnOVM2bEJVS3VUbk05Zgph'
    b'N2hHVkszVTEreTJ2TjlOVzdCS1Y2N202UFR6OVBxUW1jNDlUS2xPWExGVllyUlVZYk5sY2J2'
    b'Nit2My8vLzlZWmJXNnYrRGY0dkg5Ci9mN3A2dlc4d2VHQ2k4ZERVcXoxOXZ1RGpjaFJYN0tk'
    b'cE5QajVmTHk4L21ibzlOQ1VLcytUYW5aM082c3N0ckJ4dU5oYmJsa2NMcisKL3YvTHoraEhW'
    b'YTFTWDdLK3crTDA5ZnJsNS9QdjhQajMrUHgxZ01MQ3h1VFgydTFKVjY3Mjl2djYrLzI0dnVC'
    b'OGhzVnVlcitwcjlsdAplTDdjM3U5S1dLOU5XckMwdWQ1VFlMT3FzZG53OGZoRFVhdnQ3dmQ1'
    b'ZzhSNGdzTzB1dDZLazh2RnllVjBmOEgzOS90ZWFyZGxjTHJhCjNlK21yZGQ5aDhYOS92NU1X'
    b'ckNlcHRSMmdjTDcrLzM1K2Z4b2M3eUdqOG03d2VGeGZNQlBYTEhoNC9KWFpMVHg4dmsvVHFx'
    b'dXROdnIKN2ZiUjFPdlcyZTEvaU1aYmFMYWNvOVBvNnZWcmRyMlBsODJ6dWQxRlU2eVdudEdF'
    b'amNoNmhNUnNkNzZ2dGR5RmpzbHlmY0ZtY3J2dAo3L2RvZEx5TGxNdWFvdEp6ZnNHSGtNcWdx'
    b'TlZiWjdaQVQ2ckF4ZU51ZWIrUW1NNi94T1BTMXV0ZGFiZFJYckxNME9pM3ZOL1AwdXFVCm5O'
    b'RFAwK284UzZqcTdQWmpiN3E0dmQreHQ5eFFYYkZ5Zk1CRVU2eXd0dHpRMU9yRXlPWEl6T2FP'
    b'bDgzYjN1L0Z5dVhqNWZQbjZmVGMKMy9DbnJkaHJkNzNwNi9WcWRiMWFacmJIeSthWW9OR3Rz'
    b'OXJnNC9Ha3E5YlYyT3pHeXViTjBlbVRtOCtrcTlmUzFldmU0UERrNXZPUwptcyt5dU4zZjRm'
    b'SHM3ZmJEeU9TbnJ0aWxyTmVHa01teHQ5MldudER3OHZtWm9kSzd3T0hpNVBKZWE3aHdlOENO'
    b'bHMxWFpMWEI3cmdrCkFBQUFBV0pMUjBRVERMdGNsZ0FBQUFkMFNVMUZCK2NERGhBaERQbmxk'
    b'c0VBQUFSSFNVUkJWR2plN1puM1YxTXhGTWNqSUdLTHI3VlIKcW9JRHFDaEZBUUdWRmhVUVZC'
    b'UjMxZUpBbG9xaUtJcXpMbkFoVmxCeEFLTGlxbnNQM09OUDgrYjF2ZTVxZWVjazdUbm0rMHR5'
    b'Yis0NQorWncwTjdrdlJZaUxpNHVMaTR1TGl5dVloa1FtVmxSMFRFUnlEWTBkRmhlSlhNTlY2'
    b'dmdSRWJHZkJJMDJ5bTJPMU9GWVRaaVJSc1dQClR0QmowSml4NHhJbFh6VEdTZVBEeURSaDRp'
    b'VHNvZVNVVk5GdG1BeEdtaUZNVURGVDlOaEhrNmFLSStsRzZHZE1Dd2ZVOUV5aml5WXIKZTRa'
    b'azVPU0tnM21rUDNNVysxMGVQVnRDeWplWnliS2tGc3pKSXFadUxobWVLZzdOSzJSTVZaUWhR'
    b'Um1MNTd1YzAwcklrcFdLcDFhcwpPQnE3Z0NsVitrS0pTcjNJeTErV0Q3N0ZwTGZFT1Y3Tzhp'
    b'NWF1a3hPdmVYRVhKRTJzelI1NVNvdGRGZUQwMEsyL1JwcHI2MWxSN1hPCktsRlZyQWVyTUZP'
    b'Mk5vQzFVVjZ1ZVU2blpSTXJxcmtWY2dKT0JLdHlzeXNmTFdVSVZVRmJYUVArV3NsWngraVlH'
    b'S1dXTWJMaHdqRnMKZ2M3V2JmWHJ0eWRodkFOTzBLMWdOMERZVGpscUZ4T3F4Z1RYNnV3R2N3'
    b'KzBHOFh6dkFsNmV4SGFCMDB6bVB2bEtPTUJGbGpGTGlvagoyZU1yTVQ2WWVJZ00xTUNPTzR6'
    b'UUVSZzVRdkxBRmJlRkFaWE5mZEVrZ0NsQXdxV2h2S0hrMUFmWFVZU09TZWwzM0IyNGxEclZD'
    b'WlY3CnRwTmd0MERiaWs2ZFBvUE9ub011SEExdFdGdzBGT01PUEU4ZHE5M2pXaTRHMnl4dXNY'
    b'VndLeExQQllUc0Y2RzFrWHoxaU95Z3ZkK1QKUFNZYkM0NENhRHNSdXVUOFZTOGpkSVVjWUYz'
    b'dVkxN1VWY3BZclo1RnpEVnBRMVUzd3FwZG4zeWpHNHF0RXozZzZQVk9EYmlpb3VpVwpEVGM5'
    b'c2ZxSTZ4WjBicnNEeU03Q2Q2Qm43L2NNemFXS2RkZTc1cnNIcm01eVVyUkw0M0gzc2J4WUxW'
    b'NlJsNmhpcFhsalBTQ3BtUzMrCm5tYkJJR3g2bUNQZU5wVWt0TndyVWtVVnE5K25RaVozWDBl'
    b'RnR6TnBSWUIxeFpVVXFUUytsWHUzV0Uva2VMcHUxaE5mcXNNbnNva2kKMWg1ZnJCa0NjWGYw'
    b'dUJ3NWo1ejFnc2szTW9VaTFoemZ5ZkJqTWZOSGpIdENxbExkMDJlQ00vQzVYK0JvaWxqbGZy'
    b'UGhVOUtKWkJlTwpENWZERXR2ODQxNVF4RXJ3bnc0L0ZueWo2bDhHQ0h0RkVXdGhnUG53d2NO'
    b'ZVg4K2FZbXVncUdTS1dMTnhRRzErTGIrRHhEVm5XZ1BIClZGREUwdU5nY3ZTK2VYUTE3NjB4'
    b'YUlDZS9XcUZvaXlLV08rVVkxMWtuSWtoNmlWRnJGN2xXTzhwWW4xUWp2V1JJdGFBY3F4bWls'
    b'aFYKeXJHME5PdXRQcVZVZlZUTHdFOUtzV3FwWXQxUmluV0lLcFk5V3htVnlrNzNPL0d6TXF4'
    b'MnlwK3ZYYVZLcUw0MDBuNkRTRkdDOVpYNgowMGlxU3NIcHdPQVZ2R3p3V0xtSWdiNE5sc3JF'
    b'NU8yMHl6RTRxdStOVExEUWo2UkJsYVZuMkwvTC8xdjVQOW45aTJHMmhrcGxiVUlNClZSRGk3'
    b'N2pNaHBocVpGMG9WUDNwaUxFS24veWJLcU1JTWRlUVZ2WGZvZFMvN0NnY2l1dTBCSWV5REN0'
    b'QzRaS21SQmNrQVR2dm9YQksKaUgvaEQvVjJ0NERDTHUyQXllRTZ4L0lkcGdFdGloUVpmamZZ'
    b'ekdaYncyOEQ0dUxpNHVMaTR1TGk0dUw2ai9VSDJoODh1SWN4ZXdnQQpBQUFsZEVWWWRHUmhk'
    b'R1U2WTNKbFlYUmxBREl3TWpNdE1ETXRNVFJVTVRZNk16TTZNVElyTURBNk1ERFJMempCQUFB'
    b'QUpYUkZXSFJrCllYUmxPbTF2WkdsbWVRQXlNREl6TFRBekxURTBWREUyT2pNek9qRXlLekF3'
    b'T2pBd29IS0FmUUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBpZD0iaW1hZ2U4MzA1IiAv'
    b'PgogIDwvZz4KPC9zdmc+Cg==', 'JP_08')

JP_08 = b64_JP_08
index.append("JP_08")
index.append("Japan Ibaraki")
catalog["JP_08"] = JP_08
catalog["Japan Ibaraki"] = JP_08
country["Japan Ibaraki"] = ('JP_08', '', 1)
lookup["JP_08"] = ('JP_08', '', 'Japan Ibaraki', 1)
lookup["Japan Ibaraki"] = ('JP_08', '', 'Japan Ibaraki', 1)
details["JP_08"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_08"] = ('JP_08', 'Japan Ibaraki', 1)
regional["Japan Ibaraki"] = ('JP_08', 'Japan Ibaraki', 1)
#----------------------------------------------------------------------
b64_JP_09 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTY2MiIKICAgd2lkdGg9'
    b'IjE0MyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDMgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1RvY2hpZ2lfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTU2NjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxNTY2NCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNTY2OCI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNDMiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSThBQUFCa0NBTUFBQUNJUHBQ'
    b'Z0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUI5VkJNVkVWMnNUaUh1bERSNWIzUTVM'
    b'dXUKMFlxWnhXdkgzNjZreTNyQzNLYWx6SDJQdjEzLy8vLzArZS9KNExENCsvWFM1YjNUNXIv'
    b'ZjdkQzcySnpuOHQyOTJaL204ZHYrLy83KwovdjNpN3RYTTRyYlc2TVRlN00vZzdkSzAxSlB4'
    b'OSt2STRLLzcvZm45L3Z6UDQ3bnQ5ZVRqNzliRTNxcjMrdlA4L2ZySDM2M3U5ZWI1Ci9QYks0'
    b'Ykx5OSt2OS92M0s0YlBwOHQrTHZGYnY5dWpKNExIMit2UEw0YlBaNmNqYzY4eWt6SHVKdkZU'
    b'VjU4SHE4K0hMNHJTeTA0L1gKNk1YTzQ3aTAxSkxrNzlmYjY4dlo2c2pzOU9UMStmSDMrL1I0'
    b'c2p2Ny9mcTgyWjZQdjF6UzVyN284dDdGM3F2eitPM1Q1c0N3MFl5WAp4R2l1MFltRnVVLzIr'
    b'dkxsOE5tcHpvTHE4K0NLdlZiOC9mdnorTzU0c2pyZDdNN2E2c201MTVwN3REL2w4TnE0MXBl'
    b'QnQwakMzS2ZRCjVMeXoxSkhPNUxtU3dHQi90a1Y3dEVCNHNqbWh5bmlOdmxsOHRFR0l1MUtV'
    b'd21TZnlYU3YwWXVMdlZhV3cyYSsycUhXNThQaDd0UDYKL1Bmdzl1bTMxcFo2c3oyNjJKcXQw'
    b'WWlVd21PTnZsckkzNitPdmxwOHRVRit0a1RFM2FuUjVieWN4MitKdkZONXN6eDZzejZoeVhi'
    b'dwo5K3FmeUhPTXZsaXMwSVo5dFVLWXhXcU92MXZkNjgyQXQwZWd5WGJBMjZTdjBvdUN1RW1z'
    b'MElkNXN6MkZ1VTN5K095bnpZQ0h1MUc4CjJaMTNzanFleUhPQXQwYXcwb3pHMzZ5R3VrK1F3'
    b'RjNONDdiYzY4dW96WUdWdTVCWUFBQUFBV0pMUjBRTEg5ZkV3QUFBQUFkMFNVMUYKQitjRERo'
    b'SXRMUnE5L2YwQUFBSjFTVVJCVkdqZTdaanBXeEpSRklkUFlJSWRFQTBiTWtvd1ZBUkJ3NGlL'
    b'cEN3VkxhMGtXN0dvYkxQYwp5TFZzc2Mxb3RUMUpzNzMrem1DR3dabnE4NzNUODV6M0MrZisr'
    b'RER2YysrNW5Ia0FJQWlDSUFpQ0lBaUNJQWlDSUFqTnMwSW5vaTlZCldTaFZCaWszNmhRVXNm'
    b'TlpoVmxNNW1KTFNhbFlycFp5S3lvb1kreXpSaS9ZTExpMlhDTSs2K3lJNnpjSVdPRndhc0Nu'
    b'Y3FNcm8xVGwKcUs1QmQ2Mkh1NC9KN0VWbm5jOW04ZGMzSUphVWN2YlpwRWNNTkxweGN4QnhT'
    b'd2l4YWl0Zm4yMloxdG1PR043UkZFRzA3aFJ3bDVRSAp1UFdQcmhseDl4NmJwYVcrRWx0cjI2'
    b'VHppcllyZlRyWStleHQ5S0d3cnhNejk5M2J0UitGQXdmRnVGdXBnekYyUG9mY1dPem93YXdQ'
    b'Cll1UXc0aEV4TnF0OHVsbWUxOUZ5RytaODBCNlI3dnV4NDBxZEUzR0dQcjBueFdkS1BoaHdu'
    b'TXFFaWRPcTdUbkRjSjZlN1pORzVybnoKMHVlRml3Q1g3Q3FkY0QvWGlYLzVTb1ZLcDNXQWw4'
    b'bmcwUEJJMHF5MndmQlYxaHJSMGRoWWNIekNNNGwvTTNYdE9tT2J4TFR2SHg2VApub254NE5p'
    b'Tm0zSFdtM1BMOWNlRzNDNFlHUjRhNU5VeU16MHFtNEFoenZVdTNXbFI2WVR1UXNKd1Q2OThk'
    b'YjV2VEQ2WWZjaktaMXFsCjA1eUNSNCtYVzZpM3ErbkpVNmJ0SERVcGRkcG40WmtnTDB6SjUr'
    b'eVBhMDYxUFlYd0lqKzJYcjZDNk9zMzFXL2ZNZlZKcW54R1FTZVgKOWhRTU5HUUw3M3VXUGgx'
    b'S0hXZDhYdjVGYkV0RCtrT3VYbURvVTZiMDhjQ2lYSDRFcU1zM1VqOG5IeXZNeU9VaUxOWGs4'
    b'MC9jZmFZQQpQaS9uWDdqN2RBTE0rL1A1Z2haOElDVEgvclFtZk9ac3VjVlgwSVFQeENyRk9w'
    b'Smk2Rk9rbkp4RytKYXIrc1F2di85dytYNytXcUsvCjdBaUNJQWlDSUFpQ0lBaUNJSWovZ2Q4'
    b'bCtYbG9NUlMyV2dBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TXkweE5GUXgK'
    b'T0RvME5UbzBOU3N3TURvd01JS3JZVjhBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01q'
    b'TXRNRE10TVRSVU1UZzZORFU2TkRVcgpNREE2TUREejl0bmpBQUFBQUVsRlRrU3VRbUNDCiIK'
    b'ICAgICAgIGlkPSJpbWFnZTE1NjcwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_09')

JP_09 = b64_JP_09
index.append("JP_09")
index.append("Japan Tochigi")
catalog["JP_09"] = JP_09
catalog["Japan Tochigi"] = JP_09
country["Japan Tochigi"] = ('JP_09', '', 1)
lookup["JP_09"] = ('JP_09', '', 'Japan Tochigi', 1)
lookup["Japan Tochigi"] = ('JP_09', '', 'Japan Tochigi', 1)
details["JP_09"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_09"] = ('JP_09', 'Japan Tochigi', 1)
regional["Japan Tochigi"] = ('JP_09', 'Japan Tochigi', 1)
#----------------------------------------------------------------------
b64_JP_10 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3OTY3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfR3VubWFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzNzk3MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzc5NjkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNzk3MyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNBVkJNVkVWTUQzdGNKWWRiSTRaL1ZLSG8KNE8x'
    b'bE1JMWxNWTdwNGU1OVVaOVNGMy9yNVBELy8vL3k3dlo3VHA1NFNadnc2L1RyNWZGU0Y0Q2dm'
    b'N244Ky8yMm5jbGRKb2RlSjRpMwpuOHFkZkxkTkVIejM5UG02b3N5Q1Y2T0RXS082bzh6Mzlm'
    b'bnM1dkZ5UXBmKy9mN3Q1L0xieitWd1A1V2poTHVpZ3JxNG9NdTNuc3JLCnVOakp0OWZLdDlq'
    b'SXR0ZWlnN3VoZ2Jwd1FKWnVQWlRxNCsrYmViVlJGbi85L1AyWmRyT1ViN0Q3K3Z6cDR1K2Nl'
    b'clp2UHBXcWpjR28KaXI5aUxJdU5acXUxbThqRHI5UE11dG5IdE5hcWpjQ0tZcWxYSFlOOFVK'
    b'K1BhYTNCcTlIQnE5Q2VmYmhYSG9PMG1zaDZUSjNMdWRuKwovdjc1OS90c09aTEp0dGZJdGRh'
    b'ZGU3ZDVTNXh0TzVQQ3JkS3Vrc050UEpOVEdJQ3ZsTVJxTjVIV3grQllINFJPRW4yRlc2V3Jq'
    b'OEdVCmNMQ3NrTUtGWEtYV3lPRnBONUZpTFl6ZjFPZFdISUprTDQxK1VxQlZHNExmMWVqajJl'
    b'cS9xZENJWDZlU2JxK3RrTUtTYmE3QXF0RGkKMSttbWg3MkRXYVNraGJ6aTJPcFhIb1JYSDRU'
    b'NTkvcU1aYXIyOC9pQlZxS0xZNm04cHM2K3FNK0dYYWJsM096bjMrM2syK3RQRTMyOQpwODVR'
    b'Rlg3YzBPVmdLb3JhenVSbk5JOW5NNDlnS1lsaEs0dk92ZHQvVTZDa2hyeE5FWHlFV3FSOFQ1'
    b'N0dzOVZzT3BQWXkrTlVHb0haCnpPTjFScG5ZeXVKWklZVnpRNWVUYnE5UUZINnJqc0dRYXEz'
    b'NitQdHJPSks3cE0yeW1NZWtoYnZGc2RSOE5pV1RBQUFBQVdKTFIwUUwKSDlmRXdBQUFBQWQw'
    b'U1UxRkIrY0REZzByRDQ3OS85SUFBQUx5U1VSQlZHamU3Wm5wV3hKUkZJZkhOc0dKVWhDRUNq'
    b'RVZTYkZjME1JVwpEUkNYRW9YS3NyUTBwU3pOYkxLRlZpdlR6UGJGRnEwb1N5di95cEIxaG51'
    b'bnB5L2NRODl6M2svTTczeTQ3NFBqdWVkZU9BNUJFQVJCCkVBUkJFQVQ1VDhrZ28xWHdWcXZY'
    b'ckUyTzFtVXFvSzJVV2Z4NmxUVGFzSkhQemdIV1V2TThyOG5WSmdKZG5pWVU2V0d0RE5uOENw'
    b'czIKYjFHdVBPWVk4MDNob01BQXFyV1ZqMUZZVkZ4Y1ZCaC9OSU5xbGZBeVdFQzF0c2xwbFlK'
    b'cWxjbHBXVUcxeXVXMHRvTnE1Y2xwNVlKcQo3WkRUcWdEVnFwVFRxa3FIZGtwUURkdE9PVDFk'
    b'eXdhOVZWZlRyREpyb0VjSVJTMXBwVkhCRDF3MlVtdG5Pb3ludSt4U3FWcDFlb3pOCmlqckpl'
    b'NlhpMGdTbFBpdmVHWGJYY09tRHdXd3B0VnBMSy9hazNRbW9jdTgrTTdoRWZjTitoOVBWNkc2'
    b'S0JjMHRyUWRhRHNhZTJ0eU4KTHFmRDAxRFBWS3E5d3h0OWwzeXRoNktSL3ZDUnpxT1J6OGU2'
    b'Zk5HeXQ2eWRtVlJibC9nL3ozNDhkUHJTZHJvdEo2cEszSjJodzJ4MwpqMFpjNzJwalkzV3lM'
    b'cWw3bnVybHVMN1QvUU1EL2pOOUhOZDdObmtuR21SaGRhNkE2T3JuaDRhR0wvVGJiSDdGOEVq'
    b'VFJhS2N6ZUFOClU0NVN0dVpMV2tHNFBEWjJSUkF5cmxMSzExTGZ5NjVUQnhsM1FCQXNGa0V3'
    b'dXFubEc2bTIwdm1vNjk2OHBWZDdQR3I5N1ZGcStZNDIKeFZwM3grbHozNzJRc1k3akF2VHEr'
    b'UDFVZjEwMWdwTzI4SU5JZFlKVzYzaklaSjlzbmlTWG5veVVwc2pLSTJZVFJZNlZXTnc3c2xJ'
    b'WQpJcTFjU25hYnp6VDV4d3JmVmVxSStQRTB5MDF4NWtueStrL0RyVFk1ZlRiRGRvSjRia3Fh'
    b'bE1QWGt0MkYwdFQwZ3ZWazAvTXZyM3dQCjg0SHJwZlJnTVJGSnBWdVAvUlg3UWZDMXhDQjY1'
    b'ZjFHRWpvQjV0TzNZb0dwMlVqWWx3bDlVNmtRQ3hoajZUdHgraDc0RHVsREluYUoKWW9oejBN'
    b'ZkU4blB6aVhqK1V5SWZCTkQ2SEYvOVMxQ2NCK2ZpaGE4QVd0OWl2eE0wTGtnTEM5OWpUZlVI'
    b'Z0pZbnZQSmkvaEpaV3ZxNQpHQzcrWW04MSs3dDgyZEZ2RE5LcndZRGZzVnhlQW54VmlTQUln'
    b'aUFJZ2lBSWdpQUk4bmYrQUp2a2tyd1BRYVY3QUFBQUpYUkZXSFJrCllYUmxPbU55WldGMFpR'
    b'QXlNREl6TFRBekxURTBWREV6T2pRek9qRTFLekF3T2pBd0lKeWczd0FBQUNWMFJWaDBaR0Yw'
    b'WlRwdGIyUnAKWm5rQU1qQXlNeTB3TXkweE5GUXhNem8wTXpveE5Tc3dNRG93TUZIQkdHTUFB'
    b'QUFBU1VWT1JLNUNZSUk9CiIKICAgICAgIGlkPSJpbWFnZTc5NzUiIC8+CiAgPC9nPgo8L3N2'
    b'Zz4K', 'JP_10')

JP_10 = b64_JP_10
index.append("JP_10")
index.append("Japan Gunma")
catalog["JP_10"] = JP_10
catalog["Japan Gunma"] = JP_10
country["Japan Gunma"] = ('JP_10', '', 1)
lookup["JP_10"] = ('JP_10', '', 'Japan Gunma', 1)
lookup["Japan Gunma"] = ('JP_10', '', 'Japan Gunma', 1)
details["JP_10"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_10"] = ('JP_10', 'Japan Gunma', 1)
regional["Japan Gunma"] = ('JP_10', 'Japan Gunma', 1)
#----------------------------------------------------------------------
b64_JP_11 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMzMwNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NhaXRhbWFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTMzMTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxMzMwOSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMzMxMyI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRu'
    b'Q0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUN1RkJNVkVYLy8vLzcwdFAxZ1liemFH'
    b'MzAKZUh6NnY4SC8rL3p0SENUelpHcisrUGo5NE9IMGNYYjBlWDMzbktEdUtERDgydHY5NnVy'
    b'NndjUDgxdGYrOC9UNXNyWHRJQ2Y5Nit2OQo2K3p3UFVUMmk0L3RJU255WEdMNHJLLy8vZjMv'
    b'L3Y3d1AwWDZ2TC93UEVQMmlJenlXRjd4VGxUODE5ajgwOVg2dTc3dUpDenVLVEgrCjlmYndR'
    b'RWI3ek03NHA2cnRIaWIzbVp6NndzVDgydHoxZ29mMGIzVDJqSkQrOFBENzBkTHhVVmoxaFlu'
    b'eFMxTDV1THIzb0tQdElDajAKZG52KzcvRDFmSUh1TFRUdUtDLzd5c3Y1czdiMmtwYnVKaTMr'
    b'OGZIMGQzejBkWHI4MmRyNndzWDd4OG4rN2U3dk5Uejk0K1QxZ1lYeQpYMlQ2dmIvdUxEUHph'
    b'VzcxaDR2dk56N3phM0R6YW5ENnhjZnRJaXI2dnNENXQ3bnZNVG4rN08zOTV1ZjgzdC8rN3Uv'
    b'NXJySHRIU1gxCmZvTDZ4TWIya0pUN3p0RDk1T1h1SXl2elltajBlbi82eHNqdUx6YjZ3TUw3'
    b'eU1yOTUrajRvcVg0cXEzdUxqWDk0dVB3UGtYKzl2YnoKWTJudk9VRDcwdFR0SHlmM242THZP'
    b'RC94VUZiMmo1UDRxS3Z1S3pQd1FVajd5ODN4VDFYMGMzajNtcDd3U0U3dk5qM3ZNam42dzhY'
    b'OAoyOTMvKy92eFVsanlZR1h6YVcvOTZPbjJpWTN4VkZyeFVWZjVzYlA1dWJ2OTRlTC8rdnI4'
    b'MWRmKzlQWDJpbzcxaElqNXRybjk1ZWJ3ClFrbjRvNmY3eWN2M21KdjgzTjd3UUVmeVhXUHZP'
    b'a0h1SlMzNHFhejNuYUgvK2ZuMWZZTDgyTm4wY0hYNG9hVDgzZDc1dXJ6NXRMZjYKdXIzKzhQ'
    b'SDFob3I4MU5iemJuUHhTbEgrOHZMMGNuZnpaMnoxZzRqN3lzenZORHZ4U1UvNHBhanVLakwz'
    b'bXAzM201L3paV3J3UjAzMgpqcEx2TXpyMmtwWHhTVkQ1dGJqM25xSDNsWm45OFBEdk1EajVz'
    b'clQ4MytEN3o5SHhUVlA0cTY3eVZWdjd6Yy92TURmOTZlcjRvcWI5CjR1TDBlWDd5V1Y3dk8w'
    b'TDJqWkgya1pYLy9QenhVMW41c0xQeVhtVDkzK0h5WVdiOTd1N3piWEx6YkhIMms1ZjFnSVQz'
    b'bEpqNXJiQ0UKYnBqWkFBQUFBV0pMUjBRQWlBVWRTQUFBQUFkMFNVMUZCK2NERGdvNEIrU0dJ'
    b'UGNBQUFhNVNVUkJWR2plN1pyNVF4TkhGTWNIQkljRQpqUVRNWWV4R3dZdklVY0JHclVVS0Nv'
    b'bENSRkZiUVlVaXlxR29pQ25LWlVHZzlRQVB5cUV0WXIyUGVoVnRFYldpVnF1dHRhZXRyVWRQ'
    b'CmUvd2IzWjNkbmQyMTBPd1BtWVFmOXYzQXptWm5NaDkyWnI3ejNwc0FvSmhpaWltbW1HS0tL'
    b'ZVk5OC9FZDVPYy8wS0FHKzBIR0FsVG8KVHEwZUlGaUJrTFVoNkc2b1pwalhTSUswd1NGOGVU'
    b'aEhCWFY2NXRhZ000WjRDMnNFaEthUnoxRk0wVHlLeDRLajBiTlFHT2ExMXhVOApoc1lZTzQ0'
    b'dWpjZFVjQUx6UkJVT0xSTzl4cVdLb0RrMGtRQkVZYXBvQS9QZ2Vib1U0NzJKem5RUE5iRWdE'
    b'bU5OWWo2TzFOQ2xGenlQClk2WFk2MlNFTW9XYXlsTzlhQTJhOXRLa2VLWTQzY05NQ1M4bndx'
    b'VEFJS1k0ZzRXWm1jeGVVNUp0OW1pZWNCWlRnWnFkbXVid2pDNkUKb2w3bnBOUGx1U3pCdkF4'
    b'MG1UOE1MQkRtL2tJQUhDTmVZVFRqVmIwSHNCWngzYzRESUZQSGlaVXRpN2tNQllzRktyZ0Vq'
    b'RjdLRlkwSgp4S215ZFh5L09ZNUV2cWhHSXY4YW1DNVFoZWN1eThNM3k0bGpyY0I5K2Vmallr'
    b'RmhFZjAzSGF3VXNGWVZtNFNiMWNTeDF1QysxczdECnhSS3dqdjViQ256eEordWRyNHNHRkJM'
    b'WDF0bDhUMWxsRy9paXhZeTJvbzNaNWZ5NFZjUlVpcWtzRkdrc3FvcnJxaHBza21qQkd6V3cK'
    b'ZGpNbllPdTFvRTZNVmUrUkhab1ZVUkJrNGVTSzlhNFNHdDZzTWxmU3E4OHlwQVJrUjR1bzN2'
    b'S0FRdVJ1NFpaYUF0aUt1TUluaUIrYgpuZHUyTS9zUGV0Sll4eWhIVTZFbjlOU2ZleEU3S0xC'
    b'ejErN201YzYrS21ucENvdG91U3Fia1ZyQ3YyYkM3K3h0YnVrM3RyUk9mcU90Cjd6b3hFTzZt'
    b'UU5DbWxVMzUzT2JUVHN5bjJPTy8xMjUvNTExSFdnU2VOa1piMzFVN0dNOHJodkVrWUdJeGNv'
    b'TEd3SFlpVUNGVGsxaVUKSXIvV2RjMFZUR2xmcDZxLzJ2dWdzNFJiRWpyZi9RWHZqWUltSW43'
    b'MGdZUEMwdEswQUVmeFREeHIrckpPV0w0UVN1d1FDU3ExUm5mNAppT0NFdW93SVZhRkhHNlZZ'
    b'eTBoZ09ZOWxnK01ORnI2UHhCeFhEV3h0MVJLcU9vSktYNEQzWHovWGxVOUk5cCtUSk1YaGZk'
    b'ek5kdGZqCkhpNmlLaUNxV2Fkd1I2ZGRWejZUd2xkdVBFQldTcWRockZZNTY2U2VVYTc0cHJO'
    b'bWdrNzh1UllEMEZkd1ZFdmw5V1F1S1ZCL2tKSGMKTlRmcVBKbFExVTRENVYydytuRllsWEli'
    b'cGsvS1lsdEVuQ1dBeGZuREgzNkVncHU4aFhMYlZXWUo4NzU3c0x1cGNFeVRETmJZTC9hYwp2'
    b'M1JaWHJ0ZEV1MGE0bTRzZnV4Z0N0S2Y3Tm9yc3BwOUxCVjZXTzVtckFEOHpUVU5zZXFqVmJC'
    b'QlZnQis5Um1zSGpkanhUM3ovZk5sClJhUzk4SEJwVHV5MUd0enN1cHV4Zko3QktwWFY2a1l0'
    b'OGdGUEhpRS91WkI5SXEvUnpVZ2YzdzNUL2NFdHZwM2JIZFRCOWFKQXZsTm0KSTNNY0Nod1gy'
    b'RDVsRzE0a29GeTNhem1vN2h5NVRlN3c3b2IxQXMwWHYrbzRFYVZ2THczcitzei84d09iTytU'
    b'NVR0UmRQc2pXQTBQTAphSUtSRC9YRlNHWlhUT3FXY3lCd0R3OTdDK0VNQlBZNFU4N0ljUDh4'
    b'MWltaVZKZVNSUFBldFdmVGhuM3NRSkpVd1JxeFNNaklwZUUwCm5PbExndlBxSzRsMlZiZFpY'
    b'Ylhvd1BsQ1M2OEtHSzZsazhENldpcjAzMFFaVlhMekZjeWdIOVpabkNTd1JrcXg5dnJBLzVQ'
    b'VndqV3AKM3pwQTVuZENnOURaUklKOUU2eHRLSWlNNDNLNlYrK3I0YjUrZmRudmtmWlcxSzM3'
    b'NFVFUk40eTc5cEFSVS9nalV1bmk5WWdxRTdRdwpTZE0remZvVGZrVVJhWTRsWFhiN3c1Z3lR'
    b'ak5lQzhkeGliZEhUUUg1ZXZDNEdjS3QvU2hEcVUvcnVTZmNJdnlackpRR1BlVFhWK3ArCits'
    b'OTNET3BQdmUrZHFINFN0aE5RQytUbUs5eGg2Yjh3YWVheHpTaDBZRkpYMjJQVmtpMXlHcHBN'
    b'bGhYQXdVVVhXM0xKVTkyL0xGcU0KRmJtZ2NCYXRzWGZ2bUMvZjZHVWQxbnVjejJmUjQyeXpC'
    b'ODd3QXNVYU1RVmt6R2RMVXpmWHdwb29TWVY4d010dmxaazBGWlVreHVyTQo0T1V5Yjd4akk0'
    b'UWp4QlVDeW5DSUdFc2FLMFJNZGZCWElYaUlBNlhJVStqQW4veFdESW41eXY5eGd4TUZxcXkx'
    b'ZGlpS2FaeE1XclV3CkVuL3lTRGpHeXlRK3Q0UmNXdlJ3UjVFNFlENk5QSmpUK0RBcUY3KzRl'
    b'UEpMTWNISTlYVlRDMjZMQmxUTG5xY1gvYzRmZmRMYXdSK2gKL2VFQjNkSS9aVTdJTno2azVh'
    b'QkhvTm9CZ3RsNXR2aVFFRCtuejJGejl3WlA2Q25JVFV2ZGhwWjhOOWF2QjdaYm5Gejl5ZjJ1'
    b'SlJKdApETjBhdVBvdksvQ3NvZERSVkgvcWpDSGhDazhZUmpXanF3OG5LRGJnY1dQTzhDeVRt'
    b'ZEpUUEpwZElCYTUxcjNBYThZY0VGOUQ4eTFQCm5KeEFQeG81cVBJYTFwNUVlQVM1WU9lRXVS'
    b'OU0zNDRiU3hmR3RIdU42MjlvQkZJczFsK2wvamxrOHNxdmJGaWJhSXpQUml0T0ovd28KZzkr'
    b'bGdtUDBYbnRkd3pUSEpHbW1XV0JnbUpxTnJWWFgyUjNvTVJoZ3BuMHdxS2NjS0thWVlvb3Bw'
    b'cGhpaW5uUC9nWGZJMlFHcjNPNQpuQUFBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VBTWpBeU15'
    b'MHdNeTB4TkZReE1EbzFOam93Tnlzd01Eb3dNT0hFeVNJQUFBQWxkRVZZCmRHUmhkR1U2Ylc5'
    b'a2FXWjVBREl3TWpNdE1ETXRNVFJVTVRBNk5UWTZNRGNyTURBNk1EQ1FtWEdlQUFBQUFFbEZU'
    b'a1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMzMxNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_11')

JP_11 = b64_JP_11
index.append("JP_11")
index.append("Japan Saitama")
catalog["JP_11"] = JP_11
catalog["Japan Saitama"] = JP_11
country["Japan Saitama"] = ('JP_11', '', 1)
lookup["JP_11"] = ('JP_11', '', 'Japan Saitama', 1)
lookup["Japan Saitama"] = ('JP_11', '', 'Japan Saitama', 1)
details["JP_11"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_11"] = ('JP_11', 'Japan Saitama', 1)
regional["Japan Saitama"] = ('JP_11', 'Japan Saitama', 1)
#----------------------------------------------------------------------
b64_JP_12 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc2NDA3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQ2hpYmFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzNjQxMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzY0MDkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNjQxMyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUN5bEJNVkVVYUZYSWlISE9haklpWmk0ZE4KUlh2'
    b'ODZaZjk2cGhSU0hzakhYVGR6SkwvNzZiZzBKTWtIblQvN0pqLyt1VC8rK2YvN0puLzlNVC8v'
    b'Ly8vN3FYLy92ci8vdnYvNzZlYQpqWWYvK3VQLzlNT0VlSVAvOXM3LzlzMG5JWFROdlpELzdK'
    b'ci8rZC8vK2Q3UndaRXBKSFRIdUkvTXZJL2V6WlBnejVQLzhycmZ6cFArCjY1Y25JblJHUG5s'
    b'U1NYdi8rdUliRm5PTmdJWGgwSk9VaUlZK04zaC9kSVAvL2ZYLy9mWitjNEkzTUhlRmVZVGJ5'
    b'cEtjajRjY0YzSncKWm9ENzU1Zlp5Skk1TW5lcm5Zci83cUtxbklrekxYYkt1by83NkpoM2JJ'
    b'SldUWHp4M3BVd0tYWFh4cEgvOHJiV3haSXFKWFZ1WklEQwpzNDN6NFpaY1UzMUJPWG5qMHBU'
    b'LzhiSC83NnNzSm5VaEczUC85Y3E3ckkzLzhLem4xWlJGUFhyUXdKRC85OVQvL083Lzlzei83'
    b'Nmo1CjU1Y2xIM1JLUW5wSlFYcGZWbjZybm92MjVKYi85Y2ovL08vLytOZTVxbzMvOU1YLy8v'
    b'NzM1WmRtWFg4ZkczTjJiSUgvL2ZKMmE0RWQKR0hOWFRuMy83cVMvc0k0bUlIU2RrSWovN3FF'
    b'ZUdYS2lsWW4vN1o3LzdaK2lsWWhRU0h2czI1VC83YUQvODc3Ly92ei84N3lrbDRsLwpkWUwv'
    b'OEsvLzlNSHAySlhheVpMLzhiUC84YkwvK2VELy8vMy8vdmYvOExCaVdINy83WjMvOWNiLzda'
    b'ei84cmYvK2QzLy9QRDQ1cGRvClgzOUtRM3JxMlpULytOci8rK2ovK052Lyt1WHUzSlZQUjNz'
    b'NE1YZi83WnYvK2R3N05IZkZ0WTcvOTlQLzg4Q3lvNHYvL3ZuLzhiWDYKNXBmLzc2ci8vZlAv'
    b'NzZsVlRYdi8rK3YvKytwYlVuMXZaWUgvOEszLzhLdi84cmovOTlILzlzLy84Ny8vOEs3R3Rv'
    b'Ly85Y2ZMdTQvLwovTzMvK3ViLytObi8rK3ovOU1haGxJaTZxNHovL1BGMWFvSC83cU13S25a'
    b'SVFIa2dHblAvOWNueTM1YlZ4SkgwNHBhcG00ci8vZlI5CmNvUC8rZUgvOHJtenBJdUhlNFQv'
    b'L3ZpR2VvUmFVWHhaVUgwdUozVXZLSGIvODczbTFKU1Bnb1dPZ1lWaldYNDJMM1kxTDNmdDI1'
    b'WEQKdEk2WGk0ZVdpb1pyWVlCcVlIOC9PSGp0UUtOR0FBQUFBV0pMUjBRU2U3eHNBQUFBQUFk'
    b'MFNVMUZCK2NKQ2drbEVTaXF5QlVBQUFRUwpTVVJCVkdqZTdaajdWMVJWRk1ldnIxRW52c3g0'
    b'WVBDQk5DSkZNS2lRcjFGSFVWRlFURUlxRk1nQ05CV2hab3lBSG1LTTVwaWdJT01MCnFaU0V4'
    b'QjZpUmxJcXZrSEZVbnY1ek5SU3MvTHhQOGlkZTBjZFpxYTFXc285NTRmei9lbmNmZGFzK2F5'
    b'N3o5MW5mN2NnY0hGeGNYRngKY1hGeHRWV0hEa3hpZGV6RUlsWG5McXF1N0ZGMTY2NVdQK0hE'
    b'WGdyaHE5RjJZaStGUFFqcHdWb2F1M1gzOHlkRUY4QllHbnVpRjJtVgpSdHVSclJUMkpnNHhs'
    b'VVlwaGFLWVNtTWZCQkpaZmRHSEdheWdKL1g5SktwZ2ZmOFFkckxvODVURUZheC9Pb2lsTXk5'
    b'eHNVYlZtc2ZRCkFFSUNRaG1qRW9SbndnZ0pDMmVOS3NqUStqRUdHaUxvL1B1QUFWNDJCbUlR'
    b'SVlNdzhQLys3dkVvTXVyWndVTThiUXpGTUVLR3craHAKYjhUSVVhYlI3ZnkreGtSamJOUTR0'
    b'L0Q0R0xGQXhFeHcyNWhvakVYY3BQYlA0K1I0QVAyTlUxeWp6MDBWc2FZbXVFYWZUNXhtQUpK'
    b'ZQpVT0o4dmZnU2txZERGV3VjOFNDV0VwMHFZcVhHcFR5SVJTU21SZVBsWk14OFJabHpQK1ZW'
    b'YlhwRzVpek1Ua3Q4VFE3TlFiQ2p5bU91CmszTmUxbno0WmVlOHJrK1lxRmhOZndObUM4bklW'
    b'R05CMnB1NVl1UXQ1SWxZZWNnWG53cmV6a3JDTzJZTklabDQ5ejNsNmtUQlFvVHAKQ0xGb3pJ'
    b'V0l6NXEzU0hpL1NMcXFyWXVGMFV0TUgyQ3B6YmYxYWRtSFdMNUkwUUpXckNvWkxuSllOQ3VL'
    b'c05KVVdpWmhyU28xclVTUgpyZHd1UHF4ZW95cFd1ckN1bmEvT2tWQ1dsZHZXWWIyMFhvK0tE'
    b'WlYyYWYxUndNZWZLRi93TjI1YXFuRTJmLzVWOHZMVHpUcG5yTnBhCjh4bU5pMmhMYWUxbTRs'
    b'VmJhOE0vcDNOQmhueUJURzlVWHlKMkJxMjJJWGM4dnJKN2dyS3Z3TFlVZXUxTVpKU2hyTTZk'
    b'eW44N1RKRlUKKzZ6RUhUdS9ia3VWVngrWFQ3di8reVkrWnBjclZVTmgwcmNDZlN5c0szK1lx'
    b'bDhGNkdOOXQ2TytZWTAyL2FGUFVMdTdZUS9sSkVwSApYcmNYalU2cWZkaXJJM1ZsVkk5OGJo'
    b'YjJpd1hDVW5MQWliVzd4Q0lXaVAwVUMwVElRV2M1UFZRaGx5OTdiYmF6bkI2bVZFNjNsT3Fy'
    b'CjVIZFVoUXhwY1FSYjVWQWxwY3RuNHlacjAvMmFBQm13R1VlZHNTWnJ6UkxscWRvME5zZWt0'
    b'Um0xRzVwMTlCcWJZdFVCbHpad2xZU1MKVExVTmRHdWFGOHROYzlGeHFXbTIybnd0aWpmTlBp'
    b'MXRMVWErWkRGTzRQdjdGdU1IMldJb05zUTU2VzdJNXFMUzhmbmhsSXNoTSs5Uwp6cEI1c3Er'
    b'bkpmdjZvNXQ5bmE2VWZaMzhreWV6bitBdys5dC85bVQyZjFIQTdIc1pqVXdvZEl4R2ZxVXpH'
    b'dkU2U0RLS2c2UXpPRXRuCmtQVGZZN2R6dE1adVhoV2tDaVNrcjRHNWtXNTRHQ0huUTFtakVp'
    b'Nm9DZkhieGh6V1JmeFdoMHZNWWYyTzZtcGNaZzdyQ2hvYmNaVTUKTEdHbTdZOC8yYU1TMG5i'
    b'V3R6Q0lkVTJ2djg0ZzFnMWdMWU5ZZndFM0djUVMvcTVoa1VyNFp4cVRXUC9lWWhMcjloMG1z'
    b'ZTRPWVJLcgpvRURnNHVMaTR1TGk0dUxpZWhUZEEzWE9KT28ydWZWM0FBQUFKWFJGV0hSa1lY'
    b'UmxPbU55WldGMFpRQXlNREl6TFRBNUxURXdWREE1Ck9qTTNPakUzS3pBd09qQXdtYWZVckFB'
    b'QUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3T1MweE1GUXdPVG96TnpveE55c3cK'
    b'TURvd01PajZiQkFBQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2U2NDE1IiAv'
    b'PgogIDwvZz4KPC9zdmc+Cg==', 'JP_12')

JP_12 = b64_JP_12
index.append("JP_12")
index.append("Japan Chiba")
catalog["JP_12"] = JP_12
catalog["Japan Chiba"] = JP_12
country["Japan Chiba"] = ('JP_12', '', 1)
lookup["JP_12"] = ('JP_12', '', 'Japan Chiba', 1)
lookup["Japan Chiba"] = ('JP_12', '', 'Japan Chiba', 1)
details["JP_12"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_12"] = ('JP_12', 'Japan Chiba', 1)
regional["Japan Chiba"] = ('JP_12', 'Japan Chiba', 1)
#----------------------------------------------------------------------
b64_JP_13 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTcyMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1Rva3lvX01ldHJvcG9saXMuc3ZnLnBuZyIKICAgeG1s'
    b'bnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2Nh'
    b'cGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0'
    b'L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAg'
    b'eG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBp'
    b'ZD0iZGVmczE1NzI2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2'
    b'aWV3MTU3MjQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTU3MjgiPgog'
    b'ICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAg'
    b'ICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRl'
    b'cmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3Bu'
    b'ZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhUbkNB'
    b'QUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZB'
    b'QUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFCd2xCTVZFVkxBSUpXRDRsWEVZcll5T1Rj'
    b'CnplWlpGSXhiRm8zZTBPai8vLy9oMWVwZEdZN010OXpYeHVOWUU0dUtXYTY5b2RHTFdxNU1B'
    b'WUw5L1A3V3hlTndOWnhWRG9tQVM2ZnEKNGZDemxNdisvdi9EcXRWZkhaQk9CSVNKV0szT3V0'
    b'MzgrLzNOdU55SVY2MU5BNE8zbWMyems4cUhWYXozOVBxbGdNRlJDSWFHVkt2bgozZTdtM082'
    b'RlVxcFBCWVNaYjdqMThmanI0dkdOWHJCWUVvdkhzTmpHcnRlQlRhaGJGNDNvMysvUHU5NXFM'
    b'SmhrSkpUbTIrMWtJNU5QCkJvWDI4dm4rL2Y2OW90RmFGWXp1NS9QMDhQanQ1dk94a2NuNDlm'
    b'cFJDWVpkR28vMDcvank3ZmJrMmV4dk01dFNDb2R3Tkp1bWdjSGwKMnUzdzZmVHg2L1poSDVI'
    b'djZmU1NaYlNVWjdUdzZ2WGJ6T1oxUEo5ZUc0L2F5K2FUWnJSTUFvTlRESWlxaDhUNitQeFRD'
    b'NGZkeitkZwpIcEhKczlxU1pMT0dVNnVVYUxYYnkrYnM1UEovU2FaVURZaWxmOENuZ3NLZ2VM'
    b'MmVkYnUybDh5RVVhcTBsY3UvcE5MMDcvZStvOUtmCmQ3enI0L0dkZEx0L1NxWjlSNldvaE1O'
    b'K1NLWDcrdjNheStXWGE3Yng2L1hmMGVoaUlKSmZISkNWYWJYeDdQWnhOcHluZzhMdjZQVHQK'
    b'NWZKaUlaSldFSXJFck5aN1JLUGkxdXVEVUttQ1RxaGNHSTZJVnF6THR0dnA0UERYeCtTY2Ur'
    b'd0VBQUFBQVdKTFIwUUlodDZWZWdBQQpBQWQwU1UxRkIrWUdBaEFhSXlmc1I4MEFBQU1QU1VS'
    b'QlZHamU3VnJaWHhKUkZFYlNtRVJGOWdETDBtaEVSR3gxZ1pJQ3MwS0Vzb0N5ClVMUXNNQ3Zi'
    b'RnkzYlM5dXovN2VaZSsrczRFTVBNM2Y2ZGI2bnN6eWM3M2ZQNVo2Rk1aa0FBQUFBQUFBQUFQ'
    b'OElHaHFNeU1xOHJiSEoKZUt5Mld4aG1SN1BoYUZrWkRsYkQwV3JoYWJVQUxhQUZ0SUFXMEFK'
    b'YS93MnQxalpidS8zdmFObmJiVzJ0MnJLeU9iamdUbGVOM2UzeAo4clM4SG5lTnkrWGtIQTZi'
    b'cHJSMjhzRVpuejhnTjNiczJ1MWdDRHIzN08yUys1cTdzV3VmcHJTQ0pQcCt0a2UwaFhvWkJj'
    b'SjlvaXZTCkh5WEdrTFk5cUU4SVBuQUFXdzRlWW1wdzJJeDlSOEtDeFhkVTI4c1ZHaFNERHcx'
    b'eitrZ3ZVd2V4T09jYUhoTDF3WkRXUDhWai9jZUYKWUtPSkV5TW5KUzdKcENTbjR1YXhUa0U1'
    b'eFk3cjhFYWM3aDRWQXA0NVM0UTBPOEdGemt4bWM4Unc3cnlZUC8rVVRvL1hwRk9ac3dzWApP'
    b'OFJmWmI2ZzlCVXY2ZmVvMm9OZVdXU0w0amd1VDh0Y3FTdFhkWDN0U3pPelF1akdzc28xSjNo'
    b'bVowcTZsNkZBZ21Rd29QYk1renhlCmkxT3BqMFVVL0RwV3hrTlpkb0g4NG00Z3gwMUtxeEJV'
    b'VnRMNHRudFN2RktwNG5zZlEzVm9rUW90RHpxVFcxZ21SZEdCZVMwaHBVcUYKMW0wVWU0SVhN'
    b'eW5obGxkUUhsMUl2a09GMWwwVU84T0xDOUtUc016clpTVGVvMExyUGgvNmdTeHBDQ3d5b0Ry'
    b'MGtCNnRKQkt6RWkxOAoxNkwwYU9Fa2x1c2xzVVF4aVkra0t6OWVFVmc5N3BHdS9CTXF0SjZp'
    b'MkZra1Y0VUg0aGxTbnlObGhRb3ROMnFvY3ZnNXJhTHpHc0NzCklxZ3JYYVh6bkpwZW9EUEpr'
    b'K0xUeDdMTHBNRi9pUnpUVkVnSnBib3dyL1pNclZFcjFiTEdaazdWdlpRc3RCb2JaUnY0NnJY'
    b'Yzk2WkkKcXcxMHFacm1RbDVzbWlOdjF5ZzF6ZklSNHgwUmNrc3VyamhtM244UUpzT1BPbzhZ'
    b'eW9Fc25wTE9KUnFWNUUvcitnNWs2dkUxSHFzMwp2cWJYOVIxZnBXRS9ITVNXamMrMXJQemtM'
    b'N3d2WDNVYTl1dXRScjdsVkVmMVhmZlZDRmtrSlg3SWpWMC9yZUk5V3YwVlZDeVNtc2IwCldD'
    b'UnR0WFpickc3eXdUZFhTbFRXYmdaZFVtNE4yRFFETGFBRnRJQVcwQUphR0FiOTlNZWdIMHFa'
    b'Tm40WERmaFptVkUvd2dNQUFBQUEKQUFBQTFNTWZsUWFCUkl1WHdjY0FBQUFsZEVWWWRHUmhk'
    b'R1U2WTNKbFlYUmxBREl3TWpJdE1EWXRNREpVTVRZNk1qWTZNelVyTURBNgpNRENNbjE1ckFB'
    b'QUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl5TFRBMkxUQXlWREUyT2pJMk9qTTFLekF3'
    b'T2pBdy9jTG0xd0FBCkFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTU3MzAi'
    b'IC8+CiAgPC9nPgo8L3N2Zz4K', 'JP_13')

JP_13 = b64_JP_13
index.append("JP_13")
index.append("Japan Tokyo")
catalog["JP_13"] = JP_13
catalog["Japan Tokyo"] = JP_13
country["Japan Tokyo"] = ('JP_13', '', 1)
lookup["JP_13"] = ('JP_13', '', 'Japan Tokyo', 1)
lookup["Japan Tokyo"] = ('JP_13', '', 'Japan Tokyo', 1)
details["JP_13"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_13"] = ('JP_13', 'Japan Tokyo', 1)
regional["Japan Tokyo"] = ('JP_13', 'Japan Tokyo', 1)
#----------------------------------------------------------------------
b64_JP_14 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4ODM3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS2FuYWdhd2FfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzODg0MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzg4MzkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnODg0MyI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNRMUJNVkVYLy8vLy90YlgvaUlqL1lHRC8K'
    b'QUFELytmbi9WVlgvVmxiLyt2ci95Y24vZDNmL09Eai9CUVgvT1RuL3lzci84L1Ava3BML0pT'
    b'WC9KaWIvbFpYLzlmWC85UFQvazVQLwpKQ1QvbEpULy9Qei9tSmovRnhmL0dSbi9uWjMvL2Yz'
    b'L21wci9HQmovbTV2LzNOei9PanIvUFQzL1BEei8zZDMvc3JML0RnNy90TFQvCkFnTC9CQVQv'
    b'RlJYL0lpTC9FeFAvQXdQL0FRSC9CZ2IvVEV6LzFkWC8xTlQvUzB2L21abi9sNWYvc2JIL0NR'
    b'bi81dWIvZFhYL0NBai8KNStmLzVlWC9EQXovUlVYLzRlSC9EUTMvRHcvLzN0Ny8zOS8vUTBQ'
    b'L2YzLy8vdjcvT3p2L1B6Ly9mSHovbHBiL25wNy9GaGIvZ0lELwpHaHIvOXZiL1FVSC9Ra0wv'
    b'NE9EL0p5Zi9LQ2ovZUhqL2RIVC96TXovemMzL1cxdi9SRVQvdWJuLzVPVC9lbnIvZTN2L0lD'
    b'RC9uNS8vCk56Zi9TRWovKy92LzJ0ci8wdEwvMmRuLzA5UC8wZEgvMjl2L3VMai8rUGovOS9m'
    b'L3U3di91cnIvcWFuL3Fxci9FaEwvcmEzL3JLei8Kb2FIL0hoNy9IQnovbzZQL0J3Zi9Ta3Iv'
    b'eTh2L2NYSC96czcvS2lyL1FFRC9HeHYvbkp6L2taSC9qbzcvUGo3L2VYbi9FUkgvdDdmLwpv'
    b'S0QvSHgvL3A2Zi90cmIvMTlmLzBORC9pNHYvTEN6L0xpNy9xS2ovSXlQLzR1TC9XbHIvVjFm'
    b'L1hWMy9iMi8vRkJUL2JXMy9ZbUwvCkxTMy9JU0gvN2UzL3dzTC95TWoveGNYL3hNVC83T3ov'
    b'OGZILzh2TC9NelAvc0xEL0x5Ly9TVW4vcjYvL3BLVC93Y0gvdnI3L3E2di8KQ3d2L3o4Ly9X'
    b'Vm4vSFIzL1lXSC82ZW4vTlRYL05qYi82T2ovWDEvL1UxUC9WRlQvS3l2L2RuYi9ORFQvaVlu'
    b'LzZ1ci92YjBWYmlUawpBQUFBQVdKTFIwUUFpQVVkU0FBQUFBZDBTVTFGQitjRERnMGVHa0VS'
    b'Mlk4QUFBU1JTVVJCVkdqZTdacjVXeE5IR01jWDJXaEVGSlZECmpSQVVCWkVyQ1NwVnhDTVNO'
    b'SXBXdkZFcUZoUWpGSS9pRVZ0dnhRUHhRbHR0dGJiZTk5SER1MTUvbXQxNVo1UFpuV3hnNDc3'
    b'N1BIMmMKN3krWm5lOW01NVBaMlhmbm5Zd2tDUWtKQ1FrSkNYMnVrdm9wU2pKaDJLSmtXVkd5'
    b'Q2VNTHhuTDBKNjBQY0JvWS9SMzJNdzFNR1pRcQpnMUlIcHd5SmJReGlEWHlsRFIwbWF6VThQ'
    b'VU14TXJORzZJMlJtVFpCalhLTmxubGw1N2hINVk2SlpZeDEyMEdWTjA2T3JmRkdSbjRCClB0'
    b'V0VRdG0wQ2lkaVU2VVhNYzBWbDVTV2VXSnhlTXBLUzRxWjR5SVhNcFZYYmNsWG5qdEpDUTJP'
    b'eWE0cFBoYkpWMTR4U1FrTnpza1YKVWNQN0ZTYlZWTFd2cHFWVU10V1YwNnZraURHRE1XWkdE'
    b'QS9pZmN5YlJSdVo3ZGNaYzFTczZvRFdxWm1yanE4QVdtU2dqNXAzWGxCbgp6SS9ld3dXNmNP'
    b'Q3VwZmM5SHl0TzVGS3FoUVlHYUpIZXphSmNPVGhVbVYvRDVSZHpoaWFLMW1Yby9Wb2FWNWVn'
    b'WUdYUmNSVTBNcGJDCko5ZVo3bVVHaGlXQzkrQzA1ZnI2NEhBdy9BRjQ3Rlp3MzZ3Qll5VUcx'
    b'UkQ0eWF2NHlVVEVxSWZTYXU0VWFxeEJ3Rm9Gd1pMRXE0WnYKRkswRkl5VmlOTUtVWmgzVXJ5'
    b'VW5OU2hGYW55TGdEV1lYTG1jbEp0SXVSbU05VkZqQXluT2gvcG1jdEFrUlkxODY2bWM4Q0p4'
    b'Y1ZnTwo2SWtLcGJ3UU9xNkZ3NktHMDNLc2pUQThRaHpXSmpCYWxYSWJsTC9qc0RTR2xXcUhW'
    b'OXRtRG9zMXRzQTdjeXVIUlkxdGxtTjlUNjViCkluRllIYXl4blJ6czRMQ29zZE55ckYza3Vt'
    b'RWVTMk9FeWNFdUhtczNPZmpCY3F3T285N1N0RzVvbENIMUZoMUNqc1N3TklQT1NyRVAKbkhr'
    b'c3RDZlI0WXVHSi9OWTZhVDhZd3RXbE4rVEdOWnNyQ2hQMzRtcGpZbGcrU0VOcWtYQTJndkRv'
    b'ejRSckgzdzNmMFlNNXNWNU5KVgpBZk5ZQlREZk9vQ1RJOEpQWHVZMmkrVStDTi9FeVJVejYy'
    b'UjExbVFPQzBhbGZBaG5MaThkcGtuRUVYTlluVEpxNWlPNWo5S01yRGJjCmQ2endNWU1FMGpv'
    b'VlZHc1dRUHFFcGVvNFdsWXRTVW1lUkxFODdaaHJJeFhleExDOGgzRlhrbHllUkxDS3gyS3Z1'
    b'eVVWbXNlcVBvRy8KU2xrejNpelcwZVYyck9tNm03UE5ZTlYxQlcxYUFsK1MzWGNzcEhXYW1E'
    b'SS9seGRZQWt0Z0NTeUI5Zi9CT2tsYTdJcVAxVVhLSjIzRQpLaUV0ZHNUSDZpYmxNZlpSYllh'
    b'NVlIdDhyRk13QTdSdjI4RWFtTEpzaW85MUdzNDZZeHRXUC9nM3BTVStsaE5TL0xOMlVRWFBr'
    b'ZmJtClN2R3hKTWp4ZSt5YUJaNlgyVzR3eG9KT3BVOEcvdHowQW1SK2piMWgvUVFMcGlPMjJI'
    b'SUxHNkFUZnBaNnc1SXV3cG1YN01DYVIvY1YKQkhySHl2TVovRjlyZmNoS3BsbldMMnFONXUr'
    b'Tlg3V2o2VEk5K1FweThEcjFHMjNvNnU5cTFSOVFjVTBwWDRmeURkVzcyVVJQNzBGTQpZQ3NY'
    b'NWFzWjZaeldTTzB0dUZPbC85V0Vyc0k2OSsySUdab1YyUmpVWEluQjFINkgyUjVWZEpkeE50'
    b'QzZlejEwVDhsOXhuekE3TWtaCmZjZjZaUnQyL2FYcUllczgwbS84ZWN5NlQ1NXlhenhJV09F'
    b'L3RkWmZXaXBkUE5qL3R5MVlubitlNmF5TTV5elZDMzEyLy9KVkVUN1cKbmxiZVMzc2RwWHFU'
    b'eHZ0dDkzR3gvbjBiaXUxT2VBZnRQamZZRDlWV2Z3QUhLL1ErNS9HSE9MNi91N096MngvbmhH'
    b'Y2ZjOTZISkNFaApJU0VoSVNGVCtnUkozQ3IxZmhrOHBBQUFBQ1YwUlZoMFpHRjBaVHBqY21W'
    b'aGRHVUFNakF5TXkwd015MHhORlF4TXpvek1Eb3lOaXN3Ck1Eb3dNRjMzRXlFQUFBQWxkRVZZ'
    b'ZEdSaGRHVTZiVzlrYVdaNUFESXdNak10TURNdE1UUlVNVE02TXpBNk1qWXJNREE2TURBc3Fx'
    b'dWQKQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2U4ODQ1IiAvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'JP_14')

JP_14 = b64_JP_14
index.append("JP_14")
index.append("Japan Kanagawa")
catalog["JP_14"] = JP_14
catalog["Japan Kanagawa"] = JP_14
country["Japan Kanagawa"] = ('JP_14', '', 1)
lookup["JP_14"] = ('JP_14', '', 'Japan Kanagawa', 1)
lookup["Japan Kanagawa"] = ('JP_14', '', 'Japan Kanagawa', 1)
details["JP_14"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_14"] = ('JP_14', 'Japan Kanagawa', 1)
regional["Japan Kanagawa"] = ('JP_14', 'Japan Kanagawa', 1)
#----------------------------------------------------------------------
b64_JP_15 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTUyMiIKICAgd2lkdGg9'
    b'IjEzOSIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxMzkgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05paWdhdGFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTE1MjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxMTUyNCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMTUyOCI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxMzkiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSXNBQUFCa0NBTUFBQUNCMVRP'
    b'YUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNXMUJNVkVYc0dpVHNIU1R1TENIelpC'
    b'YjYKcVFuOHZnWHRIeVAxY1JUOXdnVDFkUlA0a3czLzJnRCt6UVAyZ0JIOXhnVDl4d1AzaHhE'
    b'dEppTDFlQkx2T1I3dk5oL3dSaHo4d0FYNAprQTc3dEFmM2lRLzd0Z2Z0SUNQeFNodi8yUUQ1'
    b'b2d2d1FCM3VMU0QvMkFEeFN4dnZOQi8rMFFMN3JnandSQnorMVFIN3NRajBhUlg0CmxRMzBa'
    b'eFg1bnd2NGxBM3VMaUR6WWhiK3p3TC8xd0h6WEJqeFR4cjRrUTd2Tng3OHZRYit6Z0x6WVJm'
    b'dk9oN3lWeG50SlNMNW5RdjUKbXd6NW93cnhVUnIxZVJMelpSYnRJaUwrMEFMMmd4RDNqQS8v'
    b'MXdEdlBCNzl5UVB5V0JqOHZBYjl4d1Q2cWdudEp5TDJnUkgwYmhUdQpNQ0R3Unh6dEtTSCsw'
    b'd0h3UWgzeVV4bjl5QVA4dWdiKzBnSC8xZ0g1bmd2dEp5SDBieFQyZnhIKzBnTDdzZ2YwYWhY'
    b'MmZCTHlXeGp1Ckt5SDZvd3IrekFQd1FSM3NHeVR5VWhuc0hTUHZPeDc5eFFUOHVBYnVNU0Qz'
    b'aFJEKzFBSHlXaGp2UFIzeFVCcjJlaEwyaEJEelh4ZnoKWUJmNGp3NzZwd3I2cGdyNGx3Mzl4'
    b'QVQ3cndqeFRScnRLQ0h5VkJuell4YnNIaVB4VEJ2dUxDRHRJU1A3c0FqMFp4YjNpZy8xY3hQ'
    b'Kwp5d1B2T0I3N3N3ZnRJeUwzaXcvNW9RdjBaaGI4dXdiMWNCVHVNaC85eWdQN3NnanZOUi84'
    b'dVFiOHZ3WHRKQ0wzalE3M2lBL3NIQ1QyCmdoSHRJaVAxZEJQN3RRZndRaHp5V1JqMGFCWDFk'
    b'aFB3UGgzOXd3VDFjaFB6WFJmd1B4M3lWaG4relFMOXdnWDVuQXp1TXgvNW1RejAKYlJUOXlB'
    b'VHhTUnY0a2c3MGJCWHVMU0gyZXhMMmZSTHpYaGY3clFqd1JSejNoaER5VVJyMGF4WHlWUm4y'
    b'ZmhINnBRcjVtZ3o0bGczdwpReHozamc3N3R3ZjZyQW41b0F2NnBBci8vLysrN0RET0FBQUFB'
    b'V0pMUjBUSUhicFh5Z0FBQUFkMFNVMUZCK2NFQlFZeU5NMkNDeDRBCkFBWnBTVVJCVkdqZTdW'
    b'bjlYMHhaR0g4bVpsTGYwU3lOdDJwd1U0MUZkTmxlbEVTam9wVFNTb1VpWmR3VUloRXF3MVRT'
    b'WUZGSm8vVysKNUNVV2kzMlJ0WmI5dC9hY3FVWlpMOTArOTdaK3VOOGY3dHo3M1BOOHpuZk9l'
    b'ZDdPYzRrMGFOQ2dRWU1HRFJvMGFQaTZvUE1aTjE3LwpWVEF4K0U3dzg0ZVIzVXdNZ09tYlNW'
    b'dzJPWENNU1pnOTF5bFRBYjlwMDJjUXpRQkhVREJSQ0N3elo0MGhrOW4rUWlqN21STUdoRWR3'
    b'CndTUXI1bjQ3RDVoUHRJQnhFaUlYamhXVlJWR01BL0hGRUJmM1M1WUFjNGltNGp1S0ZoQWpB'
    b'ckZ4cXJOWUdrK1VzSXo5ODBRMk5ZVmoKT2JzbVRWeEJLNEZrOHJGaEZhVWcxUnpOMTJaWmdy'
    b'cFUwbGFMYTh6cFFFWVNVWVNCMWtLZlNaVEZiSGNkNDVJOUhaYWM5Ymt3ZlUrMApJUS9ZYUZh'
    b'VlMwZytDbUtCd2sxRWZwYk50QVVvS2w1cllseTJBdHZZeGsya2tsVEFNbTgyYlM4RnluYW9T'
    b'bWFKbFUyMXpVNDdwWEp4Cmw1Ulo0ZkVleG1VKy95bll6RVpVN3Q3REJIdVR3NWtnYW9xYVhL'
    b'cHNiTXA5dEIvVmRDQ2JLTGptWU9taENUQUcxcktaaTh2N3gxUWUKWmc5SGdLTUNvc3JWbzVJ'
    b'ZEFDRVZ1WFZwWVhuMVhtRVdCSUhON3FmelNocE03TGxVT2liZ2lHcSs3U2dHTnNjSnlBODVm'
    b'c0lyZEM3cgozNmoxUXdhZVlEc1V0SWxiZEtPa0VwZmR3QXh5Nm9GNVhwSFVGTUI0TEc4R1R0'
    b'WWFXeEpQRGJKT0JGcGRkSnFic3pwZVpFR3hnMWgwClBlTVlGQVVHOFNVcG83UDlhNE93UWRm'
    b'UitiTmhPa2NyQkZYczEvRUQ4dWZRT1dZSmhrSFIrUXVBdmcwWFBGd21ORThyOElUai9nVmoK'
    b'VHUxSDdmbm9VR09YZk5rKzBKUlVYT3owaWk3QnNrTHF3bXJHSlNET1RYUVpRdmZnTzFjNnJH'
    b'bjBJN0JPZVNxZExkZ282YTVBdlBwZQpGbzZaM0lwTXRLamF4WitiSVhxM2o4cHowU3BKNmNq'
    b'clZweUxIM0NOcmdNM2hzamFVRWhVaUZaeWV4NURyU2dkcm5HTzl2S0x3cEIyCm9jS2VXUWE5'
    b'YnBoanBWYmZFSEc2ZjhRS0VRVTNoNnBVd0JSc3I4QXRuY0pjMWdBcjZTZmc5bEFoTDJDQTNH'
    b'aWk3anY3TStBdElRYlEKQTJ6bEtYeW53bHdLY2JmYlBSVVY3dUZ1M2dGY3pDR0s1NUVYK3B6'
    b'aE92WXJ1Q2M1bzNCZldTcXVYRlluSlFIL0taRk9QTEN6YXdsTAptVzByRFIrK0hBY2tVU1NL'
    b'bklweWllY3IzUXZySndxa3FvZDFQaDhSTzIxSW9RWmdnOExoMytxMHQyQ0JUTFZlWkxoZEJk'
    b'aXRLSmRXCkZsSFRnQnFaYWdlQXF5d0toU3Q2SWl0Z0ZjdERUNEV0QzVYY2s3cXdSMG12bnNN'
    b'OU9oSTJ1MXpGUitqaVhsMnBJSmQ5d004MGZoUnIKdlJhMVZBZUVLTWlGN2J1WjlNeXQ1ZUl4'
    b'YmxFMGNFQkJMaytBZWlwaWxaUjgvelBTVTZCSlFTNG5nVzRTbVAzS3hTK0lwVTVXbVNySQpo'
    b'VlZRblpTUFo3SVZuOEZHQ2NweWVjajNxR1VVTWFzYVJiUmQyVDJxQVU3UkVTVEtWdlJudG5z'
    b'S2VLNGdsMUFnbEY2Z2JSUSszVWpICmxmVnBNNDkxemNpVHJXakNZMnBTTnRicDhway9zd0t6'
    b'WFg0T09LZDBEcUJHRm5OLzVjbEZkb3lNb0tQSzVrYjZEV0tuMU1KTGJaazEKUTVUa0VyRktV'
    b'UzYvQXczc09HUkxscVdWSElYRHl0ZFN5VlptaEN6Si9TRkxpMlhvSHBiZXc0S1ZMWGdUWWV1'
    b'V0h1R2lXNGFPUFFnQgpVbmZVS01MUzUvRVNPRWFiZ1hnWk9qMzhaSGVXNzY3Q1o3VUFiTFE3'
    b'SHlGbTVPc3RkYUFzd2QyQmUwcWYxZmpSUHA3bnBUNDVwMTVmCmZscnhWZjVzYjRUZVllaUFX'
    b'RFZDaGJROXFKQWNlcGlTRmVmQzE4U1gwcXlJcVI4Wjl4aUlFWFFEZUtoQy8wVks1eWRuVnNt'
    b'OEdJbkoKU0srQXlSU3RVaStJY2dTME9kd0xnRCsvYkl6U1llQzEyekVkd2wvcU5Pd3VBMjhv'
    b'ZUR3d3MvTUxJdzMzZ1VNT2VxTmE3NUFNamJ6ago1V0xYdjdNL08zRGhYS0Mxaysvblc3VjZx'
    b'alE3QTVaamxGa0w1SlY4cmhHd0dualhTU3N0T0RLYlZNT2RXS1RPSjEyV0JTajkxSG4yCmZD'
    b'K0FMRGRkRjJCY1Npb2l3Z1k4czFPSkVjaE4rZGhNRDdxc3dPb1NjdmNCc1JHa0txNnk5Vjll'
    b'VC9VcC9PTk1iY253V0pPOGVBRVQKcHpablVuMHBZM1NIVkVhN0h0akZzdDJkVXQ0WEUxcXo0'
    b'a0xNVGdwZXVPUDJscmNpbDd6YndUSnBCdEJoSnRXUjBEdndqYTk5VmRsQQo2NzJYZWdmdTds'
    b'YnpGL2U1ekVWamdYRjNBVEdGVFJwYzF4Y3Vlcm1JNGM5Q1dVZzJYeW9BakRVMFJ2Q0paUHNq'
    b'bklublBVRm5ZR2hjCkEvVmNqNy9KKzl1R2E4djVLLytuTkhhb09tUGhuMFVTbjl4ODMzU1ha'
    b'bTB0RFBOWVRCcU5MUUtiYlI0TEVmV3ZEamRSMCt0LzlLTG4KT1RZbG1zWWV3VDMrano2dzNZ'
    b'RElsd2I2djJDdTZVdHMxQitrZ3pGSEUvdWV0NU1HRFJvMGFOQ2dRWU1HRGZRdjhZOWpBNjAv'
    b'UjFNQQpBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpNdE1EUXRNRFZVTURZNk5UQTZO'
    b'VElyTURBNk1EQ29HSGVVQUFBQUpYUkZXSFJrCllYUmxPbTF2WkdsbWVRQXlNREl6TFRBMExU'
    b'QTFWREEyT2pVd09qVXlLekF3T2pBdzJVWFBLQUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAg'
    b'ICBpZD0iaW1hZ2UxMTUzMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_15')

JP_15 = b64_JP_15
index.append("JP_15")
index.append("Japan Niigata")
catalog["JP_15"] = JP_15
catalog["Japan Niigata"] = JP_15
country["Japan Niigata"] = ('JP_15', '', 1)
lookup["JP_15"] = ('JP_15', '', 'Japan Niigata', 1)
lookup["Japan Niigata"] = ('JP_15', '', 'Japan Niigata', 1)
details["JP_15"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_15"] = ('JP_15', 'Japan Niigata', 1)
regional["Japan Niigata"] = ('JP_15', 'Japan Niigata', 1)
#----------------------------------------------------------------------
b64_JP_16 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTc5NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1RveWFtYV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAgIHht'
    b'bG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3Nj'
    b'YXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5l'
    b'dC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAg'
    b'IHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAg'
    b'aWQ9ImRlZnMxNTgwMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzE1Nzk5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0i'
    b'IzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNo'
    b'YWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9'
    b'ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE1ODAzIj4K'
    b'ICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAg'
    b'ICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5k'
    b'ZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9w'
    b'bmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5D'
    b'QUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2'
    b'QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ3JGQk1WRVgvLy8vLy8vL3krZlQ3L2Z4'
    b'SgpxbHZjNzkrLzRjWm11SGFWemFBYWxERlpzV3I1L1BrOHBGRG04K2dsbVR1MzNiNk15Wmcv'
    b'cFZMNy9mdGx0M1Exb1VuMSt2Ymc4T01oCmx6ZVl6NkxCNHNlSnlKVmRzMjRtbVR2bzlPcjYv'
    b'UG85cEZFZmx6YTEzYjF1dTN5T3lwbFlzV24yKy9jM29Vc2JsRExHNWN6ajh1WWoKbURtRnhw'
    b'RkNwbFZldEc0MG9FamQ3K0FnbHplZjBxbTQzcitJeDVSVnNHWXBtei9zOXU3MysvZzRva3l2'
    b'MnJkMXZvUHordlF5bjBjYwpsVFBPNk5ObHQzVzAzTHgvdzR0bnVIWktxMTM5L3YxYnNtc3pv'
    b'RWowK3ZXTHlaZk41OUllbGpVNm8wNXh2WCttMWEreDJybTAzTHMrCnBWRys0Y1V0blVMdytQ'
    b'SEk1YzVqdG5KOHdvbUF4STEydjRNaW1Eamg4ZVFkbFRQVjY5blk3ZHlJeUpTTnlwalA2ZFJQ'
    b'cldIKy8vNVQKcjJWenZvR3MyTFdxMTdLNTNzQml0bkx1OS9Bc25FRXZua1R5K2ZNd25rVmFz'
    b'bW9ubWoyaDA2cUN4WTk1d0llZTBxZ2VsalRYN052Ugo2dGJRNmRWV3NHZE1xMTQ1bzAzNC9Q'
    b'blg3ZHVpMUt5OTRNTmNzMnl6MjdydDkrOHJuRUJ5dllEaTh1WDgvdjFIcVZsTHExM0w1OUNT'
    b'CnpKMmMwYWFCeEk2YjBLVkZxRmc3cEUvcDlld29tejR3bmtUZzhlUzczOEpwdVhpdDJiWFA2'
    b'TlB2OS9EcTllekM0c2pENDhsS3FseWoKMUsyUXk1dHJ1bnJuOU9tbjFyREg1YzJYenFGOXdv'
    b'cVp6Nk5BcGxNdW5VUHgrUExyOXUxM3dJV1V6Wi9GNU1ybDgraHR1M3VsMWE1awp0bk1ubWp4'
    b'TnJGL1M2dGRzdW50Q3AxVXFuRUNUelo1NndZZFRybVNpMDZ0R3FWbW8xckcyM2I3azh1ZDB2'
    b'b0pJcVZycDlldDd3WWlHCnhwTGU3K0YydjRSQnBsU3AxN0hHNU10Y3MyM2Y4T0xVNjlpV3px'
    b'QTJvVXFLeUphdzJyaFJybUtyMkxOUXJXRit3NHZUNnRjeG4wWk8KckdDcjJMVFc3TnBTcm1O'
    b'L3c0eHd2SC9hN3Q3SzVzOXV1MzFFcUZkVXIyYWEwS1JEcDFiWjdkMDVva3c3WmFxQUFBQUFB'
    b'WFJTVGxQdwovVnNxZWdBQUFBRmlTMGRFQUlnRkhVZ0FBQUFIZEVsTlJRZm5BdzROQUNoZGg3'
    b'ZlFBQUFGV1VsRVFWUm8zdTJhK1Y4VVpSekhIVkRxCkU0WWFDdDZ0R2E2cEhHWllDcHVwR3la'
    b'cEJpaENtd2RrRmg2SmlnWkZoeFJaaVdtbGxCMkdXYWdkaGgybVdha2RkdHRsOTEzL1NNL3MK'
    b'c2p2Zjc3UFh6RG83d3cvei9ZVjVQczlyMlRmUGZPWTVQa012cFVkV0x3Zkx3WEt3SEN3SHk4'
    b'RnlzQndzQnl0VUtUb1U2N0ZTZS9lUgpsTFJ6ZWdEV3VUaVBDK2w5a1dZNzF2a1pRRCttOUFj'
    b'R1hHQTNWaWFBZ1lPSWtKVXRsTUUyWXcyQldrT0pNa3dWaG8rd0ZXdmtoWDRzCmwrYjZVWDRC'
    b'RjltS05Ub0FnWXVEUXM2WWdPQWVheVBXSmVPNnNUQ3FXeGtmRkNhazJvZVZHNFJBWHNEMStR'
    b'VWhaYUp0V0pkQ3EwbCsKNVRKTktKeHNFOWJsVnhBc3YrdW5FQUZUYmNLYVJDRlUxeGNWVThG'
    b'enBTMVlmVnlZNWlJWVZ5blRTV3VHR3pPOWRtQmRqWkpaMXhDUQp2Tm1sV3VQYTlEbkFYQnV3'
    b'cmdQbUtlblhFNjV4NUxwTW1WeUk4Z3JMc1lTUDFEbDB2aHVSYW9Ib21naFVXbzYxc0h2RnFZ'
    b'cEVWWDJECjZQSE9oTzlHaTdFV2xXSnhZQ2RhSEFGcmliOXJxUWMxdFpaaTFkNFUyczNNQzZj'
    b'YW1CUG9XZ2JjYkNuV2N1Q1c0UFd0WVZqQnJyb1YKV0xuS1FxeVUxYmd0MUJpeFJxTFNOdEgx'
    b'd0ZvTHNkYWhJRjlycmVkVVpQTWxYTit3d1RLc2pUNk1KazF2RGNOYVRMcHU5NkRSS2l4dgpF'
    b'KzY0a3dyTmRBMHFvUnQ3WmFvNjZWcURkUmR3TjFmdUlWajNzcDVOTGFIbk1zbFk0dmxhd0JW'
    b'eHEwTFZHUDQzRExVRTZ6NVUzOCtFCjFnYzBxakNIZXpmRGxXOEIxb051UE1TVmg4a3QzS0lv'
    b'Ylh5QkZuTjlidkt4V3JmaWtYU21iTnV1VVQyNlNua3NleDMvaEZnMUgwODYKVnB1NmFXRzFn'
    b'd3pXVG5YUzk3U3ovaWRXU0E5dUVyQ2UzSTRaWE5sRnFNVEsvSlQ0OFRUZmxqNERQSnRrck4w'
    b'WS9ody9WNU9Ob05qSApwRTVRTHpya2VVNTZTTXpHMnVQRzg1SFAxV3J0VlpRWC9CY3RkZktx'
    b'TUMyWldDTUg0RVdlRVdWVmExU2QrNVQ5M2ZhWFhIOGd6SkNtCllyMEV2TXlWWVdTd090UTVy'
    b'ZnN3eGwxZlVXNHc4aktFOVVvR1h1VUszUVAyOWlvYlE5Tzk1UHFEa0crK2lWaXZvWXZuVmtV'
    b'bDVMVGEKcnRRMnNhR2pyajlrTFBJeWdsVUd0SEZsQ3htc0tyRmFabWhONlREMnVnOXZKQWNy'
    b'dlMvZTVPbFFNem12dnJWSkNJY0o1dHZ5enRGSQo1R1VBYXduY2UvZzU0d2loT0VyQ3djQk5Y'
    b'Y3BkMzJrazh0S1BsWldOT1Z5WlM2amVhZlZMUTRna3ViNERXSjhFckZ3VTd1ZHJYYm1HCjRK'
    b'NGY0UmgwakkvdElRT1JsMjZzZDRGNnJpd2pCS0Z4Zkk4RUVkSmN2NkVCNzV1TmxUTUd4MXVa'
    b'MGs2MnBGMG5RbkwvNks0L3FUL3kKMG92MUFUeXptWkM2bFh4L1crU0lVSEs5T0YwZTk1cUs5'
    b'V0VCUHVMS1lFTDFNVjFZK2tWMy9TbmdvS2xZallGNVNhc1RYZVRiUDJGZApuMFozL1JIWmIy'
    b'ZUhOU1VzMmNzazM3MmJkMzFXRU5YMXpRMDRhUjVXVWJGOE85SUlsYlF2VkgwWTFmVjc0ZnZj'
    b'Tkt6cDhrWkZyRU5hCmZSSDIxSDRaeS9XNklpODlXR0xwazRiK0swSWxuWVBVT2gzZDljdjFS'
    b'VjQ2c0dwcnNISWZVOGdyRktDcEtyeXlvN3YrYTZ4T01RWHIKR1BCTjlNZ2hiblZXeUVPLzFn'
    b'd3NzZlIvV3lzL2wwWktNc0IzZWlLditGZ0gwTUR6NG9naGJvenlmYzgvZmtaSDVCVVhTeHlt'
    b'Rm5LbApFZ2JyQno3WVArcUl2T0poZVRlcnVRS3RueHFNWXVHVW5GTG5EVHBMckhyZ3RIeFlN'
    b'RnlTNnhlVnhvMjg0bURWdGVCbmZndU9Jb0dTClhQOUwzTWdyRHRhdmNQMG1oNDRKbE9UNm9q'
    b'TWtQMDhBNjNjM3huUGxEeVJVa3V0M3hvdThZbUtsL29tU1dVeUo4a0xNcU91VnYrSkUKWGpH'
    b'eC9sWmZxVExPZnhLa1VtTVRXditXeG82OFltRnRXNlA5MjBXZ0RpUGhxcFRQNHpFanIxaFlP'
    b'OFNSL1Q5V3JzU3hmUHczaVpVaQpNekdzc1c0a3Q4b1N3bXJlbGVScU52VjFnUlhsWURsWURw'
    b'YUQ1V0E1V0E2V2c1VUFWcytzL3dFWXViSlh2T3ZLZ2dBQUFDVjBSVmgwClpHRjBaVHBqY21W'
    b'aGRHVUFNakF5TXkwd015MHhORlF4TXpvd01EbzBNQ3N3TURvd01HR3FTWjBBQUFBbGRFVllk'
    b'R1JoZEdVNmJXOWsKYVdaNUFESXdNak10TURNdE1UUlVNVE02TURBNk5EQXJNREE2TURBUTkv'
    b'RWhBQUFBQUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJpbWFnZTE1ODA1IiAvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'JP_16')

JP_16 = b64_JP_16
index.append("JP_16")
index.append("Japan Toyama")
catalog["JP_16"] = JP_16
catalog["Japan Toyama"] = JP_16
country["Japan Toyama"] = ('JP_16', '', 1)
lookup["JP_16"] = ('JP_16', '', 'Japan Toyama', 1)
lookup["Japan Toyama"] = ('JP_16', '', 'Japan Toyama', 1)
details["JP_16"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_16"] = ('JP_16', 'Japan Toyama', 1)
regional["Japan Toyama"] = ('JP_16', 'Japan Toyama', 1)
#----------------------------------------------------------------------
b64_JP_17 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4NDMyIgogICB3aWR0aD0i'
    b'MTQyIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0MiAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSXNoaWthd2FfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzODQzNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzg0MzQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnODQzOCI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNDIiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSTRBQUFCa0NBTUFBQUJuL1BqZUFB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNuVkJNVkVVQWlMc0lqTDBlbHNNeG44Z3oK'
    b'b01reW44Z0JpTHNpbU1TRHhkN001L0g3L2Y3Ly8vK2kxT1lhbE1LZzArYjkvdjdzOXZvVmtz'
    b'RlFyZER0OS9waHRkVnB1ZGZCNHU1agp0dFg0L1Awbm1zVTNvc3I1L1AxL3c5MEhpNzNWNi9U'
    b'WDdQUit3OTMrLy85Q3A4MGptTVQzKy8yZDBlVzMzZXk4NE8yQnhOMWt0OVpWCnNOTGY4UGJx'
    b'OWZrVGtjQlVyOUg2L2Y2S3lPQWhsOFJOck5CZHM5UU5qcjdqOHZqVzdQVGQ3L2E3MysyTnl1'
    b'SFU2L1FTa01COXd0ejIKKy8wa21jVXVuY2N2bnNnZmxzUDErdng3d2R6RjVQQ0x5ZUMyM2V3'
    b'R2k3M2k4ZmNNanI0RmlyeVd6dU03cE1zVWtjQlJydEZKcXM1cwp1dGgzd051SnlPRGM3L2Fa'
    b'eitTYzBlV3ozT3R4dmRubjlQa1JrTUNVemVKWXNkSUVpcnpTNnZONXdOdXgyK3B6dnRvT2o3'
    b'L2s4dmdZCms4RWNsY0x6K2Z4QXBzeVZ6dVB3K1B1czJPazVvOG9ybk1idTkvb1drc0hUNnZN'
    b'SmpMMW91ZGVHeDk4ZGxzT0N4ZDdKNXZFQ2lid2wKbWNYQTR1Nk15ZUJ2dk5sSXFzNzgvdjds'
    b'OC9nUGo3K1F5K0ZPck5CWnN0T20xZWRXc05LazFlY1hrOEdUemVLNjMrMUhxYzVmdE5RSwpq'
    b'YjYrNGU3SDVmRGE3dlV3bnNpNTN1eDF2OXBtdU5Zb204WkdxYzREaWJ6SzV2RTRvc3JvOVBr'
    b'UWo3K28xdWh3dk5uaDhmZWwxZWVhCjBPVFk3ZlZldE5RL3BjengrUHM4cE10OHd0ekU0Kzl1'
    b'dTlqUjZ2UDArdng0d052TzZQSlRyOUZMcTg5eXZkbk42UEt2MnVxUnpPTHAKOWZtWHp1TUxq'
    b'YjZiME9TbjF1amc4ZmZiN3ZXSXg5OUtxOCt1MmVtU3pPSXFuTVlwbThhcTEraEZxTTJGeHQ3'
    b'eStmd2JsY0xHNVBCbgp1TmJRNmZLWXorVHI5dm8wb01rZ2w4UjB2dHBndGRYditQdDJ2OXBx'
    b'dWRldDJlbEVxTTJQeStHajFPWlhzZEo2d2R5RXh0NXJ1dGcxCm9jbTAzT3MrcGN4U3J0RmJz'
    b'dE9lMHVXNDN1eE1xODhabE1Jc25jZlZJbGNMQUFBQUFXSkxSMFFMSDlmRXdBQUFBQWQwU1Ux'
    b'RkIrY0QKRGdzc0JyenRyUU1BQUFTQ1NVUkJWR2plN1ZyNVgwMUJIRlhxUlZlOVNQWlV0b29v'
    b'KzFvb1BKS3l0QkJKSlVLMmlDZ1NSV1ZYWkMvNwpsaVg3dnUvN3Z2TzMrT0hkTzk5aDdodjNU'
    b'bTh1UDh6NThYek9uVGx2N3JtemZPZlZxU01nSUNBZ0lDQWc4Si9Cd2JHdWsyWTRtN2g2CmNh'
    b'bFgzMVhTZ1FZOHpiaTVteVZkOEdqSTBVMGpUMGtuR25OMDQyWFc2NllKeCtRMDFXdEdhdGFj'
    b'bjVzV0xYWGJhY1hQalhkcjNXNTgKdlBuWjhkWHR4cThOUHpkdDIrbTIwNTdqVjlVQjc4anNI'
    b'eERZVVIyZGtDaW9NejgzWFRBendTRmRiZXE2Z2F3N1B6Yzlla0kzdlp3cAp5MWx2Sk92RDhW'
    b'WDFCVGY5K2xOMEE1QXNOSXlmbTRHd2FnWVBvdWdHaHlOZEJEODNwaUV3T0VOcHVtRXdoaFpE'
    b'Vm9maEkyekxJa2ZDCnB4ZkZ6ODBvRDdBVGpjVTJadlFZSEdQSGdTeVdZNDdqb0p0NGVERUps'
    b'TTNHK0FuODNFVDVvVzdDWWNKSnBNM0hFL201bVpRRTNVeEcKYkRUTlRUTEhWelVGbXdEUjU1'
    b'S1NTbkdUbXNiUHpkUjBXS0duSVhZNnhVMUdYWTZETTBQdFVEQ1Rza3Z0Tkl1am14am9KM08y'
    b'UWxybQoyRFFUbkpqQzBjMWNXQktsZVlpTnNHV20xL3dzcm9lOEJkRFZ3bXlGWEFRN3NjV3hD'
    b'bklDbGl5ZHl2bjRpM1djaXdKcThrZGszakpEClQrUFFzYlFja1kyQnpEZlV6UXBzMmtmak1D'
    b'b0lrUVdHdWtuSkF6c3JFYnNLY1o2Rmh0b3BBamVyRWJrR3lHSkQzVGpucWh4dVMyQVgKVVdv'
    b'eTBrMzJXclhEYlFpczdtME5IUnd2Y0xQT1FTSFh3Nlk1cUErR0RRVWJzVWxuMmlZRVpabWJD'
    b'TlJtRmplek04SE9Gb1VzSzZkVQpLOUJHTVMwRE5xbGJyZFFXMEcycllMSFRBQnJZanNnZHRG'
    b'M09Ua1cxQzdqZDhpSzNCNmk5TEc0cVlRdFk1YWFRanVrME82R3lhaDg4Cm1pbVg0dmFENmdE'
    b'TEIyREJxaWNIRVJ0UHJSRDR5N3ZIUThTcTYzZ1kxcHIxTElOekJKbzhXcWFReCtnRmkrTlcx'
    b'UWxncXVWSFR3SjEKaXNVTjluUE1NeEZiVG5XelFVdU9UelBsT0JrYU9JUElHcXFiZG1GRWpz'
    b'K1NPV2FheVBPeG40T2RtTTZaLzE0R3BPZDRDRXVPYTg3YgpLTkwwY1BrZFkwQjN3WUhJc1pm'
    b'MW9hemE1dmlpeHJvd2ZycTVaRFBIbDRHNnd1TG1hakI2dnVVMW12QVVkSFRkeWhSbUVKL0Fq'
    b'VnJtCjJGUUtEZHpVV1BTNWRmdlB2WkFVWjZjY0YyUFRmZzF0eGI4RHdoTTJjeHhSeXh4UE9B'
    b'ME5kS01KNzRKdVRxUTF4L2ZzbitQNzBPUmwKbXE3ekF6Z3NWMXFwQlB2bitDSE1MZUdQYUVK'
    b'M0lpWllqdjNzbE9PeWFtamdNVTJJeGNTem9aWWNQMkVabklOWXdUYVNWdlRCcHJ0QQpiamxP'
    b'ZTZwV1BWSEJNK2lvUEp2SThYTXl4MHhGbG5NYTd6ZXkwb21PRXNndHlRdWdpbGpjdkpTSVFL'
    b'Z0QyOEM4MHBSamx0S2x4UWNhCmFFb1RMaVVQeTYrSmNhMTFqbjNWcWlkL0tmcThJWE1zVjZY'
    b'ZUV2SFNCK3dDelpVNmc3NlQvcnlXd1hQOG5zaXgrUVBMNEh5RUpuT28KUlo5bXNPSnZKZzQ4'
    b'S2psT1pIR0RYYUQxSEtHeDZCTWc1eGliSHo0Uk9mWmd1ZlhETDlBKzA0UmZRSGUraE1qeFZ6'
    b'TEhUSDgwd0M3UQp2bWt0K253bmNsejF3ejQ1L2dsYndGQVhqVVdmRi9JNlovOGM0eGRvYjJs'
    b'Q3AxeGl4Y2R5bkRTSnFJMHo1YmdDdTNxbTN0TTVnVzZyClVnOERTajVyV2JEV21NNTVBZ0lD'
    b'QWdJQ0FnSUNBdjhHdndEUFRXWDFndFZtSkFBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1q'
    b'QXkKTXkwd015MHhORlF4TVRvME5Eb3dOaXN3TURvd01GOWVGTzRBQUFBbGRFVllkR1JoZEdV'
    b'NmJXOWthV1o1QURJd01qTXRNRE10TVRSVQpNVEU2TkRRNk1EWXJNREE2TURBdUE2eFNBQUFB'
    b'QUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJpbWFnZTg0NDAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'JP_17')

JP_17 = b64_JP_17
index.append("JP_17")
index.append("Japan Ishikawa")
catalog["JP_17"] = JP_17
catalog["Japan Ishikawa"] = JP_17
country["Japan Ishikawa"] = ('JP_17', '', 1)
lookup["JP_17"] = ('JP_17', '', 'Japan Ishikawa', 1)
lookup["Japan Ishikawa"] = ('JP_17', '', 'Japan Ishikawa', 1)
details["JP_17"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_17"] = ('JP_17', 'Japan Ishikawa', 1)
regional["Japan Ishikawa"] = ('JP_17', 'Japan Ishikawa', 1)
#----------------------------------------------------------------------
b64_JP_18 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3NDcyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRnVrdWlfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzNzQ3NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzc0NzQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNzQ3OCI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNjMUJNVkVVQUFHc05EWE5KU1pWNWViR28KcU0z'
    b'R3h0N2s1Ty91N3ZYLy8vOGRIWHh5Y3EzRXhOMzcrLzNEdzl4eGNhMGNISHRGUlpPenM5UDkv'
    b'ZjZ4c2RKRVJKSkRRNUxIeDk3Rgp4ZDFCUVpHc3JNK3FxczRiRzN0VlZaenQ3Zlh3OFBabVpx'
    b'WUhCMitkbmNhWm1jUUdCbTRTRW5YQ3d0d1FFSFFaR1hyVDArWFEwT1FYCkYzaE1USmRkWGFG'
    b'ZVhxSk5UWmllbnNmUjBlVFMwdVZaV1o4RkJXNWFXcCtibThYbDVmQUJBV3dDQW14V1ZwM201'
    b'dkNZbU1PY25NWVIKRVhYdjcvYjYrdnhsWmFab2FLZjE5ZmxHUnBTcHFjMUNRcEZLU3BZL1A1'
    b'QmdZS05qWTZRbEpZQzd1OWpjM092MzkvcWtwTXFscGN0VQpWSnhjWEtBc0xJVW9LSUtVbE1I'
    b'QXdOcFRVNXNVRkhmMjl2ckl5TitLaXJzOVBZNERBMjArUG8rTGk3ekp5ZUFURTNibzZQS0Zo'
    b'YmdlCkhud2ZIMzJHaHJucDZmSzl2ZG44L1AyZ29NZ0xDM0YrZnJRRUJHMkFnTFVLQ25ITHkr'
    b'RXBLWU1xS29QTXpPRTdPNDF6YzY3ejgvaHcKY0t4blo2ZisvdjdCd2R2WDEralcxdWNySzRU'
    b'MDlQbDlmYlRyNi9PWGw4Ti9mN1VuSjRMWTJPZ0pDWEQ1K2Z6eTh2ZVdsc0o0ZUxGMwpkN0NK'
    b'aWJ2UHorUHg4ZmV5c3RJd01JY3pNNG1ucDh6bjUvSGYzK3k2dXRld3NORzR1TmE4dk5qZTN1'
    b'emg0ZTdVMU9ZeU1vZ0lDSEF1CkxvYjQrUHQyZHE5MWRhK2ZuOGN0TFlWUVVKbFNVcHRZV0o1'
    b'OGZMTjZlcktqbzhyczdQUzN0OVhpNHU0UEQzUzF0ZFJ1YnFzaUluOGsKSklCc2JLb1lHSGx0'
    b'YmFwWFY1Mm1wc3Q3ZTdJYUdubzVPWXlIaDdrMk5vcEhSNVNSa2I4MU5Zb09Ebk5QVDVsT1Rw'
    b'aU9qcjNqNCsrTQpqTHhiVzZDL3Y5cWFtc1E4UEk1a1pLWE96dU9JaUxycTZ2TVZGWGV0cmM5'
    b'dmI2c01ESExWMWVlaW9zbXdJSy9iQUFBQUFXSkxSMFFJCmh0NlZlZ0FBQUFkMFNVMUZCK2NE'
    b'RGcwQ01RdmFmWklBQUFTelNVUkJWR2plN1puNVYxTkhGTWNITU9FcG16eXdpQVVES1VSUmtX'
    b'cFEKUVV2QjBLbzFCaUVSaXBWMEUyTUFLN2lWSUcyMU5yUzE3bFd4clJzdFZLMTBCMXEzRnV5'
    b'QzNhaitTZTFMM3AyWmx4Y1NmcG1KNXpqZgpIMkRtemozbmZzNjhsNWw3NzBOSVNFaElTRWhJ'
    b'U0VoSVNPaFJWVng4d2pTRE1WR1NFbzJHYVFueGNROEQwL1FaU2NtU1Jza3BxV2t4CmhwcVpM'
    b'a3RoSkdka3hoQnExbVBTcE1xYUhTT290R3dwb3VZOEhndXFuRndwaXVhYXVFUGw1VXRUa1Br'
    b'SnZsUUZXZEtVVkdqaFNUVnYKdmpSRkZTM2d1RmRhcXR6OGhZdGdYTHk0SkZHeitDUzMvY3BM'
    b'b3VNdVdXcEZLQjVtOFFoWlN6WFVoYnplcjJWVTBPVTVLeFFUallWUQpXZmxLeW1VVkg2cEZW'
    b'TWluMUVla3hVS29vb1J5V3NybEVud2F4NnVzQW1Nb0ZrS3J5VTJaeU9OY0pXZTdqVng4ZWl4'
    b'VWJjT096N0NuCmVwYnMxUm9VQ1FzdEpQdTFsam1XQWNkYWh5SmpvZWV3YXhKcnF2VjJ1MkdE'
    b'UXdsVmc2SmhvWTJLeGJIQllMZXZaNHhWYXpMVlpUcGQKdFp2cUxkR3hMUFdiR2x6T3pEcVRx'
    b'WUV0MWZPVmdlQ05tMS9ZMGhRZHE4bjk0a3VPNEh2NE1sTXNFem1OWG5sMWEyU3M1bTBlNGwz'
    b'RgpGR3M3ZmExNFM5SW14NXJlNHFWOTdTeXBXcjNhL0tDeGJVZDRMT3RyanBDNll5ZERyQzI2'
    b'eEtXOUl4eldydDA2eHowTXNmYnFFNnA5CmkvVlkxWFAxZnE4enhOb1lKdEh6ZG9aaWRYckR1'
    b'TlV3eEVvSmw0RDZURnFzZFdGTHh5NkdXUHZoVmZkcDlxdUJ4c3JSVVBrYTFVRTMKUXl5b3dX'
    b'cWEyenowKzlWQnNONTRrMXJ3dk5VTXovMEFReXpJQ1E0aXRQUHRSaEsrKzVDYXhkaGM3eENy'
    b'cmMyUGtGbWQ5RERFZWxlTgo4WjR5NlNnaUJOdmVELzQvL0FHeEhYRXBYb0IxbENHV1IvT3ph'
    b'ajFHY3EvamdWM2FmNExrV1BYQmh0SkpkWHFLSWRhSGFvelQ2bG1lCmdTR3lpNVcvZFdldzRh'
    b'eDZyUGVxODNNY0RvaVAxTG4vWS95TCsrUi81SE1uOEM5MC9ublZ4UWgxR1lkU3pBZkoxb1dM'
    b'dUFhNkpFbVgKKzJEbStCUXFYUUExTThTYUFXRS9BOHRsc0J4MXliSnJIOHoyd25vL1dGSVpZ'
    b'bFZMNUlRSTZ2d3BNQTEwMWRmQmVHVWVySzhDRTh2MgpvQitLckZ3Y053SGk5bjErNVNxTUQr'
    b'Tyt3RFc0Ri93c0U2NHZJSEE1enRmaFZMMisxZzJ2dDIwUVZrdkIvMHVtMmVsWCtLeGNBYVow'
    b'Ck1IMzlEWXpPd0ZyWkVqQjl5eFRydXg2SWt3T21WTERNbmdXajcyRnRDQ3c5ak50Y3d4RElD'
    b'QS9LRFpiTzFhR1o2T0J5SHRtV29qMzQKR00rSFdnSU1DU013K2tGZHdzZVk5Q1Byc2pvcnRN'
    b'Ynl3L3pHRFJoWmd5dFYyRFdGZVEvaUpzN3lMdDRLWG93d3YzMGJSbVdCaFZ2NApCcER2c0cv'
    b'WnRKQnliR2FndzZiSCtpbHc5Sko4cklWSGw1bTBiSHVVNTdoTGozVklxVE1xU2R0dEhvOTI0'
    b'TTlVSWw4eWlHcjFXQTNJCjBrZWw4Nk44bXFkalZMWitkOENaSVd1eDVBeG5xWkZ5K1lWVHA5'
    b'bmFSZGMyUjBxZEkrMHlZTW50VjV5L0Z0SHJ2MWw1TmViak5tdEsKd0d1LzkyOGR2emN5T2pw'
    b'eWI3eTVmNW4yRTVXQjQ4ZFl5eCtoMWVuMTN1R2hvZUhldTZIMjNWdy8raFNjMXRmTjVKVW5P'
    b'bHVCdUtycAp6NmxnbVhjZzNobzRFQTNycjNJVUExV1lmUkd4NXZ5TllpUDM5c214ZXQwb2Ry'
    b'cjVUM0k0ck9Uc095aTJLaWhPcjlSaWVaTW1GcUNIClFQK09UMXd0N1BhTWpYbnVGejZZR0c5'
    b'RlFrSkNRa0pDUWtKQ1FrS1BxdjREREFnS0ozdEh3RVFBQUFBbGRFVllkR1JoZEdVNlkzSmwK'
    b'WVhSbEFESXdNak10TURNdE1UUlVNVE02TURJNk5Ea3JNREE2TUREd3g5eHpBQUFBSlhSRldI'
    b'UmtZWFJsT20xdlpHbG1lUUF5TURJegpMVEF6TFRFMFZERXpPakF5T2pRNUt6QXdPakF3Z1pw'
    b'a3p3QUFBQUJKUlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTc0ODAiIC8+CiAgPC9n'
    b'Pgo8L3N2Zz4K', 'JP_18')

JP_18 = b64_JP_18
index.append("JP_18")
index.append("Japan Fukui")
catalog["JP_18"] = JP_18
catalog["Japan Fukui"] = JP_18
country["Japan Fukui"] = ('JP_18', '', 1)
lookup["JP_18"] = ('JP_18', '', 'Japan Fukui', 1)
lookup["Japan Fukui"] = ('JP_18', '', 'Japan Fukui', 1)
details["JP_18"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_18"] = ('JP_18', 'Japan Fukui', 1)
regional["Japan Fukui"] = ('JP_18', 'Japan Fukui', 1)
#----------------------------------------------------------------------
b64_JP_19 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjg0NyIKICAgd2lkdGg9'
    b'IjE0MyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDMgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1lhbWFuYXNoaV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAg'
    b'IHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lu'
    b'a3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdl'
    b'Lm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'CiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAg'
    b'ICAgaWQ9ImRlZnMxNjg1MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5h'
    b'bWVkdmlldzE2ODQ5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3Nj'
    b'YXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1v'
    b'ZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE2ODUz'
    b'Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE0MyIKICAgICAgIGhlaWdodD0iMTAwIgog'
    b'ICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1y'
    b'ZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFn'
    b'ZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFJOEFBQUJrQ0FNQUFBQ0lQ'
    b'cFBnQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFB'
    b'Q0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ3BsQk1WRVdaQUdhYUFtZXBLSDY5'
    b'V3B6SgpkNjNRaXJuV21jTEplYSsvWUtDckxvS2JCR2l3T1lqVmxzRDM2L1AvLy8vNThmZmFv'
    b'c2UxUjVHWkFXZXZONGZrdk5mcnpPQzJTSkdkCkNXdlJqYnYrL2Y2Z0VYQ2dFbkhueE56eDNP'
    b'cW9KbjJpRjNUdzJlajM2dktwS1grZENtenB4OTMwNCs2a0hIZlhuTVRsdmRlMVJwRC8KL3Y3'
    b'RGFxYWJCbXJ3MnVuc3orTENaNlNzTUlPZkQyL0RhS1RzME9QNThQYWlGblBJZGF6Njh2ZThX'
    b'SnU5V1p2Njgvalhtc0tuR0ZpbwpHbGVxS24vMzdQVCsvUDJ0TVlQWW5zWDRwd2Yvc3dDMFE0'
    b'NnRNNFhVazc2N1Zwcm53dHI0N3ZXaEUzR2JCR1MyTTBtd0tFL3o0dTdGCmJhZWhEbDdwakJi'
    b'RWE2Ykxmckx6NE96djErZWJCV21hQTJqdDBlUDc5dnFsSDNuTmdiTzJTWkt6UW83YnBjbWxI'
    b'WGY3OWZua3U5YmYKcnM2eFBZdmRxY3Y5Ky8ycUs0Q25JbnI4OS9ycnp1S3hPNG5Ua2IzUGhy'
    b'YkFZcUhxeStDZURHMzE1ZS8yNmZMQ1pxUEViS2ZxamhXLwpYNS9RaWJpZkRtNzE1L0h2MXVh'
    b'dkoxRDVxQWFkQm1LY0JXUDRxQWV3S1UvcHlONzkrZnVwRzFiMm93bmpnUnljQm1Pdk9Jamdz'
    b'ZENuCkpIejgrUHZodE5Lb0cxZjFvUXIvc2dEamdoemhmaDZxSFZYaHRkUHpuZ3pBUkQvOHJn'
    b'UGpneHo2cXdYOXJ3TEJSajd4bWc2akdIUzEKUlkvU2o3eWxGVnJ5bkEybUYxbTNORWpoZng2'
    b'OVAwSy9SRURmZXlDNU9FYWxGRnJLZTdEdTFPWG1oeG1sRmxyZGR5SytRVUg5c0FLYwpCMnJ4'
    b'MittaEZITEhjcXE3UEVUOHJ3UCtzUUc2VTVqVWxMK2hGWFA1Ny9XZUNXSGp1dGJoczlHNVVa'
    b'Zm13Tm45K3Z5cEozMmZDMkQzCnBnamZmQ0R4M2V1Y0NHdTdWWm5TanJ1dEkxTDRwZ2ZGYjZu'
    b'eTMrejQ3ZlNwSFZidDArV2pHbmJCWTZIQlphUFpvTWJnc3RHdk5vYnQKMHVUb3h0Mi9YcDYr'
    b'WEozMDVPL09oTFdtSVhyZXJNMnpRWTNXbU1HakdYVzZVcGZUa3I0bStMSGFBQUFBQVdKTFIw'
    b'UU9iNzB3VHdBQQpBQWQwU1UxRkIrWUJIZzRrSG9BV3F1d0FBQU5uU1VSQlZHamU3WmozVzlR'
    b'd0dJQURDQWhDR1lvQzRrUWNxQWppUkZTVUtDcDNJS0NBClcxRkJuRGh3c1ZTR2V5S0M0RUFV'
    b'VkpaN1Q1WWJCKzZ0LzRtOWU4eDNCNzJCTmkzNlBIbC91R3Y2ZlduZXRFMlRGaUVHZzhGZ01C'
    b'Z00KQm9QQllERCtkMHhNelZxWlcyZ3d0Mnh0WmQxaU5tMXNiRGtoZHZZT2ppMWgwN1lkcHcr'
    b'bjlyTGJkSEIyNFF4Zzd5cXZUa2MzempDZApPc3VwMDZVclo0eHUzZVhUY2UvQkdjZWpwMncr'
    b'dmJqbTBGdXVZZGJIczFrK1hGOTVkUHIxMXpUcE5jRGJSeXZrNHozUVZ4TWNORmdXCm55SFE0'
    b'TkJoT3NMRC9TQStRcGF4WlVlYXN6V0ZuZjRqL1dGNzFHaVNFREJHQnAreHBEVVhyYWR3SUE3'
    b'VUZNWUZrQlEzNlcvcDhmQmMKRGtKNmZGQVFYTEVKVXVzNFRpUk5UUXJtaXdxbE1rVExKMFNw'
    b'VlBCL3JqRFBocnBMN0dNR1haK3NLb1poSEs3bEU0NXhtT28vQXJLbQpTRHlOVGlVTlJVWVo4'
    b'SW1lUnRLbXo1RFVaeVowZkJZeTRJTm1ROTRjS1hYbXppUE54Q0NEUG1nK1NmUmNJS0hQUXRK'
    b'S2JKd1JuMFh4CkpIV3hpV1E2UzJEaVdvcU0rS0JsY01XV1M3WjZYOUZvckJ2MlNWaEprbGY1'
    b'U09TekdycThCbWw4RXJWOEVqVSthQzFrcjVOR1ovMEcKMHNER0tMSXZDZVBrRlBCSlRjTjRF'
    b'enc1TjVQMExkS3NYWjJod3pCeHBXZGdqRE96ZnZ0a1pmS2xqSFFTM0FwMzJ6WXBkTGJ2SUlm'
    b'ZgpTWGJ0Mm8zeEhvejNwcWg5VXZlcFN4bjdTZGdlT3VBZ2djK0JwbU5kclpOOU1BZmpReW01'
    b'T0ZlbGszYzRYMHVvd0U1NGdhbHhCRHA3CmxPdzZkaHhuRjZJVE9iam9KSCtoVGhYanZCSjBP'
    b'aDludzFMb1RPUEpqaWJXWndWakhhSEMwakwrdDZTOG9wTDNxYXdvTCtGTFphV0YKRUQ5M0hp'
    b'cGRvT3h6RWJvYUlZaGQ0blV1WTN5bFFoQzVDcld1MGRXNWZrUC9yYURTS2JwWnJGUG9GaXhk'
    b'cmFqNldBakhlaU9kVktUUQpLUlFYQzI5ak5IVzhZVVY4VzQ4TzBpTmtBeDI1UTlIbkxqbm92'
    b'ZnROSWxYVkdOY28xSnVLR295cnE1cCtlSUNYamRvNmFqb1BvSk1QCkJiRkhqOVZuUnkxVW5K'
    b'd2tpRCtCdXBhMGRPcWVra00rQ3haRzZ4V3dxYWpYOGFCNFRpcjd2YURrODdLVzhPb3ZhanZB'
    b'Q1dyNE56NTYKdm9hbDZ4c3FiMXdOTWVKNEN5Zm9IWTNYMWZjY1BUNVErQllXU3RIblk0Sm9u'
    b'MDhjVFVTUCtjL3hWSDJjeFBwOG9hckRSWXJVK1VwWApoL3NtVGlmYWw2Nk94M2R4UGo5cWFl'
    b'TDFzd0F4R0F3R2c4RmdNQmdNQm9QQitITitBVk5DYUR2TzdqL3lBQUFBSlhSRldIUmtZWFJs'
    b'Ck9tTnlaV0YwWlFBeU1ESXlMVEF4TFRNd1ZERTBPak0yT2pNd0t6QXdPakF3NFhIdTZ3QUFB'
    b'Q1YwUlZoMFpHRjBaVHB0YjJScFpua0EKTWpBeU1pMHdNUzB6TUZReE5Eb3pOam96TUNzd01E'
    b'b3dNSkFzVmxjQUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAgaWQ9ImltYWdlMTY4NTUiIC8+'
    b'CiAgPC9nPgo8L3N2Zz4K', 'JP_19')

JP_19 = b64_JP_19
index.append("JP_19")
index.append("Japan Yamanashi")
catalog["JP_19"] = JP_19
catalog["Japan Yamanashi"] = JP_19
country["Japan Yamanashi"] = ('JP_19', '', 1)
lookup["JP_19"] = ('JP_19', '', 'Japan Yamanashi', 1)
lookup["Japan Yamanashi"] = ('JP_19', '', 'Japan Yamanashi', 1)
details["JP_19"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_19"] = ('JP_19', 'Japan Yamanashi', 1)
regional["Japan Yamanashi"] = ('JP_19', 'Japan Yamanashi', 1)
#----------------------------------------------------------------------
b64_JP_20 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDk5NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05hZ2Fub19QcmVmZWN0dXJlLnN2Zy5wbmciCiAgIHht'
    b'bG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3Nj'
    b'YXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5l'
    b'dC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAg'
    b'IHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAg'
    b'aWQ9ImRlZnMxMTAwMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzEwOTk5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0i'
    b'IzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNo'
    b'YWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9'
    b'ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzExMDAzIj4K'
    b'ICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAg'
    b'ICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5k'
    b'ZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9w'
    b'bmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5D'
    b'QUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2'
    b'QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQjExQk1WRVgyWmpmM2ZGUDZxWTc2cG9y'
    b'NApqMnozZUUvM2NFVDh6OEQvLy8vLytQYjkzOVg3dUtMNWtXLzJiVUQzYjBQNm9ZUDh2S2Y1'
    b'b0lQMlp6ajZxWS8vKy9yLy9QdjkyTXo1Cm9ZWDRqbXY4eTd2Lyt2bi8rdmo4eXJyNGpXcjRo'
    b'bUgrOGUzOTNkTDk0dG41bVhyM2VsSCs2ZUw5NDlyM2RFcjRqR244eDdiLy92NzgKeUxqOTJz'
    b'LzgwY1AzZDAzNnBJai85L1QrOXZQNm9vWDJia0g4eXJuOHpyLzNjMGYrNk9INGcxMys2ZVA0'
    b'Z2x6NGptei85L1g0ajIzNApoMkw1bkg3NW0zMzZxcEQ2cFluLy92MzZwSW44ME1MNW5vSCs2'
    b'K1grNk9EMmJrTDh5N3o1b1lUMmFEcis2K1QzZFV2Nm80ZjJhVHYrCjdlZjRpMmoyYkQvKzlQ'
    b'RDk0ZGo1bEhQNWtuSDd2Nno5M05MOTNkUDRpR1A2c0pqM2YxZjZvNGIrNyt2OTJjMzkxOHY4'
    b'eWJqNWtuRDQKa0c3M2VsTDd1YVA3dDZIKzlmTDkzdFQ4eDdYM2RrdjZyNWYzZGt6NW1IajVt'
    b'WG45NE5mNWxuYjVsM24zZDA3NnNKZjd0cUQzZTFMOQoxOHI1b0lMKzhlei8rZmYzZjFqNnNw'
    b'cjRqR2o5M05INGlHVDVrM0w3d0szKzlQSDRpMmY4eHJUMmFqeis3K3IzZEVuOHlMZjZySkwr'
    b'CjUrRDRnVnI4ekx6NW0zejVtbnIrN09iNWwzZjZySlA0aVdUM2ZGVCs4dS8zYzBqOTROYjRp'
    b'bWI1bjRMOHVxVDVub0QzY1ViM2ZWVDYKcDR4czhwcHRBQUFBQVdKTFIwUUlodDZWZWdBQUFB'
    b'ZDBTVTFGQitjRERnc2lEaXkxQ0w4QUFBUHNTVVJCVkdqZTdacHBWOU5BRklZagpGcHl5YVV1'
    b'S2hZSlFaU3V5bFdvRmlpS2dVQmRjRUJSVUZDeFNWQlFYQkZIY1FObGRjTjkrcklYVFNTYUIy'
    b'eWFUU2RwenlQT3g3MXg0ClR6c3o5ODZkNFRnVEV4T1RiY0NPbEoyVzFDVDBsYllMSVd0NlJt'
    b'WldJazFrNzk1ank1WitaTS9oVVFSSDd0N3NCSmx5NXVWSERMZ0sKQ3FVZjd5dENHMndTRE1G'
    b'U2pERHUvWFpTT1ZBQ0NBWjhVNldJeEMzNVlzcmNvbEJ1b0tteUNnK1NVVmxHenJtRG9sQlZi'
    b'WlNybWxxMAptVG92NmNzTkNQcFI3ME5iY3loTkhIVFlEd2g2Y2FRQlFaUTBFaHRyRVNINEcv'
    b'VjIxUlJBTU5abWNlQlJuaFF5OVhWMXpJRml3YmVJClE0OURBbnRhMjFCczJ0ckYvZjRFSURD'
    b'bkpaNHJoRHdueGZ6WUFRaXM1eFdQNHVNUXA1RUZFdGl1UVN0U2dsVmNkbmtTSWFETGVzenEK'
    b'Uk1wb0NBclpvQTRRR0ZLSmxISnE2OVZJQ3V3eURsTE9hUngwNXF4VVlKNkhaTDlIYkdxN2NO'
    b'ZzVTR0NFRDZtaEFvZWR2d0FJYkxqbwpVV1VMT1hGZ2lreGdXckhhUzlXNVFtNWNsblpma2dv'
    b'OUxPdlZYcVNXeXpqMENpUXdvRSsxclg0Y2VoVVNHRlR1U0QxQ0VkK3AyK3pLCm83RGx3OEhY'
    b'SUVFclFSZUZMUmZPTk5kbFFqNnJjKzBBb2tIWTZtOUFna1p1VXRrYXhPRkRrS0N4ZEhCUTJl'
    b'SnhlOFFMQ2RxNGhlZ0kKUmVPSElVRWJ0eWx0amVBL0VJWUVUYVJUMmhJMnpsR1pNTW9rSDFv'
    b'cGJRVncrcnNqTDZ0WjVNVlVSTXZkNkYrNEp4ZkdHTmhxcHJhRgowOHg5c096UndJTnhXaDdp'
    b'STVOY2VHUTJ2MDFNVExZaFNicWRXdGduSHhhSG44ZlV0bkFmNUFtVXd4TmIyRlJBUWtMS3dH'
    b'S29ER1J6CnNNNmd0RFVCRmMwVFRHeGxVdHJDVnhwUElVSGpnWXpYZGlBYjBPZEF4dVZTMlpx'
    b'RUdvbVRqRFpVTDVXdEtieVNuOGtFRzZ2V3lEU0YKcStuNmFQUnplYytFMlpVL1RTTnBDQWUv'
    b'MEt1UnhCVlMySnJCd1g2b0g2ZWRsL1I3NlN0SVlNQnIxYmFFNjdBM2tNQWlMN3BWdWhySApr'
    b'ZDF2QVlFSnMrcXVDenpDQk1xQkJLUHZ4OWFadzJIdjNnTUNJK2JES2x6VkNUZE83WkRBSldD'
    b'cm54SnVvanIwMmVBSkZoUzdLaEJpCkZpR0JIVmxMQ2wyVjRMVERWVnNCZ1NXTnlxcm53TElR'
    b'c1NLOTQxelc1MmptVkZKNDhVM0MrSkJVQ0hFNnNSci9lVWJiQjJGMDJrZEEKWUU1NzNNY3NO'
    b'V0ptcUFJRUhmaVVIL3NYWEJXSGZvWUVYZVpYYmF6WkxzNHJiczFoNEVPcHlIcjBnNjZXaUtY'
    b'MjVTc2c2RVU5bEI0WAppQk5OVndjZzZJaDNxNmNhNFNsaVJEYnhFaUJzNHd4aTh3TlB6OXcz'
    b'MGhYeHdITmwzc0NtVjNtUHhOWDNXVkxzS2dVRUEvZ3hLUHp2Cmw3MlNGc3l3OE5heXI5Zmd4'
    b'OE1iNTZHQzlhdjE2YUVaNmNkcjBUWG84cFZ6aVNINDg5ZHZXVlZnWDl6WXIvaEpXNUJMSHY1'
    b'RU1rNmcKZnlUVW5WVHQzNy8vV3Axam5JbUppWW1KeUg5ZVppSHdXU0VoNmdBQUFDVjBSVmgw'
    b'WkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TXkweApORlF4TVRvek5Eb3hOQ3N3TURvd01DMVFF'
    b'Tm9BQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNRE10TVRSVU1URTZNelE2Ck1U'
    b'UXJNREE2TURCY0RhaG1BQUFBQUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJpbWFnZTExMDA1'
    b'IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_20')

JP_20 = b64_JP_20
index.append("JP_20")
index.append("Japan Nagano")
catalog["JP_20"] = JP_20
catalog["Japan Nagano"] = JP_20
country["Japan Nagano"] = ('JP_20', '', 1)
lookup["JP_20"] = ('JP_20', '', 'Japan Nagano', 1)
lookup["Japan Nagano"] = ('JP_20', '', 'Japan Nagano', 1)
details["JP_20"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_20"] = ('JP_20', 'Japan Nagano', 1)
regional["Japan Nagano"] = ('JP_20', 'Japan Nagano', 1)
#----------------------------------------------------------------------
b64_JP_21 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3NTkyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfR2lmdV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAgIHhtbG5z'
    b'Omlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBl'
    b'IgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9E'
    b'VEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8x'
    b'OTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHht'
    b'bG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9'
    b'ImRlZnM3NTk2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3'
    b'NzU5NCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9'
    b'IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'Y2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXll'
    b'ciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc3NTk4Ij4KICAgIDxp'
    b'bWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJl'
    b'c2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6'
    b'b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFz'
    b'ZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5DQUFBQUJH'
    b'ZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRB'
    b'QUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ0tGQk1WRVgvLy8veitQYTMxY21GdDZOZQpvSVky'
    b'aVdnZ2ZGY1JjMHdFYTBLNDFjcjArZmZtOE95TXU2ZzZpMnNBYVQ4RmJFTTdqR3VOdktubjhl'
    b'MisyYzVLbFhjRGEwRkxsWGUvCjJjKzcxOHc1aTJxOTJNM2s3K3RXbklBZGVsV0x1Nml6MHNi'
    b'VjV0L2c3ZWp1OWZLeTBzV0t1cWRkb0lVY2VWUlluWUhsOE91bnk3ME8KY1VvbWYxeUR0cUxh'
    b'NmVQWjZlS0N0YUVsZjF1cHpMNzMrdmxucG8xQmozQzYxc3RBajI5cHA0NzQrL3J3OXZRL2pt'
    b'NHNnMkRBMnRBcQpnbC94OS9UbzhlNHdoV09IdUtYNi9QdUV0Nkl4aG1UcDh1NGZlMWJIM3RW'
    b'MHJaWW5nRnpGM2RNZWUxWXlobVZDa0hFK2pXNDlqVzFxCnA0OHVoR0xtOE90M3I1bUp1cVo3'
    b'c1p3U2RFM2M2dVdseXJ2dDlQRWhmRmdJYmtVUGNrcFZtMy9FM05QSTM5WmFub09HdUtRcmds'
    b'LzUKKy9vcGdWNFhkMUFpZlZrUWNrc1VkVTY4Mk0zQjI5Q3R6OEdUdjY1TmxubisvdjZRdnF1'
    b'QXRKL1c1K0FIYlVUMStmY2FlRk5jbjRTWgp3N0tJdWFWaG9vZzNpV2piNnVTdjBNUFQ1ZDdS'
    b'NU56aDdlamY3T2NHYlVUczlQSGU3T1lWZFUvUTQ5dzRpbW14MGNTdXo4SmZvWWRpCm80bGJu'
    b'NFM1MXNvYmVWTVlkMUhZNk9MMit2ZzhqR3lCdGFCOXM1MGtmbHJLNE5lbXk3eTIxTWpyOC9C'
    b'TWxuaFBsM3BGa25ObXBZd28KZ1YwQmFrREMyOUZabllMRDNOS3J6c0RoN3VnemgyV1B2YXZM'
    b'NE5ocnFKRHY5dk50cVpGRGtIRXRnMkh5OS9VMGlHYnE4KzkvdEorMQowOGR1cXBKK3M1N2Q2'
    b'K1hQNDl0T2wzcFFtSHVTdjYxam80cVUwYzhrQUFBQUFXSkxSMFFBaUFVZFNBQUFBQWQwU1Ux'
    b'RkIrY0REZ282CkxRMExpNk1BQUFRQlNVUkJWR2plN1puN08xUkJHTWRIYnN0bTNRdEZMcTBW'
    b'RWtLU2JJdElTVGZVSXRGbXNiU1Y3cVc3a2xzdUZaV0UKRkJXNjZQYnZOZStjWFozVldidW41'
    b'NWxaejJPK3YreDd6bnVlZVQ4N08rZWRlZDlGaUl1TGk0dUxpNHVMaTR0cnRjcHRqYnVIcDVl'
    b'MwpRdUh0NWVuaDd1TzdFcGlVYS8wVUtodjVCd1FHdVJncU9DUlVKYUhRZGV0ZENCVVdyckty'
    b'Z0FnWFFXM1lhRVdJOUlqYUZCMFRHeHNUCkhiZFpIVys5cTBsd0JkV1dSQ0Y2VXZKV1cwZkt0'
    b'bFRCazVqR0hDcDl1eEE2STB6S201a2xlSGRrczZYYW1VUEM3c3ExK3k3c0ZxanoKV0ZKcDk1'
    b'Qk1vTXUzLzBoK0Fja2JoWHNaemhXaEtpcVdjTzBEVHdreDl4OGdYTXptSzUyc25GTEplUkJo'
    b'b2FCQ3VEaklhbjJSMVY0bQpQUXRpTEpSM0NLNE9zNkZLZzFoSGpoNFRxUnloQ3NIeUJHZWw1'
    b'ZmJ4dkZLNFBNRWtpMEsrS3RMcXhTbTlDcUZxaVV3ZmpJSWk4VWVOCmtnSFdTUnhJVVl1Y3cw'
    b'S24vUEZuSFlOOUVPTFZJMmV4VUFFWTlEZnVBQnpsZEw3eldJWXoyQWluZnBLeGZua0JxOEhZ'
    b'S01acU10YVEKUEdzVVJCSmJNOXd4VWNZS2dSMEZMV0sxb0FveFZxdHRnaEJVaHUrY3BYd1do'
    b'UjBsVXg2V0Q3d2pkUGVnS0J3aTFld0lTN3kyc0pLdwplWTc2Z2s5R01ySE9Zek9IYW8wRFdT'
    b'aEZMdFlGYkxaZHBJaTFCZ2VJUjNLeDBDWHJncVFreUkyWDVXUFZZVnRIRVV1Tng0OWFGcXY0'
    b'CkNsR3lEZFpWYkYramlIVWRqeCszTEpaRk4yeXdibUxianlKV0VSNi8zZkZzcFMzQnVpVThR'
    b'azJWZVB6Ymp0ZFd5UktzTzdBdlVjUzYKaThmWHk4ZTZCeG1DTWxic3lzUDZ6eC94UHJZZlVN'
    b'VHljcmprSmJFNnNHMmtpUFVRai85SVBsWW5kSEFvWWoxMm1FNGxzWFRZN3FLSQpWWS9INzVh'
    b'UHBjRjJPVVdzSGp4K3Iyd3NjeCsyYVhiaGZDRkRQSkdMMVk3TjZuNmFCNjRCSEdGUUx0YVE5'
    b'ZnhQVFlFNHdsT3pQQ3l6ClVieUowMmxzUVluUkk4WjZCbnZ6OCtXd2hxRkVHNkZiK3J5QVpv'
    b'MFl5eXI3V0hEK2YwbTVUc3lGY00yTFdLOUdyUW9WWVRXT2F2NWkKUVQybXFxVmRWc09pVDhw'
    b'ZVV1eGJKWEZvTnJ6R1JoYjFIZ1NwOXBPZHg0SnFiT3dOL1piTk9CVEpFODVpbWVBZFVUUG9i'
    b'eW1oK3hHdgpkQTRyQVdveGJ5MkxkdUFrNmNpL25aSlFHbm9udm53dnRLUmIyRFJQcHlIV3dJ'
    b'empCMmNnTjZnK01PbzBHejZTcHE3RGptakNKNUpECkRLd2E4N05URUsvWHdmdGw2b1duNW1Z'
    b'Uk04MFRMc1hnTWhPUi9abjh1VEkzanhocWx2eU9xaEs3RFErZkpHRVhjRU5NbFQwdDVJQ0IK'
    b'WWZPL1R2TVhQK0ljKzJwQXJEWFphT2t5ZjJ1M2RiUVBWUWtlNzA3a0FnVjFqMW5TWnQrNHJy'
    b'TmpRYTlmK042aTB6UllibzZwdGNnMQpNcFhaL3dzOWF3SzVUaE0vL0tXWS9IL1dJdGRxL2xm'
    b'R2tqOHdxak5hUjlBS1VIOXplWmVmc2FtdHJja1k4THM4b2g5eGNYRnhjWEZ4CmNYRnhjYTFX'
    b'L1FITlBFekFNUnl4TkFBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TXkweE5G'
    b'UXhNRG8xT0RvME5Tc3cKTURvd01Pelk1a0lBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJ'
    b'd01qTXRNRE10TVRSVU1UQTZOVGc2TkRVck1EQTZNRENkaFY3KwpBQUFBQUVsRlRrU3VRbUND'
    b'CiIKICAgICAgIGlkPSJpbWFnZTc2MDAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'JP_21')

JP_21 = b64_JP_21
index.append("JP_21")
index.append("Japan Gifu")
catalog["JP_21"] = JP_21
catalog["Japan Gifu"] = JP_21
country["Japan Gifu"] = ('JP_21', '', 1)
lookup["JP_21"] = ('JP_21', '', 'Japan Gifu', 1)
lookup["Japan Gifu"] = ('JP_21', '', 'Japan Gifu', 1)
details["JP_21"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_21"] = ('JP_21', 'Japan Gifu', 1)
regional["Japan Gifu"] = ('JP_21', 'Japan Gifu', 1)
#----------------------------------------------------------------------
b64_JP_22 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMzg0NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NoaXp1b2thX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczEzODUxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFt'
    b'ZWR2aWV3MTM4NDkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9y'
    b'PSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'c2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2Nh'
    b'cGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9k'
    b'ZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTM4NTMi'
    b'PgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAg'
    b'ICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJl'
    b'bmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdl'
    b'L3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFEck9W'
    b'Nm5BQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFD'
    b'QTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRB'
    b'QUFLCi9rbEVRVlI0MnUyY2VWUVVSeDdIcTNwbUdPNGJGSkQ3a0VzT0lZQW84UUtUQlR5V0dC'
    b'RmVkRTFja3hVM2Fqd1MxMFR6VExKSjFwZE4KVEl5ck1USG1hVjRTWWtSUjhVamloVVRrQ1hL'
    b'S2dNTWhNaWpYZ0NBd3czUjM3UityTXQwendPQW1NSU8vNzMvejYrcWFydnBNL2VwWApWYjlw'
    b'ak9JL1FTQjlGZ1ZkQUFoQmdCQUVDQUVoQ0JDQ0FDRUlFQUpDRUNBRUFVSVFJQVNFSUVBSUFv'
    b'UWdRQWdJUVlBUUJBaEJnQkFRCmdnQWhDQkNDQU9FVEtlR1lhVW13dTkwSHk2WkcrVHBZbVlv'
    b'SEtTYnJrbCtwdVBQV3dkekM2dWF4MFhBOE5ySzVaMHlhOFBON1NTS2gKdGs1RlNiT3hieDdP'
    b'THBPQ0k5V05ueUZHKzliR2FjOFBJU1FTVWwrdGlZTzVVSWRjcU1kNGkrSGU1ZTFvR2V4dUJ3'
    b'aDFRcE85N0Ivdgp4akJ2K3pIUS9MRVF6Z1M0MlBBc3BMbUF2WDBlRVViRjJ3b281MW5ZZnZM'
    b'Z053TEMwZEZVZjBmT1owVzc4c2NZUlBmeWlqRkNZNE1WCkRVaHM5Y2dTN2VjQWpuVDBaV29r'
    b'bXV6SjhZZHN3MFYxZmdnaFJQZXdEUmM1anRScm5JbWhDQkNPc3FMOUhIbXhLT0Z5NGx5U1h1'
    b'TEYKcFZHKzR3SGhLR3R1aEFmUHdrb0hSTWh5RVNLRUVwL3lBSVNqS1FHRm41dnF4VEhKMjBo'
    b'THlZQ2pzS1VRS2RwVkxjL0hlRk1ZQThKUgowOU9CRXh5c1RUampUSkxCQ1VUNXc1Qm1KVWRW'
    b'RFU0MnB2eG9DQkNPcEpiRit2TVpWZjA0K0Mxc1ZUclA4bUtjUHlBY0hUbGFteXllCjdzTXg5'
    b'YmF3RFJlR1FIajdMT25oYkhDbnp2QWRiMlVDQ0VkQnF4S0REWVFDenNxdi9BQmk2U0Z1WTJt'
    b'MjhqdFZnMWdrU0VzSUFvUWoKTFN0VDhjcUVZRDZiNHAzYTNNc1c3ZVRObDJtSndaWW1Za0E0'
    b'b3RxU0VzazdGMlFsaDBubkxXM3VKZmRxMk9wTVZZdU5tZUhtNUFoQQpPSEx5R0crUnhodUND'
    b'REhYaG5Id3lWejdtR2RaUFMvRWZadzVJQndoZmZyS0RMR0lNd3V5MVVmSjNUenRheUNOdjdF'
    b'MXgza3o0cWV2CnpBQ0VJNkhsY3dJU0k5eTVrNXVTeVhsanVQVXdsellpVnFscW1SdnBvYjVL'
    b'QVlTL3MxenR6VDllTVowUG8vUUwwbDQxM0twSWV5VlQKdXBkbjNQSHlkQmM3TTBENFI4bklR'
    b'SGpvSHdubXhnWWNFdDJOVE83YmoxY2hrN3VWZE45UnRWaVlpTk0zeFJzYUNBSGhINkl2Vjhj'
    b'Kwo1VE9PaitHWEZVZ3VlOHdhNVRMbTUyVUlFVlZibEsvRDNsZG42MUczQ0pEM3MzcnhvSnVU'
    b'STlZdUNPV3Y4TXErVkk4dGgrZE83MVZqCk0yZmVhWDZ3dTUxQ3llU1VOK3BGeitpSHgxZ3pQ'
    b'L1NmUzZQNXZTKzdRV2V2NXhmRkZEVmhKbmFLd1E1UjJOSWJpeTBSeGtUUlFXUVYKcEsyTXJj'
    b'NGtqWmQ1dzQ2K3VFN2tPQTFiVFZRMXZ2K1hxZDF5NWM3alJicmZPWHFRUjdvcU1Yam4zMmJ5'
    b'VDRRVTdjcnZJMG5Ielg2TAp5RlFROEJJVjhuZHM2VDM0c0dOTGRqTkZPeEhUMTk4TFZqNml4'
    b'WGxJYk1rcFNkQ3EzZWQyWjVXQUkvMC9mbDhZYlUySjNQNVNESjhmClM5UEgvMHlhcnZhWGRK'
    b'd21TanBEK2FaaXd5RXltckNoTmVVNmgvSlpoTm9yeWIyYWg1TmlHMmtwb254VEVLWlV2ejAr'
    b'M0owbDVOSjEKS1NCOEhJbEZndjJ2UGJObWZxamFpU3loejZXeE53LzF0MkhLTnVHY3I0ZUV4'
    b'd0ZwWkV2NXZZQm9PV244N2RIb0pMM05sSHNDUWxpVgo0c3dnWjA4SHk1TlhheG1XQU1KaHlI'
    b'ZUNkZWJXZWZIaGJ1cU9rRG0vbWkzWjNkK0FhZjhTUkd4V0hUM2FjNlJjWXBHaE5hazc4NkRx'
    b'CnBud2tiNmZjbmxXbGlCQUtjcmVOQzNYTnVkN1kydGtMQ0xWNElBcHZTQXBMM3hUdnBtbkhr'
    b'cm00amluNnJMOXc1RlpCNUZzYTYrbm8KVm1TWFNjK1hOQlRXdE1pNjVPYkdCc1ppRGNscTFQ'
    b'aElSUGYyajhXN2VhaXZpM0o5aGxkc2dxM3BYNThKNktPWnZNcTdSTWRHb3c2RgpNeFRHQzZa'
    b'NGJrbUpEUEhRbENmUEt1bXpLOW5yKy9vZjNTRkt0Q2dIWVFHdllIYVpkUHRQK2FmeTYxaVZ6'
    b'aFlLcURtVFhkNU1qdFNRCk84clN5c096aVRTNy8wa0NWd2huN1VLVUJ1UkZOUzN2ZnA5M05M'
    b'ZWExUm1TT29IUXpNZ2dLZHByNDNOaEFhNER6R2VLRHZyRVF2YjIKV1pYUktoYWxGbUNiQUU0'
    b'cEpiTmhYL2F1RThVRGRTL0dhR1Y4OEtldlRCY0t1SG1MZDNLVjZaeEZDK1VTSzB3NHhJdFJI'
    b'Nm04WHJiOQpwL3dqdVpMT25yNG5GNkdBd2w2T2xqRUJUZ3VtZU1hR3VQQk9IdmpydnhOSlJG'
    b'YkI2ZUtBNWNLNHIxUXRmVFN6OFAyczQzazFRMzUxCi9GTnVtVnZtOFNncUQvZ1QyUTFPMTFq'
    b'N0NSTXpzTFh2UVBVb2xNeXZSZlZITGt0eXloc2xqUjJqRmUrTU5NS1pRYzdMWXYwbnVkbjQK'
    b'dTlnTWd1MVI3TUlVL0p1NThqYWk1Yndyb3BTcmVGeTRxdVcxdlJkM1pCWnErUmhYZDZTRWUz'
    b'UDI2dWdUU2F6a2lOck9oNkZneWp1Qwp5ZXZVM1RWL3E2NlB2bkZiVmxyWDlzMnY1ZWRMYm8v'
    b'WjNabm5wM21uYjByUU1tMlR5TXJwbjEvU2VBcUk3VUo0L0Fva3paOGQwM1luCkpTYkFLY2pk'
    b'VmkxUzB1UVNhVGx6NlhWV2tpR00reHBiK3cxU3A2R0JNTlRUUHRUVGZza3N2K1FQc3c3bDNC'
    b'eTVHR0lrRWE1UEN0T1cKMzMwcGs3MlJOT1ZyZm1pbkdKNWx4OUZyMnNRWEZNYWJreVBPZmZB'
    b'Y0wyOEtzVFJwS3h2d1lacnltVXV2azI2dHRrd3hSdXVUd3NicwpLRFRWK2o4bzJOUkp1Q0NM'
    b'OURRVHlXR21iQjlwTHVCYzVlNUswd3liY1ZreVpKMk8xaVlITnp3N0s5aFpRN1JiZlVSajNn'
    b'MjJEeE1FCkxxZThGeUlqdXoraW1mbzNDcjg5WHpHOGlkclluZ3BhS1VyTkZ5WC9SdmtrUDRy'
    b'eXNaVXZMejdzVVF5UmV4Z1g2bEwwK1FzYStaRU8KQ1pPOWdkc3JJbXJpWWxIeVpWRnFQaFcw'
    b'Y2xqOEhxT1oralFLdC8rVWp4QmFPdHZQMWQ3Y1dEeU1yOFlPMFVLSGFOSlZ6K1M5eTVaLwpn'
    b'd1NjVTkrbWpwN0JiLzlUdU52UkxYUDV6dk9Cazd4S0g1dmZmL0JMQ1NuL0Z3V1JXN0NaODNC'
    b'YjE2T2dielYzSGpoNzQzL05IUHVMCkNqTWpBeWNiVTFkN3MyQVB1MGx1dGlFZWRnRXVOdHJN'
    b'bEtUakpoWmJxbzZNWHdycjU3eVZNVkI1VzNPajhqMUw3U3lNMUZmMHpKVzMKbWZ6dEQ3T0hN'
    b'ZVdiSW9qYWhpMjlobjRHZ3E3WHR4VldONWZXdFJiWHR0WTNkMG5iN25mMWpzNGFjZFRPQzd0'
    b'Nit5b2FaQlVOc2pQWApIa3hDZGhaR015Wk5tQlhzUEQvS2svZG5GODZQVHUwc3lkTmhzSGNs'
    b'cENVRXFmTWpuYlgwcVZSeTU4ckRKYUMvY1BZZXJCWWw4ZFFvCjZ6NTJwZnBzOGUwTEpRMjZz'
    b'MStxaStlRkZNWlBCem9sUCsyemVQcEViWktzQ1VFT0wrd2R5SjJxTHdIWnFoL3BzeThqeGIw'
    b'SEs3K0kKTndWaHIvT2NzNm82dWhVL1hLeE16NjdLTHBPeVJPZk9LM1Q2eU5mRVVMUmtsdCty'
    b'YzBQOFhhd0hMN2x4MzZXUE1nbzBYcnAvZUpYcQp2N0haMml3Nk0vRmhXRFJSR0orTzdZSUhx'
    b'dmI2cmJhZHg0dStQVi9STFZmcWJDL3BkUHBUdDF5NTUyUkpZTnFCZWU4Y0s2bHRIYVRrCjJn'
    b'V2h2TXkyL2haUzNBbVdmakJZS2IrbG90VDhnZmdWMTdiTTNaWVptSGJ3aTFPbHVzd1A2VXY2'
    b'VTVXMGZlK3Awc3FHOWpDdmNaYWEKWHJGbWJteGdhU0xPdWxxcmZtbFJqTTg0SytOK3QyUGpq'
    b'NjM5cVlEbGd2Q05HcDFuYlZObjJxNXpxL2RjcUpTMkkzMlEzbVN3RVlUSwpiclY5ZWJwVUpL'
    b'QWlmTVlMS0g3d090bkxmdS9wc3Z0cUk4YloxalFtMEltemYySVRvREhzVk5Mc1J4a0Z5Ujlt'
    b'RmRhMEVLUTMwck5zCjdoNEYvY2IrblBDMTN4WFZ0UEIvakJSMnN0RVF4LzRucTBTYkk2R2lt'
    b'cGF3TmQ5dDJwOHo1QzRCSVB3ZFZGTGJPbVY5K3E0VHhhckcKdSszZDErczE1QVJMMis2djNI'
    b'VnU4RWp5OCtQRlVldCtLSzFyMWNmZTBCdEh5aFBOc0NmejY0cHJXNkw5SEMxTXhEY2JPNUkv'
    b'UEhtcgp1Vk5qNGRLNlZrbmp2YmhRRGFlU1RSMDlTejQ2L2NuUmF6cWIzYVRmaXdvdFpXRWl2'
    b'dGV0R0xLWWs0MXBXa0pRUW9TN2k1MDVoVkdWCnRPTklydVNMVTZXeUxybGVOMytNdkZMMlNS'
    b'YThteHNRZ2dBaENCQUNRaEFnQkFGQ0VDQUVoQ0JBQ0FLRUlFQUlDRUdBRUFRSVFZQVEKRUlJ'
    b'QUlRZ1FnZ0FoSUFRQlFoQWdCQUhDSjFQL0JhUjYveDBtcGZPaUFBQUFKWFJGV0hSa1lYUmxP'
    b'bU55WldGMFpRQXlNREl6TFRBegpMVEUwVkRFeU9qUTFPakl5S3pBd09qQXd1end3Y0FBQUFD'
    b'VjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3TXkweE5GUXhNam8wCk5Ub3lNaXN3TURv'
    b'd01NcGhpTXdBQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxMzg1NSIgLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'JP_22')

JP_22 = b64_JP_22
index.append("JP_22")
index.append("Japan Shizuoka")
catalog["JP_22"] = JP_22
catalog["Japan Shizuoka"] = JP_22
country["Japan Shizuoka"] = ('JP_22', '', 1)
lookup["JP_22"] = ('JP_22', '', 'Japan Shizuoka', 1)
lookup["Japan Shizuoka"] = ('JP_22', '', 'Japan Shizuoka', 1)
details["JP_22"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_22"] = ('JP_22', 'Japan Shizuoka', 1)
regional["Japan Shizuoka"] = ('JP_22', 'Japan Shizuoka', 1)
#----------------------------------------------------------------------
b64_JP_23 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmczODcyIgogICB3aWR0aD0i'
    b'MTQzIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0MyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQWljaGlfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMzg3NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzM4NzQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMzg3OCI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNDMiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSThBQUFCa0NBTUFBQUNJUHBQZ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNhbEJNVkVXbVBFZXVUVmZqdzhhc1NsU3EKUkUv'
    b'dDJOci8vLy9yMDlXb1FVelpyTEhWb3FpNmFIRCsvZjcrL1B5MllHbnB6dEhreGNpOWJuYTRa'
    b'RzNqd2NYZXQ3dXVUbGo4K2ZtcgpSMUxLakpMR2dvbm55ODZzU0ZQOSsvdjgrUG1wUTAycFFr'
    b'MjhiSFRNa0piYXJiTGl3TVRwejlMbnlzM2d1Ny9JaFl6T2xKck1qNVhJCmg0N1ZwS25ndkwv'
    b'cDBOTHQxOW5pd01PN2EzT29RVXV0UzFYT2xadm96TS84OS9qbnljek5rcGlzU1ZPbVBValBs'
    b'WnZ1MmR2czF0ak8KazVtMVhtZTJYMmpldHJyOSt2djkrdnJjczdlMVhHV3dVMTNmdUx6Ly92'
    b'NnlWVi9DZUlENDhQSDM3ZTYvYzN2MTZ1dStjbnF2VDFubAp4c3F0VEZiMjZ1enMxZGUwV21Q'
    b'MTZlcllxcS9mdWIzYnNiWDE2T216V1dLeFZGNnBSRTZwUlUveTQrWGh2Y0hkdGJtclJsRHIx'
    b'TmZ5CjQrVHIwOWJxME5Qa3c4ZlRuNlN3VWx6NjlQWFlxYTNOa1pld1VWdjc5L2U3YW5MNzl2'
    b'YXZVRnJ3MytIcTBkVHo1T2JCZDMrNVptL0UKZm9XMFcyWDU4dk8vZEh6cTB0VENlWUg2OWZi'
    b'RGU0Ty9jbnE1Wlc3NjlQVEdnNHE2YUhHblAwcTliM2YrL2YzaXY4TDU4L09vUUV2RgpnWWoz'
    b'N3UvQmRuN3UydHpTbktMandzWFJtNkRYcHF2WHA2emFyN1BkdHJyYXJyUFdwcXZTbktIZHRM'
    b'anMxdG12VVZydzN1Q25Qa2l4ClZGMzQ3L0QwNStteldHSDI2K3pXcGFySmlJN0ZmNGF2VUZu'
    b'QWRYellxYTdKaUkvTGpKUFFtWjd4NE9IejVlYTRaVzNRbDUzS2lwSDUKOGZMYnNMWDI3TzJ5'
    b'VlY3bXg4ckRmSVMzWVdxNloyL3YzZC9SbXFDdVRWYnk0dVRodk1DeldHSytjSGp2MjkzMDUr'
    b'anczZC9TbmFQbQp5TXZWbzZqaHZzTFJtWi9LaTVIRmdJZkNlb0cyWG1mWnJMRGNzcmJMalpP'
    b'blBra2xNOU5yQUFBQUFXSkxSMFFHWVdhNGZRQUFBQWQwClNVMUZCK2NERGcwZ0NoMWowcFlB'
    b'QUFQYVNVUkJWR2plN1publd4TkJFSWNQQ0VlUklMMEdFQVNVSW1Bb0VrUkVrVVFpWFNVSUNB'
    b'clMKUllxSTlDSXFLRVVVQ3dxS1hSQUxGaXpZQzNiL0oxTXVsMWxJMUMrM3VRLzcrd0E3cy9N'
    b'ODg5N2UzcFlKUlJFUkVSRVJFUkVSRVJFUgpZWmFKcVJtZmNBVG10SVVsajNpc2FKcTI1Zy9P'
    b'TWhzbGo5Q1dOenpMYVpYcytJSmpUMnZrd0JNZVI0YkhpUjg0emtLR3g4V1ZGenh1CnRGYnV2'
    b'T0R4WUhrYytZRGpLV0o1dkx5TnhPQ3p3dGR2cFllNWYwQ2c5YXJWdEU1QndTR2hIbXZDUE1L'
    b'dGdpTFc0b0lSUjBaNTBmOVcKZE15NldDdzhFdHU0OWYvQkU3OGhRWUx0aFcxTTNQUlhtTTFK'
    b'V3pCUG9XU3B6RENPM1Zic1U5bzdOa1Z1Z0daYnFoajdoK1ljbjVhZQpFYVVYSnpNck5YdTdN'
    b'MTZjSFR0cFdwYmpvOUNEaytTVHEveTdLdzhuVG42YVpqMHVzRnFDRTdJN1UvMC9MUjhmamxr'
    b'aGs5eGZVTFFJClo4L2VZcVpWRW9zTFIyTEtwZzh2MklmZ2xIcVg2VDR5WE1zUDNDSEtLeXFC'
    b'SlhldUFsWTFIcHo5TlNDbjdJQWJzTnpUNFdEVjFtSGgKQ1VUZVVMMVBBOXVPOFQ2STlFbHg0'
    b'Q1NnNjdLczBaNXRIMnBDSjdmc01BYWVKQ1JsY3d0RnRXcUhoNkxhMnBIZVhBemZ1Z3RNS0Zk'
    b'ZAp1am9ZbzFQWjd1cUczVjZlblBQMHdIeWlJK3JUbVdaUTVMMHE0K2d4R01EOWlmbzRUQmVw'
    b'OFNuZ3l5bUhBVVdjcjRWOUlGdGh2OFo1ClFtMjFNUnQvR3B4ZVhLK0orZkRwZzdXN3E5cXFZ'
    b'Q3hmR0pMTU1VOEt5Q1VVYXdkTk5ZbFBha1BxNElJd3dERVBmUGdHMW11dTJycFkKYXhEZU9E'
    b'am1HUUs1Rkt3M1FHbVpzdFl3aURuRk1jOEl5SFdhOWFwT0hZbXNkUWJFakdEa0NXRzlvMHJy'
    b'TEd2NWdaaHpIUE9jQjdrdQpJSXVTYnZNTUJURkRHT2Z6R0ZKUzBNMmZWb3p6dVFYa3NybW85'
    b'VjVTM1VmWm1Hd1EwOG4xTlJBdWRuR00wMUpWNHFnWlo2d01HRExCCjlYNXhHU1M3VXFCeDJx'
    b'cXRTU2FrQTBSYzVYdy9sY0tudndZbjFYV05VU0RWdTBSeHBSdVFSOWpJTG9jMFBheHVkOTVz'
    b'QmdGTm5QTUkKa0FOWHRMM1NGYXVwZGRRSWxPMWJ0KytBN2tvTTkvZ2M1RVFxbXBLdzk1OHBT'
    b'akpkbTNjWDlQcGhPRDlQaXRCRGU1VERqUGFxY2ErVgp2djhBd2s1ZzRFRzJnOFVhckhnSXJG'
    b'a3M5NitzUG9NNGp4NC9nWWQ5TVo0TDZsTkRPTzF6MXREc3dWVlFVQmlvaXoxRGpxcUIrR3Ax'
    b'CkZ2cHdudWUvZ0NmVk1RRytBbEJXeVJJYWwvS1h5TEROWjJFdEh3NmlOS0pYcjkvTVFNZmJE'
    b'THdGUk5mWmQ3cXl3ZnNQR1E1bENOOUgKSS96ME5CbjhhZlN6dEdvaFJXenlwUlNoRVM2TTQ4'
    b'ZWgranVxdnc1ODY1a2VyVjlVR1MvOVRobEhuZnAreHdocmsxQkdrOE1QdEVqZgovRE9DTXE1'
    b'NjUzNDVGYy9MWmQzWjhZcTRydDhVRVJFUkVSRVJFUkVSRVJFMi9RRUVvcmg3UDFlaU1BQUFB'
    b'Q1YwUlZoMFpHRjBaVHBqCmNtVmhkR1VBTWpBeU15MHdNeTB4TkZReE16b3pNam94TUNzd01E'
    b'b3dNTFJkOGNVQUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXcKTWpNdE1ETXRNVFJVTVRN'
    b'Nk16STZNVEFyTURBNk1EREZBRWw1QUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1h'
    b'Z2UzODgwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_23')

JP_23 = b64_JP_23
index.append("JP_23")
index.append("Japan Aichi")
catalog["JP_23"] = JP_23
catalog["Japan Aichi"] = JP_23
country["Japan Aichi"] = ('JP_23', '', 1)
lookup["JP_23"] = ('JP_23', '', 'Japan Aichi', 1)
lookup["Japan Aichi"] = ('JP_23', '', 'Japan Aichi', 1)
details["JP_23"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_23"] = ('JP_23', 'Japan Aichi', 1)
regional["Japan Aichi"] = ('JP_23', 'Japan Aichi', 1)
#----------------------------------------------------------------------
b64_JP_24 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDU3NyIKICAgd2lkdGg9'
    b'IjE0MiIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDIgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01pZV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAgIHhtbG5z'
    b'Omlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBl'
    b'IgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9E'
    b'VEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8x'
    b'OTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHht'
    b'bG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9'
    b'ImRlZnMxMDU4MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzEwNTc5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2'
    b'NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRv'
    b'dz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBh'
    b'Z2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9Imxh'
    b'eWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwNTgzIj4KICAg'
    b'IDxpbWFnZQogICAgICAgd2lkdGg9IjE0MiIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAg'
    b'cHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJp'
    b'bmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7'
    b'YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFJNEFBQUJrQ0FNQUFBQm4vUGplQUFB'
    b'QUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFB'
    b'ZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ2MxQk1WRVVBbVFBWm94bFV1MVNQMG8rSwow'
    b'SW9CbVFFaXB5SmV2MTZaMXBuVjd0WCsvLzcvLy8vditlOGZwUjhLblFwQ3MwSit5MzYzNHJm'
    b'eCtmRlZ1MVVFbXdURTU4U2QySjBECm1nTXJxaXRtd21haTJxS3AzYWtKblFtQXpJRGM4ZHdO'
    b'bmcwTW5ndzhzVHgzeVhlejRiUHUrTzczL1BjdXF5NDdzVHY3L2ZzM3J6Y2EKb3hxUjA1SDYv'
    b'ZnBxdzJvUG53L2Y4dC9lOHQ2MjRyYWwyNlhCNXNGRXRFVHcrZkRvOXVnWG9oY2VwUjdNNjh6'
    b'OS92MUt0MHBXdTFiZwo4K0NNMFl6RzZNYTc1THYyKy9iUzdkSUluQWlFem9UYjhkdjErL1Vv'
    b'cVNnOXNUMzgvdncxcmpVenJUTnZ4VytxM2FycDl1a1FueEJ6CngzTzY0N3I0L1BpdTM2NENt'
    b'Z0xrOU9RVG9STmh3R0hxOStvT253NC9zajlsd1dXRnpvV1UxSlNZMXBpSXo0aHd4bkJJdGtn'
    b'YnBCdW8KM0tnbHFDWHordk5PdUU3STZjamE4TnFWMVpVeXJUSzU0N25aOE5sWHZGY0dtd1lr'
    b'cHlUTDZzdER0RVByOStzbXFDWkJzMEYvekgrdwozN0Jpd0dJU29CTGo5T01MblF1dDNxM1g3'
    b'OWNjcEJ5NDQ3alE3TkJHdFVZaHBpSGk4K0lSb0JGSHRVYytzajcwKy9USjZjbHN4R3dGCm13'
    b'V20yNlk1c0RuVTd0Unh4bkhiOE52eSt2SWpweU5GdFVVVW9SVG05ZVpyeEd1UTA1Q3IzYXVj'
    b'MTV4QXMwQXFxaXJDNThJSG5BZlAKN005WXZGaks2c3JUN2RPMDRiUXRxeTIvNWI5YnZWc1Zv'
    b'UlhuOWVkbndtZXk0TEt2MzY5TXQwdzZzRHB0eFcxSnRrbk42ODJKMElsYwp2bHpENThOUnVW'
    b'SGQ4ZDBucVNkZnYxOWp3V01ncGlDQ3pZSmF2VnJBNXNBeHJUSFc3OVoyeUhiUjdkR1YxSldu'
    b'M0tkUXVWQ1QxSk0wCnJqVFk3OWkxNGJWU3VsTHM5K3lqMnFOMXlIVTJyelo5eTMzNS9mbkg2'
    b'Y2RvdzJoNXlYa1lveGd3ckRCZVFyRzNBQUFBQVdKTFIwUUwKSDlmRXdBQUFBQWQwU1UxRkIr'
    b'Y0REaGNQQ1BEQXJYRUFBQVIvU1VSQlZHamU3WnI1VzFSVkdNZS9aZ3JPZFlzbFpoUlVGSFdV'
    b'QVcwaApaRVFVRVdFQ0YyaWFRRXVLSlVBTElkRmdHQ3NVcWRGS295SjNUZE1vdGNpVTB2WkZi'
    b'YmMvcVRNc1orNDJjK2VoOTg3MDlKenZMNWYzCm5MbjMvVHozUGN0NzNnc2dKQ1FrSkNRa0pD'
    b'UWtGRzFOdUdmaXZaUCtHeWlUNCtLbldLU3AwMkpQTW4zR3pQc1NwR0VseGhpRnhTWXAKV1Jy'
    b'VC9URWtTYkhhWnMxT0JkSTR6Wnk1TVVLWmx6NS9RWVlrTFZ3RUxMYVAwZGlYeEFKbGFXSm1z'
    b'bU1FSUF2SVhzWmZ6dnhZeEdjNQpkeTg5d0ViT2c5eDZLQ1dhS0hNZlRsdVFJOG4xU0M0UXg2'
    b'Mk1GZEdNVDU1VFVzbXlrcTAyQ2R6TWp3cEpFb3ZQS2tsUEJheHpOYmZpCm94S2ZOWVZTQ0sw'
    b'dEF0WnhxM2hlRE9JajAvb1NvTlExWmprZU5URStaZVViTmtvR3NnR2Jna0hjYkJwTWVrV2xa'
    b'S3pIMkM4M2NLdkMKYmQ3TFNVMnNjQnJSUE80Qm51QlcxUVJhZ3VvdFc1OThLbjViemRQUDFB'
    b'N2IxcnJ3UU00WlFIMERuL0hQa21ZcU14dnRRVTlOellzRApHZFQyeG5BNE5XeUFCWC9RVEFo'
    b'VHRzT2lkdmJjOHd6SVhlNElTWlBYQXRSd2E4cDBNcGlkZFJZOWY2MXRySy8waFJBMERidUFk'
    b'aDdOCndLNU9sRHZ0RHZrRzltUXoxbUw5dmhlQmprNXVsVlBSZUx2Q0RBOWZQYkIzamw1UEY3'
    b'dDFOcmRlb3NyVnA3MGNkdlprdkFKMFYybmIKOSswSHRuSnJZeTdWS2FUVFlHMng5d0FITkVQ'
    b'THRRVW82Wlh2NmpTTDNhdUdLKy9VRXJ5bWFWd0grSU8zWmxLTjRvTVI3QVJOaHpUNwplYXNm'
    b'S09EVzY2bEVPRzlJa2VoTmRjUGhJOEJiZkk0WFdvbG8rbktrY1NtTzNmbzJ0OTZobXVQdmpv'
    b'K21uOTI2UjVHNWs2aTdjbHcwCmdUbWVSVC9IOGQ2NGFKeEhnV1ByeWVjNHZJZTF2aXBiMXh6'
    b'UENJK1RCcHc0S2MvY2lYUkttMDdadkt6ZDNSTXVyVGp0bDQrNU0wVXcKTFZabnMvbW1hZ2xG'
    b'azlNTjlQRGVoZS9UNVRqcW5mR2NQOWlYRmdyblBQREJCVzVkSkN3L3FONUE0Vjc1Y3AyblR6'
    b'T0xkWDNJclFIQwpCSEM3eXBOeTQvbElIK2RqNEpJaWN5ZlRaWldubzRwZWY2OHVUcFhWeWpj'
    b'd1p4dGxycDZ2OHRTbjdMNmkvM291K1BpZm41QWVZejVWCk9WSWRyd2VObHNNckxhUTRuNmtl'
    b'ZjBUWmZkV0FwdmR6MmtOZW0rcjUxeFM5dFJZRG5PdkVwOTRoMWZOWEszYm1Md3hvdXFnUDRX'
    b'NTEKanZlbGZMUHZEVS9UNmFIR3dRMzFhQWhXWVB2T0dMeWNVL1ExaXQxcUg0VzIwYXBuNlhL'
    b'amFiVnFpQnpucHRiTFYxOGYyTFhrK280SQpzcDdpV25LZWI2Ui9vYWFsMURpMmlIM3JsUTE4'
    b'WHVycW55OUNHc2UzT28zZmtVZnIrd2h4bWlmOW9FM2dPK2duVjNKRU5BMjUrRkc5ClNMdlNU'
    b'YWhISGt1SUJPY2F2RC9wSlBBbWFLWExtS1pBSjYwKzdUZW5YcnZaa09ibkZOelNoSy9lclBw'
    b'eHBnRk5ZelZxYitzazhHWXAKeXhHTzVrNFJQSnI2MkIwelA0TzAzdzRKNC9vRjhBU1BuRmY3'
    b'Unk3VnBuNldHZW9Qa1d1ZGJBZnFnMnVsL1ZES3dlR0wyWitzZmoybgpBN1BzdkJ1NEpTc0Iv'
    b'Y1lPR0YzREY5UFZNL0M3RXVhUGl5dzEzeDh2YXhrTXBCLytnY0hvZkh2dHlOK1dOMUxUY1Bq'
    b'cS9nd2s4dDYvCjVNV00wWCtzYUxtTDZNa3orZStkZDVOR2pSVmxjZzFCU0VoSVNFaElTRWhJ'
    b'NkgraWZ3RDNDeTF0b2o5cEhnQUFBQ1YwUlZoMFpHRjAKWlRwamNtVmhkR1VBTWpBeU15MHdN'
    b'eTB4TkZReU16b3hOVG93T0Nzd01Eb3dNSTNKT0Y4QUFBQWxkRVZZZEdSaGRHVTZiVzlrYVda'
    b'NQpBREl3TWpNdE1ETXRNVFJVTWpNNk1UVTZNRGdyTURBNk1ERDhsSURqQUFBQUFFbEZUa1N1'
    b'UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMDU4NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_24')

JP_24 = b64_JP_24
index.append("JP_24")
index.append("Japan Mie")
catalog["JP_24"] = JP_24
catalog["Japan Mie"] = JP_24
country["Japan Mie"] = ('JP_24', '', 1)
lookup["JP_24"] = ('JP_24', '', 'Japan Mie', 1)
lookup["Japan Mie"] = ('JP_24', '', 'Japan Mie', 1)
details["JP_24"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_24"] = ('JP_24', 'Japan Mie', 1)
regional["Japan Mie"] = ('JP_24', 'Japan Mie', 1)
#----------------------------------------------------------------------
b64_JP_25 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMzgxNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NoaWdhX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAgeG1s'
    b'bnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2Nh'
    b'cGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0'
    b'L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAg'
    b'eG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBp'
    b'ZD0iZGVmczEzODIxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2'
    b'aWV3MTM4MTkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTM4MjMiPgog'
    b'ICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAg'
    b'ICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRl'
    b'cmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3Bu'
    b'ZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhUbkNB'
    b'QUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZB'
    b'QUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDR1ZCTVZFVStpTUNIdGRpR3ROZFJsTWJ5'
    b'CjkvdjArUHRTbGNkR2pjUFM0L0QvLy8vUTR2QkdqY0xPNGU5SGpzTmluc3piNmZOZ25jdEFp'
    b'Y0dJdHRoUGtzVk5rY1dneGVENi9QNmYKeE9CTWtjVy8yT3I5L3Y3TjRPK051ZHBvb3M2MjB1'
    b'ZjUrLzFycE04L2lNQjNxOU5QazhhWHY5M2c3UFhtOFBlZHc5OUJpc0hzOC9sSgpqOFNpeHVI'
    b'Myt2ejMrdjJzek9TbXlPTHg5dnFRdXR0QWljQmNtc3I5L3YrU3ZOdkYzT3hVbHNlRnROZjcv'
    b'ZjVkbThyVjVmRnZwdER1CjlmcHVwZEI3cmRUNi9QMkVzOWRLajhUNCsvMkJzdGI4L2Y2ODFl'
    b'bEVqTUs3MWVuMStmeCtyOVhCMmV0enFkRkRpOEo0ck5PNTFPajAKK1B4bm9jMTRxOVArLy85'
    b'eXFOSHA4ZmpvOGZlcnkrUlltTW1id2Q1c3BNOWJtc2wwcXRKNXJOT2F3ZDVhbWNsQ2lzSFI0'
    b'L0N0emVSdApwYy9YNXZLTHVObCtzTlhjNnZSUWs4WmhuY3ZZNS9MVDVQSFo2UFB4OS91QXNk'
    b'V2F3TjZEc3RhSnR0aHhwOUdad041SWpzTmZuTXQ2CnJkVGg3ZlhkNnZTMzAraDJxOUtPdWRw'
    b'dXB0QzgxdW1Zd04zbDcvZmg3UFcrMStwWW1NaDFxdEpXbDhpcHl1TmxvTTNQNHU5WGw4alcK'
    b'NXZKRGk4Rk1rTVRIM08yNjFlbkozdTNKM2UybnllS3d6dVdLdDlsa244ekczT3loeGVDdnp1'
    b'WGE2UFBQNGU5Zm5jdFZsc2R4cU5HUgp1OXRPa3NYcjh2aExrTVJGak1MSTNlMzIrZnhWbHNp'
    b'TXVObTQwK2p3OXZwam44eVR2Tnl6ME9hb3llUE00TzdsNy9aOXI5Vm1vYzJxCnkrUEUyK3pu'
    b'OFBmRDJ1dHo5bGFrQUFBQUFXSkxSMFFKOGRtbDdBQUFBQWQwU1UxRkIrY0REZzBiRk52ZUFN'
    b'MEFBQVF2U1VSQlZHamUKN1psWFZ4TkJGSUFISXlham1KaUF0RVFFS1NhSVJpTmlrQklEYXNR'
    b'WVFSRkViS3RnUjZWWVVGUXNCTHNJTnV3Rkt5cVdYK2dtQkhabQpzKzFzSXcvelBYR3lkM2Er'
    b'TXp2bDNnRUFBb0ZBSUJBSUJBS0JvQmRKc3hMUnlqQTdlVTdpV1JsTkVNNDFKcHJWdkJSSVk1'
    b'cWZXRlptCkM0eGlXYUIxVDFaYnF0VFF0SVhwTUVaNlJxYlVWcWsycXh5dnJHeTdRNHJab3B6'
    b'RkVHRnhUbTZlQkNlSFBUdEwxbkF0b2ZzUU5jc3YKS0lSeEZDMU5FM1dpdzViSTBuSzZvbjBJ'
    b'bVJVdks0R2NMRitSS2VJRW9jc3BiM2E1cHpyaE1jdHpySVM4ekY3bEVYS2ljY3VjOUt1UgpY'
    b'a3BOYXd6c0xzcWdJUGExckFhWjNySnk1UGs2dVl1eEF1dUdOV2FWVlZDRWxkVTg0eFNsUXZZ'
    b'ZTRXQjNoSmo1MWtOUjB2MThUalFPCjJWbzF0ZkZkeGN3MmJJUVNLRTNpY1lLd3RrYitscnFK'
    b'czdPSVdjQzN1VTZLMXhaUE1Kdnp5U1lGTy8xVzN1N29GUkRhVnQ4ZzZsVzcKZlVjajU0T2RD'
    b'clE4VGZ3ZFNoeXo1dUpkWEQ4M2VaUWNqQzI3TFZDaFdiMnhPZTQzeSs0V1JlZTFzOVd6UjZu'
    b'WjNuMHNwLzBIUEsyVQpzanppb090UW03QlorK0VRQUlFalJ5Y1B3KzNIMG82dk9ZRUZGRklu'
    b'Y2FlMlE2NE9oZW1OTFhKNENaaWRPajAxRFIwYnM4K0VZcWRTClp6SWEwOVdOTzlGLzlTalVP'
    b'anQ1RnZPWlZaMWpRcy83a0xRUVBRSXVlSG94SjVvV2hWcmc0dFRMdWN4S3UvbWFWYVBiN2FV'
    b'K3pBbkMKRTRxVDFNdkk2K1BNRnZLM080TzB1NUtIT3RGY1ZheVYxNCtORDJaMlRTRHJwUzRn'
    b'ZTZyeE92N3RieWpQNlpleTV4Tmo1aGRxNTBPYQozQ3pBM3FEOEd3SXdVQnEvL2liTnlnVFRT'
    b'dyt5aTRZSHNlWUZhcFJBZHM2ZElXSW0zQzZEQ2I0VlFGZEE0MjAxdFB4OEcrbWdTRVdFClpO'
    b'RGdHdEx1ampvRk0wK2VzUDZ1Y0RzS0tUL3UzVmY3R3dMUS9ZQlRUSFRpSWp2SnVvdklOeHhR'
    b'cThJT25PY3dleWpXYW9pSnpRMHoKbVhSUXpkby8za3owOWNobTFmWW8rdG5iaDBjZVUwQmxX'
    b'R2FpV2srWTJOYW5GYys2ektvYmNabUpMaWdUbzJYVytCNkhTcDAyYzRuRgpubUswREZwZkw1'
    b'V2tPUEpqWmlLNzRnQlNNRG8xMWdLOTAyVlBza2dCMnNkb1BkZjgzcTkrTW9XUGpOa2U0Y2hS'
    b'Uml0SCsydnU2ZUlpCnhTRllHTDlBanZna3piVmVJdFdvNEhWZUVOblhEWnByWWRjNGxmeGhy'
    b'eHJWdUp5UnptdTBObjdERjVYNUZnazdySVBXTzdSVXRZZTQKZzk0ajh4M1dGZXR4Qng5R0Q4'
    b'YWhBS2ZWQnpUR3JZY1ZNSHpFTHZYR09KWUZWbGFYNU92ekw0djllRjF0WXlYUDFrLzRUVytQ'
    b'UGxZZwp3THFLdDJ4QVpsakl5NnE5QysvcXBBVUd5OW1YdDU5dDVqUUEzcGh0OVYvWXFmVlhv'
    b'QnZmdUpMb2tSR3VYMThESFJtV3F2VmRUeXRBCkJhVnBCWjFBWDY4c0tWclhLYUF6MW5GeHJY'
    b'RXIwQjkvZzdCV1F5ZVlFUVpHaGJSK2pJR1o0a2dSbjliUFgyQUdvYnk5WEZvV1B3Vm0KbUlu'
    b'ZlJiaFdmM2dDSkFTM3ZlNC9IWCs5M3I4ZC85emVNVUFnRUFnRUFvRkFJQkFJaWNWLzQyY0FD'
    b'NE5DeUFVQUFBQWxkRVZZZEdSaApkR1U2WTNKbFlYUmxBREl3TWpNdE1ETXRNVFJVTVRNNk1q'
    b'YzZNakFyTURBNk1EQWRkZUtpQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtCmVRQXlNREl6TFRB'
    b'ekxURTBWREV6T2pJM09qSXdLekF3T2pBd2JDaGFIZ0FBQUFCSlJVNUVya0pnZ2c9PQoiCiAg'
    b'ICAgICBpZD0iaW1hZ2UxMzgyNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_25')

JP_25 = b64_JP_25
index.append("JP_25")
index.append("Japan Shiga")
catalog["JP_25"] = JP_25
catalog["Japan Shiga"] = JP_25
country["Japan Shiga"] = ('JP_25', '', 1)
lookup["JP_25"] = ('JP_25', '', 'Japan Shiga', 1)
lookup["Japan Shiga"] = ('JP_25', '', 'Japan Shiga', 1)
details["JP_25"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_25"] = ('JP_25', 'Japan Shiga', 1)
regional["Japan Shiga"] = ('JP_25', 'Japan Shiga', 1)
#----------------------------------------------------------------------
b64_JP_26 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5NTU3IgogICB3aWR0aD0i'
    b'MTQwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS3lvdG9fUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzOTU2MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzk1NTkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnOTU2MyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNDAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSXdBQUFCa0NBSUFBQURidFUrR0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQU8Kemts'
    b'RVFWUjQydTFkYVhSVDU1bCtycTQyUzdZMnk1SjM0d1ZEc0RHR3NMWmtnWkRRcElTR0xkQ0VU'
    b'TnFUd2pRMHpVS2JUR2JPSkpuUwpuTFl6eVVCTENVd2hHY2hrRmdmczBnU2FEaVFsUTV1RUJE'
    b'dGdqUEdHOTEyMmJPMnk5anMvZE9WN3J5d1JPdWNNbHUzdk9UN0h1cC91CmxlLzlIcjN2Kzd6'
    b'dnQ1ZzZVUElXQ0JJYkl0SUZoQ1FDUWhJaGlZQ1FSRUJJSWlRUkVKSUlDRW1FSkFKQ0VpR0pn'
    b'SkJFUUVnaUpCRVEKa2dobUVFa0tmWkpDbjBSSVNseFFJbXJOeisrNjc3VzdLUkZGU0VwUWZQ'
    b'MkZwVGtyTXJPV1pIenRSMHNJU1ltSVJVK1VMZGhlRW41ZAovbmpwd3UvTW56YVBSajlnK05i'
    b'MFlHakZzNHZCYzNJNUs3SW9DbjNWZzRTa0JIQUZZdEVkTHk2N2ZlY0NSSVVoQ2xsTE11UnFX'
    b'ZStGCmZvWmhpTHViTkNnTmlvZU8zai8va1hueFRpaDdkTjVEUis5WEdoU0VwTWxCNm16dHB2'
    b'OVlsN0hRZU9QVE1oWVp0MVNzVDdzdGRRcXIKMWlrNk9USjF0bmJUdjYrVEtDVmNrNjhYMXBQ'
    b'd05BT0FmQTYwR3lISjR0NTArcXNlT3oxNjNVSkl1a1dRS0NSYjNsMnZ6VmV6eDR3UApmUzlp'
    b'Nk5kZ0Fyd25FOFB3TkxKK0Rrb2FickIyMlU5c2ZjL245Qk4zZHl1dzVNbHlIa01CdEs2SGFa'
    b'K0FvWEM3YVMvYU5veTNhL0pVCnQrOVlRR0xTcllCY0xTdDllQzUzUFBnTDJNL0VQZHYyQVV5'
    b'dmp4K1ZicjFOcHBJUmt2N2ZVWGpmTEM0VWhjWmcydnNWRjVoZVI4Z1QKZmlsTmxoVGVtemZs'
    b'SGxtY3dPRVN4aktEcmtDVGtwbk1NSXpINGpFM2p3N1dEbVhlbnM2ZDQ3cUFvRkFMeUFvQkJ0'
    b'NTJyaVV3QXRjWApTTGtyZkpTNU9MM3g1UFdNaFliVVlwMWNLNmNveXRIdkhHMnptSzRPZ3lF'
    b'azNUVFV1YXA1bTRwblAxQ1FrcEVjOVpiWDdyVjFPM2lLCnJvdjNLSG9VbkVESzNRRGcrQisw'
    b'YjBaZ1pPSnBtbnoxRTU4OE10SHBPUWFjMXo5b2I2aHN0dlU0Q0VseG9kQW41YS9LTGJ3dlAz'
    b'dFoKUnJ3eXRrd2wweGJTUEd2ampVcms3R01aQXBCeU43TDNvdlB4aUZQblR0TVZhaVZKTVo0'
    b'NkpTTjUwUk5sQzc4N3YvZUwvdFl6blowZgpkN3RIeG9nRUJ5Mmw4MWZscXJLU3RZVWFZNWxC'
    b'TzB1Tm14dGg4THY4YkZqeXRPRGFITFoxZ1FsaUErK2tRZFJsUkFURGRjaUtBUGpkCmZvbENj'
    b'bE4vZzRHbDAyYXFHeHB0dFRyNm5SM251b0wrMEV5MHBLQXZ1UGo3NWFtenRYRzZLUWpuZWJo'
    b'ckVYSkRtZ2ZWdlpDdzBZZ1QKRHZKaUpKVmc3QnFBY1hYQUpVL3NPWFBERElVVExCNkxBN0Iv'
    b'Q0Y4M1JBb29GaUw1VGxCOEc0VTJYeDBXK3FPdGx0YXpIVFBYM2RWWApOTjcxMHRkaVNlZFQ2'
    b'SGtHWGw3WFVCTG9keUw3RnhBSkE1WDJZWXk5QWdEZWRraHplZUdyTGVMZ0hvbis4SkFUdlMv'
    b'QS9DWVlYbUlyCnkwZk9mcWpYVGJ5WHV2OXNuRnhOTWNrU3ZQVk1SeWc0d1kwTXY0SFdid2tZ'
    b'QXNENE1md0dXbFlqYUJPMDZ4Nk5zTkl1MUJpUlErMVcKb2YzYTBMd0t3NGNFREFId2RxQjFQ'
    b'WVlQUlJNYUNMV2Q2WmpjWHBwa2tqeFdiMytOU2REa3JrSFBzNGozMVhWVm8yMlQwQUlLb1Zn'
    b'RQpBTDVZSkNsdWg3eFl3SFRiSnJocjRnYWlucWZoL3BMZjFGYzk2TEY1WjNveTIvdDVuK0M0'
    b'L3graUN6eGhlUllwd2NIeFIzVHRFTENvCldTL3diM3gzcDM1QXdFSFhEamorR1BHZlVyN3E0'
    b'NHBKQXo4VjNONkZQbEp4d0dEdE1NKzVqTUgrb1ZBQ2FsQndIT1VPbE51UWV4QWkKSlFDTXZJ'
    b'MkJQWUowRmFKb2R4YzJMTDV2SE5pRGtiY0JRS1JFN2tFc3RLUGNnWUozUVd1RTRmQy8rUnBr'
    b'OE1vUXlaTmdiaDdsOVd3MwpwOHJDeUgwRDJpMEFRTkZJZXhMSmQ2QjlNenpONlA4Sm1BQjAy'
    b'K0g4RTh4SElDdUliVW5tdzBncVJmS2RzRlNpL3ljQUlKK0Rna29rCmxYSzZnL0dqWXp2UG1M'
    b'enc5NDRMUXNIdHpWaVN2SGF2MSs1bFN3RGpQbTFjQ0dzMkNocVNTakgzSXJxZWdLVVNBNjlp'
    b'NE5XSUhMQWkKWUVIUUJqcFNIUStNc3JxOGF5Y2tCZ1JzQUFQdFp1UzlCVm9sK0V6TlJvQVNS'
    b'a0Y2UEdRbXd0QkdRaFJZTFIwUnB5VE5GZllnZzVCcgpRZzZzUXNGeFpPOEZ4VXQ2QW1Zb2w0'
    b'TGhwVXFLOGdqUk5FSmVJSVRzdlNnNEhzMFFnSkJMd0JDdGdZd3R3bHE3YkluUVB3bEJFdWRT'
    b'CktCcmFiWUwzaG40VnMxQUM0M01vUGdkcFRxUm50Y2c5QUZyUDg1T0hRR3NCZ05hQlZxUDRI'
    b'SXpQSVdaSkkrcFA2TGFOZDR1NWNZVFUKN2xpWTZvYTVJYUxNbDJHdFpKMFZnSUZYRWJUQStM'
    b'd2dVUTBqZVNWS0dtSDdBSXdQcXJVUTZ3WHZLcGVqdEFXT2owR3JvVmdJY1ZxTQpQK3pyeHVB'
    b'L1lmZ2dyejlTa2ZFU2QyTlh6VE85ZGpjT2lVTHluWE5icGNtUmdPVDhNMW9mRkNhdElxaFdR'
    b'NzhUbW8yQzRnMGZ6czh3CnRCZXVhZ0JRTG9WeE41UXIyTnlJaXFyWGhXQS9CL05oV0U4SzVE'
    b'NnRRZEVwSks5a0dYVDZqcTJxOEk4RkpyMS9FbUxlWGNnZlN0TEsKMDhzajVWRnBIblRiRURE'
    b'QjB3eUUyT0RrYllmbEJNeHZJZVJBVWdtcnhUbVh0Ui90VytGcFFOQ0dvQTJlQnBpUFFwd0s1'
    b'VklCcVVFcgp6SWZSOFNpRzlzUFRFUGx3Z0pKQ3R3V0ZsVWdxNDFXREdycisxRXNzaVdkTVNl'
    b'S3RWUStwYzRWUlBlaUE2M080TDdFLzNqWTJ3bE15CnBQMDFqTTlCbWd1STRQd016WGR3UGM2'
    b'M3Y3bWZRcms4VXE5N0h1YWpZTHhzVkF1WEtzSS95dVdnVS9oWDJ2c2NGUnQvNTNmNUNVa0MK'
    b'cEM4d3JIL3pHekVIZXlJU2JoZ0RQNFA5REpnUVFrNm8xbURXTVFCbzN3eExWZXhMdEZ0UWNC'
    b'd0FPcjZOMFFxMk1XMFhNdmRBSEhjbQpudC90ZjIvSEdWTUNwTEVKUnhJQVE2bit3ZCtzbGF2'
    b'anp4VmhBcWhMWjRkY0tScmxEb2lTY0RVUHZ1N1k1MHRuWVg0SFFtNWNUbUZOClRheEgyUUNv'
    b'dUY4Rm45TjM2dnRuQjJ1SEVxZGJFbXNpQ2kyaFJmVC9ZV2xSL0V1b3YvalRLQkZGUyttRTZw'
    b'WUVJaW05M1BEZzRiV2MKeG92aDdrYlE4eFEzYzBHN2phMlFLdU92UmxJc0FRQ1JBcnJ0a0dS'
    b'Qk5nZmlOUFErajhEd0RhVG1OdytzTVM0d0pFN1BKTGh3c01QMQpSV3pob1A4dXNsOW5OWjdy'
    b'QXBwV3hoRU9uMEc1REFqQjF3M1RQZ3ovSm81d1dCWlZpU0RDSVFaV3ZyQnN3VitWOENwNjdl'
    b'aDdNVHFQCkFTRE5odjU3U05zVm5ad09IVURQTTBLZVJNamRqN1FmQ0ZtM1l1VGZNUFNyNkpJ'
    b'NUpZWm1BN0wrRWJMODhiYmFZL1dmdm42UmtNUlAKWnJkSmt5TXBwK004Mmg1RTBIRlR5U3dU'
    b'WUZXQTYzT1k5c0oxRVFDVXkyRGNEZVd5ZUlsWm5HUldoYUpUU0w2VDFYZ3UvOUhWRllsZwpU'
    b'QWxSRmlwYU80dGp5TmVEdGcwOGhpZ1lub0x4eHpIS1FtRlI3cjZFZ0JXcWU2QmN6cXB0L3J1'
    b'MlAwQWtoL3Fid3VSWEJOVWFxTmJBCjF3M1RheGg2Zy9XaVFUdmFObUJlWFhnNWhrUXBLVnd6'
    b'cSttOTYwUTRBSUJ4UHM5M0Rld1JURXJOZUFrNSsyTXo1UHdFall2UjhSZzYKdHFHK0dLN1Bl'
    b'ZVlWaEtzYTljWG9mQnp0VzNIdE5qZy9pU1hRYzVIemEyVDhQWS9YVWY3SXJMRXNqYWc3RnFs'
    b'emRGem5Xb1RXWUhnbQpacm9FMHo2MHJFYlF6aklhdEtDYkYzNkNablR2UXRES1dXZkxhcGoy'
    b'eFo0NllYaGFjRGhhTVI3YjlITjFoS1NJbGg1ZngrTHJSdEF1ClNJQkVFMVpTQnUxb2Z4aTl1'
    b'd0VSUkhJdXFMaHJlZGZKNGE0UjFNVVpQM3Azby8xaDRlZUgrMEFweUxTQ05ualphY21hUERV'
    b'aENRQmsKS2hrM016dHE3QndNck1KNnoxZzltcGJDVWdsUXlIZ1p4ZWVSZHhnaU9RQ0llWk1z'
    b'YVRYRU90QWFpSktRZHdRbHpjaDRDYUJncVVUVApVb3pWQ3o3VFVqbkJ3b0xoWDNLTmpBdVdN'
    b'NW1rdE50MGdpQVJOWUxlL1JRc3g4RUVFUEpnK0NDYWxyTUxMak5mUWNiZlFWNE0vUTdvCmR3'
    b'TGg5UlI4OGd2aGJZZCtKL1RmZzd3WW1YdVErUW9BZUpyUnRCekRoeER5Z0FuQWNodzlQeFFL'
    b'WGhrazJlTkgrcm1UdjloMjh0VmQKT2orM0Z5VkJkUjlzcHdXWlRmdFdVREtBNGV3czlYRmt2'
    b'Q3l3R3dDeUFxRW9LSUNyV21CZUdTL0QyNEdSdHhGeW9Yc1hlcDRGcUVodQp5NFA2ZnRZMEkz'
    b'V1EvcHJCbVc1Sldjc3lCY2VacjhTb2ZqSmVqcUdVZTVCM1JCQkZ3cVJPdENRQTF2Y0ZFUzd2'
    b'Q0ZMdTRWenJSSVlvCkNYOWtGa0IyMU8zTlFKTGtHbG5tWXVFYWY4Vmk1T3lQV3pOVkxrVmhs'
    b'V0NrMWRNTTkyWFdkQVFrRlFDQSt4SThqUUlPQ3F2aTEvb28KNUI1ZzU4T09mNGVXcHN1MTho'
    b'bE5VdEUzQ2tUMGhIdElleEpGcDZMZEZ5V0Y0WWNvUHNkTjJtTERmb1dBbFNpU0FGaE9DTnJE'
    b'azFMUwpmaEFkL0dRRktEck5oamQrQjlHaW9udG56ZWl5MExhVEcyNjQ5T1hQY0Y4RzQ0TTBD'
    b'NnExc1NlVFhDdUJwd0VBNW5jSmNsNWZONjdtCkFZQjhMa29hWTFVcmhtQS9DMThmS0NrVWk1'
    b'QzhNdDdzaWRFMjYzODk5TnRKWEZneG1jS0JsdExWaHk2ck1sTzBoUnBqV1pvMlh5MVkKNEVm'
    b'UlNMbWJXN3pIZzJBUldaZ2hnQi90V2N0ai9XRVR2TmNobTQyb1JXUmlBM1RiNDkwYkUySXNI'
    b'VFpUM2JDbHpXcnZkOUFTT3VnTAp6a1NTZ3I1ZzI5bk84Y01rblR4L1ZXN1IydnpzNVprMzJG'
    b'WFFQeGJnRnBHNUwvSGt3eG1rUHNZZDh2Y05jTmVHU1pJb0pQNnh3QTFHCjZKa1EwM09odisx'
    b'c1I4ZkgzV09qSGlRR0Vtak43TmlvcDZHcXBhR3FSWjJUTW0vem5ObjNGNlJrUmk5czl0aTg5'
    b'aDZIb1RSU1NtQjQKeTFwN2QwT2FFMW5ZL0RGNmY4UzlGUnJqK1M2TE9rYzFjWVRlMGUrOC9n'
    b'ZXlzUG1tWWV0eFhOaFhjK0dYTllZU3ZhNVFxOHBLRG9VWQpqOFV6MG1JWnZESzA1bWQzY2lS'
    b'SmVTRTlZRWJMS3NqeXdURHdkUXBGQVhlYXRjTlc5Y2pwOUFXRzFEazZ1VVltRWxIMlB1ZG9x'
    b'MldvCndVeTJDUGpMd1dDbzNqeFVIejJIdEs5bXNIaGRKQ1ZTcmdDdEZWVE52Uk5XNVlsVCtR'
    b'TkwvZFdEVElnWnVHd2F1R3pDRk1IVTJ4R2wKL2NOT2JpQk9KRWY2ajcvaUF1TUxvRmpuNW5Q'
    b'NjJ6N3FtbktQUFBWSTh0aThWOTl0RW5BZ1dNNFhWZU5aQnlNWG5Pb3JHcjEyTHlIcApWcURt'
    b'WDJvdDdkYUkxQmFqOENTTXU2T0xTWlFFeHQwb3JCclBmcXlkdGkvZnZESVZuM2VxYmtxb202'
    b'M2Q5TTQ2d1RpQ3Z3K1drL0EyCnN3bXNaZ01rWE5uTjUvUlZiZi85YUN2WmxQQ1c4N1R1NEww'
    b'VDl4K2FDTmVRKy9TdXMrYW0wU242cEZONEQ5YlI2NWFxUjA4UFhQb0sKa2RiL3BlbkV0dmVu'
    b'TGtPWTZsdE8rMTMrNXZmYlpDcHB2QmtqVjk2NTl0SGZuUGM1ZlpqS21QTDdnak1NMC8xSnI4'
    b'L3V5LzE2dG1COApnMEgxb2NzWGZsa3oxVGNGeDdUWllkOVVOeHowQm5KV2NOc1hmL3JQRjc4'
    b'OFVvZHBnZW56dnlvdS9ldlZLKzljQzcrdVBWWmZlNngrCjJqeWFHTk1Jbjc1MlVWZWtGWW1w'
    b'ei9aV1Q2Zm5tbFlrTVNIbW83ODlIMzVCU0VwY3VNMWptSFlnLzlPUGtFUkFTQ0lrRVJDU0NB'
    b'aEoKaENRQ1FoSUJJWW1RUkVCSUlpUVJFSklJQ0VtRUpBSkNFc0dOOEwvNitYZnBqa0paS1FB'
    b'QUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQQpNakF5TXkwd05TMHlNRlF5TVRvMU1qb3pNaXN3'
    b'TURvd01JOFlvVklBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNRFV0Ck1qQlVN'
    b'akU2TlRJNk16SXJNREE2TUREK1JSbnVBQUFBQUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJp'
    b'bWFnZTk1NjUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'JP_26')

JP_26 = b64_JP_26
index.append("JP_26")
index.append("Japan Kyoto")
catalog["JP_26"] = JP_26
catalog["Japan Kyoto"] = JP_26
country["Japan Kyoto"] = ('JP_26', '', 1)
lookup["JP_26"] = ('JP_26', '', 'Japan Kyoto', 1)
lookup["Japan Kyoto"] = ('JP_26', '', 'Japan Kyoto', 1)
details["JP_26"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_26"] = ('JP_26', 'Japan Kyoto', 1)
regional["Japan Kyoto"] = ('JP_26', 'Japan Kyoto', 1)
#----------------------------------------------------------------------
b64_JP_27 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjE5NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09zYWthX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAgeG1s'
    b'bnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2Nh'
    b'cGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0'
    b'L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAg'
    b'eG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBp'
    b'ZD0iZGVmczEyMjAxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2'
    b'aWV3MTIxOTkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTIyMDMiPgog'
    b'ICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAg'
    b'ICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRl'
    b'cmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3Bu'
    b'ZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhUbkNB'
    b'QUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZB'
    b'QUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDQ2xCTVZFVXpRWm85U3A5ZWFhOXBkTFZC'
    b'ClRxR3ByOVhsNXZMKy92Ly8vLy9kNE82dXROZGxjTFBaM096TzB1ZHNkclpBVGFDMHVkcXNz'
    b'dFk2U0o1R1U2UktWNlZMVjZiajVmSGYKNGU5RFVLSTJSSnpSMU9qVjJPbzVSNTJab00yWW44'
    b'eFFYS2o4L1AzNStmeXJzZFd5dDluMytQdnU3L2ZGeWVMSnpPVHQ3L2IxOXZwOQpoci95OC9s'
    b'L2lNQ0JpY0R6OVBsK2g3LzUrdnhjWjY1ZGFLK2VwYytncHREUTAraFVZS3BXWXF2djhQYzNS'
    b'Wnp4OHZqMjkvdEZVYU5IClZLVHQ3dmJlNE8rQWljQTFRNXRrYnJLaXFkSE4wZVpqYnJLOHdO'
    b'N2k1UEc3d04yU21zbVJtY21WbmN2THorVkVVYUpGVXFQTjBPYU4KbE1aMmdMdnA2dlJSWGFs'
    b'OWhyNDBRcG8xUXB1NnY5MjV2dDExZjd0dmViaWNvODdHeXVOMWZycnc4ZmRKVnFYbzZmVHA2'
    b'L1JyZGJiNgorLzF4ZXJpVG1zcVJtTWg0Z2J6OS9mNXlmTG5uNmZQQXhPQThTWjdCeHVCaWJi'
    b'Rzh3TjMrL3Y2enVObWpxZEdVbThxa3E5S29ydFRNCnorYkN4dUhFeU9MRHgrSGg0L0JuY2JU'
    b'ZzR2QnFkTFgxOWZvK1M2RDQrUHYwOWZuQnhlQ2xyTktab015aHA5Qm9jclIwZnJyQnhlRjAK'
    b'ZmJwaGJMSHM3ZldQbDhpZHBNK2JvczI1dmR6cTdQV0Jpc0dwcjlSOGhiNnFzTlhyN2ZYbTZQ'
    b'TnpmYnFRbDhqSnplVEt6dVdocU5FLwpUS0NDaThIMzkvdEpWYVZWWUt2cjdQWFIxZWlmcHMv'
    b'WTJ1eXZ0TmM5UzUvZDMrN1gydXV4dHRqVzJldXRzdGI5L3Y1YlpxNzQxcjB6CkFBQUFBV0pM'
    b'UjBRSWh0NlZlZ0FBQUFkMFNVMUZCK2NERGcwQ0tvRy90SDRBQUFQbVNVUkJWR2plN1pyblE5'
    b'TkFHTWJUTnBCQTJTSUYKS1RMRUFqSmt5aWl5RVVHR3JBb0tvaUtJV0JGRnRvQzRjVE9jaUFz'
    b'VjUvOG9wdVR1MGlRdEpLblhEL2Y3MWlmM1hwNDJsemZ2dlNsRgpFUWdFQW9GQUlCQUl5dEhw'
    b'RFFZOTdWMmU5RDYrRExzSjQrZXY5eHBUeGdBV0lURElLMHdGaHpDc2tOQXcvSzUyQmJBaS9N'
    b'Snh1OW9kCndVcGdpc1RyS21vUEswbTBHYXV0R0ZhR3ZUaGR4Y2JKMllxUHhXZ3JnWlZsSHo1'
    b'WGtZbUlqLzJXcEdUa1k0b09tNjBEMEVWcVd0VG0KRFpDZUFaV0QyR3lGQWcrWldRNGxPeDVJ'
    b'L3Roc3dVeWF3MHU1UU1yRFpndXVwVU84bEEra0FteTI0RW9xNUtVd0lCVmhzMlVGSG9wNQo2'
    b'VENRU3JEWktoWGZkbVZBaXZnZkRzb3JLcXRNVnF1cHFySzZISWhIZ0llYXJTeWxxd0hTVWRl'
    b'eFdoQldpMlRLNURxK25qb0d4ZnFHCmYwSmpFMVNPdTQ3VmdPWVc0WU9scGRtaHR5SUZZSVpQ'
    b'VzVvUGtrM1pmTmV4cW1tUGNTNC9XU2JYeGgzS2szOG1Kcm1MVlludGhOUloKTzdpNU8rVnRu'
    b'WFFYcTVJYzZkT2U0ZzUyeWJtcWIzY2JxMjVkTWRKVE05MWN3WlVpZmZSMGovdFlOWmpQeVAw'
    b'ZVo3bDc2bHl2MUxHNAo4OXVKVlVHZi9PcnA1d1pjR0pBb1RTOXVMMVo1RmsyV243ckVzWEly'
    b'QmtVSGpOdU5WVW9GTXRVbG85MXV2SXdJUTQ0eDlKVmg5SXpEClY0TzNINnVRYTNDaVBvY3lB'
    b'cFZLZnRSMTFOYm96bUlWTVFhL0x5K053eVFBaGszQTgwM3VORllKVTJBZUl5OU5BK2tHR0RZ'
    b'RGJSbDIKR3FzRW1KYnNvSkVGTnpkZ0dBMXRCZTgwVmdtellCNnd2NW9EVW1Ld0sxdjBUVmV4'
    b'ODU2N2lMMEdWeGR4cHRkekZ4RXUyMXU4TkFrdApXUGdhdytKYWs0aFZ0K1FyNGR3am90S1Bi'
    b'NEMwQy9iOHR4M2FIVlFUeDk1Vlphc2FtWHQ4V3FlN055bk0xaE1HbXI3L1FKaE91eFpvCmVz'
    b'WWlIQ2VLZmVpeGh3OTRManNMdmU1akhxa3N1ZXBZai9CWWJXRXo2QWxYTGFvM0dwMk05cTZZ'
    b'QmZYbDZSUHRiVDNWWW92Um9iV3IKWjVwc2ZkcHJOYjJPR20zSU51bDJXdmZQSnhZWEUrYUZX'
    b'dEZTMi9Kb3FsQ2JYMWxjdEx3UWFpOWZhYmV0TnZlWElEbm5OZGQwYjZ4Qwp6L2FHZTBIUThC'
    b'YlZtaHJsWWpYRE5yUTZaa3BKTWRXdkR2SFg0QjN5QW1OcXEzYXh3OVlJV3pNbkgrdEoxb2JG'
    b'amFRMElBMmtZMnB2CmhiOTMxWGJML0lESmxtMVczS1EwdzQyMURaTXRxZ2g0K0NodTZYN0Mx'
    b'cVQ4RER5czg5STZrTDVncy9VVmJ1K3pIWW8rRTBncjJHeVYKSWMzQTlNM2xWYmlHNU5obGJM'
    b'YStXZEhlVWYxWUFmTFJpdkhQQnlIeWo3NGxmSzZvMW5qWlNocm5hMDR2ZlNsTW1hT2xYUVdX'
    b'WTdWRgpSWlpLdVpycW9UQVR2aUYyOWIyWXdrNlk4M3QwNXNjYzVRMEVDUXJDbjBPVXQ1RDlh'
    b'K00zOTBQNWp2Nmh2QW82eTJqSXRsTUVBb0ZBCklCQUlCSUp5L2dLTlUrTTF2Y1pXL3dBQUFD'
    b'VjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TXkweE5GUXhNem93TWpvME1pc3cKTURv'
    b'd01QTEFpSWtBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNRE10TVRSVU1UTTZN'
    b'REk2TkRJck1EQTZNRENEblRBMQpBQUFBQUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJpbWFn'
    b'ZTEyMjA1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_27')

JP_27 = b64_JP_27
index.append("JP_27")
index.append("Japan Osaka")
catalog["JP_27"] = JP_27
catalog["Japan Osaka"] = JP_27
country["Japan Osaka"] = ('JP_27', '', 1)
lookup["JP_27"] = ('JP_27', '', 'Japan Osaka', 1)
lookup["Japan Osaka"] = ('JP_27', '', 'Japan Osaka', 1)
details["JP_27"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_27"] = ('JP_27', 'Japan Osaka', 1)
regional["Japan Osaka"] = ('JP_27', 'Japan Osaka', 1)
#----------------------------------------------------------------------
b64_JP_28 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4MjY3IgogICB3aWR0aD0i'
    b'MTQzIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0MyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSHlvZ29fUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzODI3MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzgyNjkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnODI3MyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNDMiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSThBQUFCa0NBTUFBQUNJUHBQZ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUM5RkJNVkVVQm9NY0JvTWNUcDhzNHROTmUKdzl1'
    b'QjBPT2IydW14NHU3SDZ2UGM4dmZqOWZudStmdjQvUDMyL1AzTTdQUzE0KytmMitwOHp1SlZ2'
    b'OWtzc05BSG9zZ2pyYzU5enVLaQozT3ZzK1B2Ly8vLzMvUDNDNlBLRzB1Uk12TmNMcE1rRG9j'
    b'Y3ByOUJid3R1TDFPYTk1dkh2K2Z1eTR1NWx4ZDBXcU13Y3FzMk4xZWJECjZmTHorL3o2L2Y2'
    b'djRlMU92ZGdGb2NnNXRkTnh5dUNwMyt6aTlQbm05dnAveitNVnA4c2FxY3lBME9PNzV2Qm54'
    b'dDNWNy9iOS92K3EKMyt3bHJjOGVxODFXd05xTzFlYkY2Zkw1L2Y2VjJPZ2JxczArdDlSMXkr'
    b'Q3Q0TzNsOWZuMSsvMEtvOGszdE5OcHg5NloyZW5ON1BUNwovdjdnOC9nUnBzdEF0OVdoM09y'
    b'VDcvVys1L0VKbzhrdXNkRlR2OWw1emVHZDJ1bnA5L3FZMmVoMnpPRlV2OWxEdWRWQnVOVkZ1'
    b'ZFpSCnZ0bHF4OTZVMStmWThQYncrZnc4dHRRcnNOQUlvOGtpck00NnRkUlB2ZGlUMStlcjRP'
    b'M3grdnhoeE53ZnE4NEVvY2c3dHRUZTgvalMKN3ZXYzJ1bmQ4dmpSN3ZYTzdmVGs5Zmwzek9G'
    b'THZOY2dyTTR3c3RGdnlkL3IrUHU1NWZDSDB1VW1yczh5c3RMRTZmS1IxdWRmdzl3QwpvTWR3'
    b'eWQvMCsvMno0KzcrLy8vYjh2ZDR6T0ZHdXRZdnNkR3c0dTdoOVBnUXBzbzJ0Tk5IdXRaSnU5'
    b'YzFzOUlkcXMwMHM5S2wzZXVGCjB1UlF2ZGd0c05HWDJPajgvdjVzeU40WHFNeDZ6ZUxYOFBh'
    b'ZTIrcGp4ZDBZcWN4S3U5ZEl1dGZxOS9xSjArVVpxY3greitLajNldVMKMXVlZzNPcHV5ZDhV'
    b'cDh2ZjgvZ09wY3AweStDbzMreFp3ZHFJMCtYSzYvTzI1TytDME9TNDVlOWN3dHNHb3NoU3Z0'
    b'bkc2dkx5K3Z6UQo3ZlVTcHNzcXI5Qk52TmlEMGVTODV2RFA3ZlFvcjlDLzUvRll3TnBDdU5V'
    b'OXR0Um94dDd0K1BzeHN0Smd3OXdNcE1tbTN1dVcyT2cvCnQ5Vmt4ZDNaOGZmbjl2cXM0TzNM'
    b'N1BUYThmY2hyTTZ1NGUxeXl1Q00xT1lOcE1ySTYvT0UwZVRBNlBFa3JjK2EyZW1RMXVkdHlO'
    b'KzMKNU85enl1QVBwY3E2NWZDazNldHJ4OTVkd3R2VTcvWkV1ZFo3emVJbnJzOVh3Tm96czlM'
    b'VzhQYkI2UEZteHQyUDFlWml4Tnhhd2R1MAo0KyttdjNHVUFBQUFBWFJTVGxQM1l6Ky8yUUFB'
    b'QUFGaVMwZEVHZXh1dFlnQUFBQUhkRWxOUlFmbkF3NFNMUzBhdmYzOUFBQUhSVWxFClFWUm8z'
    b'bU5nSEZTQWdXSFVQYVB1R1hYUHFIc29CMHpNTEt4czdCeWNYTnc4dk56Y1hIejhBb0pDd2lJ'
    b'RDRSNVJJVEZ4RGdsSmJFQksKV2taV2puN3VrVmRRVkZKV2tjUVBlRlhWMU9uZ0hnMGhUUzF0'
    b'U2VLQWpxNmVQZzNkSTJKZ2FHUXNTUm93TVRXamlYdk05U3dzZVNYSgpBVHppQ3RSMWo3Nnds'
    b'YmkxSkFYQXh0YU9XdTZ4ZDNCMDRwR2tHRGk3dUZMc0hqazNkdzlQU1dvQkwxTnY4dDNqN2VQ'
    b'cjV4OGdTVjBRCktFU09lNEtDRFVOQ3FlMFVLQWhUSU1FOTRSR1JVZEZhTVpUYXFjTVpaaFFy'
    b'RTZjV241Q1lCQWJKS2FhcEhscHA2ZUNzWmlxQzVCNzcKakV6ekxQUkVrcDJUYTJXYWx5OGRh'
    b'RU9oUXdvNHhGa0xnNHVLY2RaekpXcEsvS1ZsT1FqM2lKU0QwaFczY1VVbEh3aFVWVlJ6VXlW'
    b'aQpwUHpGYTJycmlFeVo5VmxJOGRWQTdZVFIyTlRzMEZKTWZudWpsWTlxVHVGdWErOFE3cVMw'
    b'L2FQZjFVMjVVMHg2TFBUTXFkVWVhekdpCklPWDI5dG4yVHpDamN2dHc0cVJlY3R3eTJkWTlj'
    b'UXJPMHNKK2F0STBCd2RGaCtsSk0yYnFrOXBlblRXYnREcXBRSG5PWE93UkpESlAKcUdaK1V4'
    b'cHFnMmhCdFZQMHdoeVMyb2VMRmdjUzZaWWxTNWNKeTJNemRQa0tNVnRySGR3YUYvalBLU2tt'
    b'dm4xWXZKSnRGYUdDUld0MQpMdGJFc3FaMjdTUXVZandqc1c2YVBQSHR3K0xFOVdtNFBCZTZZ'
    b'V05PRmhZOW0xYUtUYW9tSmE0M3I1MUpTdnR3VWJJbVJ3RnFZdUhiCnNMRUVXK1J2Q2Q2NnJZ'
    b'S01qTEFnUDRMRTlxR1p6L2E0SGV0amQ3QXVqTXhZaEUxQmxzL0NEZGJrbHhNMitmT28xbDR0'
    b'Rmk1MDJlbE0KYVJGcXM4MmVDdTV4MWJQbzRhWldBOUZDaEJMM3pNeGwzZFZJM2NxM0xBUFZQ'
    b'WjI3MVRLSnFRQkZoV1QyeEVqU0FQVG1oYU9FVHp5dwpWdDZ6ZXUvRWZiajZlNW43bzVZZVVL'
    b'SEl6b09IUEpTNjlrNnIxemg4ZUF1ai9PR2lJek9PK2g3YmNEd1FVa1dkT0lrU1g3SFFEQmg0'
    b'CmFxbnB3dE5uWm1XSzFtV0xpaXFjM1g5dWJmdHN5NzRGRkxuay9LazhxeEoxbkwyVkM2ZE5i'
    b'ZE1XYUY5RWRrK1dzaVN0d0JKWG92cFEKVTlWOGtOUHpKV21hT1dnV1dlMk5yTXUwY3M5bDh0'
    b'by84bEhVYUVNSFZGMXBSaGVxSTdNOVptQk5tVnVxUGVLdUFxdTNUblJqSE1sdApING9zSmpk'
    b'TGUya3B4Y05yNjJ2b09YMEsyZU9aVy9wSnJnVVdXSXQzblVWcGdHU1pvQ21KbzJCOGRZb3A4'
    b'VU1YTnRlM2JYVzdoR21xCkdKbzZybjJValBmS24vVXJJSnh1Z2FHU3RBbFhEeGk5NjhSQzRm'
    b'aXp0OE9WVVB4ZERWYTh4cWFpcWI1aGFlbkV4M2Y4SnB0U2Z6emUKSVdnODlUdFQ3bzZidDNC'
    b'VzVLdTg4Ym5IRGw4RnM2RFAxdGVPM1BIZVM4TE1TVWxKWjFxUG9PYzhYOXh0eXBXTGJ4THNO'
    b'UVdXVDVBbgp4ejF3c0JyTndOdllqQXM2MnlWdVRXeWZzbnJISFFyY280SGVNazFHYzhxRXhY'
    b'ZEpIWUplTUdrRytlTzlJV2lHYVNIaTlPeTkyYmZKCjZtbEw5cXFlSk5jOUU5RnROQUFLN3B2'
    b'bEcxMUdVZXRJNS80RE10dnpUV2dtOFhma1BhVENDTFJrYVFKNTdwbEdxd1pKcjVJK09lN3AK'
    b'cktSWmswM0xsWnoremtXYXVVZlNzNVVrOXdUNXNEeXlQY1JMdWIzY213ODlaaGYzODV0dGEr'
    b'dGhxWlYyRURFMmtJVGtuaWVxWWZ5MgpUNS9KOUQ5ZjVyRFNiUllVbkVtU1ZmVHRYNzFoMXlF'
    b'cWpJVWZMeGZibStHSzBjbnpyalBJVGRIc1NkT1JsS3BGQ2gvMUZ6U0xpYzJxCk10dm5FV3h2'
    b'NkQrWjdyc0ZLYjQ2WHg2a3VrdWNiODAvVi9LSzNQRk1zL1lGMUhNS3VNM29UZUg0YXYxcnFy'
    b'aUY4MDFYaGh4MXhuc3YKaU90UTVCVHR0bllIMUZFcmVYdTMwMi9YN3RpeDQ1bnB4bmNsWmlT'
    b'M0Q0dVUwc2tjVm5wZnJqWVB1UW5TS1pwc21uOGRyVkZ3WHRuaQp3eVhTMnF2aER1eWtqbm1k'
    b'NTErYmhKeHVpeWRldTlLR3N3a3VwWHFSaWJUMjZxYVV4OFIyVlczSy9Bb1ZrRXNWMGUyYTBn'
    b'UW5RblIwCnA4dVQxbDU5dFQrMmxHQVpyL3NSSlZpbVREUGxKM3JnckRUcU1LbnQ1MCtGNjl1'
    b'd2UzVUJaNC9NZmcyVWtiT09kajRTUjFtMTJ6VkkKYno4WFp5b3V6bU8vWlFKdWkvWEd2RDkx'
    b'dWYyalF3UktiM1RMQkF2TEFyTHlnSlNMSzludFovbkRoN0VVK212MGRyUlJNdUxydFNPSQpX'
    b'dXNUOUMrOEZTK2x2UFJzTkJTaDNEMVRraXg2VktoVnQvVFZVdUllOVFseHMvdW9YUEhlclVO'
    b'elQrZU1UVVJNRDN6NkxNUHZTWk0yCmlaZVlDR3I0VE53Y281emF0WDhHMWltVE5WOXluenVx'
    b'THFGMHBxSjMxVmZwdTJ6cmQwVDExMWhaV2RWRTdiaS9vZWZBZFdpYjgzME8KYW55Wm5ZSm13'
    b'Y21IVG5tVSt6MEQxb0E3WFB3MlRQb1c2a2x4bDhia3dPdzUzeWUwNEJqV1dPN2pJTFl0Vk1l'
    b'bS9RRksrdEdQODZKKwpQSnhYL3ZGekZsSE5vSDFURzVxUG9LWm4wZGZVZElxeFVWVHRUQXJi'
    b'UDRxbFZIRkt3SzMyMHpPcDBoNFRXV2hDb1Z1Nlh3Z21YcUxhCmVnQkdScm4rRytRM21qbU9C'
    b'WXRRZFgwQ09Jd2NPTWh4VElXZncyRXFMR1RFV2o0SDN5UXBqL2Rhei8vbHlrZ2RnS08rT0h4'
    b'T2k3angKSlltbTV2M3ExRnR5aXFmK3l1NS9qTCt6RWZQaVVXUWRJNVVCM3ZyMFZlVFROQ3lO'
    b'UHAySzErdDl6eXhpcEFVZ1dMOC9PTHN4K2pjSApKL2Y1aXR0OGp5OC8rL2d6SVZ1ZmtYWmdk'
    b'UDM4cUh0RzNUUHFubEgzREZMM0FBRGNxQkljNG1GQU9RQUFBQ1YwUlZoMFpHRjBaVHBqCmNt'
    b'VmhkR1VBTWpBeU15MHdNeTB4TkZReE9EbzBOVG8wTlNzd01Eb3dNSUtyWVY4QUFBQWxkRVZZ'
    b'ZEdSaGRHVTZiVzlrYVdaNUFESXcKTWpNdE1ETXRNVFJVTVRnNk5EVTZORFVyTURBNk1ERHo5'
    b'dG5qQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2U4Mjc1IiAvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'JP_28')

JP_28 = b64_JP_28
index.append("JP_28")
index.append("Japan Hyogo")
catalog["JP_28"] = JP_28
catalog["Japan Hyogo"] = JP_28
country["Japan Hyogo"] = ('JP_28', '', 1)
lookup["JP_28"] = ('JP_28', '', 'Japan Hyogo', 1)
lookup["Japan Hyogo"] = ('JP_28', '', 'Japan Hyogo', 1)
details["JP_28"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_28"] = ('JP_28', 'Japan Hyogo', 1)
regional["Japan Hyogo"] = ('JP_28', 'Japan Hyogo', 1)
#----------------------------------------------------------------------
b64_JP_29 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTA4NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05hcmFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMTEwOTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXcxMTA4OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMTA5MyI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUJwMUJNVkVYLy8vLzA4UERiemM3RHJLMjgK'
    b'b3FTeWxaYTJtcHk5cEtYUHZiN28zOS84Ky92eDdPM0JxYXFYYjNGdE5UaGJIQjlmSWlXQ1VW'
    b'U3NqSTdaeXN2Ky92NysvZjNOdXJxTgpZV1JlSUNOd09UenU1K2ZFcnE5M1FrV2VlWHJyNCtU'
    b'ZzFOV0FUMUZoSkNldGpZLzYrUGlwaUlsZEh5SjFRRUxoMWRhQlVWTmdJeWJsCjI5eHVOem1p'
    b'Zm9EZjB0Tm9MakdiZEhibzRPQnFNRE9nZTMyMG1KbHVOamoxOGZIczVPVmlKaW1OWVdQZTB0'
    b'S0pYRjZMWG1EZDBORGsKMnRwY0hTQ1VhbXlvaG9oOFNrMlljWEtuaFllaGZYK09ZbVJtS3k1'
    b'c05EZW1oSWJ0NXViT3U3eDZSMG0vcHFkMlFVU3ZrWktQWkdaNwpTRXIyOC9QQ3FxeGxLaTM5'
    b'L1B6czVlYW1nNFZ5UEQrNm42RFd4c2Y3K3Zwck1UVHE0K09aY25UaDF0Zng3T3laY1hPNG5a'
    b'NmtnWU8xCm1acjE4dkxCcXF0bkxDOTFRRVBuM2Q2dWo1Q1FaV2VsZ29UTnVydDVSa2kvcDZo'
    b'OFNVeVhjSExsMnR1TFgySGN6cytLWFYrZ2ZIN3kKN2UyNG5KMXFNVFJ5T3o3dTZPaUNVbFdw'
    b'aVlyaTE5ZjYrZm5Hc0xGM1EwYWZlWHVPWTJWZklTVHo3dTdEcTZ5RVZGYXRqby9jejlERgpy'
    b'N0M5bzZYUXZyL3A0ZUZaZTdEZ0FBQUFBV0pMUjBRQWlBVWRTQUFBQUFkMFNVMUZCK2NERGcw'
    b'YkZOdmVBTTBBQUFJa1NVUkJWR2plCjdabnBWMUpCRk1CSDlJbVNjbEZCeE13dDBVaEYyN0N5'
    b'Y0tVa3l5V3dBdmVsYkRGeUs0WEtyY1gxajQ2T25nUkwza3pudkR2ejRmNCsKdmZlK3pPL01t'
    b'N2x6NTE3R0NJSWdDSUlnQ0lJZ0NGMnlUTms1bXBacnpzdTNxS0owb2FEUUNuK3dGUldYMktV'
    b'N09VcWRaWEFXVjNHNQpYS21MRmZCUGJKY3E1VmxWVmNPNTFOUmVsaU5scVhOREp1b2JaRmlW'
    b'WHdFZFBHWjhxNnVOb0U4VDlwNXM5Z0lQTGJoZXJkZUFqK3VvCkVkUUZ2T1RpV2RtZDNGWlFW'
    b'b0ttZFFNRXVIa0x5Y3JYSnFLRnRyeHVDMW1CK3c2S2xRa0V1WXVpMVM2cUJmY1FyTzc3aGJV'
    b'NkVMUTYKZncvazcrcnU2UTA4NE5UeUdMOFpIUStUdy9RRmozT0lSLzE4WG8rTlB3d0JudVNm'
    b'U2c1dy9kSkJoRkE2Tkp6Ni9wVEhLeFEyV2l2ZwpIVW4vOEl4bnVnelBDSisvT0htSXdIOFFN'
    b'Y2dxT2hwVlVXdHNuS21vTldGV1Vtc3lxS2JXQ1AxRWdTVS94U2hBQ0lUVGFTVzFBbDVmCitv'
    b'Y1pKUTZmV2VpZlMzMS95V1AxeW9HUTJNeS9QazFzM25BbE5tK05Ud090QUxaM3g5SExzdkNl'
    b'YjBuRnNKTG1ENHQ5dmM2UU9ra3oKVzFMemlzR1dsYnlRc1JWUnExV2N5MzVBOExMZnJHUnA1'
    b'Q05XSVdsV3hLb1JxNUNrYXRtTmZlSXZVcTZobG5UWFZWdFlLaGZBay9NVgpWN0Zkd0ZqaXM1'
    b'NVVUWXhKd1BJbGN5dHEvaXVUUStiRzNRYVRoV056NjV3MjU3YVB5Y1Mrc1BQdEw2bDRiWUpK'
    b'NS91UDdwUW1udWZuCnJrbCtDLzJFdWIzOUEwMWJpeDBlaFJsQkVBUkJFQVJCRUFUQnl5OEty'
    b'Ny9mSy9uVmlBQUFBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUEKTWpBeU15MHdNeTB4TkZReE16'
    b'b3lOem95TUNzd01Eb3dNQjExNHFJQUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNak10'
    b'TURNdApNVFJVTVRNNk1qYzZNakFyTURBNk1EQnNLRm9lQUFBQUFFbEZUa1N1UW1DQwoiCiAg'
    b'ICAgICBpZD0iaW1hZ2UxMTA5NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_29')

JP_29 = b64_JP_29
index.append("JP_29")
index.append("Japan Nara")
catalog["JP_29"] = JP_29
catalog["Japan Nara"] = JP_29
country["Japan Nara"] = ('JP_29', '', 1)
lookup["JP_29"] = ('JP_29', '', 'Japan Nara', 1)
lookup["Japan Nara"] = ('JP_29', '', 'Japan Nara', 1)
details["JP_29"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_29"] = ('JP_29', 'Japan Nara', 1)
regional["Japan Nara"] = ('JP_29', 'Japan Nara', 1)
#----------------------------------------------------------------------
b64_JP_30 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjQ0MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1dha2F5YW1hX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczE2NDQ2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFt'
    b'ZWR2aWV3MTY0NDQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9y'
    b'PSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'c2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2Nh'
    b'cGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9k'
    b'ZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTY0NDgi'
    b'PgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAg'
    b'ICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJl'
    b'bmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdl'
    b'L3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhU'
    b'bkNBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFD'
    b'QTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDRTFCTVZFWC8vLy81K3Z2aTVlM0ww'
    b'ZURGCnpOeTR3TlQ4L2YzUjF1T1pwY0p1ZjZoRlc1QXBRMzlHWEpCdmdLbVpwc0xTMStURHk5'
    b'dDZpcTgzVUlnNFVJakV5OXp6OWZpaXJjZEMKV1k0K1ZZeVVvYi93OHZiMjkvbWJwOE0yVG9j'
    b'elRJV05tN3V6dmRJOFZJczlWWXUwdmRMcDdQSm9lcVhJejk0N1VvcWNxTVFyUklDZQpxc1g5'
    b'L3Y2RWs3V0ZsTGIrL3Y1L2pySjZpN0NCa0xTZHFjU2dyTWJDeWRvc1JZSHM3dlByN2ZOa2Q2'
    b'Sm5lcVN4dXRDMnY5TS9Wb3owCjlmaVhwTUh5OVBjMlQ0Znk4L2VhcDhNNlVvbFFaWlptZWFS'
    b'UFpKWTVVWWxFVzQ5SFhwR1Zvc0RZM09mWDNPZEdYWkhEeXR1bXNjcjcKKy95a3I4azdVNHBa'
    b'Ylp6dThQVmRjWjU5amJGeGdxcHdncXJQMWVKYWJwejYrL3pUMmVXZXFjVnJmYWVrcjhoSlg1'
    b'TDMrUHJoNU8zWQozZWpXMitiazUrL08xT0xRMXVQQXlObFFacGU4eE5kbGVLTy94OW01d3RV'
    b'eVM0V3p2Tkc5eGRmOC9QM0d6ZDFVYVpubjZ2SFQyT1RqCjUrNHFSSDhzUm9GcGU2WHg4dll3'
    b'U1lPcXRjd3hTb1NmcThiaTV1NzQrZnVKbDdoVGFKakJ5TnJKME44MVRZYm82L0h2OGZWbGQ2'
    b'TjIKaDYzVjJ1WXZTSU93dXRDdXQ4N2Q0dXRNWXBSQldJNTdpN0JJWHBMWjN1aGdkS0R0Ny9U'
    b'ZzVPeHFmYWFwdE13dFI0Syt4dGpNMHVESAp6dDN0OFBSaGRLRmlkYUZjY0o2QWtMUE4wK0dv'
    b'c3N2ZjQreExZSlBiMytsMGhhd3VSNEpEV285QVY0MWVjWi9tNmZCVmFwcFJacGQrCmpiSjNp'
    b'SzRtY0VPV0FBQUFBV0pMUjBRQWlBVWRTQUFBQUFkMFNVMUZCK2NERGc0WktNVEJvSkVBQUFO'
    b'TFNVUkJWR2plN1puNU41UlIKR01mdjJDYnVLTU5ZaHFsQk5BbWpaRWxSWklzc1UwUkZ5d2hS'
    b'b2FGc0pVTnBYN1JUYWQvM1B6RlNhT2E1TnpQSGM5L1hPZmZ6NjN6UAplVDdublh1Zis5ejNK'
    b'VVFpa1Vna0VvbEVzZ3pRK1BqNitmdjcrZnBvMUdJVW9GMFJHRVRuMEFXdlhCV2d1Rk9JUHBT'
    b'NkVhWTNLR2tXCkhoRkpHVVFab3hXU2lqR3RwaHpXbU1PVnNJcU5vLzhoZnExd3FZUkV1Z2dT'
    b'RThSYXJZdWlpOElTSXRKcWZSSmRKRWtiaEVrbHAxQVAKU0UwV1kyVk5veDZ4VVl6WEp1b2hL'
    b'U0tzMHFuSGJNYTN5c2owWENzVGZUOW14VkV2c0dRakwvY3QxQ3R5Y0xXMlVpL1poam95eEh1'
    b'cgpsWnVIcUdXa1hyTWR6MnBIcVBkYStRVm9XanM1WlF1TGNvcExTam1CZExRSmVSZXJaRm41'
    b'N3RsSWhiR1NsZEZoblVGVmpJSngxYmI1CmtHM1BYa2JNZ0tTbGg4dlZ1UFRLMm4xd3JnN0h5'
    b'aFlHVnF0M3V4cHE5c09yRCtjMmRBQXNkaEM0c0RiQXo2c1JSY3NFcnFzc0tKcHQKZ2JLSFVM'
    b'UU9RNldxNGV3UktCdUlvZ1Z0L1RJYm5HM1FBZUdqR0ZaMjZGcFI3c2t4bFlueDNxUUorbCtP'
    b'c2RMTlVMb0ZRYXNWMnZQcwp3UXpxSnNjUnROcUFPdTNzZUJFUXowRFFPZ0hVS1diSFR3THhV'
    b'd2hhSFVDZHppNVd1cXNUaUo4V2RsQ25OVUJaaHhrTWR3czdlMmdQCnNMM08xTURaczZJYXhN'
    b'eGx5KzBaZEZzWTBWNk1BWUoxYiswei96UGdXVTJzWUw4RG84MEhNZWZoZ2NINTFPQUFNMWFH'
    b'Y2lZR3MrZjAKeUxsVlUxSEpUdFVMZnlkeTd2eWY2KzBRSjNRQlJXdFl4N3R3MVRrSmNkYnhF'
    b'cnBobkttWnMyeW1HU0c5bzd6ZkZ5N0FKWDR4d3R4awp0Qy9WZGpHTUkrV3lYWmVZUzR5WEVH'
    b'TWRWaFB2TlcraGdhQnlHV3pnN1UxWHJ2TCt3SjRXZ2d4MDNGMnpYdy9pV2NFSDV4SVQ2eklj'
    b'CjNJZ2dOM2w5WWVpV21EZmd0KzhzckRxdWRkN2xQYXA3OTBWOUw4aGJjRzErOFBCUkVjL3Fj'
    b'UUVSeDhUazNMNS9rcytSNmpkWmlVaWUKL3Y0V1ZWb1ZZT1QxQmNzeklwaXA1NVNPOWs2OTRQ'
    b'MkJMeE9JY0J3anJ6U3ZjM21OZmNSQkZPSE5KTWRxcklNb3hOc1N0dFc3OTBReAo3SHFXMVlj'
    b'WW9pUVRIK0crUUJTbThaTzcxZWRXb2ppMWJsK252bVFURmVEU1VmdFNIVVFkdElXcW9TKzQ4'
    b'L1hiWDZ2dlBrUkZPSC9NCld2MjBFM1V4TXdsT0Q0U3FvMWszcmlVcUpEcWFTQ1FTaVVRaWtV'
    b'aVdDYjhBOCs3YlFrQTkzZndBQUFBbGRFVllkR1JoZEdVNlkzSmwKWVhSbEFESXdNak10TURN'
    b'dE1UUlVNVFE2TWpVNk5EQXJNREE2TURDaW5EMUFBQUFBSlhSRldIUmtZWFJsT20xdlpHbG1l'
    b'UUF5TURJegpMVEF6TFRFMFZERTBPakkxT2pRd0t6QXdPakF3MDhHRi9BQUFBQUJKUlU1RXJr'
    b'SmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTE2NDUwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_30')

JP_30 = b64_JP_30
index.append("JP_30")
index.append("Japan Wakayama")
catalog["JP_30"] = JP_30
catalog["Japan Wakayama"] = JP_30
country["Japan Wakayama"] = ('JP_30', '', 1)
lookup["JP_30"] = ('JP_30', '', 'Japan Wakayama', 1)
lookup["Japan Wakayama"] = ('JP_30', '', 'Japan Wakayama', 1)
details["JP_30"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_30"] = ('JP_30', 'Japan Wakayama', 1)
regional["Japan Wakayama"] = ('JP_30', 'Japan Wakayama', 1)
#----------------------------------------------------------------------
b64_JP_31 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTc4MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1RvdHRvcmlfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTU3ODYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxNTc4NCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNTc4OCI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRu'
    b'Q0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNCMUJNVkVVdU1vdzFPSkJqWnFsMGQ3'
    b'TlgKV3FOOWY3ZnI2L1QvLy8vWDJPbFJWWjlCUkphL3dOenM3ZlZFU0poeWRiSHU3dmFucWM4'
    b'NlBwT3JyZEhoNGU1bmFhdm82UEwxOWZvMQpPWkNkbjhuOS9mNzI5dm92TTR4L2dybkx6T0sz'
    b'dU5mcjdQUlNWYUNJaXI2OXY5c3dOSTN4OGZkWlhLTTJPcEZkWUtaNmZiYVVsc1NpCm84eVZs'
    b'OFdQa2NIMzkvcGJYcVdjbnNqVzErajgvUDJ3c3RRN1A1UEZ4dDl2Y3JBek40KzV1OWs5UUpS'
    b'Z1k2aVdtTVhNemVQNStmeG4KYXF6VDFPZnY4UGJqNVBEVjF1aXNydEZ1Y2EranBjeHFiYTJr'
    b'cHMzaTQrOTdmcll5Tm83YTIrdisvditlb01xdHI5Sk9VWjVBUkpadApjSzl3YzdHNHVkajQr'
    b'UHRpWmFoTVVKM2c0TzZyck5GemRyTGUzKzJscDgycHE5RHc4ZmZ5OHZnME9JOUdTWm50N2ZV'
    b'NVBKSndjckJyCmJxNThmcmVMamIvSXllR3VyOUpWV2FMYjNPdlUxZWgrZ2JpTGpyOWlaYWxO'
    b'VVoyQ2hicjcrLzNkM3UxNWZMVTVQWkxaMnVxaXBNeVEKa3NKSFM1b3hOWTdQME9XWm04ZlEw'
    b'ZVZJVEpyUzArWm9hNno0K2Z0SFNwcjA5Zm5Mek9PWW1zYXZzTk5yYmEzaDR1OWVZYWVLakwr'
    b'TwprTUU4UUpUTnp1TkxUcHltcDg2b3FzLzYrdnhtYWF0S1RacytRWldFaHJ2RHhONTlnTGlT'
    b'bE1QR3lPQkNSWmMvUTVYbTV2RmZZcWRRClZKOVBVcDdsNWZISnl1SGs1UEJXV2FLMHRkWlFV'
    b'NTdLeStLRmg3eGFYYVN2c2ROcGJLeWdvc3QxZUxOMGRySmhaS2pFUDhhR0FBQUEKQVdKTFIw'
    b'UUhGbUdJNndBQUFBZDBTVTFGQitjRERnNHFFdmFtSEJNQUFBTWhTVVJCVkdqZTdabjVWMUpC'
    b'Rk1lSFNNY3REU3hseWJSSQp6SkNVU0FPMXNMS1V5SVZJb2xMTExLTkZzN0tWVk1wc0w5djNm'
    b'Uy83STN1bk9uYm53WHMrUGMwdzV6U2ZYL21lY3ovY2daazM5eUVrCkVBZ0VBb0ZBOEQram02'
    b'T2Z5NTlWV2pyR09DT1RMNm1zYlB5TG5IazhXZVhtNFQvTTUwZktZTVJUNUhOanRXRGhYeXRj'
    b'd0lsVW9ja00KckxDRkR5dnJJcE5FRVc5YXYxbk1wWmExbUV1dEVzeWwxaEkrdFpaeXFXVmJ4'
    b'cVZXcVd6ZnNwY3RMMTloMUlyRFRrbXJBbWc1VjFaVwp1ZkFNV09XbTFhM1ZlTllVVjFOYnd4'
    b'ckxySzNXZU9qOXRMd2N0a3FpbHNOV1NkUngyQ3BwTzZqbnNGVUlyZVd3VlJJbURsc2xzWTdE'
    b'ClZrbjNDM1BTMnI2R2pQWEoyZUJtWUlVMkppcmxORzd5b0JTeldTN1YxT3puNFBGaEN5a1Yy'
    b'RnBJWHJkYkdraWFXbGxZdFFVSUsyZDcKUWlMb0k4VzNzZERTRXlWRDI1TkVPc0pFeHN5aVhU'
    b'dUlGWXdrelhoMkVsNjdHR2psdzRLN0ZVSWRuVERWMVUzZGFnK3N0N2RIS2JhUAphRmN2ZGEz'
    b'OXNOd0I1VndmekxWUTF6b0lieGNHNVZ3VWFvV3BheDJDQjdCYThERDBhcU5zMVEwUHhDTnF5'
    b'YU5RcTUreTFnQXNGbFZMClpzTGtNZHFEUUZqTW9KYjBENEprTFdXdFhMaDdxMGVQTTl4UTRm'
    b'NFFVSTlXZ2FpUnN0WUp1SWduVmFOREdrNkRmMFVRYWcyb1JwdEEKOGhSbExhL212MzBQM0Vw'
    b'T1U5WTZBN1VjbXI5QU0yV3RzeUZRN0p4YThqelVLcVY5K01UZ0RuRkJ4UisrNlhEWmFXczFZ'
    b'bTEvTU9MSgpacGo2VVQwQ3k0M0dsV0k2NHJtNWtycVc3aUtzZDhtbUVCdkRUSDlhQ0YwbUNp'
    b'b2NkdVB3UU1SWEdEekxYeVZ2aWRlU1pjcWNST2c2Cml4dFpqTHdGT2hMWFVWOUFKQ3czV0dq'
    b'MXl1NzZOMi9KUmllM1pRRVRtOXQrbjZ5czh3NDRIQTBWbmZKUmpwdU5Wc21FZkRoaXJodTcK'
    b'ZSsrK1BkNy80R0hDWi9nUnErSEk0NW5NM0o1WVdXblppclJicFQ5bE4wdDY5bHlyVmYwTGxq'
    b'T3VsM25hck13UnRyTzNxRStMbFN1Tgo5VXp3MWV2cHJVTFZpRGxaYjZhemV2c09wUUJidWZw'
    b'TGx2ZXBHajUvK0tnc0ZSNUhxV05rV0dIOVBxVjRKdjc1UzVmY2FTSTdhRU1wCnArYnJ0OWpV'
    b'Zldod3lQamRnM2pCR3ZlMlQwNUdmclQ2a1VBZ0VBZ0VBb0VnQ1Q4QllxcWRsaERKaVU0QUFB'
    b'QWxkRVZZZEdSaGRHVTYKWTNKbFlYUmxBREl3TWpNdE1ETXRNVFJVTVRRNk5ESTZNVGdyTURB'
    b'Nk1ERFQrcXg1QUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeQpNREl6TFRBekxURTBWREUw'
    b'T2pReU9qRTRLekF3T2pBd29xY1V4UUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBpZD0i'
    b'aW1hZ2UxNTc5MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_31')

JP_31 = b64_JP_31
index.append("JP_31")
index.append("Japan Tottori")
catalog["JP_31"] = JP_31
catalog["Japan Tottori"] = JP_31
country["Japan Tottori"] = ('JP_31', '', 1)
lookup["JP_31"] = ('JP_31', '', 'Japan Tottori', 1)
lookup["Japan Tottori"] = ('JP_31', '', 'Japan Tottori', 1)
details["JP_31"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_31"] = ('JP_31', 'Japan Tottori', 1)
regional["Japan Tottori"] = ('JP_31', 'Japan Tottori', 1)
#----------------------------------------------------------------------
b64_JP_32 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMzgzMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NoaW1hbmVfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTM4MzYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxMzgzNCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMzgzOCI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRu'
    b'Q0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUJaVkJNVkVXVkFCZWhHUlREWGczZmxn'
    b'ZngKdXdQNHlRTDgwQUh2dHdQZ21RZWZGUlhXaEFuOTB3RC8xd0QrMUFEWWh3bWZGQlczUkJE'
    b'NXl3RzNSUkRCV2czLzFnRCsxUURDV3cyNQpTUSsxUVJENXlnSDR5Z0doR0JUWmlRalZnUW45'
    b'MUFERllRM3d1UU82U3crZEVSVzZTZy96dmdQZmxRZWZFeFdkRUJYeXZRUGZsd2Z3CnVBTzdU'
    b'Zyt3TnhHeE9SR1lCeGI3endIeHVnTzhUZys2VEEvdXRRVGhtUWZnbUFmRVhnMmdGaFdlRWhX'
    b'N1RRL3p2d1BCV1EzWGhnbWkKR2hUQ1hBM3Z0Z1RobWdhZ0Z4V3dPQkhFWUEyMVFoQzJReEN5'
    b'T3hIWWlRajZ6QUhLYXd5M1JoQzRSdy9TZkFyQldRNldBeGZka2dmVQpmd21aQ0JibnB3WDZ6'
    b'Z0g0eUFMWWlBalZnZ21jRHhYbXBBV2lHeFQ5MGdIeXZBT25KUk9wS0JQMXdnS3dOaEg4MFFH'
    b'eE9CSGVsQWZHClpBejZ6UUc4VHcrcEtSUHBxUVdlRXhYVmd3bmhtd2ExUUJDWEF4ZXpQUkcw'
    b'UHhDNFNBL1VnQW5EWFEzdXRBVEFXQTczeHdMWGhRbi8KLy85b1RFSWVBQUFBQVdKTFIwUjJN'
    b'V1BKUVFBQUFBZDBTVTFGQitjRERnb3hPSU1pdG9NQUFBT3BTVVJCVkdqZTdabjVVOXBBRk1j'
    b'WApLbkl0SWtKRVNhSGM0RkZPRlR5S2dtSTlXbHUwMW9yVlZxb3RWbnZZNC85dlNIWmpqbldt'
    b'dnlTYkdmZjdnL3BpWnZZenU4bDczL2NDCkFCTVRFeE1URXhNVEV4UFRBNWJOL21qSU1leDAy'
    b'ZDFXZ3ZKNElaSnZ4RzhWcWxFSFZDZ3daZzJxWUFpcXhJMWJnU3JNUVkxQ0UvU3AKL0pOUXB3'
    b'aFBIZXN4SkNoS2ZiTmlKQ3d2N2UxNmdrbmlDWGN5bGNaUmtESldCbE5sQjFFdWo4SXB5bGpU'
    b'aUdOR0NsT1lrakxXN0ZOSgpCZlNvNFhmUldsaHVoRldrakZWQ0hHVXByS0N3U2hsckRqOU1Z'
    b'b1ZPNGxkeG5qTFdncHdnS3JYNjRoS09saWxqOFQ1U092VlJ0MTByCjFpayt6eHF1K0dSeGRh'
    b'M1JGQ3dnb1ZRSGhBZk50ckJXYXJXbU0rdFo4NzBvNTZtQmpaQ1dpbXVEWnlPRHc5M2NGSDdF'
    b'bnBzQzFsWnQKejFZYmJFT2REZHlSN2hHeGhOeTZhenhWUSt0RkcrQUZ2QWNVWVVIdXBkRlV1'
    b'em92eW0zc3ZicUxZdEhhM211b3dZS2h0ckZVN2kzQwpBOTdzN0l0L0hGVG5sbm5ReVVBZEZu'
    b'eGpyQUU3SktXRHR5QlhIZndXN3poNkJ3bFl3ajFHYmhZeGVjWjR3Qzhock9NcUpHSjFqZHd1'
    b'CnVkU2NoUDMrVkY3aFJkOUhSS3pUc3p1bytFeWhVTWFsSERZTXhIS2hOZkpIb2hmRmhYbE9D'
    b'RDU4RkxET0F3b3FNVjM1NHlqc0dZamwKUkd1azFEYkdLZldMSU5GVm5HQkN1bWNSaFNVRHNZ'
    b'cG9qYVFVMW5HcUVxTjF1eXA1b0ZsRURiK0xCbUxoWVFNeUNFMVZMLzFwWGJ4NApRVVkzMHEr'
    b'ZW9EVXFVamlqb09vbVFPaFMyWFJvRHRGSXY2cHV2L3dsUlU0OUJ3QjZONFdyYStoS09pZjYx'
    b'U1VUV2pTNy9KcVZDNFhMCm9UdXFzMVBodjhKRDlsa29tdmhhUHVWM0o5Sm1KQWkrUzBxVndn'
    b'a2RBeEVMbmgwRG50ait4d3gxTng0aTFwYzZRRmd3M2dkWEpDeVAKc2RiZFFjREtkSUN0OGRW'
    b'NUlBYjdIVDZncDVyc0cyc2hya002ckpVYlBxbzR1UG1iYjdyS3lSayt1RnptTkZqYjRMdmF6'
    b'bCtCaHNhVQpoVXdZNFB5SXFBenhHTEJyemZ3MmFLdHNtZVBhRERPZlBmVEs3WU9IQjZNNnZ3'
    b'cDNnUHRLUGtqdlQ3Tm1jUDJGM25TckZYZmRDZ3ZXCkxzaXowMXJROWFzWWNVNEY2UXdHVjh4'
    b'UEIvK2hKbmVQWDZXclc3blVoSlB1QlBaODhKWXlGaTdNSjZKZnpXSXVGMlVzN0ZmRFVsaTIK'
    b'eU95MHFQYWlCVFN6bktXTUZiRW1WbHpkZEZ3cW13NktrbHUwbk1xdjlpaGp5VjQwWGFuWEZt'
    b'VVhiYWVNWmZNU1AwWFZhYWQ1b2hjZApvVTBGK0lpZXl0R25qa1dZbmZvczhSRjlYT3RGZndO'
    b'TGFGUmxtdjlNQUlzbysxZjJvdDBvRDZ5amJHTnFkZGdSN3cwK0lEQXhNVEV4Ck1URXhNVEV4'
    b'UFZ6OUE0azlvUTFncGtSWEFBQUFKWFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl6TFRBekxU'
    b'RTBWREV3T2pRNU9qVTIKS3pBd09qQXdQOVpJdndBQUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5r'
    b'QU1qQXlNeTB3TXkweE5GUXhNRG8wT1RvMU5pc3dNRG93TUU2TAo4QU1BQUFBQVNVVk9SSzVD'
    b'WUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxMzg0MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_32')

JP_32 = b64_JP_32
index.append("JP_32")
index.append("Japan Shimane")
catalog["JP_32"] = JP_32
catalog["Japan Shimane"] = JP_32
country["Japan Shimane"] = ('JP_32', '', 1)
lookup["JP_32"] = ('JP_32', '', 'Japan Shimane', 1)
lookup["Japan Shimane"] = ('JP_32', '', 'Japan Shimane', 1)
details["JP_32"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_32"] = ('JP_32', 'Japan Shimane', 1)
regional["Japan Shimane"] = ('JP_32', 'Japan Shimane', 1)
#----------------------------------------------------------------------
b64_JP_33 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjA0NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09rYXlhbWFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTIwNTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxMjA0OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMjA1MyI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRu'
    b'Q0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNWVkJNVkVWbEFHVm5BMlNBSmxpZ1VV'
    b'cTMKZEQzQ2d6ak1rVFBYbnkvT2t6UEVoVGU3ZVR5cVlFV05PRkZ4RVY5d0VGK2pWa2ZXbnkv'
    b'NHpoLysxaHp0dmlUQWdEbVFQRkZwQldTTQpOMUxSbURINzBoMzB5U0M2ZHoxMEZWN1pvaTc1'
    b'eng2OWV6dHlFbDV2RG1EeHhDS1hSVTZYUmszeHhDUEZoemRxQ0dKbUFXVzJjajc4CjB4M3d3'
    b'eUxhcEMxcEJtUElpelhBZ0RweUVsL2pzQ2wxRmw3VW5DL2pzU2h0REdIVG1qQm5BMk85ZkRx'
    b'VVFVLzkxUnlUUVU3d3dpUFMKbVRGNkhWekdpRGZRbGpKN0gxclBsVEorSWxtRUsxZDlJbG5M'
    b'a0RTTk4xTGtzaWpSbHpKM0dWekxqelhab3kxb0JHU3BYMFQxeVNDTQpObE40R2x5OGVqejkx'
    b'QjF6RkY1MkYxMzB5Q0hudGllUVBGQ29YVVdiUzB5RUxGYmNweXpnclNxSk1sU1lSazMzelIr'
    b'eGEwREZoamo2CjBCNmZVVXBtQW1Tc1lrVGZxeXFITDFXREtsYmJwUzJlVDBwd0QyRHl4U0tD'
    b'S0ZmaXJ5cUtNMVNGTEZiZHFTdmVxaXVHTFZhQkoxZXYKWjBLWVIwenN2aVR2d1NPalZraWVV'
    b'RW5wdVNac0NXTDJ5aUNPT1ZIbHRDZlZuVEI4SUZyb3R5ZVNQbENBSlZsNkhWdTJjVC9IaWph'
    b'MApiei9xdWlWNUhGenV2eVQyeXlENXpoOXNDbUd0WkVQM3pDRDYwUjNZb1M3dXdDUE9sRExy'
    b'dXlXVlEwN1hvQzdsc3lqb3VDYVNQMCszCmN6NktORlBpcnlubXRDaVBPMUdCSjFpZ1VrbWtW'
    b'MGVtV2tlSE1GUnpFMS9Na0RTR0xsWGNwaTNnckN2enhpS2hVMG1wWGtYVW16RFcKbmpDblhF'
    b'WDgweDZjVEV0ckNHTEtqalhJaWpaMUYxM0pqVFJxQjJQenh5R1RRRS9ocmlxcllVU1ZRazl2'
    b'RFdHV1JFNkRLVmUxY0QrNQpkangzR0YzVG1qR25XMGIvLy8rYVVtWDBBQUFBQVdKTFIwVEcr'
    b'Z0o2elFBQUFBZDBTVTFGQitjRkV4WXFGczdOVUNBQUFBUklTVVJCClZHamU3Vm5wZnd0QkdK'
    b'NW9TWkdxamxLcXFEcDZzRlZGRVNRUmVoS2hyUkxxcU5vaVZYVzJkZFlkdEZSZFVWVzNLdXFv'
    b'czNYVitYL1oKN094bUo3dEo1RU5uNHNNOG4yYWVlZmYzUHI5M2Q5NTUzMWtBR0JnWUdCZ1lH'
    b'QmdZR0JnWUdFS0Fia0JFNU1CQmVuM1U0Q0ZERGRILwpoNlpoTWNOaklZNFJjU05IaFZ0VS9P'
    b'Z3hVSXVFc1lsaEZUVU9Cc0Q0Q1VuaEVqVXhEZ1pCOHFUd3FKbzhCUWJIMUJUNm9sTFRWQ0xT'
    b'CnAwMUxWMUhUSjlKV3hXWDRLcGlSNldFelovaXlNN1BvcWhvMVN4V1lOTVNyUXpoN0R0VTNP'
    b'QldHSmd0bXo2VW9LeEtHS2d2T282ZHEKdnV6VEdGaVdkMmtCTFZYUkN5V1BpMHhtWXdCWmxz'
    b'VldPWDhSekt0TGxucVJZOHFWWFF0SFgxNitQMW41ZWNKZUxaRE1jazA1eXROTAorbFZXNFRK'
    b'dHRsek9lVlpzSyt4cVdmWVZOakdIVE5jK3M2eXduK08xY3FiS2czMlZYRUlVRmVPeWpPWVNh'
    b'V0YxcWVxUk5XdjcvejNPCmRkaDlmS3hUbHRhWEtiSTJiRlQ0VFQ0UGJDNG5VKytVYkZGMkhx'
    b'elltcXFzOERHVmFGQVp3MlBaYld1RlltL2NVa0xzeXhmQ29tRGIKOXVER081eVlNUjdFL2dk'
    b'ZmxZd0Z3QnhrNys4c3dnN3VVb2VPZEpHRnUwc0k1STZ2cWxhc2lzMlpGTExwTG56ajErejJa'
    b'N0puTDJheQpiejk1VFFkcU9aQmFWNDk1dFdoU1VhSVoyeG9IRC9HQXF6MUFXTlpoZUtRT2dL'
    b'UGxGZmpHNTNBTG0rT1lzamFtU0toc0dvN0RLc0t5ClBHbjhoSENDbkZ5RUJlelVhY1ZBUG8x'
    b'RTZNOEFjTllpREZ5RVpaMFRjOVo1WWJUZ0F2NG1HNlhFYnNiSUprK016b3R4UFVkWUZxb0wK'
    b'TG5xR0tlWGpGUW1YMHBvRjVuS0x3bHdwYXZaWUljWktXTlpWMGNzMU5ERmR4Mkp6dysyK2dV'
    b'MnZtNUROTlhGMms0cXNFZkxVME9xLwpGN3ZWSmxzMFVaRmxRVm5iLzc2VEVZdnRUVHVWbDRq'
    b'Nk1DUFdtR2JoV1VxVHlZNGlpdlFuZnh1NU9ZTno3WGR3VVhmdjRXdjNFVWs2ClFUeEFiaDRH'
    b'T2dFVEhMNGQyQ05FSHlZczY3RlUvUHF2RjR6bUR0WENFMlRmU2JxZFJsZHN5YW1hNnVvcGhN'
    b'OGVheXFKNTZKNWk0MzAKV1MxMStkcXFuTy9xNGpWa205UzVFUzhoWGlCSEwwT3pmb1dzWHhP'
    b'WGxkU05QTjBQeFhnQXloM2RIZVFycnRFd1FJSnNiOWRRVXBsaApvVkNjTmtpcDRJMTZ3YmxY'
    b'dlErcUpOTjRHbGNRVXZkVHJlb3YzQkM2ZlprT3RBMmhrOHJOaUVHS2dmTXR6dXFFUTd2VnAr'
    b'RjQrNVJtCnNBQjRKN2tyd0xOUmw0ZDVnQmZQMGtjSTMxTzZTUG9nM3kxODdQRnlQV0xYVWE4'
    b'UUtmSmxTaSsxUHdlZjVKcmhjNk5NVlNMaWl6eGYKdlUvdWNiL1N1dzRjSzUvTTFkSlgvcTFY'
    b'Q3MwM05PL3pudDJSRk85T2VlVzZTLy9kUTdqazZRL3hmTHpwWFk3U1VaUUZ1Qk5LS3gvVgp4'
    b'MlY1LzVIRlpuR1RyTVhleFZrY29Bb3VGNnY4U211dzdoKy9hM3RIV1pXUXAzNGEvL0hMQnhv'
    b'amVVQWY4M3VEcTdKdkFtRkJvam1ZCktzc3ZFQzRZeWdLSmNzYURjTUpRMEszVjFHM0pBK0ZH'
    b'aHlON3M4K0Y4dTgvU2VDL2dLMHp3cFZoMWV1dEdhNklUaHRnWUdCZ1lHQmcKWUdCZ1lHQmdD'
    b'QUYvQVVYZEVsazNMaXJiQUFBQUpYUkZXSFJrWVhSbE9tTnlaV0YwWlFBeU1ESXpMVEExTFRF'
    b'NVZESXlPalF5T2pJeQpLekF3T2pBd3NSZEhtQUFBQUNWMFJWaDBaR0YwWlRwdGIyUnBabmtB'
    b'TWpBeU15MHdOUzB4T1ZReU1qbzBNam95TWlzd01Eb3dNTUJLCi95UUFBQUFBU1VWT1JLNUNZ'
    b'SUk9CiIKICAgICAgIGlkPSJpbWFnZTEyMDU1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_33')

JP_33 = b64_JP_33
index.append("JP_33")
index.append("Japan Okayama")
catalog["JP_33"] = JP_33
catalog["Japan Okayama"] = JP_33
country["Japan Okayama"] = ('JP_33', '', 1)
lookup["JP_33"] = ('JP_33', '', 'Japan Okayama', 1)
lookup["Japan Okayama"] = ('JP_33', '', 'Japan Okayama', 1)
details["JP_33"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_33"] = ('JP_33', 'Japan Okayama', 1)
regional["Japan Okayama"] = ('JP_33', 'Japan Okayama', 1)
#----------------------------------------------------------------------
b64_JP_34 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4MTE3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSGlyb3NoaW1hX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczgxMjEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXc4MTE5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0i'
    b'IzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNo'
    b'YWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9'
    b'ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzgxMjMiPgog'
    b'ICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAg'
    b'ICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRl'
    b'cmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3Bu'
    b'ZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhUbkNB'
    b'QUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZB'
    b'QUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDQ2xCTVZFV3JOMGl2UVZIRWNuN1VsNkRp'
    b'CnU4SHQxTmoyNnV6Nzl2Yi8vLy82OHZUMjZldmVzYmk1V21pMFRWelFrSm5zMGRYKy9Qeisv'
    b'Zjdqdk1LN1hXckJiSG5sd2NiKy9mM3gKM04rN1htekJhM2ZzMHRYZXNMZXVQVTdqdmNQWW9x'
    b'cXJPRW5IZW9YNThmTGd0Ynl0UEV6ZXNiZnUxdHF4UkZUcjBOU3pTVm53Mjk3Zgpzcm13UTFQ'
    b'dzJ0MjZYR3F0UEUzdDA5ZlVtS0hKZjRxelMxcjU4dk96U2xtdlFGRGt2c1AvL3Y2dE8weTZX'
    b'bWpBYUhYODkvaXZRRkh0CjFkaStaWEswUzF2RmRvSG54Y3JEYjN6Vm02TzhZRzIwVEZ2V25x'
    b'Ym95YzIxVDE3U2s1ejgrUG5yejlPOVltL1BqWmY2OC9Td1JGUHoKNU9iQWFYYlNsSjNYbjZm'
    b'Vm1xTHk0T093UWxLNVdHYml1c0NzT1VueTRlVHUxZG5odUw3czB0YmZzN25tdzhpeFJWVzNW'
    b'R1B4M2VEMwo2KzNFYzMrc09VcnUxOXF1UGs3TWhaRHo0dVRDYlhyOSsvdjQ3L0hndEx2TmlK'
    b'TEFhbmUzVTJLMlVtQzRWbVQ3OXZmMTUrblhvS2psCndNYkNiM3ZZbzZ2b3lNM0xnNDdPaXBU'
    b'OCtmbnF6dExSa0pxeVNGalBqSmJCYkhqaXViKzhZVzdacEt6cHlzNzM3TzdYb2Fua3Y4VHYK'
    b'MmQyMlVXQzhYMjI1V1dmNzlmYTJVRisvYUhUYXA2KzlZVy85K3ZySWZZank0T0xhcHE3SGVv'
    b'YTFUbDI0VldQSGVZVGRyYlQyNit6bwp4OHp3M04vY3JMUHYyTnV5UjFmcnp0UHF6ZEdzT2t2'
    b'ZHI3YkllNGJqdk1HL1puUFFqcGpxek5EUWo1alRscC9ndHJ6MDVlZEo3TklUCkFBQUFBV0pM'
    b'UjBRSWh0NlZlZ0FBQUFkMFNVMUZCK2NERGd3VkM4bVhTb0VBQUFNMVNVUkJWR2plN1pqNVV4'
    b'TXhGSUFESG4wZzBJS0EKeWwycllHMjV5bEVvS2dnaWx4eUs0Z0dGb3FBaUtDaUtvaUFXQlVW'
    b'VVZMekEreGFCLzlFT0ZkanVadE4yaHFTWklkOXZ6YjQzODgybQorOTVMRUJJSUJBS0JRQ0FR'
    b'Q0FUcmxhRGdEUnMzYmRZQWhJUnVDZVBFS1R4Q3F3TTNrVkZiT1pHS2pvbUZaYlp0NTBScVJ4'
    b'eXNFcC9BCnlmWWxTcVFnS1prUHF4UzkxR29uSDFLR1hWSXAyTTNIRHFhbWVWaEY4dkZ2MzJQ'
    b'MHNJSzlYRmlaeko1V2tNNkRWVWFhekNxVGk1Y1YKTDdPQ0xCNnNzdVZXRU0yQmxTVkhvWlZM'
    b'VE1oam9wV3ZzTElXRUJNS1dWalpGRlpRUk00STI4ZEFhNzlTeTJvZ1pod0laekEwQUlaaQpZ'
    b'a29KZzlId0lFNnJsSmhTZG9pNlZYa3NUdXN3TWFlaWtycFdGYzRLak1TdVhrMS91cWpCYXNF'
    b'UlFrcHRIWFdyZWgxZUs1L1FRQnUwCjFMVktRWVdqcWluSG9KRzYxbkUxclJOTktoa25OVjYr'
    b'MDdYZ2xKb1d4SnpHNy9vWnFBNmlydFdzcWdVdHVNYVlhZ2RvcFY5TVE5VzEKb00yaENHOC82'
    b'K1VyWFNNMEJDMDQxK0VaM0ZsYjVGbzl6NkJQUndLUnVPRE9sZEFMRjd1VzFpNHgwT29HTC9S'
    b'Y3Z0TGJkL1ZhYVVSYgprWHNoa2NXdzFROSswbC9KUXV1NnYxclpUQWJtWmordGJxeW0wcnc1'
    b'YWZIUGFrQlNZMjBVdGJMOHNtcVJETk9GVlJTMWJ2cGpkVXU2CmI0TTB6NUpOc1Q1TGhkeVdK'
    b'dDdwcG5wYWxJMkJWcU9hVmI1Rm1wWStORXoxVTd3ckg1YzdNbkZTMm1DUHJKRXV1RWYzaUNF'
    b'ZlR3Y04KenRZNjJXbDI5TDVua3NNTU9ndmR5dFVtZnpFVlFTaWg1TUZZai92WHVQMmhVMzZp'
    b'Y0xoT3ZJOG9GMVNuWXNNbTNDL0M5TGg5c2k4RAprL0drd1JYVVM3dlEyeFZlNHgyaytKU25y'
    b'cEFhNnYybkYvTVBiMDFWaTM2MnRPbldxVUJjSkxtS1ZKa0pGNXJiNkI1dlJobTA2L0ljClhF'
    b'blFQNStVeFNXL2lILzUvMWt4aXpGaVdxV0N2bnI5NXUzeXZQeHVadmI5eW9NWk50ZVVzK290'
    b'UjlPbC9URFcvSEZJdXZhSjBlMnAKb2NhZmpqMWN3RWdMbVQ3N2JtVjJJR2FNbUgyMW12aUNH'
    b'RkwvMVRlcmJ5YkVsTzlKdmxqOU1DRFdUT3U5U2VsL29nQmcrVVcyaXJLZwp3RENsVlpmUy9r'
    b'YUJ3emFBdmJiVXhkaFFZTEg4bVpPWjZlYis1aUlPeUhQT0w5Z1hYUjA4WjlHK01POXNRZ0tC'
    b'UUNBUUNBUUNnV0M5CjhnOEtSNWYvSHRNUnVRQUFBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUFN'
    b'akF5TXkwd015MHhORlF4TWpveU1Ub3hNU3N3TURvd01PVUYKUnpjQUFBQWxkRVZZZEdSaGRH'
    b'VTZiVzlrYVdaNUFESXdNak10TURNdE1UUlVNVEk2TWpFNk1URXJNREE2TURDVVdQK0xBQUFB'
    b'QUVsRgpUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2U4MTI1IiAvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'JP_34')

JP_34 = b64_JP_34
index.append("JP_34")
index.append("Japan Hiroshima")
catalog["JP_34"] = JP_34
catalog["Japan Hiroshima"] = JP_34
country["Japan Hiroshima"] = ('JP_34', '', 1)
lookup["JP_34"] = ('JP_34', '', 'Japan Hiroshima', 1)
lookup["Japan Hiroshima"] = ('JP_34', '', 'Japan Hiroshima', 1)
details["JP_34"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_34"] = ('JP_34', 'Japan Hiroshima', 1)
regional["Japan Hiroshima"] = ('JP_34', 'Japan Hiroshima', 1)
#----------------------------------------------------------------------
b64_JP_35 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjgxNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1lhbWFndWNoaV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAg'
    b'IHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lu'
    b'a3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdl'
    b'Lm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'CiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAg'
    b'ICAgaWQ9ImRlZnMxNjgyMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5h'
    b'bWVkdmlldzE2ODE5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3Nj'
    b'YXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1v'
    b'ZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE2ODIz'
    b'Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgog'
    b'ICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1y'
    b'ZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFn'
    b'ZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRo'
    b'VG5DQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFB'
    b'Q0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ0ZsQk1WRVZwUERScVBqWjdVMHlR'
    b'Ym1taQpob0dxa1l5dmw1T1BibWhxUFRWK1YxQ3VsWkhUeHNQMTh2SC8vLy8wOGZIU3hjS3Rs'
    b'WkI5Vms5dlJEeW1pNGJoMk5iZzE5YWxpb1Z2ClJEMnpuSml4bXBhZmduM3c3T3Z2NnVxZWdY'
    b'eDNUa2ZTeE1MUXdyOTJUVWFHWWx6dDZPZUpabUNjZm5qNyt2bjYrZm1hZkhmOS9QejkKL2Yy'
    b'YmZYaisvZjJhZTNhTWFtVDYrUGlMYUdIeDdlM1R4c1RIdHJPN3A2UFV4OFYxUzBUczV1V0RY'
    b'bGVEWGxpdWxwTHM1K2FmZ256cAo0dUZyUGpaclB6ZnE0K0tjZjNseFJqNjlxYVp1UXp1K3E2'
    b'ZHdSVDZYZUhPWWVYU3dtWlR6Nys3NTkvYVNjV3VQYldmMzlmWDA4UENuCmpZaisvdjdnMXRX'
    b'OHFLUytxcWZkMDlLQVdsUHE1T050UVRucjVlUitXRkdya28yaGhZQ3BqNHJuNE4rMG5wcno4'
    b'Tzk1VVVtRllGbDQKVDBpVWRHN0RzYTdSdzhEdzYrckd0YkxaemN0NlVrdmF6ODI5cWFYRXNx'
    b'KzFuNXZGdExIQnI2dTNvWjI0b3ArNnBhR25qSWpDcjZ6Vgp5TWJXeWNkOFZVN1l6TXFXZDNH'
    b'M29wNzI4L0w3K3ZxVGNtMzU5L2QvV0ZGc1FEaUJXMVNOYTJYMjlQUDQ5dlhZemNydDUrYUNY'
    b'VmJ1CjZlaTdwcVBvNGVDNnBxSnRRVHJqMnRubTM5NTRVRWx6U1VMZTFOTGIwTTZPYkdiV3lz'
    b'aUJXMVZ4UnovTXZMcWdnMzd2NnVuRXM2L0oKdWJiQnJxdTVwS0NwajR1bWpJZVplblNkZjNx'
    b'SlpWK0laVjV5U0VITHU3alB3TDUwUzBQeTd1MndtSlRmMXRUZjFkT2tpWVJ1UWpwOApWRTJz'
    b'azQ5N1ZFM2ZBZ0l2QUFBQUFXSkxSMFFOOXJSaDlRQUFBQWQwU1UxRkIrY0REZ282THBRQzJo'
    b'a0FBQU41U1VSQlZHamU3Wm41ClA1UkJITWVmZFd4b2g2S3NZNFcwVkZiQ0tqbDJVNnVrUTA4'
    b'VWhWQkNpNG9rT3JDMlFpaEhoMjdwdnVzL3pMRThNL01jKzNqWm1jY1AKOC83eE81OTV2cC9Y'
    b'TS9QTXpIY2VqbU13R0F3R2c4RmdNQmdNaGhwMGZ2NEJnWHA5WU1BNnY2QzE0aWs0WkwwQkxC'
    b'TWF0bUdqOXA3QwpJellCRVpzand6VTFaWXd5QUVsQ296VTBGaE1MWkRIRmFXUnFTenhRSkNG'
    b'UkMxZGJrNEFYVE52b3V6SW5BNitrYktjK3JYWUFGZXdNCm9Pc3ExUUpVWVVtajZXcFhDbEJK'
    b'K201NnJoTEZDME5HWnBiVm1wV2RJWjczZTJpNUNzckdVdThOeWZGc2hVSDdjdk93eG5oYXR2'
    b'TFIKdkFXcE5yalZidDZQdGhmU2NYVUFHVUxMUVlkb255eENQZ2pUSVNxMm9wR2w2YkNVcEJo'
    b'WjFJNVEyWjVMb0l4SGowbUxqcCtBUktVMApYdGRKS0NGZkxLZEs0eUZaQkFWYnA2QjhaZkt5'
    b'Y2toMm1yeXJNMUM2aWtwNVhlVlpTSGlPdUswcUtGdStrckFhRXRZUXQ1VXBKRHV2ClV4TGFD'
    b'bWd1cWFWQ3NpaGxaYTJnckNQdHFoNGFtaHhsNlFWSWV0SEhOaG91b1RRS3FacTg5VzBTdEkz'
    b'WVl4cFdhY3ZXTEh0bXVZeEoKblU0czBDTGJ0ZG0yNnVOQ3E5eXoyekRsbFZvc2NGV3U1eldk'
    b'RDhheFhlYmhIYWpNYmpMWjBjaDFtWTd0dnBsZnViemswMXV4N1JrQQpiTnN1a25ZVjVhdDUz'
    b'eWw1Y3IrQmlyb0E2RUlqYlpLbiswN2ZmWTl4VW5YT1RVVFNQV2VkRDBaQ1BjUnJvVnNTTlVV'
    b'b2NtZlVNUis2CmpYd3NkOFI5N3ZxNGN1enRFK2ZvaDlwZEM4VkZoZ3NLRFloNzlQWDZlbmwz'
    b'MzFPY3UrYkZVQ3E4WUlnNjNQY25jT2RRaDJmSmc1YWYKQjR1aEh1aUdjQkRYRzRqY1NReUpx'
    b'a1BoM2ZSNzFoQmVHTmhDWEIwN1JHYWI3cTdBRWcwYmw1cXNTNkdIeStVUC9ySUcrMGtkSDV3'
    b'agpXS3BSVDhQWThnRFhqWGxDWlpoMHhFbXd5bitFNXVMelJRV3Q1eExRak8wTWo4ZEpIcmNt'
    b'SnJHYkQvZENlRXFJVEMwRW5tRHIzT1FFCjRTcnhLWm92T1dZdStBeCtOZk1UMjV5T3FscWVr'
    b'ejZlT3NLd2NSdzFJc1VYS09lTVZtd0V3eHprS3pMWE5QNDl4aUMzNElZWEx6SEIKdEl0R3RX'
    b'OTdCVmJFYXp1bCs2MnlsYmg2bytOb29WZnY2aTNOeTlOM3ZEcFRmQWpkcStZWlZWZk5saG1P'
    b'TXUvN1ZQd3VtT1dvODZISgo2OCtWajV3R2ZQcXM3T3JMVjA0YjRvYmxUU1hOY3BvUkhsMGli'
    b'ZXJiZHdlbkpZN0lIK0pWNGVldjM1em0vUG5iQ0IzelN4S3EvbkZyCmhYcDNkWTFlWDFQdEh1'
    b'Y1lEQWFEd1dBd0dBd0dnNkdLL3dJNjFLQVBWTEc3QUFBQUpYUkZXSFJrWVhSbE9tTnlaV0Yw'
    b'WlFBeU1ESXoKTFRBekxURTBWREV3T2pVNE9qUTJLekF3T2pBdzNURDgzd0FBQUNWMFJWaDBa'
    b'R0YwWlRwdGIyUnBabmtBTWpBeU15MHdNeTB4TkZReApNRG8xT0RvME5pc3dNRG93TUt4dFJH'
    b'TUFBQUFBU1VWT1JLNUNZSUk9CiIKICAgICAgIGlkPSJpbWFnZTE2ODI1IiAvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'JP_35')

JP_35 = b64_JP_35
index.append("JP_35")
index.append("Japan Yamaguchi")
catalog["JP_35"] = JP_35
catalog["Japan Yamaguchi"] = JP_35
country["Japan Yamaguchi"] = ('JP_35', '', 1)
lookup["JP_35"] = ('JP_35', '', 'Japan Yamaguchi', 1)
lookup["Japan Yamaguchi"] = ('JP_35', '', 'Japan Yamaguchi', 1)
details["JP_35"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_35"] = ('JP_35', 'Japan Yamaguchi', 1)
regional["Japan Yamaguchi"] = ('JP_35', 'Japan Yamaguchi', 1)
#----------------------------------------------------------------------
b64_JP_36 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTY5MiIKICAgd2lkdGg9'
    b'IjE0MyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDMgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1Rva3VzaGltYV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAg'
    b'IHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lu'
    b'a3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdl'
    b'Lm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'CiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAg'
    b'ICAgaWQ9ImRlZnMxNTY5NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5h'
    b'bWVkdmlldzE1Njk0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xv'
    b'cj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3Nj'
    b'YXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1v'
    b'ZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE1Njk4'
    b'Ij4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE0MyIKICAgICAgIGhlaWdodD0iMTAwIgog'
    b'ICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1y'
    b'ZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFn'
    b'ZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFJOEFBQUJrQ0FNQUFBQ0lQ'
    b'cFBnQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFB'
    b'Q0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ0xsQk1WRVVqUjVTTGlrMzgxQUNZ'
    b'bEVSRwpYWDE0ZmxxYmxVSzlxeXZadmhmbXhnL3d6QWlDaEZRa1NKTzJwekQ3MHdGcmRtTWxT'
    b'Sk5lYld5cW56am14US9WdXhzbVNaSXVUb3ozCjBRUHB5QTM2MHdGU1puTkpYM3J6endhZmx6'
    b'OXdlV0RueHc0eFVJdWltajVxZG1NblNwSEtzeUsvckNvNVZZWDAwQVZBV29CYWEyNzUKMGdL'
    b'SmlVK0tpazdZdkJtMXBqQlphbS9ld1JTbW5Ec3JTNC9hdnhic3lRczBVb2lnbUQ5eWVsNU9Z'
    b'M2I1MHdMSHNpWE90aDlHWG54awpjbWY0MFFQSnN5T1RqMGlobVQ2eG96TzBwVEdBaEZUTHRD'
    b'S3lwREpzZG1JdlQ0eFdhSEczcUMrb25qbDJmVnhYYVhDdm9qUjVmMWtxClRJL3V5d2xWYUhM'
    b'eHpRanZ6QWxrY1doaGNHcGdiMnFjbFVLT2pFdVBqVXJVdVJ6aHd4SXBTNURpd3hIUnVCNG9T'
    b'cEZ6ZTExMWZGenkKelFkRVhINW5kR2F6cERKbGNtZDhnRmg5Z1ZaNmdGbUhoMUJqY0dpRmgx'
    b'R1Fqa2xOWTNkUFpIWlFaSFZtYzJaOWdWZCtnbGExcFRIegp6Z1owZkYxM2ZWdlR1UnpseGhE'
    b'anhCR1Fqa3FSajBtWGswUmZibXRYYVhIdHl3cW5uVHFqbXp5NnFTMUhYbnhIWDN1N3FpeFVa'
    b'M0pnCmJtb2tSNU52ZUdETXRTR3NvRGU1cUM3Z3doUE50U0JUWm5QMjBBU0RobEpMWVhtZW1F'
    b'Q3RvVGJEcnljbVNKSXRUbzNkd1JWRFhIL2kKd3hKb2MyVzdxUzFCV29DYWxFTi9nMVVzVEk1'
    b'ZWJtdjF6d1d1b1RVM1ZJYy9XWUhreFJCN2dGZzFVb2lVa1VmRXJ5WXNUWTZUa0VjLwpXb0V6'
    b'VVlyaHdoSk9ZbmM0VlliNjBnS1psRVBadlJoQ1czOWljV24vLy85MThIVlpBQUFBQVdKTFIw'
    b'UzVPcmdXWUFBQUFBZDBTVTFGCkIrY0REaEl0TFJxOS9mMEFBQU03U1VSQlZHamU3Wm5YVjFO'
    b'QkVNYUhTQ2RHTEJBQlN4QWJDSXJSMEFNcUZvb2xDSWlBUVVVVVZCUkIKMFJqRXJ0Z1F1eWdT'
    b'Ry9aZVVQODhjM2p5N015ZWd6ZDNscGY5SG5lL2MrZDNkdmZ1enM0Q2FHbHBhV2xwYVdscGFX'
    b'bVpyREFMMXFTeApudkNJeUtqb21GakxlQlJuR285MU12NjZiVXI4MUduVExlUFhqQVR6Qmln'
    b'eEduL2ZQdFB5UDBwS05uUEdVbVpaUXRSc2M1ZlFuQkJ4CjVqcE1YdE9wb2ZITU0vc2ZTNXNm'
    b'Q3M0QzgzLzZoVEhHY1JZdFp0aUYwak1NOHl4aDJSWXpqZUprcGJId1dKY2F3N0V0WXpvM0Vy'
    b'TU4KOFN6bk9zZWNLNHpnckhSeDhlUVlHcDVjTHB5OGZDTTRCVlltSEd1aEVSeDdFZGZ3dUNV'
    b'Umk3TkxjbGF0WGxOS2F5MWJWcmFPZ3NsWQp2NkZzWXBMRWNncW5JbnpDa3RaS1ltMXNGRHli'
    b'TnVNSjI4S0Q0NmxDT0xGYjhTQldJMWVOazRXbkZtZWdic0syRGU4SmRTdzgyMUdjCmV0TFhJ'
    b'TG1KbUsxR01jd09MejJ2VGFKeEp3Zk9McFQ4N0pZNG05SCt4SkZ0RklsUjluZ2tUaTlhMGkw'
    b'TVBIdkZJUHVrVnBRbHRUTHcKdElsQjJxVFcvYUwxQUFQUFFURkl1OVRhS2xvUE1mQWNGb04w'
    b'U0sxSFJHdURDcDQ4cWJWVEJRK2FMN2ZVMnFWaXZ0QjZQaXExSGxPeApudEgvM2kyMVZxajQz'
    b'OGUvSHpxUHE5Z1A4WGx4UXVMMEtUa3Y0S1FZeGsvbk5aNGVKZWNwUktJODRoVHA2MFcrMHl3'
    b'ODdUZ2ZvOVpwClZ4THluVkdWcjFhWEk5ZFpuSytlOC9JazBPZUpmTjRuZUNMczJIUkI1WDNu'
    b'NHFWL0hKZjdLTXNWcmdzUFdVRE1MNzE2YmF6WGNiMmIKdk43ZllMdUExVXJ1eS8xQm1Kc0R4'
    b'WkxlT2pZZTZ5MUp5T0NONzdaZDBsZkNlRU5Oa1JRMDczUUMzS1c3TXU1eFhwbnZTd2FoeVFY'
    b'dwpnT3lKWkwzQ2V4b2xRQThINFZFVzBmN1l5Y29EUTlVU29GNkFGdUlWN0ltRHVjalJLbGxD'
    b'dHVIZ1VXSEQ3UUVyTTFDdWpRYXFlZ3J3CmpHalA1QzREUFUrU1BQKzlnSVFDNGhudUpUZlE4'
    b'QWdOOUFyZ3RaK29QcjloTDl5OXBZSGVBU1FUMjJLaGx4dklGVVhYV1lNblp4elIKbnNwZlMz'
    b'VDNVRUE5N3dINmlmWm1mcUN5RDlTYis4ZEIrRVJzaXlNZENzcXRqbnBpakQ0RGZDR2V3UWUr'
    b'cWlnQXg2ZFhpa2pmdmdQOAorSW1CK3VJVkZhV0hmS09CYUgrTnBjYi9LekRxK3ozVzlvZVl5'
    b'VERRMHRMUzB0TFMwdExTMGpKWmZ3RkxJSXNiQXFsWDB3QUFBQ1YwClJWaDBaR0YwWlRwamNt'
    b'VmhkR1VBTWpBeU15MHdNeTB4TkZReE9EbzBOVG8wTlNzd01Eb3dNSUtyWVY4QUFBQWxkRVZZ'
    b'ZEdSaGRHVTYKYlc5a2FXWjVBREl3TWpNdE1ETXRNVFJVTVRnNk5EVTZORFVyTURBNk1ERHo5'
    b'dG5qQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxNTcwMCIgLz4KICA8L2c+'
    b'Cjwvc3ZnPgo=', 'JP_36')

JP_36 = b64_JP_36
index.append("JP_36")
index.append("Japan Tokushima")
catalog["JP_36"] = JP_36
catalog["Japan Tokushima"] = JP_36
country["Japan Tokushima"] = ('JP_36', '', 1)
lookup["JP_36"] = ('JP_36', '', 'Japan Tokushima', 1)
lookup["Japan Tokushima"] = ('JP_36', '', 'Japan Tokushima', 1)
details["JP_36"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_36"] = ('JP_36', 'Japan Tokushima', 1)
regional["Japan Tokushima"] = ('JP_36', 'Japan Tokushima', 1)
#----------------------------------------------------------------------
b64_JP_37 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4NzMyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS2FnYXdhX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAgeG1s'
    b'bnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2Nh'
    b'cGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0'
    b'L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAg'
    b'eG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBp'
    b'ZD0iZGVmczg3MzYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXc4NzM0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2'
    b'NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRv'
    b'dz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBh'
    b'Z2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9Imxh'
    b'eWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzg3MzgiPgogICAg'
    b'PGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBw'
    b'cmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmlu'
    b'ZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZzti'
    b'YXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhUbkNBQUFB'
    b'QkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFk'
    b'VEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDSEZCTVZFVUFXVE1IWGptWnZhMml3clVKClh6'
    b'b2JhMG5IMjlMLy8vL00zdFllYlVzOGdHUG43K3pxOGU1QmcyZGRsbjM2L1B2NSsvcGFsSHR2'
    b'b1l6OS92MysvdjZBckprY2Ewa3EKZEZVQldqU0tzNkdSdDZjQ1dqVlZrSGVUdWFrMmZGNERX'
    b'eldseExmWTV1QWliMDZveHJtODA4bElpRzJnd2JQUTRObGVsbjZod3JTZAp2N0hVNDkwRVhE'
    b'YU10S09Ic1ovUjRkbzdmMkpvblladG9Jb1daMFZOaTNIOC9mMVJqblR2OWZMMitmajErUGN5'
    b'ZWx2Myt2bmg2K2NVClprTzQwY2FFcjUzMCtQWkdoMnRBZzJaRGhXbms3ZWtTWlVFMWUxM2Q2'
    b'ZVJRalhPdHlyMmV3TEZzbjRsbm5JVWRiRXFTdUtpR3NKNkoKc3FIdDgvRVZaMFFYYUVYTjM5'
    b'ZTB6c08xejhRUlpFSGM2T002ZjJFdWQxZ0ZYRGQ1cUpRbmNsSm1tNFVQWXovczgvRGY2dVVU'
    b'WlVLegp6c0xyOHU4T1lqN284TzJDcnBzWmFVZDBwWkFZYVVhVXVhbjcvUHkyejhYaTdPZ2pj'
    b'RTk5cXBjTllUM3U5UEZKaVcwSVhqa01ZVDF5Cm80N2I2T0prbW9OdW9ZdmE1K0haNXVHNjBz'
    b'aDhxcGJWNU4xQ2hHaFVrSFlRWTBEZTZ1VStnV1UzZlYrdXlyNmp3N1g0K3ZsaW1ZR3kKemNG'
    b'cW5vakQyTS94OXZTQnJacSsxY3Vmd2JJaGJrMi8xY3hPakhHSXNxQlNqblVHWFRpMzBNWHc5'
    b'Zk01Zm1GS2lXN0ExczJQdHFYVwo1TjVGaG1yejkvV3d6TURTNHR0YmxIeHJuNGwxcFpHRnNK'
    b'MGFha2k1MGNmbTcrdXN5YjFjbFgwZmJVeDRwNU43cVpYUDRObU90YVdMCnM2SndvbzNHMnRH'
    b'WHU2emw3dW8xSWVDTUFBQUFBV0pMUjBRSEZtR0k2d0FBQUFkMFNVMUZCK2NERGc0WktiUEdr'
    b'QWNBQUFPY1NVUkIKVkdqZTdabjVYNHhCSE1jM0swTkYyZDBVcXp1a29wdTJRNGVRYmtYT0hG'
    b'RXFsYkR1STRtb0NKR1E1RDdMK1ErcW5rbjdtWjFuKzhYTQpQaSt2K2Z6NCtjNis1dDAweDJm'
    b'bU1abVVsSlNVbEpTVWxKU1Uvai81ekRQUE54NlY3d0pDRmk0eUdwV2ZQNWxVd0dKalVTMEpK'
    b'Tk1LCldtb2tLb3VWVU5tQ0pYZTlMRVN2RXJxY3VHaUZYU3JXU3VJZkZzNHJSRVFTa0RsQ0x0'
    b'YWtvb0tqM2FqTWhGRk1oR3dzUXF5eHErYWcKSW1TMVhUcldwTmJFelE2SGZTM2hLRDdVQzFp'
    b'RUpNUWxVbmNkNFdxOVY3QUlTVXFlTmxPSWpsSzlnMFZzNWpTVEtUMUREeXRqZzNldwpDTmxv'
    b'Q2M4a3VuSmtlUW1Ma0d6aVFUbTUzc0x5ckUxMlEyS1JQRU5nNVRzWXcxWmdBQ3hINFdaMkJS'
    b'UnRFWSsxZFp0SHFveGl6bjZ4ClhjSndoZnFWQk9samxVNDFLV05kT2Ftd3ZFSnZwNnJVR2xR'
    b'eDlvNXFPYnRYVFJVWGJDZmRET3k3bUVLSnJFTW91cGFERlRpVGRuYnYKWVZaam9iUkRPejJI'
    b'c3c3MzB1SStacHRJMkMrTjZ3Qm52QUxxYVBFZ1U3RElvanAwbURlOWp0VFQ4bEgwanpWSXdx'
    b'cmtMOFphR2ttcgpHOUUvTG9lcXlhR3pTVFR6ejRQOEZpbFlKL1IyMU5aazJxSU4vVEFaVkdu'
    b'NjJhK2RUcStUMkNSYnhuRGxlVGdZWTJpYkR1bXo2OVJwClR3ZjJHYTJSc3gyUG9MUENzYzU1'
    b'ekJIbm5WcXJDMmhmRkI0akxrRi9sNjh3WEZmcFhmc2F1RkdpcjdPZFNIRzk2d1lhbWRIY1Rh'
    b'SmIKTUZZTWpvTGRkSlBKWUxkb2xNQlI3UkZMVlg4YmVydmpQdGxzV2J5ak1WdHNmRTdGck80'
    b'ek5kdDZ1WnVFMHgvY1BxRlkvZEJYaDNZWQozY1ZRVDZQRVBYQUhSRksxV0FHZ1hIT2JjYmp1'
    b'MDRBTjl3MXJrMENzVXVpL2w3cUpTWmhVSC9CT3hoU0JXQStocDhFWnV4dUg2NUhtClBnWXpW'
    b'dURCRXdndk5rTi9DMDl3SldpUGhUN0RybWFRdUFOb1VPOVM4eFNIcTFOemU4QjhKZ3lyZ25j'
    b'c1QrczViOUxqWHpFaURPdUYKYXpmRFF5NlZVY3lqMmovTStSS3VRTUxTTXZROUJyVlhVSHZO'
    b'dVd6WWFnUmhGVVBYYjZEMkZtcVJtbWtCTTEwUTFqdm9wUTVxNzJIegpiTlNDVElpVWpBclpx'
    b'b2dwZmdBRSt0bnFvNnZYSmlnQlFseit4RlEvdXo4cm1VeGpFSjNGWk1FdjBQRlhOdkpZT2U5'
    b'dDQvQVRYeUZZCm83d3RjMVlUTURMYXcxSUIvRVRNRitNKzZLT0xMWCtEc3BhZGM4RXJFNEkx'
    b'QW12Ti9YbUpkd1RBSThwM0lWancwTmZ2Vm02QXlmVkQKTTMveWd0Qy9GV3prOGU1MWVJejdw'
    b'WG53dFhGQ0NCYUU4L0U1dHJVQnpxMy90d2dxZXl0NzUyRVV4a0dBMjNXcjNHLytTa3BLU2tw'
    b'SwpTa3BLU2twS3h0WWZoTGl1QXRtYTErSUFBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3'
    b'TWpNdE1ETXRNVFJVTVRRNk1qVTZOREVyCk1EQTZNREFFNnpiMEFBQUFKWFJGV0hSa1lYUmxP'
    b'bTF2WkdsbWVRQXlNREl6TFRBekxURTBWREUwT2pJMU9qUXhLekF3T2pBd2RiYU8KU0FBQUFB'
    b'QkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlODc0MCIgLz4KICA8L2c+Cjwvc3Zn'
    b'Pgo=', 'JP_37')

JP_37 = b64_JP_37
index.append("JP_37")
index.append("Japan Kagawa")
catalog["JP_37"] = JP_37
catalog["Japan Kagawa"] = JP_37
country["Japan Kagawa"] = ('JP_37', '', 1)
lookup["JP_37"] = ('JP_37', '', 'Japan Kagawa', 1)
lookup["Japan Kagawa"] = ('JP_37', '', 'Japan Kagawa', 1)
details["JP_37"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_37"] = ('JP_37', 'Japan Kagawa', 1)
regional["Japan Kagawa"] = ('JP_37', 'Japan Kagawa', 1)
#----------------------------------------------------------------------
b64_JP_38 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3MTU3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRWhpbWVfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzNzE2MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzcxNTkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNzE2MyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNnbEJNVkVYL3BnQU9iVWFQdTZsMXE1WC8KLy85'
    b'eXFwTXZnVi8zK3ZuNCsvb3lnMkszMDhpMjA4YzRobWIrL3Y0NWgyZWt5TG1neGJZWGNrMzIr'
    b'dmowK1BZV2NreFhtWDVUbDN1ZQp4TFNid3JMZDZ1WGI2ZU1aZEUvOS92NFljMDVFam05QWky'
    b'eHVwNUJycFkyUnZhdWp4N21neHJhMDBzYXgwTVFSYjBnNmlHaHRwbytHCnRxS2x5YnFmeGJX'
    b'S3VLVnNwbzVLa25Rb2ZWb1Bia2ZGM05QRDI5RktrWFNad2JHRHRLQm9vNHMzaG1VUWJrZnc5'
    b'dlB4OXZSN3I1aysKaW12VzV1RFU1ZDdzOVBBdWdGL1M1TnovL1BmLzQ2Ny95MnYvd1UzLzQ2'
    b'OWFtNEQvNEtiL3NCei9zQjMvNGFoYm00SC96M2IvcUFYLwowSGNVY0VyRDJ0SC8ySkQvcHdU'
    b'L3pHei83OUwvLy83Lzc5SC95MnIvcHdQLzJaSzQxTW4vOXVUL3FRci9xQWIvNXJiLzViVC9x'
    b'Z3YvCjl1YS8yTTRiZFZBVGNFci8wSG4vMW9yLzFZZi8wWHhkbllQL3RTei9xZ3ovL1BiLy9Q'
    b'WC90aTlrb1lnbWUxai9xUWovdlVIL3ZFQ3gKejhOQmpHM0IyYy8vL2ZyL3BnSC93VTcvL3Z2'
    b'STN0VklrSEpTbG5yL3JSUC90U3IvcmhaUWxYa3hnbUhyOC9ELzhOUC93bERHM2RQLwo0S2Yv'
    b'dkQvL3V6ei80YXBDakc3Ly92My90ekwvd1V6LytPdi8rT3Ivd0VyL3VEVkZqbkFTYjBuVDVO'
    b'My84OXovcXcvL3lXVC8ycFQvCnlXUC9xdzcvODkyQXNwNy84TlQvc2lQL3N5VC84TlY5c0pz'
    b'cmYxei8xSVgvc1NELzFZYjErZmVkdzdULzh0bi82THovOHRxWXdiQW4KZkZtV3Y2NlN2YXdh'
    b'ZEUvaDdlZ2plbGJ6K1Babm80bzJoV1Jpb0llNzFzdjgvZjFXbVgzNy9meG1vb241L1B0T2xI'
    b'ZjYvUHRlbm9TQgpzNTlZbW45K3Naemo3dWs5aW1yZjdPYXowY1VkZGxJZWQxSzEwc2JsNyt2'
    b'ZzdPZW95cnpZNk9GenFwUVhjMDEwcTVUYTZlTkxrblZ4CnFaSjJoZ3N0QUFBQUFXSkxSMFFF'
    b'ajJqWlVRQUFBQWQwU1UxRkIrY0ZCUVFOSnk4R25TSUFBQU1OU1VSQlZHamU3ZG41TzFSUkdB'
    b'ZncKMS9US0lLS0lhcVlTVVJsWm9tUXBFZTJKRnRwVVFndWx0S0dVOWxYN3JuMlQwa29xcWJU'
    b'dmUvMC91WGZtenJrTVAzZ2UzWE04ei92OQpZWjV6M2pQUGN6N1BuWHZQdmVjT0FJVkNvVkFv'
    b'RkFxRlF1bVFzUk15eENLV2lDeWRUa1JXSjBSNzhWaWRIUkQxanNLeG5MQXh6cUt4CnVyaElM'
    b'SFFWak5WVlZxR2JXQ3ozYm1aV2R3K2hXSjVvU1EraFdGNEt5MXNvVmsrRjFVc2tWbStEd2pJ'
    b'WUJXTDFRV3Y2Q3NUcXgxZysKQXJINk01Wk9JSll2WS9rSnhCckFXUDc4V0FFREJ3MzJDalI1'
    b'QlEwSkRnbVZDbUdNTlZUK1JraTRUNUMzeVJReGJIamtDSTFZam01UgpUSUhSVGpHeEFTTlpm'
    b'MVJBYkl5eitndHhFYU0xWWNWajgwVHJNV0ZNWWxKUzR0Z0UxRWZiRE1kcndocUh0aGsvd2J6'
    b'Tm5EaXBoY0hKCjJweGJ2allUVDVGSXljblM1MVNiUVYrTlR2bVUxR1lUVHdPWVBtTW1wcVhQ'
    b'bWcwd3A5bGdhb3BXVjZKeGJwT0o1MlhBL0FYbTVzSmsKeUZ6VVpEQXJXN3QxSzhkUFBmTmln'
    b'Q1ZLZXluQU12V1lXNDZteTJsdUhKczZENWF2VU5yNW1iQ1NqVVN0MG5xVkwvQlg1azViRFd1'
    b'WQpaQzFrS0UyWGRRVWNiajdyQzgyekZ4WERCc1pLZ3VLTjVsYkpKazczeE0yRjhqYXNGUElZ'
    b'YXd0c2xZOVUxamFPdCtydHVoM1NBWUtkCmlpb2RZRmZqT1dXSzVQd0U0YkViOXdEc0xiTDhv'
    b'UHNBOW1OWWUyL0wyczRxTStDQmd3Q0hEa3VxSTBjQmpxV2g0VGh2MW9tVGpacFQKcFFDbno1'
    b'U1huejBIVUhwZWVvekk0Y3k2SVA5MkZ5OHByNFF2WDVFTFYvbXlybGsyK2ZuWEt5UlV4WTE4'
    b'Yzc4eWhDdnJKbHNaYmxWVgozV2E5T3p4WkJRN1lTaHp1Y21UZFUwdEtTdFM5Ky94WUR5cFZq'
    b'dXFhbW1wVjk2R1JHNnRXelhDMXMzdWtmbzUvekkzMWhDSHFuc28zCnlYcFdjZWJGeW1hSWVz'
    b'dUQxYk02YSttNWtSUHJoWlhRa0t2VVhqWllpK0djV0src3E0RW5LNzdXSzlVM25Gakt4dXh0'
    b'bWJyNjdqMjIKKzF2bk5yRXMrNThQSDV1V1AzMjIxRG14NUF2eFM2M3RnT2ZYZHI0VTI4VDZo'
    b'dmo5aDN0TEl6OS8vVVlNNU1UNjg3ZjEvMUpDWGUyRAp1YjkyKzk4aEZyR0lKUVNMUXFGUUtC'
    b'UUtoVUtoZE1qOEEraFJvN2lXcW1MMUFBQUFKWFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl6'
    b'CkxUQTFMVEExVkRBME9qRXpPak01S3pBd09qQXdnQ0RYZXdBQUFDVjBSVmgwWkdGMFpUcHRi'
    b'MlJwWm5rQU1qQXlNeTB3TlMwd05WUXcKTkRveE16b3pPU3N3TURvd01QRjliOGNBQUFBQVNV'
    b'Vk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2U3MTY1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_38')

JP_38 = b64_JP_38
index.append("JP_38")
index.append("Japan Ehime")
catalog["JP_38"] = JP_38
catalog["Japan Ehime"] = JP_38
country["Japan Ehime"] = ('JP_38', '', 1)
lookup["JP_38"] = ('JP_38', '', 'Japan Ehime', 1)
lookup["Japan Ehime"] = ('JP_38', '', 'Japan Ehime', 1)
details["JP_38"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_38"] = ('JP_38', 'Japan Ehime', 1)
regional["Japan Ehime"] = ('JP_38', 'Japan Ehime', 1)
#----------------------------------------------------------------------
b64_JP_39 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5MzAyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS29jaGlfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzOTMwNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzkzMDQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnOTMwOCI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNZVkJNVkVWN0Z4eUVKaXVpVzEraFdsNi8KajVL'
    b'L2pwSGR3OFRjd3NOOUdoLzU5UFQ1OWZWOUd5Q1ZSRW4vLy8rVVJFaXllSHV5ZDNyUXJLN1Bx'
    b'NjJLTVRhYlQxT25aR2p3NWVXbQpZMmVKTURXRUp5eWxZV1RHbTUzbDB0TGwwZExHbXB5a1lH'
    b'T0FIeVRZdXJ2OSsvdisvZjNneWNxd2RIZUNJeWlMTXpqSG5KNzY5dmFMCk1qZUpNRFRPcWFy'
    b'OCt2dk1wcWlJTGpKK0hDQzBmSC80OHZPOWk0NStIQ0dRTzBEbjFOV1BPajZ0YjNLc2JYQjhH'
    b'QjNDbEpaOEdSN1IKcjdIVXM3Vi9IaVBYdWJyUnJyREZtWnZEbFppb1pXbisvdjc0OC9QaHk4'
    b'enQ0T0h1NGVMZ3lNclp2TDJkVWxhNmhZaWRVMWZhdmIrRwpLekQzOGZMbzE5aWNVVlhwMmRy'
    b'MjhQQ0ZLUzdEbHBsL0hTTDE3ZTNCazVXUE9qK3RibkhBa1pPbVkyYno2ZXJMbzZXdmNuWHk1'
    b'K2lrClgyTEluNkhLb3FTalhXSHQzK0NBSUNXREppcUJJU2J1NHVQVHNyT2dXRnYzOFBHYlRs'
    b'SytqSS9qemM2YVRWR2xZbVhid01LOGlvelcKdDduejZ1dlZ0YmZNcGFlVFFrYVRRVVhPcWF2'
    b'czN0K3BaMnF4ZG5tcWFtMk9PRHlPT1QzUHFxeVFQRUNNTlRtWFNFejkvUHlXUjB1aApXVjJn'
    b'V1Z5Q0pDaU5OanFESlNtR0tpK2VWVm44K3ZyMTd1N2Z4OG5leHNlVVEwZXdkWGl2YzNhV1Jr'
    b'cXhkM243K2ZubzF0ZlFyYS82CjkvZTJmNEdYU1UzcDJObTBlMzYxZllDU1AwUFd0cmp2NCtP'
    b'UlBVSHg1dWV6ZW4yMWZvSEpuNktaUzAvaHlzdmZ4OGpJbnFES29hT3oKZVh6QmtwVHk2T25M'
    b'cEtieDV1Ymt6OUM4aVl1OWk0M3IzTjJmVmxuMDYrdTdpSXIwN096TnFLcnMzZDc3K1BpcmJH'
    b'K3BhR3U0Z1lUcQoydHJqenMvbTB0T3VjWFNvWm1uaXpNMk5OenVITFRHVlJVbEhRa0RUQUFB'
    b'QUFXSkxSMFFOOXJSaDlRQUFBQWQwU1UxRkIrY0REZ282CkxRMExpNk1BQUFSVVNVUkJWR2pl'
    b'N1pyNVd3MWhGTWNud3UzbUplb1dzdHpjYUtGY1pVbmlrckl2Q1NsQzFoWmJwWVJLUXFUZHJp'
    b'eEYKWmQvM05mdFNmNVZiM2Q2Wjg4NU0zZkU0YytlSCtmN1crWjU1enVlWjk3M3ZjaWFPMDZW'
    b'TGx5NWR1blQ5WjdtNWFSS3JYMzlOWXJrUAowQ1RXd0VGYXBESjRHRDAxaURXWWtDRWF4QnBL'
    b'aUpjR3NZWVJNbHhyVE40K0psOUNmUDE4Um1pRmFPUW8vOUZHUW1VY00zYmNTRmN6Cm1VMEI0'
    b'NGxJbHNBSkUxMElGUlFjUW1SazlBOTFFZFNreVdHa0Y0V0ZUM0VCbEhWcUJPbER4c2hwYWxO'
    b'Tm4wR2MwT2laNmxKRkdZbFQKOHBpbElsVDBiT0swL0dQVW9wbzJoeWpRWEp0S2t6MkFLTkk4'
    b'cXhwVU1mT0pRZzFUWXh4amlXSXR3S2VLVTA1RjRrM282OVhDZjhBaQpFY2pyVjh3aXFhcUxC'
    b'VCtDZ0NWU0dVdWpVYkc4SkVvdVd4NjlndjlyUmZUS1ZSSkpFekNwRWxhTDZpV3VzY2VGYjh2'
    b'KzU4cTFvclIxClNZaFk2MFdUT1RhNWM5VlA0U01wbmNObEN4WnhiY0NqU3ZKZ2FvM3ZIcHZw'
    b'd3RqR3JsQXFlK2d4SnFCaGJXS3BSblhIVTRYQjFPN1kKWnZiVTZvNUY1Ym1GcWVRZzROS0V3'
    b'VFJIY0N1VHZBM3JjcnVkS2JTangwZ0V2NEdlNkU0bWZSY1MxbHhZSmozREVjKzBnUHRGcGlP'
    b'Ywp0UnZtNzBFNk9UQ3JBKzBiN1lYeHZUSnZkeC9PS082SFZRS3BrUTJOYkdya1FDTVhCU3NT'
    b'RmpsQWpUeG81TWx0Ni9rb1dBZEJqUUk2CkpBYm1DaFJob01mWUZHQWNRc0dDZS9CaEdqL0NM'
    b'dWlGMUNvQzhXSU1xcXg0VU9Nb05VcFlyQkpxSFlNOWdBd0VyRkpZK3pnMVRyQlkKUmRRNkNZ'
    b'MHlCS3hUY04vaHorZkZMQlkvV0o2bmdWR09nSFVHYmlWeWc5dDVyREJURTI1WEZSaTNRemVo'
    b'S3VVR3QxTlYxS3dHRDJHMApKR3BxaGVLWHhqSXhWaEExYzhGRE5RaFl0YUJ5Q3I4bmlkcEpk'
    b'Znd1Y3hZWXRRaFlRK0Q4U2FiR09SYnJQTjhzaFBQdUFnSldLS3pOCjkrQXZzbGlYcUhVWkd0'
    b'NFlVNzVPNWlwalk2NWc2ZnlMdkFLTWVwUm1SSVBjQnVjRFpsZWQ0S0FBbXlnelVQYkVxL0RL'
    b'VUNsb0FOUUwKWG9rZkgzZTdCaDdCK1pwd0hZNlZsOEM2MFVpUHpEY0U0U2I0eEUwVXJGdXd5'
    b'QkxoVFBFME5SZllEenZOZmdaQk1Ma0ZQdEdLMDVxOApEYXZjWVEvVjdJeStDL045a2E0WXpG'
    b'VW1vby92TzZITVpmY2VFdFo5Wm4xNjBPc1AzdnFRU1M5SHd1SWFtVUtQZWt0K3pDUTNvRjMy'
    b'Cm43RHIrVlA1M0Exc3JoY2FsdmtaVyt1NXpEaGF3OW5NRjRoOThDYlJHU2FuU3ZLQS9aS285'
    b'N0xzMjErNnFGeklLek9ibGZGYS9EM3YKRGVwWHFiY1MvY2QzNzhGSzRmM3FnMFN2ZVRsdVQv'
    b'ZUVWTVBXc2pTeW9zdyt5NnhWRmRtQkZxbU1qOGdOOE14MDJTNTNmYjJzOWFrYQp1ekZmR0tL'
    b'OExkK213djl0Zkk1WC9CSGpDNmVDbmlqRnVzNnBvbXhsVlBtY1NtcXlLQmpCcjV4cU1yVTVT'
    b'M1h0QUtlaVdodWNvL3BXCnlLbXFyRFFuZnBEeGo4MmMyaXIvM2hmVmoxek9CVEw4TE80TjZr'
    b'MVVET2NhR1g3OWxvTmFGT2NxcUM0ZGY1MG9icnMxNVAvaFhLNkUKdU9DOEZnZWJaWGVldnlt'
    b'QjA0eHM3YVVkSGFYdE5rNlhMbDI2ZE9uUzlULzFGOUpaS2xtR2o4UjJBQUFBSlhSRldIUmtZ'
    b'WFJsT21OeQpaV0YwWlFBeU1ESXpMVEF6TFRFMFZERXdPalU0T2pRMUt6QXdPakF3N05qbVFn'
    b'QUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0FNakF5Ck15MHdNeTB4TkZReE1EbzFPRG8wTlNz'
    b'd01Eb3dNSjJGWHY0QUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAgaWQ9ImltYWdlOTMxMCIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_39')

JP_39 = b64_JP_39
index.append("JP_39")
index.append("Japan Kochi")
catalog["JP_39"] = JP_39
catalog["Japan Kochi"] = JP_39
country["Japan Kochi"] = ('JP_39', '', 1)
lookup["JP_39"] = ('JP_39', '', 'Japan Kochi', 1)
lookup["Japan Kochi"] = ('JP_39', '', 'Japan Kochi', 1)
details["JP_39"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_39"] = ('JP_39', 'Japan Kochi', 1)
regional["Japan Kochi"] = ('JP_39', 'Japan Kochi', 1)
#----------------------------------------------------------------------
b64_JP_40 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3NDg3IgogICB3aWR0aD0i'
    b'MTQzIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0MyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRnVrdW9rYV9QcmVmZWN0dXJlLnN2Zy5wbmciCiAgIHht'
    b'bG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3Nj'
    b'YXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5l'
    b'dC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAg'
    b'IHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAg'
    b'aWQ9ImRlZnM3NDkxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2'
    b'aWV3NzQ4OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc3NDkzIj4KICAg'
    b'IDxpbWFnZQogICAgICAgd2lkdGg9IjE0MyIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAg'
    b'cHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJp'
    b'bmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7'
    b'YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFJOEFBQUJrQ0FNQUFBQ0lQcFBnQUFB'
    b'QUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFB'
    b'ZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ3FWQk1WRVVBYUxJSGJMUVFjYmNFYXJOUgpt'
    b'TXFzenVibzhmai8vLy84L2Y3UDQvR0h1TnNrZmIwOGpNVFQ1ZktWd044TmNMWnBwdEw3L2Y3'
    b'VTV2SWZlcnRnb2MvKy92L1o2UFFVCmRMZ21mcjMyK3Z5cHpPV3YwT2NnZTd6OS92NjcxK3Fs'
    b'eXVUZDYvV3J6ZVp1cWRQbDhQY3ZoTUFEYXJPQ3RkbnorUHNHYkxTZnh1SlAKbDhyQTJ1d3Jn'
    b'Yis0MWVyNi9QMXlyTlJHa2NlMzFPbDFyZFZFa01lWncrQkprOGl4MGVjbmY3NW5wZEdkeGVF'
    b'S2JyWDArUHp5OS9zUgpjcmN1ZzhBemhzRWhmTHdkZWJ2dTlmcGVvTTRqZmIwVmRMaC9zOWp2'
    b'OXZxa3llVFM1UEZibnMzSDN1NWlvdEJ3cXRUSjMrLzErZnl6CjB1aE5sc2tCYWJKcXA5SWFk'
    b'N3AzcnRiYzZ2UUZhN1FQY2JkVG1jdm04UGZGM2UzdDlQcFhuTXo0Ky8wQ2FiUEs0TzgvamNX'
    b'UXZkMlIKdnQ2UHZkMHloc0hXNS9NdGc4QklrOGpSNVBIVjV2SzIxT2tJYmJUazcvY3Nnci9i'
    b'NnZRNmlzUmpvOUEramNYcDh2aVN2dDZCdE5uRAoyKzBaZDdyczlQa3hoY0hFM08zeDkvdWJ4'
    b'T0cwMCtqTTRmQ0l1ZHZJM3U3cTgvbUt1dHhjbnM0b2dMN2g3ZllqZkx6QjJ1d2NlYnBPCmxz'
    b'b1hkcmtxZ2I4NWlzT2h4K09BdE5uTjRmQ3cwT2R2cXRSOHNkZFVtc3V1eitkc3FOTmxwTkNP'
    b'dk4xYW5jMm55K1Job2M4SmJiVkUKa2NmTzR2Q2l5T1B3OXZwUWw4bzFoOEpmb004N2k4UlVt'
    b'Y3ZRNC9HRnQ5cEtsTWdiZUxwMHJkV2d4K0s2MXVwWW5NMk11OXd3aE1Eago3dmRBanNWQmpz'
    b'YjMrdjEycnRheTBlanI4L20vMmV4SGtzZDRyOVkramNRcGdMNDBoOEs1MXVxRXR0cjUrLzIx'
    b'MCtsK3M5ZzVpc1RhCjZmVGc3Zlp0cWRPWHdlQVNjN2Q5c3RpbXl1UzkyT3NZZHJrM2ljT0x1'
    b'dHh4cTlUbjhmaUd0OXBMbE1uQzIrMm95K1Y1c05jT2NMWm0KcE5IRzNlNDRpY043c2RlKzJl'
    b'c2VlcnVhdytBbGZyMkp1ZHNMYjdXanllTVRjN2plNi9WNnNOZXVTWHJnQUFBQUFXSkxSMFFI'
    b'Rm1HSQo2d0FBQUFkMFNVMUZCK1VNQmhRc0c4SzlPNklBQUFVVVNVUkJWR2plN1puN1cxUkZH'
    b'TWRuSVowVlNBRzVTQVJzQ25qRHRUTEpSVndpClVLNUZMQ2doQ29Wc1dwZ1lxd0lwN0pJU2wx'
    b'QWtTTklDaFNLVUFvRW9LNUVNcmN3aXVwZGQ2UEtYZE02OGMzYlAyZFhmT25OOGV1YjcKQS9Q'
    b'T25PSE01NWt6TSsvN3ppTEV4Y1hGeGNYRnhjWEY5ZitYenV2MllmRytZODVjalBYemZIeHZD'
    b'eHkvT3pHVmZ2NEM3WEg4QTdCTApnUXUxeGdrS3huS0ZoR3FMc3lnTUszV1h0anpoMkYxK1d1'
    b'TGNIVUZYY21TVWdmTGNveVhQWW1CWUVvMVFUQ3pZUzVkcHlMTWNHRmFRCnlrcW94R25JczRv'
    b'UUdHRktWZ1BQdlJyeTNFY0lJblNrY2ovd3JOR1E1d0ZBV0VzcThWQjVVRU9lZFlCZ0V1MkU5'
    b'Y1JPOUdZTnNjR2MKOUJBMWs0SG5ZWEVCcFlBOWh6NUtNQ2VsTXRocUd6Y0ZpcU9tcGNPNWx3'
    b'RVFtWUtaQldZMmdYbmtVYjFnNXp5V2ExR1Z4cEtYNkR5SQo0L09GaHMxZ2J5bEFhOERLZVZ4'
    b'b0xkenE3RldrNW5LS01jazl3N2J0Q0lVV2crMWY4Z1FZeXhIeWlwTDNTbnRTUFo1U04xKzFJ'
    b'd2FsCmcxVkdUK3BnSzBwOVN0a3BjYWRhT0xzOG5HZThiaEVKZjRxczFNL0hJNzl0N3AyZVZt'
    b'bkhXWjd4NE1IbHU4VlArT3llQ3VwWG8vY20KZW5aNlRoMmVTdnA2Mjc3OUI1eGpoVmRWNHkw'
    b'MXo5TmFxZldnOHpNZDJsUkxZN1U2ZFhqczhIYUhtRW9VMWt2anZuQzQ3a2dSdFJ0ZQpiSkNh'
    b'RzV1RVhzMUdXRlF0S2pwUC9CS3A1RHVra1F2alFxaGxiRDBxUmZiSFlraXZRMnE2MkRieTdy'
    b'bFN4bldjamwwZG5VYXRkdithCmw0blRDT2lnblRKZHgrVi9ML2dxT2RKdUtlaWtHSjJ2UURu'
    b'L0JDNjJtN3RzV1ArcTlDOTVkQXBWNFRrSkx6OGwxVitqSGdLLzNpMysKN2RrbGJ2M1RYWHZP'
    b'U0xPREN1cWdRNithd1dsWUg1a2hyemZXUlZkRFMvZWI0dXcwUzZsRy8xc0QrZVFmenRKb1Aw'
    b'eW5DaysrbFBrdApOUmdNUzRReXFvTTJySzBJT0pjaXp3dHhqcUUvbzBGS3pkSlZPcDhIM1Er'
    b'NlhJZ1A4ZHZ2VkZxR0l2QXRwQjlXaWFlcTNtMms4NzB3CkJSSEp3dE9Sa0Z2dzdGRE5uNDZP'
    b'dVEwVlJEZjl1NEkzR1I5dGYrOW1PTytyR0pXTnVNMVEvd1ZzNi96ZzhJY2ZuVzI2S0tTQzFq'
    b'elAKT1FwUFVETWdheG1VTDl1d2lhcWs1a3NUaGttTVA3NHNPb2JJTTUrVVRjbHBydlNwSGJB'
    b'bVh6M3B5RENFT01vL3phdjhMR2dWamNmdwovbG9vYTBwcnFqbyt2N1p5bnNGUTk4VytBWmJK'
    b'NnZXdU5ObFdneEIxNjVjWXR4V1dhSkRxTExEbnlEL01NQlMxNU5ETVlKK2pEbHhSCkx0dGVL'
    b'TDdxZ1RLcWhTbU50OTF0RjQzUjlHSzZuRFo4UGNJUXB5VkxlU3hHRHM1OEEyYmZ0MUpqd0RR'
    b'em5JMnlER0w5ZDl1UERPVEYKMmxkUW5tN1hvKzhaNFZqS1hjZkwxUi9hRDRnblV1QUFOUHg0'
    b'Y2R4NXdSbHhnUTFQaHpOa245WWhDK3l5bjM2R3BsOFFHcDZRbmd0WgpLd3UxMGVGdS9DcFVt'
    b'cWhYOElYeU4zSCtGa3R1THBNRnp1OTBzQzRTbG8xQzVZK0NTVkpta1M1bW1vNk5zK0JKVWR5'
    b'amJwWlNQdmpWCllBeThweS9RMWJQZ3VheTRsbk5JbDVnMFdLTnJtSHF6V1FZOGwyQW9LNFRJ'
    b'c0p0c0ZtbmFUTkRwVDZqOXhlN09lVFdwbklQS05TZloKd1Ewa3NmaWJWQ1paT05ZUm1nYWFC'
    b'ZHQ2Mm5VQjNValhsUkJpV0labzRzRmkvU3lqVVVieDBYOTZpbVgzaHlmb3ZwdWFpWlZPaEJr'
    b'bQo1OCtRUjB6cVF3SVFqK2c1Z00ydllhSHVBOXRnMmJhNzgzUXhjbUM1ZW1WK0JkZmhxS1Jj'
    b'aWRNMnk0Z0haY3VEZXFQVEs4emVVRnpUClhXY1hBSTFVT0llZDJpc0wwM3dtcGVaZ0U5UGZk'
    b'blhaSk13d05wNVMrdkRVc3ZOa1JabUdFV3ZOeHJYdTNIMnp0Q09wZGFFRmNYRngKY1hGeGNY'
    b'RnhjWEZ4Y1NuMEw4akJIUFBhaTlXNUFBQUFKWFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl4'
    b'TFRFeUxUQTJWREl3T2pRMApPakkzS3pBd09qQXdoaWg0eHdBQUFDVjBSVmgwWkdGMFpUcHRi'
    b'MlJwWm5rQU1qQXlNUzB4TWkwd05sUXlNRG8wTkRveU55c3dNRG93Ck1QZDF3SHNBQUFBQVNV'
    b'Vk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2U3NDk1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_40')

JP_40 = b64_JP_40
index.append("JP_40")
index.append("Japan Fukuoka")
catalog["JP_40"] = JP_40
catalog["Japan Fukuoka"] = JP_40
country["Japan Fukuoka"] = ('JP_40', '', 1)
lookup["JP_40"] = ('JP_40', '', 'Japan Fukuoka', 1)
lookup["Japan Fukuoka"] = ('JP_40', '', 'Japan Fukuoka', 1)
details["JP_40"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_40"] = ('JP_40', 'Japan Fukuoka', 1)
regional["Japan Fukuoka"] = ('JP_40', 'Japan Fukuoka', 1)
#----------------------------------------------------------------------
b64_JP_41 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMzI3NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NhZ2FfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMTMyODEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXcxMzI3OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMzI4MyI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVAK'
    b'blVsRVFWUjQydTJkZVZ3VVY3YkhUMVYxVjYvUWRFTTNncktEZ3Jpd2lob3dRakxHekl4eFgw'
    b'aDBqRXY4SkM1eG1SaVhlZWE5eElrNgpKaVlhbnliakJKZGtGSGVkK01aUnh4MXdBUUVYVnRG'
    b'V1FIYm9CWnJlcStyOTBSMHdyRUk3V3BENys2Kzc2dHhhdm5YdlBlZmNlNnN3Cm1EOFhrSHF5'
    b'Y0hRTEVFSWtoQkFKSVVRSWtSQkNKSVFRQ1NGRUNKRVFRaVNFRUFraFJBaVJlcTQ0dmZuYWNQ'
    b'eUQwZkVBOE8zbFMxYWEKUmdoN21CS0NRN2JPbURHNGJ6OEFXQlNmc09Md29kUDM3dmJLSzhW'
    b'NjMzaGhvRUt4WWVMa3FWRlJMZjQvbjUrMzlHQnlYbmw1TDd0ZQpBaUxDZTgzRjhEaWNQMCtZ'
    b'K09PODk0YjA2OWQ2cTc5Y1BqOXVsSWpIU3kwcW9ucFJ1OXA3YXVGQVQ4OEQ4eGNNOWZMcWRN'
    b'L2JwU1dKCnUzWVZWRllnajVSRjZ1L3VmdW1qbGMvQ0R3REN2THhUVnEwZTZPbUpFTEpGQ2lm'
    b'bkMzOWNxWEJ5Zm5ZVE43SDR6TkxsY2ljbmhKQVYKK25McXRINVNhVmV0dkdTeXpWT21Jb1F2'
    b'WDFHK3ZqT0hEKytlN2V3Ukl5TzhmUkRDbDZ6NXNhTXdET3VtTDRkaDgrTGlFTUtYNms5agpX'
    b'T3Y0cjB1YUhoWGQ3U2NBSVh3TzhwYkpaQ0tSSXlXNGlzVjlYVndRd3BjWlN6eVBRdnIwNkp2'
    b'QTNod3BseUNpZmYxR0JBUUVLaFE0CmhqV2FUUGtWRlRlVXludGxUNW9mUU93NVBJSXQydEVo'
    b'L2ZvTjl3OEk4ZkFRa2lSRjB3K3FxNjhySDk1Ni9OaENVUWpoczhwRktQeGcKOU9nbENhOTdT'
    b'Q1N0dDk1OThtVDd4UXU3VTFOb2hqRll6STRmem1TeEFnQ09ZZlBqUmkxT1NMQmx4bHVvWEtQ'
    b'WmZ2SENkMWN1YS9SNgoxamtFckVxd0VUaStZTlNyNjhkUGNCV0xPOTR6L2RHamQvY2tWVGMw'
    b'MUh5MXRja2ZvZFFxcXJhYURBcnV3TkJjVkVDNEtRaXB6UGFUCllSaTM1VXY3U0NSNzU4eU45'
    b'dlhyK0tCMU90MjZmNXpjZGZVS3ExS3NMRXB6eHdjSG4xaTRlRzVzckpBa085MjVyMVQ2ZHN6'
    b'd2M3bTUKc1VGQmJtS3hQdTFLM1RlYlZkOXNOaXVMbkg0N3ZnUEQ2di81V0xYaksxTk9OaTRT'
    b'YzcxOUN5b3JyOXkvZjM3RlIwR0t6cnRWSVVuKwpic2lRYWRIUnlwcWFCOVhWeUoxcGxyOWNm'
    b'bnpob290L1hObm1DRU43a2dxRlo1WXRQNU9iQXdENjFFdkdySFJnYUZOQkx0Mm9hOCtFCjF1'
    b'dk5oWG5BMEliTWRIM2FaUUE0bTV0ejhhT1ZicDFWK3FjVjNNZmo5TkpseHhjdThwZkxFVUs3'
    b'cnExZU96RThvcXRXbEVibHhDTkgKOXgvUWFESkpFdDhGbTJ0RFVjYmJtZTJaR0xNekdLdlY1'
    b'c05JcHMzU204M3hBNExGSkpmU3FMcDY5SW5oRWRkV3IwVUltNTNQcnBvWQpiOThxbnplai9t'
    b'anlVQyt2dklweXJyZXZjRVNzZlZQbXpmYXNERDl2RW80Y3hmWDF6eWtyRytybFZYODB1WHpl'
    b'akE3QVA4ZlRSbkdoClhmclVTMVdyUHFUVUt2WDNPOHpLb25Cdkg1UFZLbm5IN3BjWnN0TGJC'
    b'Zjh6UXNtTTJTYXJOY0xiMi9KWXFVN2FRYWxWVlI4dmJyeDQKRG9YMkwwam1oMFdNeFF3QWpN'
    b'VmN1K0VUZ3JMcXpXWmV5Q0QrNEhBQXNKUTh0bFpYdGJheTFsUmJTb3NCZ0Q4a2doYzZwTUZv'
    b'SkdpcQo1czkvWXN4bUFHQ3NGa3ZwWTRUd1JRV09zeGRJMzF0aXg2a3MwaVI5S3hVS0tacVdK'
    b'TTYyMTdhc050cFM0NjBiOWlxWU9OdENVVzVpCnNUcHBwMWxaMUZTbXkrd0ZDT0dMa3lSeGRo'
    b'TkY3Wkg5eHV3TUhNY0ZNYStRZ2YwQndKQ1ozbDVIU1BvSENvYU41T0M0OFY1Mi9aRUQKUFow'
    b'Zld4QXlET01RUllhdTJmamZUS09Pd1REbnFUTUJ3SmlaRGkzS1pCamo3VnUyWHBBR1lBejYy'
    b'cy9YQVVNN3dxOTdwOTA3RWRicQpkQTdXUmFxMnVtN3JKZ3hBRkQrRzQrNUJhVlNtZ3R5bjl6'
    b'UVY1RktxT282N2gzRDBiM0FNcS90cWc3VzYwc0g2VjZOclFBanRxdEJxCkhXOVJHeStjTVZ4'
    b'UHdUZ2M1K216QUVEOS9RN0dhckZYRjZ0Ri9iZnRBQ0NaUGd2amNQUnBWeHN2bm5XOC9Telhh'
    b'Tmh3OTFpUllBdngKOElnTkRPcTJPWDl3R0FBWTcyUWFNcTQ3VDVyQkN4bGtUTDlteXJtalQ3'
    b'bkVOT3BNZDdQcnRtMDJGK2J4UWdiSmxxMEdrN0Z5K1FMRwpiSEs4LzB0T1Q3OVlrSThRQWdB'
    b'MG1rM3pZaDJhQU1FUGk2UzFHdVBkTEZ3ZzRBK05FTDM2bXZuUkExUHVYV05XaGpFN2c5YXFC'
    b'Y05qCkZaOXV4dmtDemQ2L0dqTnZPaytjTGwzd29ZT24vZEdSdzJVc3FJaXNHS25BTWV6V2Yz'
    b'MFM3dTN0U0NGMG82NTA0dXVjUHA1OWZ6amUKRkcrWThuTUJnQmN5aVBRUHRQMzVaT1lFcXJy'
    b'SzYrUjVYT2pRY0g5bWNYSDA1K3ZaNE5Hd1lyeVFacGpWeDQrZVhiYWk3VUMrcUlBeAptOG5n'
    b'VUt6RGhCWXVFdU1pTWFWdHJoYWtmeERwMzdKOXB1dTF1TmlwVTM0TVJaa0xjakdTUndZTmFI'
    b'T0gxY2VPc3NRalpjdVE3N25jCjNHOHZYN0t0Sld1aCtoT0hkR2RPNFVJUlB6eUtIeGtqaUl6'
    b'aGVyVXhjOUJTcktTMEd0NkFnWjFjc0djLzgvMThTL0Vqcms4Ym80T1cKMG1KRDVrMWo1azFq'
    b'OWkxYTN5Z2UrNWJieDUrMDN1MS9MMTQ4bjUvSGtsdkhvbEg3cFFlVEErU0tNYUdoTFd0aFlS'
    b'NEEwUHBHZmRvVgpmZG9WQU9BbzNQa1JNWUtvR0g1RU5PRWlBd0JyZFdYTmhuVUFJQjQ3cnVP'
    b'ak9JMGRWM2MvdjJiRE9zWDZMUnlGT3dCUUdwVXhLOE53CjY2WXg2MmFMekp6NWZodmV5dG5j'
    b'bk9XSGt0bHozOWcxYXMvQjhhK25KeTVPU0hqNnorTGZ4akZHUXp1bmozRzlmWEdCMEpZMUZj'
    b'UzgKNHY3NTE0RGp0bmhmZS9qdnVyUC9aK01xbWZxT2ZUU0twcXZXTGpPa1g4TzRKQmtRUkJ2'
    b'MGxwTEgwRTZUaUF1RTN2KzgrdlEvdTY1ZQpXWko4d0d3YnNVSUkyOU80b1VNM1Rwb1NhbHUy'
    b'd2pDbXdqeEtyYUsxYWtxdG9sUXFTcXVtMVNwS1hVZHAxSlJHRFRRTkFCeTV3bW5jCkZPZkUy'
    b'VTM5cGZiUUQrcS9mdE5VcHZUOXBaSnBzNXI2T1czeTNvYWZqbEcxMVFBQU9FNjRTQWtYS1NG'
    b'MXhhVXlRaUlsWkRKQ0tzTWwKVWtJcTR3MFlhSnNnbFZOV3R2cjQwWC9lWmQwNlU1WXVUaU53'
    b'UEg1QThQaXc4RmNDQXowa0VuZG41N1luN0RJTWJUSmlPSTZSdkJaYgp5dVpNc3hRcm0xMGJ2'
    b'd0RQcEVNdHJjMW1ZR2lNNUVGYmhUTU1VMVZmWDZIVnBqMTQ4SS9iMlpjS0M5aTVLcEdsYVc0'
    b'TUFNY3hBc2Z3CnpxWmFNeVlUWXpMWnNwMHRpL2hsazl2S0Q2WVprNUUyR2pzNUV3eHduTlVU'
    b'dnRrNENYRjhXUGpHU1pORFBEeWFHbEpEWGljTktlRXEKZDNwcnNpVHhYWXhqdnlMeDJISHE3'
    b'N1kxbFNrZTgvdG02bGFyOXNDZWhsUEhxTHJhamh0U3FWVFdaOERBTUMvdmhhUGo4OHJMMXh3'
    b'Lwo5dE9kMjZnaDdjU2QyVG9qY1ZGOEY5MFprZGo4b0pBeG13WERScnB2Mk5yc3poelozMmh6'
    b'Wjk0WTV6ejE3V1ozWnMxU1E4WjFqQ1RKCndBRjBvNjVMN3N6M0tWY1hIZGpQS25lR1JiV1FT'
    b'eENubHk1N1BhUmxZTWYxN0d0V1B2akZTYmNSVkZSVnIxdGhTTC9XY09xWTAvaXAKQUFBWUxw'
    b'azJxOG1GYVZMRFQwY05HZGZKL2lHSzlWczRja1hIUVFYSG8yOEw4L2x4bzd4bHJyL2Z2bzA5'
    b'azd0WmhQQ2J4TGRiOHdNQQpzbitJV2ZtZzQ5Q2VvM0NYcjExZk5tZWE3c3dwTzhKMjFIRG1G'
    b'R0NZZk0xbk5uNEFRTGpJUkFsdmlCTGVhQjNhay8xRFdwY3dKalQwCnU1bC9tTGR2RDBMNEM0'
    b'MGROT2o5VjBlM3VjbDU0blNuMzAzc05NSEc5ZkVuSkM2VzhpY2RIOGhhL29TUVNOdE16UUFB'
    b'MTh1SDYrWGoKUEdGYVU0S3R6ZDNteHNZZXpMajU3N3c4aFBEbkxnZkROazZhM043V2ppZllO'
    b'enVZalRxNlVjZnAwL3dTQlBPRCs2YkNYQURnQlllUwpBZjN0ZFU3aVlxMnFvQnQxdUtpajZi'
    b'OFlRZkJDaDNTd3c2YkpVODdub3pUM3p4b1JFQkRtNWUxZ0lacWtuWXpWS2g3N0ZnRFE5ZHFh'
    b'CkRlc002ZGVhdGdxR3g4clhmSVk3T1F0SHZhWk4zcXRKMmluNzhHTkhEaGZoN1JQajUzZERx'
    b'VVJ4b1QyS2NKVGZ2bDMxSncvalRzN08Ka3hNWmlxcGF0Y1NRZm8zcjZ5OTliN0YwL2lLdXI3'
    b'L2hSbXJWcWlVTVJibk1uSXM3T2RlZlBLelp0K3VsbjNidlFkanBrcUpPK2RsNAp5RmQvaXZG'
    b'NERhZU9tUXJ6K0JIRFBIZnRseVMrSzNsN2p1ZXUvZnl3S0ZOQnJ1N1VNVXdnbEsvNjFHWmxt'
    b'NDNSYlEzejgwTUk3ZkowCllLbDBFei9SNjI4S1JzUXhWbXY5b1I4QlFEcC9FY2JoMmpzMkRs'
    b'ZjYzbUlBMEI3NmtiRmFCU1BqUksrTkJRQnQ4ajVIS1BaMWtTS0UKZHJsMmQ3MThFeitPWE9H'
    b'NmRCVUQwSGpwbkxXcWduQ1J0Umc0NUFXSEVqSlhhMVZGNDZWek5NTzRMbC9EY2Zkd2tHS1gx'
    b'a1AxY29UZApTMEUyOFFNTWQxdjlLUWhGR01QVUg5d0hBUHpJWVMyVG9oakdENHNDQU8yQlBU'
    b'Z3dJQkM2cmYzTWxzZnBOa1dXWkU1NzZtenVabjRBCmtta3orZUhSRE1Qb2I2U2FIejBFQUVI'
    b'a3NOWW1nc2dZQUxBVVB6TGN2RWJSTkg5d3VHVEtPN1pORHJhb0NLRkQvRWovSUplNTc2djEK'
    b'ZWdMSGJWVVFBUGdSTWEydCtGSERtNEJ4Q2FKRzErQXk3NE9teVRYYTVIMk8rNmdJNGJPS0RB'
    b'akN1Q1FBWUZ6U2JlMW5GTUVSa3FRcApQOGQ0N3pZQWNMMTlPVzJ0dXViSUZiYk1uUEZldGlu'
    b'bmpqTmZRT0dFZk4zbkdJOW5jM200WHI0STRRdVNNRGJlL1MvYkNhbE1PbjhSCjZSK1VYVkxN'
    b'NDNDMGY5OXRiekFqaHJWbnlJKzAxMDd0d1gwOERpZXpwSmpyNHkrZHU1Q1F5dHkvMkNGS0dO'
    b'TVQ3d1lyc2pQZHlQcnoKd3lJOWt3NFNFcGZiSlNVRFBUd3R4WS8wTjFKYmNHcXpPMnc0ZVJn'
    b'QTlOZFR6SThlRHU3cmRhZTBkT2lVUk5GdjNyU05lUHluVDd2WAoxc0tSbXphY3lNN3FxaFho'
    b'SXFzM21sS0tpa1E4bmpaNXIzM2duaUQ0WVpIdGdnK1B0bzhKTTB6OTRSK0ZKSG01c0tEQlpP'
    b'NEd2eFBaCldTTTNiVUFJN1ZMVzFFemF1U05oeXhkM256eDVkaXUxWGo5MjI5ZTJTWXZDdUFS'
    b'QjVEREFjVjV3YUFmNWExd29KQWNNQkJ3WFJNWUkKNHhJQVlFem9vSVF0WDNScGFWVkJaY1di'
    b'Mjc2ZXRIT0hzcWFHRlNGWkQzMTEwQTJsY3M2ZTNiVzZodXFuWHgya1VWRTF6L0RxSUxtaQpx'
    b'ZG94REtOWXNVenU1TFJuenR3WVAvK09ENHBlSGRTNUdJYTU5Zmp4cnBTcldvTmhvSWVuRTUv'
    b'ZmVwL3NrcEkvblRqK1lmS0JHbDFECmxLL3ZuRmRpbXlzWlgwQzR1blZ5d2E1dU9GL3dkSGgr'
    b'NnM2ZHJKTGkzYW1wcFNxVnQ2dXNUMXR2RFN2VHFEZWVQdjJIM1VtcFJVVXMKbVlmUExuZW1a'
    b'ZGluMTIvNjEra3Q1ODVHK3ZpTUNBajBkWFhsYzdrTlJtTkJaZVVONWNPY3NySm05NFJMT240'
    b'NEhwY0RBRFRESktXbQpKS1dtRE83Ykw4YmZQOFREUTh6akdTMldSN1cxMXg4K3pDeCt6TnJ2'
    b'emJEM1RZZ1dpcnFoVkhZOElFY3o5UE9vK3IvNGVhL3N5ZE12ClcwUng0WDlXaFpXVmpoZHl2'
    b'NnF5UjkrRW5vMndWSzJ1Nis0NmZadHFkYm95ZHF5My9wVWlaQmptU09ZdFIwbzRsSkhPTnZm'
    b'azE0VVEKQUw1UHVkcHRCZ3pESktXbTlQUTcwT01SWmhZWC8zRDlldmRzOTZTbFpaZVVJSVF2'
    b'WHl1UEhpNVZkZmx0bENVcTFhcGpSM3JCNWZjRwpoRFVORGE5dCtiS3F2cjVMWHN6WXJWL1ZP'
    b'dVlLSVlUUFUwWFZWYU8vMkh5NzlKbGF4ZXlTa3RpL2JNeXY2Q1VmditzOW42Q3MxZW4yCnBx'
    b'VnhDQ0xhejQrRHQvMW9tcXpXTDgrZW1aWDB0eTVWV1lUd3hZbWk2UXY1K1FjejBqMGtMcUd0'
    b'UGs5NFBqOXZ3bzd0QnpQU3FkNzEKYWVaZStDMWZtNTcrSEhOaFpTWDZISE9QMUsva28raTlH'
    b'ZUd2UkRpNkJRZ2hFa0tJaEJBaWhFZ0lJUkpDaUlRUUlvUklDQ0VTUW9pRQpFQ0tFU0QxWC93'
    b'OG1wNzhnMldNM2dnQUFBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUFNakF5TXkwd015MHhORlF4'
    b'TWpveU1Ub3hNaXN3Ck1Eb3dNTlR0WGFvQUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdN'
    b'ak10TURNdE1UUlVNVEk2TWpFNk1USXJNREE2TURDbHNPVVcKQUFBQUFFbEZUa1N1UW1DQwoi'
    b'CiAgICAgICBpZD0iaW1hZ2UxMzI4NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_41')

JP_41 = b64_JP_41
index.append("JP_41")
index.append("Japan Saga")
catalog["JP_41"] = JP_41
catalog["Japan Saga"] = JP_41
country["Japan Saga"] = ('JP_41', '', 1)
lookup["JP_41"] = ('JP_41', '', 'Japan Saga', 1)
lookup["Japan Saga"] = ('JP_41', '', 'Japan Saga', 1)
details["JP_41"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_41"] = ('JP_41', 'Japan Saga', 1)
regional["Japan Saga"] = ('JP_41', 'Japan Saga', 1)
#----------------------------------------------------------------------
b64_JP_42 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTAxMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05hZ2FzYWtpX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczExMDE2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFt'
    b'ZWR2aWV3MTEwMTQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9y'
    b'PSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'c2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2Nh'
    b'cGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9k'
    b'ZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTEwMTgi'
    b'PgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAg'
    b'ICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJl'
    b'bmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdl'
    b'L3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhU'
    b'bkNBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFD'
    b'QTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDVlZCTVZFWFMwdExuNStmLy8vLzgv'
    b'djdhCjd2aXQyL0dZMGUyTnpPdWIwKzI0My9QaDh2cmk4dnJFNWZXVjBPeVB6ZXVkMCs3QzVQ'
    b'VHgrZno3L2Y2KzR2Und2K1k2cDl3U2xkVUsKa3RRcG9ObDd4T2plOFBubDgvcWEwdTFndU9N'
    b'bG50a01rOVJEcTk3MSsvM0I0L1JtdStRY210Y1FsZFYzd3VmMisvMm8yUEJOc09BTgprOVVp'
    b'bmRpczJ2RDkvdit3M1BFK3FkMDNwdHpuOVB1SHl1b2JtdGR6d2VhcDJmQXZvOXN2b3RydDkv'
    b'ek02UGFUeit5MTN2TFc3ZmpQCjZ2ZWwxKzlYdE9GeXdPYmE3L2xLcjkvSTUvVWpuZGozL1A2'
    b'RXlPa1JsZFc1NFBQWjd2Z1VsdFllbTlqeitmMzQvUDdRNnZlajF1OVAKc2VCUXNlQ0l5dXBK'
    b'cnQ4MXBkeisvLytBeCtrb245bmo4L3I2L2Y2azF1OFRsdFl6cE50K3h1am85ZnVLeStwNnhP'
    b'Zy9xdDBXbDlaYwp0dUpWcytFMHBkdnI5dnNXbU5aT3NPQVhtTmFNek92WDdmZ2duTmg4eGVo'
    b'SHJkOGtudGxJcnQrUXpldWMwKzd1OS93eHBOc1BsTlh5CitmMGZtOWhidHVJOHFOMjMzL0sv'
    b'NHZUTzZmWjR3K2VDeCtrZG05ZXUyL0ZMcjkrVzBPME9sTlZkdCtKQXF0MmkxdS93K1B5cjJ2'
    b'RFIKNnZjdW90cFp0ZUpUc3VGNXhPanA5ZnZMNlBZMnB0d3dvOXM1cDl3cm9kcXEyZkM3NGZO'
    b'YXRlSlVzK0gwK3YxanV1VEE0L1E0cDl5ZgoxTzdHNXZVYW1kZFl0ZUxZN2ZnTGt0UzIzL0pX'
    b'dE9GMnd1ZEZyTjc1L1A2MDN2SnV2dVlxb05xWDBlMGhuTmpjOFBtTHkrc1ltTmZWCjdQamQ4'
    b'UG1GeWVwR3JONFptZGV4M1BIcTl2dG51K1RtOVBzVmw5YWcxZTd2K1B4U3N1RXNvZHBldCtP'
    b'aDFlN3M5dnllMU82QngrbXoKM2ZLU3oreDl4ZWpnNE9EMzkvZmVQRDR4QUFBQUFXSkxSMFFD'
    b'Wmd0OFpBQUFBQWQwU1UxRkIrY0REZ282TkdsZ0kyTUFBQVBqU1VSQgpWR2plN1puM1YxTXhG'
    b'TWNoVUNtVTFUSWVnbGhaZ2lBcUtBcXlGRUdzQTBVc0lDSWdVeXVnTEVHR2dJckZoYUNpNHA2'
    b'NEI0SWk3b1YvCmwyM3BlOUFrcjdhYTlPQTV1VDl3T1BlYm5PL25uQ2IzSlRkMmR2YXpNT3pz'
    b'N01Fc0RIdUd4YkFZRnNOaVdBeUxZVEVzaHNXd0dCYkQKWWxnTWl6eVdnNk5ranBPVDFOa0ZV'
    b'V1N1RWpkM0Q0bW4zTlpZQ2k5dkgxL09HSDV6L2FlVmdIbUI4M2xCdVVBYVpFT3M0SkJRemlU'
    b'QwpGb1liaEtDSVJaR21TdFJpRzJGRkwxbktvYkVzQmdCNTdIS01zaUxhRmxoeEt6bHNySXBQ'
    b'V0oyWTVKK2NrcXFFbERYMHNkYW1jV0lSCnlJOVpsdzRwRVpTeE10Wm5jdUt4Z1IrbTJtZ3Fi'
    b'TnBNRjJ0TDF0WnRrYUpZMmNLNDdaRGlSSDl0cVhMRXNKUXlma3dNdEx4MlVNVlMKVC8zTkZl'
    b'T0tFMGJtUVVvK0xheWRCVG03dU16QzNVVzYvNHRGc0VxRTBYc2dKWkVTbHIrUDBhQlV0NjNV'
    b'Wlhpc2NtRjRCYVM0MGNGeQpuTEhucFFCVVZtR3g5Z29WZHgra2FLaGc3YStlWVpHcEFxQUdp'
    b'MVVyak9mK1ppdGFpeVU3WU9KUkJrQVdGdXNnUDZFT1Z1b3BZRFUwCm1ubzBIUUxxWmh4V0N6'
    b'L2pNS3kwa3NkU0lOK2JOblNyR2NMYk9LTWRVVnpJWTNYZzZsTTVEdXVJY1VZZ0xIU3FpV01s'
    b'b3ZaZEFIVGoKc0k0YXZ3UEhZT0U0OFNwZldZM2FKd0hRWTZiS3B5TENDZUpZZ2FoN2hTNWRp'
    b'TVB5TXN6d1JQS1pXdEpZd1JqM1hsMCtGSWQxVWo4agovQlNTUDAzNnZCVmRnWnFmMGVXMTJM'
    b'cWwvMTZDczJpK2pUUldIT3BSM1ljdEFicW8wczg0aDU3SCtra2ZtdFVENktFcVdDOUljRmpu'
    b'CmRZTDhBcHEvU0JwckVQWG9NQWdhSEphK0RGeEMwejVxMGxpWEVRKy9Ld1poQ0llVkM0QWJK'
    b'bjJWOUQweHZrbnNHbkVOaDFVQVBNUFEKN0JEeDYrdDFzUk9Wd2hlSGRVTjFFMDEyVmhMSHVv'
    b'V3M5K1FwNFRhMlBpVDRvYms3ZDRuM0lLS1JxL3M5bzlLRm80ck13eVR2aysvWQpxRVJYcjRh'
    b'ek1CNE1rOGQ2Q0pzTThNb2pDNmtlVndMeVdFOWdseHBleWJhTTZ1a3pHbTIzNTdDTks2L1VX'
    b'a1QxSW90S2t4SytwZm9xCnJNSUtiYWZUTzYySGZCb0ZwZHVTWC9BbHBaYXVNL3h4QTFZcytZ'
    b'Rlh0RHJOK2ZDK0VoVHBINm02dFlBV0ZvRHVoOG9pMFZzelhOdHIKRkJUNzhpT1FXN0dndkRa'
    b'TDFlbE05Ym1nWWRUVXJsVEZLMlBtcUZyZVVIN0Y4SUFNbzVMTlhJajRFOWtZL2NlVnQvRG5P'
    b'R1J3UER5ZwpQU1c1WVFBUE5WcWNZWU0zSDRjUWpQVzdEdDB0b3c5M0Vtd3VsZ05nQXl3QUp1'
    b'RFRUWS8wL1ZRenZBTTZpa2FtOVE0RFlDTXNvSFh2Cm4vNkpQbWdjWjlTMWtvK0NrdjdwODVk'
    b'L2ZkNnl0dTAyN3Z5MTdsdnNSR3NTOG5yai8vM0h5RThuanpZWklCRHM5WlZoTVN5R3hiQVkK'
    b'RnNOaVdBeUxZVEVzaHNXd0dOWi9nVFg1YXhiRzVHK251aG9TSktUcDRBQUFBQ1YwUlZoMFpH'
    b'RjBaVHBqY21WaGRHVUFNakF5TXkwdwpNeTB4TkZReE1EbzFPRG8xTWlzd01Eb3dNT1hWMkZJ'
    b'QUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNak10TURNdE1UUlVNVEE2Ck5UZzZOVEly'
    b'TURBNk1EQ1VpR0R1QUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMTAyMCIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_42')

JP_42 = b64_JP_42
index.append("JP_42")
index.append("Japan Nagasaki")
catalog["JP_42"] = JP_42
catalog["Japan Nagasaki"] = JP_42
country["Japan Nagasaki"] = ('JP_42', '', 1)
lookup["JP_42"] = ('JP_42', '', 'Japan Nagasaki', 1)
lookup["Japan Nagasaki"] = ('JP_42', '', 'Japan Nagasaki', 1)
details["JP_42"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_42"] = ('JP_42', 'Japan Nagasaki', 1)
regional["Japan Nagasaki"] = ('JP_42', 'Japan Nagasaki', 1)
#----------------------------------------------------------------------
b64_JP_43 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5NDgyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS3VtYW1vdG9fUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzOTQ4NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVk'
    b'dmlldzk0ODQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIj'
    b'NjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hh'
    b'ZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6'
    b'cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0i'
    b'bGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnOTQ4OCI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRuQ0FB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNFMUJNVkVXVEhTT1ZJU2EzYUd5MVpHaXcK'
    b'V1Y2cVRWS2hPMENxVGxMLy8vLzkrL3Z2M3QvZHQ3bkRnb1dyVDFQR2g0djM3ZTdWcHFteFhH'
    b'Q1VJQ2Jpd3NQeDR1UEZob3FiTFRPVwpJaWo2OWZiNjlQWE5scGlaS1M2dFZGajA2ZW02Ym5M'
    b'SmpwSGd2YitmTmp2bHlNcXZXRjJYSml6OCtmbjkrL3l4VzEvU29LT1RIaVRNCmxaZlVwYWVV'
    b'SHlYb3o5RFBtcDNDZ0lTellHWCsvZjNQbTU3MjYreWRNampyMWRhYkxqT1pLakRUb3FUSWpJ'
    b'L3UzTnorL1B6cDB0UFYKcUtyRmhvbTlkWGk1YlhIQWUzN2R1THIxNit2MzcrK2VORG1hTERL'
    b'bVJVcktrWlR5NU9YWXJhK2tRRVc1YkhEeDRlTHExTldwUzFEOAorUGl2VjF2UW5KNlZJU2Z1'
    b'M04zV3FxeWhPais5ZEhqbXlzdW9TVTdZcnJERWc0YjA2T25idExha1FVYmFzYk9rUUViMTZ1'
    b'ckNmNFByCjFOYVdJeW5idGJmdDJ0dTBZbWFmTnp5K2QzcnQyZHFuUjB5WUp5eXhYV0hEZ1lT'
    b'elgyVGZ2TDI4YzNmdTI5ejU4dkx3NE9HMlptcXYKVjF6Nzl2Ym56Yyt0VTFpdVZWbnMyTm5h'
    b'c3JTNmIzTC8vdjdJalpEOCt2cXJVRlN3V2wvR2lJdjI3TzNseWNxc1VGWG96dENpUEVIUQpu'
    b'cUMxWldtWktTK1lLQzJjTURiNTgvUEhpbzJlTlRxYUt6RzhjbmFzVVZiUm42S3BURkdjTURY'
    b'RWhJZXBTay9JaTQ3QmZZRE5scG5xCjA5U2JMelRTb2FTK2Qzdk1sSmZ3MytERmhZanMxOWpp'
    b'dzhUeTVPVENmb0xldTcyZE1UZTRhMi96NWViNDhmR1hKU3ZUbzZYdjNkNjAKWTJlaE9UL3Vj'
    b'c2o3QUFBQUFXSkxSMFFJaHQ2VmVnQUFBQWQwU1UxRkIrY0REZ282TkdsZ0kyTUFBQU5kU1VS'
    b'QlZHamU3WmxwVnhNeApGSWJUV2lURmFxSHNJRmdFMFVvVldSUXRscVdnaUNJb0tJc2dJb0py'
    b'eFNxSWdnZ0lkY1VORmZjTjl4MS9vaDZQSG8vYW04VG1wdVZECm5xL1QrODdUbWN4TWNrT0lS'
    b'cVBSYURRYWpTWk1HSXoveVJ4VHhGeURjcTFJR2dUbXFIbVcrVXJkRnRCZ3NVYkgySlJweFZJ'
    b'SjR1SVQKMUZnbEpsRXBrbE5TVldndHBMS2twU3ZRV2tUbHNXZWdheTFHMEtMV1RHU3JyQ1VZ'
    b'V2pUYmdxdTFsQ0t4eklHcHRSeExpK1k0RWJWVwpvR25SbFhoV3FkbDRXalFYVFdzVm9oWE5N'
    b'MkZwNVdOcTBZSkNKSzNWcUZyVWptTzFKZzlYaXhwUnRJeklWalN0Q0VOckxiWVdYWWVoCjVl'
    b'S2ZwM2k5dTZUVVdGYWU0cWtRMGFwRW1PWnM0RDd5c1dVYmYvKzhhbE0xMzZ0RVhpdWRjNkUy'
    b'Yi9sN09WSVR4ZFBhS3Y5dGRETlAKVUZzWGFESmJzbzNqdFYxYUs0NFZYOThRdUtocUIxdHJw'
    b'NnhWSStzR05vRmxDZXlaWTRYc1hXeGlqUFV5MXRTeG1lblZJcW0xQzQ1dQpaUllXdVZRK2ky'
    b'MWc4bTVPWlhzeVEydVBuRlVIR0x5WHV5YnRaR2k1NUxUS3dlQW1icTF0SCtOcDZaTFM2b1p5'
    b'OXd2TXlnOHdMdGRCCkdTdW5GWW85SkZEdE9BeHIxY2xvSFlGU2s3d2k1YTJ3MWxFWnJSNjVK'
    b'eWtEMWpvbW8rV0RVbytMMVo5UW9tWG9oVkk3eEFLaWxkeEUKc0RkcEZ1endXWlFNZWJBMzJT'
    b'Y1ljRkxKQ3dMc1RkWUtCdlNEcjlQRTRLMjZUa0dwcHdVVEJsUjhmQWJCVzNCR01DRUdDaGhT'
    b'MHB0cwpFMHc0Q3dYRUsrbE5EZ3N1cVVZVVRBT3pSdUdYOURteENJK0NTZk1ZWXdJd0xwVGc4'
    b'QVBsYmtXOXlmTkNDUmVnOGtFSnJZc01yZUZMCklnbVhWU3hmcjdCMjVob0ZBaVo2ZzFxY3lP'
    b'QVErTVBRdDh0NlZkMWVIcjlKZGUwNm9IVkRuUlh4M3VUOVlnaXdxczVTcUVWYUp0bkgKYjZs'
    b'dFVzTHJ3QWJXMGR0UTE4YW4xb29VM21Gc1JFOVZRcDNUdTRxMWlNaytBVTRkb09GZWJDTEt1'
    b'ZWU2SDNnTjhLQVlHbGdQU1FpbwpOejhLY01FaUg4Tjl1bEJZRWFlYitrZWUvUG1lSGZEQjM2'
    b'eW5qcEJvRVVjOXBhUDJaKzAvVCtmdGZ6N04rSkxtaDhqcU95OStES09rCmw2ODh2dWJYdzh4'
    b'TjRUY2toR1Q2dzdTRnp0dFFlQ3RpNVhsSFFzMzdOSjdVaHhvU0JyempIMWxTdmVPZlNIaVl0'
    b'UFNCbllIT1ZCSSsKbkdNNUJmODYrVC8zTzBtWXNVWDJkRStiZnhtTmZ1bk9uYktSV1lLaE1j'
    b'STBNMk9hK2pwcmpEUWFqVWFqMFdnMExMNEJrUjNRa3kzRQp2ZWtBQUFBbGRFVllkR1JoZEdV'
    b'NlkzSmxZWFJsQURJd01qTXRNRE10TVRSVU1UQTZOVGc2TlRJck1EQTZNRERsMWRoU0FBQUFK'
    b'WFJGCldIUmtZWFJsT20xdlpHbG1lUUF5TURJekxUQXpMVEUwVkRFd09qVTRPalV5S3pBd09q'
    b'QXdsSWhnN2dBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlOTQ5MCIgLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'JP_43')

JP_43 = b64_JP_43
index.append("JP_43")
index.append("Japan Kumamoto")
catalog["JP_43"] = JP_43
catalog["Japan Kumamoto"] = JP_43
country["Japan Kumamoto"] = ('JP_43', '', 1)
lookup["JP_43"] = ('JP_43', '', 'Japan Kumamoto', 1)
lookup["Japan Kumamoto"] = ('JP_43', '', 'Japan Kumamoto', 1)
details["JP_43"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_43"] = ('JP_43', 'Japan Kumamoto', 1)
regional["Japan Kumamoto"] = ('JP_43', 'Japan Kumamoto', 1)
#----------------------------------------------------------------------
b64_JP_44 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjAxNyIKICAgd2lkdGg9'
    b'IjE0MyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDMgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09pdGFfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMTIwMjEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXcxMjAxOSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMjAyMyI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNDMiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSThBQUFCa0NBTUFBQUNJUHBQZ0FB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNiVkJNVkVYLy8vL3p6OWJPUVZ6Nzd2SDcK'
    b'OFBMT1ExNzk5dmZBQ2kzamxhVGpsS08vQ1N6ODlmZnZ3TW0rQkNqSUxFdi8vdjdKTDAzdndj'
    b'cmdoNWp3eGMzd3hNemdpSm5SVG1mVwpZSGJWWDNiUlQyakRGamZBQ3k3NjZ1MzY3Ty9BREMv'
    b'Q0ZUYisvZjMwMXR6aWo1LysrdnYzNE9YMTFkdmlqcDcxMTl6bW5hdklLa240CjVlbm1ucXpW'
    b'WG5YSUtVakNFalRtbjZ6NTV1clhZM3J1djhqcXI3dlFTbVMvQnl2cnNMenV2c2ZYWkh2TlAx'
    b'ckpMVXZOUDF2NjYrNisKQlNucnNienJzcjNjZUl2SkxrelhaWHZoakp6bnBMSGNlWXpISmti'
    b'aGpaMzQ1T2pISlVYT1FGdjkrZnJBRFREQURDN25vYTcrKy96bQpvSzIvQ3k3d3g4Ky9DQ3Z4'
    b'eU5EZ2lacmZoSmJmZzVYaGlwdklLMG5GSVVEKy9QekpMRW0vQkNqc3RML3JzNzdlZnBIYmRJ'
    b'aS9CaXI0CjR1ZlpiSUhlZjVIVlhYVDkrUG5UVlczRUhEekZIajc4OC9YUFIySHFycnJxcmJu'
    b'NTZlektORkhRU1dQUVNHTDIyK0QyM3VMMjNlSEYKSUVEQ0ZEWGttS2J5emRUREdUckxObFBV'
    b'V0hEbG02bnV2TWJwcTdmWWFINzc3L0w5OS9qMDFkdkNFemJCRHpIdHVzVGVnWlBLTWxESQpL'
    b'MHJNT0ZYamtxSHFyTGpRUzJYWmE0SFRWMi9GSHovRUhUM1phb0R5enRYeXpOUGlrYUh0dU1M'
    b'dnc4ejg4dlROUFZuMTJkN0JFREwxCjJOM2tscVhhYm9QNzhmUFpib1RXWVhmNTZ1M1NVbXY2'
    b'N2ZEYWNZYlBSRi96MHRqTU9WYlJUR2JaYllMNDQrZm9wclBmZ3BUYmNvYnQKdThYc3Q4SHow'
    b'ZGZFR3p2RUdqdnh5ZEhNT2xiMDA5blRWR3pCRGpEcHFiYllaMzNYWTNubm9yRHV2Y2Y1NSt2'
    b'NTZPeS9CU3JzdHNIRApHRG5XWW5uSEowZllabnpqa2FIa21hZjMzK1BsbXFqeHl0SEJFVFBH'
    b'STBQYWNJWDEydDlMT2pSOEFBQUFBV0pMUjBRQWlBVWRTQUFBCkFBZDBTVTFGQitjRkVnSXNL'
    b'UHBsaHNRQUFBUCtTVVJCVkdqZTdabm5XeE5CRU1aUFZORG9FS3dJU0ZFaUtoQkVCYkVsbG9D'
    b'QWhhaW8KSUZnalZyQWdxQ0FsbXFoZ1E3RjNWT3k5OTk3NzMyUjJjN25HSGZtZ04vbXk3eGYy'
    b'OXAwODgzdjI5dTVtRm81alltSmlZbUppWW1KaQpZdEpkSGY3QjFVTkJIZHN4TzNYR3hna082'
    b'ZEtPMjlYUURabW5PNFFhdGQwdzZJSE0weE9nbDZiWkc2QVBNazlmZ0hCTnN4OUFCQzZPCk1S'
    b'SWdxcitHR1IwREVCdUh5ak1BUEJyb3U0bzNEZUlHbWVKOWx3bkVISXpLTTRTa0hFcDJkR0pT'
    b'c3RrQUtWd0tHTXpKdzFLSkdVck0KSkZTZTRTUWxqSWdibVpaT1I0U0hLRDF0bERHRGprYWo4'
    b'cGhwempGamdaZVB4Nk93Y2ZUUFVFeWM4UmFRUzhMRHk5SWZrY2NLZm5sZwpBaUxQUk5sS1RK'
    b'cHN5K1F5YlpNbnlWWXRDNUZubkpoMlNuYU9NSjJUblNzYVUvRndwazMzSloyUlo1YzU5cG16'
    b'ZkZiTU5EU2UyY0lpCjVPY29yRlNENE0xQjQ1a3IzcFY1Q3F0QXRBclJlT2FMU1l1S1pVNXhr'
    b'V2d0d01JcFdDaDVqQmJKck1YU0oyd0pEazZoN0RVVG9TeEQKa0I5NTQxTDVhODloa3BqTDB1'
    b'Vm1pZTVWUi9GdzVYdDR1Y1Jkb2pSWHhPdUxzM0tWTWlPc0ZsUGExN1J4K3dicmlWTmFCbTIx'
    b'VnJEWApxYmhCbmZURFdiOUJKU0dVQy81R05Uc3NVUzhjazFrdEgxZ3FlTC9Tb2VybmJ0SUha'
    b'L0JtMVhTd3BZb1BxTnFpSHJCWmwxcTZlcXN5ClQyeE5iVlpkZmFVa3BtTzFzM0JiV1c2YndO'
    b'azZOS1N5Z2lzbHE2NzNkczFZbDl0WnVFTWF2blBYLzhaWkhNT3ZTRU1qR1lUNi9jRnUKRXJa'
    b'bnIyZTF5RHN5Wk4vL3hjblkzNVJnZGJ2SThBQkpkTkR2TDVwSldLMTN0YXdKVGZzejlIcktE'
    b'dEcreHVYdi9JTStheVVJSDdDQgpkRWNjOWhOMWhFWWRSZUE1QnJKZW1kZHh4VFh0bVdFWEFz'
    b'OEpnMHExYm5VNDVSTW5TWkNoRksyNXNKeVNUcDFLZ2ROdTZjUVoydm9FCm9kUmpaK210T0Nm'
    b'OXpKSysyZHdpbVRsUFk2cFFlTWp4anVQQ1JmRmVHR3RwOWxieEFLL2wwdVY4VDhjVGpWT3dO'
    b'c0dWcXhXMTE0UzYKeDhhL2hiT0YvbXhQbWZ2TWRiaUJWTS9mdkZWNk93cmdqdTlMa3MvenBO'
    b'L2xaODU1dHZMbDdmY1NrWGk0K3c5by9nUnZCOWdzZktZZQozcVF6MmZRaThoRmEveFVjNnMx'
    b'ZjROa3g4WkplSGg2djlPeW1CdTk0ckF1TmgzdkNOL0JQTDNFbHNzcmlCaGZkNmgwOWMyTWVT'
    b'RDNuClM4R3RMeFNsemt1K1NuS3NRejJ2NDg1YW9EMVpxamhrNWVXM2cyTjR4YUhyOVFOTm5O'
    b'VWp1QURvVGFzR3p0TzNYRUIwVjcyL2VmYysKTURpbUR4cnJFMXNaQ0J4WGplYithZXdXQUo2'
    b'UEVvQlBuNzk4L2lTNS9vaVA4MVU0QUtwcDhQYWYzL2FXQ1llWjM3Rnhma1RSdk5Nago2bEts'
    b'cFpFei9LZjNCZFFMRnlmNmx5ZnBoM0JuMndMWlZmK2JuQUlWWWY3N2dvc3JoOXpmOVhZdHQ3'
    b'cWhCcTdZRVhtc3RqOStJdjdZCnJCd1RFeE1URXhNVEV4TVRFMU1nOVJkeHp0b0pMRmgzWlFB'
    b'QUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TlMweE9GUXcKTWpvME5EbzBNQ3N3'
    b'TURvd01LTC9lazBBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNRFV0TVRoVU1E'
    b'STZORFE2TkRBcgpNREE2TUREVG9zTHhBQUFBQUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJp'
    b'bWFnZTEyMDI1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'JP_44')

JP_44 = b64_JP_44
index.append("JP_44")
index.append("Japan Oita")
catalog["JP_44"] = JP_44
catalog["Japan Oita"] = JP_44
country["Japan Oita"] = ('JP_44', '', 1)
lookup["JP_44"] = ('JP_44', '', 'Japan Oita', 1)
lookup["Japan Oita"] = ('JP_44', '', 'Japan Oita', 1)
details["JP_44"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_44"] = ('JP_44', 'Japan Oita', 1)
regional["Japan Oita"] = ('JP_44', 'Japan Oita', 1)
#----------------------------------------------------------------------
b64_JP_45 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDcyNyIKICAgd2lkdGg9'
    b'IjE0MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01peWF6YWtpX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczEwNzMxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFt'
    b'ZWR2aWV3MTA3MjkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9y'
    b'PSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'c2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2Nh'
    b'cGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9k'
    b'ZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTA3MzMi'
    b'PgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTQwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAg'
    b'ICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJl'
    b'bmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdl'
    b'L3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUl3QUFBQmtDQU1BQUFCakNT'
    b'ampBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFD'
    b'QTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFCUjFCTVZFVVZtVGtabXpoOXhpQ0N5'
    b'UjRyCm96U1B6aHovL3dHNDRCSlFzeXY4L2dMdTl3VW9vVFRvOVFka3V5WVdtVG01NFJLdTNC'
    b'V0J5Qi9yOWdZcG9qUkdyaTM1L1FKZnVTY2oKbnpiaDhnaWwyQmVzMnhYbTlBY2xvRFZ6d2lM'
    b'Ky93Rld0U2s4cWkvMit3T2MxQmtjbkRmVTdBemc4UWtnbmphaDFoajkvZ0ZOc1N0aQp1eWFT'
    b'enh3eHBUTHUrQVhaN3dyTDZBNzcvUUtUMEJ1S3pCM1M2d3dhbXpna256WGU4UWsrcXkrcjJo'
    b'YlA2ZzB6cGpKZHVTY1ltamduCm9UWHE5Z1kzcURHeTNSUjN4Q0ZxdmlUQzVSQXRvelB4K1FT'
    b'ODRoRnR2eVIwd2lMeitnUVhtam5GNWc5K3h5QTZxVEQzK3dQTjZRMkgKeXgxQXJDN2w5QWZR'
    b'Nnd5YjB4bEVyUzc2L1FMVzdRdVkwaHBSc3lwTHNTenM5d1lmblRkYnR5aWkxeGhVdFNyTzZn'
    b'MGJtemprOHdlcgoyeFZvdlNYWTdnb2VuVGY0L0FQajh3Z21vRFZKc0N5KzR4SC8vLzk4VThn'
    b'NUFBQUFBV0pMUjBSc3pBRXdPd0FBQUFkMFNVMUZCK2NECkRoTU5OZ1NlZW9RQUFBR2ZTVVJC'
    b'VkdqZTdaalhUa0pSRUVVdm9tTkhRZXdDSWlxZ1NGRkV4WVlLRnF6WU8vYjYvKy8rd242NU8y'
    b'TXkKNnd0V1pwS1RXY2R4RE1Nd0RNTXdETVBRaXFmQkM5SElrR2tTaUdhR1Mwc3I1TkxHR0V4'
    b'N0J6YVlUb0tMcnd0ejZXWXN5WSs1QkhvSQpMc0ZlVEthUDROSS9nTGtNTXBZMGhMa01qeEJj'
    b'UXBoTE9FSndHWTFpTW1NRWw5ZzQ1akl4U1pDSll5NkpKTUZsQ25PUmFZSkxhZ1p6ClNjY0lk'
    b'ME1HYzhrR0NZUEpnVXVhSmJoRUVwakxYRjdORFRoZldOQnprQzR1UWZkb2tlR3lqSzB5czBK'
    b'd1dWMkRYS0xyak1HVXNNRnMKTUZ3Mk1aY3RIOEdsakwzUWxSVGpVTi9HQnJQRFdOS3Vvckly'
    b'N3VrcHUrcStuckp6RGhTVjNlR1Juckx6SE9zcE8rZEVVZG5Wc09ROQpaWlJkL2t4UDJhRWZX'
    b'ZWNNbDR0TFBXVUh4dWhWVW8yTGM1M0dQa2k5Tis2NzNJSnRJWGRsMTEzdUM2QkwrTUg5d1R5'
    b'Q0xwSnozNlVlCkJsMmVudDB2dXhmUXBVTG9xVmQwU1c5cXlrNGtycWJzUk40LzFKU2RmTmJV'
    b'bEoxSVNFM1ppWlQwbEoxOGZhc3BPOG4rcUNrN0ViK2UKc3BQZnFwcXlrd0NoZWNHeWswVGRN'
    b'UXpETUF6RE1BekQrR2Y4QVJFVlVSa3hKVmNzQUFBQUpYUkZXSFJrWVhSbE9tTnlaV0YwWlFB'
    b'eQpNREl6TFRBekxURTBWREU1T2pFek9qVTBLekF3T2pBd1NhbHY5UUFBQUNWMFJWaDBaR0Yw'
    b'WlRwdGIyUnBabmtBTWpBeU15MHdNeTB4Ck5GUXhPVG94TXpvMU5Dc3dNRG93TURqMDEwa0FB'
    b'QUFBU1VWT1JLNUNZSUk9CiIKICAgICAgIGlkPSJpbWFnZTEwNzM1IiAvPgogIDwvZz4KPC9z'
    b'dmc+Cg==', 'JP_45')

JP_45 = b64_JP_45
index.append("JP_45")
index.append("Japan Miyazaki")
catalog["JP_45"] = JP_45
catalog["Japan Miyazaki"] = JP_45
country["Japan Miyazaki"] = ('JP_45', '', 1)
lookup["JP_45"] = ('JP_45', '', 'Japan Miyazaki', 1)
lookup["Japan Miyazaki"] = ('JP_45', '', 'Japan Miyazaki', 1)
details["JP_45"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_45"] = ('JP_45', 'Japan Miyazaki', 1)
regional["Japan Miyazaki"] = ('JP_45', 'Japan Miyazaki', 1)
#----------------------------------------------------------------------
b64_JP_46 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4NzQ3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS2Fnb3NoaW1hX1ByZWZlY3R1cmUuc3ZnLnBuZyIKICAg'
    b'eG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5r'
    b'c2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2Uu'
    b'bmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAg'
    b'ICBpZD0iZGVmczg3NTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXc4NzQ5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0i'
    b'IzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNo'
    b'YWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9'
    b'ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzg3NTMiPgog'
    b'ICAgPGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAg'
    b'ICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRl'
    b'cmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3Bu'
    b'ZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQU1BQUFCVGhUbkNB'
    b'QUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZB'
    b'QUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFDa1ZCTVZFWC8vLy93OFBDNHVMaUVoSVJY'
    b'ClYxYzVPVGthR2hvUER3OEFBQUFRRUJBY0hCeUhoNGZ6OC9QbTV1YUxpNHMrUGo0RUJBUUZC'
    b'UVU5UFQyUGo0L2w1ZVcrdnI1TlRVMEQKQXdNQ0FnSlBUMCs4dkx6QXdNQTJOamEvdjcvazVP'
    b'UlJVVkZVVkZTaG9hR21wcWI0K1BobFpXWDUrZm51N3U0OFBEeEFRRURuNStjcwpMQ3d1TGk3'
    b'cjYrdnQ3ZTB0TFMwdkx5ODdPenY2K3ZwalkyTm1abWJqNCtOVFUxTllXRmk2dXJxOXZiMU1U'
    b'RXppNHVLUmtaRVRFeE5XClZsYVZsWlhMeTh2Mjl2Ykt5c3FVbEpSVlZWVVNFaEx4OGZHY25K'
    b'ejM5L2VibTV2MDlQUzV1YmtPRGc2V2xwYisvdjc5L2YyN3U3dUMKZ29LSWlJaFpXVmxFUkVU'
    b'eTh2TCsvUHp4eU5EbnBiTGlqNS94eWRIMTlmVktTa3BkWFYwMU5UVkpTVW4yM09IWFpuM0NG'
    b'em05QWlmWApaMzMyM2VKSFIwY2ZIeC9zN096OStQbmFjWWEvQ0N6YmM0Z2lJaUloSVNFTEN3'
    b'dk16TXo2Nis3TlFGek1PMWY1NSt0aVltTDg4dlRJCkxrekhLa243OFBKZVhsNElDQWovL3Y3'
    b'UVMyYlJUV2ZoNGVFSEJ3Y01EQXpvcDdUcHE3ZFNVbElSRVJHdXJxNysrdnZHSlVYR0prWCsK'
    b'Ky95cnE2c2dJQ0FHQmdidHVzVHV2Y1phV2xyWWE0SFpib01xS2lwYlcxdktORkhLTmxPR2hv'
    b'WnhjWEhER2p2RUhEMXRiVzEwZEhURApHenpFSFQ1eWNuSkNRa0xLTlZMWmJJTFpiNFRvNk9o'
    b'UVVGRHR1OFh1dnNlcXFxckhKMGFwcWFuQndjSHBxcmJxcmJrWUdCaHVibTUyCmRuWmNYRnpS'
    b'VDJuSUswcTF0Ylg4L1B6TlFWek1QRmplM3Q2c3JLeXdzTERiZElpL0NTM2JkWW45K2ZxdnI2'
    b'OW5aMmYyM3VQWWFIN0QKR0RyREdUcllhWDhrSkNUcTZ1cEJRVUhVMU5UKy9mM3h5dExvcHJQ'
    b'eXk5UFcxdFlCQVFFL1B6OHdNREJzYkd6djcrOW9hR2dwS1NscAphV25EdzhNNk9qcmc0T0I0'
    b'ZUhpa3BLUkR0bDEzQUFBQUFXSkxSMFFBaUFVZFNBQUFBQWQwU1UxRkIrY0ZFeGM1RUVlRDNy'
    b'QUFBQU85ClNVUkJWR2plN1puM1V4TkJGSUJQU0dTRHRJQVlpb2dDQWhFUW9vZ2FCU2wyUkVX'
    b'Q3hDNVJBV1B2Q21KRlJiRTM3QlVMMkJWN3c0WWkKRmtCRTRLOHhtMEt1YkRESnpHNlljYi9m'
    b'N3IwMzg3NjV1K3krdlRBTWhVS2hVQ2dVQ29WQytWL3A1dVFzRW5kM0FVRGlLaGIxY0hMcgpD'
    b'azd1SHA1ZWdJUFUyNmVuZzZWOGU4a0FBai8vQUFkS0JmWUdGaEVIT1VpcVR6RG9sTDRPZVpU'
    b'OUpPQWZ1SVFRbHdvTkExWVExcCtzClZYZ0VzSXJJY0pKVzhnSEFTcUtpeVZuRkRBUldFeHRE'
    b'N0wyS0F6WVFxU0NrTlFqWXhHQkNLd093RVNMclJMekVWaTBKaVhWMUNMQ1oKQlB4V0FjQU9B'
    b'ckZyeGRtakZZZmJhaWl3aTJHWXRZYmJweFdNMTBvcHMwL0xDKytQMFFQWXlRaXNXdDdvcGlN'
    b'VGswWXBrNU9WS2FscApvOUVWbmppdHhpQ2ZZZFRZY2VhUzVQSElmVnc2QWFQV1JFVEQ5RWta'
    b'M0tMSlNlbUlzaWtZdGFZaWpoSkt4QTlETEt6THhLZzFUZEF0ClMyWElaRS9QVWF0elptUWJy'
    b'bWJPRWhUT3hxZzFoOTlzcm1HWW1qYy9WNk1uZDhGQ2ZVQ3hTSEJYTVdxNThucmw1Y05vd1dL'
    b'dHBnUHQKa2dMOXNMK1VWN29NbzlaeWJpdlpDaGhjdVVyRFlmVWFHRTN4NC8weU1Hcngxb2Ux'
    b'TUxadXZZYkhobzB3dm9sYlc0aFJTOHJ0Rks4TApGVzNXQ0NndTBpVzJiT1V1WEJpMXRuRTZw'
    b'Y0hRZGcyQ0hUQ3prMU5jZ2xFcmo5TnBseTZ5ZXc5S3EzU3ZMcldQVTF4R2FvSFlEN2VjCkF4'
    b'b2tCK0UyNUVWcUVqekUyUXBoNURCYTZ3ak1IU1cxbkRxekd4MkRrZU5vclJNd2w4Q3VQb2xS'
    b'eTRuZHFCeEdUcUcxVHNQY0dYYTEKTDBZdEZmdDFPUXNqV3JTV0Z1YksyZXVEQ3VmQUZjSFhP'
    b'b2ZXT2c5ekYxakZGN0ZPcHo3OFpldFNKKzhXKzZEcmcvZWt6M3FLc1RCdwpHYTExQmVaWVk2'
    b'cjBLdDZqVHdWcjc0Rno4RFcwMW5WZHlvMjErL2dUUE92ZmdLdDhLY3JxSmx6bEsxbWxWUVFQ'
    b'KzRudytoWks2emJNCkpCckw3dHk5ZHgvN040Z2cxbE9FMzBXTGlvVldEK0FFRVYxbzNBeklm'
    b'TlVWOFk0TndubnJvWDdleWpRV1BTTDA1MFdKZVNxbzFrK24KajdsV1QvVFRhWFdac2VncG9V'
    b'K256OHkzNjdrK1VQQ0N0ZGEvZlBWYUgzekRIbitJOE5aOEhETkdhdDY5TjBoOStGaGpER1da'
    b'YWo3VgpFdEpTZk83dyttS0sxWDJ0VjZ2cnY5V1pyci8vTUpYOERDVjF1OEliVEQwYkxaVTBk'
    b'dXdGVFF3eGFxTk14eXdMZzRISzlCbWlJWjhoClNGT2tzVzBxT3A5cUdoeUkvaFhGTUtHL0RI'
    b'MmJNMURaakdaRDlyZUNJVTJJWWYwS3NMeHpTaW9aQnlCUGc3MHJMTTRaSW5mR01iVDgKQVVE'
    b'V0tveTN5blFIc0JiR2NWVDV5OXFFMFRaWlJTRGpXT1R0d2xpN25LRlFLQlFLaFVLaFVDaVVy'
    b'c05mbktCZ1k4alYxSVFBQUFBbApkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURVdE1U'
    b'bFVNak02TlRjNk1UWXJNREE2TURBeDVxbHBBQUFBSlhSRldIUmtZWFJsCk9tMXZaR2xtZVFB'
    b'eU1ESXpMVEExTFRFNVZESXpPalUzT2pFMkt6QXdPakF3UUxzUjFRQUFBQUJKUlU1RXJrSmdn'
    b'Zz09CiIKICAgICAgIGlkPSJpbWFnZTg3NTUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'JP_46')

JP_46 = b64_JP_46
index.append("JP_46")
index.append("Japan Kagoshima")
catalog["JP_46"] = JP_46
catalog["Japan Kagoshima"] = JP_46
country["Japan Kagoshima"] = ('JP_46', '', 1)
lookup["JP_46"] = ('JP_46', '', 'Japan Kagoshima', 1)
lookup["Japan Kagoshima"] = ('JP_46', '', 'Japan Kagoshima', 1)
details["JP_46"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_46"] = ('JP_46', 'Japan Kagoshima', 1)
regional["Japan Kagoshima"] = ('JP_46', 'Japan Kagoshima', 1)
#----------------------------------------------------------------------
b64_JP_47 = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjA2MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09raW5hd2FfUHJlZmVjdHVyZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTIwNjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxMjA2NCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMjA2OCI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBTUFBQUJUaFRu'
    b'Q0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUNqbEJNVkVYLy8vLy8vLy85NStmN3Y3'
    b'LzQKbVpuMmVucjFaMmYwWEZ6elVWSDkzZDMwV0Zqd0Z4ZnVBQUR3R0JqMFdWbjRtNXY5M3Q3'
    b'KzcrL3lPenZ1QVFIeE16UDRrSkQrNnVyOQoyOXYxWkdUdUJ3ZnZFUkh2RUJEMVpXWDBXbHJ1'
    b'QXdQeEtpcjFiR3o1cEtUOHpNeis4ZkgrOFBEeEtTbnVCQVQrOS9mM2dZSHZDUW53Ckh4LzJm'
    b'My8yZm43d0hoN3ZDZ3IzaElULytQajd5TWp3SlNYeEppYjVvYUgvKy92NW41Lzd5c3IvL3Y3'
    b'M2pJenVCUVgzaUlqLyt2cisKOWZYNnU3djNpNHYxYW1yMFhWMzFhMnY3dkx6M2hvYnVCZ2J6'
    b'VDAveE1USDZ1TGp6VWxMMFUxUDZ1Ym45MnRyeE1ERCs5dmIrN2UzeQpPVG4wWVdIN3g4ZnhO'
    b'RFR5TmpiN3ljbjBYMS95UER6Kzd1Nzk1ZVh4S3l2MmQzZnVBZ0wyZFhYeExDejk1dWIyZVhu'
    b'MmVIanhMaTcwCllHRC8vUHp6UzB2elRFei8vZjMwWGw3eVBqNzBWRlQvK2ZuMmRIVHhNakw0'
    b'azVQdkRRMzVxcXI2cnE3ODJkbnZEQXo0bUpqOHpjMzQKajQvKzh2THdHUm53SEJ6KzlQVHZD'
    b'QWo4ME5EeExTMzNpb3IzalkzNnJhM3dIUjM5NU9UeEtDajd3c0x2RGc3MWFXbjRrcEwyZkh6'
    b'Kwo2ZW55UTBQelJVWDk2T2oyY25MelJrYjNoNGZ2RHcvNXBxYjd4TVQ1cWFuelNVbndHaHIw'
    b'VlZYMFYxZjZzYkgxYlczNGxwYjFjSEQ5CjM5Lzk0dUx4THkveVFrTDgxOWY2c0xEelNFajZz'
    b'ckw0a1pIdkZSWDk0ZUh2Q3d2NnI2Lzk0K1AzaFlYNXE2djVwNmY2dDdmODB0THkKTlRYODJO'
    b'andJaUwxYm03d0pDVHdJQ0Q0bXByN3hzYjJlM3Y2dExUNnRiWDh6czc4ejgvOTRPRDRuSnp5'
    b'UFQzODA5UDgwZEg3dmIzdwpHeHY5M056MVkyUDd3TUQyZlgzeU9EanlOemYyYzNQM2lZbjZz'
    b'N1B6VFUzelVGRDBWbGJ3SVNIKzdPejRsWlg0bDVmNW5wNzVvS0Q4CjFkWHdJeVA0bEpUODF0'
    b'YjgxTlNyeUdVcUFBQUFBWFJTVGxQdy9Wc3FlZ0FBQUFGaVMwZEVBSWdGSFVnQUFBQUhkRWxO'
    b'UlFmbkJRUU0KRUJHcGYxSjZBQUFGUkVsRVFWUm8zdTJhL1Y4VVJSekhIZTdnT0Z3SXVVZ1JQ'
    b'Y0dNQzR6ajRqbzl1RHMwUkF6SXc0ZVFSL0hwNGtvVQpVZ2dEMUtRVUh3STBFUk5MbE5STXl3'
    b'cWp6SjdVaXNxZW54LyttMnAzZG5kMmIzZFo3bVlXWHIxMmZ2dCs1anZmNy90bWIyWm5abWNh'
    b'Cm1KSmxtbzZsWStsWU9wYU9wV1BwV1A5N3JDaURNVHJHRkJ0cmlvazJHcUttQkpiWkdEZWRF'
    b'cFQ0aExzU0p4ZHJoakhKUWttVnU1UHYKbVRTc21iTlNVSlRacWFpVk1zYzhLVmptdVZZV1lW'
    b'NWErdng3LzlNV3pFOVB1NDlWTTB5Sm1tUFo3cytFMmJNV2lyS2JIOGlHVmZZYwpoN1pZRCti'
    b'Q3pNNkhYS0cxcmtWYzlXSU5zZHg1K2JBN1BGNUc4UlVzV1dwNnVEQnZtWSt4dlVXd001Y251'
    b'N1hDOGhYRHZsZ3hreEVlCktlSCsreW1sWll6MjZFcW9sUHExd1NwZkJST3V0dEgybXJYQ3ll'
    b'R3hDbHIycjROMlpaVVdXTlUxTUYwdC9YamNPWFhpU2F1dWlLbFoKRCszNkRlU3hxdXBoc28x'
    b'TW44Ukp6YVp6bVFlM0NacWJaNURHOGlYQlZGdm9IZ2s4TGpuSlV3MUJ1citlZ09hVE5zSllX'
    b'MkdpdFkyMAp1WTJTS2JWMHRXTTdOQlBJWWpYQk5NM01HSHlLa2kwN2FJZWRMZEJzSlluMU5E'
    b'c1J0Tkhtcm1ma3NkbzdhSmM4YUhidUpvZmwyc09PCkxXWnEzMHNwbEdlWmVaVjlSYTUwRWNO'
    b'aWZ6cTFqemFEWFVwWVdVSGhjMDRtaGZWY004endQSlBSUUNtVy9iUlR3QW5OQXhzSVlYV3oK'
    b'Q1E4eTlrWmxyRU9NVnpKcnA1SEJxdTZFOGZNUE04SVJaYXdYR0srZURHaG5SaEhCNm1YejlV'
    b'R2hTeGtyQzRqbzE1UEFzbkZyNHFOUQpzU3RqdFVDM0hGWTQ1aWVBOVNLWGJ3MVVNcFN4OHFI'
    b'YmNVN3BKNEIxZ2cxdTZZQktxakxXYk9pMmk5c2NOZURIS3VjMkZPMnNWS09NCnRZZjFHK0Q2'
    b'YndGMnJCMWN1aVJXT3FtTTlSTHJ0NHFUVG1ISEd1UmluMkNsZzhwWXAxbS9QazU2R1R0V1BS'
    b'ZDdLeXU5WWxHaXFqdkQKK3BWeTJoQnVMQzgvN0lvNThhd1NWaC9uVnN3UFRoZG1ySE44dmlP'
    b'Y1dLWkFaVmtzUmI4VE05WXdIM29Gcjc2cTRnOFB3QkN2bnNlTQpkWUVQM2N4dlNCT1B5VkZk'
    b'ZkkzZjdGN2k1U2JNV0RsSXltcGVmdDBxVGJWOFArOXpHZEd2WU1hcVJXTHZRM1JqblJTVmRS'
    b'SGk4Z1pTCnNRa3pWaUVTZXhDdGVETXpsQ3IxcWx6VFFzeFlnMGpzWEVITlcyK0xxYmEvSXpo'
    b'SEdVR3FybUhHaWtielZnalBiL3JmUlN0SDN3c0kKcXQ5SEs2OWp4anFLQnU4Vzc0ZysyQUtY'
    b'aE5tcmI0aG56QmkwcFFjejFtazB1RjNpdkxicXc0S0NqeVRPWm5vRS83MVd6RmpDQ1YzdApz'
    b'eEFOWVlvcXdJejFzU0I2cHVyRFduT25vT0ZsekZoQjRjSzlXQzFXZzZEWkpUZG1MSkFrbkFR'
    b'K1VkZktLR3oxS2ZiMTFpRmhBdnROCk5ZMXVpZWJhaGRpeGJvdm16TS9PcU5qd1prdnUvM0Zp'
    b'MlZyRU80aWU4WnIwMUl1YUhHakV2eUZiSjM3SGpIdyt6dUIxaWx0OFFXQ2YKdUN4MFRWV201'
    b'RytJRDJrd1JnQXJtQjI2ZnZsUzlwdU83WHJvU213MFNPSm9wRTFpWWVXOEt1MTdJMWZDK1FL'
    b'UkU1dU9pMUlydnEvTwpCOFNPZ1ZOZlMzbE85eFBCQWtYU0MrU0JiV1BJQ0hNWTdzZ2M5SDVE'
    b'NkRUUU55cTNvYkJYenZFWSsvdU5ubG1Wc3FkTEkzNUNXT2l1CmJPTGxXM0xuOHQrRlR4Vkw4'
    b'SFBCNFlGd3FlS2pDR0tCTVd0NFZOYmJKRCt1QUhBbFBLeTlnQ3dXdUJZT1ZUY2dqUlU4T1hH'
    b'cTd3UEUKc1lEamg0bFN4VFVDOGxqQTNUc3hxclFnMEFJTGdDVVo2cUh5MjhMSkVONnRrWW9m'
    b'MVZKMUhRZmFZWUdmRWxSQldVemxRRXVzZnlmVwptdkdwbkdYaFJnLy9vbFRqejFuS1VLTy9l'
    b'SUgyV0FCNGY5MHNEelgwbXplQzBCSGVEZHpkSy9ueWJyOXpLN0s0a2Qray9MMnBaQVI1CmdW'
    b'di9LUG56cjRpRDRybDM2cmc1bk43cThiU21ELy90d0JKUXY2V3JZK2xZT3BhT3BXUHBXRk1i'
    b'YTJxV2Z3Q3pGVy85ZS9xSWxnQUEKQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VBTWpBeU15MHdO'
    b'UzB3TkZReE1qb3hOam94Tnlzd01Eb3dNT2VSenlVQUFBQWxkRVZZZEdSaApkR1U2Ylc5a2FX'
    b'WjVBREl3TWpNdE1EVXRNRFJVTVRJNk1UWTZNVGNyTURBNk1EQ1d6SGVaQUFBQUFFbEZUa1N1'
    b'UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMjA3MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'JP_47')

JP_47 = b64_JP_47
index.append("JP_47")
index.append("Japan Okinawa")
catalog["JP_47"] = JP_47
catalog["Japan Okinawa"] = JP_47
country["Japan Okinawa"] = ('JP_47', '', 1)
lookup["JP_47"] = ('JP_47', '', 'Japan Okinawa', 1)
lookup["Japan Okinawa"] = ('JP_47', '', 'Japan Okinawa', 1)
details["JP_47"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":""}
regional["JP_47"] = ('JP_47', 'Japan Okinawa', 1)
regional["Japan Okinawa"] = ('JP_47', 'Japan Okinawa', 1)
#----------------------------------------------------------------------
b64_KE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1rZSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHBhdGggaWQ9ImtlLWEiIHN0cm9rZS1t'
    b'aXRlcmxpbWl0PSIxMCIgZD0ibS0yOC42IDQ3LjUgMS44IDEgNDYuNy04MWMyLjctLjYgNC4y'
    b'LTMuMiA1LjctNS44IDEtMS44IDUtOC43IDYuNy0xNy43YTU4IDU4IDAgMCAwLTExLjkgMTQu'
    b'N2MtMS41IDIuNi0zIDUuMi0yLjMgNy45eiIvPgogIDwvZGVmcz4KICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJNMCAwaDY0MHY0ODBIMHoiLz4KICA8cGF0aCBkPSJNMCAwaDY0MHYxNDRIMHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjMDYwIiBkPSJNMCAzMzZoNjQwdjE0NEgweiIvPgogIDxnIGlk'
    b'PSJrZS1iIiB0cmFuc2Zvcm09Im1hdHJpeCgzIDAgMCAzIDMyMCAyNDApIj4KICAgIDx1c2Ug'
    b'eGxpbms6aHJlZj0iI2tlLWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHN0cm9rZT0i'
    b'IzAwMCIvPgogICAgPHVzZSB4bGluazpocmVmPSIja2UtYSIgd2lkdGg9IjEwMCUiIGhlaWdo'
    b'dD0iMTAwJSIgZmlsbD0iI2ZmZiIvPgogIDwvZz4KICA8dXNlIHhsaW5rOmhyZWY9IiNrZS1i'
    b'IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09Im1hdHJpeCgtMSAwIDAg'
    b'MSA2NDAgMCkiLz4KICA8cGF0aCBmaWxsPSIjYjAwIiBkPSJNNjQwLjUgMTY4SDM3N2MtOS0y'
    b'NC0zOS03Mi01Ny03MnMtNDggNDgtNTcgNzJILS4ydjE0NEgyNjNjOSAyNCAzOSA3MiA1NyA3'
    b'MnM0OC00OCA1Ny03MmgyNjMuNVYxNjh6Ii8+CiAgPHBhdGggaWQ9ImtlLWMiIGQ9Ik0zNzcg'
    b'MzEyYzktMjQgMTUtNDggMTUtNzJzLTYtNDgtMTUtNzJjLTkgMjQtMTUgNDgtMTUgNzJzNiA0'
    b'OCAxNSA3MiIvPgogIDx1c2UgeGxpbms6aHJlZj0iI2tlLWMiIHdpZHRoPSIxMDAlIiBoZWln'
    b'aHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAgMCAxIDY0MCAwKSIvPgogIDxnIGZp'
    b'bGw9IiNmZmYiIHRyYW5zZm9ybT0ibWF0cml4KDMgMCAwIDMgMzIwIDI0MCkiPgogICAgPGVs'
    b'bGlwc2Ugcng9IjQiIHJ5PSI2Ii8+CiAgICA8cGF0aCBpZD0ia2UtZCIgZD0iTTEgNS44czQg'
    b'OCA0IDIxLTQgMjEtNCAyMXoiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2tlLWQiIHdpZHRo'
    b'PSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ic2NhbGUoLTEpIi8+CiAgICA8dXNl'
    b'IHhsaW5rOmhyZWY9IiNrZS1kIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zv'
    b'cm09InNjYWxlKC0xIDEpIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNrZS1kIiB3aWR0aD0i'
    b'MTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InNjYWxlKDEgLTEpIi8+CiAgPC9nPgo8'
    b'L3N2Zz4K', 'KE')

KE = b64_KE
index.append("KE")
index.append("KEN")
index.append("Kenya")
catalog["KE"] = KE
catalog["KEN"] = KE
catalog["Kenya"] = KE
country["Kenya"] = ('KE', 'KEN', 0)
lookup["KE"] = ('KE', 'KEN', 'Kenya', 0)
lookup["Nairobi Kenya"] = ('KE', 'KEN', 'Kenya', 0)
lookup["KEN"] = ('KE', 'KEN', 'Kenya', 0)
lookup["Kenya"] = ('KE', 'KEN', 'Kenya', 0)
details["KE"] = {"continent":"Africa","capital":"Nairobi","currency":"Kenyan Shilling","web":".ke","lang":"en-KE | sw-KE","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_KG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWtnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImtnLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1IDBoNjgyLjd2'
    b'NTEySC04NXoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgY2xpcC1wYXRoPSJ1cmwoI2tnLWEpIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSg3'
    b'OS42KSBzY2FsZSguOTM3NSkiPgogICAgPHBhdGggZmlsbD0icmVkIiBkPSJNLTEyOCAwaDc2'
    b'OC44djUxMkgtMTI4eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmMCIgZD0iTTEwNS41IDI2MS4x'
    b'YzEzLjYtMTYuNiA0MS45LS40IDY1LTEyLjMtMjcuNCAxLjUtNDIuMy0xMy4yLTYzLjktMTEu'
    b'MSAyMi40LTEzLjggNDEuNSA0LjUgNjYuNS0yLjgtMzMuMS0yLjgtMzEuNy0xNy43LTYxLjkt'
    b'MTkuOCAyNi44LTExLjQgNDAgMTEuOCA2Ni4zIDYuNS0zMS03LjEtMzUtMjUuMy01OC0yOS4y'
    b'IDMzLjYtNSAzMS40IDE0LjggNjQuMyAxNy4yLTMzLjQtMTQuMy0yNC43LTI2LjgtNTIuNi0z'
    b'Ny43IDMxLjMtLjcgMjkuMiAyMSA2MSAyNi42LTI3LjItMTcuMi0yMy45LTMyLjktNDYuMi00'
    b'NS4yIDI2LjUuNSAyOSAyNy42IDU2LjEgMzYtMjQuMS0xOS4xLTE3LjgtMzUuMy0zOC42LTUy'
    b'LjQgMjYuNCA2LjIgMjIuNSAyOS42IDUwIDQ0LjYtMjAuNC0yMi42LTEyLjYtMzguOC0zMC4z'
    b'LTU3LjMgMjUuNCA4LjEgMTUuNyAzMC40IDQyIDUxLjYtMTUtMjQuOS01LjctNDAuOC0yMC42'
    b'LTYxLjcgMjMuNiAxMi4xIDEyLjIgMzQuOSAzNCA1Ny41LTEwLjMtMjUuNSAwLTQxLjMtMTAu'
    b'NS02My45IDIwLjIgMTUgOC4yIDM5LjMgMjQuNSA2Mi41LTYtMzIgNy44LTM3LjIgMy41LTY1'
    b'LjIgMTUuMyAxOC44LTEuOCAzNy42IDEwIDY1LjMtMS41LTMxLjUgMTUuMy0zOC44IDEyLjQt'
    b'NjQgMTUuMSAyMi42LTguNSA0Mi4zIDEuNCA2Ni41IDIuNS0yOS44IDIyLjEtMzcuNiAyMi40'
    b'LTYwLjggMTIgMjEuMy0xNCAzNi43LTkuOCA2NSA4LjUtMzEuMiAyOS40LTM1IDMyLTU2IDcu'
    b'MSAyNC42LTIxLjQgMzYtMTkuNyA2My40IDguNS0yNy43IDM0LjYtMzEgNDAtNTEuNCAzLjMg'
    b'MjYtMjIuNCAzMC43LTI5LjcgNTkuNSAxMy41LTIzLjUgMzcuMi0yNS40IDQ3LjgtNDQtLjgg'
    b'MjUuOC0yOS44IDI5LjItMzguNyA1My4zIDE2LjctMjAuNSAzNy43LTE3IDU0LjQtMzUuMS0x'
    b'LjggMjMuMy0zMS4zIDIyLTQ3IDQ2LjEgMTguMS0xNi43IDQ1LjQtMTEuNyA1OS4zLTI2LjEt'
    b'LjcgMjAuNi0zNi45IDE5LTU0IDM3LjUgMjEtMTEuNiA0Ny44LTQuOCA2My4yLTE1LjUtMi44'
    b'IDE4LTQxIDEzLjgtNTkuMyAyOCAyNS4yLTcgNDQuNyAzLjcgNjUtNC05LjkgMTcuNS00NC42'
    b'IDYuNC02MyAxNy44IDIyLTMuNyA0NS4yIDkuNiA2NS4xIDUuMy02LjUgMTUuMi00NC42LTEt'
    b'NjUgOC41IDI0LjQtLjIgNDAuMyAxNS41IDYzIDE0LjQtMTIuMyAxMy44LTQ1LjctNS4xLTY1'
    b'LjItMS45IDIzLjggNSA0MiAyNC42IDYwIDI1LjYtMTQuOSAxMS4zLTQyLjUtMTQuNS02NS0x'
    b'MS4zIDIzLjIgNi4yIDQyLjYgMzIuNSA1NS44IDMzLjEtMTQuMyA5LjgtNDIuNS0yMi41LTYx'
    b'LjgtMjEuMyAyMy41IDEwLjYgMzQuMiAzNy41IDQ5LjcgNDEuMy0xOS4xIDYuMS0zNy45LTI5'
    b'LjItNTguNC0zMC41IDIzLjggMTUgMjUuMSAzOCA0My40IDQ4LjItMTkuMyA0LjctMzMtMzUu'
    b'Mi01My4zLTM4LjYgMTkuNSAxNC4zIDIyLjUgNDUgMzUuNCA1NC42LTE5LjYgMS0yNi43LTQw'
    b'LjctNDYuOC00Ni43IDE3LjIgMTQuNCAxMy4xIDQ1LjYgMjYuNSA1OS0yMC40LTQuMy0xNy44'
    b'LTQwLjYtMzkuMS01Mi45IDE1LjMgMTkuNCA3LjUgNDYuOSAxNy41IDYyLjQtMTkuOS04LTEx'
    b'LjMtNDAuNi0zMC4yLTU5IDEwLjMgMjAuNi0uOCA0NC42IDcuNCA2NC41LTE4LjItOC45LTYt'
    b'NDcuNC0xOS45LTYyLjcgNi40IDIzLjgtNS40IDQzLjUtLjYgNjQuOC0xOC42LTIxLjUgMi44'
    b'LTQzLjItMTMuMy02NS4xIDQuMiAyNS4xLTEzLjQgNDIuNy0xMC42IDYzLjctMTQuNy0xNy4y'
    b'IDgtNDQuNy0zLjUtNjYuNCAyLjQgMjQuNy0yMC4zIDQ2LjQtMTguNyA2Mi0xMi0yMCAxMy4z'
    b'LTQzLjYgNi41LTY2LjMtMS40IDIzLjYtMjQuNCAzNi40LTI4LjcgNTcuOS03LjctMjMuNyAx'
    b'OS42LTQwLjggMTcuMi02NC4xLTcuOCAyMi4xLTMwIDMxLTM3LjggNTIuNS02LjQtMjMuNyAy'
    b'Ni0zNi4yIDI2LjgtNjEtMTAgMjMuMi0zNi41IDI4LjQtNDUuMyA0Ni4yLTMuMy0yMy41IDMz'
    b'LjgtMzQgMzUuMi01Ni4zLTEyIDIxLjQtNDEgMjIuMy01MSAzOS4zLTEuNS0yMy40IDM3LjYt'
    b'MjYuMyA0My43LTUwLjgtMTEuOSAxOC4yLTQzLjcgMTUuOS01NyAzMC43IDIuMS0yMS43IDQ0'
    b'LjQtMjMgNTEuMi00Mi42LTE1LjggMTUuMi00NSA5LTYxLjUgMjEgOS4yLTIxLjQgNDguOS0x'
    b'Ni45IDU3LjgtMzIuMy0xNy41IDkuMS00OC42LjItNjQgOS40IDE0LTIwLjIgNDQuOC04LjEg'
    b'NjIuMy0yMi0yOC40IDQuMS00NS41LTcuMi02NS4yLTJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmYwIiBkPSJNMzU2IDI1Ni4xYTk5LjIgOTkuMiAwIDEgMS0xOTguNSAwIDk5LjIgOTkuMiAw'
    b'IDAgMSAxOTguNCAweiIvPgogICAgPHBhdGggZmlsbD0icmVkIiBkPSJNMzQzLjIgMjU2LjNh'
    b'ODYuMyA4Ni4zIDAgMSAxLTE3Mi42IDAgODYuMyA4Ni4zIDAgMCAxIDE3Mi42IDB6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmYwIiBkPSJNMzMxLjIgMjU2LjVhNzQgNzQgMCAxIDEtMTQ4LjIg'
    b'MCA3NCA3NCAwIDAgMSAxNDguMiAweiIvPgogICAgPHBhdGggZmlsbD0icmVkIiBkPSJNMTk0'
    b'IDIwOGMyMC41LS41IDQ2IDEuNCA2Mi45IDE0LjhhOTcuMSA5Ny4xIDAgMCAxIDYwLjUtMTQu'
    b'M2wxMSAyMC4xYTEwMSAxMDEgMCAwIDAtNTAgOC4yIDg1LjMgODUuMyAwIDAgMSAzNC42IDcy'
    b'LjFjLTIuNyAzLjQtNyA3LjEtOS43IDEwLjUgNC0yOC41LTExLTYwLjMtMzIuOS03NyAxNy44'
    b'IDI1LjYgMjguMyA0OC42IDI1LjQgODAuNGwtMTAgNi40YzQuNi0yOC0yLTYxLTIyLjctODAg'
    b'MTIgMTcuNSAyMy44IDQ5IDE2LjQgODEtMy4yIDEtOC4yIDMuNy0xMS40IDQuNmE5NiA5NiAw'
    b'IDAgMC0xMC44LTc4LjdjLTEzLjggMTkuOC0xOC4zIDUwLTEwLjUgNzgtMy44LTEtNi43LTIu'
    b'Mi0xMC42LTMuMS01LjctMzAgMi4yLTY0IDE1LjktODEuNy0xNCA4LjEtMjcuMSA0Mi43LTIz'
    b'LjQgNzhsLTkuMy00LjNjLTQuNS0yNi4zIDcuNC02MC42IDI0LjUtODAuNC0xOS40IDEyLjIt'
    b'MzUuMiA0Mi4zLTMyLjUgNzQuNi0zLTIuNi01LjctMy45LTguNy02LjYtMy40LTI4LjIgMTMt'
    b'NTYuNiAzMi4xLTczLjYtMTYuMS03LjMtMzAtOC43LTUwLTguNCAzLjEtNi41IDYtMTQuMSA5'
    b'LjItMjAuN3oiLz4KICA8L2c+Cjwvc3ZnPgo=', 'KG')

KG = b64_KG
index.append("KG")
index.append("KGZ")
index.append("Kyrgyzstan")
catalog["KG"] = KG
catalog["KGZ"] = KG
catalog["Kyrgyzstan"] = KG
country["Kyrgyzstan"] = ('KG', 'KGZ', 0)
lookup["KG"] = ('KG', 'KGZ', 'Kyrgyzstan', 0)
lookup["Bishkek Kyrgyzstan"] = ('KG', 'KGZ', 'Kyrgyzstan', 0)
lookup["KGZ"] = ('KG', 'KGZ', 'Kyrgyzstan', 0)
lookup["Kyrgyzstan"] = ('KG', 'KGZ', 'Kyrgyzstan', 0)
details["KG"] = {"continent":"Asia","capital":"Bishkek","currency":"Som","web":".kg","lang":"ky | uz | ru","tz":"+06:00","altname":""}
#----------------------------------------------------------------------
b64_KH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1raCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMzJlYTEiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNlMDAwMjUiIGQ9Ik0wIDEyMGg2NDB2MjQwSDB6Ii8+'
    b'CiAgPGcgZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjIg'
    b'MCAwIDEuMiA4NS42IC01MjIpIj4KICAgIDxnIHN0cm9rZS1saW5lam9pbj0iYmV2ZWwiPgog'
    b'ICAgICA8cGF0aCBkPSJNMTM5IDYyMy41aDExMy44djQzLjhIMTM5eiIvPgogICAgICA8cGF0'
    b'aCBkPSJNMjQ3IDY0Ny42aDMuNXYxNi41SDI0N3ptLTEwOC04LjFoMTEzLjh2NUgxMzl6bTAt'
    b'N2gxMTMuOHY0LjZIMTM5eiIvPgogICAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii45IiBkPSJN'
    b'MTM5IDYyNS43aDExMy44djQuM0gxMzl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xNjkgNjQ3LjZo'
    b'My42djE2LjVIMTY5em00OSAwaDMuNnYxNi41SDIxOHptLTc4IDBoMy41djE2LjVIMTQwem03'
    b'IDBoMy41djE2LjVIMTQ3em03LjUgMGgzLjV2MTYuNWgtMy41em03LjUgMGgzLjV2MTYuNUgx'
    b'NjJ6bTYyLjggMGgzLjZ2MTYuNWgtMy42em03LjUgMGgzLjZ2MTYuNWgtMy42em03LjUgMGgz'
    b'LjZ2MTYuNWgtMy42eiIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWpvaW49Im1pdGVyIiBk'
    b'PSJNOTQuNSA2NjkuNWE5LjMgOS4zIDAgMCAwIDQuNC01LjNIMjkyYTkuMyA5LjMgMCAwIDAg'
    b'NC40IDUuM3oiLz4KICAgIDwvZz4KICAgIDxwYXRoIGQ9Ik0xOTMgNTU2LjhzLS4xLTQuMSAy'
    b'LjMtNC4yYzIuMyAwIDIuMiA0LjIgMi4yIDQuMnptLTEyLjUgNTQuNXYtNS41YzAtMi44LTIu'
    b'OC0zLTIuOC01IDAgMC0uNC0zIC40LTQuNCAxLjEgNCAzIDMuMyAzIDEuNiAwLTEuNC0xLTIu'
    b'OC0zLjMtNi4zLS44LTEuMS0uMy00LjYuNy01LjkuNCAzIC45IDQuNSAyLjIgNC41LjggMCAx'
    b'LjQtLjUgMS40LTIgMC0yLTEuMy0zLTItNC44YTUgNSAwIDAgMSAxLjEtNS4zYy41IDMgLjQg'
    b'NC4yIDEuNyA0LjIgMi43LS45IDAtNC44LS42LTUuOC0uNi0xLjEgMS0zLjQgMS0zLjQuOCAy'
    b'LjcgMSAyLjkgMiAyLjYgMS4yLS4zIDEtMi0uNC0zLjQtLjktMS0uOC0yLjMuMi0zLjMgMSAx'
    b'LjkgMi4yIDEuOCAyLjMuNmwtLjgtNC40SDIwNGwtLjkgNC4zYy0uMiAxLjIgMS40IDEuNSAy'
    b'LjQtLjUgMSAxIDEuMSAyLjQuMiAzLjMtMS40IDEuNC0xLjYgMy4xLS40IDMuNCAxIC4zIDEu'
    b'MiAwIDItMi42IDAgMCAxLjUgMS41IDEgMy40LS42IDEtMy4zIDUtLjYgNS44IDEuMyAwIDEu'
    b'Mi0xLjIgMS43LTQuMmE1IDUgMCAwIDEgMSA1LjNjLS42IDEuOC0yIDIuOC0yIDQuOCAwIDEu'
    b'NS43IDIgMS41IDIgMS4zIDAgMS44LTEuNCAyLjItNC41IDEgMS4zIDEuNSA0LjguNyA2LTIu'
    b'MyAzLjQtMy40IDQuOC0zLjQgNi4yIDAgMS43IDIgMi40IDMtMS42LjkgMS40LjUgNC40LjUg'
    b'NC40IDAgMi0yLjcgMi4yLTIuOCA1djUuNXptNy4yLTQ2LS40LTMuMWgxNS45bC0uNCAzLjF6'
    b'bTEtMy4yLS4yLTIuNUgyMDJsLS4zIDIuNXptMi4zLTIuNi0uMy0yLjZoOWwtLjEgMi42em0z'
    b'MyAxMTBjLTItLjctNS0yLjktNS01di0yNC4zbDIuNi0zLjRIMTY5bDIuNSAzLjR2MjQuM2Mw'
    b'IDIuMS0yIDQuMy00IDV6Ii8+CiAgICA8cGF0aCBzdHJva2UtbGluZWpvaW49ImJldmVsIiBk'
    b'PSJNMTc4LjIgNjQ3LjZoMy42djE2LjVoLTMuNnptMzAuNCAwaDMuNnYxNi41aC0zLjZ6Ii8+'
    b'CiAgICA8cGF0aCBkPSJNMTY4IDYwOS4ydjI3LjZoNTR2LTI3LjZhNC4yIDQuMiAwIDAgMC0y'
    b'LjYgMi44djExLjhoLTQ4LjdWNjEycy0uNi0yLTIuOC0yLjh6Ii8+CiAgICA8cGF0aCBkPSJN'
    b'MjE0LjYgNjY5LjVjLTEuOC0uNy01LjYtMi45LTUuNi01di0yNy4yYy40LTEuNSAyLjQtMi40'
    b'IDMuNy0zLjRIMTc3YzEuNyAxIDMuNiAxLjcgNC4zIDMuNHYyNy4yYzAgMi4xLTMgNC4zLTQu'
    b'OCA1eiIvPgogICAgPHBhdGggZD0iTTIxOS40IDYzNC4ydi0xOS42aC00Ljl2LTEuOWgtMzgu'
    b'OHYyaC01djE5LjV6TTIwNyA2NjkuNWMtMS44LS43LTQuMy0yLjktNC4zLTV2LTIzLjJsMS40'
    b'LTIuMWgtMTcuN2wxLjUgMnYyMy4zYzAgMi4xLTIuNiA0LjMtNC4zIDV6Ii8+CiAgICA8cGF0'
    b'aCBkPSJNMTkwLjcgNjM5LjJoOXYzMC4zaC05eiIvPgogICAgPHBhdGggc3Ryb2tlLWxpbmVq'
    b'b2luPSJiZXZlbCIgZD0iTTIwNC40IDYzMi41YzAtMiA1LjgtMi4xIDguOC0zLjhoLTM2YzMg'
    b'MS43IDguNyAxLjggOC43IDMuOGwxLjIgMy45IDE1IC42eiIvPgogICAgPHBhdGggZD0iTTIx'
    b'MS40IDYxMS4zYzAtNC45LjItNi43IDEuNy02LjdWNjIwYy0zLjcgMS40LTYuMyA2LTYuMyA2'
    b'aC0yMy4ycy0yLjYtNC42LTYuMy02di0xNS41YzEuOCAwIDEuOCAyIDEuOCA2Ljd6bTEuNy0y'
    b'YzAtNS42IDQuOS02LjIgNC45LTYuMnY1Yy0xLjktLjEtMi44IDEuNi0yLjggNCAwIDIuNSAx'
    b'LjUgMi41IDEuNSAyLjV2MTQuMmgtMy42eiIvPgogICAgPHBhdGggZD0iTTE3Ny4zIDYwOS4z'
    b'YzAtNS42LTQuOS02LjItNC45LTYuMnY1YzEuOS0uMSAyLjggMS42IDIuOCA0IDAgMi41LTEu'
    b'NSAyLjUtMS41IDIuNXYxNC4yaDMuNnoiLz4KICAgIDxnIGZpbGw9Im5vbmUiIHN0cm9rZS13'
    b'aWR0aD0iLjgiPgogICAgICA8cGF0aCBkPSJNMTg2LjggNTcwLjZIMjA0bS0xOS4yIDUuNGgy'
    b'MW0tMjMgNi41aDI0LjltLTI3IDcuOWgyOS41bS0zMC4yIDloMzAuNCIvPgogICAgICA8cGF0'
    b'aCBzdHJva2Utd2lkdGg9IjEiIGQ9Ik0xNzAuOCA2MjloNDguNm0tMzMuMiAwaDE4djYuNmgt'
    b'MTh6Ii8+CiAgICA8L2c+CiAgICA8cGF0aCBkPSJNMTg0IDYxNC4yYzMgMy42IDIuNiA5Ljcg'
    b'Mi42IDEzLjNIMjA0YzAtMy42LS40LTkuNyAyLjYtMTMuM3ptOS43LTQxLTIuNC0xLjN2LTMu'
    b'NWMxIC4zIDIgLjQgMi4yIDIgLjMtMi4zIDEtMi4xIDEuOS0zIDEgLjkgMS41LjcgMS45IDMg'
    b'MC0xLjYgMS4yLTEuNyAyLjEtMnYzLjVsLTIuMyAxLjJ6Ii8+CiAgICA8cGF0aCBkPSJtMTkz'
    b'LjUgNTc4LjktNC0yLjhWNTczYzEuNS4zIDMgLjUgMy4yIDIuMi40LTIuNSAxLjMtMy43IDIu'
    b'Ny00LjcgMS4zIDEgMi4yIDIuMiAyLjcgNC43LjEtMS43IDEuNy0xLjkgMy0yLjJ2My4ybC0z'
    b'LjkgMi43eiIvPgogICAgPHBhdGggZD0ibTE5My4yIDU4Ny44LTQuNS00di00LjdjMS42LjQg'
    b'My40LjYgMy42IDMuMS41LTMuNSAxLjUtNS40IDMtNi44IDEuNiAxLjQgMi42IDMuMyAzLjIg'
    b'Ni44LjItMi41IDItMi43IDMuNi0zLjF2NC43bC00LjYgNHptOC40IDUuMy00IDUuN2gtNC43'
    b'bC00LjEtNS43em0tMTUuMiA5LjVjMiAxLjEgMi44IDMuNCAzIDcuNkgyMDFjLjItNC4yIDEt'
    b'Ni41IDMtNy42eiIvPgogICAgPHBhdGggc3Ryb2tlLWxpbmVqb2luPSJiZXZlbCIgZD0iTTIw'
    b'NC4yIDU5M3YtNS42YTUuMiA1LjIgMCAwIDAtMy44IDMuM2MwLTItMi41LTYuMy01LjItOC41'
    b'LTIuNyAyLjQtNS4zIDYuNC01LjIgOC40LS41LTEuNS0xLjgtMi43LTMuOC0zLjJ2NS43eiIv'
    b'PgogICAgPHBhdGggc3Ryb2tlLWxpbmVqb2luPSJiZXZlbCIgZD0iTTIwNSA2MDIuNlY1OTdj'
    b'LTIuMS42LTMuNSAxLjctNC4xIDMuMyAwLTItMi43LTYuMy01LjctOC41LTMgMi41LTUuOCA2'
    b'LjQtNS43IDguNS0uNS0xLjUtMi0yLjctNC4xLTMuM3Y1Ljd6Ii8+CiAgICA8cGF0aCBzdHJv'
    b'a2UtbGluZWpvaW49ImJldmVsIiBkPSJNMjA3LjQgNjE0LjN2LTYuNmE5LjYgOS42IDAgMCAw'
    b'LTUuMSAzLjhjMC0zLjUtNC05LTcuMS0xMC43LTMuMiAxLjgtNy4xIDcuNC03LjEgMTAuN2E5'
    b'LjcgOS43IDAgMCAwLTUuMi0zLjh2Ni42eiIvPgogICAgPHBhdGggc3Ryb2tlLWxpbmVqb2lu'
    b'PSJiZXZlbCIgZD0iTTIwNiA2Mjl2LTYuOGMtMi40LjktMyAzLjEtMy44IDQuNy4zLTYuOS0z'
    b'LjgtMTQuMi03LTE2LjEtMy4yIDEuOS03LjQgOS40LTcgMTYtLjgtMS40LTEuNS0zLjctMy44'
    b'LTQuNnY2Ljd6Ii8+CiAgICA8cGF0aCBkPSJNMjA0LjQgNjM5LjJ2LTYuOGMtMi41LjYtMi42'
    b'IDEuNS0zLjQgMyAuMy00LjEtMi42LTguOC01LjgtMTAuNi0zLjIgMS44LTYgNi41LTUuOCAx'
    b'MC42LS44LTEuNS0uOS0yLjQtMy40LTN2Ni44eiIvPgogICAgPGcgaWQ9ImtoLWEiPgogICAg'
    b'ICA8cGF0aCBkPSJNOTkgNjY0LjJ2LTIwLjRjLS43LTIuNi0zLTUtNC42LTUuNHYtMThsMy43'
    b'IDIgNC4zIDE4Ljl2MjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik05OSA2NjQuM3YtMjAuNWMtLjct'
    b'Mi42LTMtNS00LjYtNS40di0xOS4yYzIuNSAwIDMuNyAzLjIgMy43IDMuMmw0LjMgMTguOXYy'
    b'Mi45eiIvPgogICAgICA8cGF0aCBkPSJNOTYuMyA2NjkuNWMxLjctLjcgNC4yLTIuOSA0LjIt'
    b'NXYtMjUuNmwtMS4yLTJIMTQzbC0xLjcgMnYyNS42YTYgNiAwIDAgMCAzLjQgNXoiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTEzNS44IDY2OS41Yy0xLjctLjctNC4yLTIuOS00LjItNXYtMjQuM2wz'
    b'LjYtMy40aC0yOS42bDMuNiAzLjR2MjQuM2MwIDIuMS0yLjUgNC4zLTQuMiA1eiIvPgogICAg'
    b'ICA8cGF0aCBkPSJNMTMxLjcgNjY5LjVjLTEuNy0uNy00LjMtMi45LTQuMy01di0yMmwyLjQt'
    b'My4zSDExMWwyLjQgMy4zdjIyYzAgMi4xLTIuNSA0LjMtNC4zIDV6Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0xMTYgNjM5LjJoOC45djMwLjRoLTl6Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5l'
    b'am9pbj0iYmV2ZWwiIGQ9Ik0xMDMuNyA2NDcuNmgzLjZ2MTYuNWgtMy42em0zMC44IDBoMy41'
    b'djE2LjVoLTMuNnptLTMzLjktMjcuOGg0LjR2MTdoLTQuNHptMC0zLjJoNC4zdjMuMmgtNC4z'
    b'em0zNS42IDYuOWg2LjF2MTNoLTYuMXoiLz4KICAgICAgPHBhdGggZD0iTTEwNC45IDYzNi42'
    b'di0yOWMxLjIgMCAxLjQgNC4zIDQuMiA0LjMgMS41IDAgMS40LTEuOC41LTMuMi0uNy0xLjMt'
    b'MS42LTMtLjQtNi4zLjkgMi41IDMuMSAzLjMgMi43IDEuOC0uNy0yLjctMi44LTMuMi0xLjIt'
    b'Ny4zLjUgMy40IDIuNyAzLjMgMi4yIDEuMy0uNi0yLjMtMS45LTMuMy0uMy02LjUuOSAzLjcg'
    b'MiAzLjUgMiAxLjIgMC0zLjQgMC03IDQuMi04LjMgMCAwIC4zLTMgMS45LTMgMS41IDAgMS44'
    b'IDMgMS44IDMgNC4zIDEuMyA0LjIgNSA0LjIgOC4zIDAgMi4zIDEuMSAyLjUgMi0xLjIgMS42'
    b'IDMuMi4zIDQuMi0uMyA2LjUtLjUgMiAxLjcgMi4xIDIuMi0xLjMgMS42IDQuMS0uNSA0LjYt'
    b'MS4yIDcuMy0uNCAxLjUgMS44LjcgMi43LTEuOCAxLjIgMy4zLjMgNS0uNCA2LjMtLjggMS40'
    b'LTEgMy4yLjUgMy4yIDIuOCAwIDMtNC4yIDQuMi00LjJ2MjguOXpNOTggNjE0Ljd2MjIuMWgy'
    b'LjV2LTIyLjFjLS45LS41LTEuNy0uNS0yLjUgMHoiLz4KICAgICAgPHBhdGggZD0iTTk4LjIg'
    b'NjI5YzMuMSAxLjYgNi4yIDMuNSA3IDcuOGgtN3ptNDMuMi02LjZ2MTQuNGgydi0xNC40Yy0u'
    b'Ni0uMy0xLjUtLjQtMiAweiIvPgogICAgICA8cGF0aCBkPSJNMTQzLjQgNjI5Yy0zLjEgMS41'
    b'LTYuMiAzLjMtNyA3LjdoN3ptLTIwLjYtMzMuNyAxLjgtMS41di0yYy0uNiAwLTEgLjMtMS41'
    b'IDFhNSA1IDAgMCAwLTIuNS0zIDUgNSAwIDAgMC0yLjYgMi45Yy0uNS0uNy0uOC0uOC0xLjUt'
    b'MXYybDEuOCAxLjZ6Ii8+CiAgICAgIDxwYXRoIGQ9Im0xMjMuOCA2MDAuMi44LTEuOXYtMi41'
    b'Yy0uNiAwLTEgLjMtMS41IDFhNSA1IDAgMCAwLTIuNS0zIDUgNSAwIDAgMC0yLjYgMi45Yy0u'
    b'NS0uNy0uOC0uOC0xLjUtLjl2Mi41bC44IDEuOXoiLz4KICAgICAgPHBhdGggZD0ibTEyNCA2'
    b'MDYuOCAyLjYtMy4zdi0zLjJjLTEgMC0xLjUuNS0yLjIgMS42LS43LTIuMy0yLTIuNy0zLjgt'
    b'My44LTEuOSAxLTMuMiAxLjUtMy44IDMuNy0uOC0xLjEtMS4zLTEuNC0yLjMtMS41djMuMmwy'
    b'LjcgMy4zeiIvPgogICAgICA8cGF0aCBkPSJNMTI0LjcgNjEzLjNzMy4yLTIuNyAzLjMtNC4y'
    b'di0zLjVjLTEuMi4xLTIuMy40LTMuMiAxLjktLjgtMi45LTItMy43LTQuMi01LTIuMyAxLjMt'
    b'My41IDIuMS00LjIgNS0xLTEuNS0yLTEuOC0zLjMtMnYzLjZhMTUgMTUgMCAwIDAgMy4zIDQu'
    b'MnoiLz4KICAgICAgPHBhdGggZD0iTTEyNiA2MjUuM3M0LjQtNC43IDQuNS02LjZ2LTUuNGMt'
    b'MS42LjItMy4yIDEuMy00LjQgMy42LTEtNC41LTIuNi03LjYtNS41LTkuOC0zIDIuMi00LjYg'
    b'NS4zLTUuNiA5LjgtMS4yLTIuMy0yLjctMy40LTQuMy0zLjZ2NS40Yy4zIDEuOSA0LjQgNi42'
    b'IDQuNCA2LjZ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xMjYgNjMyLjRzMy43LTMuNyA0LjUtNS4z'
    b'di01LjRjLTEuNi4yLTMuMiAxLjMtNC40IDMuNWExNCAxNCAwIDAgMC01LjUtOS4yYy0zIDIu'
    b'Mi00LjYgNC43LTUuNiA5LjItMS4yLTIuMi0yLjctMy4zLTQuMy0zLjV2NS40YzEgMS42IDQu'
    b'NCA1LjMgNC40IDUuM3oiLz4KICAgICAgPHBhdGggZD0iTTEyNy41IDYzNi42Yy0xLTQuNy0y'
    b'LTguMi03LjEtMTEuNy01LjIgMy41LTYuMSA3LTcuMiAxMS43eiIvPgogICAgICA8cGF0aCBk'
    b'PSJNMTMwLjIgNjM5LjJ2LTYuOGMtMi40IDEtNC41IDIuMy01LjMgMy44LS44LTMuOC0yLjUt'
    b'NS40LTQuNi03LjctMi4xIDIuMy0zLjUgNC00LjQgNy43LS44LTEuNS0yLjktMi45LTUuMi0z'
    b'Ljh2Ni44eiIvPgogICAgPC9nPgogICAgPHVzZSB4bGluazpocmVmPSIja2gtYSIgd2lkdGg9'
    b'IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEgMzkwLjcg'
    b'MCkiLz4KICAgIDxwYXRoIGQ9Ik03Mi43IDY5NC4zSDMxOHYxMi41SDcyLjd6bS02LjUgMTIu'
    b'NWgyNTguM3YxMi41SDY2LjJ6bTE5LjQtMzEuM0gzMDV2OC4xSDg1LjZ6Ii8+CiAgICA8cGF0'
    b'aCBkPSJNNzkuMiA2ODMuNmgyMzIuNHYxMC42SDc5LjJ6bTEwLjItMTQuM2gyMTJ2Ni4yaC0y'
    b'MTJ6Ii8+CiAgICA8cGF0aCBkPSJNMTEyLjQgNjY5LjNoMTZ2NTBoLTE2eiIvPgogICAgPHBh'
    b'dGggZD0iTTExNiA2NjkuM2g4Ljl2NTBoLTl6bTcxIDBoMTZ2NTBoLTE2eiIvPgogICAgPHBh'
    b'dGggZD0iTTE5MC43IDY2OS4zaDl2NTBoLTl6bTcxLjUgMGgxNnY1MGgtMTZ6Ii8+CiAgICA8'
    b'cGF0aCBkPSJNMjY1LjcgNjY5LjNoOXY1MGgtOXoiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUi'
    b'IGQ9Ik05OSA2NjQuMmgxOTNNMTE1LjggNzEzaDkuMm0tOS4yLTYuM2g5LjJtLTkuMi02LjJo'
    b'OS4ybS05LjItNi4zaDkuMm0tOS4yLTYuMmg5LjJtLTkuMi02LjNoOS4ybS05LjItNi4yaDku'
    b'Mm02NS44IDM3LjVoOC42bS04LjYtNi4zaDguNm0tOC42LTYuMmg4LjZtLTguNi02LjNoOC42'
    b'bS04LjYtNi4yaDguNm0tOC42LTYuM2g4LjZtLTguNi02LjJoOC42bTY2LjIgMzcuNWg5LjJt'
    b'LTkuMi02LjNoOS4ybS05LjItNi4yaDkuMm0tOS4yLTYuM2g5LjJtLTkuMi02LjJoOS4ybS05'
    b'LjItNi4zaDkuMm0tOS4yLTYuMmg5LjIiLz4KICA8L2c+Cjwvc3ZnPgo=', 'KH')

KH = b64_KH
index.append("KH")
index.append("KHM")
index.append("Cambodia")
catalog["KH"] = KH
catalog["KHM"] = KH
catalog["Cambodia"] = KH
country["Cambodia"] = ('KH', 'KHM', 0)
lookup["KH"] = ('KH', 'KHM', 'Cambodia', 0)
lookup["Phnom Penh Cambodia"] = ('KH', 'KHM', 'Cambodia', 0)
lookup["KHM"] = ('KH', 'KHM', 'Cambodia', 0)
lookup["Cambodia"] = ('KH', 'KHM', 'Cambodia', 0)
details["KH"] = {"continent":"Asia","capital":"Phnom Penh","currency":"Riel","web":".kh","lang":"km | fr | en","tz":"+07:00","altname":""}
#----------------------------------------------------------------------
b64_KI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWtpIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImtpLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg2LjMgMGg2ODIu'
    b'NnY1MTJILTg2LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBjbGlwLXBh'
    b'dGg9InVybCgja2ktYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDgxKSBzY2FsZSguOTM3NSki'
    b'PgogICAgPHBhdGggZmlsbD0iI2U3M2UyZCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNLTE2'
    b'NC4zIDBoODM1Ljh2MzA2LjVoLTgzNS44eiIvPgogICAgPHBhdGggZmlsbD0iI2ZlYzc0YSIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNkOGFhM2YiIHN0cm9rZS13aWR0aD0iMS43'
    b'IiBkPSJNMjA0LjMgMjgyLjFjLTE5LjQtMTUuMi01NS42LTEwLTYxLjYtNTEuMyAyNy43IDIx'
    b'LjUgMjIuNy0xLjIgNjQgMTkuM2wtMi40IDMyeiIvPgogICAgPHBhdGggZmlsbD0iI2ZlYzc0'
    b'YSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNkOGFhM2YiIHN0cm9rZS13aWR0aD0i'
    b'MS43IiBkPSJNMjA5LjUgMjYzLjRjLTEzLjktMjAuNC01MC0yNi42LTQzLTY3LjcgMTkuOSAy'
    b'OC45IDIyIDUuNyA1NS4yIDM3LjlsLTEyLjIgMjkuOHoiLz4KICAgIDxwYXRoIGZpbGw9IiNm'
    b'ZWM3NGEiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjZDhhYTNmIiBzdHJva2Utd2lk'
    b'dGg9IjEuNyIgZD0iTTIxNS44IDI1MGMtNS0yNC4xLTM2LTQzLjYtMTMuOC03OSA3LjIgMzQu'
    b'NCAxOCAxMy44IDM2LjQgNTYuMkwyMTUuOCAyNTB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmVj'
    b'NzRhIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2Q4YWEzZiIgc3Ryb2tlLXdpZHRo'
    b'PSIxLjciIGQ9Ik0yMzAuMyAyMzcuNmMyLjctMjQuNS0yMC44LTUyLjYgMTEuMS03OS40LTMu'
    b'NiAzNC45IDEzIDE4LjcgMTcuNSA2NC42bC0yOC42IDE0Ljh6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjZmVjNzRhIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2Q4YWEzZiIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjciIGQ9Ik0yNDMuMyAyMjcuN2MxMi40LTIxLjMgMi41LTU2LjUgNDIuNi02'
    b'Ny45LTE3LjYgMzAuMyA0LjIgMjIuMy0xMC41IDY2bC0zMi4xIDEuOXoiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNmZWM3NGEiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjZDhhYTNmIiBz'
    b'dHJva2Utd2lkdGg9IjEuNyIgZD0iTTI2MiAyMzAuM2MxOC42LTE2LjIgMjAuNC01Mi44IDYy'
    b'LTUwLjktMjYuMyAyMy4yLTMgMjIuNS0zMSA1OS40bC0zMS04LjV6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmVjNzRhIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2Q4YWEzZiIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjciIGQ9Ik0yNzguNiAyMzkuOWMyMi41LTEwLjEgMzQuOS00NC41IDc0'
    b'LjEtMzAuNS0zMiAxNC41LTkuNSAyMC43LTQ3IDQ3LjdsLTI3LjEtMTcuMnoiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZWM3NGEiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjZDhhYTNm'
    b'IiBzdHJva2Utd2lkdGg9IjEuNyIgZD0iTTI5Mi41IDI1NWMyNC40LTMuNCA0Ni0zMyA3OS43'
    b'LTguNC0zNC43IDQuOS0xNSAxNy4xLTU4LjUgMzIuNWwtMjEuMi0yNC4yeiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZlYzc0YSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNkOGFhM2Yi'
    b'IHN0cm9rZS13aWR0aD0iMS43IiBkPSJtMzc5LjUgMjU5LjYtMTEyLjEgMi41IDQuNyAzMC4y'
    b'IDEwNy40LTMyLjd6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmVjNzRhIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iI2Q4YWEzZiIgc3Ryb2tlLXdpZHRoPSIxLjciIGQ9Im0zNjMgMjE4'
    b'LjQtMTAzLjggMzkuOSAxNy4zIDMzLjMgODYuNS03My4yeiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZlYzc0YSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNkOGFhM2YiIHN0cm9rZS13'
    b'aWR0aD0iMS43IiBkPSJtMjgwLjYgMjgwLjcgNTMuNy05Ny42LTgyLjQgNzYuNyAyOC43IDIw'
    b'Ljl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmVjNzRhIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0'
    b'cm9rZT0iI2Q4YWEzZiIgc3Ryb2tlLXdpZHRoPSIxLjciIGQ9Im0yNzkuNSAyNzIuNiAxNy4y'
    b'LTEwOS40LTUzLjggOTcuMiAzNi42IDEyLjJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmVjNzRh'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2Q4YWEzZiIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjciIGQ9Im0yNzMgMjYzLjctMTgtMTEwLjItMjAgMTEwLjcgMzgtLjV6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZmVjNzRhIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2Q4YWEzZiIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjciIGQ9Im0yNjMuNyAyNTQuMy01Mi4zLTkyIDIwIDExMS44IDMy'
    b'LjMtMTkuOHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZWM3NGEiIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlPSIjZDhhYTNmIiBzdHJva2Utd2lkdGg9IjEuNyIgZD0ibTI1NS42IDI1My42'
    b'LTgxLjEtNjguNSA1Ny42IDk4IDIzLjUtMjkuNXoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZWM3'
    b'NGEiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjZDhhYTNmIiBzdHJva2Utd2lkdGg9'
    b'IjEuNyIgZD0ibTE0NiAyMTguOSA4NyA3MS45IDEzLjQtMzcuNkwxNDYgMjE4Ljl6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZmVjNzRhIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2Q4'
    b'YWEzZiIgc3Ryb2tlLXdpZHRoPSIxLjciIGQ9Im0yMzIuMSAyNjAuOS0xMDIuMy0xLjUgMTAx'
    b'LjkgMzQgLjQtMzIuNXoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZWM3NGEiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgc3Ryb2tlPSIjZDhhYTNmIiBzdHJva2Utd2lkdGg9IjEuNyIgZD0iTTMxNS4x'
    b'IDI3OS4yYTYxLjQgNjEuNCAwIDEgMS0xMjIuNyAwIDYxLjQgNjEuNCAwIDAgMSAxMjIuNyAw'
    b'eiIvPgogICAgPHBhdGggZmlsbD0iIzAwNTk4OSIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJN'
    b'LTE2NS4xIDMwMy40aDgzOS45VjUxMmgtODQweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNLTE2NS42IDQ1NGMxNS42IDcuMiAzOCAyNS4zIDYy'
    b'IDI1LjMgNDAtLjMgNDEtMjcuNCA4MS42LTI2LjEgNDAuNyAxIDMzLjMgMjkuNiA4OC4yIDI5'
    b'LjUgNDUuNC0uMiA2MC0zNC43IDk5LjItMzAuNiAyOS0xLjUgNDAuOCAzMi43IDg1LjMgMzMu'
    b'MiA0Ni4yIDEgNjMuMS0zNy4zIDkyLTM0LjEgMzEgMCA0MSAzMC44IDg0LjMgMzEgNTUuMi4z'
    b'IDY0LjktMzIgOTkuMy0zMCAyNC42LS41IDQ0IDIzLjcgODAgMjQuMyAyOC42LjUgNTIuNy0y'
    b'MS4yIDY5LTI5bC43LTM2LjhjLTE3IDYuMy00Mi40IDI3LjEtNjcuNyAyNy4zLTM2LjYgMS40'
    b'LTU5LjEtMjQtODQuNS0yMy43LTMwLjQuMy00Mi41IDMxLjMtOTQgMzEuMy00Ny4yIDAtNTgt'
    b'MzEuMy04OC40LTMxLjMtMjkuNy4yLTM4LjggMzQtOTAuMyAzMy40LTQyLS41LTU4LjMtMzIu'
    b'My04OC0zMi0zMS41IDAtNjQgMzAuOS05OSAyOS40LTQ4LTItNTguNS0yOS40LTkwLTI5LjQt'
    b'MjMuNSAwLTQ5IDI1LjYtNzcuMyAyNi0yOC4yLjUtNTkuOS0yNS41LTYyLjgtMjZsLjQgMzgu'
    b'M3ptMC03M2MxNS42IDcuMyAzOCAyNS40IDYyIDI1LjQgNDAtLjMgNDEtMjcuNCA4MS42LTI2'
    b'LjIgNDAuNyAxIDMzLjMgMjkuNyA4OC4yIDI5LjUgNDUuNCAwIDYwLTM0LjYgOTkuMi0zMC41'
    b'IDI5LTEuNSA0MC44IDMyLjcgODUuMyAzMy4xIDQ2LjIgMSA2My4xLTM3LjIgOTItMzQgMzEg'
    b'MCA0MSAzMC44IDg0LjMgMzEgNTUuMi4zIDY0LjktMzIgOTkuMy0zMCAyNC42LS41IDQ0IDIz'
    b'LjcgODAgMjQuMyAyOC42LjUgNTIuNy0yMS4yIDY5LTI5bC43LTM2LjhjLTE3IDYuMy00Mi40'
    b'IDI3LTY3LjcgMjcuMy0zNi42IDEuMy01OS4xLTI0LTg0LjUtMjMuNy0zMC40LjMtNDIuNSAz'
    b'MS4zLTk0IDMxLjMtNDcuMiAwLTU4LTMxLjMtODguNC0zMS4zLTI5LjcuMi0zOC44IDM0LTkw'
    b'LjMgMzMuNC00Mi0uNS01OC4zLTMyLjMtODgtMzItMzEuNSAwLTY0IDMwLjgtOTkgMjkuMy00'
    b'OC0yLTU4LjUtMjkuNC05MC0yOS40LTIzLjUgMC00OSAyNS43LTc3LjMgMjYuMS0yOC4yLjQt'
    b'NTkuOS0yNS41LTYyLjgtMjZsLjQgMzguM3oiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgZD0iTS0xNjUuNiAzMDljMTUuNiA3LjIgMzggMjUuMiA2MS45'
    b'IDI1LjIgNDAtLjIgNDEtMjcuNCA4MS42LTI2LjEgNDAuNiAxIDMzLjIgMjkuNiA4OC4xIDI5'
    b'LjUgNDUuMy0uMSA2MC0zNC43IDk5LTMwLjUgMjktMS41IDQwLjggMzIuNyA4NS4zIDMzLjEg'
    b'NDYuMSAxIDYzLTM3LjMgOTItMzQuMSAzMC44IDAgNDEgMzAuOCA4NC4yIDMxIDU1IC4zIDY0'
    b'LjctMzIgOTkuMi0zMCAyNC41LS41IDQzLjkgMjMuNyA3OS44IDI0LjMgMjguNy41IDUyLjct'
    b'MjEuMiA2OS0yOWwuNy0zNi44Yy0xNyA2LjQtNDIuMyAyNy4xLTY3LjcgMjcuMy0zNi40IDEu'
    b'NC01OS0yMy45LTg0LjQtMjMuNy0zMC4zLjMtNDIuNCAzMS4zLTk0IDMxLjMtNDcgMC01Ny44'
    b'LTMxLjMtODguMi0zMS4zLTI5LjcuMy0zOC44IDM0LTkwLjEgMzMuNC00Mi0uNS01OC4zLTMy'
    b'LjItODgtMzItMzEuNSAwLTY0IDMwLjktOTguOCAyOS40LTQ4LjEtMi01OC41LTI5LjQtOTAt'
    b'MjkuNC0yMy41IDAtNDguOSAyNS42LTc3LjIgMjYtMjguMi41LTU5LjgtMjUuNC02Mi44LTI2'
    b'bC40IDM4LjN6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZjODRiIiBmaWxsLXJ1bGU9ImV2ZW5v'
    b'ZGQiIHN0cm9rZT0iI2Q4YWEzZiIgc3Ryb2tlLXdpZHRoPSIxLjgiIGQ9Ik0xMzYuOCA3NmM2'
    b'MS00LjIgNTAtOS40IDc0LjUtMTMuNCAzMSA0LjMgMzQuNSAyMyA1MS44IDM0LjUgMCAwLTYu'
    b'NSAyMi0yNy43IDE4LjktMi45LTguOCAxMC4yLTExLjYtMjcuNS0zNC42LTIyLTEuMy02MS4z'
    b'IDMuOS03MS01LjR6bTE4OS4zIDMzLjktNDQgMS44djEwLjljMjkuNyAxIDM1LTMgNDQtMTIu'
    b'N3oiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmM4NGIiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlPSIjZDhhYTNmIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEu'
    b'NyIgZD0iTTE3NC44IDEwOGM3LjctMy45IDExLjUtMi4zIDE4LjItMi41IDQuNSA4LjMgOC44'
    b'IDkgMTguOCAxMGE0OS41IDQ5LjUgMCAwIDAgMzkuOSAyMS44YzI5LjktLjggMzkuNC0yMS43'
    b'IDU5LjUtMjRoMjEuMmMtMy41LTYtNi4zLTkuNS0xNC05LjktMTUuOC0uOC0zNi4yLS40LTU0'
    b'IDMuNmwtMjUuMSA2LjNjLTcuNC0zLjYtMjUuMy0yMi40LTM2LjgtMjItNi43IDEuOC02Ljcg'
    b'NC4xLTEwIDYuNy02LjUgMi44LTEzIDEuNC0xNy43IDEweiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmYzg0YiIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNkOGFhM2YiIHN0cm9rZS13'
    b'aWR0aD0iMS43IiBkPSJNMjA1LjEgOTlhMy4yIDMuMiAwIDEgMS02LjMgMCAzLjIgMy4yIDAg'
    b'MCAxIDYuMyAweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmYzg0YiIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2U9IiNkOGFhM2YiIHN0cm9rZS13aWR0aD0iMS44IiBkPSJNMjI1LjYgMTA3'
    b'LjhjNDQuOS01NC4xIDg0LjEtNDcuNSAxMzUuMy01MS4yIDEuNyA2LjMgMSAxNS43LTIzLjMg'
    b'MjQtMzMuNCA1LTkzLjEgNDAuMi05My40IDQwLjItMTEuMS0uNi0xOC45LTEyLjItMTguNi0x'
    b'M3oiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iI2Q5YTQzZSIgc3Ryb2tlLWxp'
    b'bmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuOCIgZD0iTTMxNy45IDcyLjUgMzUxIDc0'
    b'bS0zNi43IDQgMjQuMSAyIi8+CiAgPC9nPgo8L3N2Zz4K', 'KI')

KI = b64_KI
index.append("KI")
index.append("KIR")
index.append("Kiribati")
catalog["KI"] = KI
catalog["KIR"] = KI
catalog["Kiribati"] = KI
country["Kiribati"] = ('KI', 'KIR', 0)
lookup["KI"] = ('KI', 'KIR', 'Kiribati', 0)
lookup["Tarawa Kiribati"] = ('KI', 'KIR', 'Kiribati', 0)
lookup["KIR"] = ('KI', 'KIR', 'Kiribati', 0)
lookup["Kiribati"] = ('KI', 'KIR', 'Kiribati', 0)
details["KI"] = {"continent":"Oceania","capital":"Tarawa","currency":"Australian Dollar","web":".ki","lang":"en-KI | gil","tz":"+12:00","altname":""}
#----------------------------------------------------------------------
b64_KM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWttIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImttLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBjbGlwLXBhdGg9InVybCgja20tYSkiIHRyYW5zZm9ybT0ic2NhbGUoLjkzNzUpIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZjAiIGQ9Ik0wIDBoNzY4Ljh2MTI4SDB6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNMCAxMjhoNzY4Ljh2MTI4SDB6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYmUwMDI3IiBkPSJNMCAyNTZoNzY4Ljh2MTI4SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'M2I1YWEzIiBkPSJNMCAzODRoNzY4Ljh2MTI4SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMjM5'
    b'ZTQ2IiBkPSJNMCAwdjUxMmwzODEuOS0yNTUuM0wwIDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJNMTU3LjIgMTQxLjRjLTg1LTQuMy0xMjMuOSA2My41LTEyMy44IDExNS45LS4y'
    b'IDYyIDU4LjYgMTEzIDExMi44IDExMEMxMTcgMzUzLjUgODEuMiAzMTQuNiA4MSAyNTdjLS4z'
    b'LTUyLjEgMjkuNS05Ny41IDc2LjMtMTE1LjZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBk'
    b'PSJtMTU2IDE5Ny0xMi05LjMtMTQuNiA0LjYgNS4yLTE0LjQtOC44LTEyLjQgMTUuMi42IDkt'
    b'MTIuMyA0LjMgMTQuNyAxNC40IDQuOC0xMi42IDguNXptLS4zIDUyLjEtMTItOS40LTE0LjYg'
    b'NC42IDUuMy0xNC4zLTguOS0xMi40IDE1LjMuNSA5LTEyLjIgNC4yIDE0LjYgMTQuNSA0Ljkt'
    b'MTIuNyA4LjV6bS4yIDUyLjYtMTItOS40LTE0LjUgNC42IDUuMi0xNC4zLTguOC0xMi40IDE1'
    b'LjIuNSA5LTEyLjIgNC4zIDE0LjYgMTQuNCA0LjgtMTIuNiA4LjZ6bS0uMiA1My0xMi05LjNM'
    b'MTI5IDM1MGw1LjMtMTQuNC04LjktMTIuNCAxNS4zLjYgOS0xMi4zIDQuMiAxNC43IDE0LjUg'
    b'NC44LTEyLjcgOC41eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'KM')

KM = b64_KM
index.append("KM")
index.append("COM")
index.append("Comoros")
catalog["KM"] = KM
catalog["COM"] = KM
catalog["Comoros"] = KM
country["Comoros"] = ('KM', 'COM', 0)
lookup["KM"] = ('KM', 'COM', 'Comoros', 0)
lookup["Moroni Comoros"] = ('KM', 'COM', 'Comoros', 0)
lookup["COM"] = ('KM', 'COM', 'Comoros', 0)
lookup["Comoros"] = ('KM', 'COM', 'Comoros', 0)
details["KM"] = {"continent":"Africa","capital":"Moroni","currency":"Comorian Franc","web":".km","lang":"ar | fr-KM","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_KN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWtuIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImtuLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTgwLjEgMGg2ODIu'
    b'N3Y1MTJILTgwLjF6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNrbi1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoNzUuMSkgc2NhbGUoLjkzNzUpIj4KICAgIDxwYXRoIGZpbGw9IiNmZmU5MDAiIGQ9Ik0t'
    b'MTA3LjguMmg3MzcuNnY1MTEuM2gtNzM3LjZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMzVhMTAw'
    b'IiBkPSJtLTEwOC4yLjIuOCAzNjguNkw0NjYuNiAwbC01NzQuOC4yeiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2M3MDAwMCIgZD0ibTYzMC43IDUxMS41LTEuNC0zODMuMi01NzkgMzgzLjUgNTgw'
    b'LjQtLjN6Ii8+CiAgICA8cGF0aCBkPSJtLTEwNy45IDM5Ni42LjUgMTE1LjQgMTI1LjMtLjIg'
    b'NjExLjctNDEwLjFMNjI5IDEuNCA1MDUuMi4ybC02MTMgMzk2LjR6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJtMzgwLjQgMTU2LjYtOS44LTQyLjIgMzMuMyAyNyAzOC0yNC42LTE3'
    b'LjQgNDEuMyAzMy40IDI3LTQ0LjItMS41LTE3LjMgNDEuMy05LjktNDIuMi00NC4xLTEuNXpt'
    b'LTI3NS4yIDE3OS05LjktNDIuMyAzMy4zIDI3IDM4LTI0LjYtMTcuNCA0MS4zIDMzLjQgMjct'
    b'NDQuMS0xLjUtMTcuNCA0MS4zLTkuOC00Mi4yLTQ0LjEtMS41eiIvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'KN')

KN = b64_KN
index.append("KN")
index.append("KNA")
index.append("Saint Kitts and Nevis")
catalog["KN"] = KN
catalog["KNA"] = KN
catalog["Saint Kitts and Nevis"] = KN
country["Saint Kitts and Nevis"] = ('KN', 'KNA', 0)
lookup["KN"] = ('KN', 'KNA', 'Saint Kitts and Nevis', 0)
lookup["Basseterre Saint Kitts and Nevis"] = ('KN', 'KNA', 'Saint Kitts and Nevis', 0)
lookup["KNA"] = ('KN', 'KNA', 'Saint Kitts and Nevis', 0)
lookup["Saint Kitts and Nevis"] = ('KN', 'KNA', 'Saint Kitts and Nevis', 0)
details["KN"] = {"continent":"Americas","capital":"Basseterre","currency":"East Caribbean Dollar","web":".kn","lang":"en-KN","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_KP = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWtwIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImtwLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNNSAuMWg2ODIuNlY1'
    b'MTJINS4xeiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBjbGlwLXBhdGg9InVybCgja3AtYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRlKC00'
    b'LjggLS4xKSBzY2FsZSguOTM3NjgpIj4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIHN0cm9rZT0i'
    b'IzAwMCIgZD0iTTc3NiA1MTEuNUgtNzZWLjVoODUyeiIvPgogICAgPHBhdGggZmlsbD0iIzNl'
    b'NTY5OCIgZD0iTTc3NiA0MTlILTc2djkyLjVoODUyeiIvPgogICAgPHBhdGggZmlsbD0iI2M2'
    b'MDAwMCIgZD0iTTc3NiAzOTcuNkgtNzZWMTE0LjRoODUyeiIvPgogICAgPHBhdGggZmlsbD0i'
    b'IzNlNTY5OCIgZD0iTTc3NiAuNkgtNzZWOTNoODUyeiIvPgogICAgPHBhdGggZmlsbD0iI2Zm'
    b'ZiIgZD0iTTMyOC41IDI1NmMwIDYzLjUtNTMgMTE1LTExOC42IDExNVM5MS4zIDMxOS41IDkx'
    b'LjMgMjU2czUzLTExNC44IDExOC42LTExNC44YzY1LjUgMCAxMTguNiA1MS40IDExOC42IDEx'
    b'NC45eiIvPgogICAgPHBhdGggZmlsbD0iI2M0MDAwMCIgZD0ibTE3NS44IDI3MC42LTU3LTQw'
    b'LjcgNzEtLjIgMjIuNy02Ni40IDIxLjEgNjYuMSA3MS0uNC01Ny45IDQxLjIgMjEuMyA2Ni4x'
    b'LTU3LTQwLjctNTggNDEuM3oiLz4KICA8L2c+Cjwvc3ZnPgo=', 'KP')

KP = b64_KP
index.append("KP")
index.append("PRK")
index.append("North Korea")
catalog["KP"] = KP
catalog["PRK"] = KP
catalog["North Korea"] = KP
country["North Korea"] = ('KP', 'PRK', 0)
lookup["KP"] = ('KP', 'PRK', 'North Korea', 0)
lookup["Pyongyang North Korea"] = ('KP', 'PRK', 'North Korea', 0)
lookup["PRK"] = ('KP', 'PRK', 'North Korea', 0)
lookup["North Korea"] = ('KP', 'PRK', 'North Korea', 0)
details["KP"] = {"continent":"Asia","capital":"Pyongyang","currency":"North Korean Won","web":".kp","lang":"ko-KP","tz":"+09:00","altname":""}
#----------------------------------------------------------------------
b64_KR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1rciIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGNsaXBQYXRoIGlkPSJrci1hIj4KICAg'
    b'ICAgPHBhdGggZmlsbC1vcGFjaXR5PSIuNyIgZD0iTS05NS44LS40aDY4Mi43djUxMkgtOTUu'
    b'OHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgY2xpcC1wYXRoPSJ1cmwoI2tyLWEpIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSg4OS44IC40'
    b'KSBzY2FsZSguOTM3NSkiPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTS05NS44LS40SDU4'
    b'N3Y1MTJILTk1LjhaIi8+CiAgICA8ZyB0cmFuc2Zvcm09InJvdGF0ZSgtNTYuMyAzNjEuNiAt'
    b'MTAxLjMpIHNjYWxlKDEwLjY2NjY3KSI+CiAgICAgIDxnIGlkPSJrci1jIj4KICAgICAgICA8'
    b'cGF0aCBpZD0ia3ItYiIgZD0iTS02LTI2SDZ2MkgtNlptMCAzSDZ2MkgtNlptMCAzSDZ2Mkgt'
    b'NloiLz4KICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiNrci1iIiB3aWR0aD0iMTAwJSIgaGVp'
    b'Z2h0PSIxMDAlIiB5PSI0NCIvPgogICAgICA8L2c+CiAgICAgIDxwYXRoIHN0cm9rZT0iI2Zm'
    b'ZiIgZD0iTTAgMTd2MTAiLz4KICAgICAgPHBhdGggZmlsbD0iI2NkMmUzYSIgZD0iTTAtMTJh'
    b'MTIgMTIgMCAwIDEgMCAyNFoiLz4KICAgICAgPHBhdGggZmlsbD0iIzAwNDdhMCIgZD0iTTAt'
    b'MTJhMTIgMTIgMCAwIDAgMCAyNEE2IDYgMCAwIDAgMCAwWiIvPgogICAgICA8Y2lyY2xlIGN5'
    b'PSItNiIgcj0iNiIgZmlsbD0iI2NkMmUzYSIvPgogICAgPC9nPgogICAgPGcgdHJhbnNmb3Jt'
    b'PSJyb3RhdGUoLTEyMy43IDE5MS4yIDYyLjIpIHNjYWxlKDEwLjY2NjY3KSI+CiAgICAgIDx1'
    b'c2UgeGxpbms6aHJlZj0iI2tyLWMiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiLz4KICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjZmZmIiBkPSJNMC0yMy41djNNMCAxN3YzLjVtMCAzdjMiLz4K'
    b'ICAgIDwvZz4KICA8L2c+Cjwvc3ZnPgo=', 'KR')

KR = b64_KR
index.append("KR")
index.append("KOR")
index.append("South Korea")
catalog["KR"] = KR
catalog["KOR"] = KR
catalog["South Korea"] = KR
country["South Korea"] = ('KR', 'KOR', 0)
lookup["KR"] = ('KR', 'KOR', 'South Korea', 0)
lookup["Seoul South Korea"] = ('KR', 'KOR', 'South Korea', 0)
lookup["KOR"] = ('KR', 'KOR', 'South Korea', 0)
lookup["South Korea"] = ('KR', 'KOR', 'South Korea', 0)
details["KR"] = {"continent":"Asia","capital":"Seoul","currency":"Won","web":".kr","lang":"ko-KR | en","tz":"+09:00","altname":""}
#----------------------------------------------------------------------
b64_KW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWt3IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Imt3LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI2t3LWEpIiB0cmFuc2Zv'
    b'cm09InNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAxNzAuNmgx'
    b'MDI0djE3MC43SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZjMxODMwIiBkPSJNMCAzNDEuM2gx'
    b'MDI0VjUxMkgweiIvPgogICAgPHBhdGggZmlsbD0iIzAwZDk0MSIgZD0iTTAgMGgxMDI0djE3'
    b'MC43SDB6Ii8+CiAgICA8cGF0aCBkPSJNMCAwdjUxMmwyNTUuNC0xNzAuNy42LTE3MC44TDAg'
    b'MHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'KW')

KW = b64_KW
index.append("KW")
index.append("KWT")
index.append("Kuwait")
catalog["KW"] = KW
catalog["KWT"] = KW
catalog["Kuwait"] = KW
country["Kuwait"] = ('KW', 'KWT', 0)
lookup["KW"] = ('KW', 'KWT', 'Kuwait', 0)
lookup["Kuwait City Kuwait"] = ('KW', 'KWT', 'Kuwait', 0)
lookup["KWT"] = ('KW', 'KWT', 'Kuwait', 0)
lookup["Kuwait"] = ('KW', 'KWT', 'Kuwait', 0)
details["KW"] = {"continent":"Asia","capital":"Kuwait City","currency":"Kuwaiti Dinar","web":".kw","lang":"ar-KW | en","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_KY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1reSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMDYiIGQ9Ik0wIDBoNjQwdjQ4MEgw'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9Ik0wIDBoMzIwdjI0MEgweiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Im0zNy41IDAgMTIyIDkwLjVMMjgxIDBoMzl2MzFsLTEyMCA4'
    b'OS41IDEyMCA4OVYyNDBoLTQwbC0xMjAtODkuNUw0MC41IDI0MEgwdi0zMGwxMTkuNS04OUww'
    b'IDMyVjB6Ii8+CiAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0iTTIxMiAxNDAuNSAzMjAgMjIw'
    b'djIwbC0xMzUuNS05OS41em0tOTIgMTAgMyAxNy41LTk2IDcySDB6TTMyMCAwdjEuNWwtMTI0'
    b'LjUgOTQgMS0yMkwyOTUgMHpNMCAwbDExOS41IDg4aC0zMEwwIDIxeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIGQ9Ik0xMjAuNSAwdjI0MGg4MFYwek0wIDgwdjgwaDMyMFY4MHoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjYzgxMDJlIiBkPSJNMCA5Ni41djQ4aDMyMHYtNDh6TTEzNi41IDB2MjQw'
    b'aDQ4VjB6Ii8+CiAgPGcgc3Ryb2tlPSIjZmZmIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBz'
    b'dHJva2Utd2lkdGg9IjkuNiIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTMwNi44IC0yMS4yKSBz'
    b'Y2FsZSguODcxMzYpIj4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5LWEiIHdpZHRoPSIxMDAl'
    b'IiBoZWlnaHQ9IjEwMCUiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5LWIiIHdpZHRoPSIx'
    b'MDAlIiBoZWlnaHQ9IjEwMCUiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5LWMiIHdpZHRo'
    b'PSIxMDAlIiBoZWlnaHQ9IjEwMCUiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5LWQiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5LWUi'
    b'IHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5'
    b'LWYiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0i'
    b'I2t5LWciIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiLz4KICA8L2c+CiAgPGcgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNCIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTMwNi44'
    b'IC0yMS4yKSBzY2FsZSguODcxMzYpIj4KICAgIDxnIGlkPSJreS1iIiBmaWxsPSIjZmNlYTgz'
    b'Ij4KICAgICAgPHBhdGggZD0iTTc1NC40IDQ0OS42YzIuOSA3LjYgMjMuNSAxNy43IDQ3LjUg'
    b'NC44IDE2LjMtOS4yIDI2LjgtMjIgMzYuOS00NSAyLjgtNS44IDQuMy0xMy0yLjQtMTcuMy01'
    b'LjMtMy45LTE0LTguMi0xNy44LTEyLTEuOS0yLTMuOC0zLjQtNS4yLTQuOCAxIDEgMS45IDEu'
    b'OSAyLjggMy4zIDkuNiAxMS41LS40IDI4LjMtMTEgMzguNC03LjcgNy4yLTIxLjUgMjQuOS00'
    b'MS43IDguMS00LjMtMy44LTE0LjQgMTItOSAyNC41em0yOTEuNCAwYy0zLjQgNy42LTI0IDE3'
    b'LjctNDcuNSA0LjgtMTYuMi05LjItMjYuOC0yMi0zNy4zLTQ1LTIuNC01LjgtMy45LTEzIDIu'
    b'OC0xNy4zIDUuMy0zLjkgMTQtOC4yIDE3LjgtMTIgMS45LTIgMy4zLTMuNCA1LjItNC44LTEg'
    b'MS0xLjkgMS45LTIuOCAzLjMtOS42IDExLjUuNCAyOC4zIDEwLjUgMzguNCA3LjcgNy4yIDIy'
    b'IDI0LjkgNDIuMiA4LjEgNC4zLTMuOCAxMy45IDEyIDkgMjQuNXoiLz4KICAgICAgPHBhdGgg'
    b'ZD0iTTkwMC4xIDQ5MC44YzM4LjMgMCA5Ny4zLTE3LjMgMTI5LTc3LjcgNS4yLTEwIDAtMTUu'
    b'My02LjMtMTguNmE3MyA3MyAwIDAgMS0xOS4yLTE0YzcuNyA3LjcgNi4yIDEzIDEgMjEuNi0y'
    b'NC41IDQwLjgtNTggNjEuNC0xMDQuNSA2MS40cy04MC0yMC42LTEwNC41LTYxLjRjLTUuMi04'
    b'LjYtNi43LTEzLjkuNS0yMS41YTY2IDY2IDAgMCAxLTE5LjIgMTMuOWMtNi4yIDMuMy0xMS41'
    b'IDguNi02LjIgMTguNiAzMS42IDYwLjQgOTEgNzcuNyAxMjkuNCA3Ny43eiIvPgogICAgPC9n'
    b'PgogICAgPHBhdGggaWQ9Imt5LWMiIGZpbGw9IiNjODEwMmUiIGQ9Ik04MTEuNCA0MDkuOGMt'
    b'MS00LjgtNy4xLTIuOS05IDIuOWE2OC40IDY4LjQgMCAwIDEtNi44LTEwLjZjLTUuNy04LjYt'
    b'Ni43LTE0LjQgMS41LTIyLjUgMy44LTMuOCAxMS41LTguMiAxNi43LTMuNCAxMSA5LjEgNS4z'
    b'IDI0LTIuNCAzMy42em0xNzYuOSAwYzEtNC44IDcuNy0yLjkgOS42IDIuOSAyLjQtMy40IDQu'
    b'OC02LjcgNi43LTEwLjYgNS43LTguNiA2LjctMTQuNC0yLTIyLjUtMy4zLTMuOC0xMS04LjIt'
    b'MTYuNy0zLjQtMTAuNiA5LjEtNS4zIDI0IDIuNCAzMy42em0tMjMzLjkgMzkuOGMtNC44LTcu'
    b'Mi04LjYtMjYtOS42LTMwLjctMS40LTQuMy0xLjktOC4yIDMuNC0xMCA1LjMtMiAxMCA0Ljcg'
    b'MTIuNCAxMC41IDIuNCA1LjcgNi4zIDE0LjMgMTAuNiAyNC45LTEwLjYtNi4yLTE5LjItMi0x'
    b'Ni44IDUuM3ptMjkxLjQgMGM0LjMtNy4yIDguMS0yNiA5LjYtMzAuNyAxLTQuMyAxLjktOC4y'
    b'LTMuNC0xMC01LjMtMi0xMCA0LjctMTIuNCAxMC41LTIuNCA1LjctNi4zIDE0LjMtMTAuNiAy'
    b'NC45IDEwLjYtNi4yIDE4LjctMiAxNi44IDUuM3oiLz4KICAgIDxnIGZpbGw9IiMwMDQ5M2Qi'
    b'IHN0cm9rZT0ibm9uZSI+CiAgICAgIDxwYXRoIGQ9Im03ODIuMiA0MDYuNC0zLjggMmMtMSAu'
    b'NC0xIDEuNC0xIDEuOWgtLjVMNzc1IDQwNmguNWMwIC40LjUgMSAxLjQuNGw4LjItNC4zYzEt'
    b'LjUgMS0xIC41LTEuNGwuNC0uNSAyLjQgNC44aC0uNGMtLjUtLjUtMS0xLTItLjVsLTMuMyAy'
    b'IDEuNCAyLjggMy45LTEuNGMxLS41LjQtMS41LjQtMmguNWwyIDQuNGMtLjUtLjUtMS0xLTIt'
    b'LjVsLTguMSA0LjNjLTEgLjUtMSAxLS41IDEuNGwtLjUuNS0yLjQtNC4zLjUtLjVjLjUuNSAx'
    b'IDEgMiAuNWwzLjgtMnptOC4yIDYuM2MxLS41IDEtMSAuNC0yaC41bDQuOCA3LjItMy4zIDIu'
    b'NHYtLjRjMS45LTEuNSAxLjktMy40IDEuNC0zLjlzLTEtMS0xLTEuNGMtLjQgMC0uNC0uNS0x'
    b'LjQuNWwtMy40IDIuNGMuNS40IDEgMS45IDMuNC40aC41bC01LjMgMy45di0uNWMyLjQtMiAx'
    b'LjQtMy40IDEtMy44bC0zLjQgMi40Yy0xIC40LTEgMS0xIDEuNC41IDAgLjUuNSAxIDEgLjUg'
    b'MSAyIDEuOSA0LjMgMWwuNS40LTMuOCAxLjQtNC44LTcuNmguNWMuNC40IDEgMSAxLjkuNHpt'
    b'Ny42IDE4LjItMy4zIDIuOGMtLjUuNS0uNSAxLjUgMCAyaC0uNWwtMy40LTMuNC41LS41Yy41'
    b'LjUgMSAxIDIgMGw2LjItNi4yYzEtLjUgMS0xIC40LTJsMy40IDRjLS41LS42LTEuNC0uNi0y'
    b'IDBsLTIuOCAyLjggMi40IDIuNCAyLjktMi40YzEtMSAuNS0xLjQgMC0ybC41LS40IDMuMyAz'
    b'LjhoLS41Yy0uNCAwLTEtLjQtMS45LjVsLTYuMiA1LjhjLTEgMS0xIDEuNC0uNSAxLjl2LjVs'
    b'LTMuMy0zLjljLjQgMCAxLjQuNSAxLjkgMGwzLjMtMy4zem03LjIgMTAuMSAxLjUgMS40IDEu'
    b'OS00LjNzLTEuNS40LTMuOSAxLjlsLjUgMS0uNS40LTEtMWMtLjQuNS0uOS41LTEuNCAxLTEu'
    b'NCAxLTEgMS41LS40IDJ2LjRsLTIuNC0yLjRoLjRsMi0uNSA5LjUtNS4yLjUuNHMtLjUuNS00'
    b'LjggMTAuMWMwIDEtLjQgMS40IDAgMi40bC0zLjgtMy4zLjUtLjVjLjUgMSAxLjQgMSAxLjkg'
    b'MCAwLS41LjUtMS41LjUtMmwtMS41LTEuNC41LS41em0zLjggOS41LjUtLjVjLjUuNSAxIC41'
    b'IDIgMGw2LjItOC4xLS41LS41Yy0xLS41LTIuNC0uNS0zLjggMXYtLjVsMS45LTIuNCA3LjIg'
    b'NS4zLTIuNCAyLjhoLS41YzEuNC0xLjQgMS0zLjMgMC0zLjh2LS41bC02LjIgOC4yYy0xIC41'
    b'LS41IDEuNCAwIDEuOWgtLjV6Ii8+CiAgICAgIDxwYXRoIGQ9Im04MjEuNSA0NTIuNC0yLjQg'
    b'My40Yy0uNSAxIDAgMS40LjUgMmwtLjUuNC0zLjgtMi45di0uNWMxIC41IDEuNC41IDEuOS0u'
    b'NGw1LjMtNy4yYy40LTEgMC0xLjUtLjUtMmwuNS0uNCAzLjggMi44di41Yy0xLS41LTEuNC0u'
    b'NS0yIC41TDgyMiA0NTJsMi45IDEuOSAyLjQtMy40Yy40LTEgMC0xLjQtLjUtMS45bC41LS41'
    b'IDMuOCAyLjl2LjVjLS41LS41LTEuNC0uNS0yIC41bC00LjcgNy42Yy0xIC41LS41IDEgMCAx'
    b'LjV2LjRsLTQuMy0yLjhoLjVjLjQgMCAxIDAgMS40LS41bDIuNC0zLjh6bTkuNiAxMy41LjUt'
    b'LjVjLjUuNSAxLjQuNSAxLjktLjVsMy44LTguMWMuNS0xIDAtMS41LS41LTJsOC4yIDMuOS0y'
    b'IDMuOC0uNC0uNWMxLjQtMS45IDAtMy44LS41LTQuMy0uNSAwLTEtLjUtMS40LS41LS41IDAt'
    b'LjUgMC0xIDEtLjUuNS0xLjkgMy4zLTEuOSAzLjMuNS41IDEuNCAxLjUgMy40LTFoLjRsLTIu'
    b'OCA1LjgtLjUtLjRjMS40LTMtLjUtMy40LTEtMy40bC0xLjkgMy44Yy0uNSAxIDAgMS41LjUg'
    b'MS41di41em0xMy45IDYuN2MtMS40LTEtMS40LTMuOSAwLTYuNyAxLTMgMi45LTUuMyA0Ljgt'
    b'NC40IDEuNC41IDEgMy40IDAgNi4zLTEuNSAzLjMtMy40IDUuMi00LjggNC44aC0uNWMzLjQg'
    b'MS40IDUuOC0uNSA3LjItMy45IDEuNC0yLjggMS02LjItMi03LjYtMi44LTEuNS01LjcuNC03'
    b'LjEgMy44LTEuNCAzLjQtMSA2LjcgMiA3Ljd6bTE0LjguOSAyLTUuN2MuNC0xIDAtMS41LS41'
    b'LTJsMi40LjV2LjVjLS41IDAtMSAwLTEuNSAxbC0xLjkgNS43Yy0xIDIuNC0yLjQgNC4zLTUu'
    b'MiAzLjQtMi0uNS0zLjQtMi45LTIuNC01LjNsMi40LTYuMmMuNC0xIDAtMS41LS41LTJ2LS40'
    b'bDQuMyAxLjl2LjVjLS41LS41LTEuNC0uNS0xLjQuNUw4NTUgNDcyYy0uNSAxLjktLjUgMy44'
    b'IDEgNC4zIDEuNC41IDIuOC0uNSAzLjctMi45em00LjQtNi4yYzAtLjUgMC0uNS0uNS0uNWwz'
    b'LjMuNSAzIDkuMSAxLjQtNS44Yy40LTEgMC0xLjQtLjUtMS45bDIuOC41LS40LjVjLS41IDAt'
    b'MSAwLTEuNSAxbC0yLjQgMTAuNWgtLjRsLTMuOS0xMS41LTIuNCA3LjdjMCAxLjQuNSAxLjQg'
    b'MSAxLjl2LjVsLTIuOS0xdi0uNWMuNS41IDEuNCAwIDEuNC0xbDIuNC04LjZ6bTE2LjMgOS42'
    b'Yy0xIDQuMy0zIDUuMy0zLjkgNS4zaC0xcy0uNC0uNSAwLTFsMS41LTkuNmMuNS0uNS41LTEg'
    b'MS0uNWgxYy45IDAgMS44IDIgMS40IDUuOGwxLjQuNWMxLTQuOC0xLTYuOC0zLjQtNy4yLTEu'
    b'OS0uNS00LjgtMS00LjgtMXYuNWMuNS41IDEuNS41IDEgMmwtMS40IDguNWMtLjUgMS0xIDEu'
    b'NS0xLjUgMS41aC0uNGw0LjcgMWMyLjQuNCA0LjggMCA1LjgtNS4zem00LjMtMy45YzAtMS0x'
    b'LTEuNC0xLjUtMS40di0uNWw4LjcgMS0uNSAzLjhjMC0yLjQtMS41LTMuMy0yLjQtMy4zLS41'
    b'LS41LTEtLjUtMS41LS41LS40IDAtLjQgMC0uNCAxLjRsLS41IDMuOWMuNSAwIDEuOS40IDIu'
    b'OS0yLjRsLS41IDYuMmgtLjVjMC0yLjktMS40LTIuOS0yLTIuOWwtLjQgNC4zYzAgMSAwIDEg'
    b'LjUgMWwxIC41YzEuNCAwIDIuOC0uNSAzLjgtMy40aC41bC0xIDMuOC05LjEtMWMxIDAgMS40'
    b'LS40IDItMS4zem0xNS44IDUuOGMwIDQuMy0xLjUgNS43LTIuOSA1LjctLjUtLjQtLjUtLjQt'
    b'MS0uNGwtLjQtLjUuNS0xMGMwLS42IDAtLjYuNC0uNmgxYzEgMCAyLjQgMS41IDIuNCA1Ljho'
    b'MS45YzAtNC44LTIuNC02LjItNC44LTYuMi0yLS41LTQuOC0uNS00LjgtLjV2LjVjLjUgMCAx'
    b'LjUuNCAxLjUgMS40bC0uNSA5LjFjMCAxLS41IDEuNC0xIDEuNHYuNWg0LjNjMi40IDAgNC44'
    b'LTEgNS4zLTYuMmgtMnptMTMuOSAzLjhjMCAxIC41IDEgMS40IDF2LjVsLTUuMy40Yy41LS40'
    b'IDEuNS0xIDEuNS0xLjlsLTEtOWMtLjUtMS0xLTEtMS45LTF2LS41bDUuMy0uNWMtLjUuNS0x'
    b'LjUgMS0xIDJ6bTQuOCAxdi0uNWMuNSAwIDEtLjUgMS0xLjRsLTItMTBoLS41Yy0xIC40LTEu'
    b'OSAxLjMtMS40IDMuM2gtLjVsLS41LTMuNCA4LjctMS40LjQgMy4zaC0uNGMwLTEuOS0xLjUt'
    b'Mi40LTMtMi40aC0uNGwyIDEwYzAgMSAuNCAxLjUgMS40IDEuNXYuNXptMjAuNi05LjYtMi01'
    b'LjdjMC0xLS45LTEtMS40LTF2LS41bDIuNC0xdi41Yy0uNS41LS41LjUtLjUgMS41bDIgNi4y'
    b'Yy40IDIgLjQgNC44LTIuNCA1LjgtMiAuNC00LjMtLjUtNC44LTMuNGwtMi02LjJjLS40LTEt'
    b'LjktMS0xLjQtMWwtLjUtLjUgNC44LTEuNHYuNWMtLjQuNS0xIDEtLjQgMS45bDEuNCA2LjJj'
    b'LjUgMiAyIDIuOSAzLjMgMi45IDEuNS0uNSAyLTIuNCAxLjUtNC44em01LjMtMy40YzIuMy0x'
    b'IDEuOS0yLjMgMS40LTMuOC0uNS0xLjQtMS40LTIuNC0yLjQtMS45LS41IDAtMSAuNS0uNSAx'
    b'bDEuNSA0LjcuNC41IDEgMy45Yy41IDEgMS40IDEgMiAuNHYuNWwtNC40IDItLjUtLjVjMS0u'
    b'NSAxLTEgMS0ybC0zLjQtOC4xYy0uNS0xLjQtMS0xLTEuOS0xdi0uNGw0LjgtMmMyLS40IDMu'
    b'OCAwIDQuOCAyIC41IDIuNC0uNSAzLjgtMi40IDQuOC0uNSAwLTEgLjQtMSAuNHoiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTk1Ny4xIDQ3MmMtMS40LjYtMy4zLTEuNC00LjgtNC43LTEuNC0yLjkt'
    b'MS40LTUuOCAwLTYuMiAxLjUtLjUgMy40IDEuNCA0LjggNC4zIDEuNSAyLjkgMS41IDUuNyAw'
    b'IDYuNyAzLTEgMy45LTQuMyAyLjQtNy43LTEuNC0yLjktNC4zLTQuOC03LjItMy44YTUuNiA1'
    b'LjYgMCAwIDAtMi40IDcuN2MxLjUgMy4zIDQuNCA1LjIgNy4yIDMuOHptLjUtMTMuM2gtLjls'
    b'Mi44LTIgOC43IDQuOC0zLTUuMmMtLjQtMS0xLjQtMS0xLjgtMXYtLjVsMi40LTFjLS41LjYt'
    b'MSAxIDAgMmw0LjggOS42LS41LjUtMTAuNi01LjggMy45IDcuMmMuNCAxIDEuNCAxIDEuOS41'
    b'di41bC0yLjQgMS40di0uNWMuNS0uNS41LTEgMC0xLjlsLTMuOC03LjctMS41LTF6bTIxLjYg'
    b'MS40di0uNWMwLS41LjUtMSAwLTEuOWwtNS44LTguMWgtLjVjLTEgLjQtMS40IDIuNCAwIDMu'
    b'OGwtLjQuNS0yLTMuNCA3LjItNC44IDIgM2MtMS41LTEuNS0zLTEuNS0zLjktMWwtLjUuNCA1'
    b'LjggOC4yYy41IDEgMS40IDEgMiAuNXYuNHoiLz4KICAgICAgPHBhdGggZD0ibTk4NC41IDQ0'
    b'OC42IDIuOCAzLjRjLjUuNCAxLjUuNCAyIDB2LjRsLTMuOSAzLjR2LS41Yy41LS41LjUtMSAw'
    b'LTEuOWwtNS43LTcuMmMtLjUtMS0xLS41LTItLjVsMy45LTMuM3YuNWMwIC40LS41IDEgMCAx'
    b'LjlsMi40IDIuOCAyLjgtMS45LTIuMy0zLjNjLS41LTEtMS41LS41LTItLjVsMy45LTMuNHYu'
    b'NWMtLjUuNS0uNSAxIDAgMmw1LjcgNy4xYy41LjUgMSAuNSAxLjUgMGwuNC41LTMuOCAzLjQt'
    b'LjUtLjVjLjUtLjUgMS0xIC41LTJsLTIuOS0zLjN6bTQuMy0xMC4xYy0uNS0uNC0xLjUtLjQt'
    b'MiAwdi0uNGw2LjMtNS44IDIuOSAyLjloLS41Yy0xLjUtMi0zLjQtMS00LjMtLjUgMCAuNS0u'
    b'NS41LTEgMSAwIDAgMCAuNC41IDEuNGwyLjkgMi45Yy40LS41IDEuOS0xLjUgMC0zLjloLjRs'
    b'My45IDQuNHYuNGMtMi40LTIuNC0zLjQtMS0zLjktLjRsMyAyLjhjLjQgMSAuOSAxIC45IDFs'
    b'MS40LTEuNGMuNS0uNSAxLTIgMC00LjhoLjVsMS45IDMuMy02LjIgNi4yLS41LS40Yy41LS41'
    b'IDEtMSAwLTJ6bTExLjUtMTMuNGMtLjUuNS0uNSAxLjUuNCAyIDEgLjkgMiAuOSAzLjkgMCAx'
    b'LS41IDIuOC0xIDQuMy40IDIuNCAyLjQgMS40IDQuMyAxIDUuMy0uNS41LTEuNSAxLTIgMS40'
    b'LS41IDAtLjUgMC0uNS41di41bC0zLjMtMi45aC41YzEuOSAxIDMuOCAxLjQgNC44IDAgMS0x'
    b'IDAtMi0uNS0yLjQtMS0xLTItMS0zLjQgMC0xLjQuNS0zLjMuNS00LjgtLjUtMS45LTEuOS0x'
    b'LjktMy4zLTEtNC44bDItMS40Yy41IDAgLjUgMCAwLTFsMy40IDIuNGgtLjVjLTIuNC0xLTMu'
    b'OS0uNC00LjMuNXptNC4zLTMuOGMtMS0uNS0xLjUgMC0yIC41aC0uNGw1LjMtNy43IDMuMyAy'
    b'LjQtLjUuNWEzLjMgMy4zIDAgMCAwLTQuMyAwYzAgLjUtLjUgMS0uNSAxLjQtLjQgMC0uNC41'
    b'LjUgMSAuNS41IDMuNCAyLjQgMy40IDIuNC41LS41IDEuNC0xLjUtLjUtMy40di0uNWw0Ljgg'
    b'My45Yy0yLjktMS41LTMuNCAwLTMuOC40bDMuMyAyLjRjMSAuNSAxLjQuNSAxLjQuNSAwLS41'
    b'LjUtMSAxLTEuNC41LTEgMS0yLjQtMS00LjNsLjUtLjUgMi40IDIuOS00LjggNy4yaC0uNWMu'
    b'NS0xIC41LTEuNS0uNC0yLjR6bTEyLjktOC42LTEuNCAyLjRjLTItMi0yLjktMy40LTIuOS0z'
    b'LjRsNC4zIDFoMWMuNSAwIDEuNC40IDEuOS40IDEuNC41IDEgMSAuNSAyaC41bDIuNC00LjRj'
    b'LTEgMS0xLjUuNS0yLjQuNS0xMC4xLTEuOS0xMS0yLjQtMTEtMi40di41bDcuNiA4LjZjLjUu'
    b'NS41IDEuNS41IDJoLjVsMS40LTIuNC0uNS0uNWMtLjUgMS0xIDEuNC0xLjkgMGwtMS0xIDEu'
    b'NS0zLjN6bS0yLjktMTAuNmMtLjQuNS0uNCAxLjUgMSAyIDEuNC40IDIgMCAzLjQtMXMyLjgt'
    b'MiA0LjctMWMzIDEuNSAyLjQgMy45IDIgNC44bC0xLjUgMnYuOWwtMy44LTJjMi40LjUgNC4z'
    b'IDAgNC44LTEuNC41LTEtLjUtMS45LTEtMi40LTEtLjQtMS45IDAtMy4zIDEtMS41IDEuNC0z'
    b'IDItNC44IDEtMi0xLTIuOS0yLjQtMi0zLjkgMC0xIDEtMS40IDEuNS0xLjkgMC0uNSAwLS41'
    b'LS41LTF2LS40bDMuOSAxLjloLS41Yy0yLjQtLjUtMy45LjUtMy45IDEuNHoiLz4KICAgIDwv'
    b'Zz4KICA8L2c+CiAgPGcgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNCIgdHJhbnNm'
    b'b3JtPSJ0cmFuc2xhdGUoLTMwNi44IC0yMS4yKSBzY2FsZSguODcxMzYpIj4KICAgIDxnIGlk'
    b'PSJreS1kIiBmaWxsPSIjMDczMTYzIj4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTg2'
    b'My4yIDIzMi41Yy02LjIgMS40LTEwLjUgMS45LTE2LjMtMy40LTMuOC0zLjgtMi45LTEwLjUg'
    b'MS0xMyA0LjMtMi44IDguMS00LjcgMTMuNC0zLjMgNS4zIDEuNSAxOS4yIDE0LjQgMTUuOCAx'
    b'NC45LTMuNCAwLTguNiAzLjMtMTMuOSA0Ljh6bTE0LjgtMjNjMi0xLjUgNC40LTIuNCAxMC42'
    b'LTMgNS44LS40IDEwLS40IDExLjUgNCAyIDUuMiAzLjQgMTEuNCA3LjIgMTQuMy0yLjQgMS40'
    b'LTE0LjQgMi45LTE4LjcuNS01LjctMi45LTcuMi0xNC0xMC41LTE1Ljh6bTQxLjMuNWMxLjkt'
    b'MS41IDQuMy0xLjUgMTAuNS0xczguNiAxIDEwIDUuM2MxLjUgNC44IDAgMTEgMyAxNS4zLTMg'
    b'MS0xMi41IDEtMTUuOS0yLjQtNS4yLTMuOC00LjgtMTQuOS03LjYtMTcuM3oiLz4KICAgICAg'
    b'PHBhdGggZD0iTTk0OCAyMTIuOGMtNC4zLTEtNy4yLTEuNC05IDAgMi4zIDIuOS40IDE0LjQg'
    b'NS4yIDE4LjIgMy4zIDIuNCAxMiAzIDEzLjktMi40IDIuNC00LjggMi40LTEyLTEwLTE1Ljh6'
    b'bS00OS4zLTQuOGMxLjQtMS40IDQuMy0xLjkgMTAtMS45IDYuMyAwIDEwIDEgMTIgNC44IDIg'
    b'NC44IDEuNCAxMSA0LjggMTQuOS0xLjQgMS45LTE0LjQgMS45LTE4LjItMS01LjMtMy40LTUu'
    b'OC0xNC40LTguNi0xNi44em0tNDAuNyA0LjNjMC0yLjQgMy4zLTIuOCAxMi0zLjMgOC41LTEg'
    b'OS0uNSAxMS45IDUuNyAxLjQgMy40IDMuMyA5LjEgNy4yIDExLTEwLjYgMi41LTE0IDMuOS0x'
    b'OS43LjVhMjkuMiAyOS4yIDAgMCAxLTEwLTEwLjVjLS41LTEuNC0uNS0yLjktMS41LTMuNHoi'
    b'Lz4KICAgIDwvZz4KICAgIDxnIGZpbGw9IiNmOWQwNTAiIHN0cm9rZS13aWR0aD0iLjYiPgog'
    b'ICAgICA8ZyBpZD0ia3ktZiI+CiAgICAgICAgPHBhdGggZD0iTTg4MSAxNjMuNWMtMTAuMS03'
    b'LjctMjIuMS0xNC45LTMzLjEtMTYuM2EyODAgMjgwIDAgMCAxIDMyLjYgMjUuNCIvPgogICAg'
    b'ICAgIDxwYXRoIGQ9Ik04ODYuNyAxNTYuM2MtMTItOC4yLTI1LjktMTcuMy0zOS4zLTE4LjJh'
    b'MTI0IDEyNCAwIDAgMSAzMyAyNy44bTIxLjYtMjNhOTMgOTMgMCAwIDEgMjMuNS0zMi4yYy00'
    b'LjggMTAuMS0xMCAzMC43LTEyLjUgMzguOSIvPgogICAgICAgIDxwYXRoIGQ9Ik05MTIuNiAx'
    b'NDAuNUE0OC40IDQ4LjQgMCAwIDEgOTM3IDExNWExMDEuMiAxMDEuMiAwIDAgMC0xOC4yIDM1'
    b'Ii8+CiAgICAgICAgPHBhdGggZD0iTTkxNi45IDE1MGE4NC41IDg0LjUgMCAwIDEgMzcuOC0z'
    b'MS42Yy0xMiAxMi0yOS43IDM0LTM0IDQyLjdtMi45LS41YzguNi00LjggMjUuOS0xMi41IDM4'
    b'LjMtMTAtNy42IDIuOC0zMC42IDEzLjMtNDAuNyAyMyIvPgogICAgICAgIDxwYXRoIGQ9Ik05'
    b'MjEuNyAxNTcuMmM4LjEtOC42IDIzLTIxLjUgMzguOC0yNi44LTExLjUgMTEtMzYgMzYtMzku'
    b'MyAzOS44TTg5OC43IDE1MmMtNS44LTE3LjgtMTQuNC0zNC41LTI3LjMtMzkuOGExMzAuOSAx'
    b'MzAuOSAwIDAgMSAyMSA0OC45bS00LjgtOS42Yy05LjUtMTEuNS0yMi41LTIzLTM3LjMtMjUu'
    b'NGE5MC4xIDkwLjEgMCAwIDEgMzMgMzguOCIvPgogICAgICAgIDxwYXRoIGQ9Ik04OTMgMTUx'
    b'Yy0xMi0yMS42LTIxLjItMjUuNC0yNi40LTI5LjcgNC4zIDguMSAxNC44IDI5LjcgMjEgMzgu'
    b'OCIvPgogICAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik04NjkgMTQ5LjZhNTcuNyA1Ny43'
    b'IDAgMCAxIDE3LjIgMTYuNyIvPgogICAgICAgIDxwYXRoIGQ9Ik04NjkgMTU5LjZjMi44IDIu'
    b'NCA4LjEgNS4zIDEyLjkgOS42bTQ0LjEtMi40YzQuOC0zLjggMTUuMy0xMCAyMC42LTEybS0y'
    b'NCA4LjdjNC44LTYuMyAxNC40LTE0LjkgMTcuOC0xNy44bS00LjQtMTJhMjg2LjkgMjg2Ljkg'
    b'MCAwIDAtMTguMiAyMi42bTUuOC0yNi45YTE1NyAxNTcgMCAwIDAtMTIgMjEuMW0tMjUuOS0y'
    b'MC4xYzIuOSA3LjcgOC4yIDIwLjYgMTAgMjUuOW0tMTQuMy0xNy44YzIgMyA1LjggOS42IDcu'
    b'MiAxNC40Ii8+CiAgICAgIDwvZz4KICAgICAgPGcgaWQ9Imt5LWciPgogICAgICAgIDxwYXRo'
    b'IGQ9Ik04OTcuNyAxMzYuMWMwLTQuMyAyLjktOSA1LjgtOSAzLjMgMCA1LjcgNS43IDUuNyA5'
    b'IDAgMy45LTIuOSA3LjItNS43IDcuMi0zIDAtNS44LTIuOC01LjgtNy4yeiIvPgogICAgICAg'
    b'IDxwYXRoIGQ9Ik04OTEuNSAxNDBjLjUtNC44IDMuOC04LjYgNi43LTguMiAyLjkuNSA0LjMg'
    b'Ni4zIDMuOCA5LjYtLjUgMy44LTMuOCA2LjctNi4yIDYuMi0yLjQgMC00LjgtMy4zLTQuMy03'
    b'LjZ6bTEyLjkgMS40Yy0xLTQuMyAxLTkgMy45LTkuNiAyLjgtLjQgNS43IDQuMyA2LjIgOC4y'
    b'IDEgMy44LTEuNSA3LjYtMy45IDcuNi0yLjMuNS01LjctMS45LTYuMi02LjJ6Ii8+CiAgICAg'
    b'ICAgPHBhdGggZD0iTTg5Ny4yIDE0NS4yYzAtNC43IDIuOS05IDUuOC05IDMuMyAwIDUuNyA1'
    b'LjIgNS43IDkgMCAzLjktMi44IDcuMi01LjcgNy4yLTIuOSAwLTUuOC0yLjgtNS44LTcuMnoi'
    b'Lz4KICAgICAgICA8cGF0aCBkPSJNODg4LjYgMTQ3LjZjMC00LjMgMy40LTkgNi4yLTkgMyAw'
    b'IDUuOCA1LjcgNS44IDkgMCAzLjktMy40IDcuMi01LjggNy4yLTIuOCAwLTYuMi0yLjgtNi4y'
    b'LTcuMnptMTcuNy0xLjljMC00LjMgMy05IDUuOC05IDMuMyAwIDUuNyA1LjcgNS43IDkgMCAz'
    b'LjktMi44IDcuMi01LjcgNy4yLTIuOSAwLTUuOC0yLjktNS44LTcuMnoiLz4KICAgICAgICA8'
    b'cGF0aCBkPSJNOTA0LjQgMTQ5LjZjMC00LjggMy40LTkuMSA2LjItOS4xIDMgMCA1LjggNS4y'
    b'IDUuOCA5IDAgMy45LTIuOSA3LjMtNS44IDcuMy0yLjggMC02LjItMy02LjItNy4yeiIvPgog'
    b'ICAgICAgIDxwYXRoIGQ9Ik04OTYuOCAxNTMuOWMwLTQuOCAyLjgtOS4xIDUuNy05LjEgMy40'
    b'IDAgNS44IDUuNyA1LjggOSAwIDQtMyA3LjMtNS44IDcuMy0yLjkgMC01LjgtMy01LjgtNy4y'
    b'em0tMTIgMGMwLTQuOCAyLjQtOS4xIDQuOC05LjFzNC4zIDUuNyA0LjMgOWMwIDQtMi40IDcu'
    b'My00LjMgNy4zLTIuNCAwLTQuOC0zLTQuOC03LjJ6bTI2LjgtLjljMC00LjQgMi40LTguNyA0'
    b'LjgtOC43czQuOCA1LjMgNC44IDguNmMwIDQuMy0yLjkgNy4yLTQuOCA3LjItMi40IDAtNC44'
    b'LTIuOS00LjgtNy4yeiIvPgogICAgICAgIDxwYXRoIGQ9Ik05MTQuNSAxNjFjMS00LjcgMy44'
    b'LTguNiA1LjctOCAyIC40IDIuNCA2LjEgMS41IDkuNS0uNSA0LjMtMy40IDYuNy01LjMgNi4y'
    b'LTItLjQtMi45LTMuOC0yLTcuNnoiLz4KICAgICAgICA8cGF0aCBkPSJNOTA1LjQgMTU5LjZj'
    b'LjUtNC4zIDMuMy04LjYgNS43LTguMSAyLjkgMCA0LjMgNS43IDMuOSA5LS41IDQuNC0zIDcu'
    b'My01LjMgNi44LTIuNCAwLTQuOC0zLjQtNC4zLTcuN3pNODkyIDE2MWMtMS41LTQuNy00LjQt'
    b'OC02LjMtNy42LTEuOS41LTIuNCA2LjItMS40IDkuNiAxIDMuOCAzLjggNi4yIDUuNyA1Ljcg'
    b'MS41LS40IDMtMy44IDItNy42eiIvPgogICAgICAgIDxwYXRoIGQ9Ik04ODguNiAxNjAuMWMw'
    b'LTQuMyAyLjQtOC42IDQuOC04LjYgMi45IDAgNC44IDUuMyA0LjggOC42IDAgNC4zLTIuNCA3'
    b'LjItNC44IDcuMi0yIDAtNC44LTIuOS00LjgtNy4yeiIvPgogICAgICAgIDxwYXRoIGQ9Ik04'
    b'OTUuOCAxNjJjMC00LjggMi45LTkgNS43LTkgMy40IDAgNS44IDUuMiA1LjggOSAwIDMuOS0y'
    b'LjkgNy4yLTUuOCA3LjItMi44IDAtNS43LTIuOS01LjctNy4yem0yLjQtNTIuN2MtMSAzLjgt'
    b'NC4zIDcuMi0yIDEyLjUtNC4yLTEuNS04LTItMTEuNCAxLjkgNC4zLS41IDguMSAxIDEwIDMu'
    b'OC0zLjgtLjUtNS43IDEuNS02LjcgMy45IDMuNC0xIDYuNy0yIDguMi0xLjUtMS41IDEuNS0z'
    b'LjkgMy44LTQuMyA1LjggMi44LTIuNCA2LjItMiA4LjEtMy40LTEuNCAzLjQgMS40IDYuNyAz'
    b'LjggMTAtLjQtNC43IDIuNC04IDEtMTAuNSA0LjMgMSA0LjggNC44IDExIDQuOC0yLjQtMS40'
    b'LTMuOC02LjItNi43LTYuMiAxLjQtLjUgNy4yLTEgOC4yIDAtMS0yLTQuNC0zLjgtNi4zLTMu'
    b'OCAyLTIgNS4zLTUuOCA3LjctNi44LTMuNC41LTguNiAxLTEwLjUgMy45IDQuNy0zLjkgMy44'
    b'LTExIDktMTItMi44LS41LTcuMSAxLjQtMTAuNSA0LjggMS41LTIuOSAxLjUtNi43IDMuNC03'
    b'LjctMy45IDEtOC4yIDUuOC05LjYgOC4yYTE4IDE4IDAgMCAwLTIuNC03Ljd6Ii8+CiAgICAg'
    b'ICAgPHBhdGggZD0iTTkwMC42IDExN2MwIDEuNCAwIDQuMy0uNSA1LjJtNi43LTUuN2MtMSAx'
    b'LTIuOSA0LjMtMi45IDcuMiIvPgogICAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik05MDku'
    b'NyAxMjIuMmE3LjYgNy42IDAgMCAwLTMuNCA0LjQiLz4KICAgICAgPC9nPgogICAgPC9nPgog'
    b'ICAgPGcgaWQ9Imt5LWUiIGZpbGw9IiMwNTkzMzQiPgogICAgICA8cGF0aCBkPSJNODU4Ljkg'
    b'MTY5LjdjLTMuNCAwLTYuMi0xLjQtOC4yLTMuOC0zLjMtNC40LTEyLjQtNi4zLTE2LjMtMi40'
    b'LTEuNCAxLTMuMyAxLTQuNyAxLjQtMi40IDAtNS4zIDIuNC00LjQgNy4yIDItMS41IDIuNCAw'
    b'IDMuOSAwIDEtLjUuNS41LjUgMS40IDAgMi40IDUuMiA3LjIgMTAgNi43IDUuMyAwIDcuNyAy'
    b'IDguNiAzIDEuNSAxLjMuNS45IDEuNSAzLjMgMS40IDEuNCAxLjkgMS45LS41IDMuOGE5Ljcg'
    b'OS43IDAgMCAwIDAgMTQuOWM2LjIgNC43IDIyIDEyIDM5LjgtMiAxNy4yLTEzLjQgNDQtNS43'
    b'IDQ2LTEgMi40IDQuOSAzLjMgNy43IDMuOCAxMC4xLjUgMiAyLjkgMy45IDYuMyAzLjQgMy4z'
    b'IDAgNy4xIDEuNCA5IDIuOSAyLjUgMS40IDUuOCAxIDQuOS0zLjQtMi0xMy40LTEwLjEtMTUu'
    b'My0xMS0yMS41IDQuNy40IDggLjQgMTAtMS41IDEuNC0xLjkgMy4zLTUuMyA1LjMtNi4yIDEu'
    b'NC0xIDEuNC0yLS41LTEuNS0yLjQuNS0zLjggMS41LTguMiAxLTIyLTIuNC04My44LTE5LjIt'
    b'OTUuOC0xNS44eiIvPgogICAgICA8cGF0aCBmaWxsPSIjMDAwIiBkPSJNOTU2LjcgMTg2YTM0'
    b'LjggMzQuOCAwIDAgMC05LjIgOS42Yy00LjcgNi4yLTE5LjEgMTIuNC0zNi45IDEyLjQtMTcu'
    b'MiAwLTI3LjctMi44LTM1LjQtOWE2MC42IDYwLjYgMCAwIDAtMTAuNi02LjhjLTUuMi0yLjQt'
    b'Ni4yLTcuNy00LjgtMTItMS40IDIuNC0yLjMgNC44LTUuMiA0LjMtMiAwLTUuOCAwLTQuOCAy'
    b'LS41LTEtLjUtMi40LTEtM2wtMS0uOWMxLjUgMSA0LjktMS45IDcuMy0xLjkgMS45LjUgNC4z'
    b'LTEuOSAzLjgtNC44bC0xLjQtNi4yYzMuOC0yIDU0LjEgNy4yIDY0LjIgOC4xIDEwIC41IDM4'
    b'LjggNC44IDM1IDguMnoiLz4KICAgICAgPHBhdGggZD0iTTg2NS42IDE2Ny44YzQuOC00Ljgg'
    b'MTAuNS03LjIgMTYuMy01LjhoMS40YzMtMi40IDkuNi0yLjkgMTMuNS0xaDEuOWM1LjctMS45'
    b'IDE2LjcgMCAyMC42IDMuOWwxLjQgMWMxMy0xIDIwLjYgNC43IDI5LjcgMTMuOSAxIDEgMi40'
    b'IDIuOCA0LjggMy4zIDIuOS41IDMuNCAyIDEgMy40YTM3LjggMzcuOCAwIDAgMC0xMCA5Yy00'
    b'LjQgNS44LTE4LjMgMTEuNi0zNS42IDExLjYtMTYuNyAwLTI2LjgtMy0zNC41LTguNy00LjMt'
    b'My4zLTcuNi01LjItMTAtNi43LTIuOS0xLTYuNy00LjgtNS4zLTguNiAxLTMuOC0xLjQtOC42'
    b'LTMuMy0xMy40IDEuNC0xIDUuMi0yLjQgNy4xLTEuNHoiLz4KICAgICAgPGcgZmlsbD0iIzAw'
    b'NDkzZCI+CiAgICAgICAgPHBhdGggZD0iTTk1MC40IDE3OS44Yy05LTkuMi0xNi43LTE0Ljkt'
    b'MjkuNy0xNCAwIC41IDAgMi0uNSAzYTY2LjMgNjYuMyAwIDAgMSAyMy41IDE3LjdjMi0yIDUu'
    b'My00LjMgNi43LTYuN3ptLTMxLjEtMTQuOWMtMy45LTMuOC0xNC45LTUuOC0yMC42LTMuOCAw'
    b'IDEuOSAwIDQuOC0xIDYuNyAzLjQgMS40IDYuMiA0LjggOS4xIDguMSAyLS41IDYuNy0xLjkg'
    b'OS4xLTIuNGE0NCA0NCAwIDAgMCAzLjQtOC42em0tMjIuNS0zLjljLTMuOS0xLjktMTAuNi0x'
    b'LjQtMTMuNSAxLTEgMi0xLjQgNS44LTEuNCA3LjcgMiAwIDQuOCAxLjQgNS43IDIuNCAzLTEg'
    b'Ni44LTIuOSA4LjItNC4zLjUtMiAxLjQtNC44IDEtNi43em0tMzEuMiA2LjhjNC44LTQuOCAx'
    b'MC41LTcuMiAxNi4zLTUuOC0xIDEuNS0xLjQgNC4zLTEuNCA3LjItNS4zLS41LTEyIDEtMTQu'
    b'OSAyLjl6Ii8+CiAgICAgICAgPHBhdGggZD0iTTk0MS44IDE4Ny40YTY0LjIgNjQuMiAwIDAg'
    b'MC0yMi0xNi44YzAgLjUtMSAyLjQtMS41IDMuOSAyLjkgNC4zIDguNiAxMy45IDExIDE5LjIg'
    b'Mi40LTEgOS4xLTMuOSAxMi41LTYuM3pNOTA1LjQgMTk4YTE3OSAxNzkgMCAwIDAgMS40LTE5'
    b'LjdjMi40LS41IDcuMi0xLjkgOS4xLTIuNCAyLjQgMy45IDguMiAxNCAxMC42IDE4LjctNS44'
    b'IDEuNC0xNS40IDMuOC0yMS4xIDMuNHptLTE2LjgtMjNjMi40LTEgNS44LTMgOC4xLTQuOCAy'
    b'IDEuNCA1LjggNC44IDcuMiA2LjcgMCA0LjMtMS40IDE2LjgtMS45IDIxLTMuOCAwLTEwLS45'
    b'LTEzLjQtMi44LjUtNy4yIDEtMTUuMyAwLTIwLjF6bS0yNCA1LjdjLjUtMSAxLTQuMyAxLTUu'
    b'NyAzLjgtMi40IDEzLjQtNC44IDIwLjYtMSAuNSA0LjggMCAxNi44LS41IDE5LjdhOTYuNCA5'
    b'Ni40IDAgMCAwLTIxLTEzeiIvPgogICAgICA8L2c+CiAgICAgIDxnIGZpbGw9Im5vbmUiPgog'
    b'ICAgICAgIDxwYXRoIGZpbGw9IiMwMDAiIHN0cm9rZT0ibm9uZSIgZD0iTTg0MC43IDE3MmMt'
    b'MSAwLTEuNS0yLjgtMy40LTIuOC0uNSAwLTEuOS41LTIuNCAwIDAgMSAuNSAyIDEgMi40LjUg'
    b'MS40IDIuOS41IDQuOC41eiIvPgogICAgICAgIDxwYXRoIGQ9Ik04NDAuNyAxODAuMmM1Ljcg'
    b'MCA2LjctNy4yIDkuNi03LjZtLTYuMyA4LjFjNC4zIDIgNy43LTguMSAxMS03LjdtLTE5LjYt'
    b'NC43YzEuNCAwIDIuNC0yIDQuOC40IDEgMSAyLjQgMS41IDMuNCAxLjVtLTEgNS4yYy0yIDMt'
    b'NS4zIDQuOC03LjIgMy45bS0xLTE1LjhjLTEuNCAxLTIuMyAyLjgtMy4zIDQuM20tMS40IDIu'
    b'OHYyLjQiLz4KICAgICAgPC9nPgogICAgPC9nPgogIDwvZz4KICA8ZyBzdHJva2Utd2lkdGg9'
    b'IjEuNCIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTMwNi44IC0yMS4yKSBzY2FsZSguODcxMzYp'
    b'Ij4KICAgIDxwYXRoIGlkPSJreS1hIiBmaWxsPSIjZmZmIiBkPSJNOTg5LjcgMjMzdjkzLjRj'
    b'MCA4MS0zOC4zIDEwOC44LTg5LjYgMTMwLjgtNTEuMy0yMi05MC00OS44LTkwLTEzMC44di05'
    b'My41aDE3OS42eiIvPgogICAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0iTTkwMC4xIDMxMmM0'
    b'LjMgMCAxMS0zLjggMTYuOC05LjYgNi4yLTYuNyAxNi44LTkgMjcuOCAwIDExIDkuMSAxNy43'
    b'IDUuMyAyMy41IDAgNS43LTUuMiAxMC41LTcuMiAyMS41LTcuMlYyMzNIODEwdjYyLjNjMTEg'
    b'MCAxNS44IDIgMjEuNiA3LjIgNS43IDUuMyAxMi40IDkuMSAyMy41IDAgMTEuNS05IDIxLjUt'
    b'Ni43IDI4LjIgMCA1LjMgNS44IDEyIDkuNiAxNi44IDkuNnoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiMwYjUwYTAiIGQ9Ik05MDAuMSAzNjBjNS44IDAgMTcuMy02LjMgMjAuMS03LjcgMTAuNi02'
    b'LjMgMTguMi0uNSAyNC41IDIuNCA2LjcgMi44IDE5LjEgNi4yIDI2LjggMCA3LjctNi4zIDEy'
    b'LTUuOCAxNy4zLTUuOCAxLTcuMiAxLTE0LjQgMS0yMi41di01LjhjLTYuOC0xLjQtMTAuMS41'
    b'LTE3LjMgNi44LTcuMiA2LjItMTUuNCA0LjgtMjYgMS0xMC00LjQtMjAtMTItMzAuMSAwYTI0'
    b'LjIgMjQuMiAwIDAgMS0xNi4zIDhjLTcuMiAwLTEzLjQtNC43LTE2LjMtOC0xMC41LTEyLTIw'
    b'LjEtNC40LTMwLjIgMC0xMC41IDMuOC0xOS4yIDUuMi0yNi4zLTEtNi43LTYuMy0xMC4xLTgu'
    b'Mi0xNy4zLTYuOHY1LjhjMCA4LjEuNSAxNS4zIDEuNCAyMi41IDUuMyAwIDkuMi0uNSAxNi44'
    b'IDUuOCA3LjcgNi4yIDIwLjYgMi44IDI2LjkgMCA2LjctMi45IDE0LjMtOC43IDI0LjktMi40'
    b'IDIuOSAxLjQgMTMuOSA3LjYgMjAuMSA3LjZ6bTAgMjAuNmE1MSA1MSAwIDAgMCAyMy41LTcu'
    b'MmM5LjYtNS4zIDE2LjMtMyAyNS45IDEuOSAxMCA0LjggMTguMiAzLjMgMjQgMCAyLjgtMiA1'
    b'LjItNS44IDExLjQtNC4zLTIuOCAxMi03LjIgMjIuNS0xMi40IDMxLjFhMzIuNSAzMi41IDAg'
    b'MCAxLTI1LTEuOWMtMTAtNC44LTIyLjUtNy43LTI5LjItMy40YTM2IDM2IDAgMCAxLTE4LjIg'
    b'NS44Yy01LjMgMC0xMi0yLTE4LjItNS44LTYuNy00LjMtMTkuMi0xLjQtMjkuMiAzLjRhMzIu'
    b'NSAzMi41IDAgMCAxLTI1IDJjLTUuMi04LjctOS41LTE5LjMtMTIuNC0zMS4yIDYuMi0xLjUg'
    b'OC42IDIuNCAxMS41IDQuM2EyMy45IDIzLjkgMCAwIDAgMjMuNSAwYzEwLTQuOCAxNi43LTcu'
    b'MiAyNi4zLTJhNTEgNTEgMCAwIDAgMjMuNSA3LjN6bTAgNzYuNmExOTEuOSAxOTEuOSAwIDAg'
    b'MCA1MS4zLTI5LjdjLTMuOS0xLjQtNi4yLS41LTkuNi0yLjktMy40LTIuNC0xMy40LTMuMy0y'
    b'MiAxLjVhMzkgMzkgMCAwIDEtMzkuMyAwYy04LjctNC44LTE4LjctMy45LTIyLTEuNS0zLjQg'
    b'Mi40LTUuOCAxLjUtOS43IDNhMTg0LjcgMTg0LjcgMCAwIDAgNTEuMyAyOS42eiIvPgogICAg'
    b'PGcgc3Ryb2tlPSIjMDAwIj4KICAgICAgPHBhdGggZmlsbD0iI2Y5ZDA1MCIgZD0iTTg4Ny42'
    b'IDI1Ni40Yy41IDEtLjQgMy40IDAgNC4zIDEgMiAxIDMgMi40IDMuOWgzLjRjMTAuNSAwIDIz'
    b'LTQuMyAzMy41LTQuMyAxMC4xIDAgMTYuMyAzLjMgMjIgMy4zIDMuNCAwIDYuMy0yLjQgNi4z'
    b'LTQuOHMtMy44LTMuOC0xMi0zLjhjLTExLjUgMC0xNy43IDIuOS0yNy4zIDIuOS0xNC40IDAt'
    b'MTYuOC01LjMtMTYuOC03LjcgMC0yLjQgMi40LTUuNyAxMC4xLTUuNyAyLjQgMCA0LjMtLjUg'
    b'NS4zLTEuNS41LTEgMS45LTIuOSA0LjgtNC4zIDMuMy0yIDEwIDAgMTMuNC0yLjQgMCAyLTIu'
    b'OSA0LjgtNS4zIDUuOCA0LjgtMS41IDEwLTEuNSAxMSAyLjQtMi40LTEuNS02LjItLjUtNy42'
    b'IDAtMiAuNC0yLjkgMS00LjggMS40IDEuOS0uNSAyLjkgMy4zIDUuNyAzLjMtMi44IDIuNC03'
    b'LjYgMi40LTEyLjQuNS0xLjUtLjUtNS4zLTEuOS03LjctMS45LTQuOCAwLTcuNyAxLTcuNyAy'
    b'LjkgMCAyLjQgMyAzLjggMTEuNSAzLjggOC43IDAgMTMuNS0yLjQgMjYuNC0yLjQtMS0xLjQu'
    b'NS0yLjktMS40LTQuMyA0LjggMCAxMCAxLjQgMTIgNC44LS41LTMuNCAyLjMtNi4yIDEuNC05'
    b'LjEgMi45LjUgNS4zIDMuMyA1LjcgNS43IDAtMS40IDItMS40IDItMi44YTcuNCA3LjQgMCAw'
    b'IDEgMy44IDcuNmMxLjQtMi40IDIuOS0xLjQgMy44LTQuMyAxIDIgLjUgNy43LTIuOSA5LjYg'
    b'My0yIDcuMi0yIDEwLjEgMS40LTIuOS0uNC00LjMgMS01LjcgMS41QTQ0LjQgNDQuNCAwIDAg'
    b'MSA5NDggMjY3Yy03LjYtLjUtOC42LTItMTMuNC0yIDIuOS41IDguNiA2LjMgMTQgNi4zIDMu'
    b'MyAwIDUuNyAwIDcuMS0uNSAxLjQtLjUgMy44IDAgNS43IDEgMS41IDEuNCA0LjQgMi44IDYu'
    b'MyAyLjQtLjUgMS45LTEuNSAyLjgtMi45IDMuMyAyLjQgMS41IDEgMi40IDMuNCA0LjMtMSAw'
    b'LTIgMS0zLjQuNSAxLjQgMS40IDEuNCAzLjQgMi45IDQuMy0uNSAwLTIgLjUtMi45IDAgMS40'
    b'IDIgMCA0LjMgMS40IDUuMyAxLjUgMi0xLjQgNC4zLTMuOCAyLjQuNSAxLjQtMSAyLjktMi40'
    b'IDIuNHMtMi40LTItMi0yLjRjMC0uNSAwLS41LjYtMS0xIDEuNS0yLjkgMS41LTMuOSAxLS40'
    b'LS41LTEtMS0xLTEuNC0zLjMgMS00LjctMi00LjItMy40LjQtMS40IDMuMy0yIDQuMy0xLjQg'
    b'MSAuNCAxLjkgMSAyLjkgMCAxLS41IDEuNC0xLjUgMS40LTIuNCAwLTEuNS0xLjQtNS44LTcu'
    b'Ny01LjMtNy4yLjUtMTguNy0xLjQtMjQuNC0zLjQtLjUtLjQtMS0uNC0xLjUtMSAwIDItMS45'
    b'IDMtMS45IDQuOSAwIDIuNCAxIDQuMyAzLjkgNS4yLTEuNSAyLjQtMy45IDItNC44LjUgMCAx'
    b'LjUtMiAyLjQtMiA0LjMtLjQtMS0xLTEuNC0xLjQtMi40LTEuNCAzLjQtNS4zIDUuMy03LjIg'
    b'NC40LTIuNCAxLjktNS4yIDEuNC02LjItLjUtMS40IDEtMy40IDEtNC4zIDAgMCAxLjQtMSAx'
    b'LTEuNSAyLjkgMCAxLTEuOSAxLjQtMi44IDEtMS0uNi0xLjUtMi41LS41LTMuNC0xLjQgMS0y'
    b'LjkgMS0zLjggMCAwLTEgMC0yLjQgMS0zaC45Yy0xLS40LTIuNCAwLTMuNC0uNC0xLTEtMS0y'
    b'LS41LTIuOS41LS41IDItMS40IDMtLjVsLjQuNWMwLTEgLjUtMS45IDEtMS45IDEtLjUgMi4z'
    b'LS41IDMuOCAxIDEgMS40IDEuOSAxLjQgNC44IDEgMi40IDAgNi4yLTIuNSA5LTQuOS04LTEu'
    b'NC0zLjMtNi43LS45LTguNi0xLjktLjUtNC44LS41LTYuNy41LTEwIDUuMy0yMC42IDExLjUt'
    b'MjcuMyA5LjZhNiA2IDAgMCAwIDEgMi44Yy0xLjUgMC00LjQgMC01LjMtMS40LS41IDEtMS40'
    b'IDMuNC0uNSA1LjMtMS0xLTMuOC0yLTUuMy0yLjQgMSAxIDAgMi45LjUgNC4zLTEuNC0xLjQt'
    b'My44LTIuNC00LjgtMS40cy0yLjkgMS40LTQuMyAxYTcuNSA3LjUgMCAwIDEtMy44IDIuOGMw'
    b'LTEgMC0yLjQtLjUtMi45LS41IDEuNS0yIDMuNC0zLjggNC4zIDAtMSAwLTIuNC0uNS0zLjMg'
    b'MCAxLjktMy44IDIuOS00LjMgNC4zLjUtMS40LjUtMi45LjUtMy44YTcuMyA3LjMgMCAwIDEt'
    b'NC44IDMuM2MuNC0xIDEtMiAuNC0yLjktLjQgMi0zLjMgMy01LjcgMi40IDAgMS0yIDIuNC00'
    b'LjMgMS0xLjUtLjUtMi40LTItMS41LTIuOS0xLjkgMC0zLjgtMS45LTIuOC0zLjMgMC0uNS40'
    b'LTEgLjQtMS41LTEuNC0xLTEuOS0yLjktLjQtNC4zLjQtLjUgMS45LS41IDIuOC0uNSAwLTMu'
    b'OCAzLjQtMy44IDQuOC0xIDEgMS41IDMuOSAzLjkgNi4zIDMuNCAxIDAgMS40LS41IDIuNC0u'
    b'NWE0MyA0MyAwIDAgMCAxMi02LjJjLjQtMS40LjQtMi40LjQtMy4zLTEuOSAxLTMuOCAxLjkt'
    b'NC44IDMuM3YtMS40Yy0xLjQgMC0zLjgtLjUtNC44LS41LjUtLjUgMS0yLjkgMi0zLjQtMi40'
    b'LjUtNC44IDAtNi44LS40IDEtMSAxLTIuNCAxLjUtMy45LTEgLjUtMy40LS40LTUuMyAwIC41'
    b'LTEuNCAxLTMuMyAyLjQtMy44LTIgLjUtNC4zIDAtNi43LTEgMiAwIDIuOS0yLjQgNC4zLTIu'
    b'NC0zLjggMC00LjgtMS45LTYuNy0yLjggMS40LjQgMi40LTEgMy44LTEtMS40LS41LTMuOC0y'
    b'LjktMi44LTQuMy0uNS41LTEgMS40LTIgMi0xIC40LTIuOCAwLTQuMy0xLjUtMS0yLS41LTQu'
    b'MyAxLjUtNC44YTIuMyAyLjMgMCAwIDEtMS41LTMuOWMuNS0xIDIuNC0yLjMgMy40LTFsMS40'
    b'IDJjLS41LTEtLjUtMi45LS41LTQuMy41LTEuNCAxLjUtMS40IDMtMiAxLjMgMCAyLjMgMS41'
    b'IDIuMyAzIDAgMS40LjUgMi4zIDEgNC4zbC40LTJjMC0xLjkgMi40LTEuNCAzLjktMSAxLjQu'
    b'NiAxLjkgMy40IDAgNC45LTEgMS0uNSAyLjQuNSAzLjMgMy4zIDUuMyA5IDkuNiAxMy45IDEw'
    b'LjEgMC0yIDEtMy44IDIuNC01LjMgMC0xIC40LTIuNCAxLTMuMy40LTIuOSAxLjgtNC4zIDMu'
    b'Ny0zLjQtLjQtLjUtMS0xLTEtMS40LTEuNC0xLjUtMi44LTMuOS0xLjgtNS44IDEtMS45IDMu'
    b'OC0xLjQgNC44LS40LS41LTMgMi44LTUuMyAyLjgtNi44LjUgMS41IDEuNSAzLjQgMSA0Ljgu'
    b'NS0xLjkgMy44LTQuMyA2LjItNS4yLTEgMS40IDIgMy44IDEuNSA1LjIgMS0yLjQgNC44LTMu'
    b'OCA3LjYtMy44LTEgMS0xIDIuOS0xIDMuOCAxLjUgMCA0LS40IDQuOS0xLjkgMCAyLTEgMy45'
    b'LTIgNC44LjUtLjUgMi40LS41IDMuOS0uNS0xLjUgMS41LTEgMy0yLjQgMy45IDEuOS0xIDQu'
    b'My0xIDQuOCAxIDEgMS40LS41IDMuOC0xLjUgNS4yLTEgLjUtMS45IDEuNC0yLjQgMS40eiIv'
    b'PgogICAgICA8ZyBmaWxsPSJub25lIj4KICAgICAgICA8cGF0aCBkPSJNODU4IDI2Mi4yYy0z'
    b'LjQgMS40LTQuNCA0LjgtNC45IDYuNyIvPgogICAgICAgIDxwYXRoIGQ9Ik04NTcuNSAyNjUu'
    b'NWMtNC44IDMtNi44IDUuMy01LjggMTAuNm04LjEgMy45YzMtMSA0LjgtMiA3LjItNi4zIi8+'
    b'CiAgICAgICAgPHBhdGggZD0iTTg2NS42IDI3NS42Yy0xIDIgMCA1LjMtMS40IDYuN2E4Ljgg'
    b'OC44IDAgMCAwIDQuOC02LjciLz4KICAgICAgICA8cGF0aCBkPSJNODY2LjYgMjgwLjljMS45'
    b'LTEgNC44LTMuOSA2LjItNy4yLS41IDEuNCAwIDMuOC0xIDUuMyAyLjQtMi40IDMuNC0zLjkg'
    b'My45LTYuM2wuNCAyYzEtMSAyLTIgMi0zLjltLS4xIDEuNHYyLjRjMi0xLjQgMi41LTMuMyAy'
    b'LjUtNS43Ii8+CiAgICAgICAgPHBhdGggZD0iTTg4MCAyNzEuOGMyLjktMiAzLjMtNC44IDMu'
    b'My05LjFtMCA0LjhjMi0xLjUgMi40LTIuNCAyLjQtNi44bS02LjItMTIuOWMtMSAwLTIgLjUt'
    b'MiAyIDAgLjktMS40IDIuMy0xLjQgMy44LS40IDEuOS0xLjQgMi40LTIuOCAxLjktMS41LTEt'
    b'MS41LTEtMS41LTIuNCAwLTIgMi40LTIuNCAyLjQtNC4zLjUtMSAxLTIuNCAxLjUtMi40LTIu'
    b'NCAxLjQtNS44LjQtNi4zLTIuNCIvPgogICAgICAgIDxwYXRoIGQ9Ik04ODMuOCAyNDkuMmMt'
    b'MSAuNS0yLTEtMy4zLS40LS41IDAtMiAuNC0yLjQgMCIvPgogICAgICAgIDxwYXRoIGQ9Ik04'
    b'NzcuMSAyNTEuNmMuNS41IDIuOSAxLjUgNS4zLjUtMiAuNS0zLjQtMS45LTEuNS0zLjNtLTgu'
    b'MS0yYy0yIDAtMy40IDEuNS0yLjkgMyAuNSAxLjQgMi40IDEuNCAzLjguNG0tNC4zIDIwLjZj'
    b'LjUtLjUgMS0xLjQgMS0yIDEgMCAyLS40IDIuNC0uOSAxLjkgMCAzLjMtMS40IDMuOC0yLjgg'
    b'MSAwIDEuNS0yLjQgMi0zLjQuNC41IDEuNCAwIDEuOS0yIDEgLjYgMi40IDAgMi44LTEuNG0t'
    b'MTkuNi0zLjNjMCAuNS0xIDEuNC0yIDIgLjUuOSAwIDMuMy0uOSAzLjcuNSAxIDAgMi40LS41'
    b'IDMuNCAwIC41LjUgMiAuNSAyLjRtNC44LTIxLjFjLTEgMi40LS41IDUuMyAxLjQgNS44Ii8+'
    b'CiAgICAgICAgPHBhdGggZD0iTTg2Ni42IDI1M2MtLjUgMi41LS41IDUuOC0xIDcuMy0uNSAx'
    b'LTEuNCA0LjMgMi40IDUuMiA0LjMgMSA2LjcuNSA5LjEtNi43bTcuMiAxOC43YzAgLjUtLjUg'
    b'MS41LTEuNCAxLjVtNC43LTIuNGMwIDEtMSAyLjQtMS40IDIuOG00LjgtMy44YzAgMSAwIDIu'
    b'NC0xIDIuOW0tMjguMi0zMi42Yy40IDAgMSAxIDEuNCAxLjktMS40LTEtMi45IDEuNC0yIDIu'
    b'OW0tLjkgMy4zLTEuOSAxLjVtLjUgMi44Yy0uNSAwLTEgLjUtMS40LjVtLTIxLjYtOS4xYzAt'
    b'LjUgMC0uNS41LTFtLTQuOC0uNGMtLjUgMC0uNSAwLTEtLjVtMS40IDcuMmgxbS0yLjktMi45'
    b'YTUgNSAwIDAgMC0yLjgtMS40bTI5LjIgMTkuMmMtMy40IDIuOC00LjggNS4yLTUuMyA4LjZt'
    b'OC42LTYuM2ExMSAxMSAwIDAgMS0zLjggNC40bS0xNC44IDEwYTExIDExIDAgMCAxLTkuNi0x'
    b'LjRjLS41LS41LTEtLjUtMS41LTFtMjUuNC00LjJjLS40IDEuOC0xIDQuMi0xLjkgNC43IDMu'
    b'OS0yIDcuMi00LjggNy43LTkuMU04MjcuNyAyODljMS41LS41IDMgLjUgMy45LS41bTc5LjUt'
    b'MTUuM2MxIC41IDIuNCAxIDIuOSAxLjQuNS0xIDIuNC0yLjQgMy44LTIuOG0tNDAuNyAxMS41'
    b'Yy0uNS0yIC41LTQuMyAzLjQtNS4zbS0yMi4xIDEzLjRjLjUtMSAuNS0yLjQgMS0zLjNtLTIy'
    b'LjEgNC44Yy0uNSAxLTEuNCAxLjktMS40IDIuOG0tNS44LTEuOXMwLS41LjUtLjVjMS0uNCAy'
    b'LjQtMS40IDIuOS0yLjRtNjEuOC0zLjhjLTEgLjUtMS40IDAtMS45LS41bTEuNCAyLjlzLS40'
    b'LjUtMSAuNW0zLjQgMS45Yy0uNS41LTEgMS0xLjQgMW0xNS4zIDBjMS0uNSAxLjUtMS41IDIt'
    b'My40bS04LjIgMi45YzEuNC0uNSAyLjQtMS41IDMuOC0yLjltOS42LTFjMC0xIDAtMS45LjUt'
    b'Mi44bTM1IDcuMmMtMS0xLTEtMi40LjUtMy40IDEtLjUgMS40LTEgMi40LTEuNCIvPgogICAg'
    b'ICAgIDxwYXRoIGQ9Ik05MjQuNSAyNzZjLTcuNi0zLjMtNy4xLTcuNi0xMy40LTcuMW00Ny41'
    b'IDIyLjFjLjUuNCAwIDEuOSAwIDIuM200LjMtMi4zYy0uNSAxLjQtLjUgMS45LS41IDMuM005'
    b'MjYgMjQ1LjloLTRtLTM2LjMgMTYuM2MwIDEgMS41IDIuOSA1LjMgMi45LS41IDAtMS0uNS0x'
    b'LS41bS0yLjQtOC4yYy0uNC41LTEgMC0xIDAtLjktMSAuNi0yLjggMi0zLjgtMS40LjUtMi40'
    b'LjUtMy40LjUtMSAyLjktMy44IDQuMy01LjcgMi40LS41IDEuOS0yLjkgNC4zLTQuOCAzLjgt'
    b'Mi0xLTIuNC0yLjQtMi0zLjgtMi4zIDIuOC01LjIgMS02LjEgMC0uNS0xIDAtMy40IDEtNi4z'
    b'Ii8+CiAgICAgIDwvZz4KICAgICAgPHBhdGggc3Ryb2tlPSJub25lIiBkPSJNOTE4LjMgMjc0'
    b'LjZjLTEuNCAxLTIuOSAwLTQuMyAxLjUtMSAxIC41IDEuNCAxLjQgMS40LS40IDEuNS0uNCAy'
    b'IDIgMi0xIDEuNCAxLjkgMS45IDEuNCAzLjhhNC42IDQuNiAwIDAgMCAxLTQuOGMtLjUtMS41'
    b'LTMtMi40LTEuNS0zLjl6Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiMwNzMxNjMiIHN0cm9rZT0i'
    b'bm9uZSIgZD0iTTg3NC43IDI1OS4zYy0yLTEtMi40LTIuNC0yLTMuOC0uNCAxLTEuMyAxLjQt'
    b'Mi4zIDEuNC0yIDQuMy00LjMgOC4yLTcuMiA4LjItMy40LjQtMi45IDMuOC0uNSAzLjggNS4z'
    b'IDEgNy43LTEgMTItOS42em0tNDcuNC0xMS41YzEuNC0xLjQuNC0yLjktLjUtMy4zLTEuNS0u'
    b'NS00LjMgMC01LjggMi4zIDEuNS0uNCAzLS40IDMuNC41LjUgMSAxLjQgMiAyLjkuNXptMi40'
    b'LTguNmMzLjMgMCA0LjMuNSA0LjcgMS45LjUgMS0uNCAyLjQtMS40IDIuNC0xLjQgMC0yLjkt'
    b'MS0yLjQtMS40LjUtMSAuNS0yLjQtMS0zem05LjUgNy42YzIuNC41IDMuNC0xIDItMi44LS41'
    b'LTEuNS0yLTIuNC00LjQtMiAyLjQgMS41IDAgMy45IDIuNCA0Ljh6bS0xNy43IDguMmE0IDQg'
    b'MCAwIDAgNC44IDJjMS40LS42IDItMiAxLjQtMy0xLTEuNC0yLjQtMS45LTIuOCAwLTEgMi0y'
    b'LjQgMS41LTMuNCAxem03LjIgMjkuMmMtMS0xLjktMy44LTEuOS02LjIgMCAxLS41IDIuOCAw'
    b'IDMuMyAxczEuNSAxIDIgMWMuNC0uNSAxLjQtMSAuOS0yem0zLjgtMi44YzAtMi40LTMuMy0z'
    b'LTUuMi0yIDEgMCAyLjQgMSAyLjQgMiAuNCAxIDEuNCAxLjQgMS45IDEuNCAxLS41IDEuNC0x'
    b'IDEtMS40em0tNC44IDguNmMtMi44LS41LTQuMyAyLjktNC4zIDUuMi41LTEuNCAyLTIuMyAz'
    b'LjQtMS45IDEuNCAwIDEuOS0uNCAxLjktMS40LjUtMSAwLTEuNC0xLTJ6bS41IDguMWMxIC41'
    b'IDItLjUgMi40LTEuOSAwLTEgMi0xIDIuNC0uNSAxIC41IDEgMi40LS41IDMuNC0xIC41LTMu'
    b'MyAxLTQuMy0xem02Ni42LTE0LjRjLTEtLjQtMy4zLTEuNC01LjIgMCAxLjQtLjQgMi40LjUg'
    b'Mi44IDEuNSAwIDEgMS41IDEuNCAyIC41LjQtLjUgMS0xLjUuNC0yem0tNC4zIDMuNGMtMS45'
    b'LTEtNC4zIDEuNC00LjggMy40YTcgNyAwIDAgMSAzLjQtMS41YzEgLjUgMS45IDAgMS45LTEg'
    b'LjUtLjQuNS0uOS0uNS0uOXptMi41IDMuOWMtMS41IDAtMy40IDEuOS0zLjQgMy44LjQtMSAx'
    b'LjQtMS41IDIuNC0xIDEgMCAyLjQtLjUgMi40LTEuNCAwLTEtLjUtMS41LTEuNS0xLjV6bTQu'
    b'MiAzLjhjLTEtLjUtMi40IDAtMi40IDEuNHMwIDIuOS0uNCAzLjRjMS0xIDEuOS0xLjUgMi44'
    b'LTIgLjUtLjQgMS0xLjkgMC0yLjh6bTU0LjItNC4zYy0xLTEtMi40LS41LTIuOS40LS41IDEt'
    b'MSAzLjQgMCA1LjMgMC0xIDEtMi40IDItMi40IDEuNC0uNSAxLjgtMi40LjktMy4zem0yLjkg'
    b'MS45Yy0yIDEtMiA0LjMtLjUgNi4yIDAtMSAuNS0yLjQgMS40LTIuOSAxLjUgMCAyLTEuOSAx'
    b'LjUtMi44LTEtMS0yLS41LTIuNC0uNXptNS43IDEuOWMtMS0uNS0yIC41LTIgMS40LS40IDEu'
    b'NS42IDMuNCAyIDQuMyAwLTEgLjUtMS45IDEtMi40IDEuNC0xIDEtMi44LTEtMy4zem00LjMt'
    b'LjVjLTEgMC0xLjkgMS40LTEgMi45LjUgMSAxLjUgMS40IDMuNCAxLS41IDAtMS40LTEuNS0x'
    b'LTIgLjUtMSAwLTEuOS0xLjQtMS45eiIvPgogICAgPC9nPgogICAgPGcgaWQ9Imt5LWgiPgog'
    b'ICAgICA8cGF0aCBmaWxsPSIjZjlkMDUwIiBkPSJtODMxLjEgMzgzLjQgMjQtNzMuOCAyNCA3'
    b'My44LTYyLjktNDUuNUg4OTRaIi8+CiAgICAgIDxwYXRoIGZpbGw9IiMwMjQ5MTkiIGQ9Im04'
    b'MzUuOSAzNzYuNyA0OS44LTM2LjRoLTYxLjNsNDkuMyAzNi40LTE4LjYtNTguNHoiLz4KICAg'
    b'IDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5LWgiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9'
    b'IjEwMCUiIHg9IjkwLjEiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI2t5LWgiIHdpZHRoPSIx'
    b'MDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjQ1IiB5PSI1Mi4yIi8+CiAgICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIGQ9Ik05ODkuNyAyMzN2OTMuNGMwIDgxLTM4LjMgMTA4Ljgt'
    b'ODkuNiAxMzAuOC01MS4zLTIyLTkwLTQ5LjgtOTAtMTMwLjh2LTkzLjVoMTc5LjZ6Ii8+CiAg'
    b'PC9nPgo8L3N2Zz4K', 'KY')

KY = b64_KY
index.append("KY")
index.append("CYM")
index.append("Cayman Islands")
catalog["KY"] = KY
catalog["CYM"] = KY
catalog["Cayman Islands"] = KY
country["Cayman Islands"] = ('KY', 'CYM', 0)
lookup["KY"] = ('KY', 'CYM', 'Cayman Islands', 0)
lookup["George Town Cayman Islands"] = ('KY', 'CYM', 'Cayman Islands', 0)
lookup["CYM"] = ('KY', 'CYM', 'Cayman Islands', 0)
lookup["Cayman Islands"] = ('KY', 'CYM', 'Cayman Islands', 0)
details["KY"] = {"continent":"Americas","capital":"George Town","currency":"Cayman Islands Dollar","web":".ky","lang":"en-KY","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_KZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1reiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMGFiYzIiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxnIGZpbGw9IiNmZmVjMmQiPgogICAgPGcgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'LjQ4IDAgMCAuNDggMzQ1LjggMjAxLjYpIj4KICAgICAgPGNpcmNsZSByPSIxMzQuNiIvPgog'
    b'ICAgICA8ZyBpZD0ia3otYyI+CiAgICAgICAgPGcgaWQ9Imt6LWIiPgogICAgICAgICAgPHBh'
    b'dGggaWQ9Imt6LWEiIGQ9Ik0wLTE1Mi45YzgtLjEgMTEtNS4xIDExLTExLjEgMC04LTExLTQ2'
    b'LjEtMTEtNDYuMVMtMTEtMTcyLTExLTE2NGMwIDYgMyAxMS4xIDExIDExLjF6Ii8+CiAgICAg'
    b'ICAgICA8dXNlIHhsaW5rOmhyZWY9IiNrei1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAl'
    b'IiB0cmFuc2Zvcm09InJvdGF0ZSg5MCkiLz4KICAgICAgICAgIDx1c2UgeGxpbms6aHJlZj0i'
    b'I2t6LWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ic2NhbGUoLTEp'
    b'Ii8+CiAgICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiNrei1hIiB3aWR0aD0iMTAwJSIgaGVp'
    b'Z2h0PSIxMDAlIiB0cmFuc2Zvcm09InJvdGF0ZSgtOTApIi8+CiAgICAgICAgPC9nPgogICAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI2t6LWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHRyYW5zZm9ybT0icm90YXRlKDIyLjUpIi8+CiAgICAgICAgPHVzZSB4bGluazpocmVmPSIj'
    b'a3otYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoNDUp'
    b'Ii8+CiAgICAgICAgPHVzZSB4bGluazpocmVmPSIja3otYiIgd2lkdGg9IjEwMCUiIGhlaWdo'
    b'dD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoNjcuNSkiLz4KICAgICAgPC9nPgogICAgICA8'
    b'dXNlIHhsaW5rOmhyZWY9IiNrei1jIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFu'
    b'c2Zvcm09InJvdGF0ZSgxMS4zKSIvPgogICAgPC9nPgogICAgPGcgdHJhbnNmb3JtPSJ0cmFu'
    b'c2xhdGUoLTE3Mi44KSBzY2FsZSguNDgpIj4KICAgICAgPHBhdGggZD0iTTEwNzUuOCA2NTVj'
    b'LTMuNSA2LjMtNS42IDEzLjYtMTAgMTkuMy0xMy42LTEyLjMtMzMuMi0xMi01MC40LTEyLjct'
    b'MTQuMi0uOC0yOS42LTIuMS00MC42LTEyLjItMTEuNS05LjUtMjEtMjEuNy0zMy44LTI5LjRh'
    b'ODMuMiA4My4yIDAgMCAxLTMzLjEtMTUuM2MtMjAuMi0xNi41LTMxLjgtNDEtNTEuNi01OC0z'
    b'LjctMy42LTguMi02LjUtMTIuNC05LjYtNCAxLTIuMiA5LjYtNy4xIDUuMi0yLjctMi05LjQt'
    b'Mi4xLTEwIC42IDYgOCAxMi4xIDE3IDEzIDI3LjItNC4yLjQtMTEuNS0uOS0xMy41LjZhODQu'
    b'MyA4NC4zIDAgMCAwIDIwLjQgMjEuM2MtMy44LjYtMTEuMy4zLTEyLjggMS44YTU5IDU5IDAg'
    b'MCAwIDI2LjggMTQuN2MyIDIuOC0zLjEgOC4yIDEuMyAxMC42IDIuNSAxIDEwLjkgMi44IDUu'
    b'MSA1LjctNCAyLjYtMi41IDguOSAyLjYgOC43IDMuMiAxLjcgMTAuNCAyIDExIDUtMi45IDIu'
    b'OC0xMS43IDYuMi00LjIgOWE1MiA1MiAwIDAgMCAyMy4xIDYuN2MtNCAzLjQtOSA1LjMtMTMu'
    b'MSA4LjUgMTguNSAxMC45IDM5IDE4IDU5LjQgMjUgOCAyLjYgMTYuMyA1LjEgMjQuNyA2Ljct'
    b'MjQuNC0xLjQtNDgtOC42LTcwLjItMTguNS0xMS41LTUtMjMtOS45LTM0LjgtMTQuMiA1LjEt'
    b'Mi43IDExLjEtMy40IDE2LjUtNS43LTExLjItMi4yLTIzLjMtMy0zMy05IDEuNC0yLjggNy0y'
    b'LjkgMTAuMi00LjMgNi0xLjQgOS42LTMgMS4zLTMuNi04LjQtMi4zLTE4LTEuMy0yNS41LTYu'
    b'My41LTMgOC4zLTIgMTEuNC0zLjMgNC0uNyA4LjQtMS4zIDExLjYtNC0xMy01LjMtMzAtMS41'
    b'LTQwLjItMTMtMi4zLTQuNCA3LjMtLjkgMTAtMS42IDcgMCAxNC41IDIuMiAyMS4yLS42LTE5'
    b'LTguMy0zOS4zLTE2LTUzLjctMzEuNC0xLjYtMi41LTYuNC05LjMtMi41LTEwLjEgMTEuMiAx'
    b'LjUgMTkuMyAxMy43IDMxLjQgMTEuOCAxLjYtMi4xLTctNS42LTkuMi04LjdhMjI5LjQgMjI5'
    b'LjQgMCAwIDEtNDYuOC01MWMtLjgtNi43IDkuNS03LjcgMTIuMi0yLjYgMTMuNCAxMyAyNS41'
    b'IDI4IDQyLjIgMzYuOCA2IDIuOS0zLjQtMy40LTQuNi01LjdhMjk4LjcgMjk4LjcgMCAwIDEt'
    b'NDAuOS01Ny45Yy0yLTMuOC01LjEtMTAuNy43LTEyLjcgNS43LTIuOSAxMS41IDEgMTQuNCA2'
    b'IDExLjMgMTQuMyAxOS43IDMxLjMgMzMuOCA0My4yLTEyLTIzLjMtMjQuOS00OC0yNS4yLTc0'
    b'LjguMy01LjIuNi0xMyA3LjctMTIuOSA2LS45IDUgNi43IDcgMTAuMyA1LjggMTkuOCA4LjMg'
    b'NDEuMiAyMCA1OC42LTIuNS0xNC42LTYuNC0yOS43LTMuOC00NC42LjYtNSA2LTYuNCA5Ljct'
    b'My40IDIuOSA3IDMuNSAxNS45IDYuMSAyMy41YTIzNyAyMzcgMCAwIDAgOTMgMTI3LjIgMjQ0'
    b'LjcgMjQ0LjcgMCAwIDAgMTIzLjMgNDIuM2M0IC40IDggLjUgMTEuOS43bTEzNi40IDkxLjFj'
    b'LTcuMiA0LjQtMTIuOC0zLjQtMTguOC01LjctNC40IDIuNC00LjggMTAuMi04LjggMTQtNC44'
    b'IDUuNS0xMC44LTEuNi0xMC4zLTctNS44IDQuOS04LjcgMTYtMTggMTQuNC00LjUtMy42LTcu'
    b'OC0xMS4yLTExLjItMi41LTIuNyA0LjItMTAgMTAuMi0xMy45IDMuOC0xLjItNS42LTQtMTIu'
    b'Mi03LTMuMy0yLjIgNi40LTkgMTEtMTUuNCA4LjItMy42LTIuOSAyLjgtMTMuNy0xLjctMTMt'
    b'Ni44IDQuNi0xMC44IDE1LjctMjAuMyAxNC44LTMuNy00IDIuMy0xMS4xLTEuOC0xNS43LTQu'
    b'NyA2LjEtMTAgMTUuMS0xOC4zIDE1LjctNC0zLjIuMi0xMi41LTIuNC0xMy44LTguNCA1LTE3'
    b'LjQgMTQuMS0yOCAxMS4zIDQuMS0xNiAyMS41LTIxLjUgMzYtMjIuNyAyNS4xLTMuMSA1MS41'
    b'IDIuNiA3NS43LTYuNSAzLjktMi40IDEzLjMtNS43IDEwLTExLjItMy00LjQgNy43LTIuNyA4'
    b'LjctNy44LS42LTYuNCA1LTUuNSAxMC40LTYgMjQuNC0xLjEgNDguNSA0IDcyLjggNC45IDEu'
    b'OCAxMS44LTExLjMgMjAuMS0yMiAxNi41LTUgLjgtMTIuNS0xMS42LTExLTIuNi0xIDQuOC0u'
    b'NCAxMS00LjcgMTQuMm0tMjA3LjQtMjQuMmM1LjYgNS4xIDkuNi0xIDE0LjktMy4zYTE5NyAx'
    b'OTcgMCAwIDAgNDguMy0yNy4zYzkuMi03LjYgMTcuMi0xNy41IDI5LjYtMjAgMjQuMi03LjMg'
    b'NDkuOS02LjQgNzQuMS0xMy4yIDE4LjUtMjUuMiA0OS44LTM0LjMgNzYuMS00OC44IDUuOS0x'
    b'LjggOC4yLTYuNyAxMC0xMiAxMC0xNS45IDIzLjctMjkuOSAzOS45LTM5LjVhMzcuMiAzNy4y'
    b'IDAgMCAxIDI1LjQtNC42IDQyLjQgNDIuNCAwIDAgMS0xMy43IDI2LjVjNS45LS4xIDExLTMu'
    b'OCAxNi44LTMuNiAyIDEwLjYtOS40IDE2LjEtMTUuNSAyMi43IDMuNC44IDE2LjQgMS44IDku'
    b'MyA1LjItOSA2LjItMTkuMyAxMC41LTI3LjYgMTcuOCA3LjcgMS40IDguNiAzIC44IDUuOC00'
    b'LjMgMi44LTEyLjQgMy44LTEzLjIgOS40IDUuOCAzLjYtMi42IDctNS45IDguMi02LjIgMS41'
    b'LTEyLjggNC4yLTQuNSA5LTMuMSA0LjctOS45IDUuNy0xNS40IDUuMiAxLjcgNS40IDQuMSAx'
    b'MS40LTIuOCAxMy44YTEwNy43IDEwNy43IDAgMCAxLTUzLjYgMjIuNGMyNC41IDEuOCA0OS44'
    b'LTIuNyA3MC43LTE2IDIuOC0zLjMgMTcuMy02LjkgOS4yLTkuNi0zLjgtMS42LTEyLTMuNC0x'
    b'Mi42LTYuMyAxMS40LTcgMjUuNy00LjUgMzcuOS04LjYuMy00LTkuMy0yLjktMTIuOS0zLjgt'
    b'OC41LS43LTgtMi45LjItMy43IDEwLjQtMi44IDIyLjItMy4zIDMxLTEwLTcuMS0zLjQtMTYu'
    b'MS0uNS0yMy43LTMuMiAxMi45LTUuNiAyOC4xLTYuMiAzOS43LTE0LjcgNS4zLTUuOS02Ljgt'
    b'NC0xMC4zLTMuOS03LjEgMS4zLTEwLjQtMi4yLTIuMy01LjEgMTMuOS0xMC4zIDMxLjQtMTYu'
    b'OSA0MS4yLTMxLjcgMi4zLTMuMyA1LjQtMTMuMy0yLTkuOC05LjYgMy4zLTE4LjEgMTQuMS0y'
    b'OS4yIDEwLjggMjEuOC0xNi45IDQyLjQtMzYgNTcuMy01OS4zLjgtNi44LTkuOC03LjUtMTIu'
    b'NS0yLjItMTQgMTMuNC0yNi42IDI5LjMtNDQuNSAzNy44YTI4MC42IDI4MC42IDAgMCAwIDQz'
    b'LjYtNTYuNGMyLjctNiA5LjgtMTMuMyA2LTIwLTYuMy01LjItMTQuMS0uNC0xNy4zIDUuNy0x'
    b'MC45IDE0LjItMTkuMSAzMC43LTMzIDQyLjMgMTIuMS0yMy4zIDI0LjgtNDguMiAyNS03NSAw'
    b'LTUuNi0xLTEzLjgtOC42LTEyLjctNiAxLTQuNSAxMC03IDE0LjUtNS40IDE4LjQtOCAzOC4z'
    b'LTE5IDU0LjMgMi41LTE0LjkgNi44LTMwLjUgMy41LTQ1LjUtMS42LTYuOC0xMi41LTMuOS0x'
    b'MSAyLjgtMTMgNjUuOS01Ny4zIDEyMy41LTExNSAxNTYuOC0yNi41IDE1LTU2IDI0LjYtODYu'
    b'MiAyOS04IDEuNy0xNi44LjctMjQuNSAzLjUtMTguOCAxNC4zLTMwLjEgMzguNC01My44IDQ1'
    b'LjktMTAuNyA1LjMtMjQuNSA2LjQtMzIuMSAxNi4yYTguNiA4LjYgMCAwIDAtLjggNC4ybTUx'
    b'LjctMTAuM2MtMy42LjItNy4xLjYtMTAuNiAxLjctNC43LjctOS4yIDIuMy0xMy44IDNsLTEu'
    b'OS40LTMuMS4zYTEwLjkgMTAuOSAwIDAgMSAwIDUuMSA2IDYgMCAwIDEtMS40IDJjLS42Ljgt'
    b'MS4zIDEuNC0yLjIgMS44YTcgNyAwIDAgMS0yLjYuN2MtLjkgMC0xLjggMC0yLjctLjQtLjkt'
    b'LjMtMS43LS44LTIuNS0xLjVsLTIuOC41aC0yLjZsLTIuOC0xYTE2LjEgMTYuMSAwIDAgMS0y'
    b'LjYtMS4zYy0zLjQgMi03LjIgMy45LTkuMyA3LjRhMTEgMTEgMCAwIDAtMS42IDUuM2MtLjIg'
    b'Mi40LjQgNC44IDEuNCA3IC40LjYuNy0yLjMgMS44LTIuNyAxLjktMS42IDQuMy0yLjcgNi43'
    b'LTMuMyAyLTEgMS43IDAgLjkgMS42LS4yLjktMS4zIDQgLjIgMi40YTY1IDY1IDAgMCAxIDIx'
    b'LjYtNC4xYzEwLjYtMS4xIDIxLjItMS40IDMxLjgtMS41bDMwIC42YzQuOC4yIDkuNiAxLjIg'
    b'MTQuMy40IDEuMS0uMyAyLjktLjMgMy42LTEtMi4yLTEuMi00LjctMS4zLTctMS42aC0xOS4x'
    b'Yy01LjMtLjUtMTAuOC0uNi0xNS44LTIuNi0xLjQtLjUtMi42LTEuOC0zLjktLjRhMjQgMjQg'
    b'MCAwIDEtNS45IDEuM2MtMy41LjItNy0uNS0xMC4yLTEuOCAyLjMtMy4yIDUuMS02IDcuNy05'
    b'bC02LjItMS4zYzMuNy0yLjUgNy01LjQgMTAuNi04eiIvPgogICAgICA8Y2lyY2xlIGN4PSIx'
    b'MDIwIiBjeT0iNzIwLjkiIHI9IjIuNCIvPgogICAgICA8Y2lyY2xlIGN4PSIxMDE5LjgiIGN5'
    b'PSI3MjAuNSIgcj0iMSIgc3Ryb2tlPSIjZmZlYzJkIiBzdHJva2Utd2lkdGg9Ii40Ii8+CiAg'
    b'ICA8L2c+CiAgICA8ZyB0cmFuc2Zvcm09InNjYWxlKC40OCkiPgogICAgICA8ZyBpZD0ia3ot'
    b'ZiI+CiAgICAgICAgPGcgaWQ9Imt6LWUiPgogICAgICAgICAgPHBhdGggZD0iTTEyMCA3M3Mt'
    b'OS42LTguMi0xMi45LTQuMWMtNS4yIDYuNSAxNi4yIDM5IDE2LjIgNTAuNCAwIDE4LjgtMTIu'
    b'NiAyMy45LTI4IDI2LjUtMTAuNCAxLjgtMjcuMy0uNy0yNy4zLS43IDMuMi00LjMgNS4zLTUu'
    b'NiAxMC42LTUuOS02LTMtMTItOS44LTEyLTIwLjMgMC0xNi4xIDYuNi0yMi44IDYuNi00MUM3'
    b'My4yIDY4IDY1IDU1IDY1IDU1YzE0LjYgMS41IDIxLjggMTUgMTcuNyAyNS44YTcgNyAwIDAg'
    b'MCA2LjMtMS45YzEgMy0uNiA2LjUtMi45IDkuNSAxLjggMSAzLjIuNCA2LS4yLS4yIDMtMiA2'
    b'LjQtNi42IDkuNSAxMy4yLTMuNCAyMS4yIDUuNyAyMS4yIDE1LjMgMCA3LjMtNSAxMi41LTEw'
    b'IDEyLjUtMS42IDAtNC0uNy01LjMtMS43LTEgMi0uNCA0LjcuNSA2LjctMy42LTEtNi0zLjIt'
    b'NC4zLTcuNy0yLjgtLjItNS0xLjItNi41LTMgMS41LTIgMy44LTMgNi41LTMtMi00LjIuMy02'
    b'LjUgMy42LTguNCAwIDAtMi4xIDguNCAzLjIgOC40IDIuNCAwIDQuNi0uNyA0LjYtNC4zIDAt'
    b'My4xLTIuNy03LjQtOS03LjEtNi4yLjMtMTEuMyA0LjMtMTEuMyAxNC4zIDAgOS4yIDcuNSAx'
    b'My44IDE3LjMgMTQgOC44LjQgMTUuNS00LjQgMTUuNS0xMy41QzExMS41IDEwOCA5NCA4MC40'
    b'IDk0IDY5LjZjMC04LjEgNy4yLTEyLjcgMTQuNC0xMi43IDkuMiAwIDE3IDkuMiAxNyA5LjJs'
    b'LTUuNCA2Ljh6Ii8+CiAgICAgICAgICA8cGF0aCBpZD0ia3otZCIgZD0iTTEyMiAyOTIuMWMw'
    b'IDIwLjMtMTguMiAzMC43LTMyLjUgMzAuNy0xOS4yIDAtMjkuNS0xMS41LTI5LjUtMjYuNiAw'
    b'LTguNSAxLjYtMTMuOSA1LjUtMjJsNDQuMi05MS43YTI3IDI3IDAgMCAwIDItMTIuMmMwLTgu'
    b'Mi04LTE0LjktMTYuMy0xNS03LjYtLjMtMTYgNy0xNiAxNS4zIDAgMTAuMSA1LjMgMTQuNiAx'
    b'MC43IDE0LjYgNi42IDAgOS4yLTIuNyA5LjItNy40IDAtMy4yLTEuNS00LjYtMy44LTQuNi01'
    b'LjcgMC00IDcuNi00IDcuNmE1LjIgNS4yIDAgMCAxLTMuOS03IDEwLjIgMTAuMiAwIDAgMS01'
    b'LjUtMy4zYzEuNS0xLjUgMy4zLTIuNiA1LjUtMy0xLjMtNC40LjUtNi41IDQuMy03LjVhNy42'
    b'IDcuNiAwIDAgMC0uNSA0LjhjNi0xLjggMTUuMyAxIDE1LjMgMTEuNHMtNy4yIDE5LjEtMjAu'
    b'NyAxN2MzLjIgMS41IDQuOCA0LjYgNS4yIDguMS0yLjUtMS01LjItMS01LjItMSAxLjYgMi43'
    b'IDMuOCA1IDMuNyAxMC42LTIuNS0xLjItNC45LTMuMy04LTIgNSAxMC0xLjIgMjMuNi0xNyAy'
    b'Ni44IDUuOC02LjggOC42LTE0IDguNi0yMS4zIDAtMjMuNS02LjUtMjcuNC02LjUtNDMuOGEy'
    b'NCAyNCAwIDAgMSAxMC41LTE5LjJ2LjNBMTQgMTQgMCAwIDEgNjggMTQ1YTYyIDYyIDAgMCAx'
    b'IDM0IC4zIDI1IDI1IDAgMCAxIDE4IDEyIDM2IDM2IDAgMCAxIDAgMjguOWMtNi4zIDEzLTM1'
    b'LjcgNzUuNi00NC45IDk1LjItMiA0LjItMy4xIDguNi0zLjEgMTMuNCAwIDEyIDExIDE2LjIg'
    b'MTcuMiAxNi4yIDcuNSAwIDE1LjItNS43IDE1LjItMTIuOCAwLTQuNS0yLjUtNy4zLTYtNy4z'
    b'LTguNSAwLTggNy4yLTYuMyAxMS44LTUuMy0yLjQtOC4zLTYuNi03LjUtMTFhMTQgMTQgMCAw'
    b'IDEtOC40LTQuOGMyLTIuNiA0LjYtNC42IDguNC00LjctMS43LTYuOSAzLTkuOCA3LjUtMTEu'
    b'NC0xLjQgNS0yLjQgMTAuOSA2LjMgMTAuOSA2LjMgMCAxMS4yIDEgMTQuMSA1LjJsLjctMjdj'
    b'LjQtOC4xLTEwLjgtOC0xOC01LjUgMi43LTkuMyA4LjItMTQuNCAyMS0xMy4xYTEwIDEwIDAg'
    b'MCAxLTYuNC05LjhjMC03LjYgNi4yLTE2IDEwLjItMTguNWwyIDc5eiIvPgogICAgICAgICAg'
    b'PHVzZSB4bGluazpocmVmPSIja3otZCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoMSAwIDAgLTEgMCA2NDUpIi8+CiAgICAgICAgPC9nPgogICAgICAg'
    b'IDx1c2UgeGxpbms6aHJlZj0iI2t6LWUiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC0xIDAgMCAxIDI0MCAwKSIvPgogICAgICA8L2c+CiAgICAgIDx1'
    b'c2UgeGxpbms6aHJlZj0iI2t6LWYiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDEgMCAwIC0xIDAgMTAwMCkiLz4KICAgIDwvZz4KICA8L2c+Cjwvc3Zn'
    b'Pgo=', 'KZ')

KZ = b64_KZ
index.append("KZ")
index.append("KAZ")
index.append("Kazakhstan")
catalog["KZ"] = KZ
catalog["KAZ"] = KZ
catalog["Kazakhstan"] = KZ
country["Kazakhstan"] = ('KZ', 'KAZ', 0)
lookup["KZ"] = ('KZ', 'KAZ', 'Kazakhstan', 0)
lookup["Astana Kazakhstan"] = ('KZ', 'KAZ', 'Kazakhstan', 0)
lookup["KAZ"] = ('KZ', 'KAZ', 'Kazakhstan', 0)
lookup["Kazakhstan"] = ('KZ', 'KAZ', 'Kazakhstan', 0)
details["KZ"] = {"continent":"Asia","capital":"Astana","currency":"Tenge","web":".kz","lang":"kk | ru","tz":"+05:00 | +06:00","altname":""}
#----------------------------------------------------------------------
b64_LA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWxhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImxhLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgY2xpcC1wYXRoPSJ1cmwoI2xhLWEpIj4KICAgIDxwYXRoIGZpbGw9IiNjZTExMjYiIGQ9'
    b'Ik0tNDAgMGg3MjB2NDgwSC00MHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDI4NjgiIGQ9Ik0t'
    b'NDAgMTE5LjNoNzIwdjI0MS40SC00MHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00'
    b'MjMuNCAyNDBhMTAzLjQgMTAzLjQgMCAxIDEtMjA2LjggMCAxMDMuNCAxMDMuNCAwIDEgMSAy'
    b'MDYuOCAweiIvPgogIDwvZz4KPC9zdmc+Cg==', 'LA')

LA = b64_LA
index.append("LA")
index.append("LAO")
index.append("Laos")
catalog["LA"] = LA
catalog["LAO"] = LA
catalog["Laos"] = LA
country["Laos"] = ('LA', 'LAO', 0)
lookup["LA"] = ('LA', 'LAO', 'Laos', 0)
lookup["Vientiane Laos"] = ('LA', 'LAO', 'Laos', 0)
lookup["LAO"] = ('LA', 'LAO', 'Laos', 0)
lookup["Laos"] = ('LA', 'LAO', 'Laos', 0)
details["LA"] = {"continent":"Asia","capital":"Vientiane","currency":"Lao Kip","web":".la","lang":"lo | fr | en","tz":"+07:00","altname":""}
#----------------------------------------------------------------------
b64_LB = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWxiIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImxiLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1LjMgMGg2ODIu'
    b'NnY1MTJILTg1LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBjbGlwLXBh'
    b'dGg9InVybCgjbGItYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDgwKSBzY2FsZSguOTM3NSki'
    b'PgogICAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCI+CiAgICAg'
    b'IDxwYXRoIGZpbGw9IiNFRTE2MUYiIGQ9Ik0tMTI4IDM4NGg3Njh2MTI4aC03Njh6bTAtMzg0'
    b'aDc2OHYxMjhoLTc2OHoiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTS0xMjggMTI4'
    b'aDc2OHYyNTZoLTc2OHoiLz4KICAgIDwvZz4KICAgIDxwYXRoIGZpbGw9IiMwMEE4NTAiIGQ9'
    b'Ik0yNTIuMSAxMzBjLTcuOCAxNS41LTEzIDE1LjUtMjYgMjYtNS4yIDUuMS0xMyA3LjctMi42'
    b'IDEzLTEwLjUgNS4xLTE1LjcgNy43LTIwLjkgMTguMWwyLjYgMi42czEwLTQuOCAxMC40LTIu'
    b'NmMxLjggMi4xLTEzIDEwLTE0LjkgMTEuM2wtMTEgN2MtMTMuMSAxMC4zLTIxIDcuNy0yOC43'
    b'IDIzLjNsMjYtMi42YzUuMiAxOC4yLTEzIDIwLjgtMjYgMjguNmwtMjAuOSAxM2M1LjMgMTgu'
    b'MiAyMC45IDcuOCAzMy45IDIuNmwyLjYgMi42djUuMmwtMjYgMTNzLTMwLjggMTcuNi0zMS4z'
    b'IDE4LjJjLS4yIDEgMCA1LjIgMCA1LjIgMTAuNCAyLjYgMjYgNS4yIDM2LjUgMCAxMy01LjIg'
    b'MTUuNi0xMC40IDMxLjItMTAuNGExMDAuNiAxMDAuNiAwIDAgMS01MiAyMC44djEwLjRjMTUu'
    b'NiAwIDI2IDAgMzktMi42bDMzLjgtMTAuNGM3LjggMCAxNS43IDcuOCAxMyAxNS42LTcuNyAy'
    b'OC42LTM5IDIzLjQtNDkuNCA0Ni44TDIxMyAzNjljMTAuNC01LjIgMjAuOC0xMC4zIDMzLjgt'
    b'Ny43IDE1LjYgNS4yIDE1LjYgMTUuNiAzNi40IDIwLjhsLTUuMi0xM2M1LjIgMi42IDEwLjQg'
    b'Mi42IDE1LjcgNS4yIDEzIDUuMiAxNS42IDEwLjQgMzEuMiA3LjgtMTMtMTUuNi0xNS42LTEz'
    b'LTI2LTIzLjQtMTAuNC0xNS42LTE1LjctMzkgMC00MS42bDE4LjIgNS4yYzE4LjIgMi42IDE4'
    b'LjItMi42IDQ0LjIgNy44IDE1LjcgNS4yIDIwLjkgMTMgMzkgNy44LTcuNy0xOC4yLTM2LjMt'
    b'MzEuMi01NC42LTM2LjQgMjAuOS0xMyAxNS42IDUuMiA0NC4zLTIuNnYtNS4yQzM2OS4zIDI3'
    b'OCAzNjEuNCAyNjUgMzMyLjggMjY1bDQ0LjMtNS4ydi01LjJzLTQzLjctMTEuNC00NC43LTEx'
    b'LjljLjMtMS4zIDEuNC0zLjMgNC4zLTQuNSA4LjMgNS40IDMzLjMgNC44IDM0LjggNC43LS44'
    b'LTYuNC0xMi43LTExLjctMjMtMTYuOSAwIDAtNDQuNy0yNy41LTQ0LjktMjkuOS45LTcgMTgu'
    b'MyAxLjEgMzcgNi41LTUuMi0xMC40LTE1LjYtMTUuNi0yNi0xOC4ybDE1LjYtMi42Yy0xMC40'
    b'LTIzLjQtMzYuNC0yMC44LTUyLTMxLjItMTAuNS03LjgtMTAuNS0xMy0yNi4xLTIwLjd6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2Zm'
    b'ZiIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJv'
    b'a2Utd2lkdGg9IjMuMiIgZD0iTTIyNCAzMDNjMS45LTYuMSA0LjQtMTEuNi03LjItMTYuOS0x'
    b'MS42LTUuMyA1LjggMjEuMSA3LjIgMTd6bTEzLjctMTIuM2MtMi4zLjMtMy42IDguOCAxLjEg'
    b'MTEuMiA1LjIuOCAxLTExLjEtMS4xLTExLjJ6bTEzLjUtMWMtMi40LjgtMi41IDEyLjggNiAx'
    b'MC42IDguNi0yLjEgMC0xMS41LTYtMTAuNXpNMjY3IDI1OWMxLjgtMy0uMS0xNS03LjQtMTAt'
    b'Ny40IDUuMSA1IDEwLjggNy40IDEwem0tMTYtMTBjMi4zLS45IDIuNS04LjMtNC02LjMtNi4z'
    b'IDEuOSAyLjMgNy44IDQgNi4zem0tMTQuNCAyLjlzLTQuNS02LjItOC00LjljLTQuMyA0LjIg'
    b'OC4zIDUgOCA0Ljl6TTE4NyAyNzEuN2MxLjkuMiAxNi0yLjMgMjAuOS03LjggNC45LTUuNS0y'
    b'NS4xIDIuMy0yNS4xIDIuNCAwIC4xIDIuOCA0LjkgNC4yIDUuNHptMTQxLjEtMzVjLjctMS4z'
    b'LTcuNS03LjEtMTIuNC00LjgtMS4zIDQuMyAxMi40IDUuNyAxMi40IDQuOHptLTI3LjgtMTRj'
    b'MS42LTIuMi0zLjUtMTEuMy0xMy43LTYuMi0xMC4yIDUgMTAuNyA5LjggMTMuNyA2LjN6bS0z'
    b'Mi4xLTUuM3MyLjUtOC4yIDguNi02LjZjNyA1LjMtOC4zIDYuOS04LjYgNi42em0tNi02LjJj'
    b'LTEtMi4zLTcuMy0xLTE0LjYgMy45LTcuNCA0LjcgMTYuOCAxLjQgMTQuNi00em0xOC43LTIy'
    b'LjFzNi41LTMgOC41IDBjMi43IDQuMy04LjYgMC04LjUgMHptLTUuNS0yLjljLTEuMy0yLjYt'
    b'OC41LTIuOS04LjMgMS0xLjIgMyA5LjQgMi40IDguMy0xem0tMTcuMiAwYy0uNy0xLjUtMTEg'
    b'MC0xNCA2LjIgNSAyLjQgMTYuMy0yLjMgMTQtNi4yem0tMjIgNi4zcy0xMy40IDguMy0xNC4z'
    b'IDE0LjNjLjQgNS4yIDE2LjgtOS40IDE2LjgtOS40czEuNC01LjgtMi40LTQuOXptLTE0Ljkt'
    b'Ny41Yy40LTEuNyA2LjctNS42IDcuMi01LjMuNSAxLjctNS4xIDYuMy03LjIgNS4zem00LjMg'
    b'MzEuNmMuMy0yLjUtMTYtMi4zLTkuOSA1LjIgNS4yIDYuMyAxMS00LjEgOS45LTUuMnptLTE1'
    b'IDEwLjdjLS44LTEuNi0yLTYtNC4yLTYuNC0xLjkgMC0xMS43IDItMTIuNSAzLjYtLjQgMS4z'
    b'IDQuMSA5LjQgNS42IDkuNiAxLjguNyAxMC45LTYgMTEuMi02Ljh6bTg4LjQgNTUuMmMuNS0x'
    b'LjggMTcuMy03LjUgMjMtMiA2LjggOS4zLTIzLjQgNS0yMyAyem00NiAxMC45YzMuNy02LjIt'
    b'MTEuMy0xMy42LTE3LjYtNi41IDIuMiA4LjUgMTQuNiAxMS42IDE3LjYgNi41eiIvPgogIDwv'
    b'Zz4KPC9zdmc+Cg==', 'LB')

LB = b64_LB
index.append("LB")
index.append("LBN")
index.append("Lebanon")
catalog["LB"] = LB
catalog["LBN"] = LB
catalog["Lebanon"] = LB
country["Lebanon"] = ('LB', 'LBN', 0)
lookup["LB"] = ('LB', 'LBN', 'Lebanon', 0)
lookup["Beirut Lebanon"] = ('LB', 'LBN', 'Lebanon', 0)
lookup["LBN"] = ('LB', 'LBN', 'Lebanon', 0)
lookup["Lebanon"] = ('LB', 'LBN', 'Lebanon', 0)
details["LB"] = {"continent":"Asia","capital":"Beirut","currency":"Lebanese Pound","web":".lb","lang":"ar-LB | fr-LB | en | hy","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_LC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWxjIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiM2NWNmZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0ibTMxOC45IDQyIDE2Mi43IDM5NS4zLTMyMi42LjlMMzE4Ljkg'
    b'NDJ6Ii8+CiAgICA8cGF0aCBkPSJtMzE5IDk2LjUgMTQwLjggMzQwLTI3OSAuOEwzMTkgOTYu'
    b'NXoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmNlMDAiIGQ9Im0zMTguOSAyNDAuMSAxNjIuNyAx'
    b'OTcuNi0zMjIuNi41IDE1OS45LTE5OC4xeiIvPgogIDwvZz4KPC9zdmc+Cg==', 'LC')

LC = b64_LC
index.append("LC")
index.append("LCA")
index.append("Saint Lucia")
catalog["LC"] = LC
catalog["LCA"] = LC
catalog["Saint Lucia"] = LC
country["Saint Lucia"] = ('LC', 'LCA', 0)
lookup["LC"] = ('LC', 'LCA', 'Saint Lucia', 0)
lookup["Castries Saint Lucia"] = ('LC', 'LCA', 'Saint Lucia', 0)
lookup["LCA"] = ('LC', 'LCA', 'Saint Lucia', 0)
lookup["Saint Lucia"] = ('LC', 'LCA', 'Saint Lucia', 0)
details["LC"] = {"continent":"Americas","capital":"Castries","currency":"East Caribbean Dollar","web":".lc","lang":"en-LC","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_LI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1saSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMDJiN2YiIGQ9Ik0wIDBoNjQwdjI0'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNjZTExMjYiIGQ9Ik0wIDI0MGg2NDB2MjQwSDB6Ii8+'
    b'CiAgPGcgZmlsbD0iI2ZmZDgzZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWNhcD0icm91'
    b'bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMiIgdHJhbnNmb3Jt'
    b'PSJzY2FsZSguOCkiPgogICAgPGcgaWQ9ImxpLWEiPgogICAgICA8cGF0aCBzdHJva2U9Im5v'
    b'bmUiIGQ9Im0yMTYuNCAxMjIuMy0xLjkgNjIuNWgtNjMuNGMtNy44LTE1LjItMTQuMi0yOC0x'
    b'NC4yLTQ1LjUgMC0xNC42IDExLjUtMjYuMiAyOC0yNi4yIDE3LjUgMCAzNi44IDUuOSA1MS41'
    b'IDkuMnoiLz4KICAgICAgPGcgc3Ryb2tlLXdpZHRoPSIxLjUiPgogICAgICAgIDxwYXRoIGQ9'
    b'Ik0xNDQuNSAxMjUuMnYzNm01LTM5Ljd2NDhtNS4yLTUwLjV2NTcuMm01LTU4LjR2NDQuOW01'
    b'LjEtNDUuMXY0NS4zbTUuMS00N3Y0N201LjEtNDd2NDdtNS4xLTQ2LjV2NDdtNS4xLTQ2LjV2'
    b'NDYuOW01LjEtNDR2NDdtNS00Ni41djUyLjltNS4yLTUyLjl2NDdtNS00N3Y0NyIvPgogICAg'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMDAiIGQ9Ik0xNzYuNCAxMThjMTAuOCAxLjcgMzQuNCAxMi44'
    b'IDMxLjcgMjcuNy0zLjggMjEuMi0xNi4yIDEyLjctMzIuNiA5LjdsLTEyLjQgNC4xYy00LjUg'
    b'NC41LTExIDguNy0xNS40IDMuMmgtNy40djI4LjhoODEuNFYxMjJ6Ii8+CiAgICAgIDwvZz4K'
    b'ICAgICAgPGNpcmNsZSBjeD0iMjEyLjgiIGN5PSIxMTMiIHI9IjQuOSIvPgogICAgICA8Y2ly'
    b'Y2xlIGN4PSIyMDEuNyIgY3k9IjExMC4zIiByPSI0LjkiLz4KICAgICAgPGNpcmNsZSBjeD0i'
    b'MTkwLjQiIGN5PSIxMDcuNSIgcj0iNC45Ii8+CiAgICAgIDxjaXJjbGUgY3g9IjE3OS4xIiBj'
    b'eT0iMTA1LjYiIHI9IjQuOSIvPgogICAgICA8Y2lyY2xlIGN4PSIxNjcuOCIgY3k9IjEwNC41'
    b'IiByPSI0LjkiLz4KICAgICAgPGNpcmNsZSBjeD0iMTU2LjgiIGN5PSIxMDUuMSIgcj0iNC45'
    b'Ii8+CiAgICAgIDxjaXJjbGUgY3g9IjE0Ni4yIiBjeT0iMTA4LjciIHI9IjQuOSIvPgogICAg'
    b'ICA8Y2lyY2xlIGN4PSIxMzcuMyIgY3k9IjExNS4zIiByPSI0LjkiLz4KICAgICAgPGNpcmNs'
    b'ZSBjeD0iMTMxIiBjeT0iMTI0LjQiIHI9IjQuOSIvPgogICAgICA8Y2lyY2xlIGN4PSIxMjcu'
    b'OSIgY3k9IjEzNS4yIiByPSI0LjkiLz4KICAgICAgPGNpcmNsZSBjeD0iMTI4IiBjeT0iMTQ2'
    b'LjMiIHI9IjQuOSIvPgogICAgICA8Y2lyY2xlIGN4PSIxMzAuMiIgY3k9IjE1Ny4yIiByPSI0'
    b'LjkiLz4KICAgICAgPHBhdGggZD0ibTIxNSAxMTkuNS0uNSA2LjVjLTEyLjMtMi0yOS43LTgu'
    b'OC00Ni04LjgtMTUgMC0yNi42IDYtMjYuNiAyMS4yIDAgMTQuOSA2LjMgMjguNSAxNC43IDQy'
    b'LjNsLTguNyA0Yy03LjgtMTUtMTQuMy0yOC0xNC4zLTQ1LjQgMC0xNC42IDExLjUtMjkgMzEu'
    b'My0yOSAxNy41IDAgMzUuNCA2IDUwLjEgOS4yeiIvPgogICAgPC9nPgogICAgPHVzZSB4bGlu'
    b'azpocmVmPSIjbGktYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoLTEgMCAwIDEgNDQ0IDApIi8+CiAgICA8cGF0aCBkPSJtMjIyIDUzLjEtNS4yIDku'
    b'NyA1LjIgOS42IDUuMS05LjZMMjIyIDUzem0wIDI0LjQtNS4yIDkuNiA1LjIgOS43IDUtOS44'
    b'LTUuMS05LjZ6TTIwMy42IDc1bDguMSA1LjEgOC4xLTUuMS04LTUuMi04LjIgNS4yem0yMC41'
    b'IDAgOC4xIDUuMSA4LjItNS4xLTguMi01LjItOCA1LjJ6Ii8+CiAgICA8Y2lyY2xlIGN4PSIy'
    b'MjIiIGN5PSI3NS4xIiByPSIzLjkiLz4KICAgIDxjaXJjbGUgY3g9IjIyMiIgY3k9IjEwMCIg'
    b'cj0iMTAuNSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9'
    b'Ik0yMTkuMyA4OS45djYuNmE2Mi41IDYyLjUgMCAwIDAtNy40LjhtMjAuMiAwYTYyLjEgNjIu'
    b'MSAwIDAgMC03LjUtLjh2LTYuNm0tMTIuOCAxMi43YTYxLjQgNjEuNCAwIDAgMSAxMC4yLS45'
    b'YzMuNCAwIDYuOC4zIDEwIC45Ii8+CiAgICA8cGF0aCBkPSJNMjExLjggMTE3LjdjLTEgMTct'
    b'MyAzNC41LTkuNyA0Ny4xbDEwLjgtNC40YzMuOC0xNC4zIDQuNi0zMi44IDUuNy00MS42bC02'
    b'LjgtMS4xem0yMC40IDAtNi45IDEuMWMxLjIgOC44IDIgMjcuMyA1LjcgNDEuNmwxMC44IDQu'
    b'NGMtNi42LTEyLjYtOC42LTMwLTkuNi00Ny4xeiIvPgogICAgPHBhdGggZD0iTTIyMiAxNTQu'
    b'N2MtMTMgMC0yMi41IDYtMjMgMjEuNi0zLjItNS42LTE2LjUtMjMtMjktMjAuNy03LjQgMS40'
    b'LTE0IDExLjctMTIuOCAyMy40LTYuMi0xNy42LTI0LjEtMjAuNS0zNy4zLTEwIDExLjcgOS41'
    b'IDE2LjkgMzcuOCAyNi43IDUwaDE1MC43YzkuOC0xMi4yIDE1LTQwLjUgMjYuNy01MC0xMy4x'
    b'LTEwLjUtMzEuMS03LjYtMzcuMiAxMCAxLTExLjctNS41LTIyLTEzLTIzLjQtMTIuNC0yLjMt'
    b'MjUuNyAxNS4xLTI4LjkgMjAuNy0uNS0xNS41LTEwLTIxLjYtMjMtMjEuNnoiLz4KICAgIDxn'
    b'IHN0cm9rZS13aWR0aD0iMS41Ij4KICAgICAgPHBhdGggZmlsbD0iIzAwMCIgZD0iTTI5Ny4x'
    b'IDIxOWMwIDUuNi0zMy42IDExLjctNzUuMSAxMS43cy03NS4yLTYtNzUuMi0xMS43YzAtNS41'
    b'IDMzLjctOC41IDc1LjItOC41IDQxLjQgMCA3NS4xIDMgNzUuMSA4LjV6Ii8+CiAgICAgIDxj'
    b'aXJjbGUgY3g9IjIyMiIgY3k9IjExNC40IiByPSIzLjUiLz4KICAgICAgPGNpcmNsZSBjeD0i'
    b'MjIyIiBjeT0iMTIyIiByPSIzLjciLz4KICAgICAgPGNpcmNsZSBjeD0iMjIyIiBjeT0iMTMw'
    b'LjIiIHI9IjQuMSIvPgogICAgICA8Y2lyY2xlIGN4PSIyMjIiIGN5PSIxMzkuMyIgcj0iNC43'
    b'Ii8+CiAgICAgIDxjaXJjbGUgY3g9IjIyMiIgY3k9IjE0OS40IiByPSI1LjEiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iIzAwMCIgc3Ryb2tlPSJub25lIiBkPSJNMjIwIDE1OS4yYy0uNiAwLTEu'
    b'MS41LTEgMS40bC42IDQuM2MuMiAxLjUgMSAxIDEuMyAwIC4yLTEuMi4xLTIgLjItNC4xIDAt'
    b'MS4xLS42LTEuNi0xLjItMS42em00IDBjLS42IDAtMS4xLjUtMS4xIDEuNiAwIDIuMSAwIDIu'
    b'OS4yIDQgLjIgMS4yIDEgMS42IDEuMyAwbC41LTQuMmMuMi0xLS40LTEuNC0uOS0xLjR6bS03'
    b'LjcuNmExIDEgMCAwIDAtMSAxYzAgMSAuMyAyLjMuNCAzLjguMiAxLjUgMS4zIDEgMS40IDAg'
    b'MC0uOC4yLTIuMiAwLTMuOSAwLS42LS4yLS45LS42LTFhLjguOCAwIDAgMC0uMiAwem0xMS4x'
    b'IDBjLS4zIDAtLjYuMy0uNyAxYTIwLjEgMjAuMSAwIDAgMCAuMiAzLjhjMCAxIDEuMiAxLjUg'
    b'MS4zIDAgMC0xLjUuNC0yLjcuNC0zLjcgMC0uNi0uNS0xLTEtMS4xYS44LjggMCAwIDAtLjIg'
    b'MHptLTE1LjQgMS43Yy0uNS4xLTEgLjctLjggMS4zLjMgMS4zLjYgMi43LjYgNCAwIDEuMS45'
    b'LjcgMSAwYTU5LjggNTkuOCAwIDAgMCAuMS00YzAtMS0uNS0xLjQtMS0xLjN6bTE5LjYgMGMt'
    b'LjMuMS0uNi41LS42IDEuM2wuMiA0YzAgLjcgMSAxLjEgMSAwIDAtMS4zLjItMi43LjUtNCAu'
    b'Mi0uNi0uMy0xLjItLjctMS4zYS42LjYgMCAwIDAtLjMgMHptLTU5IC4yYy0uNiAwLTEgLjct'
    b'LjYgMS41LjYgMS40IDEuMyAyLjIgMS45IDMuNi41IDEuMyAxLjQuNSAxLjEtLjRsLTEuNC0z'
    b'LjdjLS4zLS43LS43LTEtMS0xem05OC44IDBjLS40IDAtLjcuMy0xIDEtLjkgMS45LTEuMiAy'
    b'LjgtMS41IDMuNy0uMiAxIC42IDEuNyAxLjIuNGwxLjgtMy42Yy40LS44IDAtMS41LS41LTEu'
    b'NXptLTk0LjggMGMtLjUuMi0uNy43LS41IDEuMy42IDEuMiAxLjMgMi41IDEuOCAzLjguNCAx'
    b'LjEgMS40LjggMS0uMmwtMS0zLjdjLS40LTEtMS0xLjMtMS4zLTEuMnptOTAuNSAwYy0uNC4x'
    b'LS44LjUtMSAxLjItLjcgMi0uOCAyLjYtMS4xIDMuNy0uNCAxIC42IDEuMyAxIC4ybDEuOC0z'
    b'LjhjLjItLjYgMC0xLjEtLjQtMS4zYS42LjYgMCAwIDAtLjMgMHptLTg1LjUgMWMtLjYuMS0x'
    b'IC45LS42IDEuOS40IDEuMiAxIDIuMyAxLjYgMy43LjYgMS40IDEuNSAxLjEgMS4zLjItLjMt'
    b'LjktLjUtMi4zLTEuMi00LjUtLjMtMS0uNy0xLjQtMS4xLTEuM3ptODAuOCAwYy0uNCAwLS45'
    b'LjMtMS4yIDEuMy0uNiAyLjItMSAzLjYtMS4xIDQuNS0uMyAxIC43IDEuMiAxLjItLjIuNi0x'
    b'LjQgMS4yLTIuNSAxLjYtMy43LjQtMSAwLTEuOC0uNS0xLjl6bS05My4yLjdjLS42IDAtMSAx'
    b'LS43IDEuNy41IDEgLjkgMS40IDEuNCAyLjYuNiAxLjIgMS4yLjMgMS0uNS0uMy0uOC0uNi0x'
    b'LjctLjgtMi44LS4yLS44LS42LTEtMS0xem0xMDUuNiAwYy0uNCAwLS43LjItMSAxbC0uNyAy'
    b'LjhjLS4yLjguNCAxLjcgMSAuNS41LTEuMi44LTEuNSAxLjQtMi42LjMtLjctLjItMS42LS43'
    b'LTEuN3ptLTY3IDIuOGMtLjcgMC0xLjMuOC0xIDEuNS4yIDEuMi44IDIuMiAxLjEgMy43LjQg'
    b'MS4zIDEuMy43IDEuMi0uMmEyOC43IDI4LjcgMCAwIDAtLjUtNGMtLjItLjctLjUtMS0uOS0x'
    b'em0yOC40IDBjLS4zIDAtLjcuMy0uOCAxYTI4LjcgMjguNyAwIDAgMC0uNiA0YzAgLjkuOSAx'
    b'LjUgMS4yLjJsMS4yLTMuN2MuMi0uNy0uNC0xLjUtMS0xLjV6bS0xNC4yIDEuMmMtLjggMC0u'
    b'OSAxLS45IDEuN2ExMi4zIDEyLjMgMCAwIDEtMiA2LjRjLTEgMS4yLTIuMy45LTMuNS4yYTIy'
    b'LjMgMjIuMyAwIDAgMS0zLjMtMi4yYy0xLjQtMS0yLjQtLjQtLjggMS45IDQuNiA2LjYgOS42'
    b'IDEyLjIgOS42IDIzIDAgMS4zLjMgMS43LjkgMS43cy44LS40LjgtMS44YzAtMTAuNyA1LTE2'
    b'LjMgOS42LTIzIDEuNi0yLjIuNi0yLjgtLjctMS44YTIxIDIxIDAgMCAxLTMuMyAyLjJjLTEu'
    b'My43LTIuNiAxLTMuNS0uMmExMi4zIDEyLjMgMCAwIDEtMi02LjRjLS4xLS43LS4yLTEuNy0x'
    b'LTEuN3ptLTM1LjMtMS42YS42LjYgMCAwIDAtLjIgMGMtLjMuMS0uNC40LS4zIDFsMS4xIDMu'
    b'OWMuMyAxIDEuNC43IDEuMi0uNWwtLjYtMy4xYy0uMi0uOC0uOC0xLjMtMS4yLTEuM3ptNzAu'
    b'NiAwYy0uNSAwLTEgLjUtMS4yIDEuMy0uNCAxLjQtLjQgMS44LS42IDMtLjMgMS4zLjkgMS41'
    b'IDEuMS42bDEuMi00YzAtLjUtLjEtLjgtLjQtLjlhLjYuNiAwIDAgMC0uMiAwem0tOTEuNi40'
    b'Yy0uNiAwLTEgLjgtLjQgMS44LjYgMS4yIDEuNyAyLjYgMi4yIDMuNS41LjggMS40LjIuOC0u'
    b'OC0uNi0xLS44LTIuMy0xLjYtMy44YTEgMSAwIDAgMC0xLS43em0xMTIuNSAwYy0uMyAwLS43'
    b'LjItMSAuNy0uNyAxLjUtMSAyLjctMS41IDMuOC0uNiAxIC4yIDEuNi43LjguNS0uOSAxLjYt'
    b'Mi4zIDIuMi0zLjUuNi0xIC4yLTEuOC0uNC0xLjh6TTEzNCAxNjkuNWMtLjYgMC0uOCAxLjIt'
    b'LjIgMmExOS4yIDE5LjIgMCAwIDAgMi42IDIuN2MuOC44IDEtLjIuNi0xbC0xLjgtMi43Yy0u'
    b'NS0uNy0uOS0xLTEuMi0xem0xNzUuOSAwYy0uMyAwLS43LjMtMS4xIDFsLTEuOSAyLjdjLS40'
    b'LjgtLjIgMS44LjcgMWExOSAxOSAwIDAgMCAyLjYtMi43Yy42LS44LjQtMi0uMy0yem0tMTcw'
    b'LjggMWMtLjYgMC0xIC40LS41IDEuM2wxLjkgMy44Yy41IDEgMiAxLjMgMS40LS4ybC0xLjMt'
    b'My44Yy0uMy0uNy0xLTEtMS41LTF6bTE2NS44IDBjLS42IDAtMS4zLjQtMS42IDEuMWwtMS4y'
    b'IDMuOGMtLjYgMS41LjkgMS4yIDEuNC4yLjUtMSAxLjMtMi41IDEuOC0zLjguNS0uOS4xLTEu'
    b'My0uNC0xLjN6bS0xNzUuNi40Yy0uOCAwLS44LjctLjEgMS4yLjkuNyAyIDEuNCAzIDIuMyAx'
    b'LjMgMSAxLjcgMCAxLS44LS42LS44LTEuMi0xLjYtMi45LTIuNS0uNC0uMi0uNy0uMi0xLS4y'
    b'em0xODUuMyAwYy0uMiAwLS42IDAtMSAuMi0xLjYuOS0yLjMgMS43LTMgMi41LS42LjktLjEg'
    b'MS44IDEuMS44IDEtLjkgMi4yLTEuNiAzLTIuMy44LS41LjctMS4yIDAtMS4yem0tMTA5LjYu'
    b'N2MtLjUgMC0uOC41LS43IDEuMmwxIDMuNmMuMiAxLjEgMS41IDEuMSAxLjMgMC0uMi0xLS4z'
    b'LTIuMy0uNy0zLjktLjEtLjYtLjQtLjktLjgtMWEuNi42IDAgMCAwLS4xIDB6bTMzLjggMGMt'
    b'LjMgMC0uNi4zLS44IDEtLjQgMS41LS41IDIuOC0uNyAzLjktLjIgMSAxLjEgMSAxLjMtLjFs'
    b'MS0zLjZjLjItLjctLjItMS4yLS42LTEuMmEuNi42IDAgMCAwLS4yIDB6bS02NC0yYy0uMyAw'
    b'LS41LjctLjIgMS43YTI2IDI2IDAgMCAxIDEuNiA5Yy0uMyAxLjItMSAxLjMtMS45IDFhMTgu'
    b'OCAxOC44IDAgMCAxLTIuOC0xLjdjLS44LS41LTEuNy4xLS41IDEuMSA2IDUgMTAuMyAxMC43'
    b'IDEyIDE3LjYuMiAxLjQgMS4xIDEuNi45IDAtMS40LTguNy0xLjctMTUuOS40LTIwLjMuOC0x'
    b'LjcgMC0zLjMtMS4yLS42LS45IDEuOC0yLjIgMi41LTMuMyAxYTQ3LjkgNDcuOSAwIDAgMS00'
    b'LTcuN2MtLjItLjctLjUtMS0uOC0xLjFhLjMuMyAwIDAgMC0uMSAwem05NC4xIDBjLS4zIDAt'
    b'LjYuNC0uOCAxLS43IDItMi45IDYuMi00IDcuOHMtMi40LjgtMy4yLTFjLTEuMy0yLjctMi0x'
    b'LjEtMS4zLjYgMi4xIDQuNCAxLjggMTEuNi41IDIwLjMtLjMgMS42LjYgMS40IDEgMGEzMi40'
    b'IDMyLjQgMCAwIDEgMTEuOC0xNy42YzEuMi0xIC4zLTEuNi0uNS0xYTE4IDE4IDAgMCAxLTIu'
    b'OCAxLjVjLTEgLjQtMS42LjMtMS45LTEtLjItMS4yLjItMy45IDEuNy05IC4yLS44IDAtMS41'
    b'LS4zLTEuNmEuMy4zIDAgMCAwLS4yIDB6TTE0NC40IDE3MmMtLjUgMC0xIC40LS43IDEuMi40'
    b'IDEuNCAxLjIgMi44IDEuNSAzLjYuMy45IDEuMi41IDEtLjdsLS41LTMuMWMwLS42LS43LTEt'
    b'MS4zLTF6bTE1NS4xIDBjLS42IDAtMS4yLjQtMS4zIDFsLS40IDMuMWMtLjIgMS4yLjcgMS42'
    b'IDEgLjcuMi0uOCAxLTIuMiAxLjQtMy42LjMtLjgtLjEtMS4yLS43LTEuMnptLTEzNi4zLTEu'
    b'N2MtLjYtLjEtLjcgMS41LS4yIDIuMmwyLjggMy4xYy44IDEgMS4zLjEuOC0uN2wtMi42LTMu'
    b'OGMtLjMtLjUtLjYtLjgtLjgtLjh6bTExNy41IDBjLS4yIDAtLjUuMy0uOC44bC0yLjYgMy44'
    b'Yy0uNS44IDAgMS43LjkuN2wyLjctMy4xYy41LS43LjUtMi4zLS4yLTIuMnptLTEzMiA0Yy0u'
    b'NCAwLS43LjItLjUgMSAuMiAxLjIuNSAyIC44IDMuMS4zIDEgMSAuOSAxLS4xbC0uMy0zLjJh'
    b'MS4xIDEuMSAwIDAgMC0xLS45em0xNDYuNSAwYTEgMSAwIDAgMC0xIC44bC0uMyAzLjJjMCAx'
    b'IC44IDEuMiAxIC4xbC45LTNjLjItLjktLjItMS4yLS42LTEuMnptLTEzMy40IDEuNGMtLjYg'
    b'MC0xLjEuNy0uNCAxLjYgMS4xIDEuNSAyLjQgMi41IDIuOSAzIC40LjYgMS41LjQuOC0uN2wt'
    b'Mi4zLTMuNWMtLjItLjQtLjYtLjUtMS0uNHptMTIwIDBjLS4yIDAtLjUuMS0uNi40bC0yLjQg'
    b'My41Yy0uNyAxLjEuNCAxLjMuOS44LjQtLjYgMS43LTEuNiAyLjktMy4xLjctMSAuMS0xLjYt'
    b'LjUtMS42YS45LjkgMCAwIDAtLjIgMHptLTE0MC43IDQuMWMtLjQgMC0uNi40IDAgMS4zYTE3'
    b'IDE3IDAgMCAxIDMuMyA2LjRjLjEgMS40LS41IDEuNC0xLjEgMS40LTEuOSAwLTIuOC0xLjQt'
    b'NC40LTEuOC0xLjctLjMtMiAuNS0uOCAxLjRhNTMuNCA1My40IDAgMCAxIDE0LjcgMTMuOGMx'
    b'IDEuOSAyLjMgMi41IDEuNi44YTIzLjcgMjMuNyAwIDAgMS0yLjQtMTIuNmMuNS0yLjggMS4y'
    b'LTQuNiAxLjEtNi4yIDAtMS41LTEtMS40LTEuMyAwbC0xIDIuOGMtLjQuNS0xLjguOC0zLS45'
    b'YTQ4IDQ4IDAgMCAwLTUuNi01LjhjLS4zLS4zLS43LS41LTEtLjZ6bTE2MS43IDBjLS4zIDAt'
    b'LjcuMi0xLjEuNmE0OC4yIDQ4LjIgMCAwIDAtNS41IDUuOGMtMS4zIDEuNy0yLjcgMS40LTMg'
    b'MWExMiAxMiAwIDAgMS0xLTIuOWMtLjQtMS40LTEuMy0xLjUtMS40IDAgMCAxLjYuNiAzLjQg'
    b'MS4xIDYuMnMwIDcuMi0yLjMgMTIuNmMtLjggMS43LjYgMSAxLjYtLjhhNTMgNTMgMCAwIDEg'
    b'MTQuNi0xMy44YzEuMi0uOSAxLTEuNy0uNy0xLjQtMS43LjQtMi42IDEuOC00LjQgMS44LS42'
    b'IDAtMS4zIDAtMS4yLTEuNC4xLTEuMyAxLjgtNC40IDMuMy02LjQuNi0xIC41LTEuMyAwLTEu'
    b'M3oiLz4KICAgICAgPHBhdGggZD0ibTE1MC4xIDIxMi43IDIgNi4xbTItNy4zIDEuOCA2LjJt'
    b'Mi42LTcgMS4yIDYuNG0yLjgtNy4xIDEuMyA2LjNtMy44LTYuOCAxIDYuNG00LjUtNi40IDEu'
    b'MSA2LjNtNC4zLTguMS44IDYuNG00LjItNi4xLjggNi40bTQuMS03IC44IDYuNG00LTcgLjUg'
    b'Ni41bTQuOC02LjUuNCA2LjVtNC40LTYuOC4zIDYuNW00LjktNi44LjMgNi40bTUuNy02LjYu'
    b'MyA2LjVtNzkgLjItMiA2LjFtLTItNy4zLTEuNyA2LjJtLTIuNi03LTEuMiA2LjRtLTIuOC03'
    b'LjEtMS4zIDYuM20tNC02LjgtMSA2LjRtLTQuNC02LjQtMS4xIDYuNG0tNC4yLTguMi0uOCA2'
    b'LjRtLTQuMy02LjEtLjggNi40bS00LTctLjkgNi40bS00LTctLjUgNi41bS00LjgtNi41LS40'
    b'IDYuNW0tNC4zLTYuOC0uMyA2LjVtLTUtNi44LS4yIDYuNG0tNS44LTYuNi0uMiA2LjVtLTcu'
    b'Mi03djcuMiIvPgogICAgPC9nPgogIDwvZz4KPC9zdmc+Cg==', 'LI')

LI = b64_LI
index.append("LI")
index.append("LIE")
index.append("Liechtenstein")
catalog["LI"] = LI
catalog["LIE"] = LI
catalog["Liechtenstein"] = LI
country["Liechtenstein"] = ('LI', 'LIE', 0)
lookup["LI"] = ('LI', 'LIE', 'Liechtenstein', 0)
lookup["Vaduz Liechtenstein"] = ('LI', 'LIE', 'Liechtenstein', 0)
lookup["LIE"] = ('LI', 'LIE', 'Liechtenstein', 0)
lookup["Liechtenstein"] = ('LI', 'LIE', 'Liechtenstein', 0)
details["LI"] = {"continent":"Europe","capital":"Vaduz","currency":"Swiss Franc","web":".li","lang":"de-LI","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_LK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1sayIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmI3MDAiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZjViMDAiIGQ9Im0yNi43IDI0MCA4OC0yMTMuM2g4'
    b'OHY0MjYuNmgtODh6Ii8+CiAgPHBhdGggZmlsbD0iIzAwNTY0MSIgZD0iTTI2LjcgMjYuN2g4'
    b'OHY0MjYuNmgtODh6Ii8+CiAgPHBhdGggZmlsbD0iIzhkMjAyOSIgZD0iTTIyOS4zIDI2LjdI'
    b'NjE2djQyNi42SDIyOS4zeiIvPgogIDxwYXRoIGlkPSJsay1hIiBmaWxsPSIjZmZiNzAwIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJNNTc5LjMgNDA4LjZzMy42IDcu'
    b'MyA3LjYgMTAuNGM2IDQuNCAxOCA0IDIzLjMgOS4zIDYuMSA2LjEtLjUgMTQuMi0uNSAxNWwu'
    b'NCA0LjJzLTQuMiAwLTYgLjNjLTIuNi40LTMuNiAyLjYtOC42IDIuMy0xMi4zLS44LTExLjgt'
    b'MTItMTIuNS0yMS41LS42LTMuNi0yLTguNC0yLjktMTItLjctMy0uOC04LS44LTh6Ii8+CiAg'
    b'PHVzZSB4bGluazpocmVmPSIjbGstYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEgODQ1LjMgMCkiLz4KICA8dXNlIHhsaW5rOmhyZWY9'
    b'IiNsay1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09Im1hdHJpeCgx'
    b'IDAgMCAtMSAwIDQ4MCkiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiNsay1hIiB3aWR0aD0iMTAw'
    b'JSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InJvdGF0ZSgxODAgNDIyLjcgMjQwKSIvPgog'
    b'IDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKDAgLTc2KSI+CiAgICA8dXNlIHhsaW5rOmhyZWY9'
    b'IiNsay1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iNS42Ii8+CiAgICA8ZyBpZD0ibGstYiIgZmlsbD0iI2ZmYjcwMCI+CiAgICAg'
    b'IDxwYXRoIGQ9Im0zNjMuNSA0MTUuOCAyLjMtMS40IDEgMS40YzEuMyAxLjggNSAxLjcgNy40'
    b'IDBsMS45LTEuNSAxLjYgMS40YzIgMS45IDUuOCAxLjkgOC4zIDAgMS43LTEuMiAyLTEuMyAz'
    b'LS4zLjcuNiAyLjcgMS4yIDQuNCAxLjUgMy4yLjQgMy4yLjQgNS0yLjQgMS42LTIuMyAxLjgt'
    b'My4yIDEuNS01LjVhNTkuNCA1OS40IDAgMCAxLS42LTUuM2MtLjItMi42LS4xLTIuNiAzLjYt'
    b'NGE1MC41IDUwLjUgMCAwIDAgNS40LTJjMS41LS45IDUuNy01LjggNS43LTYuOCAwLS4yLTEu'
    b'Ni0uNi0zLjYtLjgtOC0xLTkuMy01LjItNC4xLTEzIDguMy0xMyAxMy40LTI1LjUgMTMuNC0z'
    b'My40IDAtMy42LjMtNC44LjctNCAxLjkgMy4xLTEuNSAxNi40LTYuNSAyNmwtMiAzLjggMS45'
    b'LS40YzEtLjMgNy40LTMgMTQtNiAxOC4yLTguMiAyNC40LTkuOCAzNi4yLTkuMyA5LjkuNCAx'
    b'NCAyLjMgMjEgOS42IDMuNyA0IDcuMyA2LjcgMTMuOCAxMC44IDEzLjggOC42IDE0LjQgOS40'
    b'IDE1LjEgMTkuNi43IDEwLjMuMyAxMC45LTcuNSAxMi42LTYuNyAxLjUtMTAuOSA0LjYtMTIg'
    b'OS0uNiAyLjIuNyAyLjMgNCAuMWwyLjUtMS42IDEuMSAxLjZjMS41IDIuMSA0LjUgMi4xIDcg'
    b'MGwyLTEuNSAyIDEuNWMzIDIuNSA3IDEuOSA4LjItMS4yLjItLjUuOC0uNCAyIC43IDIuMyAy'
    b'IDggMi44IDguNiAxLjIuMi0uNi0uMi0yLTEtMy4yLTMuMy01LTQuNC03LjMtNC40LTEwIDAt'
    b'My44IDEtNS43IDUuNC04LjcgNS4yLTMuOCA2LjgtOC42IDIuOC04LjYtMi40IDAtNC45LTIu'
    b'Mi02LjUtNS43LTMuMi03LjItMi41LTE1LjIgMi4zLTI4LjZhNTcuNiA1Ny42IDAgMCAwIDUu'
    b'NC0yNS4yYzAtNy40LS4yLTguNi0xLjgtMTIuN2E0NS40IDQ1LjQgMCAwIDAtNC42LTguMWwt'
    b'Mi44LTMuNyAzLjUtM2MxMC44LTguOSA4LjYtMjMuNS00LjQtMjkuMS00LTEuOC01LTEuOS0x'
    b'Mi0xLjktNCAwLTEwLjUuNi0xNCAxLjNhOTguMiA5OC4yIDAgMCAxLTE0LjIgMS4yYy02Ljgg'
    b'MC04LS4yLTEwLjYtMS42LTIuNy0xLjQtMy4yLTIuMS0zLjctNS41YTIgMiAwIDAgMC0xLjEt'
    b'MS41Yy0xLS4zLTUuMiAzLjQtNS44IDUtLjQuOS0uNi44LTEuNS0uM2ExMy40IDEzLjQgMCAw'
    b'IDEtMi0zLjZjLTEtMy4zLjMtNS43IDQuMi03LjZsMy0xLjQtMS44LTEuMWMtMy42LTIuMy05'
    b'LjgtLjctMTIgMy0uNyAxLTEuNCAyLTEuNiAyLS4yIDAtMS40LTEtMi42LTIuMy00LjctNC42'
    b'LTMuMS0xMS40IDMuMi0xMy40IDMuMy0xLjEgNi4zLS4zIDYuOSAyIDEgMy4zIDMuOC0xLjEg'
    b'My4zLTUuMi0uMy0yLjctLjMtMi44IDEuNi0yLjggMi42IDAgOCAzLjQgOS44IDYgMiAzLjEg'
    b'MS44IDgtLjQgMTEuNmwtMS43IDIuOCAyLjMtLjRjMy4yLS43IDYuNC0yLjcgOC01LjJhMTIg'
    b'MTIgMCAwIDAgLjQtMTAuNGMtMS41LTIuNy0xLjMtMy4xLjktMi4yIDMuNiAxLjUgNS42IDMu'
    b'MiA3IDYuMSAxLjQgMi42IDEuNSAzLjIuOCA2YTE3IDE3IDAgMCAxLTIuMiA0LjhjLTEuMiAx'
    b'LjYtMS4zIDEuOS0uMyAxLjkgMS44IDAgNS40LTEuNyA2LjctMyAuNy0uOCAxLjctMi41IDIu'
    b'Mi00bDEtMi41IDEgMmMxLjUgMi43IDQuNSA1LjIgOC4xIDYuOCAzLjkgMS42IDUuNSAxLjcg'
    b'My41LjItMS40LTEtNC04LjUtMy4xLTkuMmE1MSA1MSAwIDAgMSAxMS43IDljNS43IDUuMSA5'
    b'LjMgNi44IDE0LjUgNi44IDYuNyAwIDEwLjYtNS44IDcuNi0xMS4zLTEuNy0zLjItNS42LTMu'
    b'Ny04LTEtMSAxLjMtMS4zIDIuMy0xIDMuNy40IDEuNi4zIDEuOC0xLjIgMS44LTIgMC01Ljgt'
    b'Mi41LTEyLjYtOC4yYTEwMiAxMDIgMCAwIDAtMzIuMS0xOC43IDcwLjQgNzAuNCAwIDAgMC0y'
    b'NC4zLTEuM2MtNi40IDEuMi0xNCA0LjktMTguMiA4LjgtNy4zIDctNy40IDE2LjMtLjMgMjQu'
    b'OGwyIDIuNC0xLjMgMi4yYTkuMyA5LjMgMCAwIDAgLjQgMTAuNGMxIDEuNCAyIDIuNSAyLjMg'
    b'Mi41LjIgMCAuNC0uOS41LTIgLjItMi43IDEuNC00LjUgMy40LTUuMiAxLjgtLjcgMy0uMyAx'
    b'MS4yIDMgOC43IDMuNCAyMyAzLjYgMzguMi42YTQyLjYgNDIuNiAwIDAgMSAyMCAuMmM3LjIg'
    b'MyA4LjggMTAuNyAzLjYgMTYuNS0yLjMgMi42LTQuNCAzLjYtMTEuNyA1LjZhNTQuMyA1NC4z'
    b'IDAgMCAxLTE5LjUgMS41Yy0xMC44LS4xLTE0LjcuMS0xOSAxLTQuOSAxLTcuOCAxLjEtMjEu'
    b'OC44bC0xNi4zLS40IDEuOCAxLjRhMjIgMjIgMCAwIDAgMy4xIDIuM2MxLjMuNyAxLjIuOC0u'
    b'NiAxLjUtMSAuNC0zLjQuNy01LjMuN2gtMy4zbC0uNCAyLjhhMTAgMTAgMCAwIDAgMCA0Yy40'
    b'IDEgLjIgMS4yLS44LjgtLjctLjMtMi42LS44LTQuMy0xLjFhMjYuNyAyNi43IDAgMCAxLTUt'
    b'MS42Yy0xLjktMS0yLjEtMS0yLjguMy0uNiAxLTYuMiA1LjItNyA1LjJhMjYuNyAyNi43IDAg'
    b'MCAwLTIuMi03LjVjLTEtMi4xLTEuOS00LjUtMi4yLTUuMi0uMy0xLjEtLjUtMS4yLTEtLjMt'
    b'LjMuNS0uNyAyLTEgMy4yYTE1LjUgMTUuNSAwIDAgMS0xLjggNC42bC0xLjUgMi4yLTEtMS45'
    b'Yy0xLTItMi42LTQuMi0zLjItNC4yLS4yIDAtLjUuNi0uNyAxLjUtLjUgMS42LTQuNCA2LjMt'
    b'NS40IDYuMy0uMyAwLS42LTEuMy0uNi0zIDAtMS41LS4zLTIuOS0uNy0yLjktLjQgMC0uNy41'
    b'LS43IDEgMCAxLjItMy4zIDUtNC41IDUtLjQgMC0xLjIuNC0xLjcgMS0xLjIgMS4zLTIuMiAx'
    b'LjEtMS43LS40YTkgOSAwIDAgMC0uNC0zLjhsLTEtMy4yYy0uMi0uNS0xLjQtLjMtNCAuNS00'
    b'IDEuMy01LjQgMS0zLjMtLjYuOC0uNiAyLTIuNyAyLjYtNC42LjctMiAxLjctMy43IDIuMi0z'
    b'LjkuNy0uMi43IDAtLjIgMS4yYTUuNyA1LjcgMCAwIDAtMS4xIDIuNmMwIC41LS41IDEuOC0x'
    b'IDIuOS0uNiAxLTEgMi0uOSAyLjFzMS43LS41IDMuNS0xLjNsMy4yLTEuNnYxLjRjMCAuOC40'
    b'IDIuOC45IDQuNWwuOSAzIDIuMi0xYzIuMi0xIDQuMy00LjYgNC4zLTcuNSAwLTEuNC44LTEu'
    b'MiAxLjIuMyAwIC40LjYgMi4xIDEgMy43bDEgMi44IDEuNS0xLjhjLjktMSAxLjktMyAyLjMt'
    b'NC4zLjgtMi40IDItMy41IDItMS43IDAgMS4yIDMuNCA1LjggNCA1LjQuNC0uMiAxLTEuOSAx'
    b'LjUtMy44IDEtNCAyLjUtNi42IDMuNS02IC40LjIuNS42LjMgMS0uMi4yLjYgMi44IDEuOCA1'
    b'LjZhMjU1Ny43IDI1NTcuNyAwIDAgMSAyLjYgNi4zYy40IDEgLjggMSAzLjMtMS4zIDEuNS0x'
    b'LjQgMy0yLjkgMy4xLTMuNC4zLS44LjYtLjcgMiAuMmEyNSAyNSAwIDAgMCA5LjUgMi44Yy4y'
    b'LS4yLjQtMiAuNC00bC4xLTMuNyAyIC40YzEgLjMgMy4zLjMgNSAwbDMtLjQtMi43LTJjLTEu'
    b'NS0xLTMtMi4zLTMuNC0yLjktLjMtLjYtMS43LTEuMi0zLjItMS4zLTQuMS0uNC0xMS40LTQu'
    b'NC0xMS40LTYuNCAwLS40IDEgLjMgMi4yIDEuNCAyLjggMi41IDYuNiA0IDEwIDRoMi40bC0x'
    b'LjUtMmExMS45IDExLjkgMCAwIDEtMi01LjJjLS4yLTMtLjUtMy40LTMuNi01LjVhMzUuMiAz'
    b'NS4yIDAgMCAxLTUtNC4zbC0xLjctMS45LS45IDIuM2MtLjUgMS4zLTEgMi4zLTEuMyAyLjMt'
    b'LjIgMC0xLjItLjgtMi0xLjdhNyA3IDAgMCAwLTItMS42Yy0uMyAwLTEgMS4yLTEuOCAyLjds'
    b'LTEuNCAyLjctMS0xLjVhMjMuOCAyMy44IDAgMCAwLTMtMy40Yy0xLjItMS0xLjctMS44LTEu'
    b'My0xLjguNCAwIDEuNyAxIDMgMi4zbDIuMiAyLjMgMS0xLjdhNiA2IDAgMCAwIC41LTMuOGMt'
    b'LjQtMS44LS4zLTEuOS4zLS43YTE2IDE2IDAgMCAwIDMgM2wyLjIgMS44IDEuNS0yLjdjMS41'
    b'LTIuOCAxLjUtMi44IDIuMS0xLjEgMSAyLjEgNy41IDcuNSAxMyAxMC42IDEgLjUuNi0xLjEt'
    b'MS01YTEyLjcgMTIuNyAwIDAgMS0uOC00YzAtMS44LS41LTIuNi0yLjgtNC40YTEwLjkgMTAu'
    b'OSAwIDAgMS01LTguNGMtLjMtMS43LS45LTMuNS0xLjQtNC4xLS42LTEtLjgtLjQtLjYgMi42'
    b'LjIgMi4xLS4xIDQuNy0uNiA1LjhsLS44IDItLjYtMS43Yy0uNC0uOS0yLTIuNS0zLjUtMy41'
    b'cy0yLjYtMi0yLjQtMi4yYy4yLS4yIDEuOC43IDMuNSAyIDIuNyAyLjEgMy4yIDIuMyAzLjYg'
    b'MS40LjQtMSAwLTUuNi0uOC04LjgtLjQtMS42LS40LTEuNiAxLjYuNCAxLjQgMS40IDIuMiAz'
    b'LjIgMi45IDYuMi44IDMuOCAxLjIgNC41IDQuNyA3LjYgMi4xIDEuOSA0IDMuMyA0LjEgMy4y'
    b'LjItLjIuNC01IC42LTEwLjguNC0xMS4xIDAtMTMuOC0yLjctMTcuMmwtMS40LTEuOCAyLjIt'
    b'Mi4zYTE2IDE2IDAgMCAwIDQuNy04LjhsLjQtMi43LTIuNCAyLjNjLTIgMS45LTMgMi4zLTUu'
    b'MyAyLjNzLTMuMi0uNC00LjctMmEyMCAyMCAwIDAgMC04LjMtNC44Yy0xLjItLjQtMS42LS4y'
    b'LTEuNi42IDAgLjYtLjYgMi4yLTEuNCAzLjdsLTEuNCAyLjYtMy0zYy0xLjktMS43LTQtMy4y'
    b'LTUuNy0zLjYtNC4xLTEtNC4zLTEtNC4zIDIuMSAwIDQuNy0yIDUuNi01LjYgMi41LTIuOC0y'
    b'LjQtNS0zLTEwLjMtMi4zbC00IC40LjcgMS44Yy42IDEuNS41IDIuMi0uOCAzLjktMi4xIDIu'
    b'OC00LjggNC05IDQtMiAwLTQuNC40LTUuNC45cy0zLjYgMS01LjcgMS4yYy0yIC4yLTQuMy42'
    b'LTUgLjgtMSAuNC0xIDAtLjctMi4yLjUtMy40LTItNi01LjctNi00LjkgMC03LjEgNC40LTUu'
    b'MiAxMC4yYTQ0LjYgNDQuNiAwIDAgMSAxIDMuOCAyMyAyMyAwIDAgMCA1LjIgNi42YzIuNiAy'
    b'LjYgNSA1LjMgNS40IDZhOSA5IDAgMCAwIDMgMi41bDIuMiAxLjItLjMtMi40Yy0uMy0yLjYu'
    b'Mi0zIDEuNi0xLjEuNS42IDEuOCAxLjcgMi44IDIuMyAxLjcgMSAyIDEgMiAuMiAwLS42LjMt'
    b'MS45LjctMi45bC43LTEuOCAxLjMgMi41Yy43IDEuNCAzIDQuNSA1LjEgNyA0LjEgNC43IDYu'
    b'NyAxMCA1LjQgMTEuMi0uNi41LTIgLjUtNS0uMS0yLjItLjQtNS0uNy02LjItLjUtMi4zLjMt'
    b'Mi41IDAtMS0xLjggMS41LTIgMS4yLTIuMy0xLjgtMi4zLTMuNSAwLTEyLjItMS43LTE1LjYt'
    b'My0zLjItMS4zLTQtMS01IDIuMWwtMS43IDUuNi0xIDMgMy42LS4zYTM3IDM3IDAgMCAwIDUu'
    b'NS0xIDYgNiAwIDAgMSAyLjItLjNjLjIuMS0uMyAxLjMtMSAyLjdsLTEuNCAyLjQgMi4yLS40'
    b'YzEuMi0uMyAzLS45IDQtMS40IDEuOC0uOCAyLS44IDMuNCAxLjUgMS43IDIuNyAzIDIuNiAz'
    b'LjMtLjMuMy0zIDEuMy0yLjYgMy4yIDEuNCAxLjggMy44IDMuNiA1LjIgNCAzIC4xLS44IDEt'
    b'MiAyLjEtMi44IDIuMi0xLjUgMy44LTEgNC43IDEuMyAxIDIuNS0xLjIgNS03LjQgOC44YTQz'
    b'IDQzIDAgMCAwLTIxLjcgMzFjLTEuOSAxMS44IDQgMjQgMTUuNiAzMi45IDUuNiA0LjIgMTQu'
    b'NSA4LjYgMTMuOSA3LTIuNC03LjMtMi4zLTIxIC4xLTIzLjMuNC0uNC4zIDEtLjMgMy4xLTIg'
    b'Ny45LTEgMTQuMSA0IDI4LjcgNC40IDEzLjIgMy44IDE4LjktMi42IDIyLjYtMiAxLjItMy4z'
    b'IDEuNC04LjggMS4zLTYgMC02LjcgMC04LjYgMS42YTE1LjcgMTUuNyAwIDAgMC00LjMgOC42'
    b'YzAgMS4zIDEuNCAxLjEgNC0uNHoiLz4KICAgICAgPHBhdGggZD0ibTQ2MC41IDQxNS41IDIu'
    b'NS0xLjYgMS43IDEuNmMyLjIgMi4xIDQuOSAyIDctLjEgMS0xIDEuOC0xLjYgMS45LTEuNWwu'
    b'OSAxLjZjLjUuOSAxLjYgMS4zIDMuNiAxLjUgMi4zLjEgMyAwIDQtMS40bDEtMS43IDIuNSAx'
    b'LjZjNi44IDQuNCAxMC40LS4yIDcuMy05LjMtMS41LTQuNi0uNi03LjIgNC4zLTEzIDIuMS0y'
    b'LjUgMy44LTUuMiAzLjgtNiAwLTEuMS0uNC0xLjMtMy4yLTEuMi0yLjYgMC0zLjQtLjMtNC44'
    b'LTEuOC0yLjMtMi41LTIuMS01LjQuNC04LjZsMi0yLjUtMy42LTIuNGE1OS43IDU5LjcgMCAw'
    b'IDEtOC03LjEgMjUuNyAyNS43IDAgMCAwLTE3LjUtOWwtNC43LS41djMuNmMwIDQuNSAyLjIg'
    b'OC45IDggMTYuMyA2LjYgOC40IDcgOS43IDcuMyAyMC43bC4zIDkuMy0yIDEuOGMtMS43IDEu'
    b'Ni0yLjQgMS45LTggMi4yLTUuMy4zLTYuNS42LTggMmE4LjcgOC43IDAgMCAwLTMuNCA1LjNj'
    b'LS4zIDEuNS0uMiAxLjguOSAxLjguNyAwIDIuNC0uNyAzLjgtMS42em0tMTQyLjItMjRhNS44'
    b'IDUuOCAwIDAgMCAxLTNjMC0xIC42LTEuNCAzLjItMS44bDMuMS0uNC0yLTEuN2MtMi41LTIt'
    b'Mi44LTMuNS0uNi0zLjVzNS44LTIuMiA2LjQtMy45Yy4zLS44IDAtMS44LS40LTIuMy0xLjIt'
    b'MS40LTMuNS0xLjItMy45LjQtLjUgMS42LTEuMiAxLjYtMyAwLTIuNS0yLjUtMi42LTcuNiAw'
    b'LTEwLjYgMS4xLTEuNCAxLjEtMS40LS40LTIuOS0xLjYtMS42LTIuOC00LjYtMi01LjQuMi0u'
    b'MiAxLjUgMCAyLjguNSAyIC42IDIuNy42IDMuNSAwIDIuMy0xLjktLjItNC4zLTQtMy43LTEu'
    b'Ni4yLTIuMiAwLTIuNC0uOC0uMi0uNi0xLjUtMS40LTMtMS44LTIuNy0uNy0yLjctLjctMi43'
    b'IDEuMiAwIDItMS4yIDIuNC0zLjQgMS4xLTEuOC0xLTMuNS0uMi0zLjUgMS43IDAgMS44IDEu'
    b'NyAyLjYgNSAyLjQgMi40LS4xIDIuNSAxLjcuMiA0LjNsLTEuNyAyIDEuMyAxLjljMiAyLjgg'
    b'MS44IDcuNS0uMyA5LjlsLTEuNyAxLjgtMS4xLTEuNWMtMS42LTItMy43LTEuOS00LjMuMy0u'
    b'MyAxLjQgMCAyIDEuOCAzLjYgMS4yIDEgMyAxLjggMy45IDEuOCAyLjMgMCAyLjIgMS45LS4y'
    b'IDMuN2wtMiAxLjUgMyAuNGMxLjYuMyAzIC43IDMgMSAwIDEuMyAyIDUuMiAyLjYgNS4yLjQg'
    b'MCAxLjItLjcgMS44LTEuNXoiLz4KICAgICAgPHBhdGggZD0iTTM1Ni41IDM3NC45YzIuNy0x'
    b'IDguNS02IDguNS03LjEgMC0uNC0xLjYtMi4yLTMuNi00LTQtMy42LTguNS05LjktOS43LTEz'
    b'LjUtLjYtMi0zLjUtNS4yLTExLjctMTMuMmwtMTAuOS0xMC41LTMuMS44Yy0xLjguNC0zLjku'
    b'OC00LjcuOC0xLjUgMC0xLjUgMCAuNSAxLjZsMiAxLjYgMy0xLjZjMi43LTEuNiAyLjgtMS42'
    b'IDMuMS0uMy4yLjctLjIgMi0xIDIuOS0uNy45LTEuMSAyLTEgMi4zLjMuMy0uNCAxLTEuNSAx'
    b'LjYtMiAxLTMuNSA0LjMtMS45IDQuMyAxLjUgMCA0LjctNCA0LjMtNS4zLS4yLS43IDAtMS40'
    b'LjItMS42IDEuMy0uNyAxLjIgMi40IDAgNC0uOC44LTEuMiAxLjgtMSAyLjIuMi4zLS41IDEt'
    b'MS42IDEuNi0yIDEtMy41IDQuMy0xLjkgNC4zczQuNy0zLjggNC40LTUuMmMtLjItLjctLjIt'
    b'MS41LjEtMS43LjktLjQgMS4zIDIgLjYgMy4yYTIuMyAyLjMgMCAwIDAgMCAyLjJjLjcgMS4z'
    b'IDAgMy43LTEuMyA0LjUtLjUuMy0uMiAxIDEuMiAyIDIgMS40IDIgMS42IDIgOCAwIDUuNC4y'
    b'IDYuOCAxLjIgNy43IDEgMSAxLjIgMSAxLjIgMHMyLTIuNCAzLjUtMi40Yy41IDAgMy40IDIu'
    b'NSA2LjUgNS41czYuNCA1LjcgNy4zIDUuOGwyLjIuNGMuMyAwIDEuNy0uMyAzLjEtMXptLTMz'
    b'LjMtMjYuMWMwLTEuNy0zLjYtMy42LTcuOS00LTMuNS0uNS0zLjUtLjQtMy41IDEuMyAwIDEu'
    b'NC41IDIgMyAzIDMuOCAxLjcgOC40IDEuNSA4LjQtLjN6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0z'
    b'MjcuMSAzNDguNmMxLjgtMS42IDIuNi0zLjQgMS41LTMuNC0xLjIgMC00LjQgMi44LTQuNCA0'
    b'IDAgMS42LjYgMS41IDMtLjZ6bS0zLjctNS4xYy4xLTEtLjUtMS42LTIuMy0yLjUtNC0xLjct'
    b'OC42LTIuNi05LjctMS43LTIuMSAxLjctLjcgMy45IDIuNiA0LjMgMS40LjEgMy4yLjUgNC4x'
    b'LjkgMi42IDEgNSAuNSA1LjMtMXptMC01LjNjLjItMS4zLS43LTEuOC04LTQuNC01LjUtMi03'
    b'LjktMS02LjEgMi4zLjYgMS4xIDEuNiAxLjYgMy45IDIgMS43LjIgNCAuNyA1LjEgMS4xIDMg'
    b'MSA0LjguNiA1LTF6bTMuNi00LjljMS4xLTEuMSAyLTIuNCAyLTMgMC0xLjUtNC4zIDEuMy00'
    b'LjkgMy4zLS42IDIuMy41IDIuMiAzLS4zem0tMy42LS4zYy4yLTEuNi0yLjQtMy03LjYtNC4x'
    b'LTMuOS0uOS01LjYtLjQtNS4zIDEuNC4yIDEgMS41IDEuNyA1IDIuOCA1LjkgMS44IDcuNiAx'
    b'LjggNy45LS4xem01LTcuNGM2LjgtMyA3LjMtMTAuNSAxLTEyLjUtMi42LS44LTQuMi0uMy01'
    b'LjIgMS40LS44IDEuNC0uMyAzLjguNyAzLjguNCAwIC43LjUuNyAxIDAgMi43LTEwLjIgMy44'
    b'LTE0LjQgMS43LTEuNS0uNy0yLTIuNy0uOS0yLjcgMSAwIDEuNi0yIDEuMS0zLjMtLjYtMi0y'
    b'LjYtMi42LTUuMy0xLjgtNi4zIDEuNi02LjEgOSAuMyAxMmEzMy42IDMzLjYgMCAwIDAgMjIg'
    b'LjR6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0zMjQuMyAzMTkuOGMuNC0uNC4yLTEtLjQtMS40LTEu'
    b'NC0xLjEtMS4zLTIuOC4yLTQuNyAxLjItMS40IDEuMy0zLjYgMS43LTI1LjEuNy0zNy4xIDMu'
    b'NS02NSA3LjEtNzEuOCAxLjUtMi42IDEuMy0yLjYtMi41IDBhMzYgMzYgMCAwIDAtMTEuNyAx'
    b'My42Yy02LjIgMTEuNS04LjMgMjctOC4zIDYwLjIgMCAxOC44LjEgMjEuMyAxLjIgMjMgMSAx'
    b'LjggMSAyLjQuNCA0LjItLjUgMS4xLS43IDIuMy0uNSAyLjUgMS40IDEuMyAxMS40IDEgMTIu'
    b'OC0uNXptNTYuMS0zNS40Yy4zLS4zLS4yLTItMS0zLjYtMS4yLTIuNi0xLjctMy0zLjQtM2E2'
    b'NSA2NSAwIDAgMS0yMy02LjRjLTUuMS0yLjMtNy0yLjgtNy41LTIuMi0xLjYgMS41IDEgNSA1'
    b'IDYuOWE2NCA2NCAwIDAgMCAxOC4zIDMuN2MyLjcgMCAyLjggMCAxLjIgMi4zbC0xIDEuNmgz'
    b'bDUgLjZjMyAuNyAzIC43IDMuNC4xeiIvPgogICAgICA8cGF0aCBmaWxsPSIjMDAwIiBkPSJN'
    b'NDEyIDMwMS4xYzAtMS0yLjktMy41LTUuNy01LjItMi4zLTEuMy0yLjctMS40LTIuNy0uMyAw'
    b'IDEuNi0xLjQgNS43LTIgNS43LS4zIDAtLjgtLjgtMS0xLjctLjMtMS0xLjQtMy0yLjUtNC4z'
    b'bC0yLTIuNS0xLjQgMi4zYy0xLjQgMi4yLTMuOSA0LjMtNSA0LjMtLjIgMC0uMy0xLjIgMC0y'
    b'LjUuMS0xLjYgMC0yLjgtLjUtMy0uNC0uMy0uOC0uMi0uOC4yIDAgLjgtMy40IDQuNi00IDQu'
    b'Ni0uNCAwLS44LTEtMS0yLjRsLS44LTQuOGMtLjItMS4yLjMtLjQgMSAybDEuNiA0LjEgMS42'
    b'LTIuNWExMSAxMSAwIDAgMCAxLjYtMy40YzAtLjUuMy0uNy43LS41LjQuMi45IDEuOSAxLjEg'
    b'My43bC41IDMuNCAxLjgtMmEyOC44IDI4LjggMCAwIDAgMi42LTMuMmMuNy0xLjIuOC0xLjIg'
    b'Mi4zIDAgLjguOCAyLjEgMi41IDIuOSAzLjlzMS41IDIuNCAxLjYgMi4zbC42LTMuMi40LTNj'
    b'LjEtLjUgNS40IDMgNy40IDQuNyAxLjIgMS4xIDIuNCAxLjkgMi42IDEuNy4yLS4yLjQtMS44'
    b'LjQtMy43IDAtMi44LS4zLTMuNi0yLTUuMS0yLTEuOC0yLTEuOC0yLjgtLjUtMSAxLjctMi4x'
    b'IDEuNy0yLjEgMCAwLTEuMi0zLjgtNS45LTQuNy01LjktLjMgMC0xLjEgMS0xLjggMi4zcy0x'
    b'LjUgMi4zLTEuNyAyLjNjLTEgMC02LjMtNi02LjMtNyAwLS44LjQtLjYgMS4zLjhhMjEgMjEg'
    b'MCAwIDAgMy4xIDMuNmMyIDEuOCAyLjggMS40IDMuNi0yLjEuMy0xIC43LTEuOCAxLTEuOC44'
    b'IDAgNS40IDQuOSA2IDYuNWwuNyAxLjYuNS0xLjhjLjYtMi4yIDEuMy0yLjIgMi4zLS4yLjQu'
    b'OCAyLjQgMi42IDQuNCAzLjhsMy43IDIuNC43LTIuNGMuNC0xLjMgMS0yIDEuMi0xLjYuNC41'
    b'LS42IDQuNS0xLjMgNS4zIDAgLjEtMS4zLS42LTIuNi0xLjVsLTIuNS0xLjh2My4yYzAgMS43'
    b'LS4yIDMuOC0uNCA0LjYtLjUgMS42LTEuNyAyLTEuNy42em0tMTguNS0yNS40Yy00LjQtMy42'
    b'LTUtNC40LTUtNi4ybC4xLTEuOC4zIDEuN2MuMiAxIDEuNCAyLjYgMi44IDMuOGwyLjYgMiAx'
    b'LjUtMS44Yy45LTEgMS42LTIuMiAxLjYtMi42IDAtMS4yLjItMS4xIDMuMiAxLjUgMi42IDIu'
    b'MyAyLjcgMi4zIDMgLjguMy0uOC4yLTIuNCAwLTMuNS0xLTMtLjgtMy40LjUtMS42bDIuNCAy'
    b'LjhjMSAxLjEgMS4xIDEuMSAxLjUtLjMuMy0uOS41LTIuNC41LTMuNHYtMS45bDIuMyAyLjdj'
    b'Mi4zIDIuNiAyLjUgMi43IDMuMSAxLjQuNS0uNy44LTIuNC44LTMuNyAwLTEuOC4yLTIuMi42'
    b'LTEuNi44IDEuMi4zIDQuMi0xLjEgNi44bC0xIDItMS4zLTIuMWMtMS43LTIuNi0yLjMtMi42'
    b'LTMuMy4yLTEgMi43LTEuNyAyLjktMi43LjgtLjYtMS4zLS44LTEuMS0xLjIgMS43bC0uNSAz'
    b'LTMtMi4zLTMtMi4zLTEuNSAxLjVjLS43LjktMS4zIDItMS4zIDIuNCAwIDEtLjggMS0xLjkg'
    b'MHptMzktMTMuNmMtMS41LTEuNC0yLjYtMi44LTIuNC0zIC4zLS4zLjUtLjQuNi0uMmE2NyA2'
    b'NyAwIDAgMCAzIDNjMy40IDMuNiAyLjcgMy43LTEuMS4yem0tNTItNS40Yy0xLjQtMi0xLjMt'
    b'My4yLjUtNS40IDEuMi0xLjUgMS44LTEuNyA0LTEuNCAxLjUuMSA0LjYgMS40IDYuOSAyLjhh'
    b'MjEuMiAyMS4yIDAgMCAwIDExIDNsLTEuNy0yLjhjLTIuMi0zLjMtMi4yLTMuNy40LTEuNyAy'
    b'LjYgMi4xIDUuNyAyLjcgMTIuNyAyLjVsMy40LS4xLTItMmMtMi43LTIuNy0xLjktMyAxLjIt'
    b'LjMgMi44IDIuNSAyLjcgMi43LTMuNCAzLjNhMjMgMjMgMCAwIDEtNy42LS41Yy0zLjQtMS0z'
    b'LjYtLjktMi45LjIuNC43IDEgMS4yIDEuMyAxLjIuNCAwIC43LjQuNy44IDAgMS4zLTcuNC4x'
    b'LTExLTEuNi04LTQuMS05LTQuNS0xMS0zLjlhNC4zIDQuMyAwIDAgMC0yLjQgMi4zYy0xLjMg'
    b'My4zIDMuNCA1LjkgNS4zIDMgLjYtLjkuNS0xLjQtLjUtMi41LTEuNC0xLjQtMS4yLTEuNi42'
    b'LTEgMS4zLjUgMS40IDMuNi4yIDQuOC0xLjMgMS4zLTQuNSAxLTUuNy0uN3oiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iIzAwMCIgZD0iTTQxMi40IDI0OC42Yy0xLTEtLjItMS4yIDQuMy0xLjMg'
    b'NS42LS4xIDktMSAxMy0zLjYgMy4yLTIgNC4xLTEuNiAxIC41LTIuNyAyLTcgMy40LTExLjMg'
    b'My44bC01LjEuN2MtLjguMi0xLjcuMS0yLS4xeiIvPgogICAgPC9nPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'LK')

LK = b64_LK
index.append("LK")
index.append("LKA")
index.append("Sri Lanka")
catalog["LK"] = LK
catalog["LKA"] = LK
catalog["Sri Lanka"] = LK
country["Sri Lanka"] = ('LK', 'LKA', 0)
lookup["LK"] = ('LK', 'LKA', 'Sri Lanka', 0)
lookup["Colombo Sri Lanka"] = ('LK', 'LKA', 'Sri Lanka', 0)
lookup["LKA"] = ('LK', 'LKA', 'Sri Lanka', 0)
lookup["Sri Lanka"] = ('LK', 'LKA', 'Sri Lanka', 0)
details["LK"] = {"continent":"Asia","capital":"Colombo","currency":"Sri Lanka Rupee","web":".lk","lang":"si | ta | en","tz":"+05:30","altname":""}
#----------------------------------------------------------------------
b64_LR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWxyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'ImxyLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBjbGlwLXBhdGg9InVybCgjbHItYSkiIHRyYW5zZm9ybT0ic2NhbGUoLjkzNzUpIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNzY3Ljl2NTEySDB6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjMDA2IiBkPSJNMCAwaDIzMi43djIzMi44SDB6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYzAwIiBkPSJNMCA0NjQuOWg3NjcuOVY1MTJIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNj'
    b'MDAiIGQ9Ik0wIDQ2NS40aDc2Ny45VjUxMkgwem0wLTkyLjloNzY3Ljl2NDYuMkgwem0wLTkz'
    b'LjJoNzY2VjMyNkgwek0yMzIuNyAwaDUzNS4xdjQ2LjVIMjMyLjd6bTAgMTg2aDUzNS4xdjQ2'
    b'LjhIMjMyLjd6bTAtOTIuN2g1MzUuMXY0Ni41SDIzMi43eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZD0ibTE2Ni4zIDE3Ny41LTUwLjctMzEtNTAuNCAzMS4zIDE4LjctNTAuOS01MC4z'
    b'LTMxLjQgNjIuMy0uNCAxOS4zLTUwLjdMMTM1IDk1aDYyLjNsLTUwLjEgMzEuNyAxOS4xIDUw'
    b'Ljh6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'LR')

LR = b64_LR
index.append("LR")
index.append("LBR")
index.append("Liberia")
catalog["LR"] = LR
catalog["LBR"] = LR
catalog["Liberia"] = LR
country["Liberia"] = ('LR', 'LBR', 0)
lookup["LR"] = ('LR', 'LBR', 'Liberia', 0)
lookup["Monrovia Liberia"] = ('LR', 'LBR', 'Liberia', 0)
lookup["LBR"] = ('LR', 'LBR', 'Liberia', 0)
lookup["Liberia"] = ('LR', 'LBR', 'Liberia', 0)
details["LR"] = {"continent":"Africa","capital":"Monrovia","currency":"Liberian Dollar","web":".lr","lang":"en-LR","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_LS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWxzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwOTU0MyIgZD0iTTAgMzM2aDY0MHYx'
    b'NDRIMHoiLz4KICA8cGF0aCBmaWxsPSIjMDAyMDlmIiBkPSJNMCAwaDY0MHYxNDRIMHoiLz4K'
    b'ICA8cGF0aCBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS42IiBkPSJNMzE5LjYgMTUz'
    b'Yy0yLjcgMC01LjQgMy01LjQgM2wuMyAzMi40LTEwLjMgMTAuN2g4LjN2MTguNWwtNDkgNjYt'
    b'Ny4yLTIuNi0xMi43IDI3czMxLjMgMTkuNiA3Ni43IDE5YzQ5LjgtLjUgNzYuOS0xOS45IDc2'
    b'LjktMTkuOWwtMTMtMjYuNi02LjUgMi44LTQ5LjYtNjUuNnYtMTkuMWg4LjJMMzI1LjEgMTg4'
    b'di0zMi4ycy0yLjctMy01LjUtMi45eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSI4IiBkPSJNMzM2LjcgMjMwLjRoLTMzLjlzLTEyLjItMjUu'
    b'OS0xMC4zLTQ0YzItMTguNCAxMi42LTI3LjEgMjYuNi0yNy4zIDE2LjYtLjEgMjUuMiA4LjEg'
    b'MjcuOCAyNi42IDIuNiAxOC4zLTEwLjIgNDQuNy0xMC4yIDQ0Ljd6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTI2MC41IDI5Mi4xYy0uNi43LTQuNyA4LjktNC43IDguOWw3LTEuNS0y'
    b'LjMtNy40em00IDEwLjUtNy40IDIuNCA4LjkgMy41LTEuNS01Ljl6bTMuMy0xMC4zIDMuNyAx'
    b'MC45IDktMi42LTIuMy01LjItMTAuNC0zLjF6bTUuOCAxNC44IDEuMiA0LjQgMTIgMy00Ljgt'
    b'MTAuMi04LjQgMi44em0xMy4yLTkuMyA0LjMgMTAuMiA5LTMuNS0zLTQuNS0xMC4zLTIuMnpt'
    b'NiAxMy45IDEuNCAzLjggMTQgMi01LjktOS4yLTkuNiAzLjR6bTEzLjQtMTEgNS4yIDkuMSAx'
    b'My00LjgtMS40LTMuNS0xNi44LS43em03LjYgMTIuNCAyLjcgNC44IDE2LjItLjUtNi05LTEz'
    b'IDQuN3ptMTcuMS0xMiA0LjQgNy42IDEwLjQtNS0yLjgtNC0xMiAxLjR6bTE3IDUuOC0xMC4z'
    b'IDUuMSAyLjcgNC41IDEzLjgtMi4yLTYuMi03LjR6bTMuMy04IDUuMyA2LjcgOC43LTYuOS0z'
    b'LTMtMTEgMy4yem0xNS45IDMuNS04LjMgNi4zIDIuMiAzLjkgMTEuNC0zLTUuMy03LjJ6bTEx'
    b'LjQtMTMgMiAyLjktNS43IDguNS01LjktNy42IDkuNi0zLjh6bTMuOSA3LjMgMy41IDctNyAy'
    b'LjQtLjYtMy4zIDQtNnoiLz4KPC9zdmc+Cg==', 'LS')

LS = b64_LS
index.append("LS")
index.append("LSO")
index.append("Lesotho")
catalog["LS"] = LS
catalog["LSO"] = LS
catalog["Lesotho"] = LS
country["Lesotho"] = ('LS', 'LSO', 0)
lookup["LS"] = ('LS', 'LSO', 'Lesotho', 0)
lookup["Maseru Lesotho"] = ('LS', 'LSO', 'Lesotho', 0)
lookup["LSO"] = ('LS', 'LSO', 'Lesotho', 0)
lookup["Lesotho"] = ('LS', 'LSO', 'Lesotho', 0)
details["LS"] = {"continent":"Africa","capital":"Maseru","currency":"Loti | Rand","web":".ls","lang":"en-LS | st | zu | xh","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_LT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWx0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCIgdHJhbnNmb3JtPSJzY2FsZSguNjQxNDMgLjk2NzczKSI+CiAg'
    b'ICA8cmVjdCB3aWR0aD0iMTA2MyIgaGVpZ2h0PSI3MDguNyIgZmlsbD0iIzAwNmE0NCIgcng9'
    b'IjAiIHJ5PSIwIiB0cmFuc2Zvcm09InNjYWxlKC45Mzg2NSAuNjk2ODYpIi8+CiAgICA8cmVj'
    b'dCB3aWR0aD0iMTA2MyIgaGVpZ2h0PSIyMzYuMiIgeT0iNDc1LjYiIGZpbGw9IiNjMTI3MmQi'
    b'IHJ4PSIwIiByeT0iMCIgdHJhbnNmb3JtPSJzY2FsZSguOTM4NjUgLjY5Njg2KSIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZkYjkxMyIgZD0iTTAgMGg5OTcuOHYxNjQuNkgweiIvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'LT')

LT = b64_LT
index.append("LT")
index.append("LTU")
index.append("Lithuania")
catalog["LT"] = LT
catalog["LTU"] = LT
catalog["Lithuania"] = LT
country["Lithuania"] = ('LT', 'LTU', 0)
lookup["LT"] = ('LT', 'LTU', 'Lithuania', 0)
lookup["Vilnius Lithuania"] = ('LT', 'LTU', 'Lithuania', 0)
lookup["LTU"] = ('LT', 'LTU', 'Lithuania', 0)
lookup["Lithuania"] = ('LT', 'LTU', 'Lithuania', 0)
details["LT"] = {"continent":"Europe","capital":"Vilnius","currency":"Euro","web":".lt","lang":"lt | ru | pl","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_LU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWx1IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwYTFkZSIgZD0i'
    b'TTAgMjQwaDY0MHYyNDBIMHoiLz4KICA8cGF0aCBmaWxsPSIjZWQyOTM5IiBkPSJNMCAwaDY0'
    b'MHYyNDBIMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAxNjBoNjQwdjE2MEgweiIv'
    b'Pgo8L3N2Zz4K', 'LU')

LU = b64_LU
index.append("LU")
index.append("LUX")
index.append("Luxembourg")
catalog["LU"] = LU
catalog["LUX"] = LU
catalog["Luxembourg"] = LU
country["Luxembourg"] = ('LU', 'LUX', 0)
lookup["LU"] = ('LU', 'LUX', 'Luxembourg', 0)
lookup["Luxembourg Luxembourg"] = ('LU', 'LUX', 'Luxembourg', 0)
lookup["LUX"] = ('LU', 'LUX', 'Luxembourg', 0)
lookup["Luxembourg"] = ('LU', 'LUX', 'Luxembourg', 0)
details["LU"] = {"continent":"Europe","capital":"Luxembourg","currency":"Euro","web":".lu","lang":"lb | de-LU | fr-LU","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_LV = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWx2IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iIzk4MWUzMiIgZD0iTTAgMGg2NDB2MTkySDB6bTAgMjg4aDY0MHYxOTJIMHoiLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'LV')

LV = b64_LV
index.append("LV")
index.append("LVA")
index.append("Latvia")
catalog["LV"] = LV
catalog["LVA"] = LV
catalog["Latvia"] = LV
country["Latvia"] = ('LV', 'LVA', 0)
lookup["LV"] = ('LV', 'LVA', 'Latvia', 0)
lookup["Riga Latvia"] = ('LV', 'LVA', 'Latvia', 0)
lookup["LVA"] = ('LV', 'LVA', 'Latvia', 0)
lookup["Latvia"] = ('LV', 'LVA', 'Latvia', 0)
details["LV"] = {"continent":"Europe","capital":"Riga","currency":"Euro","web":".lv","lang":"lv | ru | lt","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_LY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWx5IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Imx5LWEiPgogICAgICA8cGF0aCBkPSJNMTY2LjctMjBoNjY2LjZ2NTAwSDE2Ni43eiIvPgog'
    b'ICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgY2xpcC1wYXRoPSJ1cmwoI2x5LWEpIiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCguOTYgMCAwIC45NiAtMTYwIDE5LjIpIj4KICAgIDxwYXRoIGZp'
    b'bGw9IiMyMzllNDYiIGQ9Ik0wLTIwaDEwMDB2NTAwSDB6Ii8+CiAgICA8cGF0aCBkPSJNMC0y'
    b'MGgxMDAwdjM3NUgweiIvPgogICAgPHBhdGggZmlsbD0iI2U3MDAxMyIgZD0iTTAtMjBoMTAw'
    b'MHYxMjVIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik01NDQuMiAxODUuOGE1NC4z'
    b'IDU0LjMgMCAxIDAgMCA4OC40IDYyLjUgNjIuNSAwIDEgMSAwLTg4LjRNNTMwLjQgMjMwbDg0'
    b'LjEtMjcuMy01MiA3MS41di04OC40bDUyIDcxLjV6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'LY')

LY = b64_LY
index.append("LY")
index.append("LBY")
index.append("Libya")
catalog["LY"] = LY
catalog["LBY"] = LY
catalog["Libya"] = LY
country["Libya"] = ('LY', 'LBY', 0)
lookup["LY"] = ('LY', 'LBY', 'Libya', 0)
lookup["Tripoli Libya"] = ('LY', 'LBY', 'Libya', 0)
lookup["LBY"] = ('LY', 'LBY', 'Libya', 0)
lookup["Libya"] = ('LY', 'LBY', 'Libya', 0)
details["LY"] = {"continent":"Africa","capital":"Tripoli","currency":"Libyan Dinar","web":".ly","lang":"ar-LY | it | en","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_MA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1hIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2MxMjcyZCIgZD0i'
    b'TTY0MCAwSDB2NDgwaDY0MHoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDYy'
    b'MzMiIHN0cm9rZS13aWR0aD0iMTEuNyIgZD0iTTMyMCAxNzkuNCAyODQuNCAyODlsOTMuMi02'
    b'Ny42SDI2Mi40bDkzLjIgNjcuNnoiLz4KPC9zdmc+Cg==', 'MA')

MA = b64_MA
index.append("MA")
index.append("MAR")
index.append("Morocco")
catalog["MA"] = MA
catalog["MAR"] = MA
catalog["Morocco"] = MA
country["Morocco"] = ('MA', 'MAR', 0)
lookup["MA"] = ('MA', 'MAR', 'Morocco', 0)
lookup["Rabat Morocco"] = ('MA', 'MAR', 'Morocco', 0)
lookup["MAR"] = ('MA', 'MAR', 'Morocco', 0)
lookup["Morocco"] = ('MA', 'MAR', 'Morocco', 0)
details["MA"] = {"continent":"Africa","capital":"Rabat","currency":"Moroccan Dirham","web":".ma","lang":"ar-MA | ber | fr","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_MC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1jIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZjMxODMwIiBkPSJNMCAwaDY0'
    b'MHYyNDBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDI0MGg2NDB2MjQwSDB6'
    b'Ii8+CiAgPC9nPgo8L3N2Zz4K', 'MC')

MC = b64_MC
index.append("MC")
index.append("MCO")
index.append("Monaco")
catalog["MC"] = MC
catalog["MCO"] = MC
catalog["Monaco"] = MC
country["Monaco"] = ('MC', 'MCO', 0)
lookup["MC"] = ('MC', 'MCO', 'Monaco', 0)
lookup["Monaco Monaco"] = ('MC', 'MCO', 'Monaco', 0)
lookup["MCO"] = ('MC', 'MCO', 'Monaco', 0)
lookup["Monaco"] = ('MC', 'MCO', 'Monaco', 0)
details["MC"] = {"continent":"Europe","capital":"Monaco","currency":"Euro","web":".mc","lang":"fr-MC | en | it","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_MD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1kIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjMDAzMTljIiBkPSJNMCAwaDIx'
    b'My4zdjQ4MEgweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZGUwMCIgZD0iTTIxMy4zIDBoMjEz'
    b'LjR2NDgwSDIxMy4zeiIvPgogICAgPHBhdGggZmlsbD0iI2RlMjExMCIgZD0iTTQyNi43IDBI'
    b'NjQwdjQ4MEg0MjYuN3oiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iI2ZmMTkwMCIgZmlsbC1y'
    b'dWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjciIGQ9Im0zNjAu'
    b'NCAzMjAuNCAyNC4yIDM1YzEuNCAyIDIuNyAzLjkuNyA1LjItMiAxLjMtMS40IDYuNCAwIDgu'
    b'NCAyLjcgMy45IDYgNC41IDggMy4ybDE4LjQtMTEuNmMyLTEuMiAyLjctNC41IDAtOC40LTEu'
    b'NS0yLTYtNC41LTgtMy4yLTIuMSAxLjMtMy41LS43LTQuOC0yLjZsLTI0LjMtMzUiLz4KICA8'
    b'cGF0aCBmaWxsPSIjYTc3YjNiIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLXdpZHRoPSIyLjUiIGQ9Ik0xNzcuMiA2OTYuM2MwIDI0LjQtOS42IDQ0LjMtMjEu'
    b'MyA0NC4zLTExLjcgMC0yMS4zLTE5LjktMjEuMy00NC4zUzE0NC4zIDY1MiAxNTYgNjUyczIx'
    b'LjMgMTkuOCAyMS4zIDQ0LjN6IiB0cmFuc2Zvcm09Im1hdHJpeCguNTI3MjggLS40MjM4NiAu'
    b'NDQzNTggLjUwMzg2IC0zMi40IDIwKSIvPgogIDxwYXRoIGZpbGw9IiNmZjE5MDAiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJtMjYy'
    b'IDMwNi4xLTIxLjUgMzYuN2MtMS4yIDItMi40IDQtNC41IDMtMi4xLTEuMi02LjYgMS43LTcu'
    b'OCAzLjgtMi40IDQtMS41IDcuMi43IDguNGwxOS4yIDEwLjJjMiAxLjEgNS40LjIgNy44LTMu'
    b'OCAxLjEtMi4yIDEuNC03LjMtLjctOC40LTIuMS0xLjEtMS0zLjIuMy01LjJsMjEuNC0zNi43'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2E3N2IzYiIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iMS43IiBkPSJNMzMxLjIgMjgwLjZoLTE5LjZjLS42LjYt'
    b'Ni4yIDM1LjYtMTIuMiA0OS03LjMgMTYuMy0yOS4yIDMwLjctMjkuMiAzMC43czEzLjEgNCAx'
    b'NyA2LjZjMS0uMyAyMi00LjcgMjQuNC0zMC4zIDIuNCAyNS42LTE0LjYgMzcuMy0xNC42IDM3'
    b'LjNzMjQuNCA3IDI0LjQgMjMuM2MwLTE2LjMgMjQuNC0yMy4zIDI0LjQtMjMuM3MtMTIuMi0x'
    b'MS43LTE0LjctMzcuM2M1IDI1LjYgMjMuNSAzMCAyNC41IDMwLjMgMy45LTIuNiAxNy02LjYg'
    b'MTctNi42cy0yMS45LTE0LjQtMjkuMi0zMC43Yy02LTEzLjQtMTEuNi00OC40LTEyLjItNDl6'
    b'bS04My0xMTYuNyAzNi42IDExLjdjMTIuMSAwIDI0LjQtMTEuNyAyNC40LTIzLjQuNC0yNi05'
    b'LjgtMzUtMTIuMi0zNWw0LjgtNC42LTcuMy03czIuNS0xMi4xIDI2LjktMTEuN2MyNC40LjUg'
    b'MjQuNCAxMS43IDI0LjQgMjMuM3MtMTIuMiAxMS43LTEyLjIgMzVjMCAxMS43IDEyLjIgMjMu'
    b'NCAyNC40IDIzLjRsMzYuNi0xMS43djExNi43SDI0OC4xVjE2My45eiIvPgogIDxnIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzAwMCI+CiAgICA8cGF0aCBzdHJva2Utd2lkdGg9Ii41IiBkPSJt'
    b'MzAyLjIgMjkyLjIgMTQuNiAxNSAxNC43LTE1IDE0LjYgMTUgMjkuMy0xNSAxNC4zIDE1Ljgg'
    b'MTUtMTUuOCAyMS42IDE1LjggMjIuMy0xNS44IDE0LjYgMTUgMTQuNy0xNSIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoLjE2NjcyIDAgMCAuNDY3NzMgMjUzLjkgMzEuOSkiLz4KICAgIDxwYXRoIHN0'
    b'cm9rZS13aWR0aD0iLjIiIGQ9Im00MzIuMyA0MzUuOC03LjEgMzltMTAuNi0zOXYzOW03LjEt'
    b'Mzl2MzltNy4xLTM5IDMuNSAzOW0zLjYtMzkgMy41IDM5IiB0cmFuc2Zvcm09Im1hdHJpeCgu'
    b'Njg5MDUgMCAwIC42NTg0MyAxNi4yIC0xNDQpIi8+CiAgPC9nPgogIDxnIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIyLjUiPgogICAgPHBhdGggZmlsbD0iI2E3N2IzYiIgZmlsbC1y'
    b'dWxlPSJldmVub2RkIiBkPSJNMzE4LjkgMzYxLjRjMzUuNCAxNy43IDM1LjQgNTMuMiAzNS40'
    b'IDcwLjktMS4yIDE2LjEgMCAzNTQuMyAwIDM1NC4zcy0yLjMtMjAtMTcuNy0zNS40TDMxOSA3'
    b'MzMuNWwtMTcuNy0xNy43Yy0xMy0xMS44LTE3LjctMzUuNS0xNy43LTUzLjJ2LTI0OHMwLTE3'
    b'LjggMzUuNC01My4yeiIgdHJhbnNmb3JtPSJtYXRyaXgoLS42ODkwNSAwIDAgLjY1ODQzIDQ0'
    b'My40IC0xNDQpIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJNMjgzLjUgNTc0Yy40IDAg'
    b'MTcuNy0xNy43IDE3LjctMTcuN2wxNy43IDE3LjcgMTcuNy0xNy43IDE3LjcgMTcuNyIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoLS42ODkwNSAwIDAgLjY1ODQzIDQ0My40IC0yMzcuMykiLz4KICAg'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik0yODMuNSA1NzRjLjQgMCAxNy43LTE3LjcgMTcuNy0x'
    b'Ny43bDE3LjcgMTcuNyAxNy43LTE3LjcgMTcuNyAxNy43IiB0cmFuc2Zvcm09Im1hdHJpeCgt'
    b'LjY4OTA1IDAgMCAtLjY1ODQzIDQ0My40IDUzMC4yKSIvPgogICAgPHBhdGggZmlsbD0ibm9u'
    b'ZSIgZD0iTTI4My41IDU3NGMuNCAwIDE3LjctMTcuNyAxNy43LTE3LjdsMTcuNyAxNy43IDE3'
    b'LjctMTcuNyAxNy43IDE3LjciIHRyYW5zZm9ybT0ibWF0cml4KC0uNjg5MDUgMCAwIC42NTg0'
    b'MyA0NDMuNCAtMTkwLjcpIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJtMzAxLjQgNTU3'
    b'LS4yIDE1OC44IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjY4OTA1IDAgMCAxLjI0OTExIDQ0My40'
    b'IC01NjYuOCkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Im0zMDEuNCA1MzkuMy0uMiAx'
    b'NzYuNSIgdHJhbnNmb3JtPSJtYXRyaXgoLS42ODkwNSAwIDAgMS4xMjExMSA0MzEuNCAtNDY0'
    b'KSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgZD0ibTMwMS40IDUzOS4zLS4yIDE3Ni41IiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCgtLjY4OTA1IDAgMCAxLjI1NTkgNDE5LjIgLTU0OC4zKSIvPgog'
    b'IDwvZz4KICA8ZyBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMi41Ij4KICAgIDxwYXRo'
    b'IGZpbGw9IiNhNzdiM2IiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMxOC45IDM2MS40YzM1'
    b'LjQgMTcuNyAzNS40IDUzLjIgMzUuNCA3MC45LTEuMiAxNi4xIDAgMzU0LjMgMCAzNTQuM3Mt'
    b'Mi4zLTIwLTE3LjctMzUuNEwzMTkgNzMzLjVsLTE3LjctMTcuN2MtMTMtMTEuOC0xNy43LTM1'
    b'LjUtMTcuNy01My4ydi0yNDhzMC0xNy44IDM1LjQtNTMuMnoiIHRyYW5zZm9ybT0ibWF0cml4'
    b'KC42ODkwNSAwIDAgLjY1ODQzIDE5OS4zIC0xNDQpIi8+CiAgICA8cGF0aCBmaWxsPSJub25l'
    b'IiBkPSJNMjgzLjUgNTc0Yy40IDAgMTcuNy0xNy43IDE3LjctMTcuN2wxNy43IDE3LjcgMTcu'
    b'Ny0xNy43IDE3LjcgMTcuNyIgdHJhbnNmb3JtPSJtYXRyaXgoLjY4OTA1IDAgMCAuNjU4NDMg'
    b'MTk5LjMgLTIzNy4zKSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgZD0iTTI4My41IDU3NGMu'
    b'NCAwIDE3LjctMTcuNyAxNy43LTE3LjdsMTcuNyAxNy43IDE3LjctMTcuNyAxNy43IDE3Ljci'
    b'IHRyYW5zZm9ybT0ibWF0cml4KC42ODkwNSAwIDAgLS42NTg0MyAxOTkuMyA1MzAuMikiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik0yODMuNSA1NzRjLjQgMCAxNy43LTE3LjcgMTcu'
    b'Ny0xNy43bDE3LjcgMTcuNyAxNy43LTE3LjcgMTcuNyAxNy43IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCguNjg5MDUgMCAwIC42NTg0MyAxOTkuMyAtMTkwLjcpIi8+CiAgICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBkPSJtMzAxLjQgNTU3LS4yIDE1OC44IiB0cmFuc2Zvcm09Im1hdHJpeCguNjg5MDUg'
    b'MCAwIDEuMjQ5MTEgMTk5LjMgLTU2Ni44KSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgZD0i'
    b'bTMwMS40IDUzOS4zLS4yIDE3Ni41IiB0cmFuc2Zvcm09Im1hdHJpeCguNjg5MDUgMCAwIDEu'
    b'MTIxMTEgMjExLjQgLTQ2NCkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Im0zMDEuNCA1'
    b'MzkuMy0uMiAxNzYuNSIgdHJhbnNmb3JtPSJtYXRyaXgoLjY4OTA1IDAgMCAxLjI1NTkgMjIz'
    b'LjYgLTU0OC4zKSIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSIjYTc3YjNiIiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIyLjUiIGQ9Ik0xNzcuMiA2'
    b'OTYuM2MwIDI0LjQtOS42IDQ0LjMtMjEuMyA0NC4zLTExLjcgMC0yMS4zLTE5LjktMjEuMy00'
    b'NC4zUzE0NC4zIDY1MiAxNTYgNjUyczIxLjMgMTkuOCAyMS4zIDQ0LjN6IiB0cmFuc2Zvcm09'
    b'Im1hdHJpeCguNjM2MDUgLjI1MzIzIC0uMjY1MDIgLjYwNzc4IDM2MS4xIC0xNjUuMikiLz4K'
    b'ICA8cGF0aCBmaWxsPSJyZWQiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTI0OC4xIDE3NS42'
    b'aDE0Ni41djcwSDI0OC4xeiIvPgogIDxwYXRoIGZpbGw9IiM1NjRkZmYiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgZD0iTTI0OC4xIDI0NS42aDE0Ni41djM1YzAgMjMuMy0zNi42IDIzLjMtNzMu'
    b'MiA0Ni42QzI4NC43IDMwNCAyNDggMzA0IDI0OCAyODAuNnYtMzV6Ii8+CiAgPHBhdGggZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjZmYwIiBzdHJva2Utd2lkdGg9IjIiIGQ9Ik0zMzYuNiA0ODUu'
    b'NGgyMTIuNlY2NDVjMCAzNS40LTUzLjEgMzUuNC0xMDYuMyA3MC45LTUzLjEtMzUuNS0xMDYu'
    b'My0zNS41LTEwNi4zLTcxVjQ4NS41eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjY4OTA1IDAgMCAu'
    b'NjU4NDMgMTYuMiAtMTQ0KSIvPgogIDxwYXRoIGZpbGw9IiNmZjAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIuNSIgZD0iTTM4NS42IDEyOS45'
    b'UzMzNSAxODUuNCAzMzUgMjM4LjVjMCA1My4xIDUzLjEgNzAuOSA1My4xIDcwLjlzLTE3Ljcg'
    b'MC0xNy43IDcwLjhjMCAzNS41IDUzLjEgMTcuOCA1My4xIDM1LjVzLS43IDYwLjUgMCA4OC42'
    b'YzAgMTcuNy0zNS40IDAtMzUuNCAxNy43IDAgOC44IDI2LjYgNTMuMSA1My4yIDUzLjFzNTMu'
    b'MS00NC4zIDUzLjEtNTMuMWMwLTE3LjctMzUuNCAwLTM1LjQtMTcuN3YtODguNmMwLTE3Ljcg'
    b'NTMuMSAwIDUzLjEtMzUuNSAwLTcwLjgtMTcuNy03MC44LTE3LjctNzAuOHM1My4yLTE3Ljcg'
    b'NTMuMi03MC45LTUwLjctMTA4LjYtNTAuNy0xMDguNiAyOC41IDczLjIgMjguNSAxMDguNmMw'
    b'IDE3LjctMTMuMyA1My4yLTQ4LjcgNTMuMiAwIDAtOS0xNy44LTE3LjcgMCAwIDAtMTAuMi0x'
    b'Ny44LTE3LjcgMC0yLjYgNi03LjItMTcuOC0xNy44IDAtNC40IDQuNy04LTE3LjgtMTcuNyAw'
    b'LTE3LjcgMC01My4xLTE3LjgtNTMuMS01My4yczMyLjktMTA4LjYgMzIuOS0xMDguNnoiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KC40ODIzNCAwIDAgLjMwOTE3IDEwOC41IDE0MC4xKSIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZjAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9IjIuNSIgZD0iTTM4Mi43IDI0OGMtMy42IDMuNiA0LjYgNjEuMyA3IDYzLjgg'
    b'My42IDMuNSAyNC45IDMuNSAyOC40IDAgMi41LTIuNSAwLTU2LjctMy41LTYwLjItMy42LTMu'
    b'Ni0yOS40LTYtMzItMy42eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjQ4MjM0IDAgMCAuMzA5MTcg'
    b'MTEwLjQgMjAxLjYpIi8+CiAgPHBhdGggZmlsbD0iI2ZmMCIgZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMi41IiBkPSJNMzgyLjcgMjQ4Yy0zLjYg'
    b'My42IDQuNiA2MS4zIDcgNjMuOCAzLjYgMy41IDI0LjkgMy41IDI4LjQgMCAyLjUtMi41IDAt'
    b'NTYuNy0zLjUtNjAuMi0zLjYtMy42LTI5LjQtNi0zMi0zLjZ6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgtLjQ4MjM0IDAgMCAuMzA5MTcgNTMyLjQgMjAxLjYpIi8+CiAgPHBhdGggZmlsbD0iI2Zm'
    b'MCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMi41'
    b'IiBkPSJNNDE0LjYgMjI4LjVhMTYgMTYgMCAxIDEtMzIgMCAxNiAxNiAwIDAgMSAzMiAweiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLjU1NDQgMCAwIC4zODU0MiA4Mi43IDE4My43KSIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmZjAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9IjIuNSIgZD0iTTQxNC42IDIyOC41YTE2IDE2IDAgMSAxLTMyIDAgMTYgMTYg'
    b'MCAwIDEgMzIgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC41NTQ0MSAwIDAgLjM4NTQzIDExOCAx'
    b'ODMuNykiLz4KICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zMzYuOCAzMDcuNWMw'
    b'IDEuNS0yIDIuNy00LjMgMi43LTIuNCAwLTQuMy0xLjItNC4zLTIuN3MyLTIuNyA0LjMtMi43'
    b'IDQuMyAxLjIgNC4zIDIuN3ptLTIyLjMgMGMwIDEuNS0xLjkgMi43LTQuMiAyLjctMi40IDAt'
    b'NC4zLTEuMi00LjMtMi43czEuOS0yLjcgNC4zLTIuN2MyLjMgMCA0LjIgMS4yIDQuMiAyLjd6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZmMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJtNDM5LjQgNTUwLTcuOC0xMC4zLTEyLjggMS43'
    b'IDEuOC0xMi44LTEwLjMtNy43IDEwLjMtNy44LTEuOC0xMi44IDEyLjggMS44IDcuOC0xMC4z'
    b'IDcuOCAxMC4zIDEyLjctMS44LTEuNyAxMi44IDEwLjIgNy44LTEwLjIgNy44IDEuNyAxMi43'
    b'LTEyLjgtMS43eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjY3MjI1IDAgMCAuNjQyMzcgMjYgLTEz'
    b'My4zKSIvPgogIDxwYXRoIGZpbGw9IiNmZjAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0ibTQ5NiA1OTEuNyAyMS4zIDEwLjcgMjEu'
    b'My0xMC43LTIxLjMtMTAuNi0yMS4yIDEwLjZ6IiB0cmFuc2Zvcm09Im1hdHJpeCguNjg5MDUg'
    b'MCAwIC42NTg0MyAxNi4yIC0xNDQpIi8+CiAgPHBhdGggZmlsbD0iI2ZmMCIgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJtNDk2IDU5'
    b'MS43IDIxLjMgMTAuNyAyMS4zLTEwLjctMjEuMy0xMC42LTIxLjIgMTAuNnoiIHRyYW5zZm9y'
    b'bT0ibWF0cml4KC42ODkwNSAwIDAgLjY1ODQzIC04OC44IC0xNDQpIi8+CiAgPHBhdGggZmls'
    b'bD0iI2ZmMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iMS4xIiBkPSJNNTM1IDY1OWMtMy41LTctMTQuMS0xMC42LTIxLjItMTAuNnMtMTQuMiAw'
    b'LTIxLjMgMTAuN2MwLTE0LjIgMTAuNS0yMS4zIDIxLjMtMjEuM2EyMi43IDIyLjcgMCAwIDEg'
    b'MjEuMiAyMS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoLjU5NzUzIC0uMzI3OSAuMzQzMTYgLjU3'
    b'MDk3IC0xNjUuMiA4Ni41KSIvPgogIDxwYXRoIGZpbGw9IiNmZjAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0iTTM4Ni4yIDY1MmE3'
    b'IDcgMCAxIDEtMTQuMSAwIDcgNyAwIDAgMSAxNC4xIDB6IiB0cmFuc2Zvcm09Im1hdHJpeCgu'
    b'Njg5MDUgMCAwIC42NTg0MyAxMy43IC0xNTUuNykiLz4KICA8cGF0aCBmaWxsPSIjZmYwIiBm'
    b'aWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9'
    b'Ik0zODYuMiA2NTJhNyA3IDAgMSAxLTE0LjEgMCA3IDcgMCAwIDEgMTQuMSAweiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjY4OTA1IDAgMCAuNjU4NDMgOC44IC0xMzkuNCkiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZmYwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjEiIGQ9Ik0zODYuMiA2NTJhNyA3IDAgMSAxLTE0LjEgMCA3IDcgMCAwIDEgMTQu'
    b'MSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLjY4OTA1IDAgMCAuNjU4NDMgNi40IC0xNDguNyki'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZmYwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0zODYuMiA2NTJhNyA3IDAgMSAxLTE0LjEgMCA3'
    b'IDcgMCAwIDEgMTQuMSAweiIgdHJhbnNmb3JtPSJtYXRyaXgoLjY4OTA1IDAgMCAuNjU4NDMg'
    b'MTguNiAtMTM5LjQpIi8+CiAgPHBhdGggZmlsbD0iI2ZmMCIgZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJNMzg2LjIgNjUyYTcgNyAw'
    b'IDEgMS0xNC4xIDAgNyA3IDAgMCAxIDE0LjEgMHoiIHRyYW5zZm9ybT0ibWF0cml4KC42ODkw'
    b'NSAwIDAgLjY1ODQzIDIxIC0xNDguNykiLz4KICA8cGF0aCBmaWxsPSIjZmYwIiBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0zODYu'
    b'MiA2NTJhNyA3IDAgMSAxLTE0LjEgMCA3IDcgMCAwIDEgMTQuMSAweiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoLjY4OTA1IDAgMCAuNjU4NDMgMTMuNyAtMTQ2LjQpIi8+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIj4KICAgIDxwYXRoIGZpbGw9IiNkYTQ1MDAiIGQ9Ik0yOTcuOCAxMjAuNGMt'
    b'MTIuNCAwLTE0IDItMTkuNiAzLjkgMC01LjQgMTMuOC0xMS43IDI2LTExLjcgMCAzLjktMy4y'
    b'IDcuOC02LjQgNy44eiIvPgogICAgPHBhdGggZmlsbD0iI2NhYzljNyIgZD0iTTMxNi41IDEw'
    b'OGMwIDIuNS0yLjIgNC42LTQuOSA0LjZzLTQuOS0yLjEtNC45LTQuNyAyLjItNC42IDQuOS00'
    b'LjYgNC45IDIgNC45IDQuNnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZjAiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0zNjEuNCAzNTcuOXYxMC42aDE3Ljd2NTMuMWgx'
    b'MC43di01My4xaDE3Ljd2LTEwLjZoLTE3Ljd2LTE0LjJIMzc5djE0LjJoLTE3Ljd6IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCguNjg5MDUgMCAwIC42NTg0MyAxNi4yIC0xNDQpIi8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZGE0NTAwIiBkPSJNMzA0LjMgMTEyLjZhNzguNSA3OC41IDAgMCAwLTI5LjMg'
    b'My45YzAtNy4yIDguNC0xNS42IDIyLjgtMTUuNiAzLjIgMCA2LjUgNy44IDYuNSAxMS43eiIv'
    b'PgogIDwvZz4KICA8ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgPHBhdGggZmlsbD0iIzAw'
    b'ODUwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNNjcuMyA2MTNjLTE0'
    b'LjItMTQuMi0xNi42LTIxLjQgMy42LTEwLjFsMjgzLjcgMjQ3LjUtMy40IDdMNjcuNCA2MTN6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCguMzg4MjEgLjI5NjUzIC0uMTQwNzMgLjIzNjkyIDIzNy40'
    b'IDcxLjMpIi8+CiAgICA8cGF0aCBmaWxsPSIjMDA4ZjAwIiBkPSJNMjI4LjQgMzMwLjRjLjgt'
    b'MTAuNi0xOC42LTIyLTE5LjQtMjEuMy0uNy44IDEuMiA3IDQuOSAxMC4xLTctMy42LTE0LjQt'
    b'NS44LTE0LjYtNC4zLS42IDIuMiAxMSA3LjIgMTIgOS4yIDAgMS40LTguNiAxLjItOC40IDIu'
    b'Ni4yIDEuNCAyNC4zIDEzLjYgMjUuNSAzLjd6TTIwOSAyOTkuNmMuOC0xMC42LTE4LjYtMjIt'
    b'MTkuMy0yMS4zLS44LjcgMS4xIDYuOSA0LjggMTAuMS03LTMuNi0xNC40LTUuOS0xNC42LTQu'
    b'My0uNSAyLjEgMTEgNy4yIDEyIDkuMi4xIDEuNC04LjUgMS4yLTguNCAyLjYuMiAxLjQgMjQu'
    b'MyAxMy41IDI1LjUgMy43em0tMTQuOC0yOGMuOC0xMC42LTE4LjYtMjItMTkuNC0yMS4zLS43'
    b'LjcgMS4yIDYuOSA0LjkgMTAuMS03LTMuNi0xNC40LTUuOS0xNC42LTQuMy0uNSAyLjEgMTEg'
    b'Ny4yIDEyIDkuMiAwIDEuNC04LjUgMS4yLTguNCAyLjYuMiAxLjQgMjQuMyAxMy42IDI1LjUg'
    b'My43em0tMTQuNi0zMC40Yy43LTEwLjUtMTguNi0yMi0xOS40LTIxLjMtLjguOCAxLjIgNyA0'
    b'LjggMTAuMi03LTMuNy0xNC40LTUuOS0xNC41LTQuMy0uNiAyLjEgMTEgNy4yIDExLjkgOS4x'
    b'LjEgMS40LTguNSAxLjMtOC4zIDIuNy4xIDEuNCAyNC4yIDEzLjUgMjUuNSAzLjZ6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjMDA4ZjAwIiBkPSJNMTg0LjYgMjM5LjljOS40LTUuNyA3LjUtMjcu'
    b'NCA2LjUtMjcuNi0xLjEtLjEtNS4yIDUtNS43IDkuOC0xLjEtNy42LTMuNi0xNC42LTUtMTMu'
    b'OC0yLjEuOC40IDEyLjctLjcgMTQuNi0xIDEtNi01LjgtNy00LjgtMS4yIDEgMi44IDI2Ljcg'
    b'MTIgMjEuOHptMTMuNiAyNi42YzEwLjgtMi40IDE2LjctMjMuNCAxNS43LTIzLjlzLTYuNiAz'
    b'LTguNyA3LjRjMS42LTcuNSAxLjctMTQuOSAwLTE0LjYtMi4zLjEtNCAxMi4xLTUuNyAxMy41'
    b'LTEuMy42LTMuNy03LjMtNS02LjgtMS40LjYtNi42IDI2LjEgMy43IDI0LjR6bTE2LjIgMjcu'
    b'MmM5LjktNC44IDEwLTI2LjYgOS0yNi44LTEtLjMtNS41IDQuNS02LjUgOS4yLS40LTcuNy0y'
    b'LjItMTQuOC0zLjctMTQuMS0yLjIuNi0uOCAxMi42LTIgMTQuNC0xLjIuOS01LjUtNi4zLTYu'
    b'Ny01LjQtMS4yLjguNCAyNi44IDEwIDIyLjd6bTE3LjYgMzUuNmMxMC4zLTMuOSAxMi44LTI1'
    b'LjUgMTEuOC0yNS45LTEtLjMtNiA0LTcuNSA4LjYuNC03LjctLjYtMTUtMi4yLTE0LjQtMi4z'
    b'LjQtMi4xIDEyLjUtMy41IDE0LjItMS4zLjctNC44LTYuOC02LTYtMS4zLjYtMi41IDI2Ljcg'
    b'Ny40IDIzLjV6Ii8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiNmZjE5MDAiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0iTTIwOSA3NzZj'
    b'MCA3LjgtMTAuMiAxNC4yLTIzIDE0LjJzLTIzLTYuNC0yMy0xNC4yIDEwLjMtMTQuMiAyMy0x'
    b'NC4yIDIzIDYuNCAyMyAxNC4yeiIgdHJhbnNmb3JtPSJtYXRyaXgoLjYwMTY0IC4zMjA5NyAt'
    b'LjMzNTkgLjU3NDkgMzg5LjYgLTE0Ni44KSIvPgogIDxnIGZpbGw9IiNmZjAiIGZpbGwtcnVs'
    b'ZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii41Ij4KICAgIDxwYXRo'
    b'IGQ9Ik0xNTYgNDE0LjZ2LTcuMWg3di03LjFoN3Y3aDcuMnY3LjJIMTcwdjE3LjdoLTd2LTE3'
    b'LjdoLTd6bTcgNjAuMmg3djIwNS41aC03eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjQ5ODg3IC4x'
    b'NTcxIC0uMTgyNiAuNDcxMyA0NTEuNCAtMy43KSIvPgogICAgPHBhdGggZD0iTTE1OS40IDY3'
    b'Ni44aDE0LjJ2NTYuN2gtMTQuMnpNMTU2IDQzOS40aDIxLjNjMTQuMSAwLTMuNiAzOS0zLjYg'
    b'MzloLTE0LjFzLTE3LjgtMzktMy42LTM5em0xNy42LTUuNGMwIDMtMy4xIDUuNC03IDUuNHMt'
    b'Ny4xLTIuNC03LjEtNS4zIDMuMS01LjQgNy01LjQgNy4xIDIuNCA3LjEgNS40eiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjQ5ODg3IC4xNTcxIC0uMTgyNiAuNDcxMyA0NTEuNCAtMy43KSIvPgog'
    b'IDwvZz4KICA8cGF0aCBmaWxsPSIjZmYxOTAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0yMDkgNzc2YzAgNy44LTEwLjIgMTQu'
    b'Mi0yMyAxNC4ycy0yMy02LjQtMjMtMTQuMiAxMC4zLTE0LjIgMjMtMTQuMiAyMyA2LjQgMjMg'
    b'MTQuMnoiIHRyYW5zZm9ybT0ibWF0cml4KC41NzQ0OSAtLjM2MzU3IC4zODA0OCAuNTQ4OTUg'
    b'LTIuMyA0LjIpIi8+Cjwvc3ZnPgo=', 'MD')

MD = b64_MD
index.append("MD")
index.append("MDA")
index.append("Republic of Moldova")
catalog["MD"] = MD
catalog["MDA"] = MD
catalog["Republic of Moldova"] = MD
country["Republic of Moldova"] = ('MD', 'MDA', 0)
lookup["MD"] = ('MD', 'MDA', 'Republic of Moldova', 0)
lookup["Chisinau Republic of Moldova"] = ('MD', 'MDA', 'Republic of Moldova', 0)
lookup["MDA"] = ('MD', 'MDA', 'Republic of Moldova', 0)
lookup["Republic of Moldova"] = ('MD', 'MDA', 'Republic of Moldova', 0)
details["MD"] = {"continent":"Europe","capital":"Chisinau","currency":"Moldovan Leu","web":".md","lang":"ro | ru | gag | tr","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_ME = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1lIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2QzYWUzYiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2M0MDMwOCIgZD0iTTI0IDI0aDU5'
    b'MnY0MzJIMjR6Ii8+CiAgPHBhdGggZmlsbD0iI2I5NmIyOSIgZD0iTTQyNC41IDIzNi4xYTU4'
    b'IDU4IDAgMCAwIDE5LjQtOS4yYzctNS42IDguMy0xMC4xIDguOC0xMi41LjYtMi40LjgtNC4z'
    b'LTEtMy0xLjggMS40LTcuMSA1LjYtMTAuNyA3LjYtMy43IDItNyAzLTkgMy42LTIgLjUtMy42'
    b'LjktMS43LjEgMi0uNyA4LjEtMi45IDEzLTcuNyA0LjctNC44IDguNS0xMiA4LjYtMTYuNCAw'
    b'LTQuNC0uMy00LTEuNy0zLTEuNCAxLjEtNi40IDcuMy05LjMgOS43YTkwIDkwIDAgMCAxLTku'
    b'NyA2LjljLTIuMyAxLjMtNS41IDIuOC0xLS4zIDQuNS0zIDEzLTEwLjMgMTYuNS0xOS43YTM1'
    b'LjQgMzUuNCAwIDAgMCAyLjctMTUuOGMwLTEtLjgtMi44LTEuNi0xLjEtLjggMS43LTYuNSAx'
    b'My0xMSAxOC00LjYgNC44LTMuNSAzLjktNC42IDQuNy0xIC44LTIuNyAyLjItLjUtLjZhNTEu'
    b'MiA1MS4yIDAgMCAwIDEyLjItMzEuN2MwLTMuNi0xLjUtOC42LTIuMi0xMC4xLS43LTEuNS0x'
    b'LjQtMi42LTEuNy0uOWExOTEgMTkxIDAgMCAxLTUuOCAxOC40IDc1IDc1IDAgMCAxLTYuNyAx'
    b'Mi44Yy0uOCAxLjEtMi44IDMuNi0uNi0uNWE3Ny40IDc3LjQgMCAwIDAgNy0yNy42IDQ0IDQ0'
    b'IDAgMCAwLTIuNi0yMC45Yy0xLjYtMy4xLTMtNC4yLTMtNC4ycy4zIDcuOC0yIDE5LTUuNyAx'
    b'Ny01LjcgMTctMS41IDEuNy0uNS0xYTYyLjQgNjIuNCAwIDAgMCAxLjQtMzQuNWMtMi4zLTcu'
    b'NS02LjItMTEuMy02LjItMTEuMy0xIDEwLjctLjkgMjQuNS00LjggMzUuNy0uNy0uNy0xLjct'
    b'MS45LTIuMS42YTYzLjEgNjMuMSAwIDAgMS03IDE5LjRjLTQuOCA4LjgtNi44IDEwLTYuOCAx'
    b'MGwtMS41LTMuNGMtLjYtMS4yLTEtMS44LTEuOC0uMnMtMy41IDcuOC05LjQgMTQuNi05LjIg'
    b'MTAuMi05IDE1LjNjLjEgNSAyLjggNy43IDYuNCAxMCAzLjYgMi4zIDQuMiAzLjYgMy43IDYu'
    b'NC0uNiAyLjgtMy44IDMuNy02LjYgMy44LTIuNy4xLTYuMi0uMS03LjUuNi0xLjIuNy0xLjMg'
    b'Mi41LTIuNiAzLjctMS4yIDEuMy0xLjggMi0zIDIuMmwtMSAuMWMtLjItMTMuNSA1LTE5LjUg'
    b'NS0xOS41bC0xNC42LTE3LjFhNTAuOCA1MC44IDAgMCAxLTIuMiAxIDQgNCAwIDAgMC0uNC0u'
    b'NiAxMSAxMSAwIDAgMS0yLjYtNy44Yy43IDAgMi4yLjYgMy41LjMgMS4zLS4yLjMtMS42IDAt'
    b'Mi44LS41LTEuMy0uOS01LjctLjYtNy4zbC40LTIuM3MyLjEgMi4zIDMuNCAyLjNjMS4zIDAg'
    b'MS4yLTEuMyAxLjQtMi44LjMtMi4yIDEuMy01IDMtNi41IDAgMCAyLjQgMS42IDUgMS42czYu'
    b'Mi0uNyA5LTMuNWMzLTIuNyAyLjktMy4zIDIuOS0zLjNzNS4zIDEuOCA5LjMgMmM0IC4yIDgu'
    b'My0uNCAxMC40LTQuNyAyLTQuMi0uNi04LjItMS04LjgtLjYtLjctMS45LTEuMi0xLjkgMHMu'
    b'MSA0LjQtMi40IDZjLTIuNCAxLjYtNC4zIDEuNS02LjYuOGEyMC41IDIwLjUgMCAwIDAtMTMu'
    b'MS0uNCAxNyAxNyAwIDAgMSA2LjEtNC4yYzMtLjkgNC44LjQgNS44IDEuNiAxIDEuMiAxLjkg'
    b'MyAyLjcuMy44LTIuOC4zLTYtMS04YTcuNiA3LjYgMCAwIDAtNy4yLTNjLTMgLjItNCAuNy00'
    b'IC43cy0xLjUtNC4zLTUuMy01YTIxIDIxIDAgMCAwLTE0IDNzLTMuMS43LTYuNC0uMmEyMSAy'
    b'MSAwIDAgMS01LjQtMi44bDEuMS0zLjUgMS45LS42YzEtLjQuNy0uNy45LTEuNS4xLS44LTEu'
    b'OC0yLjItMS44LTIuMnMtLjMtMi41IDIuOS00LjFsMi44LTEuNHMxLjkuMyAyLjYtLjJjLjgt'
    b'LjYuOC0xIC44LTFzMS40LS40IDItMS4yYy40LS45LjUtMi4xLjItMy4xLS40LTEtLjktMS4y'
    b'LS40LTEuN3MxLTEuNiAxLTIuNGwuMS0xczEuMS0uNCAxLTJjMC0xLjctLjktMi4zLTEuNC0y'
    b'LjVsLS45LS4xczAtMS0uOS0yLjNjLS44LTEuNC0xLjQtMi0xLjQtMnMuNi0uNC4zLTEuNS0x'
    b'LjEtMS43LTEuOS0yYy0uNy0uMi0xLjUgMC0xLjUgMGwtMy43LTIuMS0xLjUtLjhzMC0xLS40'
    b'LTEuNmMtLjUtLjUtMS41LS44LTItLjhzLTEgLjMtMSAuM2wtNi0xLjRjLTEuOC0uMi0xLjkt'
    b'LjQtMS45LS40cy0zLjgtMS44LTUuMi0ybC0yLS41czEuNi0xLjggMS43LTRhNiA2IDAgMCAw'
    b'LTIuOC01bC0xLjYtLjhWOTNsMi44LjMuMi00LjYtMi43LjMuNC0yLjdoLTUuOGwuNCAyLjct'
    b'Mi44LS4yLjMgNC41IDMtLjQtLjQgMS43cy0xIC4yLTIgLjlhNS40IDUuNCAwIDAgMC0yLjYg'
    b'NC43YzAgMi4yIDEuMyA0IDEuMyA0bC0xLjguNGMtMS41LjMtNS4zIDIuMS01LjMgMi4xczAg'
    b'LjItMS44LjRsLTYgMS40cy0uNi0uMy0xLS4zLTEuNi4zLTIgLjhjLS40LjYtLjUgMS42LS41'
    b'IDEuNmwtMS40LjgtMy43IDIuMXMtLjgtLjItMS42IDBjLS43LjMtMS41IDEtMS44IDItLjMg'
    b'MS4xLjMgMS42LjMgMS42cy0uNi41LTEuNSAxLjlhNiA2IDAgMCAwLS45IDIuM2wtLjguMWMt'
    b'LjYuMi0xLjUuOC0xLjUgMi41IDAgMS42IDEgMiAxIDJ2MWMuMS44LjYgMiAxLjEgMi40LjUu'
    b'NSAwIC43LS4zIDEuNy0uNCAxLS4zIDIuMi4yIDMgLjUgMSAyIDEuNCAyIDEuNHMwIC4zLjcu'
    b'OSAyLjYuMiAyLjYuMmwyLjkgMS40YzMuMiAxLjYgMi45IDQgMi45IDRzLTIgMS41LTEuOCAy'
    b'LjNjLjEuOCAwIDEuMS45IDEuNWwxLjkuNiAxIDMuNWEyMSAyMSAwIDAgMS01LjQgMi44Yy0z'
    b'LjIuOS02LjQuMi02LjQuMmEyMSAyMSAwIDAgMC0xMy45LTNjLTMuOC43LTUuNCA1LTUuNCA1'
    b'cy0xLS40LTQtLjhjLTMtLjMtNS44IDEtNy4xIDMtMS40IDIuMS0xLjggNS4zLTEgOC4xczEu'
    b'Ni45IDIuNi0uMyAyLjgtMi41IDUuOC0xLjZjMyAxIDYgNCA2LjIgNC4yIDAgMC0uNS0uMy0z'
    b'LjktLjgtMy43LS41LTYuOS40LTkuMiAxLjItMi4zLjctNC4yLjgtNi43LS44LTIuNC0xLjYt'
    b'Mi40LTQuOC0yLjQtNiAwLTEuMi0xLjMtLjctMS44IDAtLjQuNi0zIDQuNi0xIDguOCAyIDQu'
    b'MyA2LjMgNSAxMC40IDQuNyA0LS4yIDkuMy0yIDkuMy0yczAgLjYgMi44IDMuM2ExMyAxMyAw'
    b'IDAgMCA5IDMuNWMyLjcgMCA1LTEuNiA1LTEuNiAxLjcgMS41IDIuNyA0LjMgMyA2LjUuMiAx'
    b'LjUuMSAyLjggMS40IDIuOCAxLjQgMCAzLjUtMi4zIDMuNS0yLjNsLjQgMi4zYTI2IDI2IDAg'
    b'MCAxLS42IDcuM2MtLjQgMS4yLTEuNCAyLjYgMCAyLjggMS4zLjMgMi43LS4yIDMuNS0uMyAw'
    b'IDMuMi0uNyA1LjMtMi42IDcuOGE0LjQgNC40IDAgMCAwLS40LjYgNTMuOSA1My45IDAgMCAx'
    b'LTIuMi0xbC0xNC42IDE3LjFzNS4zIDYgNSAxOS42YTIwLjYgMjAuNiAwIDAgMS0xLS4yYy0x'
    b'LjItLjItMS44LTEtMy0yLjItMS4zLTEuMi0xLjQtMy0yLjYtMy43LTEuMy0uOC00LjgtLjUt'
    b'Ny41LS42LTIuOCAwLTYtMS02LjYtMy44LS41LTIuOC4xLTQgMy43LTYuNCAzLjYtMi4zIDYu'
    b'My01IDYuNC0xMCAuMi01LjEtMy04LjUtOS0xNS4zLTUuOS02LjgtOC42LTEzLTkuNC0xNC42'
    b'LS44LTEuNi0xLjItMS0xLjguMmwtMS41IDMuM3MtMi0xLjItNi44LTEwYTYzIDYzIDAgMCAx'
    b'LTctMTkuM2MtLjQtMi41LTEuNC0xLjMtMi0uNi00LTExLjItMy44LTI1LTQuOS0zNS43IDAg'
    b'MC0zLjkgMy44LTYuMiAxMS4zLTIgNi44LTIgMTQuOS0xLjMgMjIgLjYgNi43IDIgMTAuNyAy'
    b'LjcgMTIuNSAxIDIuNy0uNSAxLS41IDFzLTMuNC01LjgtNS43LTE3Yy0yLjMtMTEuMi0yLTE5'
    b'LTItMTlzLTEuNCAxLTMgNC4yYTQ0IDQ0IDAgMCAwLTIuNiAyMSA3Ny40IDc3LjQgMCAwIDAg'
    b'NyAyNy41YzIuMiA0IC4yIDEuNi0uNi41YTcxIDcxIDAgMCAxLTYuNy0xMi44Yy0yLTUuNS01'
    b'LjYtMTYuNi01LjgtMTguNC0uMy0xLjctMS0uNi0xLjcuOXMtMi4zIDYuNS0yLjIgMTAuMmE1'
    b'MS4yIDUxLjIgMCAwIDAgMTIuMiAzMS42YzIuMiAyLjguNSAxLjQtLjUuNi0xLS44IDAgLjEt'
    b'NC41LTQuN2E5MS43IDkxLjcgMCAwIDEtMTEtMThjLS45LTEuNy0xLjYuMS0xLjcgMS4xLS4x'
    b'IDEtLjcgNi41IDIuNyAxNS44IDMuNSA5LjQgMTIgMTYuNyAxNi41IDE5LjcgNC41IDMuMSAx'
    b'LjMgMS42LTEgLjNhOTAgOTAgMCAwIDEtOS43LTYuOWMtMi45LTIuNC03LjktOC42LTkuMy05'
    b'LjctMS40LTEtMS43LTEuNC0xLjcgMyAuMSA0LjQgMy45IDExLjYgOC43IDE2LjQgNC44IDQu'
    b'OCAxMSA3IDEyLjkgNy43IDEuOS44LjMuNC0xLjctLjFhNDAuMiA0MC4yIDAgMCAxLTktMy42'
    b'IDkzIDkzIDAgMCAxLTEwLjctNy42Yy0xLjgtMS40LTEuNi42LTEgMyAuNSAyLjQgMS45IDYu'
    b'OSA4LjggMTIuNWE1Ny43IDU3LjcgMCAwIDAgMTkuNCA5LjJjMi45LjguOS44LjkuOGwtNi44'
    b'LTEuNGE3MS4zIDcxLjMgMCAwIDEtMTYuNy03LjNjLTIuMy0xLjUtMi43LTItMi40IDFhMjAg'
    b'MjAgMCAwIDAgOC45IDEyLjkgNDkuNiA0OS42IDAgMCAwIDE3LjIgNC44YzIuNS4xIDEuOC40'
    b'LjcuNWE1MC41IDUwLjUgMCAwIDEtMTkuMi0zLjJsLS41LTJjLS4yLTEuMi0uOS0xLTEuMi0u'
    b'OC0uNC4zLS43LjUtMiAxLjEtMS4zLjctMS4zLS4xLTEuNC0uNWwtLjMtM2MwLS44LS41LS45'
    b'LTEuMS0uNmwtNC43IDJjLTEgLjQgMCAxLjMuNSAyLjNhMTQ3LjMgMTQ3LjMgMCAwIDAgMS41'
    b'IDIuNmwtMy43IDFjLS44LjItLjYuOC0uMyAxLjRsMS45IDQuNmMuMy44IDEuMS4zIDEuMS4z'
    b'bDIuNy0xLjYgMSAzLjdzLTEuMy4zLTIuNyAxLjJjLTEuMyAxLTEgMi4zLjcgMi43IDEuNi41'
    b'IDMuNiAxLjQgNS43IDUuMyAyLjIgMy45IDIuNyAxMC45IDQgMjIgMS40IDExIDguNCAxNi42'
    b'IDkuNCAxNy4zIDEgLjcuNCAxLjMuNCAxLjNzLTEgMS40LS41IDMuNWE1LjMgNS4zIDAgMCAw'
    b'IDMuMiAzLjhjMSAuMy43IDEuMy43IDEuM3MtLjUgMi4zIDAgNi43Yy41IDQuMyA0IDkuMSA1'
    b'IDEwIDEgLjggMSAxLjIgMSAxLjYtLjIuMy0uOSAwLTIgMWExMi4yIDEyLjIgMCAwIDAtMy40'
    b'IDMuNmMtLjggMS42LS41IDIuNS0uMiA0LjUuMiAyLjEgMy4zIDQgMy4zIDRzLS42LjEtLjcg'
    b'MS43Yy0uMSAxLjUgMSAzLjIgMi40IDQuNCAxLjMgMSA0IDEuNiA0IDEuNmwuMyAyLjJjLjIg'
    b'MSAxLjkgMS45IDMgMi41IDEuMS42IDMuMy4zIDQuMi0uMi45LS40IDEuNS4xIDIgMSAuNiAx'
    b'IC40IDQuNC40IDUuOCAwIDEuNC0uOCAyLjgtLjQgMy41LjUuNyAxLjguMiAzLjItLjUgMS4z'
    b'LS44IDEuNi0uMiAyLjguNWE5IDkgMCAwIDAgMy41IDEuNGMuNSAwIC4zLTEuMy4zLTIuM3Mu'
    b'Mi0zLjQuNy0zLjhjLjItLjIgMi4zLS4zIDMuOC0xIC43LS4zIDEuNy0uNiAxLjctMS4zLjEt'
    b'LjctMS0uNy0zLjItMS45LTIuMy0xLjEtMi43LTEuOC00LjItMi44LTEuNC0xLS43LTEuMy0u'
    b'Ny0xLjggMC0uNC43LS45IDEtMS40LjItLjYgMC0xLjggMC0xLjhsMS44LTEuOCAyLTIuM2Mu'
    b'OC0uNiAyLTMuNiAyLjctNC41LjgtMSAyLjUtMiAzLjYtMy40YTI5LjcgMjkuNyAwIDAgMSAx'
    b'MS4zLTcuNnMtLjEgMi42IDEgMy45IDIuNi0xIDcuNS00LjVjNS0zLjUgOC42LTQuNyA4LjYt'
    b'NC43bDIuNCAzLjNjMS4zIDEuNiAyLjUtLjEgOC41LTguNSA0LjgtNi41IDExLTEyLjYgMTMu'
    b'NS0xNC44bDEuMy42LS40IDFjLS41IDEuOC0xLjQgMy0yLjYgNS4zLTEuMSAyLjQtMyAzLTUg'
    b'Ni4ycy0yLjQgNS41LTIuNiA4LjhjLS4yIDMuMyAxLjcgNCAxLjcgNHMtMyAzLTQgNS4yYy0u'
    b'OSAyLjItMS4zIDYuNy0xLjMgNi43cy0uNS4yLTEuNiAyLjUtMy4xIDIuNi02IDUuNWMtMyAz'
    b'LTYuMiA0LjItNy43IDUtMS41IDEtMSAxLjktLjcgMyAuNCAxLjIgMi41IDIuNCA1IDMuMyAy'
    b'LjMuOSAzLjIuNSA0LjguNSAxLjctLjEuNCAxLjItLjMgMS45cy0xLjYgMy4xLTEuNSA1Ljhj'
    b'LjIgMi43IDIuMiAyIDQuNyAxLjZhMjggMjggMCAwIDAgNS4zLTEuNmwtLjIuOGMtLjMuNy0u'
    b'NCAxLjMtLjQgMy40IDAgMi4xLjMgMy4yIDEgMy43LjUuNiAxLjgtLjYgMi43LS45LjktLjIg'
    b'Mi40LTEuMSA0LjYtMS42IDIuMi0uNSAzLTEuNSAzLTEuNXMtLjUuNy0uNiAyLjJjLS4yIDEu'
    b'Ni0uMSAzLjguMiA1LjJhOS40IDkuNCAwIDAgMCAyLjkgNC4yYzEuNSAxLjQgMS44LjggMy0x'
    b'IDEtMS43IDMuMy0zLjkgMy4zLTMuOWwxLjcgNS41YzEuNSA0LjkgNi41IDkgNi41IDlzNS00'
    b'LjEgNi41LTlsMS42LTUuNXMyLjMgMi4yIDMuNCA0YzEuMSAxLjcgMS41IDIuMyAzIDFhOS40'
    b'IDkuNCAwIDAgMCAyLjgtNC4zYy4zLTEuNC40LTMuNi4zLTUuMi0uMi0xLjUtLjctMi4yLS43'
    b'LTIuMnMuOCAxIDMgMS41IDMuOCAxLjQgNC43IDEuNmMuOS4zIDIuMSAxLjUgMi43IDEgLjYt'
    b'LjYgMS0xLjcgMS0zLjggMC0yLjEtLjEtMi43LS40LTMuNGwtLjMtLjhzMi45IDEuMiA1LjQg'
    b'MS42YzIuNS41IDQuNSAxIDQuNi0xLjZhMTAgMTAgMCAwIDAtMS40LTUuOGMtLjctLjctMi0y'
    b'LS40LTIgMS43LjEgMi41LjUgNS0uNCAyLjMtMSA0LjQtMi4xIDQuOC0zLjMuNC0xLjEuOS0y'
    b'LS43LTMtMS41LS44LTQuNy0yLTcuNi01LTMtMi45LTUtMy4yLTYtNS41LTEuMS0yLjMtMS42'
    b'LTIuNS0xLjYtMi41cy0uNS00LjUtMS40LTYuN2MtMS0yLjItNC01LjItNC01LjJzMi0uNyAx'
    b'LjctNGMtLjItMy4zLS41LTUuNS0yLjUtOC44LTIuMS0zLjItNC0zLjgtNS02LjItMS4zLTIu'
    b'NC0yLjItMy41LTIuNy01LjJsLS40LTFhMTQ2IDE0NiAwIDAgMSAxLjgtLjhjMi40IDIuMiA4'
    b'LjcgOC4yIDEzLjUgMTQuOCA2IDguNCA3LjIgMTAuMSA4LjUgOC40bDIuNC0zLjJzMy43IDEu'
    b'MiA4LjYgNC43YzUgMy41IDYuNCA1LjcgNy41IDQuNC42LS42LjgtMS43LjgtMi42YTEwNCAx'
    b'MDQgMCAwIDEgMTEuOCA0LjJjNC4zIDEuOCA0LjcgMi44IDguMSA1LjQgMy40IDIuNyA4LjIg'
    b'Mi41IDEyLjggMWEzMDQgMzA0IDAgMCAwIDIxLjYtNy41YzQuOS0yIDguNC00IDktNC45LjQt'
    b'MSAxLTMuNyAxLTQuN3MtMS0yLjQtMS40LTIuN2MtLjQtLjItLjItMS0uMS0xLjYgMC0uNi0u'
    b'My0yLjUtMS0zLjMtLjgtLjgtLjctMS4xLS42LTMuNS4yLTUtMy40LTExLjQtOC40LTEzLjQg'
    b'MCAwLS4yLS42LS42LTFsLTEtLjZ2LTMuNWMwLS42LjItLjUuNi0uNC4zLjIuOS45IDEuNyAx'
    b'LjEuOC4yIDEuMy0uNCAxLjUtMS4zLjItMSAuOC0yLjggMS4yLTMuNy4zLTEtLjEtMS0uNS0x'
    b'LjJsLTIuMi0uNGMtLjYtLjEtLjYtLjItLjQtLjVsMS0yYy44LTEgLjEtMS4xLS42LTEuNGE1'
    b'OC40IDU4LjQgMCAwIDAtNC45LTEuM2MtLjktLjItMSAuNi0xIDF2Mi42YzAgLjYtLjUuNC0u'
    b'OS4zYTEyLjYgMTIuNiAwIDAgMS0xLjctMS4yYy0uNy0uNC0xIDAtMS4zLjdsLTEuMyA0LjNj'
    b'LS4yLjktLjEgMS41LjIgMS42LjMuMiAyIDAgMyAwIC45IDAgLjMuNi4zLjZsLTEuMyAyLjNj'
    b'LS40LjctMSAuOC0xLjguOGgtMnMtNS4zLjItOS4yIDMtNSA1LjMtNS42IDYuN2MtLjYgMS40'
    b'LTEuMyAxLjEtMS45IDEuNi0uNi41LTIuMyAyLjMtMi4zIDMuNHMuNCAxLjctMS4zIDIuOGMt'
    b'MS43IDEuMS0zIDUuOS0uOCA4LjMgMi4zIDIuNSAzLjIgNSA0IDYuMi42IDEuMiAwIDEuNy0u'
    b'NyAxLjdzLTEuOC0xLTIuOS0xLjhsLTguNS02LjVjLTIuMy0xLjctLjYtMS41LS42LTEuNXMu'
    b'NiAwIDEuOS0uNWMxLjMtLjYgMS41LTEuMy4yLTEuN2ExNi43IDE2LjcgMCAwIDEtNC42LTIu'
    b'NmMtLjctLjctMS0xLjQuMy0yLjEgMS4zLS43IDQuMi0yLjYgMi0zLjItMi40LS43LTUtMS4x'
    b'LTcuMy0xLjgtMi4yLS42LTIuNC0xLjItMi40LTEuMmwxLjUtMi4xczEuMS0xLjctLjItMS45'
    b'Yy0xLjQtLjItNC44LS42LTcuOC0yYTE4LjggMTguOCAwIDAgMS0xMS4zLTEyLjV2LS4xYzEu'
    b'MiAyLjIgMy44IDYuNCA3LjggNi41IDUuNS4yIDYuMS0xLjUgNC45LTMuMy0xLjMtMS44LTIu'
    b'Ny0zLjQtMy00LS40LS41LS41LTEuMiAxIC4yIDEuNCAxLjMgNCA1LjkgMTIuMyA1LjQgOC4y'
    b'LS42IDguMi0yLjIgOC4yLTIuNiAwLTEuNi0xLjctMS45LTIuNy0yLjktLjUtLjUtLjgtMS4y'
    b'LjktLjZzNS43IDEuNCAxMS4zLjJjMi4xLS41IDgtMyA4LjUtNiAwIDAtMy43LS4yLTYuMy0x'
    b'LjMtMi41LTEtNC0yLTEuMy0xLjQgMi43LjUgOCAxLjYgMTIuNyAwIDIuNy0uOSA2LjItMyA2'
    b'LjItNy4xIDAgMC01LTEtNi45LTEuOC0xLjktLjYtMi41LTEuMi0yLjUtMS4yczcuMyAyLjMg'
    b'MTMuOC0xYzYuNi0zLjMgNi45LTcuOSA2LjktOSAwLTEtLjItMS4zLS4yLTEuM3MtNiAxLjQt'
    b'MTAuNCAxLjRjLTQuNSAwLTUuOS0uNC01LjktLjRzMTIuNS0uNCAxOC44LTQuMmM2LjMtMy45'
    b'IDYuNy0xMS41IDYuNy0xMS41cy03LjEgMi42LTExLjYgMy4xLTcuMi41LTguMy40Yy0xLjEg'
    b'MC0xLjgtLjQuNy0uNWE0OSA0OSAwIDAgMCAxNy4yLTQuOGM1LjMtMy4xIDguNi05LjcgOC45'
    b'LTEyLjguMy0zLjEgMC0yLjYtMi40LTEtMi4zIDEuNC0xMSA1LjktMTYuNyA3LjJsLTYuOCAx'
    b'LjRzLTIuMi0uMS43LS45em0tMjI1LjIgMTQuNC0yLjUgMS40LTEuMy0yLjdjLS4yLS42LS4x'
    b'LS44LjItLjhsMi4zLS40aC4zYy4zLjcuNiAxLjYgMS4xIDIuNGgtLjF6bTc2LjggNDVhMjAu'
    b'MSAyMC4xIDAgMCAxLTguOCA3Yy0zIDEuNC02LjMgMS44LTcuNyAyLTEuNC4yLS4yIDItLjIg'
    b'MmwxLjQgMnMtLjIuNi0yLjQgMS4zYy0yLjIuNi01IDEtNy4yIDEuNy0yLjMuNi42IDIuNSAy'
    b'IDMuMiAxLjIuNyAxIDEuNS4yIDIuMS0uNy43LTMuMiAyLjItNC42IDIuNi0xLjMuNC0xIDEu'
    b'MS4yIDEuNyAxLjQuNSA1IDEuMiA1IDEuMmwtMi4zIDEuOGExOC45IDE4LjkgMCAwIDEtOC43'
    b'IDNjLTIuNS4xLTYuNi4zLTExLjcgMGwtNS44LS4zLS41LTQuM2EyMS41IDIxLjUgMCAwIDAt'
    b'My03LjhsLTMuNy01IC4yLTEuNWMuMi0uOCAwLTEuNy0uNS0zLjMtLjYtMS41LTMuNi0zLjgt'
    b'My42LTMuOGwtLjItMy4yYzAtMS42LTEtNy43LTItMTAuNi0xLTIuOS01LjctMTAuNS03Ljgt'
    b'MTRhMzkuMiAzOS4yIDAgMCAxLTQuMy0xOS44bC41LTEuM2ExMi45IDEyLjkgMCAwIDAgMy41'
    b'IDMuMmM2LjMgMy44IDE4LjggNC4yIDE4LjggNC4ycy0xLjQuNC01LjkuNC0xMC40LTEuNC0x'
    b'MC40LTEuNC0uMi4zLS4yIDEuNGMwIDEgLjMgNS42IDYuOSA5IDYuNSAzLjIgMTMuOCAxIDEz'
    b'LjggMXMtLjYuNS0yLjUgMS4xYy0xLjguNy03IDEuOC03IDEuOCAwIDQgMy42IDYuMiA2LjMg'
    b'Ny4yIDQuNyAxLjUgMTAgLjQgMTIuNy0uMSAyLjgtLjYgMS4yLjMtMS4zIDEuNC0yLjYgMS4x'
    b'LTYuMyAxLjMtNi4zIDEuMy42IDMgNi40IDUuNSA4LjYgNiA1LjUgMS4yIDkuNi40IDExLjIt'
    b'LjIgMS43LS42IDEuNC4xLjkuNi0xIDEtMi43IDEuMy0yLjcgMi45IDAgLjQgMCAyIDguMiAy'
    b'LjYgOC4yLjUgMTEtNCAxMi40LTUuNCAxLjQtMS40IDEuMy0uNyAxLS4xLS40LjUtMS44IDIu'
    b'MS0zIDQtMS4zIDEuNy0uNyAzLjQgNC44IDMuMiA0IDAgNi42LTQuNCA3LjgtNi42di4xbC4z'
    b'LjNhNTEuNyA1MS43IDAgMCAxLTIuNCA1LjN6bTY2LjQtMTc4LjItMS4xLTJzMyAxLjQgNSAz'
    b'LjVjMS44IDIgMS43IDMuMiAyIDQuMi4zIDEgMCAyLjktLjMgNC43LS4zIDEuNy0uMyAyLjgu'
    b'MSAzLjQuMy43LjcgMSAuNyAxbC0yLjcuOGMtMS4zLjYtMyAxLTQgLjItLjktLjgtMS4xLTEu'
    b'My0uNS0xLjguNi0uNSAyLjgtMS4yIDMtNSAuMy0zLjctMS41LTcuNi0yLjItOXptLTE3IDEw'
    b'LjNjLjgtMS44IDEtMy41LjUtNy4yLS40LTMuMS0xLTUuNy0xLjItOSAwIDAgMi4zLjQgNS42'
    b'IDMuNHM0IDYuMSA0IDcuNi0uNyAzLjQtLjkgNC44YzAgMS41LjQgMi44LjQgMi44cy0xLjEu'
    b'NS0yLjIgMS4zYy0xLjEuNy0xLjkgMS4yLTMuNSAxLTEuNyAwLTIuNy0uNy0zLjctMS4ybC0x'
    b'LjUtLjZzMS45LTEuMSAyLjYtM3ptLTE2LTEyLjhhMTQgMTQgMCAwIDEgNS42LTMuNWMtLjEg'
    b'My40LS43IDYtMS4yIDktLjUgMy44LS4zIDUuNS41IDcuMy43IDEuOCAyLjYgMi45IDIuNiAy'
    b'LjlzLS42IDAtMS42LjZjLTEgLjUtMiAxLjItMy42IDEuMy0xLjcgMC0yLjQtLjQtMy41LTEu'
    b'MWExNCAxNCAwIDAgMC0yLjMtMS4zcy41LTEuMy40LTIuN2MtLjEtMS41LTEtMy4zLTEtNC44'
    b'LjEtMS42LjgtNC42IDQuMS03Ljd6bS0xMS44IDE4LjNjLTEgLjgtMi43LjQtNC0uMmwtMi42'
    b'LS44cy4zLS4zLjYtMWMuNC0uNi40LTEuNy4xLTMuNC0uMy0xLjgtLjUtMy43LS4zLTQuNy4z'
    b'LTEgLjMtMi4yIDIuMS00LjIgMS45LTIuMSA1LTMuNiA1LTMuNmwtMS4yIDIuMWMtLjcgMS40'
    b'LTIuNSA1LjMtMi4yIDkgLjMgMy44IDIuNSA0LjUgMyA1IC42LjUuNCAxLS42IDEuOHptNDMu'
    b'OCAzMS43Yy0zLjIgMS43LTUgMS4zLTUgMi43LjIgMS4zIDMuMSAyLjMgMy4xIDIuM3MtMyAz'
    b'LjItNS4zIDQuNmMtMi4zIDEuNS01IDIuNC01IDIuNHMtMSAuMi0uNCAxLjZhNS40IDUuNCAw'
    b'IDAgMCAyLjIgMi45bDEuMS41cy00IDQuMy01LjggNS43YTE1LjMgMTUuMyAwIDAgMS00LjMg'
    b'Mi41Yy0xLjQuNi0uNyAzLS40IDQgLjQgMSAxLjYgMi41IDIuNCAyLjcuNy4yIDEgLjggMCAy'
    b'LjItLjcgMS4xLTMgNC00IDUuNmgtLjFsLTQuMi01LjZjLS45LTEuNC0uNi0yIDAtMi4yLjgt'
    b'LjIgMi0xLjYgMi40LTIuNy4zLTEgMS0zLjQtLjQtNGExNS4yIDE1LjIgMCAwIDEtNC4yLTIu'
    b'NSA4MC4yIDgwLjIgMCAwIDEtNS44LTUuN2wxLS41YTUuNCA1LjQgMCAwIDAgMi4zLTIuOWMu'
    b'NS0xLjQtLjQtMS42LS40LTEuNnMtMi43LTEtNS0yLjRjLTIuNC0xLjQtNS40LTQuNi01LjQt'
    b'NC42czMtMSAzLTIuM2MuMi0xLjQtMS42LTEtNC45LTIuNy0zLjItMS44LTQuMy00LjEtNC4z'
    b'LTQuMXMzLjgtMS4zIDUuNy01YTcgNyAwIDAgMCAuNy0zLjZoLjFjNiAyIDEzLjEgMi44IDE5'
    b'LjQgMi44YTYzIDYzIDAgMCAwIDE5LjMtMi44aC4yYTcgNyAwIDAgMCAuNyAzLjZjMS45IDMu'
    b'NyA1LjYgNSA1LjYgNXMtMSAyLjMtNC4zIDR6Ii8+CiAgPHBhdGggZmlsbD0iI2Q0YWYzYSIg'
    b'ZD0iTTM2MS4yIDIzNy44YzAtMTAuMiA0LjctMTYuNyA0LjctMTYuN2wtMTIuNy0xNC42Yy0x'
    b'Mi4yIDQuNy0yMy4zIDUtMzMuMiAwLTkuOSA1LTIxIDQuNy0zMy4xIDBMMjc0IDIyMS4xczQu'
    b'NyA2LjUgNC43IDE2LjYtMiAxNy44LTMuMSAyMi43Yy0xLjIgNS0yLjEgMTQuMS41IDIwLjdh'
    b'MjYuMyAyNi4zIDAgMCAwIDE2LjcgMTdjMTEuMyA0LjggMTcuMyA3LjMgMjEuMiAxMC42IDQg'
    b'My4yIDUuOSA1LjkgNS45IDUuOXMyLTIuNyA2LTZjMy45LTMuMiA5LjgtNS43IDIxLTEwLjRh'
    b'MjYuNCAyNi40IDAgMCAwIDE2LjgtMTcuMWMyLjctNi42IDEuNy0xNS44LjUtMjAuNy0xLjEt'
    b'NS0zLTEyLjUtMy0yMi42eiIvPgogIDxwYXRoIGZpbGw9IiNiOTZiMjkiIGQ9Ik0zNTcuMiAy'
    b'NDJjLTEuNi05LjggNC0xOC4zIDQtMTguM2wtMTAuOS0xMi44Yy04LjQgNC43LTIwLjEgNC4x'
    b'LTMwLjMtLjYtMTAuMSA0LjctMjEuOCA1LjMtMzAuMi42bC0xMSAxMi44czUuNyA4LjUgNCAx'
    b'OC4zYy0xLjUgOS43LTUgMjUtNC4xIDMxLjMuOSA2LjMgNS4zIDEzLjYgOS44IDE3LjRhNTgg'
    b'NTggMCAwIDAgMTYuMiA4LjcgNDYuNyA0Ni43IDAgMCAxIDE1LjMgMTBzMS41LTEuNSAzLjct'
    b'My4yYzIuMy0xLjcgNy01IDExLjctNi44YTU5IDU5IDAgMCAwIDE2LjEtOC43YzQuNi0zLjgg'
    b'OS0xMS4xIDkuOS0xNy40LjgtNi4zLTIuNi0yMS43LTQuMi0zMS40eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiMxZDVlOTEiIGQ9Ik0zNTYuMSAyNDMuMWEzMi41IDMyLjUgMCAwIDEgMy4yLTE5bC05'
    b'LjgtMTFjLTguNCA0LjQtMTguNSAzLjMtMjkuNS0uNi0xMSAzLjktMjEuMSA1LTI5LjQuN2wt'
    b'OS45IDExczQuNyA4LjQgMy4yIDE4LjktNCAyMi40LTMuNiAyOS40bC4yIDEuNGg5cy41LS42'
    b'IDEuNS0xIDEuMy0uNyAxLjMtLjcuMi0xLjggMS4yLTIuMmMxLjEtLjQgMS42LS40IDItLjQu'
    b'NSAwIC44LS4xIDEuMy0uNi41LS42IDItMS44IDIuNi0zLjYuNi0xLjkgMS0yLjYgMS0zLjgg'
    b'MC0xLjIuNC0zIC40LTNzLS4yLS42LTEuMS0uM2MtMSAuMy0xLS42LTEuMi0xLjUgMC0uOSAw'
    b'LTIuNy41LTMuNmwuNy0xLjEtLjQtMS41cy01LjcgMS4yLTYuNy0zLjMtMS4xLTYuNS0xLjMt'
    b'N2MtLjEtLjUtLjMtLjctMS0uNy0uOCAwLTIuNC0uNC0zLjYtMi43LTEtMi4zLTEuMi0zLjMt'
    b'LjgtNC4yLjMtLjkuOS0uNSAxLS4zLjMuMyAxLjggMi41IDIuNCAxLjkuNi0uNi4zLS42LS42'
    b'LTIuMy0uOC0xLjgtLjUtMi4zLS40LTMuMmwtLjMtMi41YzAtLjQuNS0uOCAxLS42LjYuMyAx'
    b'IC42IDEuMyAxIC4yLjIuMy42LjguNC41LS4zLjItMS45LjItMi40IDAtLjYuNi0xIDEuMy0u'
    b'NWEyLjIgMi4yIDAgMCAxIDEuMiAxLjhjMCAuNiAwIDEuMS4zIDEuMXMuNi0uOS43LTEuNGMw'
    b'LS42LjQtMS41LjktLjcuNS43LjcgMS43LjUgMi44LS4yIDEuMS4yLjUtLjIgMi40LS40IDIt'
    b'LjYgMi44LS41IDQuMiAwIDEuNSAwIDIuMy44IDQgLjcgMS44IDEuMyAzLjggMi42IDMuOWgx'
    b'LjdzMS41LTIuOCAyLjYtMy41YzEuMi0uNiAyLjgtLjcgNC0uOSAxLS4xIDEuNS0uNSAxLjUt'
    b'LjggMC0uMi0uMy0uMy0xLjctLjVzLTIuNS0uNS0yLjYtMS42YzAtMSAuMy0yLS42LTItMSAw'
    b'LTMuMi0uOC00LTIuMi0uOC0xLjUtLjYtMS44LS41LTIuNyAwLS44IDEuMS0yLjQgMS44LS45'
    b'LjcgMS42IDEuMSAxLjggMS43IDIgLjUuNCAxLjMuNSAxLS41LS41LTEtLjctMS43LS42LTIu'
    b'NSAwLS44LjYtMS4xIDEuMi0xLjJsMy40LTEgMS0uMnMuMS0uNyAxLjQtMWE5IDkgMCAwIDEg'
    b'My0uNWMuOCAwIDEuNS4xIDIuNy0uNGE1LjcgNS43IDAgMCAxIDIuOS0uNyAzLjcgMy43IDAg'
    b'MCAxIDEuOS44Yy41LjMuNC45LjQgMS40IDAgLjUgMCAuOC44LjguOSAwIDEuNiAwIDIuMy4z'
    b'LjguMyAxLjguNyAxLjIgMS41LS43LjgtLjcgMS43LTEuMiAxLjctLjQgMC0uNC40LS41Ljct'
    b'LjIuMy0uNC41LjEuOC41LjMuNS42IDEuMiAxLjIuNi42IDEuNiAxLjMuNiAyLjMtMSAxLTIu'
    b'NyAxLjgtMi43IDEuOHMtMSAuNS4xIDEuMWMxLjIuNyAxLjcgMiAyLjEgMi4zbDEuMi44Yy4z'
    b'LjEuMiAxIC4yIDFsLTEuNS44Yy0uOC40LTEuNy44LTIuNS44cy0xLjMgMC0xIC43Yy40Ljgg'
    b'MSAxLjYgMS4xIDJsLjMgMS4yczEuNC4zIDIuNi4zbDQuMy0uMmMyLjYtLjMgMy40LS40IDUu'
    b'OS0uMSAyLjUuMiAyLjkuMiAzLjUuNGwxLjQuNnMzLjUgMCA1LjUtLjVjMi0uNCAyLjQtMS43'
    b'IDIuMS0yLjQtLjMtLjYtLjItMS42LTMuNi0yLTMuNS0uNi00LjgtLjQtNy41LS45LTIuOC0u'
    b'NS03LTEuOS03LjctNS4zLS44LTMuNCAyLTQuOCAzLjMtNS41bDUuOC0yLjNjMS40LS41IDMu'
    b'OS0xIDYuNS0uNyAyLjcuNCA0LjIgMSA1LjMuNSAxLS43IDEuOS0uMiAxLjcuOC0uMiAxLTEu'
    b'MyAyLjktNC4zIDMuOC0zIC45LTYuNiAxLTguNS41LTItLjYtMy40LTEuMy00LjYtLjktMS4y'
    b'LjQtMi41IDEuOS0xLjMgMy43IDEuMyAxLjcgNy45IDIuMyA5LjYgMi40IDEuOC4yIDguMy0u'
    b'MiAxMC4yIDMgMS44IDMuMi4zIDYuOS0xLjggNy43YTI5IDI5IDAgMCAxLTUuNyAxLjVsLTEu'
    b'Ny4zcy44IDEuNy44IDIuNC0uMSAyIC43IDIuNmMuOC41IDIgLjkgMy4zLjcgMS40LS4xIDMg'
    b'LjggMy4xIDIgLjEgMS4zLjUgMyAuNiA1LjUuMiAyLjUgMCA0LjUgMCA0LjVzMCAxLS40IDEu'
    b'OWMtLjMgMS0yIDQuNC0yIDQuNGg5LjVsLjItMS40Yy40LTcuMS0yLTE5LTMuNi0yOS41eiIv'
    b'PgogIDxwYXRoIGZpbGw9IiM2ZDhjM2UiIGQ9Ik0yODEuNiAyNzguNmEyNy40IDI3LjQgMCAw'
    b'IDAgMTEuNiAxNC4zYzguMiA1IDExLjggNC4zIDE5LjUgOS4zIDcuNyA1IDcuMiA1LjggNy4z'
    b'IDUuOC4xIDAtLjQtLjggNy4zLTUuOHMxMS4zLTQuNCAxOS41LTkuM2EyNy40IDI3LjQgMCAw'
    b'IDAgMTEuNi0xNC4zaC03Ni43eiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0yODgu'
    b'MyAyMzcuMmMuOSAxIDEuNSAxLjIgMi45IDEgMS4zIDAgMS43LjkgMS45IDIgLjIgMSAuMiAz'
    b'LjUgMS4yIDUuOHM0LjIgMi41IDQuMiAyLjVjMC0xLjEuNS0yLjYgMS0zLjkgMC0uMi41LTEu'
    b'Mi0uNy0xLjJzLTEuMS0uNS0xLjgtMS42Yy0uNy0xLTItNC0yLjQtNmExNiAxNiAwIDAgMSAu'
    b'Ni01LjdjLjQtMSAuNC0xLjcgMC0xLjloLTFzLjIgMS0uMSAxYy0uMy4yLS42LS40LS44LTEt'
    b'LjMtLjctLjUtLjYtMS0uNnMtLjUuNS0uMSAxYy4zLjQuMSAxLjMuMSAxLjNsLTEuNC0xYy0u'
    b'NS0uMi0xLjQuMi0xLjUuOC0uMS41LjMgMiAxLjIgMi43czEgMi4yLjYgM2MtLjIuNi0xLjUu'
    b'NS0xLjguMmEuOC44IDAgMCAwLTEuMiAwYy0uNC41LS44LjcuMSAxLjZ6bS0uNS0yLjUtLjct'
    b'LjZhMzUuMSAzNS4xIDAgMCAxLS41LS43bC0uMS43YzAgLjUuNiAxLjIuNiAxLjJsLjctLjZ6'
    b'bTItNi40Yy40LS4xLjctLjIuNC0uNy0uNC0uNS0uNi0xLTEtMS0uMy0uMi0uNi0uMS0uNi0u'
    b'MWwuNSAxLjNjMCAuNS4yLjcuNi41em0yLjQtMmMwIC41IDAgLjcuNC41LjQtLjIuNS0uNy4z'
    b'LTFhMiAyIDAgMCAwLS42LS43bC0uMy0uMnMuMiAxIC4xIDEuNXptMy40LjYtLjEtMXMwIC42'
    b'LS4zIDFjLS4yLjMtLjEuMiAwIC41LjMuMi40IDAgLjQtLjV6bTUuNCAyMy41Yy43IDEuNiAy'
    b'LjQtLjkgNC0yLjlzMS41LS40IDEuMyAxLjJhNy42IDcuNiAwIDAgMCAxIDQuNWMuNyAxIDEu'
    b'Mi40IDEuNS0uNC4yLS43LjUtMi40IDEtMy4yLjUtLjcgMSAwIDEgLjYuMS43IDEgMi4yIDEu'
    b'NyAzLjEuOCAxIDEuMi0uMyAxLjUtMS40bC43LTMuNWMuMi0uNiAxIDAgMSAwbDEuNiAxLjVj'
    b'MSAxIDEuMS0uNiAxLjItMS40LjEtLjgtLjEtMi41LjItMi44LjMtLjMgMS4yLjQgMi41IDEg'
    b'MS40LjcgMS4zLS42IDEuMi0xLjNhNy40IDcuNCAwIDAgMC0yLTMuNGMtMS4yLTEtMS4zLTIt'
    b'MS0yLjUuNC0uNSAxLjcgMCAyLjYtLjFsMS44LS4zYy43LS4yLjctLjguNy0uOHMtLjUtLjgt'
    b'MS40LTEuNmMtLjktLjgtMS40LTEuNC0yLjUtMS42LTEuMS0uMy0yLjYgMC0yLjYgMGwtLjIt'
    b'LjRjLS4xLS4zLS40LS4zLS42IDBsLTEuMiAxLjFjLS40LjQtLjcuNi0xIC41LS4yLS4yLjMt'
    b'LjYuMy0uNnMuNS0uNCAxLTEuNGMuNi0xIC43LTIgLjMtMi42LS40LS40LTEuNSAwLTIuMiAw'
    b'LS42IDAtMSAuMi0xLS4yIDAtLjMuNi0uMSAxLjQtLjIuOC0uMSAxLjMtMSAxLjUtMS45cy41'
    b'LS42IDEtLjJjLjQuNS45LjQgMSAwbDEtMS44Yy41LS44LjgtMS45LjMtMi42LS42LS44LTIt'
    b'LjctMi42LS4yLS42LjUtMSAxLTEuMSAyLjEtLjIgMS4yLS41LjUtLjUuMiAwLS40LS40LTEt'
    b'LjItMS41LjItLjQgMC0xIDAtMXMtLjEtMS0xLjItMS4xYTguNiA4LjYgMCAwIDAtMy41LjNj'
    b'LTEgLjItLjkgMS4yLS45IDEuMmwtMS43LjFjLS45LjEtMiAuNS0yLjguNy0uOC4yLTEuMS4z'
    b'LTEuMS43bC4xIDEuMXMuNyAwIDEgLjMuMi41LS4yLjdjLS40LjItLjYuMi0uNi43cy4yLjcu'
    b'Ny43Yy40IDAgMS4zIDAgMi4zLjRzMS4zIDEuNCAxLjIgMmMwIC41LTEuNSAxLjItMi4zIDEu'
    b'MnMtMSAuMS0xIC42IDEgLjQgMSAuNGwyLjYuM2MxLjcuMiAyIC42IDIuOCAxLjIuNy43LjIu'
    b'OS0uMiAxLS40LjMtMSAuOC0xLjUgMS0uNi4yLTEgLjYtMS41LjctLjUuMS0xLjggMC00LjIg'
    b'MS0yLjQgMS0zLjMgNC4xLTMuMyA0LjFsMS40LS43YzEuMS0uNSAyLjUtMS4yIDMuOC0yIDEu'
    b'Mi0uNyAxLjIuNC42IDEuNXMuNi45IDEgLjZsMi0xLjNjMS4yLS42LjguNC44LjRzLS40Ljct'
    b'LjUgMi41Yy0uMSAxLjcgMS43IDAgMi41LTEgLjktMS4xIDEuMiAwIC42IDEuMi0uNiAxLjMt'
    b'MS44IDIuMy0yLjUgMi4zcy0xLjItLjgtMS4zLTEuMmMwLS40LjMtMS43LS4xLTItLjUtLjMt'
    b'MS43IDAtMi42LjYtLjkuNS0xIC4xLTEuMy0uNC0uMi0uNC4zLS42LjEtMS0uMi0uMi0uNiAw'
    b'LTEgLjJsLTIuOCAxLjVjLTEuNy45LTEuNiAxLjMtMS42IDIuNXMuMyAxLjUgMSAzeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Im0zMTYuNyAyMjQuMiAxLS41IDEuNS0uM2MuNyAw'
    b'IC42LS41LjQtLjgtLjEtLjQtLjQtLjUtMS40LS41LS45IDAtMS41LjUtMiAuN2wtMS4xLjQu'
    b'NC42Yy40LjUuOS42IDEuMi40em0zLjggMy43LjgtLjIgMS4zLS42Yy42LS4yLjgtLjMgMS4y'
    b'LTEgLjQtLjgtLjQtLjgtMS41LTEtMS0uMy0xLjYgMC0xLjcuNS0uMS40IDAgLjgtLjUgMS42'
    b'czAgLjcuNC43em0tLjMgMWMtMSAwLTIuMyAxLjUtMi43IDEuOC0uNC4zLS4yLjYtLjIuNmwu'
    b'NCAxLjJjLjIuNy4yIDEuNy4yIDEuN2guOGMuNiAwIDEtLjIgMS42LS43YTQgNCAwIDAgMSAx'
    b'LjgtLjdjLjktLjIgMS4zLS4zIDIuMi0uOCAxLS41LS41LTEuNC0xLjUtMi4yYTMuNyAzLjcg'
    b'MCAwIDAtMi42LTF6bS0xNCAzLjZjLjgtLjEgMS4yLS41IDEuMi0xcy0uNC0xLTEuNS0uOWMt'
    b'Mi42LjMtNS4xLS43LTUuNi0zLjIgMCAwLS44IDEuNi44IDMuNCAxLjYgMS44IDQuMyAxLjgg'
    b'NS4xIDEuN3ptLTguOSA0MSAuNS40aDRjLjctLjIuNy0uOC43LTEuMiAwLS41LjQtMiAxLTQu'
    b'Ny41LTIuNiAxLjUtNC41IDEuOS01LjYuNC0xLS40LTEuNC0uNy0ybC0uOC0yLjVjLS4xLS42'
    b'LTEtLjUtMS42LS41LS41IDAtLjYuOS0uNyAxLjcgMCAuOC0uNCAzLjEtLjggNS4xLS40IDIt'
    b'Mi43IDQuNy0zLjMgNS4zLS42LjYtMS4yLjgtMS42LjgtLjQgMC0xLjQgMC0xLjguM2EyLjQg'
    b'Mi40IDAgMCAwLTEgMS42YzAgLjYuOSAxIC45IDFsMS0uOGMuMy0uNCAxLS41IDEuNS0uNi43'
    b'LS4xLjcuMS41LjQtLjIuMy0uMS40LjMgMS4yem0tNi0uMmMtLjQgMC0uNi40LS43LjZoMi42'
    b'YTEuNCAxLjQgMCAwIDAtLjMtLjdjLS4zLS4zLTEuMS0uMS0xLjcgMHoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZDRhZjNhIiBkPSJNMjk0LjggMjczLjJhMyAzIDAgMCAwLTEgLjdoMi45YzAtLjIu'
    b'MS0uNi0uMi0uOS0uNy0uNS0xLjMgMC0xLjcuMnpNMzE5IDI3MmMtLjMgMC0uNi4zLTEgLjYt'
    b'LjUuMy0uNi44LS43IDEuMmEuMy4zIDAgMCAwIDAgLjFoMS4zYS4yLjIgMCAwIDAgMC0uMWMw'
    b'LS40LjItLjcuNy0xLjEuNS0uNSAwLS43LS4zLS43em0yLjMgMS4zYzAtLjQtLjEtLjctLjQt'
    b'LjctLjIgMC0uNy41LTEgLjhhMi40IDIuNCAwIDAgMC0uNS41aDEuN2wuMi0uNnoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMzMyLjMgMjYwLjRjLjgtLjYuNy0uOC43LTEuNSAw'
    b'LS42IDAtLjgtLjMtMWE1LjkgNS45IDAgMCAwLTIuOC0uOGMtMS4xIDAtMy40LjMtNC4yLjgt'
    b'LjkuNi0xLjMgMi43LTEuMyAzLjggMCAxIC4yIDEuMi41IDEuMnMuOC0uOC44LS44bDEuOCAy'
    b'LjVjLjcgMSAuNCAxLjQgMCAyLjItLjIuOC0xLjQgMi45LTIuMiAzLjMtMSAuNS0xLjYgMC0y'
    b'LjYtLjEtMS4xLS4yLTEuNy4xLTIuMy43czAgMS4xLjQgMS4xYy4zIDAgLjggMCAxLjIuNS4z'
    b'LjMuMSAxLjIgMCAxLjZoNS4yYy45LS40IDEuNS0xLjYgMS43LTIuMy4zLS43IDEuNC0xLjcg'
    b'Mi0yLjIuNS0uNS41LS44LjUtMnMtLjItMS43LS42LTIuNWMtLjUtLjgtLjgtMi0uNi0yLjYg'
    b'MC0uNyAxLjItMS40IDItMnoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMzIzLjcg'
    b'MjQ3LjRjLjYuOS4zIDEtLjQgMS4yYTguNSA4LjUgMCAwIDEtMi44LjJjLTEuMS0uMS0xLjEg'
    b'MC0xLjEuNmE1IDUgMCAwIDEtLjggMi43Yy0uNyAxLTEuNi42LTIgLjItLjYtLjMtLjktLjIt'
    b'MSAuNGwtMS4yIDIuMWMtLjUgMS0uOSAxLTEuMy45LS40LS4xLS43LS43LTEuMS0uNy0uNCAw'
    b'LTEtLjgtMS42LTEuOC0uNi0uOS0uOS4xLTEuMyAxLS40LjgtLjcgMS4zLTEuNSAxLjItLjcg'
    b'MC0xLjYtMS41LTItMi4zLS40LS44LS43LTEuNi0xLjMtMS42LS43IDAtMS43IDEuNC0yLjQg'
    b'MS43LS43LjQtMSAuMy0xLjMtLjItLjMtLjQtLjcuMi0xLjEgMS4yLS40IDEuMSAwIDIgLjYg'
    b'Mi4zLjYuMyAxLjctLjUgMi41LTEgLjgtLjYgMS4xLS41IDItLjUuOCAwIC43IDEuNCAxIDMu'
    b'My40IDIgMS41IDIuMiAxLjUgMi4ycy40LjMgMS4zLTEuMWMuOS0xLjUgMS0zIDEuOC0zIC45'
    b'IDAgMSAuMiAxLjggMS40LjggMS4xIDEuNSAyIDIgMS4xLjUtLjguOS0yLjEgMS41LTIuNi41'
    b'LS40IDEtLjYuNC4zLS41LjgtLjggMS43LjQgMS40IDEuMi0uNCA1LjctMi4yIDcuNi0yLjZs'
    b'NC43LS41IDQtLjNjMSAwIDEgMCAxLjEtLjcgMC0uNy0uNS0uNS0yLjMtLjUtMS44IDAtMyAu'
    b'Mi00LjMuNC0xLjMuMi0xLjguMi0xLjYtLjIuMi0uMy42LS41IDItLjdhNTggNTggMCAwIDEg'
    b'Ni0uNWMxLjYgMCAxIC41IDEgMS41LS4yIDEgMCAyLjYuMiAzLjUgMCAxIC4xIDEuMyAxIDIu'
    b'N3MzLjcgMi4yIDQuNSAyLjZjLjkuNS43IDAgLjctLjhzLjctLjggMS40LS4zYy43LjQgMiAu'
    b'NyAyLjkgMSAuOC4yIDEgLjQgMSAuOCAwIC41IDAgMS41LjIgMi40IDAgMSAwIDEuMi0uNCAx'
    b'LjhsLTIgMi4zcy0uOCAwLTIuMy40Yy0xLjYuMy0yLjEgMS4xLTIuMyAxLjctLjEuNy4zLjku'
    b'NCAxLjF2LjhoLjRjMC0uMi4zLS41LjUtLjguNi0uNyAyLS45IDIuOS0uNS42LjMuNiAxIC41'
    b'IDEuM2gzLjZsMi0zLjlhNiA2IDAgMCAwIC42LTIuNmMwLTEuMi4yLTUuOCAwLTYtLjMtLjMg'
    b'MC0xLjEgMC0yLjQtLjEtMS4zIDAtMi4zLTIuNC0yLjUtMi40LS4yLTMuMi0xLjItNC0yLS44'
    b'LS44LS42LTIuNy0xLjItNS0uNy0yLjItMi4zLTIuNi01LTMuMWEyMy4zIDIzLjMgMCAwIDAt'
    b'Ny0uNWMtMi4yLjItNC44LjUtNi4yLjQtMS41LS4yLTEuMi4yLS43IDF6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2Q0YWYzYSIgZD0ibTMzNy4zIDI3My40LS41LjVoMi40YTEgMSAwIDAgMC0uMi0u'
    b'N2MtLjQtLjQtMS0uMi0xLjcuMnptNC40LS4yYTIuMiAyLjIgMCAwIDAtLjguN2gyLjVhMSAx'
    b'IDAgMCAwIDAtLjNjLS4xLS40LS45LS44LTEuNy0uNHptLTYxIDEuNmEyNC4xIDI0LjEgMCAw'
    b'IDAgLjUgMi4zaDc3LjZsLjYtMi4zaC03OC44em01Mi4zLTM3LjFjMi40IDEuNiAxMC4yIDEu'
    b'NyAxMy45IDIuNCAzLjYuOCAzLjQgMy42IDIuMyA1LTEuMiAxLjUtNi4zIDEuNy03LjIgMS44'
    b'LjUuMyAxLjIgMS40IDEuMiAxLjRsMi4xLS4yYTExIDExIDAgMCAwIDYuMS0yYzEuOS0xLjYg'
    b'MS44LTQgLjEtNS44LTEuNi0xLjYtNC4zLTEuOC03LTIuMS0yLjgtLjMtNS0uNS04LTEtMy4y'
    b'LS42LTQuNy0xLjgtNC43LTMuNnMxLjctMi44IDIuOS0zLjFjMS4yLS40IDMuMS0uOSA0Ljkt'
    b'LjIgMS43LjYgMy43LjcgNy4xLjMgMy40LS41IDQuMi0yLjggNC4yLTIuOHMtLjQuMi0yLjIu'
    b'MmMtMS43IDAtMy0uNy02LS43LTMuMiAwLTQuMyAxLTUuOCAxLjYtMS41LjUtNS40LjktNi41'
    b'IDMuNC0xLjIgMi41LjEgMy43IDIuNiA1LjR6Ii8+CiAgPGVsbGlwc2UgY3g9IjMxMi42IiBj'
    b'eT0iMjI2IiBmaWxsPSIjYjk2YjI5IiByeD0iMS41IiByeT0iMS40Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2I5NmIyOSIgZD0iTTM0NCAyMjguNGMtMi0uMi00LjUuNC00LjUuNHMuNS40IDEuMi4z'
    b'Yy42IDAgMS44IDAgMy43LjMgMS45LjMgMy4yLS42IDMuMi0uNmwtMy42LS40eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiMxZDVlOTEiIGQ9Ik0zMjUuNiAyNjQuNmMtLjUtLjgtLjYtLjctMS4yLS4y'
    b'LS41LjQtMS0xLjItMS4xLTIuMmwuNC00LjFzLTIuNi41LTQgMWwtNCAuOWMtMS4xLjItMS44'
    b'LjUtMi40LjQtLjYtLjItMS45LS4yLTIuOS0uMnMtMSAuMi0yIDEuMi0xLjMgMS41LTIgMy40'
    b'YTIwIDIwIDAgMCAwLTEuNCA2IDE1LjYgMTUuNiAwIDAgMS0uNyAzLjFoMTIuMmwuNS0xLjJh'
    b'MyAzIDAgMCAxIDEuNC0xLjRjLjUtLjIgMS0uMiAxLjItLjguMi0uNS44LTEgMS40LTEuMi43'
    b'LS4zIDEuOC0uMiAyLjguMSAxIC4zIDEuNC0uNCAxLjctLjguMy0uNC40LTEgMS0xLjYuNS0u'
    b'NyAwLTEuMyAwLTEuM2wtMS0xLjF6bTE5LjUuM2MtLjEtLjcgMC0uOC0uNS0uOS0uNCAwLTEu'
    b'MS0uMi0xLjctLjUtLjYtLjItLjUgMS40LS41IDEuNHMtMS41LjItMy4xIDAtMy41LTEuNy00'
    b'LjItMi4yYTUuNSA1LjUgMCAwIDEtMS40LTEuNWwtMSAuN2MtLjUuMy0uOCAxLjMtMSAyLjQg'
    b'MCAxIDEuMyAyLjIgMS40IDMuMiAwIDEtMS4yIDMuMS0xLjggNGE5IDkgMCAwIDAtMS4yIDIu'
    b'NGg1LjlhMyAzIDAgMCAxIC42LTFjLjYtLjYgMS42LS43IDEuNi0uN2wuMi0uOGMuMi0uNS45'
    b'LTEuMiAyLjMtMS44IDEuNS0uNSAzLjMtLjYgMy4zLS42cy43LS42IDEuMi0xLjRjLjUtLjgg'
    b'MC0yIDAtMi43eiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0yOTYuMiAzMjkuNmMx'
    b'LjEuNCAzLjItLjQgNC4yLTEuNiAxLTEuMyAxLjQtMy4yIDIuMS00LjNsMS4zLTEuOXMtLjIg'
    b'MS44LTEuMiA0LjNhMTUuNSAxNS41IDAgMCAwLS44IDYuOGMuNCAyLjcgMi4yIDMuMSAzLjIg'
    b'Mi43LjgtLjIgMi0xLjQgMy0zLjJsMS0yYy42LTEuMyAxLjItMy41IDEuNS0zLjQuNy4xLjMg'
    b'MS42IDAgMi42LS41IDItMS41IDUtMS42IDcgMCAxLjcuMiA1IDIgNS4yIDEuOC4xIDIuOC0x'
    b'LjUgMy44LTUuMnMxLjItNSAxLjctNWMuNCAwIC40IDIuNi40IDMuN2ExOC4yIDE4LjIgMCAw'
    b'IDAgMS42IDcuNGMuOS44IDEuNi43IDEuNi43cy43LjEgMS42LS43Yy45LS44IDEuNi02LjMg'
    b'MS42LTcuNCAwLTEgMC0zLjYuNS0zLjZzLjYgMS4yIDEuNiA0LjkgMiA1LjMgMy44IDUuMmMx'
    b'LjktLjIgMi0zLjUgMi01LjMgMC0xLjgtMS4xLTQuOC0xLjYtNi45LS41LTIgLjItMS45IDEu'
    b'Ni44bDEuMyAyLjVjMSAxLjYgMiAyLjUgMi42IDIuNyAxIC40IDIuOCAwIDMuMi0yLjcuNS0y'
    b'LjctMS42LTEwLjUtMS42LTEwLjVsMSAxLjNjLjcgMS4xIDEgMyAyIDQuMyAxIDEuMiAzLjEg'
    b'MiA0LjIgMS43IDEtLjQgMS4yLTIuNC40LTYuMXMtNC01LjctNi40LTguNmEzMS42IDMxLjYg'
    b'MCAwIDEtNC04LjIgMjcgMjcgMCAwIDAtNy45IDUuNmwtNS45IDYuM3MtMS0xLjMtNS44LTYu'
    b'M2EyNyAyNyAwIDAgMC04LTUuNmMtLjIuNi0yLjIgNS4yLTQuNCA3LjktMSAxLjMtMi41IDIu'
    b'My0zLjYgMy42YTEyLjQgMTIuNCAwIDAgMC0yLjQgNS4zYy0uOCAzLjYtLjYgNS43LjUgNnoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMjk2IDM0MmMxLjUtMS4yIDIuMi0yIDIu'
    b'Mi0yczEtLjguOC45Yy0uMyAxLjYtLjggNS0uNSA2LjQuNCAxLjQuNSAyLjcgMi4zIDEuNiAx'
    b'LjgtMSAyLjMtMS43IDMuMS0yLjYuOS0uOSAxLjgtMS4zIDEuNi4xLS4zIDEuNC0uOSAzLjYt'
    b'LjYgNi40LjMgMyAxLjcgMy4zIDMuNi45YTMyLjMgMzIuMyAwIDAgMCAzLjUtNS45Yy41LTEu'
    b'MiAxLjYtMi4yIDEuNiAwIDAgNC44IDEuMSAxMS44IDYuNCAxMy42IDUuMy0xLjggNi40LTgu'
    b'OCA2LjQtMTMuNiAwLTIuMiAxLjEtMS4yIDEuNyAwYTMyLjQgMzIuNCAwIDAgMCAzLjUgNS45'
    b'YzEuOCAyLjQgMy4yIDIgMy41LS45LjMtMi44LS4zLTUtLjUtNi40LS4yLTEuNC42LTEgMS41'
    b'LS4xczEuMyAxLjUgMyAyLjZjMS45IDEgMi0uMiAyLjQtMS42LjMtMS41LS4yLTQuOC0uNS02'
    b'LjQtLjItMS43LjgtLjguOC0uOGwyLjEgMmE2IDYgMCAwIDAgMy40IDEuMnMuOS01LTEuMi04'
    b'Yy0yLTMtMi45LTQtMi45LTRzLTEuMSAwLTItLjRjLTEtLjMtMS44LTEtMS44LTF2Mi44bDMu'
    b'MSAzLjFjLjYuOCAxLjggMiAwIC44YTUwLjUgNTAuNSAwIDAgMS0zLjEtMi40cy0uNCAyLjUt'
    b'MS4xIDMuMmMtLjcuNi0xLjguNy0yLjIuNWwtLjQtLjEtLjIgMXMxLjYgMyAxLjggNC4xYy4z'
    b'IDEuMiAwIDEtLjgtLjUtLjctMS41LTIuMi0zLjUtMi44LTQuNS0uNi0xLjEtMS42LTEuOC0x'
    b'LjUtLjUuMSAxLjQtLjUgMy45LTEgNC44LS40LjktLjcgMS4yLS43IDEuMmwxLjEgNGMuMS43'
    b'IDAgMS41LS41LjYtLjYtLjgtMi4xLTQuMi0yLjEtNC4ycy0yLjEgMC0yLjctLjdjLS42LS42'
    b'LTEuNi0yLjktMS42LTIuOXMtLjggMy0xLjUgNGMtLjcuOS0yLjQgMS44LTIuNCAxLjhsLS4y'
    b'IDZjLS4yIDEtLjIgMS4zLS42IDEuM3MtLjQtLjQtLjUtMS4zbC0uMy02cy0xLjYtMS0yLjMt'
    b'MS45Yy0uNy0xLTEuNi0zLjktMS42LTMuOXMtMSAyLjMtMS41IDNjLS42LjUtMi43LjYtMi43'
    b'LjZzLTEuNiAzLjQtMi4yIDQuMmMtLjUuOS0uNi4xLS41LS41bDEuMS00LjFzLS4zLS4zLS43'
    b'LTEuMmMtLjUtMS0xLTMuNC0xLTQuOC4xLTEuMy0uOC0uNi0xLjUuNXMtMiAzLTIuOCA0LjUt'
    b'MSAxLjctLjguNWMuMi0xLjIgMS44LTQuMSAxLjgtNC4xbC0uMS0xLS41LjFjLS40LjItMS40'
    b'LjEtMi4yLS41LS43LS42LTEtMy4yLTEtMy4ybC0zLjIgMi40Yy0xLjggMS4yLS42IDAgMC0u'
    b'OGwzLjItMy4xdi0yLjhzLTEgLjctMS44IDFjLTEgLjQtMi4xLjQtMi4xLjRsLTIuOSA0Yy0y'
    b'IDMtMS4yIDgtMS4yIDhzMiAwIDMuNC0xLjN6bTI1LjggMzMuNUwzMjAgMzczcy0uNC44LTEu'
    b'OCAyLjRhNDMgNDMgMCAwIDEtNC41IDRzLjMgNC4yIDEuOCA2LjVjMS4zIDEuOSAyLjUgMy42'
    b'IDQuNSA1IDItMS40IDMuMy0zLjEgNC41LTUgMS42LTIuMyAxLjktNi41IDEuOS02LjVzLTMu'
    b'Mi0yLjQtNC42LTR6Ii8+CiAgPHBhdGggZmlsbD0iI2I5NmIyOSIgZD0iTTMxOS40IDM4MC42'
    b'YzAgMSAwIDMuNC42IDMuNHMuNS0yLjQuNi0zLjRsLjItMy4zaC0xLjZzMCAyLjMuMiAzLjN6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2Q0YWYzYSIgZD0iTTMyMCAxNTEuM2MtNS43LjEtMTIuMy0u'
    b'Ny0xNi0ybC0zLjguOGE1MiA1MiAwIDAgMCAxOS44IDMuM2M4LjgtLjEgMTMuOC0xIDE5Ljgt'
    b'My4zbC00LS44YTUwLjcgNTAuNyAwIDAgMS0xNS44IDJ6bTIwLjUtNC43Yy0uNC0uNC0zLTIu'
    b'Mi0zLjctMi41LS42LS40LS4xLTEuMyAwLTEuNi4xLS40IDMtMS4yIDQuNi0xLjcgMS42LS40'
    b'IDEuNC0uNyAxLjQtLjdzLTEtMS4xLTYuOC0xLjdjLTUuOC0uNy0xNi0uNS0xNi0uNXMtMTAu'
    b'Mi0uMi0xNiAuNWMtNS44LjYtNi44IDEuNy02LjggMS43cy0uMi4zIDEuNC43YTE5IDE5IDAg'
    b'MCAxIDQuNiAxLjZjLjEuNC42IDEuMyAwIDEuNmE0NSA0NSAwIDAgMC0zLjcgMi42Yy0uNS40'
    b'LS41IDEgLjIgMXMuNyAwIDIuNy0uNGE5NC40IDk0LjQgMCAwIDEgMzUuMiAwYzIgLjQgMiAu'
    b'NCAyLjcuNC43IDAgLjctLjYuMi0xeiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0z'
    b'MzMuOSAxNDljLTQtLjQtNi41LTEtMTMuOS0uOS03LjQuMS0xMCAuNS0xMy45IDEgMi41IDEg'
    b'Ni42IDEuNSAxMy45IDEuNXMxMS40LS41IDEzLjktMS41em0tMTUtNTcuNS0uMSAyLjggMy0u'
    b'Mi0uMy0yLjcgMy4zLjUuMS0yLjYtMy40LjMuNi0yLjloLTMuOGwuNyAyLjktMy4zLS4zdjIu'
    b'NnptNi41IDcuMWgtNHYtMy40YTYgNiAwIDAgMC0xLjMtLjJsLTEgLjF2My41aC00LjNhNC42'
    b'IDQuNiAwIDAgMC0uMiAyaDExdi0uNmE1LjQgNS40IDAgMCAwLS4yLTEuNHoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjMWQ1ZTkxIiBkPSJNMzIwLjEgMTA1YTUuNSA1LjUgMCAwIDAgNS4yLTMuNEgz'
    b'MTVhNS41IDUuNSAwIDAgMCA1LjIgMy41em0yLjMtOS41djIuNGgyLjdhNS4zIDUuMyAwIDAg'
    b'MC0yLjctMi40em0tNC41IDBhNS4zIDUuMyAwIDAgMC0yLjggMi40aDIuOHYtMi40eiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNiOTZiMjkiIGQ9Im0zMjMuMyAxNDAtMy4zLTEuNS0zLjMgMS43Yy0x'
    b'LjIuNS0xIC40LTEuNCAxLjItLjMuOSAwIDEuMi42IDEuNGw0LjEgMiA0LjYtMmMuOC0uNC43'
    b'LS44LjQtMS41LS4yLS42LS43LS44LTEuNy0xLjN6Ii8+CiAgPHBhdGggZmlsbD0iI2Q0YWYz'
    b'YSIgZD0ibTMyMCAxMzkuMy0zLjUgMS43IDMuNiAxLjkgMy41LTEuOXptMC0xMi4zcy0uMyAx'
    b'LjItLjcgMS44Yy0uNC41LS43IDEtLjYgMS43IDAgLjYuOCAxIDEuMyAxIC40IDAgMS4yLS40'
    b'IDEuMy0xIDAtLjctLjItMS4yLS42LTEuNy0uNC0uNi0uNy0xLjgtLjctMS44eiIvPgogIDxj'
    b'aXJjbGUgY3g9IjMyMCIgY3k9IjEzMi44IiByPSIuNyIgZmlsbD0iI2Q0YWYzYSIvPgogIDxw'
    b'YXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zMTcuNiAxMjkuNHMxLjEtMS4zIDEuNi0yLjJsLjgt'
    b'MS41LjggMS41Yy40LjkgMS42IDIuMiAxLjYgMi4yczEuNi0xIDIuNi00YzEtMy4yLS4zLTYu'
    b'Ni0uNy0xMC4xYTIwOCAyMDggMCAwIDEtLjgtOS44IDcuMyA3LjMgMCAwIDEtMy41IDEgNy4z'
    b'IDcuMyAwIDAgMS0zLjYtMXMtLjMgNi4yLS44IDkuOGMtLjQgMy42LTEuNiA2LjktLjYgMTAg'
    b'MSAzLjIgMi42IDQgMi42IDR6Ii8+CiAgPGVsbGlwc2UgY3g9IjMyMCIgY3k9IjEyMi4zIiBm'
    b'aWxsPSIjYjk2YjI5IiByeD0iMi44IiByeT0iMi43Ii8+CiAgPGVsbGlwc2UgY3g9IjMyMCIg'
    b'Y3k9IjExNS44IiBmaWxsPSIjYjk2YjI5IiByeD0iMi43IiByeT0iMi42Ii8+CiAgPGVsbGlw'
    b'c2UgY3g9IjMyMCIgY3k9IjEwOS43IiBmaWxsPSIjYjk2YjI5IiByeD0iMi42IiByeT0iMi41'
    b'Ii8+CiAgPGVsbGlwc2UgY3g9IjMyMCIgY3k9IjEyMS44IiBmaWxsPSIjZDRhZjNhIiByeD0i'
    b'MS41IiByeT0iMS40Ii8+CiAgPGNpcmNsZSBjeD0iMzIwIiBjeT0iMTE1LjQiIHI9IjEuNCIg'
    b'ZmlsbD0iI2Q0YWYzYSIvPgogIDxlbGxpcHNlIGN4PSIzMjAiIGN5PSIxMDkuMiIgZmlsbD0i'
    b'I2Q0YWYzYSIgcng9IjEuMyIgcnk9IjEuMiIvPgogIDxwYXRoIGZpbGw9IiNiOTZiMjkiIGQ9'
    b'Ik0zMTkuOSAzMzZjLjIuMS4yLS4zLjItMS4ybC40LTRjLjItMS4yLS4zLTEuMS0uNi0xLS4z'
    b'IDAtLjUuOS0uNSAxLjRsLjEgNC4yYzAgLjYuMi42LjQuN3oiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZDRhZjNhIiBkPSJtMjkwLjQgMzU5LjEgNS4yLTMuNmExMS44IDExLjggMCAwIDAgNC00aC0x'
    b'Yy0uNiAwLTEtLjctMS4xLTEuNSAwLS44IDAtMi4zLjItNC4xLjItMS44LS4zLTMuMy0uMy0z'
    b'LjNzLTEuMiAxLjEtMyAyYy0yIDEtMi43LjYtMi43LjZsLS40LTEuOS0yIDMuN2MtMS4xIDIt'
    b'NC4yIDQuMi02LjQgNS44YTI4LjYgMjguNiAwIDAgMS02LjQgNGMtMS44LjctLjcgMS41LS43'
    b'IDEuNXMxLjggMS44IDYuNSAyLjdjNC42LjggNi45LTEgOC4xLTEuOXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZDRhZjNhIiBkPSJNMzA2LjggMzU3LjNjLTEuNy0uMi0yLjctLjgtMy0yLjYtLjIt'
    b'MS4yIDAtNS43IDAtNS43bC0xLjEgMS4yYy0uNy44LTIgMS0yIDFsLTEgMS42YTkuMyA5LjMg'
    b'MCAwIDEtMyAzLjIgNTAuNyA1MC43IDAgMCAwLTQuNiAzLjIgMjguMSAyOC4xIDAgMCAxLTQu'
    b'MyAzLjEgNyA3IDAgMCAwLTMuNiA0LjdjLS41IDIuNCAwIDMuMSAxLjggMyAxLjgtLjEgMiAw'
    b'IDUtLjcgMy0uOCA3LjMtNC4xIDEwLjQtNiAzLTIgNS40LTYgNS40LTZ6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2Q0YWYzYSIgZD0iTTMxNSAzNjBzLTEuMi0xLjYtMS43LTMuNGwtMS4zLTUuNC0x'
    b'LjUgMy4zYy0xIDIuMS0yLjcgMi43LTIuNyAyLjdzMCAuOS0xLjUgMi43YTIxIDIxIDAgMCAx'
    b'LTUuNyA0LjhjLTIuMSAxLjItNSAzLTYuNCA1LjEtMS41IDIuMi0xLjcgNC40LTEgNS40Ljgg'
    b'MSAxLjgtLjEgMy4yLS45IDEuNC0uNyA1LjUtMS4zIDExLjItNC40IDUuNi0zIDcuNC05Ljkg'
    b'Ny40LTkuOXoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMzE3LjUgMzcyLjdjMS41'
    b'LTIuNCAxLjgtOCAxLjgtOGwtMS4zLTFjLS44LS43LTIuMi0yLjktMi4yLTIuOWwtMiAzLjhj'
    b'LTEgMS44LTEuNSAyLjQtMy42IDQuMy0yLjEgMi01IDMuOS02LjIgNi0xLjIgMi0uNSA2LjEu'
    b'MyA3LjUuOCAxLjUgMiAxIDMtLjFsMy43LTMuM2MyLjEtMS44IDUtNCA2LjUtNi4zeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNiOTZiMjkiIGQ9Ik0yOTkgMzI1LjNjLjgtMS43IDEuNy0zLjcgMi41'
    b'LTQuOGExNSAxNSAwIDAgMCAxLjMtMi4ycy0yIDEuOC0yLjggMy4xYy0uOCAxLjQtMS4zIDIu'
    b'Ni0xLjcgNC0uMyAxLjQtLjIgMS42LjcgMHptOCAxLjUuNS0xLjlzLjMtMSAuMS0xLjFjLS4y'
    b'LS4xLTEgLjYtMS42IDIuNS0uNSAxLjgtMS40IDQuNS0xLjIgNC42LjIgMCAxLjgtMyAyLjIt'
    b'NC4xem02LjMgNSAuMy0uOHMuNy0yIC43LTIuNWMwLS40LS4yLTEtLjguMXMtLjYgMi4yLS43'
    b'IDIuNmMwIC41LS43IDIuMS0uNSAyLjMuMi4xLjYtLjkgMS0xLjd6TTI5My43IDM1MWwtLjgt'
    b'LjUtMS4zIDEuNWMtLjcuNy0xLjUgMS0yIDEuN2E4IDggMCAwIDEtMi43IDIuM2MtMS4zLjct'
    b'MS44IDEtMS42IDEuMS4zLjIgMS4yLS4zIDEuMi0uM3MuMyAwIDEuOS0xYzEuNi0uOSAyLTEu'
    b'NCAzLTIuMyAxLS45IDIuMy0yLjUgMi4zLTIuNXptNi44IDguMWMuNi0uNiAxLjMtMSAxLTEu'
    b'NC0uNC0uMy0uOC0uMy0xLjQuMmwtMi44IDIuNi0yIDEuNWMtLjcuNi0yLjMgMS40LTMgMS44'
    b'LS44LjUtLjEuNS0uMS41bDEuMi0uNSAyLjUtMXMuNy0uMyAxLjYtMWMxLS43IDIuNC0yIDMt'
    b'Mi43em03LjkgNS41Yy41LTEgMC0uOC0uOS0uNC0uOC4zLTIuNyAyLjQtMy44IDMuMS0xLjEu'
    b'OC0yIDEuMS0zIDEuNi0uOS40LS45LjctLjguOSAwIC4yLjQuMi44IDBsMS42LS45IDEtLjJj'
    b'LjYgMCAxLjMtLjYgMi40LTEuNiAxLjItMSAyLjItMS41IDIuNy0yLjV6bTMuNyA3LjJjLTEu'
    b'NC44LTMuOCAyLjctNC41IDQtLjYgMS4yLTEgMi4xLS44IDIuMy4yLjIuOS0uMiAxLjItLjds'
    b'LjktMS4yczIuNC0yLjQgMy4zLTNhOC4zIDguMyAwIDAgMCAyLjYtM2MuNC0xIC4xLTEuNC4x'
    b'LTEuNHMtMS41IDIuMS0yLjggM3oiLz4KICA8cGF0aCBmaWxsPSIjYzUyMTI2IiBkPSJNMjc1'
    b'IDE3MGEyMi4zIDIyLjMgMCAwIDAtOC4zLTIuNmMtMy43LS4zLTYuNS4yLTkuNSAxLTIuMi42'
    b'LTQgLjctNS43LjMtMi42LS43LTQuNi0zLTUuMy02IDAgMC0yLjQgMy4xIDAgNi41YTcuMiA3'
    b'LjIgMCAwIDAgNC40IDIuOWM1IDEgMTAtMiAxNC4zLTIuNCA0LS4yIDcuMyAyLjQgNy4zIDIu'
    b'NHMxIC44IDIuMyAwYzEuNC0uOCAxLjgtMS40LjUtMi4yeiIvPgogIDxwYXRoIGZpbGw9IiNk'
    b'NGFmM2EiIGQ9Im0yNjAuMyAzMTcuNS0xLjItLjJjLS43IDAtMi4yLS42LTIuNy0uOC0uNC0u'
    b'Mi0xLjEtLjItMS42LjMtLjQuNS00IDIuNy00IDIuN2g2YzIgMCAzLjUtMiAzLjUtMnoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMjc3LjQgMzE2LjR2LS41bC0uOC0xLjhzLTEg'
    b'LjYtMS45IDEuNWMtMS4yIDEuMy0yLjQgMy0zIDMuNy0xIDEuMy0yLjQgMi41LTEuMi41czEu'
    b'Ni0zIDIuNi00LjRjMS0xLjMgMS43LTIgMS41LTJsLTMuNC0uNWMtMi41LS4zLTQuMS0xLjMt'
    b'NS4zLTJsLTMuMy0xLjlzLTQuMyAxLjktNS45IDIuM2MtMS42LjQtMi42LjYtMSAxLjQgMS42'
    b'LjggMi45IDEgMy43IDEuNWExMSAxMSAwIDAgMCA0LjYgMS4yYzEuNCAwIDMuOSAwIDMgMS0x'
    b'IDEuMS0yLjEgMy0zLjIgNmEyMC4zIDIwLjMgMCAwIDAtMSA3djIuNXMxLjgtMiA2LjYtNSA2'
    b'LjYtNCA3LjUtNC40Yy45LS40IDEuMy0uNCAxLjEtMS41bC0uNi00LjZ6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2Q0YWYzYSIgZD0iTTI5NS42IDMwMmE2OC41IDY4LjUgMCAwIDEtLjktLjQgMSAx'
    b'IDAgMCAwLS4yIDAgMTUgMTUgMCAwIDAtNC42IDQuMmMtMS4yIDEuOS0yLjQgMi0xLjEgMGEx'
    b'Ny45IDE3LjkgMCAwIDEgMy4yLTQuMiAyMy41IDIzLjUgMCAwIDEgMS0uOCA1My4zIDUzLjMg'
    b'MCAwIDEtNy4zLTQuMmwtMS42IDIuNWMtMSAxLTMuMyAyLTMuMyAyczEuOC0yIDIuNC0zLjNs'
    b'LjgtMi41YTMxLjYgMzEuNiAwIDAgMS00LjgtNC42IDE3LjggMTcuOCAwIDAgMS00LjEgNy40'
    b'Yy0zLjggNC4yLTExLjMgNi4zLTExLjMgNi4zcy0yLjYuMy0uNS45YzIuMi41IDMuNyAxLjUg'
    b'Ny44LjhsNS0xLjFjLjYtLjIgMiAwIDAgLjctMiAuOC02LjkgMS41LTguNyAxLjQtMS45LS4y'
    b'LTQuNC0uNi0xLjguOCAyLjcgMS40IDMuOCAyIDUuNCAyczIuMy41IDMuOS41IDItLjMgMy0u'
    b'NWMxLjItLjMgMiAuMSAyIC42IDAgLjQtMS42IDEuNy0xLjUgNC43IDAgMy4xLjMgNS4xLjUg'
    b'NiAuMyAxIDEgMi40IDEuNCAzLjIuNS44LjcgMS43IDEuMS0uMS41LTEuOCAxLjUtNC40IDEu'
    b'OS02LjEuMy0xLjcuNi0xLjguNy0yLjcuMi0uOSAxLjItMS42LjcgMGExMzMuNCAxMzMuNCAw'
    b'IDAgMC0xLjMgNS4yYy0uMyAxLjUtMS4xIDQuMi4yIDIgMS40LTIgNi40LTcuNyA3LjMtOC44'
    b'bDItMi44Yy43LS44IDIuNC0xLjkgMy4zLTMuMWEyOC41IDI4LjUgMCAwIDEgMy45LTRsLTQu'
    b'NS0yem0tNjkuNS0xMjkuMmMwIDMuMSAzLjUgOSA1LjUgMTIuMiAxLjkgMy4xIDIuNCA0LjQg'
    b'MiA0LjYtLjIuMi0xLTEuNC0yLjEtMi44cy0zLjItNC43LTUtNy4yYy0xLjYtMi41LTQuMi04'
    b'LjQtNC41LTguOS0uNC0uNS0uNS0uOS0xLjQtLjItLjguNy0yLjUgNy4yLS41IDExLjYgMiA0'
    b'LjQgNSA3LjYgNi4zIDkuMiAxLjMgMS41IDMgNCAyLjcgNC4xLS4zLjItLjgtLjQtMi4zLTJM'
    b'MjIxIDE4N2E1MS42IDUxLjYgMCAwIDEtMy44LTZjLS4yLS41LS42LS40LS44LS4yLS41LjYt'
    b'MS40IDEuOS0xIDUuNGExNyAxNyAwIDAgMCA1LjMgMTAuMmMyLjMgMi40IDQuNiA0LjUgNC4y'
    b'IDQuOS0uMy4zLTIuNy0xLjgtNC4zLTMuMy0xLjYtMS42LTUuNS01LjQtNi40LTYuNS0uOS0x'
    b'LTIuMS0uNS0yIDMuNyAwIDQuMyA0LjcgOC41IDYuNiAxMC45IDIgMi4zIDQuNCAzLjcgNC4y'
    b'IDQuMi0uMi41LTIuMi0uNy0zLjQtMS42bC03LTQuNmMtMS0uNy0xLjQuNi0uMiA0LjYgMS4y'
    b'IDQgNC43IDcuMiA2LjggOC43IDIgMS41IDUuNCAzLjMgNS4yIDMuOC0uMi40LTEuNi0uMi0z'
    b'LjYtMS4xYTM5LjQgMzkuNCAwIDAgMC02LTIuM2MtMS42LS41LTEuNi43LTEuNi43cy0uMyAz'
    b'LjUgMi4yIDYuMmExMy4zIDEzLjMgMCAwIDAgOCA0LjNjMi42LjUgMyAuNiAzIDEtLjEuNC0u'
    b'NC41LTEgLjVsLTUuNC4yYy0yLjIgMC0zLjQuNi0zLjQgMS42cy0uMSAyLjMgMy4zIDQuNiA3'
    b'LjIgMi42IDguOCAzYzEuNi4zIDEuNy40IDEuNC45LS40LjUtMS4xLjQtMy42LjctMi42LjIt'
    b'NC4xIDEuMi00LjUgMi0uMy42LjIgMi42IDIuMyA0IDIgMS40IDQuOCAxLjkgOC44IDEuNiA0'
    b'LS4zIDUtLjMgNS4xLjMuMi43LTEuMiAxLTMuMiAxLjItMiAuNC0zLjUuNC00LjcgMS4zLTEu'
    b'MSAxLS4yIDIuOSAxLjcgNC4zIDIgMS40IDYuOCAxLjQgOC44IDEuMyAyLS4yIDUtLjkgNS4z'
    b'LS40LjIuNi0xLjUgMS40LTMuNiAyLjEtMiAuOC0yLjcgMS4yLTMgMi4xLS41LjktLjEgMS43'
    b'IDIuMyAyLjYgMi41IDEgNi4xIDEgOCAwIDEuOS0uOCAyLjktMS4xIDMuMi0uOC40LjMgMCAu'
    b'Ny0uNCAxLjEtLjQuNS0yIDEuOC00IDIuMy0yLjEuNi0yLjMuNi0zIDIuMi0uOCAxLjcgMSAz'
    b'IDQuOCAzLjIgMy44LjEgOC44LTEuNCAxMC40LTIuMyAxLjYtMSAyLjItMS4xIDIuNS0uOC4y'
    b'LjMuMi41LS42IDEuMS0uOC42LTMuNCAyLjUtNC43IDIuOC0xLjIuMy0xLjQgMS4zLTEuNCAy'
    b'LjEgMCAxLS4zIDIuNiAzIDMuNSAzLjQuOCA3LjMuMiAxMS0yLjRhOC4zIDguMyAwIDAgMCAy'
    b'LjItMiAyOCAyOCAwIDAgMSAuMi04Yy0uNyAwLTItLjMtMy40LS45LTItLjgtMi44LTIuNi0z'
    b'LjMtMy42LS40LTEtMS4xLTEtMi0uOC0uNy4zLTEuNS42LTIuNi42YTcuOSA3LjkgMCAwIDEt'
    b'NS4zLTIuOGMtMS44LTItMS40LTQtMS41LTUgMC0xLTEuNy0uMy0yLjUtLjNzLTMuMS0uNC01'
    b'LjMtMS45Yy0yLjEtMS40LTIuMS0zLjQtMi4zLTQuMy0uMi0uOC0xLTEuMy0xLjctMS42LS43'
    b'LS4yLTEuOC0uNS0zLjMtMS43YTYuOSA2LjkgMCAwIDEtMi00LjRjLS4xLS44LTEtLjgtNC0y'
    b'LjQtMy0xLjUtMi43LTQuNy0yLjYtNiAuMS0xLjMgMS41LTIuMyAxLjUtMi44cy0xLS42LTIt'
    b'MS4yLTMuNS0xLjYtMy42LTUuNGMwLTMuNyAyLjQtNC4xIDIuNC00LjFsLTEuNC0uOGMtMS0u'
    b'Ni0zLjgtMi41LTMuOC00LjdzMS0zLjIgMS44LTMuOCAyLjctMSAyLjctMS0xLjMtLjktMS44'
    b'LTIuNmMtLjUtMS43LS43LTMuOS41LTUuNCAxLjMtMS42IDMuNC0xLjYgNC42LTEuNiAxLjEg'
    b'MCAyLjEuNiAyLjUuMy40LS4zLjUtLjYgMC0xLjVhNi42IDYuNiAwIDAgMSAwLTMuN2MuMy0u'
    b'OC40LTIuMiAzLjItMy4yIDIuOS0uOSA2IDEgNi45IDEuNi45LjUuNS0uOC41LTEuNyAwLTEt'
    b'Mi0zLjMtNC4yLTYuNmE3MyA3MyAwIDAgMS01LjYtMTAuMiA2NS43IDY1LjcgMCAwIDEtNC41'
    b'LTEzLjRjLS4zLTEuNi0xLS44LTEtLjhzLS42LjItMi4yIDQuMWEyNSAyNSAwIDAgMC0xLjYg'
    b'MTAuNXoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMjc2LjUgMjQxLjRjLTEuNy0u'
    b'MS00LTEtNS43LTMuNi0xLjctMi41LTQuMy0zLTguOC0zLTQuNC4xLTYuNS0yLTcuNi01LjIt'
    b'MS4xLTMgLjEtNi42IDQuNy04LjkgNC42LTIuMiA2LjctNC43IDYuOC04LjYuMi0zLjktNC41'
    b'LTguNy05LjMtMTQuMS00LjctNS41LTguNC0xMy4yLTguNC0xMy4ycy0xLjQgMS44LTEuNCAz'
    b'LjdjMCAxLjguNyAzLjcgMCA0LjJzLTEtLjgtMy43LTJjLTIuOC0xLjItNS0xLjQtNi43LjYt'
    b'MS44IDIgMCA1LjQgMS41IDcgMS42IDEuNyAyLjkgMyAyLjQgMy41LS40LjYtMi43LS45LTMu'
    b'NS0xLjQtLjgtLjUtMi42LTIuNS01LjMtMi4zLTIuNi4zLTMuNiAxLTMuOCAzLjMtLjMgMi4z'
    b'IDIuNCA0LjIgNC4xIDUuMSAxLjcuOSAyLjQgMS42IDIgMi0uNS4zLS45IDAtMS43LS4zYTgg'
    b'OCAwIDAgMC00LjMgMGMtMS40LjYtMy42IDIuNS0xLjUgNC44czYuNCAzLjIgNy4yIDMuM2Mu'
    b'OS4yIDEuMyAwIDEuNC42IDAgLjctMS44LjctNC4xLjgtMi40LjEtMyAyLjQtMi43IDQgLjMg'
    b'MS44IDQuMiAzLjcgNi40IDQgMi4xLjQgMi45IDAgMyAuNy4yLjYtLjIuOC0xLjQgMS4yLTEu'
    b'Mi4zLTMuNS42LTQgMi41LS40IDEuOS0uNSAyLjcgMS4zIDQuNCAxLjggMS42IDQuOCAxLjQg'
    b'NS42IDEuMi45LS4yIDItMS4xIDIuOC0uMy45LjktLjggMS42LTIuMyAyLjYtMS40IDEtMS4z'
    b'IDMgMS4yIDQuNCAyLjUgMS40IDUgLjkgNiAuNSAxLS4zIDIuNC0yIDMuMS0xIC43IDEuMS0y'
    b'LjIgMS41LTMuNCAzLTEuMiAxLjQtLjcgMy44IDEuNyA1LjNzNi40LjQgNy0uMmMuNy0uNiAx'
    b'LjYtLjggMi4xLS4zcy0uMiAxLjktLjggM2MtLjUgMS4zLTEuNCA0LjggMi4yIDYuMnM2Ljkt'
    b'MS43IDcuNS0yLjNjLjYtLjYgMS4yLS43IDEuNy0uNS41LjMuMy44LS4xIDEuNC0uNS42LTEu'
    b'NCAzLjIgMS4yIDVhNi4zIDYuMyAwIDAgMCA0LjcgMWwyLTcuMmgtLjZjLS4zIDAtLjQuNS0u'
    b'NC43IDAgLjIgMCAuNC0uMi40LS4zIDAtLjQuMi0uOC41LS41LjMtLjkuNy0xLjEuNS0uMy0u'
    b'MiAxLS44IDEuMi0xLjIuMy0uNCAxLTEgMS0xLjQgMC0uNC4yLS42LjktMS4xbC40LS42YTEw'
    b'MC41IDEwMC41IDAgMCAwIDEuNy0xMi43aC0xLjJ6TTIwMyAxODcuNmEzNy4zIDM3LjMgMCAw'
    b'IDAgOS4zIDEyLjFsLTEtMy4yYy0uNC0xLjQtLjItMi45LS4yLTIuOXMtMS4zLTEuNy0zLjgt'
    b'NS42Yy0yLjYtMy45LTMuOS05LjYtMy45LTkuNnMyLjQgNS43IDQuMiA4LjhjMS44IDMgNCA1'
    b'LjUgNCA1LjVzLjYtMi43IDEuMi0yLjhjLjUtLjIuOS4yIDEuMy44LjUuNi45LjYuOS42bC0x'
    b'LjYtMi44LTEuNS0yLjJjLTEuNS0yLjMtNC42LTYuNi02LjEtMTAuOS0xLjYtNC4zLTUuMS0x'
    b'NS4xLTUuNy0xOC4zLS42LTMuMi0xLjItMS40LTEuOC45YTI3LjYgMjcuNiAwIDAgMC0xIDEw'
    b'LjcgNTMuNSA1My41IDAgMCAwIDUuNyAxOC45em01IDIxYTEzNS45IDEzNS45IDAgMCAwIDMu'
    b'NSAyLjVsLS42LTEuNy0uMy0yLjktMi44LTIuNWE0MS43IDQxLjcgMCAwIDEtNS42LTZjLTMt'
    b'My42LS42LTEuNCAxLjggMS4yczcgNi4zIDcgNi4zdi0uOGEzLjEgMy4xIDAgMCAxIC43LTEu'
    b'OWMuNC0uNi4yLS42LTIuNC0yLjZhNzQuNSA3NC41IDAgMCAxLTE3LjYtMjQuNHMtMS40IDkg'
    b'NCAxOC43YzUuNCA5LjkgMTAuOCAxMyAxMi4yIDE0LjF6bTI4LjUgNTYuM2MzLTEuMiAyLjEt'
    b'NC4xIDIuMS00LjFzLTEuOC41LTMuNSAxLjJjLTEuNy42LTUuOCAxLjgtNy40IDEuOC0xLjcg'
    b'MC0xLjctLjItMS43LS40czEuMiAwIDMuNi0uNGEyOSAyOSAwIDAgMCA3LjItMy4xYy43LS41'
    b'LjYtLjYtLjQtLjdhNC41IDQuNSAwIDAgMS0yLjQtLjljLS40LS4zLTEuNS4xLTQuMi44YTUw'
    b'LjggNTAuOCAwIDAgMS0yMS41LjdjLS42LS4yLTEuMy4yLjcgMy43IDIuMSAzLjUgOS40IDUu'
    b'MyAxNC40IDUuM3MxMC4xLTIuOCAxMy0zLjl6bS0xMy40LTcuMmM1LjIgMCA3LjEtMS41IDcu'
    b'MS0xLjVsLS43LTEuM2MtLjctMS0uNi0yLjktLjYtMi45bC0zLjQuNmMtMi4xLjMtNC42LjYt'
    b'Ny40LjEtMi44LS41LTEuNi0uOC42LS41IDIuMi4yIDYuNC0uNiA3LjgtMSAxLjQtLjUuOC0x'
    b'LS4xLTEuMy0xLS4zLTMuNS0xLjktMy41LTEuOXMtNi4zLjgtMTIuMS4yYy02LS43LTkuNi0y'
    b'LjItMTAuOC0yLjQtMS4yLS4yLTEuMi4zLTEuMi4zcy0uMy42IDEuOCAzLjdjMiAzLjIgNiA1'
    b'LjMgOS4zIDYuMyAzLjQgMSA4IDEuNiAxMy4yIDEuNnptLTEuNC0xMi4yLS41LTEuM2MtLjMt'
    b'MSAuNi0xLjkuNi0xLjlzLTEuMi0uMy01LjEtLjhjLTMuOS0uNS00LjEtLjgtNi41LTEuMy0y'
    b'LjQtLjYtNC0xLjMtNC0xLjUuMS0uMy45IDAgMi4zLjYgMS40LjUgNy40IDEuMiA5LjkgMS41'
    b'IDIuNS40IDMuOS42IDQuMy40LjUtLjMgMi0uNyAyLS43bC0yLjQtLjVhOC40IDguNCAwIDAg'
    b'MS0zLjItMS4zYy0uNy0uNS0uOS0uNi00LTEtMy4zLS4zLTUuOC0xLjMtMTEuNS0zLjQtNS43'
    b'LTItMTAtNC42LTExLjEtNS41LTEuMi0xLTEtLjMtLjggMSAuMyAxLjEuMyAyLjYgMy4yIDYg'
    b'Mi44IDMuMyA0LjIgNC44IDExLjUgNy40IDcuMiAyLjcgMTUuMyAyLjMgMTUuMyAyLjN6TTIw'
    b'MC4yIDIyOGE0MC42IDQwLjYgMCAwIDAgMTUuNSA2LjRjLjQtLjQtLjQtMiAwLTIuOC40LTEu'
    b'MSAxLTEuMSAyLjYtMS4yIDEuNi0uMS41LS40LjItLjRsLTMtLjdjLTIuNi0uNy01LjItMS4x'
    b'LTguNy0yLjQtMy41LTEuNC00LjYtMi4zLTQuNS0yLjYuMS0uMyAxLjYuOCA1IDIgMy4yIDEu'
    b'MyA3IDEuOCA5IDIuMyAyLjEuNC4zLS41LS43LTEtMS0uNi0yLjMtMi44LTIuMy0yLjhzLTIu'
    b'My0uNC02LTEuNWE0OC44IDQ4LjggMCAwIDEtMTAtNC4yYy0xLjEtLjYtMi4yLTEuNC0zLjMt'
    b'Mi4ybC01LjEtMy43Yy0xLjMtMS0xLS4yLS44LjRzMSAzLjIgMyA2LjFjMiAzIDIuNyAzLjgg'
    b'OS4xIDguM3ptLTEtMTIuN2M2LjMgNSAxMS43IDYuNiAxMi42IDcgMSAuNC45LS4yLjctLjct'
    b'LjItLjUtLjMtMi4yLS4zLTIuMmwtNC44LTIuOGE3OS42IDc5LjYgMCAwIDEtNy4xLTQuN2Mt'
    b'MS45LTEuMy0uOC0xLjItLjItLjcuNi41IDMuMSAyIDUuNyAzLjZsNi40IDMuOXMuMS0uOS43'
    b'LTEuNGMuNS0uNSAxLjgtLjQgMS44LS40bC0xLTEuM2MtLjQtLjYtMi41LTEuMy00LjktMi40'
    b'YTU3LjUgNTcuNSAwIDAgMS05LjYtNi44Yy0zLTIuNi05LTkuMS05LjUtOS43LS40LS41LS42'
    b'LS40LS43LjMgMCAuNi0uMiAxIC40IDQgLjcgMyAzLjUgOS40IDkuOCAxNC4zem0yMi4zLTQ3'
    b'LjJjLjcgMS41IDEuNSAyLjYgMiAzLjZhNTIgNTIgMCAwIDEgMS40IDIuNHMuMi0uNSAwLTEu'
    b'NGMtLjEtLjgtLjItMiAwLTMuNWwuMy0yLjNjMC0uNy0uNC0xLjQtLjUtMS45bC0xLjUtN2Mt'
    b'LjUtMi43LTEtNi40LS45LTkuNyAwLTMuMi41LTEuNi41IDBhNjIuMiA2Mi4yIDAgMCAwIDIu'
    b'OCAxNy4yczAtLjkuNS0yLjFjLjUtMS4zIDEuMy0yLjcgMi00LjIuNS0xLjYuMy0xLjkuMy0x'
    b'LjlzLTIuMi0xMC42LTIuOC0xNS42Yy0uNi01LTEuNS0xOC4xLTEuNS0xOC4xLTMuMyAzLjIt'
    b'NS43IDExLjgtNiAyMC0uNCA2IC42IDExLjcuOSAxNCAuNSA0LjUgMS4zIDggMi41IDEwLjV6'
    b'bS03LjIgMTYuOGMuMS0yLjQuNy00LjMgMi4yLTQuOCAwIDAtMS4zLTIuNC0yLjUtNS44YTQ1'
    b'LjcgNDUuNyAwIDAgMS0xLjktNy43Yy0uOC01LjYtMS41LTExLjUuMi0yIDEuNyA5LjcgMy43'
    b'IDEzIDMuNyAxM2wyLjUgNGExNy4zIDE3LjMgMCAwIDEtLjQtNC45Yy4xLTEuOS40LTQuNSAx'
    b'LTYuNSAwIDAtMy02LTQuOS0xM2E4Mi4yIDgyLjIgMCAwIDEtMy4yLTIyLjdzLTMgMi4zLTQg'
    b'MTMuOWE2OSA2OSAwIDAgMCA3LjMgMzYuNXptMzMuMyA4OC42LTItMS4zYy0xLjQtLjktMS0z'
    b'LjctMS0zLjdsLTEuNCAxYTE5LjIgMTkuMiAwIDAgMS0zLjcgMi4yYy0xLjUuNi0yLjIgMS0z'
    b'IDEuMi0xIC4zLS44IDAgMC0uNS44LS40IDEtLjcgMy0xLjQgMS45LS44IDUuNy00LjIgNS43'
    b'LTQuMmwtMi41LS4xYy0xLjYgMC0zLjYtLjktMy42LS45cy0xLjYgMS40LTggNC4yYTUwIDUw'
    b'IDAgMCAxLTExLjggMy41cy43IDMuMiAzLjggNC4zYzIuNSAxLjEgNiAxLjggMTIuOS4yYTQz'
    b'LjUgNDMuNSAwIDAgMCAxMS42LTQuNXptOC40IDYuNWMuNS0yLjctMS00LjYtMS00LjZsLTEu'
    b'MyAxLjFjLTEgLjktMi40IDIuNS01IDMuOS0yLjggMS4zLTMuNyAxLjItMS4xLS4yczYuNC01'
    b'LjMgNi40LTUuM2wtMS0uNGMtMS0uNC0yLjguMy0xMCA0LjZzLTExLjQgNC41LTExLjQgNC41'
    b'IDMuMiAzLjkgMTIgMy42YzguNy0uMyAxMS44LTQuNSAxMi40LTcuMnptMTYuNS0zLjFzLTEg'
    b'MS4zLTIuMyAyLjJjLTEuMy45LTQuNyAxLjQtNC43IDEuNGwtLjggMS4yYy0uNyAxLTIuMiAz'
    b'LTMuNyA0LTEuNiAxLjItNCAyLTQuMSAxLjYtLjEtLjMgMS40LS44IDIuOS0xLjggMS41LS45'
    b'IDIuOC0yLjYgMy44LTMuNyAxLTEuMi0uNC0xLS40LTFoLTMuNWMtMS43LS4yLTEuNCAwLTEu'
    b'OS43bC0yLjQgMy00LjQgNS4xYy0xIDEuMi0uMiAxLjUtLjIgMS41cy40LjcgNC4zIDEuMmMy'
    b'LjQuMiA1IDAgNy44LTEuNmEyMyAyMyAwIDAgMCA1LjItNC41YzQuNi01LjEgNC40LTkuMyA0'
    b'LjQtOS4zem0yIDEwLjUtMS40IDEuOCAxLjItM2MuMy0uNi43LTEgMS0xLjQtLjctMS40LTEu'
    b'My0zLTEuNi00LjctLjUgMS40LTEuOCA1LjUtMy40IDguMS0yIDMuMi0zLjggNC40LTIuNyA1'
    b'LjMgMS4yLjggMy40IDEgNi0uMiAyLjQtMS4yIDMuMS0zLjMgMy41LTVhMjQuOCAyNC44IDAg'
    b'MCAxLTEuMi0yLjEgNSA1IDAgMCAwLTEuMyAxLjJ6Ii8+CiAgPGVsbGlwc2UgY3g9IjI3NCIg'
    b'Y3k9IjE1OC42IiBmaWxsPSIjZDRhZjNhIiByeD0iMS44IiByeT0iMS42Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2Q0YWYzYSIgZD0iTTI3MC4zIDE1NS41YzEuNiAwIDIuNC0uOCA0LjItLjYgMi4y'
    b'LjIgNSAxLjQgOC42IDMuM2ExNC42IDE0LjYgMCAwIDAgOS44LjljMS0uMyAyLS45IDIuOS0x'
    b'LjQgNC4yLTIuNCAzLjItNy4xIDMuMi03LjFhMTYuNyAxNi43IDAgMCAxLTEwLjcgMy4ybDEg'
    b'LjhjLjUuNiAxLjcgMS40IDEuMyAxLjctLjQuMy0yLTEuMi0zLjItMi4yYTE5LjQgMTkuNCAw'
    b'IDAgMC02LjUtMy4yYy0zLjMtMS03LTEtOS41LjQtMi41IDEuMy0yLjcgMy0yLjMgMy43LjIu'
    b'NC42LjUgMS4xLjV6bTQ2LjIgMzQuN2MtLjgtLjItMi4xLS40LTMuOC0yYTcxLjQgNzEuNCAw'
    b'IDAgMS02LjMtN2MtLjUtLjgtLjMtMS41LjktMiAxLjEtLjUgMi0yIDItMnMtMi42LTEtNC4z'
    b'LTIuMmE0NCA0NCAwIDAgMS02LjItNS43Yy0uNi0xLS4zLTEgLjUtMS4zLjgtLjMgMS0uOCAx'
    b'LS44cy0xLjgtMS4yLTMuNS0yLjZhNzEgNzEgMCAwIDEtNC0zLjZjLTIuNiAxLTYuNy42LTgu'
    b'OS4yLTMuOC0uNy02LjYtMi4zLTYuNi0yLjNsLS42IDEuOGMtLjUgMS4yLTIuMyAxLjgtNCAu'
    b'Ny0xLjgtMS4yLTEuNC0zLjctMS40LTMuN3MtMS41LTEtNC40LTJjLTMtMS4xLTUuNC0xLjMt'
    b'Ny44LS4yLTIuNCAxLjEtMy42IDQuNC0zLjYgNyAwIDIuNCAxLjQgMS4zIDEuNiAxIC4zLS4z'
    b'LjktMi4xIDMuOS0yLjZzNS43IDEgOS4yIDMuOGMzLjQgMi44IDQuMSAzIDUuOSA0LjggMS43'
    b'IDEuOC4zIDIuNy0yLjYgMy43LTMgMS02LjgtMS02LjktLjktLjYuMyAxLjMgMyAzLjggNCAy'
    b'LjYgMSA1LjguMyA4LjMtLjggMS43LS42IDIgMCAyLjYuNmExNSAxNSAwIDAgMSA0IDkgNCA0'
    b'IDAgMCAwIDIuNi0zYzAtLjYuMi0xLjggMS4yLTEgMSAxIDEuNyA2IDEuNyA4LjJzLS43IDUu'
    b'My0uNyA1LjNoLjdsMi4zLTEuMmMxLjEtLjcgMS4yIDAgMS4yIDEuM3MuNCAzLjYgMiA3Ljhj'
    b'MS43IDQuMiA0LjEgNS41IDQuMSA1LjVzLjUtLjggMS0yLjUuOC00LjguOC03LjdjMC0yLjgt'
    b'LjgtOC44LS44LTguOHMzLjUgNC4yIDcgNS4yYzMuNiAxIDcuMi40IDguNy0xLjMgMS41LTEu'
    b'Ny4xLTIuNS0uNi0yLjd6Ii8+CiAgPHBhdGggZmlsbD0iI2Q0YWYzYSIgZD0iTTI5MyAyMDFz'
    b'LTEgMi41LTEuNyAzLjNsLS44IDFzMSAxIDIuNiAxLjRsMyAuOHMtMS44LTIuNC0yLjQtNC4x'
    b'bC0uNy0yLjN6bTIxLjQtMS4zYTcxLjYgNzEuNiAwIDAgMC0uOC0yLjEgMTUgMTUgMCAwIDEt'
    b'OC4yLTEuN3MxLjcgMy4zIDMuMyA0LjVsMS45IDEuMnMtMS43LjMtMy45LTJjLTIuMi0yLTMu'
    b'MS00LjYtMy4xLTQuNnMuNSA1LjgtLjQgOS4zbC0xLjEgNHM0LjYuOSA5LjgtLjZjNS4yLTEu'
    b'NCA1LjYtMS45IDUuNi0xLjlzLjYtLjEtLjItMS4yYTI4IDI4IDAgMCAxLTIuOS01eiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNiOTZiMjkiIGQ9Ik0zMDUgMTg3YTExIDExIDAgMCAxLTEuOC0yLjNz'
    b'LS41LjUgMCAxLjNhMTUgMTUgMCAwIDAgNC4zIDMuNyAxMS4xIDExLjEgMCAwIDAgMyAxLjJ2'
    b'LS40cy0zLjktMS43LTUuNS0zLjV6bS02LjMgMTItLjQtOC4zYzAtMS0uNy0uOC0uNy0uOGwt'
    b'LjguMyAxLjYgMTAuNmMuMSAxLjIuNyAxIDEgMS0uNi0uMy0uNy0yLjUtLjctMi44em0tOS44'
    b'LTMxLjRjLS42LS42LTItMS0uNy40czMgMy4yIDMuNSA0LjdjLjUgMS40LjggMy4zIDAgMi45'
    b'LS45LS40LTEuNS0uNC0yLjQtMS4yYTE1IDE1IDAgMCAwLTMuMi0yLjFjLS43LS4yLTIgMC0x'
    b'IDFhMjQuOCAyNC44IDAgMCAwIDQgMy42YzEuOCAxLjMgMyAyIDQgMi42YTM2LjkgMzYuOSAw'
    b'IDAgMCAxLjkgMS4zcy0uOS02LTIuNS04LjVhMjYuMyAyNi4zIDAgMCAwLTMuNi00Ljd6bS0z'
    b'MiA5OS4yYTcgNyAwIDAgMS0yLjggMS4zcy0uOCAwLS44LjIgMSAwIDEuOC0uMWE4IDggMCAw'
    b'IDAgMi42LTEuNGMuNS0uNCAxLjItLjggMS0xLjQtLjMtLjYtLjYuNS0xLjggMS40em0xMC4z'
    b'IDUuNS0yLjIgMS44LTEuMy43Yy0uNy4yLS45LjYtLjkuNnMuMi4yLjkgMCAyLjctMS43IDMu'
    b'NC0yLjNjLjctLjYgMS0uNy43LTFzLS40IDAtLjYuMnpNMjI1LjMgMTk4Yy40LjQuOCAxIDEg'
    b'LjkuMi0uMiAwLS41LS41LTFsLS44LS45LTEuMS0xLjVjLS40LS40LTEtLjctLjMuM2wxLjcg'
    b'Mi4yem0tMy4yIDcgMS40IDEuM2MuNS41LjggMS4xIDEuMS44LjMtLjMtLjctLjktMS4yLTEu'
    b'NWE3LjUgNy41IDAgMCAwLTEuNC0xLjQgMTAgMTAgMCAwIDAtMS4yLS44bDEuMyAxLjZ6bTEu'
    b'MiAxMS4yYy44LjkgMiAxLjEgMi4xLjguMi0uNCAwLS42LS43LTFhMjQgMjQgMCAwIDEtMi4z'
    b'LTEuNGwtMS40LTEuMWMtLjQtLjQtLjgtLjctMS0uNi0uMS4xIDEuMSAxLjUgMS41IDEuNy40'
    b'LjIgMSAuOCAxLjggMS42em0yLjMgOWMwLS4zIDAtLjUtLjYtLjVhMjYuOSAyNi45IDAgMCAx'
    b'LTEuNi0uMnMtMS4zLS41LTEuMy0uMmMtLjEuMyAxIC44IDEuNS44bDEuNC40Yy4zLjIuNiAw'
    b'IC42LS4zem0xIDkuOGMtMS40IDAtMi42LS4zLTIuNyAwLS4xLjEuNi41IDEuMy43LjguMyAy'
    b'IC4zIDMgLjQgMSAwIDEtLjIgMS0uNiAwLS41LTEuMi0uNS0yLjYtLjV6bTExIDEwLjhjLS4y'
    b'LS4yLS43IDAtMS41IDAtLjguMy0yIC41LTIuOC41bC0yLjQtLjEtLjkuMmMwIC4yIDEuMi4y'
    b'IDMgLjQgMS43LjIgMi45LS4yIDMuNy0uMy44LS4yIDEuMS0uNSAxLS43em00LjYgNy42YTUu'
    b'NiA1LjYgMCAwIDEtMi4yLjRsLTIuMi4zcy0uOCAwLS42LjRjMCAuMy4zIDAgMS0uMWgyLjNj'
    b'MS4xIDAgMS44LS40IDIuNS0uNS43LS4xIDEuNS0uNSAxLjItMS0uNC0uNC0xLjIuMi0yIC41'
    b'em04LjkgNS44LTIuNCAxLjgtMS4yLjZjLS43LjQtLjcuNi0uNi44LjIuMi42LS4zIDEtLjUu'
    b'NS0uMSAxLjgtMSAyLjUtMS42LjctLjYgMS42LTEgMS41LTEuNS0uMi0uNC0uMy0uMS0uOC40'
    b'em0tMTQuOC03NC44IDEuNyAyLjNjMS42IDEuOS43LjEuMy0uNGwtMy40LTQuNWMtLjgtLjkt'
    b'LjktLjUtLjUgMGwxLjkgMi42em0tMy4yIDkuOGMuMi0uMi0uMy0uNC0xLjItMS41bC0yLjYt'
    b'My4zcy0uNS0xLS43LTFjLS4xLjEuNiAxLjggMS4zIDIuNS43LjcgMS43IDIgMi4yIDIuNy41'
    b'LjYuNy45IDEgLjZ6bTQuMiAxOC41YzAtLjUtMS43LS41LTIuNS0uNmwtMi4yLS41cy0xLjYt'
    b'LjMtMS43IDBjMCAuMS4zLjMgMS4yLjVsMy40LjhjMSAuMSAxLjguMyAxLjgtLjJ6bS00LjIt'
    b'MTBjMS4xIDEgMS45IDEuNCAyLjUgMS43LjYuNCAxIC44IDEuNC41LjMtLjQtLjMtLjctMS4z'
    b'LTEuMS0xLS41LTEuNC0uOS0xLjQtLjlsLTEtLjVjLS42LS4zLTEuNC0uNi0uMi4zem05Ljkt'
    b'Ni41LTEuNC0xcy0uOC0uOC0xLS41Yy0uMi4zIDEgMSAxLjUgMS42LjYuNSAxLjYgMS45IDIg'
    b'MS42LjYtLjMtLjQtMS4xLTEuMS0xLjd6bS02LjUgMjUuNy0xLjYuNGMtLjYuMi0uNy40LjUu'
    b'NCAxLjEgMCAxLjUtLjMgMi43LS41IDEtLjIgMS41LS4zIDEuMy0uNy0uMi0uMy0uOC0uMi0x'
    b'LjIgMGwtMS43LjR6bTEuNyA5LjNjMCAuMi44IDAgMS40LS4yLjYtLjIgMS44LS45IDIuNS0x'
    b'IC43LS4zLjctLjQuNy0uOHMtLjggMC0xLjcuMmMtLjkuMy0yIDEuMi0yIDEuMnMtLjguNC0u'
    b'OS42em0xMiA1LjZjLjktLjUgMS0uOC43LTEtLjMtLjMtLjUtLjMtMS4yLjJhNTEgNTEgMCAw'
    b'IDEtMiAxLjVsLTEgLjVjLS42LjItMS4yLjctMSAxIC4xLjEgMS4yIDAgMS43LS42czItMSAy'
    b'LjgtMS42em01LjcgNy41Yy4zLS4zIDEuMy0uNiAxLjgtMSAuNC0uMy43LTEuMy4zLTEuNC0u'
    b'My0uMS0uNS40LTEuMyAxbC0zLjUgMi40LS43LjNjLS44LjItLjQuNS4yLjQuNi0uMSAxLS4x'
    b'IDEuOC0uN2wxLjQtMXptOC4zIDcuMWExMCAxMCAwIDAgMCAyLjMtMS43Yy41LS40IDEuMS0x'
    b'IC43LTEuMy0uMy0uMy0uNy4xLTEuMy42bC0yLjEgMi4ycy0uMyAwLTEgLjdjLTEgLjcgMCAu'
    b'NS4yLjNhMyAzIDAgMCAxIDEuMi0uOHoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJt'
    b'Mjk1LjIgMTQzLjUgMy4yIDEuNCAzLjQtMi40LTQtMXoiLz4KICA8ZWxsaXBzZSBjeD0iMzA5'
    b'LjIiIGN5PSIxNDIuMSIgZmlsbD0iI2I5NmIyOSIgcng9IjMuMiIgcnk9IjMuMSIvPgogIDxj'
    b'aXJjbGUgY3g9IjMwOS4yIiBjeT0iMTQxLjQiIHI9IjEuOSIgZmlsbD0iI2Q0YWYzYSIvPgog'
    b'IDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zMDIuNCAxMzEuNGMuOS4zIDIgLjIgMiAuMnMu'
    b'My0xLjQtLjUtMi4xbC0yLTEuNy0uNS0uNi0uMSAyYzAgLjguMyAxLjkgMS4yIDIuMnoiLz4K'
    b'ICA8Y2lyY2xlIGN4PSIzMDQuMiIgY3k9IjEzMyIgcj0iLjYiIGZpbGw9IiNkNGFmM2EiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJtMjk5LjggMTMyLjQtLjguOXMuNiAwIDEuMi40'
    b'Yy41LjQgMS4yLjcgMS44LjYuNyAwIDEtLjcuOC0xLS4xLS41LS40LTEtMS41LTEuMy0xLS40'
    b'LTEuMyAwLTEuNS40em0yLjIgMy43Yy0yIC4yLTQuNy0yLTQuNy0yLS4yIDEuOC0xLjMgMi43'
    b'LTMgM2wuMS4xczEuNi44IDMuNSAxLjFhNyA3IDAgMCAwIDIuNS0uMmMxLS4yIDIuMy0uNSAz'
    b'LTEgMS4yLS43LjgtMi42LjgtMi42cy0uMiAxLjUtMi4yIDEuNnptLTcuOS0yYy0uOC0uMy0y'
    b'LS45LTIuNi0xLS41IDAtMS4yIDAtMS4xLjkuMSAxIDEuMSAxLjQgMiAxLjQgMSAwIDEuNS0u'
    b'MyAyLjEtLjYuNi0uMy41LS40LS40LS43em0tNi4zLTMuNGMtLjktLjctMS43LS45LTEuNy0u'
    b'OXMtLjYgMS42LS4zIDIuNmMuNCAxIDEgMS4yIDIgMS4yLjggMCAyLS41IDEuNy0xLjJhNSA1'
    b'IDAgMCAwLTEuNy0xLjd6Ii8+CiAgPGVsbGlwc2UgY3g9IjI4OC42IiBjeT0iMTM1LjEiIGZp'
    b'bGw9IiNkNGFmM2EiIHJ4PSIuNyIgcnk9Ii41Ii8+CiAgPHBhdGggZmlsbD0iI2Q0YWYzYSIg'
    b'ZD0iTTI5MC42IDEyNy4zYTExIDExIDAgMCAxIDItOS4zYzIuNS0zLjYgNy01LjEgNy01LjFs'
    b'MS41LTEuOGMxLjQtMS41IDQuMi0zLjQgNC4yLTMuNGwtNS4yIDEuNWEyLjMgMi4zIDAgMCAx'
    b'LTIuMiAyLjRjLS41IDAtMS0uMi0xLjMtLjQtMSAuMS00LjQgMi4yLTUuMyAyLjlsLjMgMS4y'
    b'YTIuMyAyLjMgMCAwIDEtMi4yIDIuM2MtLjQgMC0uNyAwLTEtLjJhOS42IDkuNiAwIDAgMC0u'
    b'My41IDIzLjQgMjMuNCAwIDAgMC0xLjcgMy43Yy42LjQgMSAxLjEgMSAyIDAgMS4zLS45IDIu'
    b'My0yIDIuM2E3LjkgNy45IDAgMCAwIDAgMS41Yy4xLjcuNCAxLjIgMS43IDEuNiAxLjMuMyAz'
    b'LjEgMi42IDMuMSAyLjYuMSAwIDEtMS42LjQtNC4zeiIvPgogIDxwYXRoIGZpbGw9IiNkNGFm'
    b'M2EiIGQ9Ik0yOTguNiAxMTAuM2MuNS0uNC42LTEgLjItMS40LS40LS4zLTEtLjMtMS41LjFz'
    b'LS42IDEtLjIgMS40Yy4zLjMgMSAuMyAxLjUtLjF6bS04LjUgNS43Yy42LS41LjctMS4zLjMt'
    b'MS43LS41LS40LTEuMi0uNC0xLjguMXMtLjYgMS4zLS4yIDEuN2MuNC40IDEuMi40IDEuOC0u'
    b'MXoiLz4KICA8Y2lyY2xlIGN4PSIyODUuMSIgY3k9IjEyMy4yIiByPSIxLjMiIGZpbGw9IiNk'
    b'NGFmM2EiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMzEzLjMgMTA1Yy0uNy4yLTIg'
    b'LjYtMy44IDEuNiAxLjMgMCAyLjMuOCAyLjMgMS45IDAgMS0xLjEgMi4yLTIuNCAyLjJhMi4y'
    b'IDIuMiAwIDAgMS0yLjItMi4ybC4xLS43LTEuNyAxLjJhMTcuNiAxNy42IDAgMCAwLTcuMiA4'
    b'Yy0yIDMuOC0yLjggOC0yIDEwLjQgMSAyLjUgNC4yIDMgNC4zIDMgMCAwLS40LS4zLS41LS44'
    b'bC4zLTEuNnYtMi4xcy44LS4xIDEuMi40bDEuNCAxLjcgMS42IDEuNXMuNi0xIC42LTIuMS0u'
    b'Ny0yLjMtLjktNC4zYy0uMS0yIDEtNS41IDIuOC04IDItMi42IDUuNS01IDYuNi01LjVhMi4x'
    b'IDIuMSAwIDAgMCAxLjMtMS43bC4zLTJjMC0xLjItMS0xLjEtMi0uOXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZDRhZjNhIiBkPSJNMzA5LjIgMTA5LjVjLjcgMCAxLjQtLjcgMS40LTEuMyAwLS42'
    b'LS42LTEtMS4zLTEtLjggMC0xLjQuNC0xLjQgMXMuNiAxLjMgMS4zIDEuM3ptNi4yIDI0LjRj'
    b'MSAuNCAyLjEuMSAyLjYtLjIuNi0uNC43LTEuMy4xLTEuOGEyIDIgMCAwIDAtMi4xLS4ybC0y'
    b'IDEuM3MuNC41IDEuNC45eiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zMTguNiAx'
    b'MzVjLS40LjYtLjcuOS0xLjggMS0xIDAtMi4zIDAtMy0uOGE3LjcgNy43IDAgMCAxLTEuMy0x'
    b'LjdoLTEuMnMtLjQgMS43LTEgMi4xYy0uNS41LTIuNS42LTMuMyAwLS45LS43LTEuNi0xLjQt'
    b'MS44LTEuMy0uMSAwIDAgLjcuOSAxLjRzMS41IDEuMyAyLjkgMS4zaDhzMS42IDAgMi0xYy41'
    b'LS45LjUtMS41LjMtMS43LS4yLS4zLS40LjEtLjcuN3oiLz4KICA8cGF0aCBmaWxsPSIjZDRh'
    b'ZjNhIiBkPSJNMzA2LjQgMTMzLjdjMS4yLjYgMS45LjIgMi4zLS4zbC42LS44LTEuNy0uN2Mt'
    b'LjYtLjQtMS0uNy0xLjUtLjZsLS42LjFzLS4zIDEuNiAxIDIuMnoiLz4KICA8ZWxsaXBzZSBj'
    b'eD0iMzAwLjciIGN5PSIxMjEuOSIgZmlsbD0iI2I5NmIyOSIgcng9IjIuNyIgcnk9IjIuNiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNiOTZiMjkiIGQ9Ik0zMDUuMyAxMTIuN2MtMS0uNy0yLjYtLjQt'
    b'My41LjYtLjkgMS4xLS43IDIuNi40IDMuMyAxIC43IDIuNi40IDMuNS0uNi44LTEuMS43LTIu'
    b'Ni0uNC0zLjN6Ii8+CiAgPGVsbGlwc2UgY3g9IjMwMC42IiBjeT0iMTIxLjUiIGZpbGw9IiNk'
    b'NGFmM2EiIHJ4PSIxLjYiIHJ5PSIxLjUiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJN'
    b'MzA0LjIgMTEzYTEuOCAxLjggMCAwIDAtMiAuOGMtLjMuNi4xIDEuMiAxIDEuNCAxLjcuMyAy'
    b'LjUtMS44IDEtMi4yem0tNDAuNyAyMDZzLTQuMSAyLTUuNCAyLjNsLTEuNi40cy0yLjggMi41'
    b'LTQuOSAzLjhhMTguMyAxOC4zIDAgMCAxLTcuMSAyLjRjLTMuMi40LTEyIC4zLTE2IC4xLTQt'
    b'LjEtNi40LjgtOC4xIDIuNy0xLjcgMi0yLjEgNC43IDAgNi44IDIuMiAyLjEgNC42IDEgNS40'
    b'LS4yLjgtMS4zLjQtMyAwLTMuNy0uMy0uOC43LTEgMS44LTEuMWEyNC4zIDI0LjMgMCAwIDEg'
    b'MTAuNyAyLjNjMS4zLjcuNi44LS4zLjctMS0uMi0yLS41LTMuNS0xLjEtMS42LS42LTMtMS00'
    b'LTFzLS43LjUtLjUuOWwxIDEuNmMuMS40LS4zIDEuOS0uMyAxLjlsLjUgMSAuOC0xLjVjLjIt'
    b'LjUtLjEtMS41LjEtMiAuMi0uNCAxLS40IDEuNy40YTYuNyA2LjcgMCAwIDEgMS44IDMuNWMu'
    b'MyAyLS4zIDMuMy0uMyAzLjNzLjguNyAxIDEuMWwtLjMgMi4zcy42LjMgMS0uN2MuNi0xIDEu'
    b'Mi0zIDEuMy0zLjYuMi0uNy42LTEuOSAxLjQtMSAuOCAxIDEuNCAyIDEuNSAyLjZsLjIgMXMx'
    b'LjgtMS43IDIuNC0yLjhhMTcgMTcgMCAwIDEgMy42LTMuOWMxLjctMS40IDQuNi00LjIgNi01'
    b'LjIgMS41LTEgNS4yLTMgNi40LTMuNiAxLjEtLjcgMS4zLS44IDEuNS0yLjcuMi0yIDEuMi0z'
    b'LjggMS42LTUuMWwuNi0xLjl6bS02NS44LTczLjdjMC0uNC0uNy0xLjUtLjgtMi4xLS4yLS42'
    b'LS44LS4zLS44LS4zcy0xLjMuOC0yLjMgMWMtMSAuMy0xIDAtMS4yLS42bC0uNS0zLjJjLS4y'
    b'LTEtLjQtMS0uOC0uOGwtMi40IDFjLS45LjMtLjYuNy0uMyAxLjJsMS42IDMuMWMuNS43IDAg'
    b'MS0uNCAxLjNsLTIuMy42Yy0xIC40LTEgLjYtLjggMSAwIC4zLjggMS43IDEuMSAyLjMuNC42'
    b'LjcuMi43LjJzMS4xLTEgMi0xLjRjLjktLjQgMS0uMyAxLjIuNGwxLjUgNC44Yy4yLjcuNS42'
    b'IDEgLjRsMS42LS40Yy41LS4yLjctMS4zLjctMS4zbC0yLjUtNC40Yy0uNS0xIDAtMS4xLjQt'
    b'MS4yLjQgMCAxLjYtLjIgMi42LS41IDEtLjIuNy0uOC43LTEuMnptMjIuMyA5Ni41Yy0uMS0u'
    b'OCAwLTEuNy0uNi0yLjNhOC4xIDguMSAwIDAgMS0xLjgtM2MtLjMtMSAuMy0xLjYuMi0yLjIt'
    b'LjEtLjYtMS0uNi0xLjcgMC0uOC43LTEuOSAxLjMtMS45IDMuMiAwIDIgLjcgNC4yIDMuNCA1'
    b'IDIuNi44IDIuNi4yIDIuNC0uNnptMi43LS45cy0uNS0uMy0uOC4yYy0uMi41LS4yLjcuNSAx'
    b'LjkuNyAxIDEuMiAxLjMgMiAxLjhzLjItLjUuMS0uOGMwLS4zIDAtLjctLjItMXMtLjMtLjUt'
    b'LjMtMS4zLTEuMy0uOC0xLjMtLjh6Ii8+CiAgPHBhdGggZmlsbD0iI2Q0YWYzYSIgZD0iTTIy'
    b'NiAzNTBjLjUtLjggMS0xIDIuMS0xLjVhMTUuMyAxNS4zIDAgMCAxIDQuMi0xYy43IDAgMi41'
    b'LTEuNCAyLjItMy0uMy0xLjQtMS40LTItMi4zLTIuMi0xLS4zLTEuOC0uMy0yLjEuMi0uMy41'
    b'LS45IDEtMiAxLjRzLTEuMS43LTEuOCAxYy0uNi4xLS4xLjUtLjcgMS0uNS40LTEuMyAwLTIu'
    b'MS0uMy0uOS0uMi0xLS40LTEuOS0uNGwtMy40LS4yaC0uN2MtLjYgMC0uNiAwLS45LjZzLjEg'
    b'Mi4xLjcgMi45Yy42LjcgMi42IDEgMy45IDEuNWwzIC44YzEuMi4xIDEuMyAwIDEuOC0uOHpt'
    b'MTIuMiAxLjJjMS0uNy40LTIgLjItMi43LS4zLS43LTEuNy0uOS0yLjUtLjktLjcgMC0xLjEg'
    b'MC0xLjUuNC0uNC4zLTEgLjgtMiAxLjItMS4yLjMtMiAuNy0zLjYgMS4zLTEuNS42LTIgMS42'
    b'LTIuNiAyLS42LjQtMS45IDAtMS45IDBzLS45LS4yLTEuMiAwYy0uMy4zIDAgLjguNiAxLjUu'
    b'Ni42IDEuOC42IDMgMSAxLjQuNCAxLjYgMCAyLjEtLjNzMS0xIDEuOC0xLjZjMS0uNiAzLS43'
    b'IDMuOS0uOCAxLS4xIDIuNi0uNCAzLjctMS4xem0wLTQuNmMuNC40IDEgMSAxLjMuMy40LS42'
    b'IDEtMiAuNi0yLjgtLjQtLjgtMS0xLjUtMS0xLjVsLTEgM2MtLjQuNS0uNC42IDAgMXptLTQt'
    b'N2MwLTEuMi0xLTIuOC0xLTIuOHMtLjMgMS4yLS45IDIuMmMtLjUgMS0xIDEuNi0xIDEuNmwx'
    b'LjcuNGMuNSAwIDEuMSAwIDEuMS0xLjN6bS03LjYgMi44YzEuNC0uMiAyLjEtLjggMi43LTEu'
    b'My42LS41IDEtMS45LjYtMi42LS40LS43LTEuNC0xLjQtMS44LTEuNGgtLjhzLS40IDEuMy0x'
    b'IDJjLS41LjYtMS4xIDEtMSAxLjkgMCAuOC0uMSAxLjcgMS4zIDEuNHptMi44LTYuM2EyLjQg'
    b'Mi40IDAgMCAwLS42LTEuOWwtLjgtLjctLjIgMS42LS4xLjYuNy42Yy40LjEgMSAuNCAxLS4y'
    b'em0tMTcuMy0zNS43IDEtNmEzOSAzOSAwIDAgMC02LjMtMTUuNGMtMi40LTMuOC01LTEwLTYt'
    b'MTMuMmEzNy40IDM3LjQgMCAwIDEtMi0xMGMwLTIuMyAxLTMuNSAxLTMuNXMuNS0uNi4xLTEt'
    b'MSAwLTEuNy42YTcuNSA3LjUgMCAwIDAtMS41IDIuNmwtLjMgMS4xcy0xLjItLjMtMy4zLS4x'
    b'Yy0yIC4yLTMgLjMtMyAuOCAwIC40LjMuNyAxLjcgMS40IDEuNS42IDIuNC45IDMuMSAxLjcu'
    b'OC45IDIuNiA1LjIgMy4yIDcuMy42IDIuMSAxLjggNy44IDIuMyAxMi4yYTQ5IDQ5IDAgMCAw'
    b'IDQgMTQuNGMuOCAxLjUgNC41IDguNSA3LjcgN3ptMy43IDEwLjRjLTEuNC44LTEuMyA2LjQt'
    b'LjcgOS4zLjYgMi45IDMuNCA2LjUgNC4zIDcuNS45IDEgMSAxIDEuNS43bC43LS4yczEuMi0u'
    b'NSAyLjEtMS4yYzEtLjcuNi0yLjUuNC00LS4xLTEuNi0xLjQtNC44LTMuNi04LjUtMi4yLTMu'
    b'Ni0zLjMtNC40LTQuNy0zLjZ6bTEuNS00LjVjMC0xLjktMS42LTMuMi0zLjQtMy4yLS45IDAt'
    b'MS42LjItMi4xLjYtMS45IDEuNy0uNyA1LjggMiA1LjguOSAwIDItLjEgMi43LS44LjctLjYu'
    b'OC0xLjYuOC0yLjR6bTI2LjUgNTIuN2E3IDcgMCAwIDEtMi4yLTEuMiAxMCAxMCAwIDAgMS0z'
    b'LjEtM2MtLjMtLjctLjMtLjctMS40LS40LTEgLjQtMi41LjMtMy42LjQtMSAwIC4yIDEuMyAx'
    b'IDIuNC43IDEuMi40IDUuMS40IDUuMWwtLjEuOWMtLjIuNiAwIDEgLjIgMSAuMy4yLjUgMCAx'
    b'LjMtMSAuOC0uOSAyLjItMy4yIDIuMi0zLjJsMS40LjNjMS4yLjMgMy4xLjEgNC4xLS4yIDEt'
    b'LjMuNi0xLS4yLTEuMXoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMjM5LjIgMzYy'
    b'Yy0uNSAwLS43LS4xLTEgLjJsLS42IDEuNGMtLjEuMyAwIC42LjIuOWwuOC41cy40LjUuOC43'
    b'Yy41LjIuNS0uNC41LS45bC4zLTEuOWMwLS42LS40LS44LTEtLjl6Ii8+CiAgPHBhdGggZmls'
    b'bD0iIzFkNWU5MSIgZD0iTTQzNSAzMjQuMmMtMS4zLS4zLTEuOS0uOC0xLjktLjhzLS41IDAt'
    b'MSAuN2MtLjMuOC0yIDEuOC0yIDEuOHMtMi4yLjYtMi41IDIuMmMtLjMgMS41LjggMiAxLjgg'
    b'MS45IDEuMS0uMiAzLjctLjcgNC45LTIuMSAxLjEtMS40IDEuMy0yLjIgMS41LTIuNy4yLS41'
    b'LjQtLjctLjktMXptMy41LTEyLjRhMTUgMTUgMCAwIDAtNy40LTkuOWwtMi4xIDcuNWMtLjUg'
    b'MS44LS41IDEuNy45IDJsNi43IDEuNmMuOS4zIDIuNCAxIDEuOS0xLjJ6bS0yMC42LTMuMmMx'
    b'IC4xIDEtLjMgMS4zLTEuN2wyLjEtOC4ycy00LjUtLjEtOC41IDEuOGMtMy45IDEuOS01LjYg'
    b'NS40LTUuNiA1LjRzMSAuNCAzLjcgMSA2IDEuNSA3IDEuNnptLTEwLjUgOS4zLTIuMi0uNHMx'
    b'IDMuOCAyLjcgNmMxLjcgMi4yIDMuNSAzLjIgNyAzLjMgMy41IDAgNi0xLjkgNi41LTMuNC40'
    b'LTEuNSAxLjEtMi42IDEuMS0yLjZzLTYuMi0uOC04LjgtMS40bC02LjMtMS41eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNkNGFmM2EiIGQ9Im00MDYuMyAzMTUuNSAxNS41IDNjMSAuMyAyIC41IDIu'
    b'Mi4yLjMtLjMuNS0uNSAxLjYtLjkgMS4yLS40IDEuMS0xLjUgMS4xLTEuNWwuNC0yLjJjLjIt'
    b'MSAuOC0xLjQgMi0uMSAxLjMgMS4zIDEuNSAzLjIgMS43IDUgLjMgMiAzLjIgMi40IDQuNCAy'
    b'LjYgMS4xLjIgMS42LS4yIDIuMy0xLjMuNy0xIDEtMy4yIDEuMi00LjYuMi0xLjQgMC0xLjIt'
    b'MS40LTEuNmwtOS4zLTIuMmMtMS4yLS4yLTEtMS0uNy0xLjkuMS0uOCAyLjgtOS4yIDIuOC05'
    b'LjJhMTguOSAxOC45IDAgMCAwLTcuNy0yLjNsLTIuMyAxMGMtLjMgMS4zLTEuMiAxLjMtMi41'
    b'IDEtMS40LS4yLTExLjMtMi41LTExLjMtMi41bC0uOCAxLjhhMTUuNSAxNS41IDAgMCAwLTEu'
    b'MSA1LjJjMCAxLjIuNCAxLjIgMS45IDEuNXoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBk'
    b'PSJNNDQwLjMgMzIzLjNjLTEuMy0uOS0yLjMtMS4xLTMgLjUtLjcgMS42LS43IDQtMi40IDUu'
    b'Ni0xLjggMS43LTQuMiAzLjQtNi42IDMuMi0yLjQtLjItMy43LS43LTMuMi0zLjUuNi0yLjcg'
    b'NC4zLTMuNiA1LjEtNSAuOS0xLjUuNy0zLjEtLjYtNC4yLTEuMy0xLjEtMy4xLTEuMy0zLjYt'
    b'MWE4IDggMCAwIDAtMi44IDMuN2MtLjcgMi0xLjIgMy43LTIuOCA1YTEyLjIgMTIuMiAwIDAg'
    b'MS05IDJjLTMuMS0uOC00LjMtMS44LTUuNS01LTEuMi0zLjEtMi42LTguMy0zLjItOS0uNy0u'
    b'NS0xLjUtMS0yLjggMC0xLjQgMS0xLjUgMi40LTEuNyAzLjYtLjIgMS4xIDAgMi41IDEuNCA0'
    b'LjEgMS40IDEuNyAyLjggMy4zIDMuMyA1IC41IDEuOCAyIDQuNC0uMSA0LjUtMi4yLjItMy4y'
    b'LjItNC44LTEuNC0xLjctMS42LTguMi02LTEwLTcuNGEyOSAyOSAwIDAgMC0yLjUtMmMtMyAw'
    b'LTYtMS4yLTktMy4zIDAgMCAxLjggNC40IDIuMSA2LjEuNCAxLjcuMyAyLjYuMyAyLjZsOS4x'
    b'IDQuNmExNjggMTY4IDAgMCAxIDEwLjMgNS44YzIuNSAxLjUgNC43IDQgOS4xIDMgNC41LS45'
    b'IDEzLjUtMy42IDE2LjUtNC41IDIuOS0uOSAxMS0yLjkgMTQtNSAzLTIgMy4yLTEuOSAzLjct'
    b'NCAuNS0yIDAtMy4xLTEuMy00em0tMTcuMi0zMSAyLjItLjNjMS41LS4xIDEgMS4zLjcgMS45'
    b'bC0xLjQgMi43Yy0uNiAxIC4yIDEuMi42IDEuNGwyLjMuNmMxLjMuMyAxLS42IDEtMWwuMy0z'
    b'LjhjLjEtLjkgMS0uNiAxLjItLjVsMS43IDFjLjYuMyAxIDAgMS0uNGwuOC0yYy4yLTEtLjQt'
    b'LjgtMS0uOGgtMi40Yy0xIDAtLjQtMS0uNC0xbDEuMy0yLjFjLjYtLjkuNC0xLS4yLTEuMmwt'
    b'Mi44LS43Yy0uNS0uMS0uNyAwLS43LjNsLS4xIDIuN2MwIC43IDAgMS0xIDEtLjguMS0xLjMt'
    b'LjQtMi0xLjEtLjctLjgtMS0uNS0xLS4ybC0uOCAzYy0uMi43LjEuNi42LjZ6bTQuOCAyMS44'
    b'cy0uMSAxLjctLjMgMi4zYy0uMi43LS42IDEuNi4xIDEuOC44LjIgMS40LjUgMS44LjQuNS0u'
    b'MS4zLTEgMC0xLjdhNi40IDYuNCAwIDAgMC0xLjEtMi4ybC0uNS0uNnptMTAuNSA3Yy4yLjUu'
    b'Ny42IDEgLjcuNC4xIDEgLjEgMS0uNXMwLTEuNS0uNS0yLjJjLS41LS44LS44LTEuMy0xLjEt'
    b'LjItLjQgMS0uNiAxLjYtLjQgMi4yem0tMzYuNy03IDEuNC40czAtMS43LjMtMi44Yy4yLTEu'
    b'Mi43LTIgLjMtMi0uNCAwLS43LjQtMSAuOS0uMy41LTEuMS42LTEuNCAyLS4zIDEuMy4xIDEu'
    b'NC40IDEuNHoiLz4KICA8Y2lyY2xlIGN4PSI0MDguOSIgY3k9IjMxMS4yIiByPSIyLjMiIGZp'
    b'bGw9IiNiOTZiMjkiLz4KICA8Y2lyY2xlIGN4PSI0MTUuNSIgY3k9IjMxMi44IiByPSIyLjQi'
    b'IGZpbGw9IiNiOTZiMjkiLz4KICA8Y2lyY2xlIGN4PSI0MzQuNiIgY3k9IjMxNi45IiByPSIy'
    b'LjQiIGZpbGw9IiNiOTZiMjkiLz4KICA8Y2lyY2xlIGN4PSI0MjIuMSIgY3k9IjMxNC40IiBy'
    b'PSIyLjQiIGZpbGw9IiNiOTZiMjkiLz4KICA8Y2lyY2xlIGN4PSI0MjMuOCIgY3k9IjMwOC42'
    b'IiByPSIyLjQiIGZpbGw9IiNiOTZiMjkiLz4KICA8Y2lyY2xlIGN4PSI0MjUuNSIgY3k9IjMw'
    b'Mi45IiByPSIyLjQiIGZpbGw9IiNiOTZiMjkiLz4KICA8Y2lyY2xlIGN4PSI0MDkuMSIgY3k9'
    b'IjMxMC45IiByPSIxLjIiIGZpbGw9IiNkNGFmM2EiLz4KICA8Y2lyY2xlIGN4PSI0MTUuNiIg'
    b'Y3k9IjMxMi42IiByPSIxLjIiIGZpbGw9IiNkNGFmM2EiLz4KICA8Y2lyY2xlIGN4PSI0MzQu'
    b'OCIgY3k9IjMxNi42IiByPSIxLjIiIGZpbGw9IiNkNGFmM2EiLz4KICA8Y2lyY2xlIGN4PSI0'
    b'MjIuMiIgY3k9IjMxNC4xIiByPSIxLjIiIGZpbGw9IiNkNGFmM2EiLz4KICA8Y2lyY2xlIGN4'
    b'PSI0MjQiIGN5PSIzMDguNCIgcj0iMS4yIiBmaWxsPSIjZDRhZjNhIi8+CiAgPGNpcmNsZSBj'
    b'eD0iNDI1LjciIGN5PSIzMDIuNiIgcj0iMS4yIiBmaWxsPSIjZDRhZjNhIi8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2Q0YWYzYSIgZD0ibTM0OS41IDM1OS4xLTUuMi0zLjZhMTEuOCAxMS44IDAgMCAx'
    b'LTMuOS00aDFjLjYgMCAxLS43IDEtMS41LjEtLjggMC0yLjMtLjItNC4xLS4yLTEuOC4zLTMu'
    b'My4zLTMuM3MxLjMgMS4xIDMuMSAyYzEuOSAxIDIuNi42IDIuNi42bC41LTEuOSAyIDMuN2Mx'
    b'IDIgNC4xIDQuMiA2LjMgNS44IDIuMiAxLjcgNC42IDMuNCA2LjQgNCAxLjguNy44IDEuNS44'
    b'IDEuNXMtMS44IDEuOC02LjUgMi43Yy00LjcuOC03LTEtOC4yLTEuOXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZDRhZjNhIiBkPSJNMzMzLjIgMzU3LjNjMS43LS4yIDIuNy0uOCAzLTIuNi4yLTEu'
    b'Mi0uMS01LjctLjEtNS43bDEuMiAxLjJjLjYuOCAyIDEgMiAxcy4yLjYuOSAxLjZhOS4zIDku'
    b'MyAwIDAgMCAzIDMuMmMxLjYgMSAzLjUgMi4yIDQuNyAzLjJhMjguMSAyOC4xIDAgMCAwIDQu'
    b'MiAzLjEgNyA3IDAgMCAxIDMuNiA0LjdjLjYgMi40LjEgMy4xLTEuNyAzLTEuOS0uMS0yIDAt'
    b'NS0uNy0zLS44LTcuMy00LjEtMTAuNC02LTMuMS0yLTUuNC02LTUuNC02eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNkNGFmM2EiIGQ9Ik0zMjUgMzYwczEuMi0xLjYgMS42LTMuNGwxLjQtNS40IDEu'
    b'NCAzLjNhNC45IDQuOSAwIDAgMCAyLjggMi43czAgLjkgMS41IDIuN2EyMSAyMSAwIDAgMCA1'
    b'LjYgNC44YzIuMiAxLjIgNSAzIDYuNSA1LjEgMS41IDIuMiAxLjYgNC40IDEgNS40LS44IDEt'
    b'MS44LS4xLTMuMi0uOS0xLjUtLjctNS42LTEuMy0xMS4yLTQuNC01LjYtMy03LjUtOS45LTcu'
    b'NS05Ljl6Ii8+CiAgPHBhdGggZmlsbD0iI2Q0YWYzYSIgZD0iTTMyMi41IDM3Mi43Yy0xLjYt'
    b'Mi40LTEuOC04LTEuOC04bDEuMy0xYy43LS43IDIuMi0yLjkgMi4yLTIuOWwyIDMuOGMxIDEu'
    b'OCAxLjQgMi40IDMuNiA0LjMgMiAyIDUgMy45IDYuMSA2IDEuMyAyIC42IDYuMS0uMiA3LjUt'
    b'LjggMS41LTIgMS0zLjEtLjFMMzI5IDM3OWMtMi4xLTEuNy01LTQtNi41LTYuM3oiLz4KICA8'
    b'cGF0aCBmaWxsPSIjYjk2YjI5IiBkPSJNMzQxIDMyNS4zYy0uOC0xLjctMS44LTMuNy0yLjUt'
    b'NC44YTE1IDE1IDAgMCAxLTEuMy0yLjJzMiAxLjggMi44IDMuMWMuOCAxLjQgMS4zIDIuNiAx'
    b'LjYgNCAuNCAxLjQuMiAxLjYtLjYgMHptLTggMS41LS41LTEuOXMtLjMtMS0uMi0xLjFjLjIt'
    b'LjEgMSAuNiAxLjYgMi41LjYgMS44IDEuNSA0LjUgMS4zIDQuNi0uMiAwLTEuOS0zLTIuMi00'
    b'LjF6bS02LjMgNS0uNC0uOHMtLjYtMi0uNi0yLjVjMC0uNC4yLTEgLjcuMXMuNiAyLjIuNyAy'
    b'LjZjLjEuNS43IDIuMS41IDIuMy0uMS4xLS41LS45LTEtMS43em0xOS41IDE5LjIuOS0uNSAx'
    b'LjIgMS41Yy43LjcgMS41IDEgMiAxLjdhOCA4IDAgMCAwIDIuOCAyLjNjMS4zLjcgMS44IDEg'
    b'MS41IDEuMS0uMi4yLTEuMS0uMy0xLjEtLjNzLS40IDAtMi0xYy0xLjUtLjktMS45LTEuNC0y'
    b'LjktMi4zbC0yLjQtMi41em0tNi44IDguMWMtLjYtLjYtMS4yLTEtLjktMS40LjQtLjMuOC0u'
    b'MyAxLjMuMmwyLjkgMi42IDIgMS41Yy43LjYgMi4zIDEuNCAzIDEuOC44LjUgMCAuNSAwIC41'
    b'bC0xLjItLjUtMi40LTEtMS43LTFjLTEtLjctMi40LTItMy0yLjd6bS03LjggNS41Yy0uNS0x'
    b'IDAtLjguOC0uNC45LjMgMi44IDIuNCAzLjkgMy4xIDEgLjggMiAxLjEgMyAxLjYuOC40Ljgu'
    b'Ny44LjkgMCAuMi0uNC4yLS44IDBsLTEuNy0uOS0xLS4yYy0uNSAwLTEuMy0uNi0yLjQtMS42'
    b'LTEuMS0xLTIuMS0xLjUtMi42LTIuNXptLTMuNyA3LjJjMS40LjggMy44IDIuNyA0LjQgNCAu'
    b'NiAxLjIgMSAyLjEuOSAyLjMtLjMuMi0xLS4yLTEuMi0uN2wtMS0xLjJzLTIuNC0yLjQtMy4y'
    b'LTNhOC4zIDguMyAwIDAgMS0yLjctM2MtLjMtMSAwLTEuNCAwLTEuNHMxLjQgMi4xIDIuOCAz'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNjNTIxMjYiIGQ9Ik0zNjUgMTcwYTIyLjMgMjIuMyAwIDAg'
    b'MSA4LjMtMi42YzMuNi0uMyA2LjQuMiA5LjUgMSAyLjEuNiAzLjkuNyA1LjYuMyAyLjYtLjcg'
    b'NC42LTMgNS4zLTYgMCAwIDIuNCAzLjEgMCA2LjVhNy4yIDcuMiAwIDAgMS00LjMgMi45Yy01'
    b'LjEgMS0xMC4xLTItMTQuMy0yLjQtNC4xLS4yLTcuMyAyLjQtNy4zIDIuNHMtMSAuOC0yLjQg'
    b'MGMtMS4zLS44LTEuNy0xLjQtLjQtMi4yeiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9'
    b'Im0zNzkuNiAzMTcuNSAxLjItLjJjLjcgMCAyLjItLjYgMi43LS44LjUtLjIgMS4yLS4yIDEu'
    b'Ni4zLjUuNSA0LjEgMi43IDQuMSAyLjdoLTZjLTIuMSAwLTMuNS0yLTMuNS0yeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zNjIuNiAzMTYuNHYtLjVsLjgtMS44czEgLjYgMS44'
    b'IDEuNWMxLjIgMS4zIDIuNSAzIDMgMy43IDEgMS4zIDIuNSAyLjUgMS4zLjVzLTEuNi0zLTIu'
    b'Ni00LjRsLTEuNi0yIDMuNC0uNWMyLjUtLjMgNC4yLTEuMyA1LjMtMmwzLjMtMS45czQuMyAx'
    b'LjkgNiAyLjNjMS42LjQgMi41LjYgMSAxLjQtMS42LjgtMyAxLTMuNyAxLjVhMTIgMTIgMCAw'
    b'IDEtNC42IDEuMmMtMS41IDAtNCAwLTMgMWEyMiAyMiAwIDAgMSA0LjIgMTNsLS4xIDIuNXMt'
    b'MS44LTItNi42LTVhNzEgNzEgMCAwIDAtNy40LTQuNGMtLjktLjQtMS4zLS40LTEuMi0xLjVs'
    b'LjctNC42eiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zNDQuNCAzMDJhNjguNSA2'
    b'OC41IDAgMCAwIC44LS40aC4zYy41LjMgMy40IDIuMyA0LjYgNC4yIDEuMiAxLjkgMi40IDIg'
    b'MSAwYTE3LjkgMTcuOSAwIDAgMC0zLjItNC4yIDIzLjQgMjMuNCAwIDAgMC0xLS44IDUzLjMg'
    b'NTMuMyAwIDAgMCA3LjMtNC4yYy40LjYgMSAxLjcgMS43IDIuNSAxIDEgMy4yIDIgMy4yIDJz'
    b'LTEuOC0yLTIuNC0zLjNsLS44LTIuNWEzMS43IDMxLjcgMCAwIDAgNC44LTQuNmMuMyAxLjMg'
    b'MS4zIDQuMiA0LjIgNy40IDMuNyA0LjIgMTEuMiA2LjMgMTEuMiA2LjNzMi42LjMuNS45Yy0y'
    b'LjEuNS0zLjYgMS41LTcuOC44bC01LTEuMWMtLjUtLjItMiAwIDAgLjcgMi4xLjggNyAxLjUg'
    b'OC44IDEuNCAxLjgtLjIgNC40LS42IDEuNy44LTIuNiAxLjQtMy43IDItNS4zIDJzLTIuMy41'
    b'LTQgLjVjLTEuNSAwLTItLjMtMy0uNS0xLjItLjMtMS45LjEtMS45LjYgMCAuNCAxLjUgMS43'
    b'IDEuNSA0LjcgMCAzLjEtLjMgNS4xLS42IDYtLjMgMS0xIDIuNC0xLjQgMy4yLS40LjgtLjYg'
    b'MS43LTEtLjEtLjUtMS44LTEuNS00LjQtMS45LTYuMWwtLjgtMi43Yy0uMS0uOS0xLjEtMS42'
    b'LS42IDBhMTMzLjQgMTMzLjQgMCAwIDEgMS4yIDUuMmMuNCAxLjUgMS4xIDQuMi0uMiAyLTEu'
    b'My0yLTYuNC03LjctNy4yLTguOGwtMi4xLTIuOGMtLjctLjgtMi40LTEuOS0zLjItMy4xYTI4'
    b'LjUgMjguNSAwIDAgMC00LTRsNC41LTJ6bTY5LjUtMTI5LjJjLS4xIDMuMS0zLjUgOS01LjUg'
    b'MTIuMi0yIDMuMS0yLjUgNC40LTIuMSA0LjYuMy4yIDEuMS0xLjQgMi4yLTIuOGw0LjktNy4y'
    b'YzEuNy0yLjUgNC4yLTguNCA0LjYtOC45LjMtLjUuNC0uOSAxLjMtLjJzMi42IDcuMi41IDEx'
    b'LjZjLTIgNC40LTUgNy42LTYuMiA5LjItMS4zIDEuNS0zIDQtMi43IDQuMS4zLjIuNy0uNCAy'
    b'LjMtMmE0Ny4zIDQ3LjMgMCAwIDAgOS42LTEyLjVjLjItLjQuNS0uMy44IDAgLjUuNSAxLjQg'
    b'MS44IDEgNS4zYTE3IDE3IDAgMCAxLTUuMyAxMC4yYy0yLjMgMi40LTQuNiA0LjUtNC4zIDQu'
    b'OS40LjMgMi43LTEuOCA0LjMtMy4zIDEuNi0xLjYgNS42LTUuNCA2LjQtNi41IDEtMSAyLjIt'
    b'LjUgMi4xIDMuNyAwIDQuMy00LjcgOC41LTYuNyAxMC45LTIgMi4zLTQuMyAzLjctNC4xIDQu'
    b'Mi4yLjUgMi4xLS43IDMuNC0xLjZsNy00LjZjLjktLjcgMS4zLjYuMSA0LjYtMS4yIDQtNC42'
    b'IDcuMi02LjcgOC43LTIgMS41LTUuNCAzLjMtNS4yIDMuOC4yLjQgMS42LS4yIDMuNS0xLjEg'
    b'Mi0xIDQuMy0xLjggNi0yLjMgMS42LS41IDEuNi43IDEuNi43cy40IDMuNS0yLjEgNi4yYTEz'
    b'LjMgMTMuMyAwIDAgMS04IDQuM2MtMi42LjUtMyAuNi0zIDFzLjQuNSAxIC41bDUuMy4yYzIu'
    b'MyAwIDMuNS42IDMuNSAxLjZzMCAyLjMtMy4zIDQuNmMtMy41IDIuMy03LjMgMi42LTguOSAz'
    b'LTEuNi4zLTEuNi40LTEuMy45LjMuNSAxIC40IDMuNi43IDIuNS4yIDQgMS4yIDQuNCAyIC4z'
    b'LjYtLjIgMi42LTIuMyA0LTIgMS40LTQuNyAxLjktOC43IDEuNi00LS4zLTUtLjMtNS4yLjMt'
    b'LjEuNyAxLjIgMSAzLjIgMS4yIDIgLjQgMy42LjQgNC43IDEuMyAxLjIgMSAuMyAyLjktMS43'
    b'IDQuMy0xLjkgMS40LTYuNyAxLjQtOC43IDEuMy0yLS4yLTUuMS0uOS01LjMtLjQtLjIuNiAx'
    b'LjUgMS40IDMuNSAyLjEgMi4xLjggMi43IDEuMiAzLjEgMi4xLjQuOSAwIDEuNy0yLjQgMi42'
    b'YTEyIDEyIDAgMCAxLTggMGMtMS44LS44LTIuOC0xLjEtMy4yLS44LS4zLjMgMCAuNy40IDEu'
    b'MS40LjUgMiAxLjggNC4xIDIuMyAyIC42IDIuMy42IDMgMi4yLjggMS43LTEuMSAzLTQuOSAz'
    b'LjItMy43LjEtOC43LTEuNC0xMC4zLTIuMy0xLjYtMS0yLjItMS4xLTIuNS0uOC0uMy4zLS4y'
    b'LjUuNiAxLjEuOC42IDMuMyAyLjUgNC42IDIuOCAxLjMuMyAxLjQgMS4zIDEuNCAyLjEgMCAx'
    b'IC40IDIuNi0zIDMuNS0zLjMuOC03LjMuMi0xMC45LTIuNGE4LjMgOC4zIDAgMCAxLTIuMi0y'
    b'IDI4IDI4IDAgMCAwLS4zLThjLjcgMCAyLS4zIDMuNC0uOSAyLS44IDIuOC0yLjYgMy4zLTMu'
    b'NnMxLjItMSAyLS44Yy44LjMgMS42LjYgMi43LjZhNy45IDcuOSAwIDAgMCA1LjMtMi44YzEu'
    b'Ny0yIDEuNC00IDEuNS01IDAtMSAxLjYtLjMgMi40LS4zLjggMCAzLjItLjQgNS4zLTEuOSAy'
    b'LjItMS40IDIuMi0zLjQgMi40LTQuMy4yLS44IDEtMS4zIDEuNy0xLjYuNy0uMiAxLjctLjUg'
    b'My4yLTEuNyAxLjUtMS4yIDItMy41IDItNC40LjItLjggMS0uOCA0LTIuNCAzLTEuNSAyLjgt'
    b'NC43IDIuNi02IDAtMS4zLTEuNS0yLjMtMS41LTIuOHMxLS42IDItMS4yIDMuNi0xLjYgMy42'
    b'LTUuNGMwLTMuNy0yLjQtNC4xLTIuNC00LjFsMS41LS44YzEtLjYgMy43LTIuNSAzLjctNC43'
    b'cy0xLTMuMi0xLjctMy44Yy0uNy0uNS0yLjctMS0yLjctMXMxLjItLjkgMS44LTIuNmMuNS0x'
    b'LjcuNy0zLjktLjYtNS40LTEuMi0xLjYtMy40LTEuNi00LjUtMS42LTEuMiAwLTIuMi42LTIu'
    b'Ni4zLS40LS4zLS40LS42IDAtMS41LjQtLjguNC0zIC4xLTMuNy0uMy0uOC0uNC0yLjItMy4z'
    b'LTMuMi0yLjktLjktNS45IDEtNi44IDEuNi0xIC41LS41LS44LS41LTEuNyAwLTEgMS45LTMu'
    b'MyA0LjEtNi42IDIuMi0zLjQgMy4yLTUuMSA1LjctMTAuMkE2NS43IDY1LjcgMCAwIDAgNDA5'
    b'IDE1OWMuNC0xLjYgMS0uOCAxLS44cy43LjIgMi4yIDQuMWEyNSAyNSAwIDAgMSAxLjcgMTAu'
    b'NXoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJNMzYzLjQgMjQxLjRjMS43LS4xIDQt'
    b'MSA1LjctMy42IDEuNy0yLjUgNC4zLTMgOC44LTMgNC41LjEgNi42LTIgNy43LTUuMiAxLTMt'
    b'LjItNi42LTQuOC04LjktNC41LTIuMi02LjYtNC43LTYuOC04LjYtLjEtMy45IDQuNi04Ljcg'
    b'OS4zLTE0LjEgNC44LTUuNSA4LjUtMTMuMiA4LjUtMTMuMnMxLjQgMS44IDEuNCAzLjdjMCAx'
    b'LjgtLjcgMy43IDAgNC4ycy45LS44IDMuNy0yYzIuNy0xLjIgNS0xLjQgNi43LjYgMS43IDIg'
    b'MCA1LjQtMS42IDctMS41IDEuNy0yLjggMy0yLjQgMy41LjQuNiAyLjgtLjkgMy41LTEuNC44'
    b'LS41IDIuNi0yLjUgNS4zLTIuMyAyLjcuMyAzLjYgMSAzLjkgMy4zLjIgMi4zLTIuNCA0LjIt'
    b'NC4yIDUuMS0xLjcuOS0yLjQgMS42LTIgMiAuNS4zIDEgMCAxLjctLjNhOCA4IDAgMCAxIDQu'
    b'MyAwYzEuNC42IDMuNiAyLjUgMS42IDQuOC0yLjEgMi4zLTYuNCAzLjItNy4zIDMuMy0uOC4y'
    b'LTEuMyAwLTEuNC42IDAgLjcgMS44LjcgNC4yLjggMi4zLjEgMyAyLjQgMi43IDQtLjQgMS44'
    b'LTQuMyAzLjctNi40IDQtMi4yLjQtMyAwLTMuMS43LS4yLjYuMi44IDEuNCAxLjIgMS4yLjMg'
    b'My42LjYgNCAyLjUuNCAxLjkuNSAyLjctMS4zIDQuNC0xLjggMS42LTQuNyAxLjQtNS42IDEu'
    b'Mi0uOS0uMi0xLjktMS4xLTIuOC0uMy0uOC45LjggMS42IDIuMyAyLjYgMS41IDEgMS40IDMt'
    b'MS4xIDQuNC0yLjUgMS40LTUgLjktNiAuNS0xLS4zLTIuNS0yLTMuMi0xLS43IDEuMSAyLjIg'
    b'MS41IDMuNCAzIDEuMiAxLjQuOCAzLjgtMS42IDUuMy0yLjUgMS41LTYuNC40LTcuMS0uMi0u'
    b'Ny0uNi0xLjYtLjgtMi0uMy0uNi41LjIgMS45LjcgMyAuNSAxLjMgMS41IDQuOC0yLjIgNi4y'
    b'cy02LjktMS43LTcuNS0yLjNjLS42LS42LTEuMi0uNy0xLjctLjUtLjUuMy0uMi44LjIgMS40'
    b'LjQuNiAxLjQgMy4yLTEuMiA1YTYuMyA2LjMgMCAwIDEtNC43IDFjLS42LTItMS4zLTQuMi0y'
    b'LTcuMmguNWMuNCAwIC41LjUuNS43IDAgLjItLjEuNC4yLjQuMyAwIC4zLjIuOC41LjQuMy44'
    b'LjcgMSAuNS4zLS4yLS45LS44LTEuMi0xLjItLjMtLjQtMS0xLTEtMS40IDAtLjQtLjItLjYt'
    b'LjgtMS4xYTIuNCAyLjQgMCAwIDEtLjUtLjYgOTcuOSA5Ny45IDAgMCAxLTEuMi03LjIgNTcu'
    b'MSA1Ny4xIDAgMCAxLS40LTUuNWgxLjF6bTczLjctNTMuOGMtMy45IDcuOC05LjMgMTIuMS05'
    b'LjMgMTIuMWwxLTMuMmMuMy0xLjQuMS0yLjkuMS0yLjlzMS40LTEuNyAzLjktNS42YzIuNS0z'
    b'LjkgMy44LTkuNiAzLjgtOS42cy0yLjMgNS43LTQuMSA4LjhjLTEuOSAzLTQgNS41LTQgNS41'
    b'cy0uNy0yLjctMS4yLTIuOGMtLjUtLjItMSAuMi0xLjQuOC0uNC42LS44LjYtLjguNmwxLjUt'
    b'Mi44IDEuNi0yLjJjMS40LTIuMyA0LjUtNi42IDYtMTAuOWExNjkgMTY5IDAgMCAwIDUuNy0x'
    b'OC4zYy43LTMuMiAxLjMtMS40IDEuOS45LjYgMi4zIDEuNCA1LjcuOSAxMC43YTUzLjUgNTMu'
    b'NSAwIDAgMS01LjYgMTguOXptLTUgMjFhMTM1LjkgMTM1LjkgMCAwIDEtMy41IDIuNWwuNS0x'
    b'LjcuMy0yLjkgMi45LTIuNWE0MS43IDQxLjcgMCAwIDAgNS42LTZjMi45LTMuNi41LTEuNC0x'
    b'LjkgMS4yLTIuMyAyLjYtNi45IDYuMy02LjkgNi4zdi0uOGEzLjEgMy4xIDAgMCAwLS43LTEu'
    b'OWMtLjQtLjYtLjItLjYgMi4zLTIuNmE3My44IDczLjggMCAwIDAgMTcuNi0yNC40czEuNSA5'
    b'LTQgMTguN2MtNS40IDkuOS0xMC44IDEzLTEyLjIgMTQuMXptLTI4LjUgNTYuM2MtMy0xLjIt'
    b'Mi4yLTQuMS0yLjItNC4xczEuOC41IDMuNSAxLjJhMzYgMzYgMCAwIDAgNy41IDEuOGMxLjYg'
    b'MCAxLjYtLjIgMS43LS40IDAtLjItMS4zIDAtMy43LS40YTI5IDI5IDAgMCAxLTcuMi0zLjFj'
    b'LS43LS41LS42LS42LjUtLjdhNC41IDQuNSAwIDAgMCAyLjMtLjljLjQtLjMgMS41LjEgNC4y'
    b'LjhhNTAuNiA1MC42IDAgMCAwIDIxLjUuN2MuNy0uMiAxLjQuMi0uNyAzLjctMiAzLjUtOS4z'
    b'IDUuMy0xNC40IDUuMy01IDAtMTAtMi44LTEzLTMuOXptMTMuNC03LjJjLTUuMiAwLTcuMi0x'
    b'LjUtNy4yLTEuNWwuNy0xLjNjLjctMS4xLjYtMi45LjYtMi45bDMuNC42YzIuMi4zIDQuNy42'
    b'IDcuNS4xczEuNi0uOC0uNi0uNWEyOSAyOSAwIDAgMS03LjgtMWMtMS40LS41LS45LTEgMC0x'
    b'LjMgMS0uMyAzLjUtMS45IDMuNS0xLjlzNi4zLjggMTIuMi4yYzUuOS0uNyA5LjYtMi4yIDEw'
    b'LjgtMi40IDEuMS0uMiAxLjEuMyAxLjEuM3MuMy42LTEuNyAzLjdjLTIgMy4yLTYgNS4zLTku'
    b'NCA2LjNhNTAuMyA1MC4zIDAgMCAxLTEzLjEgMS42em0xLjMtMTIuMi42LTEuM2MuMy0xLS42'
    b'LTEuOS0uNi0xLjlzMS4yLS4zIDUtLjhjNC0uNSA0LjItLjggNi41LTEuMyAyLjQtLjYgNC0x'
    b'LjMgNC0xLjUgMC0uMy0uOCAwLTIuMi42YTk0IDk0IDAgMCAxLTE0LjMgMS45Yy0uNC0uMy0y'
    b'LS43LTItLjdsMi40LS41YTguNCA4LjQgMCAwIDAgMy4yLTEuM2MuNy0uNSAxLS42IDQuMS0x'
    b'IDMuMi0uMyA1LjgtMS4zIDExLjUtMy40IDUuNi0yIDEwLTQuNiAxMS01LjUgMS4yLTEgMS4x'
    b'LS4zLjggMS0uMyAxLjEtLjIgMi42LTMuMSA2LTIuOSAzLjMtNC4zIDQuOC0xMS41IDcuNC03'
    b'LjMgMi43LTE1LjQgMi4zLTE1LjQgMi4zem0yMS40LTE3LjZhNDAuNSA0MC41IDAgMCAxLTE1'
    b'LjUgNi40Yy0uMy0uNC40LTIgMC0yLjgtLjMtMS4xLTEtMS4xLTIuNi0xLjItMS41LS4xLS41'
    b'LS40LS4xLS40bDMtLjdjMi41LS43IDUuMS0xLjEgOC42LTIuNCAzLjYtMS40IDQuNi0yLjMg'
    b'NC41LTIuNiAwLS4zLTEuNi44LTQuOSAyLTMuMiAxLjMtNyAxLjgtOSAyLjMtMi4yLjQtLjQt'
    b'LjUuNi0xIDEtLjYgMi40LTIuOCAyLjQtMi44czIuMy0uNCA2LTEuNWE0OC44IDQ4LjggMCAw'
    b'IDAgMTAtNC4ybDMuMi0yLjIgNS4yLTMuN2MxLjMtMSAuOS0uMi43LjRzLTEgMy4yLTMgNi4x'
    b'Yy0yIDMtMi43IDMuOC05IDguM3ptMS0xMi43Yy02LjIgNS0xMS43IDYuNi0xMi42IDctMSAu'
    b'NC0uOC0uMi0uNy0uNy4yLS41LjMtMi4yLjMtMi4ybDQuOC0yLjhjMi41LTEuNCA1LjMtMy40'
    b'IDcuMi00LjcgMS44LTEuMy43LTEuMi4xLS43LS41LjUtMy4xIDItNS43IDMuNmwtNi40IDMu'
    b'OXMwLS45LS42LTEuNGMtLjUtLjUtMS45LS40LTEuOS0uNGwxLTEuM2MuNS0uNiAyLjYtMS4z'
    b'IDQuOS0yLjQgMi4zLTEgNi41LTQuMiA5LjYtNi44IDMuMS0yLjYgOS4xLTkuMSA5LjUtOS43'
    b'LjQtLjUuNy0uNC43LjMgMCAuNi4zIDEtLjQgNHMtMy40IDkuNC05LjcgMTQuM3pNNDE4LjUg'
    b'MTY4Yy0uNyAxLjUtMS41IDIuNi0yIDMuNkw0MTUgMTc0di0xLjRjLjEtLjguMy0yIDAtMy41'
    b'IDAtLjgtLjMtMS42LS4yLTIuMyAwLS43LjMtMS40LjQtMS45bDEuNi03Yy40LTIuNy45LTYu'
    b'NC44LTkuNyAwLTMuMi0uNS0xLjYtLjUgMHMtLjEgNC0uNiA3LjhjLS41IDMuNy0yLjEgOS40'
    b'LTIuMSA5LjRzLS4xLS45LS42LTIuMWwtMS45LTQuMmMtLjYtMS42LS40LTEuOS0uNC0xLjlz'
    b'Mi4zLTEwLjYgMi44LTE1LjZjLjYtNSAxLjYtMTguMSAxLjYtMTguMSAzLjIgMy4yIDUuNiAx'
    b'MS44IDYgMjAgLjQgNi0uNiAxMS43LTEgMTQtLjUgNC41LTEuMyA4LTIuNSAxMC41em03LjIg'
    b'MTYuOGMwLTIuNC0uNi00LjMtMi4yLTQuOCAwIDAgMS40LTIuNCAyLjYtNS44YTQ1IDQ1IDAg'
    b'MCAwIDEuOC03LjdjLjktNS42IDEuNi0xMS41LS4xLTItMS43IDkuNy0zLjggMTMtMy44IDEz'
    b'bC0yLjQgNGMuMy0xLjcuNC0zIC4zLTQuOSAwLTEuOS0uMy00LjUtMS02LjUgMCAwIDMtNiA1'
    b'LTEzYTgxLjQgODEuNCAwIDAgMCAzLjEtMjIuN3MzIDIuMyA0IDEzLjlhNjguNCA2OC40IDAg'
    b'MCAxLTcuMyAzNi41em0tMzMuMiA4OC42IDEuOS0xLjNjMS41LS45IDEtMy43IDEtMy43YTQ4'
    b'LjcgNDguNyAwIDAgMCA1LjIgMy4yYzEuNC42IDIuMSAxIDMgMS4yIDEgLjMuNyAwIDAtLjUt'
    b'LjgtLjQtMS0uNy0zLTEuNC0yLS44LTUuOC00LjItNS44LTQuMmwyLjUtLjFjMS42IDAgMy42'
    b'LS45IDMuNi0uOXMxLjYgMS40IDggNC4yYTUwIDUwIDAgMCAwIDExLjggMy41cy0uNiAzLjIt'
    b'My43IDQuM2MtMi42IDEuMS02IDEuOC0xMyAuMmE0My41IDQzLjUgMCAwIDEtMTEuNS00LjV6'
    b'bS04LjQgNi41Yy0uNi0yLjcgMS00LjYgMS00LjZsMS4zIDEuMWMxIC45IDIuMyAyLjUgNSAz'
    b'LjkgMi43IDEuMyAzLjcgMS4yIDEtLjJhMzkuMyAzOS4zIDAgMCAxLTYuMy01LjNsMS0uNGMx'
    b'LS40IDIuNy4zIDEwIDQuNiA3LjEgNC4zIDExLjQgNC41IDExLjQgNC41cy0zLjIgMy45LTEy'
    b'IDMuNmMtOC43LS4zLTExLjktNC41LTEyLjQtNy4yem0tMTYuNi0zLjFzMSAxLjMgMi4zIDIu'
    b'MmMxLjMuOSA0LjggMS40IDQuOCAxLjRsLjggMS4yYy42IDEgMi4xIDMgMy43IDQgMS41IDEu'
    b'MiA0IDIgNCAxLjYuMi0uMy0xLjMtLjgtMi44LTEuOC0xLjUtLjktMi45LTIuNi0zLjktMy43'
    b'LTEtMS4yLjUtMSAuNS0xaDMuNWMxLjctLjIgMS4zIDAgMS44LjdsMi40IDMgNC40IDUuMWMx'
    b'IDEuMi4zIDEuNS4zIDEuNXMtLjUuNy00LjQgMS4yYy0yLjQuMi01IDAtNy43LTEuNmEyMy40'
    b'IDIzLjQgMCAwIDEtNS4yLTQuNWMtNC43LTUuMS00LjUtOS4zLTQuNS05LjN6bS0yIDEwLjUg'
    b'MS41IDEuOHMtLjctMi0xLjMtM2wtLjktMS40Yy43LTEuNCAxLjItMyAxLjYtNC43LjQgMS40'
    b'IDEuNyA1LjUgMy40IDguMSAyIDMuMiAzLjggNC40IDIuNiA1LjMtMS4xLjgtMy40IDEtNi0u'
    b'Mi0yLjQtMS4yLTMtMy4zLTMuNC01YTI0LjggMjQuOCAwIDAgMCAxLjItMi4xYy4zLjIuOC41'
    b'IDEuMyAxLjJ6Ii8+CiAgPGVsbGlwc2UgY3g9Ii0zNjUuOSIgY3k9IjE1OC42IiBmaWxsPSIj'
    b'ZDRhZjNhIiByeD0iMS44IiByeT0iMS42IiB0cmFuc2Zvcm09InNjYWxlKC0xIDEpIi8+CiAg'
    b'PHBhdGggZmlsbD0iI2Q0YWYzYSIgZD0iTTM2OS43IDE1NS41Yy0xLjYgMC0yLjUtLjgtNC4z'
    b'LS42YTI2IDI2IDAgMCAwLTguNSAzLjMgMTQuNiAxNC42IDAgMCAxLTkuOC45Yy0xLS4zLTIt'
    b'LjktMi45LTEuNC00LjMtMi40LTMuMi03LjEtMy4yLTcuMWExNi43IDE2LjcgMCAwIDAgMTAu'
    b'NiAzLjJsLS45LjhjLS42LjYtMS43IDEuNC0xLjQgMS43LjQuMyAyLTEuMiAzLjMtMi4yIDEu'
    b'My0xIDMuMi0yLjIgNi41LTMuMnM3LTEgOS40LjRjMi41IDEuMyAyLjcgMyAyLjQgMy43LS4y'
    b'LjQtLjcuNS0xLjIuNXptLTQ2LjIgMzQuN2MuOC0uMiAyLS40IDMuOC0yYTY5IDY5IDAgMCAw'
    b'IDYuMy03Yy41LS44LjMtMS41LTEtMi0xLS41LTEuOS0yLTEuOS0yczIuNS0xIDQuMy0yLjJj'
    b'MS43LTEuMiA1LjYtNC44IDYuMi01LjcuNS0xIC4zLTEtLjUtMS4zLS45LS4zLTEtLjgtMS0u'
    b'OHMxLjgtMS4yIDMuNS0yLjZhNzEgNzEgMCAwIDAgNC0zLjZjMi42IDEgNi42LjYgOC44LjIg'
    b'My44LS43IDYuNy0yLjMgNi43LTIuM2wuNiAxLjhjLjUgMS4yIDIuMiAxLjggNCAuNyAxLjgt'
    b'MS4yIDEuNC0zLjcgMS40LTMuN3MxLjQtMSA0LjQtMmMzLTEuMSA1LjMtMS4zIDcuNy0uMiAy'
    b'LjQgMS4xIDMuNiA0LjQgMy42IDcgMCAyLjQtMS4zIDEuMy0xLjYgMS0uMy0uMy0uOC0yLjEt'
    b'My44LTIuNnMtNS44IDEtOS4yIDMuOGMtMy40IDIuOC00LjIgMy02IDQuOC0xLjYgMS44LS4z'
    b'IDIuNyAyLjcgMy43czYuNy0xIDYuOS0uOWMuNS4zLTEuMyAzLTMuOSA0LTIuNSAxLTUuOC4z'
    b'LTguMy0uOC0xLjctLjYtMiAwLTIuNS42YTE1IDE1IDAgMCAwLTQgOSA0IDQgMCAwIDEtMi42'
    b'LTNjLS4xLS42LS4zLTEuOC0xLjItMS0xIDEtMS44IDYtMS44IDguMnMuNyA1LjMuNyA1LjNo'
    b'LS43bC0yLjMtMS4yYy0xLS43LTEuMiAwLTEuMiAxLjNzLS40IDMuNi0yIDcuOGMtMS43IDQu'
    b'Mi00IDUuNS00IDUuNXMtLjUtLjgtMS0yLjVhMzMgMzMgMCAwIDEtLjgtNy43YzAtMi44Ljct'
    b'OC44LjctOC44cy0zLjQgNC4yLTcgNS4yLTcuMS40LTguNi0xLjNjLTEuNS0xLjctLjItMi41'
    b'LjYtMi43eiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zNDcgMjAxczEgMi41IDEu'
    b'NiAzLjNjLjYuOS45IDEgLjkgMXMtMS4xIDEtMi43IDEuNGEzNS41IDM1LjUgMCAwIDEtMyAu'
    b'OHMxLjgtMi40IDIuNC00LjFsLjctMi4zem0tMjEuNS0xLjNhNzEuNiA3MS42IDAgMCAxIC45'
    b'LTIuMSAxNSAxNSAwIDAgMCA4LjEtMS43cy0xLjYgMy4zLTMuMyA0LjVsLTEuOCAxLjJzMS42'
    b'LjMgMy44LTJjMi4yLTIgMy4yLTQuNiAzLjItNC42cy0uNSA1LjguNCA5LjNsMSA0cy00LjYu'
    b'OS05LjgtLjZjLTUuMi0xLjQtNS42LTEuOS01LjYtMS45cy0uNi0uMS4yLTEuMmEyOCAyOCAw'
    b'IDAgMCAzLTV6Ii8+CiAgPHBhdGggZmlsbD0iI2I5NmIyOSIgZD0ibTMzNSAxODcgMS43LTIu'
    b'M3MuNi41IDAgMS4zYTE2IDE2IDAgMCAxLTQuMiAzLjdjLTEuNi45LTMuMSAxLjItMy4xIDEu'
    b'MnYtLjRzNC0xLjcgNS41LTMuNXptNi4zIDEyIC40LTguM2MwLTEgLjYtLjguNi0uOGwuOC4z'
    b'LTEuNSAxMC42Yy0uMiAxLjItLjcgMS0xIDEgLjUtLjMuNi0yLjUuNy0yLjh6bTkuOC0zMS40'
    b'Yy42LS42IDEuOS0xIC42LjQtMS4zIDEuNC0zIDMuMi0zLjQgNC43LS41IDEuNC0uOCAzLjMg'
    b'MCAyLjkuOC0uNCAxLjQtLjQgMi4zLTEuMiAxLS43IDIuNi0yIDMuMy0yLjEuNy0uMiAyIDAg'
    b'MSAxYTI0LjggMjQuOCAwIDAgMS00IDMuNmwtNCAyLjZhMzYuOSAzNi45IDAgMCAxLTIgMS4z'
    b'czEtNiAyLjYtOC41YTI2LjMgMjYuMyAwIDAgMSAzLjYtNC43em0zMiA5OS4yYzEuMiAxIDIu'
    b'OCAxLjMgMi44IDEuM3MuNyAwIC43LjItLjkgMC0xLjgtLjFhOCA4IDAgMCAxLTIuNi0xLjRj'
    b'LS40LS40LTEuMS0uOC0uOS0xLjQuMi0uNi42LjUgMS44IDEuNHptLTEwLjQgNS41IDIuMyAx'
    b'LjggMS4zLjdjLjYuMi44LjYuOC42cy0uMS4yLS44IDBjLS43LS4yLTIuOC0xLjctMy41LTIu'
    b'My0uNi0uNi0xLS43LS43LTEgLjMtLjIuNCAwIC42LjJ6bTQyLTc0LjRjLS40LjQtLjkgMS0x'
    b'IC45LS4zLS4yIDAtLjUuNC0xbC44LS45IDEuMS0xLjVjLjQtLjQgMS0uNy4zLjNsLTEuNyAy'
    b'LjJ6bTMuMSA3LTEuMyAxLjNjLS41LjUtLjkgMS4xLTEuMi44LS4zLS4zLjctLjkgMS4yLTEu'
    b'NWE3LjUgNy41IDAgMCAxIDEuNC0xLjQgMTAgMTAgMCAwIDEgMS4zLS44bC0xLjQgMS42em0t'
    b'MS4yIDExLjJjLS44LjktMiAxLjEtMiAuOC0uMi0uNCAwLS42LjctMWEyNC40IDI0LjQgMCAw'
    b'IDAgNC42LTNjLjIgMC0xIDEuNC0xLjQgMS42LS40LjItMSAuOC0xLjkgMS42em0tMi4yIDlj'
    b'MC0uMy0uMS0uNS41LS41bDEuNi0uMnMxLjMtLjUgMS40LS4yYzAgLjMtMSAuOC0xLjYuOGwt'
    b'MS40LjRjLS4zLjItLjUgMC0uNS0uM3ptLTEgOS44YzEuNCAwIDIuNi0uMyAyLjcgMCAwIC4x'
    b'LS43LjUtMS40LjctLjcuMy0yIC4zLTMgLjQtLjkgMC0xLS4yLTEtLjYgMC0uNSAxLjMtLjUg'
    b'Mi43LS41em0tMTEgMTAuOGMuMS0uMi42IDAgMS40IDAgLjguMyAyLjEuNSAyLjguNWwyLjQt'
    b'LjEgMSAuMmMwIC4yLTEuMy4yLTMgLjQtMS44LjItMy0uMi0zLjgtLjMtLjgtLjItMS0uNS0u'
    b'OS0uN3ptLTQuNiA3LjZhNiA2IDAgMCAwIDIuMS40bDIuMy4zcy43IDAgLjYuNGMtLjEuMy0u'
    b'NCAwLTEtLjFoLTIuNGMtMS4yIDAtMS44LS40LTIuNS0uNS0uNy0uMS0xLjUtLjUtMS4xLTEg'
    b'LjQtLjQgMS4xLjIgMiAuNXptLTkgNS44IDIuNSAxLjggMS4xLjZjLjguNC43LjYuNi44LS4x'
    b'LjItLjYtLjMtMS0uNWExNi40IDE2LjQgMCAwIDEtMi41LTEuNmMtLjctLjYtMS42LTEtMS40'
    b'LTEuNS4xLS40LjMtLjEuOC40em0xNC45LTc0LjgtMS43IDIuM2MtMS42IDItLjcuMS0uNC0u'
    b'NGwzLjQtNC41Yy44LS45IDEtLjUuNSAwbC0xLjggMi42em0zLjIgOS44Yy0uMi0uMi4zLS40'
    b'IDEuMS0xLjVsMi43LTMuMy42LTFjLjIuMS0uNiAxLjgtMS4zIDIuNS0uNy43LTEuNiAyLTIu'
    b'MSAyLjctLjUuNi0uOC45LTEgLjZ6bS00LjMgMTguNWMwLS41IDEuOC0uNSAyLjYtLjZsMi4y'
    b'LS41czEuNi0uMyAxLjYgMGMwIC4xLS4zLjMtMS4yLjVsLTMuMy44Yy0xIC4xLTEuOS4zLTEu'
    b'OS0uMnptNC4zLTEwYTE1LjMgMTUuMyAwIDAgMS0yLjUgMS43Yy0uNi40LTEuMS44LTEuNC41'
    b'LS40LS40LjItLjcgMS4yLTEuMWwxLjUtLjkgMS0uNWMuNS0uMyAxLjMtLjYuMi4zem0tMTAt'
    b'Ni41IDEuNC0xcy45LS44IDEtLjVjLjIuMy0xIDEtMS41IDEuNi0uNS41LTEuNSAxLjktMiAx'
    b'LjYtLjUtLjMuNS0xLjEgMS4yLTEuN3ptNi42IDI1LjcgMS41LjRjLjcuMi43LjQtLjQuNHMt'
    b'MS42LS4zLTIuNy0uNS0xLjUtLjMtMS4zLS43Yy4xLS4zLjctLjIgMS4yIDBsMS43LjR6bS0x'
    b'LjggOS4zYy4xLjItLjggMC0xLjQtLjItLjUtLjItMS43LS45LTIuNC0xLS43LS4zLS43LS40'
    b'LS43LS44cy43IDAgMS42LjJjMSAuMyAyIDEuMiAyIDEuMmwxIC42em0tMTIgNS42Yy0uOC0u'
    b'NS0xLS44LS43LTEgLjMtLjMuNi0uMyAxLjIuMmE1MSA1MSAwIDAgMCAyIDEuNWwxLjEuNWMu'
    b'NS4yIDEuMi43IDEgMS0uMi4xLTEuMiAwLTEuNy0uNnMtMi0xLTIuOS0xLjZ6bS01LjYgNy41'
    b'Yy0uNC0uMy0xLjQtLjYtMS44LTEtLjUtLjMtLjgtMS4zLS40LTEuNC40LS4xLjYuNCAxLjQg'
    b'MWwzLjUgMi40LjcuM2MuNy4yLjQuNS0uMi40LS43LS4xLTEtLjEtMS44LS43bC0xLjQtMXpt'
    b'LTguNCA3LjFhOS4yIDkuMiAwIDAgMS0yLjItMS43Yy0uNS0uNC0xLjItMS0uOC0xLjMuNC0u'
    b'My44LjEgMS40LjZsMi4xIDIuMnMuMiAwIDEgLjdjLjkuNyAwIC41LS4zLjNhMyAzIDAgMCAw'
    b'LTEuMi0uOHoiLz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJtMzM4LjIgMTQyLjUgNC0x'
    b'IDIuNSAyLTMuMSAxLjR6Ii8+CiAgPGVsbGlwc2UgY3g9Ii0zMzAuOCIgY3k9IjE0Mi4xIiBm'
    b'aWxsPSIjYjk2YjI5IiByeD0iMy4yIiByeT0iMy4xIiB0cmFuc2Zvcm09InNjYWxlKC0xIDEp'
    b'Ii8+CiAgPGNpcmNsZSBjeD0iLTMzMC44IiBjeT0iMTQxLjQiIHI9IjEuOSIgZmlsbD0iI2Q0'
    b'YWYzYSIgdHJhbnNmb3JtPSJzY2FsZSgtMSAxKSIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2Ei'
    b'IGQ9Ik0zMzcuNSAxMzEuNGMtLjguMy0xLjkuMi0xLjkuMnMtLjMtMS40LjUtMi4xbDItMS43'
    b'LjUtLjZ2MmMuMS44LS4zIDEuOS0xLjEgMi4yeiIvPgogIDxjaXJjbGUgY3g9Ii0zMzUuOCIg'
    b'Y3k9IjEzMyIgcj0iLjYiIGZpbGw9IiNkNGFmM2EiIHRyYW5zZm9ybT0ic2NhbGUoLTEgMSki'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZDRhZjNhIiBkPSJtMzQwLjIgMTMyLjQuOC45cy0uNyAwLTEu'
    b'Mi40Yy0uNi40LTEuMi43LTEuOS42YS45LjkgMCAwIDEtLjgtMWMuMi0uNS41LTEgMS41LTEu'
    b'MyAxLS40IDEuMyAwIDEuNi40em0tMi4yIDMuN2MyIC4yIDQuNi0yIDQuNi0yIC4zIDEuOCAx'
    b'LjQgMi43IDMgM3YuMXMtMS43LjgtMy41IDEuMWE3IDcgMCAwIDEtMi41LS4yIDEwLjYgMTAu'
    b'NiAwIDAgMS0zLTFjLTEuMi0uNy0uOS0yLjYtLjktMi42cy4yIDEuNSAyLjIgMS42em03Ljgt'
    b'MmMuOC0uMyAyLS45IDIuNi0xIC41IDAgMS4zIDAgMS4xLjkgMCAxLTEgMS40LTIgMS40cy0x'
    b'LjUtLjMtMi0uNmMtLjYtLjMtLjUtLjQuMy0uN3ptNi4zLTMuNGMxLS43IDEuNy0uOSAxLjct'
    b'LjlzLjYgMS42LjMgMi42LTEgMS4yLTEuOSAxLjJjLS44IDAtMi4xLS41LTEuOC0xLjIuNC0u'
    b'Ni44LTEgMS43LTEuN3oiLz4KICA8ZWxsaXBzZSBjeD0iLTM1MS4zIiBjeT0iMTM1LjEiIGZp'
    b'bGw9IiNkNGFmM2EiIHJ4PSIuNyIgcnk9Ii41IiB0cmFuc2Zvcm09InNjYWxlKC0xIDEpIi8+'
    b'CiAgPHBhdGggZmlsbD0iI2Q0YWYzYSIgZD0iTTM0OS40IDEyNy4zYy41LTIuNy40LTUuNi0y'
    b'LTkuM2ExNiAxNiAwIDAgMC03LTUuMUwzMzkgMTExYy0xLjQtMS41LTQuMy0zLjQtNC4zLTMu'
    b'NGw1LjIgMS41YTIuMyAyLjMgMCAwIDAgMi4zIDIuNGMuNCAwIC45LS4yIDEuMy0uNCAxIC4x'
    b'IDQuNCAyLjIgNS4yIDIuOWEyLjMgMi4zIDAgMCAwLS4zIDEuMiAyLjMgMi4zIDAgMCAwIDIu'
    b'MyAyLjNjLjMgMCAuNyAwIDEtLjJsLjMuNWEyMy40IDIzLjQgMCAwIDEgMS42IDMuN2MtLjYu'
    b'NC0xIDEuMS0xIDIgMCAxLjMgMSAyLjMgMiAyLjN2MS41YzAgLjctLjQgMS4yLTEuNyAxLjYt'
    b'MS4zLjMtMyAyLjYtMyAyLjYtLjIgMC0xLjEtMS42LS40LTQuM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZDRhZjNhIiBkPSJNMzQxLjMgMTEwLjNjLS40LS40LS41LTEtLjEtMS40LjMtLjMgMS0u'
    b'MyAxLjUuMXMuNiAxIC4yIDEuNGMtLjQuMy0xIC4zLTEuNi0uMXptOC41IDUuN2MtLjUtLjUt'
    b'LjYtMS4zLS4yLTEuNy40LS40IDEuMi0uNCAxLjcuMS42LjUuNyAxLjMuMiAxLjctLjQuNC0x'
    b'LjIuNC0xLjctLjF6Ii8+CiAgPGNpcmNsZSBjeD0iLTM1NC44IiBjeT0iMTIzLjIiIHI9IjEu'
    b'MyIgZmlsbD0iI2Q0YWYzYSIgdHJhbnNmb3JtPSJzY2FsZSgtMSAxKSIvPgogIDxwYXRoIGZp'
    b'bGw9IiNkNGFmM2EiIGQ9Ik0zMjYuNiAxMDVjLjcuMiAyIC42IDMuOCAxLjYtMS4zIDAtMi4z'
    b'LjgtMi4zIDEuOSAwIDEgMS4yIDIuMiAyLjUgMi4yczIuMi0xLjEgMi4yLTIuMmMwLS4yIDAt'
    b'LjUtLjItLjdsMS44IDEuMmM0LjIgMi44IDUuMSA0LjEgNy4yIDggMiAzLjggMi44IDggMS45'
    b'IDEwLjQtLjkgMi41LTQuMiAzLTQuMiAzcy40LS4zLjQtLjhsLS4yLTEuNmMtLjItMSAwLTIu'
    b'MSAwLTIuMXMtLjgtLjEtMS4yLjRsLTEuNSAxLjctMS41IDEuNXMtLjctMS0uNy0yLjEuOC0y'
    b'LjMgMS00LjNjMC0yLTEtNS41LTIuOS04YTIyIDIyIDAgMCAwLTYuNi01LjUgMi4xIDIuMSAw'
    b'IDAgMS0xLjMtMS43bC0uMi0yYy0uMS0xLjIgMS0xLjEgMi0uOXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZDRhZjNhIiBkPSJNMzMwLjggMTA5LjVjLS44IDAtMS40LS43LTEuNC0xLjMgMC0uNi41'
    b'LTEgMS4zLTEgLjcgMCAxLjMuNCAxLjMgMXMtLjUgMS4zLTEuMiAxLjN6bS02LjIgMjQuNGMt'
    b'MSAuNC0yLjIuMS0yLjctLjItLjUtLjQtLjctMS4zIDAtMS44YTIgMiAwIDAgMSAyLS4ybDIg'
    b'MS4zcy0uMy41LTEuMy45eiIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zMjEuNCAx'
    b'MzVjLjMuNi42LjkgMS43IDEgMS4xIDAgMi4zIDAgMy0uOGE3LjcgNy43IDAgMCAwIDEuMy0x'
    b'LjdoMS4zcy40IDEuNyAxIDIuMWMuNS41IDIuNC42IDMuMyAwIC44LS43IDEuNi0xLjQgMS43'
    b'LTEuMy4yIDAgMCAuNy0uOCAxLjRzLTEuNSAxLjMtMyAxLjNIMzIzcy0xLjYgMC0yLTFjLS41'
    b'LS45LS42LTEuNS0uMy0xLjcuMi0uMy4zLjEuNy43eiIvPgogIDxwYXRoIGZpbGw9IiNkNGFm'
    b'M2EiIGQ9Ik0zMzMuNSAxMzMuN2MtMS4yLjYtMS45LjItMi4zLS4zbC0uNS0uOCAxLjctLjdj'
    b'LjUtLjQuOS0uNyAxLjUtLjZsLjYuMXMuMiAxLjYtMSAyLjJ6Ii8+CiAgPGVsbGlwc2UgY3g9'
    b'Ii0zMzkuMyIgY3k9IjEyMS45IiBmaWxsPSIjYjk2YjI5IiByeD0iMi43IiByeT0iMi42IiB0'
    b'cmFuc2Zvcm09InNjYWxlKC0xIDEpIi8+CiAgPHBhdGggZmlsbD0iI2I5NmIyOSIgZD0iTTMz'
    b'NC43IDExMi43YzEtLjcgMi42LS40IDMuNS42LjggMS4xLjcgMi42LS40IDMuMy0xIC43LTIu'
    b'Ni40LTMuNS0uNi0uOS0xLjEtLjctMi42LjQtMy4zeiIvPgogIDxlbGxpcHNlIGN4PSItMzM5'
    b'LjQiIGN5PSIxMjEuNSIgZmlsbD0iI2Q0YWYzYSIgcng9IjEuNiIgcnk9IjEuNSIgdHJhbnNm'
    b'b3JtPSJzY2FsZSgtMSAxKSIvPgogIDxwYXRoIGZpbGw9IiNkNGFmM2EiIGQ9Ik0zMzUuOCAx'
    b'MTNjLjctLjIgMS41LjIgMS45LjguMy42IDAgMS4yLTEgMS40LTEuNy4zLTIuNS0xLjgtMS0y'
    b'LjJ6Ii8+Cjwvc3ZnPgo=', 'ME')

ME = b64_ME
index.append("ME")
index.append("MNE")
index.append("Montenegro")
catalog["ME"] = ME
catalog["MNE"] = ME
catalog["Montenegro"] = ME
country["Montenegro"] = ('ME', 'MNE', 0)
lookup["ME"] = ('ME', 'MNE', 'Montenegro', 0)
lookup["Podgorica Montenegro"] = ('ME', 'MNE', 'Montenegro', 0)
lookup["MNE"] = ('ME', 'MNE', 'Montenegro', 0)
lookup["Montenegro"] = ('ME', 'MNE', 'Montenegro', 0)
details["ME"] = {"continent":"Europe","capital":"Podgorica","currency":"Euro","web":".me","lang":"sr | hu | bs | sq | hr | rom","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_MF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1mIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'MF')

MF = b64_MF
index.append("MF")
index.append("MAF")
index.append("Saint Martin (French Part)")
catalog["MF"] = MF
catalog["MAF"] = MF
catalog["Saint Martin (French Part)"] = MF
country["Saint Martin (French Part)"] = ('MF', 'MAF', 0)
lookup["MF"] = ('MF', 'MAF', 'Saint Martin (French Part)', 0)
lookup["Marigot Saint Martin (French Part)"] = ('MF', 'MAF', 'Saint Martin (French Part)', 0)
lookup["MAF"] = ('MF', 'MAF', 'Saint Martin (French Part)', 0)
lookup["Saint Martin (French Part)"] = ('MF', 'MAF', 'Saint Martin (French Part)', 0)
details["MF"] = {"continent":"Americas","capital":"Marigot","currency":"Euro","web":".gp","lang":"fr","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_MG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1nIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmMzZDMyIiBkPSJNMjEzLjMg'
    b'MEg2NDB2MjQwSDIxMy4zeiIvPgogICAgPHBhdGggZmlsbD0iIzAwN2UzYSIgZD0iTTIxMy4z'
    b'IDI0MEg2NDB2MjQwSDIxMy4zeiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGgy'
    b'MTMuM3Y0ODBIMHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'MG')

MG = b64_MG
index.append("MG")
index.append("MDG")
index.append("Madagascar")
catalog["MG"] = MG
catalog["MDG"] = MG
catalog["Madagascar"] = MG
country["Madagascar"] = ('MG', 'MDG', 0)
lookup["MG"] = ('MG', 'MDG', 'Madagascar', 0)
lookup["Antananarivo Madagascar"] = ('MG', 'MDG', 'Madagascar', 0)
lookup["MDG"] = ('MG', 'MDG', 'Madagascar', 0)
lookup["Madagascar"] = ('MG', 'MDG', 'Madagascar', 0)
details["MG"] = {"continent":"Africa","capital":"Antananarivo","currency":"Malagasy Ariary","web":".mg","lang":"fr-MG | mg","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_MH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1oIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMzYjVhYTMiIGQ9Ik0wIDBoNjM5Ljl2NDgwSDB6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZTJhZTU3IiBkPSJNMCA0NjcgNjM5LjkgMHY4N0wwIDQ4MHYtMTN6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjIuNCA0ODAgNjQwIDE3OS4ybC0uMS05NS41'
    b'TDAgNDgwaDIyLjR6bTE1My00NjQuOEwxNjkgMTE4bC0yNy02NS42IDEwLjQgNjkuOC00MS45'
    b'LTU2LjQgMjcuNSA2NC4zLTU1LTQyLjYgNDIuOCA1My42LTYyLjEtMjcuNiA1NC40IDQxLjIt'
    b'NjcuNy05IDY0IDI1LjRMMTQgMTgwLjNsMTAwLjYgNi43LTYzLjcgMjYuMiA2Ny05LTU0LjMg'
    b'NDAgNjMtMjcuNi00MyA1NCA1NC42LTQxLjMtMjcgNjIuOSA0My42LTU0LjctMTEuOCA2OC4x'
    b'IDI3LjUtNjMuNyA2LjIgMTAwLjcgOS43LTEwMC40IDIzLjcgNjQtOS02OSA0My40IDU0Ljgt'
    b'MjguNi02NCA1NC42IDQ0LTQzLjQtNTQuOSA2NC45IDI3LTU3LjQtNDEuOSA2OS45IDExLjgt'
    b'NjctMjUuNyAxMDQuMS02LjUtMTA0LTkuNyA2OC41LTIyLjgtNzEgOSA1OC42LTQxLTY2IDI2'
    b'LjUgNDUuNi01NS4zLTU1LjYgNDMuNCAyNi43LTY2LjQtNDMuMSA1Ni40IDkuMy03MC40LTI1'
    b'LjcgNjYuNS05LjYtMTAyLjh6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'MH')

MH = b64_MH
index.append("MH")
index.append("MHL")
index.append("Marshall Islands")
catalog["MH"] = MH
catalog["MHL"] = MH
catalog["Marshall Islands"] = MH
country["Marshall Islands"] = ('MH', 'MHL', 0)
lookup["MH"] = ('MH', 'MHL', 'Marshall Islands', 0)
lookup["Majuro Marshall Islands"] = ('MH', 'MHL', 'Marshall Islands', 0)
lookup["MHL"] = ('MH', 'MHL', 'Marshall Islands', 0)
lookup["Marshall Islands"] = ('MH', 'MHL', 'Marshall Islands', 0)
details["MH"] = {"continent":"Oceania","capital":"Majuro","currency":"US Dollar","web":".mh","lang":"mh | en-MH","tz":"+12:00","altname":""}
#----------------------------------------------------------------------
b64_MK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1rIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2QyMDAwMCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZTYwMCIgZD0iTTAgMGg5Nmwy'
    b'MjQgMjMxLjRMNTQ0IDBoOTZMMCA0ODBoOTZsMjI0LTIzMS40TDU0NCA0ODBoOTZ6bTY0MCAx'
    b'OTJ2OTZMMCAxOTJ2OTZ6TTI4MCAwbDQwIDIwNS43TDM2MCAwem0wIDQ4MCA0MC0yMDUuN0wz'
    b'NjAgNDgweiIvPgogIDxjaXJjbGUgY3g9IjMyMCIgY3k9IjI0MCIgcj0iNzcuMSIgZmlsbD0i'
    b'I2ZmZTYwMCIgc3Ryb2tlPSIjZDIwMDAwIiBzdHJva2Utd2lkdGg9IjE3LjEiLz4KPC9zdmc+'
    b'Cg==', 'MK')

MK = b64_MK
index.append("MK")
index.append("MKD")
index.append("Macedonia")
catalog["MK"] = MK
catalog["MKD"] = MK
catalog["Macedonia"] = MK
country["Macedonia"] = ('MK', 'MKD', 0)
lookup["MK"] = ('MK', 'MKD', 'Macedonia', 0)
lookup["Skopje Macedonia"] = ('MK', 'MKD', 'Macedonia', 0)
lookup["MKD"] = ('MK', 'MKD', 'Macedonia', 0)
lookup["Macedonia"] = ('MK', 'MKD', 'Macedonia', 0)
details["MK"] = {"continent":"Europe","capital":"Skopje","currency":"Denar","web":".mk","lang":"mk | sq | tr | rmm | sr","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_ML = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1sIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9InJlZCIgZD0iTTQyNS44IDBINjQwdjQ4MEg0MjUuN3oiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiMwMDlhMDAiIGQ9Ik0wIDBoMjEyLjl2NDgwSDB6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZmYwIiBkPSJNMjEyLjkgMGgyMTR2NDgwaC0yMTR6Ii8+CiAgPC9nPgo8L3N2'
    b'Zz4K', 'ML')

ML = b64_ML
index.append("ML")
index.append("MLI")
index.append("Mali")
catalog["ML"] = ML
catalog["MLI"] = ML
catalog["Mali"] = ML
country["Mali"] = ('ML', 'MLI', 0)
lookup["ML"] = ('ML', 'MLI', 'Mali', 0)
lookup["Bamako Mali"] = ('ML', 'MLI', 'Mali', 0)
lookup["MLI"] = ('ML', 'MLI', 'Mali', 0)
lookup["Mali"] = ('ML', 'MLI', 'Mali', 0)
details["ML"] = {"continent":"Africa","capital":"Bamako","currency":"CFA Franc BCEAO","web":".ml","lang":"fr-ML | bm","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_MM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1tbSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZWNiMDAiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiMzNGIyMzMiIGQ9Ik0wIDE2MGg2NDB2MzIwSDB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2VhMjgzOSIgZD0iTTAgMzIwaDY0MHYxNjBIMHoiLz4KICA8ZyB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSgzMjAgMjU2LjkpIHNjYWxlKDE3Ni44Nzk5OSkiPgogICAg'
    b'PHBhdGggaWQ9Im1tLWEiIGZpbGw9IiNmZmYiIGQ9Im0wLTEgLjMgMWgtLjZ6Ii8+CiAgICA8'
    b'dXNlIHhsaW5rOmhyZWY9IiNtbS1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFu'
    b'c2Zvcm09InJvdGF0ZSgtMTQ0KSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjbW0tYSIgd2lk'
    b'dGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoLTcyKSIvPgogICAg'
    b'PHVzZSB4bGluazpocmVmPSIjbW0tYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJh'
    b'bnNmb3JtPSJyb3RhdGUoNzIpIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNtbS1hIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InJvdGF0ZSgxNDQpIi8+CiAgPC9n'
    b'Pgo8L3N2Zz4K', 'MM')

MM = b64_MM
index.append("MM")
index.append("MMR")
index.append("Myanmar")
catalog["MM"] = MM
catalog["MMR"] = MM
catalog["Myanmar"] = MM
country["Myanmar"] = ('MM', 'MMR', 0)
lookup["MM"] = ('MM', 'MMR', 'Myanmar', 0)
lookup["Nay Pyi Taw Myanmar"] = ('MM', 'MMR', 'Myanmar', 0)
lookup["MMR"] = ('MM', 'MMR', 'Myanmar', 0)
lookup["Myanmar"] = ('MM', 'MMR', 'Myanmar', 0)
details["MM"] = {"continent":"Asia","capital":"Nay Pyi Taw","currency":"Kyat","web":".mm","lang":"my","tz":"+06:30","altname":""}
#----------------------------------------------------------------------
b64_MN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGZpbGw9IiNmZmQ5MDAi'
    b'IGlkPSJmbGFnLWljb25zLW1uIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmls'
    b'bD0iI2RhMjAzMiIgZD0iTTAgMGg2NDB2NDgwSDBaIi8+CiAgPHBhdGggZmlsbD0iIzAwNjZi'
    b'MyIgZD0iTTIxMy4zIDBoMjEzLjR2NDgwSDIxMy4zWiIvPgogIDxjaXJjbGUgY3g9IjEwNi43'
    b'IiBjeT0iMTgxLjgiIHI9IjQwIi8+CiAgPGNpcmNsZSBjeD0iMTA2LjciIGN5PSIxNjMuNiIg'
    b'cj0iNDMuNiIgZmlsbD0iI2RhMjAzMiIvPgogIDxjaXJjbGUgY3g9IjEwNi43IiBjeT0iMTcw'
    b'LjkiIHI9IjI5LjEiLz4KICA8cGF0aCBkPSJNMTA5LjcgNzYuNGE4LjcgOC43IDAgMCAwLTUu'
    b'MiA3LjVjLS4yIDIuNS45IDUuMyAxIDcuNyAwIDQuMi00LjMgNS42LTQuMyAxMS41IDAgMiAx'
    b'LjkgNC4zIDEuOSA5LjYtLjQgMi44LTIgMy41LTMuNyAzLjdhMy42IDMuNiAwIDAgMS0zLjYt'
    b'My43IDMuNiAzLjYgMCAwIDEgMS0yLjUgMy42IDMuNiAwIDAgMSAuNC0uM2MuOC0uOSAyLTEu'
    b'MiAyLTMuNCAwLTEuMS0uOC0yLjItMS41LTQuMnMtLjItNS4yIDEuNC03LjFjLTIuNiAxLTQu'
    b'MSAzLjQtNSA1LjYtLjggMi43IDAgNC4yLTEuMiA2LjUtLjcgMS40LTEuNSAyLTIuMyAzLjIt'
    b'MSAxLjQtMiA0LjQtMiA1LjlhMTguMiAxOC4yIDAgMCAwIDM2LjMgMGMwLTEuNS0xLjEtNC41'
    b'LTItNS45LS45LTEuMi0xLjctMS44LTIuNC0zLjItMS4yLTIuMy0uNC0zLjgtMS4zLTYuNS0u'
    b'OC0yLjItMi4zLTQuNi00LjktNS42IDEuNiAyIDIgNS4yIDEuNCA3LjEtLjcgMi0xLjQgMy0x'
    b'LjQgNC4yIDAgMi4yIDEuMSAyLjUgMiAzLjRhMy42IDMuNiAwIDAgMSAuMy4zIDMuNiAzLjYg'
    b'MCAwIDEgMSAyLjUgMy42IDMuNiAwIDAgMS0zLjYgMy43Yy0yLS4zLTMuNS0xLjItMy43LTMu'
    b'NyAwLTcgMy03LjQgMy0xMi42IDAtNy40LTYuNi0xMC45LTYuNi0xNi4zIDAtMS44LjQtNSAz'
    b'LTcuNHpNMjYuNyAyMjlINjN2MTc0LjVIMjYuN1ptMTIzLjYgMGgzNi40djE3NC41aC0zNi40'
    b'em0tODAgMEgxNDNsLTM2LjMgMjEuOFptMCAyOUgxNDN2MTQuNkg3MC4zWm0wIDEwMS45SDE0'
    b'M3YxNC42SDcwLjNabTAgMjEuOEgxNDNsLTM2LjMgMjEuOFoiLz4KICA8Y2lyY2xlIGN4PSIx'
    b'MDYuNyIgY3k9IjMxNi40IiByPSIzNi40Ii8+CiAgPGcgZmlsbD0iI2RhMjAzMiIgdHJhbnNm'
    b'b3JtPSJ0cmFuc2xhdGUoLTM4LjggMzIuNykgc2NhbGUoLjcyNzI3KSI+CiAgICA8Y2lyY2xl'
    b'IGN4PSIyMDAiIGN5PSIzNjMuNSIgcj0iMTAiLz4KICAgIDxjaXJjbGUgY3g9IjIwMCIgY3k9'
    b'IjQxNi41IiByPSIxMCIvPgogICAgPHBhdGggZD0iTTIwMCAzMzRhMjkuNSAyOS41IDAgMCAx'
    b'IDAgNTkgMjMuNSAyMy41IDAgMCAwIDAgNDd2NmEyOS41IDI5LjUgMCAwIDEgMC01OSAyMy41'
    b'IDIzLjUgMCAwIDAgMC00N3oiLz4KICA8L2c+Cjwvc3ZnPgo=', 'MN')

MN = b64_MN
index.append("MN")
index.append("MNG")
index.append("Mongolia")
catalog["MN"] = MN
catalog["MNG"] = MN
catalog["Mongolia"] = MN
country["Mongolia"] = ('MN', 'MNG', 0)
lookup["MN"] = ('MN', 'MNG', 'Mongolia', 0)
lookup["Ulan Bator Mongolia"] = ('MN', 'MNG', 'Mongolia', 0)
lookup["MNG"] = ('MN', 'MNG', 'Mongolia', 0)
lookup["Mongolia"] = ('MN', 'MNG', 'Mongolia', 0)
details["MN"] = {"continent":"Asia","capital":"Ulan Bator","currency":"Tugrik","web":".mn","lang":"mn | ru","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_MO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1tbyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMDc4NWUiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmYmQxMTYiIGQ9Im0yOTUgMTA4LjcgNDAuNSAyOS41'
    b'TDMyMCA5MC41bC0xNS41IDQ3LjcgNDAuNi0yOS41eiIvPgogIDxnIGlkPSJtby1hIj4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMjAgMzMxLjZIMjE3LjVhMTQ2LjMgMTQ2LjMgMCAw'
    b'IDEtMy44LTRIMzIwYTIuMSAyLjEgMCAwIDEgMS40IDJjMCAuOC0uNSAxLjctMS40IDJ6bTAt'
    b'MzEuM2ExMyAxMyAwIDAgMCAxLjItNy42IDEyLjQgMTIuNCAwIDAgMC0xLjItMy44IDgyIDgy'
    b'IDAgMCAxLTMyLjUgMTkgODEgODEgMCAwIDEtMjMuNSAzLjVoLTYzLjFhMTQ0LjQgMTQ0LjQg'
    b'MCAwIDAgNS44IDhoNjFjMjAgMCAzOC4yLTcuMiA1Mi4zLTE5LjF6bS0xMDkuNi0yNC43YTMy'
    b'LjMgMzIuMyAwIDAgMS05LjcgMiA4MSA4MSAwIDAgMCA2MC44IDI3LjUgODAuOSA4MC45IDAg'
    b'MCAwIDU4LjUtMjUgNDQxIDQ0MSAwIDAgMCA0LjUtNTguOCA0NDEgNDQxIDAgMCAwLTQuNS02'
    b'Ny43Yy02LjYgNi0xOSAxOC43LTI0LjggMzguM0E4MSA4MSAwIDAgMCAyOTIgMjE1YTgwLjcg'
    b'ODAuNyAwIDAgMCAxMy43IDQ1IDgwLjcgODAuNyAwIDAgMS0xNy00OS41YzAtMTIuNCAyLjgt'
    b'MjQuMiA3LjgtMzQuN2EzMi41IDMyLjUgMCAwIDEtNy41LTEzIDgwLjcgODAuNyAwIDAgMC0x'
    b'MC41IDQwYzAgMTggNS45IDM0LjcgMTUuOSA0OC4xYTk1IDk1IDAgMCAwLTczLjQtMjkuNCAz'
    b'Mi42IDMyLjYgMCAwIDEgNi44IDguOSA5NSA5NSAwIDAgMSA2OC42IDI5LjQgOTUgOTUgMCAw'
    b'IDAtNjEtMjIuMiA5NSA5NSAwIDAgMC0zNi43IDcuMyA4MS4yIDgxLjIgMCAwIDAgODIuNiA1'
    b'Mi4yYy00LjcuOC05LjUgMS4zLTE0LjQgMS4zYTgwLjggODAuOCAwIDAgMS01Ni40LTIyLjh6'
    b'TTMyMCAzNjQuNGgtNTMuMWExNDMuNSAxNDMuNSAwIDAgMCA1My4xIDEwLjEgMTEgMTEgMCAw'
    b'IDAgMS4zLTUgMTEgMTEgMCAwIDAtMS4zLTUuMXptMC0yNC41aC05My42YTE0My44IDE0My44'
    b'IDAgMCAwIDcuOCA2LjJIMzIwYTQuNiA0LjYgMCAwIDAgMS4zLTMuMSA0IDQgMCAwIDAtMS4z'
    b'LTMuMXptMCAxMi41aC03Ni43YTE0My42IDE0My42IDAgMCAwIDE0LjQgOEgzMjBhNy42IDcu'
    b'NiAwIDAgMCAxLjItNC4yIDcuNSA3LjUgMCAwIDAtMS4yLTMuOHoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNmYmQxMTYiIGQ9Im0yMDAuNSAxNzQuOCAyNS40IDIzLjYtNi43LTM0LTE0LjYgMzEu'
    b'NCAzMC4zLTE2Ljh6bTM2LjktMzIgMzQuNy42LTI3LjctMjEgMTAuMSAzMy4zIDExLjMtMzIu'
    b'OXoiLz4KICA8L2c+CiAgPHVzZSB4bGluazpocmVmPSIjbW8tYSIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEgNjQwIDApIi8+Cjwvc3Zn'
    b'Pgo=', 'MO')

MO = b64_MO
index.append("MO")
index.append("MAC")
index.append("China - Macao")
catalog["MO"] = MO
catalog["MAC"] = MO
catalog["China - Macao"] = MO
country["China - Macao"] = ('MO', 'MAC', 0)
lookup["MO"] = ('MO', 'MAC', 'China - Macao', 0)
lookup["Macao China - Macao"] = ('MO', 'MAC', 'China - Macao', 0)
lookup["MAC"] = ('MO', 'MAC', 'China - Macao', 0)
lookup["China - Macao"] = ('MO', 'MAC', 'China - Macao', 0)
details["MO"] = {"continent":"Asia","capital":"Macao","currency":"Pataca","web":".mo","lang":"zh | zh-MO | pt","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_MP = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1wIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Im1wLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGNsaXAtcGF0aD0idXJsKCNt'
    b'cC1hKSI+CiAgICA8cGF0aCBmaWxsPSIjMDA3MWJjIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0tMTYwIDBoOTYwdjQ4MGgtOTYweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1y'
    b'dWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS45IiBkPSJNMzcw'
    b'IDM2NS43czE1LjItMTYuMSAyOS44LTEzYzQuNC0xNyAyMS0xOC40IDIxLTE4LjRzLTEuNy0x'
    b'OC43IDE5LjUtMjIuOGMuNi0xMi43IDEzLjUtMjMuMyAxMy41LTIzLjNzLTIuNi0xOS43IDEw'
    b'LjgtMjQuM2MtOC4yLTE1LjYgMi44LTI3IDIuNy0yNy4zLS4yLS4zLTE0LTI0LjgtMS42LTMx'
    b'LjgtMTMtMTEtOC44LTIzLjQtOC44LTIzLjRzLTE0LjItMy43LTkuMS0yMC43Yy0xMS43LTIt'
    b'MTQtMjAuOS0xNC0yMC45cy0xOCAzLjctMjAuMi0xMmMtMTIgMS45LTEzLjItOS44LTEzLjQt'
    b'OS44LS4xIDAtMjMuNSA2LjMtMjguMi0xMS40LTkuMSA0LjctMTMtMy43LTEzLTMuN3MtMTMg'
    b'Ni41LTIwLjgtNmMtMTUuNSA5LjctMjQuMi0uNC0yNC4yLS40cy0yMC4zIDEzLjQtMjcgM2Mt'
    b'MTIgMTIuMi0yMi44IDctMjIuOCA3cy05IDE2LTIzLjcgMTJjLTMuMyAxNC45LTIwLjIgMTUu'
    b'Mi0yMC4yIDE1LjJzMS44IDEzLjEtMTguNCAxNi43Yy0yLjYgMTUuNS0xMy4yIDE4LTEzLjIg'
    b'MThzMSAxNS4yLTguNSAyMGMzLjQgOC41LTUuNCAxOC45LTUuNCAxOC45czkuNCAxMS43LTMu'
    b'NCAyNC45YzEyLjMgMy4yIDMuNCAyNC40IDMuNCAyNC40czE3IDcuNiA2LjMgMjEuN2MxMi4y'
    b'IDQgOC40IDEzLjYgOC41IDE5LjMgNy44IDMuNSAxNC42IDEuOCAxMS4zIDE3LjQgMjMuOCAy'
    b'LjcgMTIuNiAxNS44IDEyLjYgMTUuOHMxMSAuNSA2LjcgOS4zYzIwLjMtLjUgMjMuMyAxNS4y'
    b'IDIzLjMgMTUuMnMxOC44LTUgMjEuMyAyLjMtOC4yIDU2LjctOC4yIDU2LjctMTYgMC0yNy44'
    b'LTEyLjhjLTI3LjgtLjctMjEuNi0xOS0yMi0xOS0uNSAwLTkuMyAzLjQtMTMuOC0xMS45LTE4'
    b'LjYgMy44LTE4LTExLjgtMTguMi0xMi0uMS0uMS04LjMtMy44LTUuMy0xMS41LTE5LjEgMS43'
    b'LTE3LjctMTctMTcuNy0xNy00LjItMS43LTUuNy01LjYtNS4xLTkuNS0yLjUtLjktMTkuNS0x'
    b'LjItMTAuNy0yMy42LTE2LjItOS44LTYuMS0yMS02LjEtMjFzLTIyLjQtMTEuNi01LjEtMjVj'
    b'LTEzLTE5IDEtMjguNSAxLTI4LjVzLTE3LjktMTguMS4zLTMxYy0zLTI3LjUgMTMuNC0zNC4x'
    b'IDEzLjQtMzQuMXMtOC42LTIyLjQgMTQuOC0zMS44YzEuNS0yMi43IDE3LjktMjMuMyAxNy45'
    b'LTIzLjNzLjQtMTggMjYuMi0xNi4yYzUtMTYuMSAyMi41LTEyLjkgMjIuNS0xMi45czUuNC0x'
    b'OS41IDI5LjMtMTAuMWMxMi4xLTIzLjcgMzAuMi0xMS42IDMwLjItMTEuNnMxMS40LTcuNCAx'
    b'Ny01YzcuMy0xMi41IDIyLjgtLjYgMzIuNyAxLjkgMy43LTEuNSAxNi42LTExLjIgMjYuNSAx'
    b'IDEzLjItOC41IDI0LjUgNyAyNC41IDdzMTguMS05LjIgMjYuNiAxMS44YzM4LjUtMy41IDMz'
    b'IDIxLjcgMzMgMjEuN3MzMC4yLTYuOSAyMy42IDIzLjNjMjcuNiAxLjkgMjQuOCAyMCAyNC44'
    b'IDIwczE3LjQgMTMuMiA5LjggMjVjMTUuNS44IDkuOCAxNS43IDkuOCAxNS43czExLjkgNC42'
    b'IDIgMjNjMjIuNyAxOC4xIDQuNCAzNi4yIDQuMyAzNi0uMi0uMSAxMi4xIDE0LjYgMSAzMS42'
    b'IDMuNCAyNy0xMC4yIDMzLjgtMTAuMiAzMy44czMuNSAxNy41LTExLjcgMjIuNGMtLjMgMjAu'
    b'NS0xOS43IDIzLTE5LjcgMjNzNS4yIDktMTQgMTguM2MtLjggMTMuNy0yMC44IDE0LjgtMjAu'
    b'OCAxNC44cy0xLjkgMjUuMi0yNy40IDE4LjRjLTYuMSAyMC4yLTM2IDE0LjItMzYuNiAxNC0u'
    b'NS0uMy01LjctNDMuNC01LjctNDMuNXoiLz4KICAgIDxwYXRoIGZpbGw9IiMyMTc5MDAiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5k'
    b'IiBzdHJva2Utd2lkdGg9IjEuOSIgZD0iTTE4NSAxMjRzNi40IDUuNiA1LjIgMTRjLTEuMiA4'
    b'LjMtNiAxOS45LTUgMjguNS42IDMuNS4zIDkuNy4zIDkuN3MtNS43LTguMi01LjgtMTcgNi4y'
    b'LTE3LjEgNi4yLTIzLjYtMS4xLTExLjctMS0xMS41em0tMy4yIDIuNnMtOC40IDgtOS41IDE1'
    b'LjdjLS44IDQtMSAyMi43LTEuMiAzMS0uMiAyLjUtMS4yIDEyLjUtMS40IDE2LjItLjMgMy42'
    b'IDYuMS02LjIgNi41LTE0LjMtLjItOC4zLS4yLTI1LjguNi0yOC41LjgtMy40LjYtNy4xIDEu'
    b'OC0xMC41bDMuMi05LjZ6Ii8+CiAgICA8ZyBmaWxsPSIjZmZkMjAwIiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iI2VmOGExMCI+CiAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS45'
    b'IiBkPSJNMzY2IDEwMC41czEwLjgtNSAxNC0xNC40LTkuNS05LjQtMTEuMS02LjRjLTEuNyAz'
    b'IDEuNCAxMC4zLjYgMTIuMy0uOCAyLTUuMiA2LjYtMy41IDguNHoiLz4KICAgICAgPHBhdGgg'
    b'c3Ryb2tlLXdpZHRoPSIyLjUiIGQ9Ik0yNjkuOCAxMDMuOXM3LTkuNyA1LjItMTkuNGMtMS45'
    b'LTkuNi0xMi44LTMuNi0xMi44LS4yczYuMiA4LjMgNi41IDEwLjRjLjMgMi4xLTEuMyA4LjQg'
    b'MSA5LjF6bS0xOS4xIDUuN3M3LTkuNyA1LjItMTkuM2MtMS44LTkuNy0xMi44LTMuNy0xMi44'
    b'LS4zIDAgMy40IDYuMyA4LjQgNi42IDEwLjUuMiAyLTEuMyA4LjMgMSA5LjF6bS0yMS4xIDYu'
    b'NXM3LTkuNiA1LjItMTkuM2MtMS45LTkuNy0xMi44LTMuNy0xMi44LS4zIDAgMy40IDYuMiA4'
    b'LjQgNi41IDEwLjUuMyAyLTEuMyA4LjMgMSA5LjF6bS0xNSAxNC45czcuMS05LjcgNS4zLTE5'
    b'LjNjLTEuOC05LjctMTIuOC0zLjctMTIuOC0uMyAwIDMuNCA2LjMgOC40IDYuNSAxMC41LjMg'
    b'Mi0xLjMgOC4zIDEgOS4xek0xOTkgMTQ1LjRzNy05LjcgNS4yLTE5LjQtMTIuOC0zLjYtMTIu'
    b'OC0uMiA2LjMgOC4zIDYuNiAxMC40Yy4yIDIuMS0xLjMgOC40IDEgOS4yeiIvPgogICAgICA8'
    b'cGF0aCBzdHJva2Utd2lkdGg9IjEuOSIgZD0iTTIzNSA2MS43cy05LjQgNy40LTEwLjIgMTcu'
    b'MmMtLjggOS44IDExLjMgNyAxMi4yIDMuNyAxLTMuMy0zLjctOS43LTMuNC0xMS44LjMtMiAz'
    b'LjUtNy43IDEuNC05em0zMS4zLTkuNnMtOS4zIDcuNC0xMC4yIDE3LjJjLS44IDkuOCAxMS4z'
    b'IDcgMTIuMyAzLjcuOS0zLjMtMy44LTkuOC0zLjUtMTEuOS4zLTIgMy41LTcuNyAxLjQtOXpt'
    b'LTExNi43IDg0LjVzMiAxMS44IDEwLjIgMTcuM2M4LjIgNS40IDExLjUtNi42IDkuMS05cy0x'
    b'MC4zLTEuNC0xMi0yLjZjLTEuNy0xLjMtNS02LjgtNy4zLTUuN3ptLTE1LjYgNDBzMCAxMiA3'
    b'LjMgMTguN2M3LjIgNi42IDEyLjQtNC43IDEwLjQtNy40cy0xMC0zLTExLjQtNC41Yy0xLjUt'
    b'MS42LTQtNy41LTYuMy02Ljd6bTM2IDQ0LjhzLTQuMi0xMS4yLTEzLjMtMTVjLTkuMS0zLjYt'
    b'MTAgOC44LTcuMiAxMC43IDIuOSAxLjggMTAuNC0uNyAxMi4zLjIgMiAuOSA2LjMgNS42IDgu'
    b'MyA0em0tNy40LTE5LjRzNy4yLTkuNSA1LjYtMTkuMWMtMS43LTkuNy0xMi43LTQtMTIuOC0u'
    b'NiAwIDMuNCA2IDguNSA2LjMgMTAuNi4yIDIuMS0xLjUgOC4zLjkgOS4yem0yMjUuNi05MS45'
    b'czEwLjgtNSAxNC0xNC4zLTkuNS05LjQtMTEuMS02LjVjLTEuNyAzIDEuNCAxMC40LjYgMTIu'
    b'My0uOCAyLTUuMiA2LjctMy41IDguNXptMzIuOCAxNi40czYuNC0xMC4xIDMuOS0xOS42Yy0y'
    b'LjUtOS41LTEzLTIuOC0xMi44LjYuMiAzLjMgNi44IDcuOSA3LjIgMTAgLjQgMi0uNyA4LjQg'
    b'MS43IDl6bTg5LjYgOTNzLTQuMy0xMS4xLTEzLjQtMTQuOWMtOS4xLTMuNy0xMCA4LjgtNy4y'
    b'IDEwLjYgMi45IDEuOSAxMC41LS43IDEyLjMuMiAyIDEgNi4zIDUuNyA4LjMgNC4xem0tNDMu'
    b'OCA3cy4yLTEyIDcuNS0xOC42YzcuMy02LjYgMTIuNCA0LjkgMTAuNCA3LjYtMi4xIDIuNy0x'
    b'MCAyLjgtMTEuNiA0LjMtMS40IDEuNS00IDcuNC02LjMgNi42em0tNy0xMjYuOHMtMTEuMy00'
    b'LjMtMjAgMGMtOSA0LjQtLjIgMTMuNCAzIDEyLjUgMy4zLTEgNi40LTguMyA4LjQtOS4xIDIt'
    b'LjggOC40LTEgOC41LTMuNHpNNDM0IDc4LjNzLTExLjEtNC4zLTIwIDBjLTguOCA0LjQtLjEg'
    b'MTMuNCAzLjIgMTIuNSAzLjItMSA2LjQtOC4zIDguMy05LjEgMi0uOCA4LjQtMSA4LjUtMy40'
    b'em0tMzgtMjAuNHMtOS41IDcuMy0xMC40IDE3Yy0xIDkuOCAxMS4yIDcuMSAxMi4yIDMuOSAx'
    b'LTMuMy0zLjctOS44LTMuNC0xMS45LjQtMiAzLjYtNy42IDEuNi05em0tMjQuOC02cy00LjQg'
    b'MTEuMS0uMSAyMGM0LjMgOC45IDEzLjMuMiAxMi40LTMtLjktMy4zLTguMi02LjUtOS04LjQt'
    b'LjgtMi0uOS04LjUtMy4zLTguNnptLTcwLjUgNDNzNy43LTkuMiA2LjYtMTljLTEuMS05Ljct'
    b'MTIuNS00LjUtMTIuNy0xLjEtLjMgMy40IDUuNiA4LjggNS43IDEwLjkuMSAyLTEuOSA4LjIu'
    b'NCA5LjF6Ii8+CiAgICA8L2c+CiAgICA8cGF0aCBmaWxsPSIjOGM4YThjIiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjkiIGQ9Ik0zNDIuOCAx'
    b'MTQuNHMxOC41IDEuMiAxOS40IDExLjgtNC40IDE3LjEtNC40IDE3LjEgMi4zIDIzLTE1Ljgg'
    b'MjkuN2MtMTkuNCAyLjMtNDkuOS41LTQ5LjkuNXMtOSAyLjItMTIuNi0xNi4zYTMwNSAzMDUg'
    b'MCAwIDEtNC42LTMxLjZzMS44LTEwLjQgMTQuOS0xMWMxMy0uNyA1Mi44IDAgNTMtLjJ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lY2FwPSJy'
    b'b3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjkiIGQ9Ik0zNTcuNyAxNDMuMnMtMTAgMTIuNC05IDE3'
    b'LjUiLz4KICAgIDxwYXRoIGZpbGw9IiM4YzhhOGMiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuOSIgZD0iTTM0NC4zIDE3Mi4zYzIuNSAyLjEg'
    b'NC44IDQuNCA1LjMgMTJsMSAxNS40IDEzIDExNi42IDExLjQgODQuMy44IDEzcy0yLjcgOS43'
    b'LTEwLjQgMTAuNWMtNS41IDExLjYtMzUuNyAxNS0zOC43IDE0LjktMi43LS4yLTEyLjMtNC4y'
    b'LTE4LjEtMy43LTUuOS41LTE2IDQuNC0yMC41IDMuOC00LjUtLjctMTQuOC00LjItMTYuNi0x'
    b'MS42LTEyLjctNC0xNC43LTEzLjctMTQuNy0xMy43bDEzLjctOTcuNSAxMy4zLTEyMy40czEu'
    b'Ni0xNi40IDguMi0xOC45YzYuOS0uNiA0Mi40LjcgNTIuMy0xLjd6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS45IiBkPSJtMjc0LjQg'
    b'MzQxLjEtMi43IDg2LjNtODYuNS03NC45IDcuNiA3MS4yIi8+CiAgICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIGQ9Im0xMzYuNiAyOTYuMy0uMyAxbTM1OC43LTQuMS4zIDEi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzZiMThiNSIgc3Ryb2tlLWxpbmVq'
    b'b2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjkiIGQ9Ik0xMjcgMTc5LjhzNS42IDcuOSA2'
    b'LjcgMTIuNGMxIDQuNSAyLjkgMTMuNCA1LjMgMTcgMi41IDMuNyAxNi42IDIzLjkgMTcuNCAz'
    b'Mi4zLjEgNS42LTUuOSAxNS0xNC43IDE1LjItNS42LS4yLTE5LjgtMy44LTIwLjQtMTYtLjYt'
    b'MTIuMyA0LjMtMTIuNSA1LTIwIC41LTcuNC43LTQwLjcuNy00MC45eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjNmIxOGI1IiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBk'
    b'PSJNMjI0LjUgNzIuOHMtNiAuNC0xMC40IDIuOWMtMy41IDIuMS05LjUgNS4zLTEzLjYgMTEt'
    b'MTAuNiA4LjItMjYuNSAxMi0zMS41IDE5LTMgNC42LTIuOCAxNS43IDQuNyAyMC41IDQuOCAy'
    b'LjcgMTkgNyAyNS44LTMuMSA2LjgtMTAuMiAyLjctMTMgNi0xOS42YTExNy40IDExNy40IDAg'
    b'MCAxIDE5LTMwLjd6TTM2NyA1OHMtNC40LTQtOS4zLTUuNWMtNC0xLTEwLjYtLjYtMTcuNS0x'
    b'LjMtMTMuMy0xLjgtMjctMTEuNC0zNS4zLTEwLjItNS40IDEtMTMuMyA5LTExLjUgMTcuNiAx'
    b'LjMgNS40IDcuMyAxNi4yIDE5LjQgMTQuMSAxMi0yLjEgMTItNC44IDE5LTcgMTcuNC05Ljcg'
    b'MzUtNy43IDM1LjItNy43em0xNDEuNCAxMzcuNGMxLTIuMy0uOS02LjYtMi4yLTExLjUtMS4y'
    b'LTQtMy4xLTEwLTcuNy0xNS41LTUuNC0xMi4yLTQuNS0yOS0xMC0zNS40LTMuNy00LTE0LjYt'
    b'Ni42LTIxLS40LTMuOSA0LTExLjQgMTYuNi0zLjIgMjUuNyA4LjIgOSAxMS44IDUuNyAxNy40'
    b'IDEwLjUgMTMuNSA5IDIwIDI1IDI2LjcgMjYuNnpNNTAzLjUgMzAyYzEuOS0yLjUgNS4yLTcu'
    b'NCA0LjgtMTEuNS0uMy0zLjIgMS41LTEzIDEuNy0xNy4zIDEuMi0xMy4zIDkuNS0yNC4yIDcu'
    b'Mi0zNS43LTEuMy01LjQtOS4yLTEzLTE3LjgtMTAuOC01LjIgMS42LTE3IDgtMTQuMyAyMCAy'
    b'LjcgMTIgNi42IDExLjcgOS4xIDE4LjcgNy4zIDE0LjUgMi43IDMxLjcgOS4zIDM2LjZ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS45'
    b'IiBkPSJNNDA1LjUgMzg2LjhzLTIuMyA0LjQgNi44IDguMm0xMS4zLTE4LjRzMTAtMi41IDE2'
    b'LjggMG0xMy4yLTI1LjRjMCAuMi0xLjQgNC41IDYuNiAxMC44bS0uOC0yMnM1LjkgNC4zIDE1'
    b'LjggNG0tNzUuNCA4LjZzLjMgMTEuNS01LjYgMTYuOG0yNS40LTM0LjVzOS43IDIuNCAxNy43'
    b'LTEuNm00NC42LTE1LjNzMi4xIDMgMTIuOSAyLjVtLTU0LjktOS4zYy4zLjIgMTIuNyA0LjIg'
    b'MjAuNS42bTQuMi00Ny44cy41LS43IDQuMyAxMi43bTUuMi01MC40cy0uNSA3LjEtNi4yIDEw'
    b'LjJtNDIuOS0zOS40cy04LjQgNi44LTYuOCA5LjVtLTM0LjctMTQuNHM0LjMgNy4zLTIuOCAx'
    b'Mi4zTTQ0OC4yIDE2MXM3LjUtLjMgMTAuOCA2LjFtLTI0LjgtMjcuM2g1LjdtMjQtMjZjMCAu'
    b'MSAxLjUgMS41LTEuNCA0LjVtLTUyLTMuOHM0IDYuMiAzLjMgMTMuOW0xOS44LTM1LjFjMS44'
    b'LS4yIDcuNy0yLjggNy43LTIuOG0tMzMuNC0yMmMtLjEgMC0yLjIgNy43IDEuNiAxMC41bS0x'
    b'MS4xIDI1YzAgOC40IDYuNiA2LjMgMiAxNC4zTTM4Mi4yIDk3YTU3IDU3IDAgMCAwLTEwLjQg'
    b'OS40bS0xNi40LTEzLjdzNC40IDQuMyAzLjMgMTAuMm0tMTYtMTMuN3MtMi4yIDYuNi01LjEg'
    b'OC4zbS0xOC0xMGMtLjEuMy0zLjYgNy44LTYgOS4xbS0yNS42LTljLjIgMCAzLjUgNy0uOCAx'
    b'Mm0tNi41LTQ4Yy4yLjIuNyA1LjQtMi42IDEwbS0yOC43IDEuOWMwIC4xIDEuNCA1LjktNy44'
    b'IDcuOG0tOS45IDQ1LjJjLjIuMyA4LjkgMS43IDguOSAxLjdNMjEwIDEzNi42Yy4yLS4yIDEw'
    b'LjYtMy4zIDEwLjYtMy4zbS0yNy40IDE2LjNjLjMgMCA3LjMgMS4zIDkgLjRtLTE0IDZzMi4z'
    b'IDEuMy40IDEzbS0zNC4yLTQzLjUgNC4yIDYuMm0tMTguNSAyNmMwLS4yIDQuMiA2LjIgOS44'
    b'IDcuNG0yMyAyNS4yYTQ5IDQ5IDAgMCAwIDgtMk0xNzAgMjEzLjhjLjIgMC0uMS00LjMgNS4y'
    b'LTcuM00xNjMgMjI0LjdjMCAuMiA1IDYuNCA4LjUgNy4zbS0xMS41IDQuN2MuNi0uMiA2LTQu'
    b'OSAxMi4yLTQuNW0tMTMuOSAyMC42cy4yIDUuNCAxNi4yIDRtLTE0LjYgMTVjMC0uMiA0Ljct'
    b'MTAuOCAxNC4yLTE0LjhtLTEuNCAyOC40czEuNC00LjYgOS40LTcuN20tLjUgMjUuNXM1Ljct'
    b'NC43IDcuOC01LjNtLS43IDE5LjNzMy41IDMuNiAxMi4yLTIuN20tNTQgNS42YzEtLjIgMTMu'
    b'Ny0zLjEgMTggMy41bS0xMyA3czEzLjQtMS44IDE1LjEtLjRtMzIuNyAzLjFzLTEuOCAzLjcg'
    b'MTQuNy0yLjRtNS44IDljLTMgNSAuNyA5LTMuMiAxMS4zbS00Ny00LjNjLjUtLjQgNi0yLjMg'
    b'NS4yLTEwLjNtLS4yIDIyLjNjLjctLjIgOS45LTQuMiAxMS44LTIuMW02LjMgMTMuN3MxLjIt'
    b'OC4yIDMuOC05bTEwIDIxLjNzNy43LS4xIDExLTIuNm0zLjgtMjVjLjIuMiA3LjEgMy44IDIy'
    b'IC4ybS0xNi40IDMzczIgMTAuNiAyIDEzIi8+CiAgICA8ZyBmaWxsPSIjZGUyMDEwIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiPgogICAg'
    b'ICA8cGF0aCBkPSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAw'
    b'cy0yLjEgMy0yLjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjIt'
    b'MyAyLjEtNXoiIHRyYW5zZm9ybT0ibWF0cml4KDEuNjA4ODUgLS4yMDExIC4yMDcyIDEuNjU3'
    b'NjIgOTQuOCA3NSkiLz4KICAgICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUt'
    b'MS40LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAx'
    b'LjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjYwODg1'
    b'IC0uMjAxMSAuMjA3MiAxLjY1NzYyIDkzLjQgNTcuMykiLz4KICAgICAgPHBhdGggZD0iTTIz'
    b'Mi44IDExOWMwLTItLjgtNC0yLTUtMS40LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVj'
    b'MCAyLjEuOCA0IDIgNS4xIDEuNCAxLjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCgxLjU4NDk3IC0uMzQxNyAuMzUyMDYgMS42MzMgNzggNzQpIi8+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik0yMzIuOCAxMTljMC0yLS44LTQtMi01LTEuNC0xLjEtMy0xLjEtNC4y'
    b'IDBzLTIuMSAzLTIuMSA1YzAgMi4xLjggNCAyIDUuMSAxLjQgMS4xIDMgMS4xIDQuMiAwczIu'
    b'Mi0zIDIuMS01eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS40NDU1IC0uNzM0NDYgLjc1NjcgMS40'
    b'ODkzIDU1LjkgMTYzKSIvPgogICAgICA8cGF0aCBkPSJNMjMyLjggMTE5YzAtMi0uOC00LTIt'
    b'NS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEgMy0yLjEgNWMwIDIuMS44IDQgMiA1LjEgMS40'
    b'IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEtNXoiIHRyYW5zZm9ybT0ibWF0cml4KDEuNDQ1'
    b'NSAtLjczNDQ2IC43NTY3IDEuNDg5MyA0OC45IDE0Ny4xKSIvPgogICAgICA8cGF0aCBkPSJN'
    b'MjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEgMy0yLjEg'
    b'NWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEtNXoiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KDEuMzc4MSAtLjg1NDIzIC44ODAxMSAxLjQxOTg3IDQwIDE2Ny40'
    b'KSIvPgogICAgICA8cGF0aCBkPSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMt'
    b'MS4xLTQuMiAwcy0yLjEgMy0yLjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0'
    b'LjIgMHMyLjItMyAyLjEtNXoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMjg5MDcgLS45ODM0NiAx'
    b'LjAxMzI3IDEuMzI4MTIgMzMuOCAxOTMpIi8+CiAgICAgIDxwYXRoIGQ9Ik0yMzIuOCAxMTlj'
    b'MC0yLS44LTQtMi01LTEuNC0xLjEtMy0xLjEtNC4yIDBzLTIuMSAzLTIuMSA1YzAgMi4xLjgg'
    b'NCAyIDUuMSAxLjQgMS4xIDMgMS4xIDQuMiAwczIuMi0zIDIuMS01eiIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoMS4xMzI5IC0xLjE1OTk0IDEuMTk1MDggMS4xNjcyMiAzNS4zIDIzOSkiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUtMS40LTEuMS0zLTEuMS00LjIg'
    b'MHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAxLjEgMyAxLjEgNC4yIDBzMi4y'
    b'LTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjAyMTM4IC0xLjI1OTIyIDEuMjk3Mzkg'
    b'MS4wNTIzNCAzNC4zIDI2Mi43KSIvPgogICAgICA8cGF0aCBkPSJNMjMyLjggMTE5YzAtMi0u'
    b'OC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEgMy0yLjEgNWMwIDIuMS44IDQgMiA1'
    b'LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEtNXoiIHRyYW5zZm9ybT0ibWF0cml4'
    b'KC43OTgxNyAtMS40MTEzMiAxLjQ1NDA4IC44MjIzNiA1MS45IDMxNSkiLz4KICAgICAgPHBh'
    b'dGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUtMS40LTEuMS0zLTEuMS00LjIgMHMtMi4x'
    b'IDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAxLjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4x'
    b'LTV6IiB0cmFuc2Zvcm09Im1hdHJpeCguNjY2NDIgLTEuNDc4MSAxLjUyMjg5IC42ODY2IDU2'
    b'LjggMzM3LjQpIi8+CiAgICAgIDxwYXRoIGQ9Ik0yMzIuOCAxMTljMC0yLS44LTQtMi01LTEu'
    b'NC0xLjEtMy0xLjEtNC4yIDBzLTIuMSAzLTIuMSA1YzAgMi4xLjggNCAyIDUuMSAxLjQgMS4x'
    b'IDMgMS4xIDQuMiAwczIuMi0zIDIuMS01eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjU2NTgyIC0x'
    b'LjUxOTQ1IDEuNTY1NSAuNTgyOTYgNTcuOSAzNTIuNCkiLz4KICAgICAgPHBhdGggZD0iTTIz'
    b'Mi44IDExOWMwLTItLjgtNC0yLTUtMS40LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVj'
    b'MCAyLjEuOCA0IDIgNS4xIDEuNCAxLjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCguNDQ4MiAtMS41NTgyIDEuNjA1NDMgLjQ2MTc4IDYzIDM3MC40KSIv'
    b'PgogICAgICA8cGF0aCBkPSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMtMS4x'
    b'LTQuMiAwcy0yLjEgMy0yLjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0LjIg'
    b'MHMyLjItMyAyLjEtNXoiIHRyYW5zZm9ybT0ibWF0cml4KC4yMDI4OCAtMS42MDg2NCAxLjY1'
    b'NzM4IC4yMDkwMyA5NC43IDQwOC45KSIvPgogICAgICA8cGF0aCBkPSJNMjMyLjggMTE5YzAt'
    b'Mi0uOC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEgMy0yLjEgNWMwIDIuMS44IDQg'
    b'MiA1LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEtNXoiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC4wNjUwNiAtMS42MjAwOCAxLjY2OTE4IC4wNjcwMyAxMDYuMyA0MjcuNCkiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUtMS40LTEuMS0zLTEuMS00LjIg'
    b'MHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAxLjEgMyAxLjEgNC4yIDBzMi4y'
    b'LTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCguMDY1MDYgLTEuNjIwMDggMS42NjkxOCAu'
    b'MDY3MDMgODguOCA0MjgpIi8+CiAgICAgIDxwYXRoIGQ9Ik0yMzIuOCAxMTljMC0yLS44LTQt'
    b'Mi01LTEuNC0xLjEtMy0xLjEtNC4yIDBzLTIuMSAzLTIuMSA1YzAgMi4xLjggNCAyIDUuMSAx'
    b'LjQgMS4xIDMgMS4xIDQuMiAwczIuMi0zIDIuMS01eiIgdHJhbnNmb3JtPSJtYXRyaXgoLS4z'
    b'NjEzMiAtMS41ODA2IDEuNjI4NTIgLS4zNzIyNiAxNzIuNSA0NzMuNSkiLz4KICAgICAgPHBh'
    b'dGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUtMS40LTEuMS0zLTEuMS00LjIgMHMtMi4x'
    b'IDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAxLjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4x'
    b'LTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjQ5MDQ1IC0xLjU0NTQyIDEuNTkyMjcgLS41MDUz'
    b'MSAxODguMyA0ODUuOCkiLz4KICAgICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0y'
    b'LTUtMS40LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEu'
    b'NCAxLjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjY3'
    b'MTAzIC0xLjQ3NiAxLjUyMDczIC0uNjkxMzggMjIxLjkgNDk5LjEpIi8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0yMzIuOCAxMTljMC0yLS44LTQtMi01LTEuNC0xLjEtMy0xLjEtNC4yIDBzLTIuMSAz'
    b'LTIuMSA1YzAgMi4xLjggNCAyIDUuMSAxLjQgMS4xIDMgMS4xIDQuMiAwczIuMi0zIDIuMS01'
    b'eiIgdHJhbnNmb3JtPSJtYXRyaXgoLS43OTQ1IC0xLjQxMzM3IDEuNDU2MiAtLjgxODU4IDI0'
    b'MS40IDUwOC4zKSIvPgogICAgICA8cGF0aCBkPSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0x'
    b'LjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEgMy0yLjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEu'
    b'MSAzIDEuMSA0LjIgMHMyLjItMyAyLjEtNXoiIHRyYW5zZm9ybT0ibWF0cml4KC0uOTQzMzkg'
    b'LTEuMzE4NjcgMS4zNTg2MyAtLjk3MTk3IDI3MS42IDUxNS40KSIvPgogICAgICA8cGF0aCBk'
    b'PSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEgMy0y'
    b'LjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEtNXoi'
    b'IHRyYW5zZm9ybT0ibWF0cml4KC0xLjA1MTU5IC0xLjIzNDEgMS4yNzE1MSAtMS4wODM0NCAy'
    b'OTIuNCA1MjAuMikiLz4KICAgICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUt'
    b'MS40LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAx'
    b'LjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS4xMzcz'
    b'NyAtMS4xNTU1MyAxLjE5MDU2IC0xLjE3MTgzIDMwOC45IDUyNi4xKSIvPgogICAgICA8cGF0'
    b'aCBkPSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEg'
    b'My0yLjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEt'
    b'NXoiIHRyYW5zZm9ybT0ibWF0cml4KC0xLjIzMDEgLTEuMDU2MjggMS4wODgyOSAtMS4yNjcz'
    b'OCAzMzEuNCA1MjkuNikiLz4KICAgICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0y'
    b'LTUtMS40LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEu'
    b'NCAxLjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS4z'
    b'MzU3MyAtLjkxOTA4IC45NDY5MyAtMS4zNzYyIDM2Mi41IDUyNi4xKSIvPgogICAgICA8cGF0'
    b'aCBkPSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEg'
    b'My0yLjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEt'
    b'NXoiIHRyYW5zZm9ybT0ibWF0cml4KC0xLjQ3Mzc0IC0uNjc1OTcgLjY5NjQ1IC0xLjUxODQx'
    b'IDQxNS45IDUwNCkiLz4KICAgICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUt'
    b'MS40LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAx'
    b'LjEgMyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS41Mjg5'
    b'NSAtLjUzOTU4IC41NTU5MyAtMS41NzUzIDQzOC43IDQ5Ny41KSIvPgogICAgICA8cGF0aCBk'
    b'PSJNMjMyLjggMTE5YzAtMi0uOC00LTItNS0xLjQtMS4xLTMtMS4xLTQuMiAwcy0yLjEgMy0y'
    b'LjEgNWMwIDIuMS44IDQgMiA1LjEgMS40IDEuMSAzIDEuMSA0LjIgMHMyLjItMyAyLjEtNXoi'
    b'IHRyYW5zZm9ybT0ibWF0cml4KC0xLjYxNDQ1IC0uMTIwMDUgLjE1NDI5IC0xLjMzMzQ0IDUw'
    b'MC41IDQwNikiLz4KICAgICAgPHBhdGggZD0iTTIzMi44IDExOWMwLTItLjgtNC0yLTUtMS40'
    b'LTEuMS0zLTEuMS00LjIgMHMtMi4xIDMtMi4xIDVjMCAyLjEuOCA0IDIgNS4xIDEuNCAxLjEg'
    b'MyAxLjEgNC4yIDBzMi4yLTMgMi4xLTV6IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS41ODA4MiAt'
    b'LjM2MDM1IC4zNzEyNSAtMS42Mjg3MyA0NjguNCA0ODAuOCkiLz4KICAgIDwvZz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmUzMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTQ4MCAxOTQuN2My'
    b'LjItMi4zIDQuMi0zIDYuNy0yLjEtMS02LjEtMi44LTguMi01LjItNy40LTIuMy43LTMuNCAz'
    b'LjgtMS41IDkuNXptMy4zIDE4LjJjMi4zLTIuMSA0LjMtMi42IDYuOC0xLjYtLjQtNi0yLjIt'
    b'OC4zLTQuNi03LjctMi40LjUtMy42IDMuNi0yLjIgOS4zem0tNy44LTM1YzEuNS0yLjcgMy4z'
    b'LTMuOCA2LTMuNy0yLjUtNS42LTQuOC03LjEtNy01LjgtMiAxLjMtMi4yIDQuNiAxIDkuNnpt'
    b'LTguMS0xNi42YzEuNS0yLjggMy4zLTMuOSA2LTMuNy0yLjUtNS43LTQuOS03LjItNy01Ljkt'
    b'MiAxLjMtMi4yIDQuNiAxIDkuNnptLTE5LjUtMzAuNWMxLTMgMi42LTQuNCA1LjItNC42LTMu'
    b'My01LjItNS45LTYuMy03LjctNC43cy0xLjUgNSAyLjUgOS4zek00MzUgMTE3LjVjMS0zIDIu'
    b'NC00LjQgNS00LjgtMy40LTUtNi02LTcuOC00LjQtMS44IDEuNy0xLjQgNSAyLjggOS4yek00'
    b'MDguMyA5NWMwLTMuMiAxLTUgMy4zLTYuMi00LjgtMy43LTcuNy0zLjgtOC44LTEuN3MuMiA1'
    b'LjEgNS41IDcuOXptMTQgMTAuNWMuNC0zLjEgMS43LTQuOCA0LjMtNS41LTQuMi00LjUtNi45'
    b'LTUuMi04LjQtMy4zLTEuNSAyLS43IDUuMSA0IDguOHptLTMwLTE5LjNjLS4zLTMuMS41LTUg'
    b'Mi43LTYuNS01LjItMy4yLTgtMy05LS44LS45IDIuMy44IDUuMSA2LjQgNy4zek0zNzYuMiA3'
    b'OWMtLjgtMy0uMy01IDEuNy02LjgtNS42LTIuNC04LjQtMS45LTkgLjUtLjYgMi40IDEuNSA0'
    b'LjkgNy4zIDYuM3ptLTE3LjUtNS40Yy0xLjEtMy0uOC01IDEuMS03LTUuOC0xLjktOC41LTEu'
    b'MS05IDEuMy0uMyAyLjQgMiA0LjggNy45IDUuN3ptLTE3LjMtMy40Yy0xLjItMi44LTEtNSAu'
    b'Ny03LTYtMS41LTguNi0uNS04LjggMi0uMyAyLjQgMi4yIDQuNiA4LjEgNXptLTE4LjItMS40'
    b'Yy0xLjYtMi43LTEuNi00LjggMC03LTYuMS0uOS04LjcuNC04LjYgMi44IDAgMi41IDIuNyA0'
    b'LjQgOC42IDQuMnptLTM1LjcgMi43Yy0yLjItMi4yLTIuNy00LjMtMS44LTYuOC02IC42LTgu'
    b'MiAyLjQtNy42IDQuOC42IDIuNCAzLjcgMy42IDkuNCAyem0xNy42LTIuM2MtMS45LTIuNS0y'
    b'LjItNC42LS45LTctNi4xLS4yLTguNSAxLjMtOC4yIDMuOC4zIDIuNCAzLjIgNCA5IDMuMnpt'
    b'LTM0LjkgNmMtMi40LTEuOS0zLjMtMy44LTIuNy02LjQtNiAxLjUtNy44IDMuNi02LjkgNS44'
    b'IDEgMi4zIDQuMiAzIDkuNi42em0tMzMgMTUuMmMtMi44LTEuNC00LTMuMS0zLjktNS44LTUu'
    b'NiAyLjYtNyA1LTUuNiA3IDEuMyAyIDQuNiAyLjIgOS41LTEuMnptMTYtOC4xYy0yLjctMS43'
    b'LTMuNi0zLjYtMy4yLTYuMi01LjkgMS44LTcuNiA0LTYuNSA2LjIgMS4xIDIuMiA0LjQgMi44'
    b'IDkuNiAwem0tNDUuNiAyOC44Yy0zLS44LTQuNi0yLjMtNS01LTUgMy44LTUuOCA2LjQtNC4x'
    b'IDguMSAxLjggMS43IDUgMS4yIDktMy4xem0xNC4xLTExLjZjLTMtMS00LjQtMi42LTQuNi01'
    b'LjItNS4yIDMuMi02LjMgNS44LTQuNyA3LjcgMS42IDEuOCA1IDEuNSA5LjMtMi41em0tMjYu'
    b'NyAyNGMtMy0uNi00LjctMS45LTUuNC00LjUtNC42IDQuMS01LjIgNi45LTMuMyA4LjQgMS45'
    b'IDEuNiA1IC43IDguNy00ek0xODMuNyAxMzhjLTMuMi0uMi01LTEuMy01LjgtMy44LTQuMiA0'
    b'LjUtNC42IDcuMi0yLjYgOC42IDIgMS40IDUuMS4yIDguNC00Ljh6bS05LjQgMTVjLTMuMi4y'
    b'LTUtLjctNi40LTMtMy40IDUuMS0zLjQgOC0xLjIgOXM1LjEtLjYgNy42LTZ6bS04LjMgMTZj'
    b'LTMgLjYtNSAwLTYuNy0yLjItMi43IDUuNS0yLjMgOC4zIDAgOSAyLjMuOCA1LTEuMiA2Ljct'
    b'Ni45em0tNi42IDE2LjNjLTMgMS4xLTUgLjgtNy0xLTEuOCA1LjgtMSA4LjUgMS41IDguOSAy'
    b'LjQuMyA0LjctMiA1LjUtOHptLTQuNSAxOC4yYy0yLjggMS4zLTQuOSAxLjItNy0uNS0xLjQg'
    b'Ni0uNCA4LjUgMiA4LjcgMi41LjMgNC43LTIuMiA1LTguMnptLTEuOCAxNS4yYy0yLjYgMS40'
    b'LTQuNyAxLjYtNyAuNS0uNyA0LjkuNiA2LjggMyA2LjYgMi40LS4yIDQuMy0yLjQgNC03LjF6'
    b'bTMwNy03Mi4yYzEuMS0zIDIuNy00LjQgNS4zLTQuNi0zLjItNS4yLTUuNy02LjMtNy42LTQu'
    b'OC0xLjkgMS42LTEuNiA1IDIuMyA5LjR6bTI1LjIgODVjMi4zLTIuMiA0LjQtMi43IDYuOC0x'
    b'LjYtLjQtNi4xLTIuMi04LjMtNC42LTcuOC0yLjMuNi0zLjYgMy42LTIuMiA5LjR6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjMjE3OTAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjkiIGQ9Ik00NjEu'
    b'MyAxMzJzLTcgNi45LTUuNyAxNS4yYzEuMiA4LjMgNi41IDE4LjYgNS41IDI3LjMtMSA4LjYt'
    b'Mi41IDE0LjMtMi41IDE0LjNzOC05LjEgOC0xOGMuMi04LjctNS40LTIwLjMtNS40LTI2Ljdz'
    b'LjMtMTIuMi4xLTEyem0xMi43IDI4cy01LjMgNC00LjggMTNjLjUgOS4xIDEwIDI1LjggMTAg'
    b'MjUuOHM2LjggMTQgNi41IDE3LjdjLS4yIDMuNyAxLjMtMy41LjYtMTEuNXMtMTEtMjUuOC0x'
    b'MS0yNS44LTIuMi0zLjYtMi05LjdjLjItNiAuOC05LjQuOC05LjV6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjNmIxOGI1IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zMTMgNDcuNGMwLTEuOC0y'
    b'LjItMy40LTQuOC0zLjRzLTQuNyAxLjYtNC43IDMuNCAyIDMuNCA0LjcgMy40IDQuNy0xLjUg'
    b'NC43LTMuNHptMiA4YzAtMS44LTIuMi0zLjMtNS0zLjMtMi42IDAtNC44IDEuNC00LjggMy4y'
    b'czIuMiAzLjMgNC45IDMuMyA0LjgtMS41IDQuOC0zLjN6bTYtOS40cy01LjYgNC4xLTMuMyA1'
    b'LjhjMi4zIDEuNyA4LjYtMy42IDguNi0zLjZMMzIxIDQ2em0xNjMuMyA5NS40YzAtMS4yLS41'
    b'LTIuMy0xLjQtMi45YTIuNiAyLjYgMCAwIDAtMyAwYy0uOS42LTEuNCAxLjctMS40IDIuOXMu'
    b'NSAyLjMgMS40IDIuOWEyLjYgMi42IDAgMCAwIDMgMGMuOS0uNiAxLjQtMS43IDEuNC0yLjl6'
    b'bS0yLjEtOGMwLTItMS40LTMuNS0zLTMuNXMtMy4xIDEuNi0zLjEgMy42IDEuNCAzLjUgMyAz'
    b'LjUgMy4xLTEuNiAzLjEtMy41em0xLjUgMTYuMmMwLTEtLjYtMS44LTEuMi0xLjhzLTEuMi44'
    b'LTEuMiAxLjguNSAxLjkgMS4yIDEuOSAxLjItLjkgMS4yLTEuOXptNC45LTE0LjRjMC0xLjIt'
    b'LjYtMi4xLTEuMi0yLjEtLjcgMC0xLjIuOS0xLjIgMnMuNSAyLjIgMS4yIDIuMmMuNiAwIDEu'
    b'Mi0xIDEuMi0yLjF6bS0xMy40IDEuNGMwLTEtLjYtMS43LTEuMi0xLjdzLTEuMi44LTEuMiAx'
    b'LjcuNSAxLjggMS4yIDEuOCAxLjItLjggMS4yLTEuOHptMi4xIDExLjRjMC0xLjUtMS4xLTIu'
    b'Ny0yLjUtMi43cy0yLjUgMS4yLTIuNSAyLjdjMCAxLjYgMSAyLjggMi41IDIuOHMyLjUtMS4y'
    b'IDIuNS0yLjh6bS02LjYtNWMwLTEuMy0xLTIuNC0yLjEtMi40LTEuMiAwLTIuMiAxLTIuMiAy'
    b'LjRzMSAyLjQgMi4yIDIuNGMxLjEgMCAyLTEgMi0yLjR6bS0xLTYuOGEyIDIgMCAwIDAtMS0x'
    b'LjcgMS44IDEuOCAwIDAgMC0xLjkgMCAyIDIgMCAwIDAtLjkgMS43IDIgMiAwIDAgMCAxIDEu'
    b'OCAxLjggMS44IDAgMCAwIDEuOCAwYy42LS40IDEtMSAxLTEuOHptMzAuMSAzNC40Yy0yLjct'
    b'My42LTcuMS01LjEtOS44LTMuNC0yLjYgMS43LTIuNiA2IC4yIDkuNyAyLjcgMy42IDcgNS4x'
    b'IDkuNyAzLjQgMi43LTEuOCAyLjctNiAwLTkuN3ptNy44IDY2LjdjLjUtNC41LTEuNi04LjQt'
    b'NC44LTguOC0zLjItLjMtNi4yIDMtNi44IDcuNC0uNSA0LjQgMS43IDguMyA0LjkgOC43IDMu'
    b'Mi40IDYuMi0zIDYuNy03LjN6bTEuNiAzOC44YzEtNC40LS45LTguNS00LTkuMi0zLjItLjYt'
    b'Ni41IDIuNC03LjQgNi44LS45IDQuMyAxIDguNCA0IDkgMy4yLjcgNi41LTIuMyA3LjQtNi43'
    b'em03LjUtMzYuNGMwLTEuNy0xLjItMy4xLTIuNi0zLjFzLTIuNyAxLjQtMi43IDMuMWMwIDEu'
    b'OCAxLjIgMy4yIDIuNyAzLjJzMi42LTEuNCAyLjYtMy4yem0tNi41IDcuMy01LjQgNi4ycy01'
    b'LjEuMS00LjggMS44Yy4yIDEuNiA3IDYuNiA3IDguNi0uMSAyIDQuNC0uNSA0LjQtLjVsMy43'
    b'LTExLjFzLS4yLTcuNy0yLjItNy42Yy0yIC4yLTIuNSAyLjUtMi43IDIuNnptLTM1Ny40LTIu'
    b'NGEyLjYgMi42IDAgMSAwLTUuMSAwIDIuNiAyLjYgMCAwIDAgNS4xIDB6bTIuNS04YzAtMS40'
    b'LTEuMi0yLjYtMi42LTIuNnMtMi42IDEuMi0yLjYgMi43IDEuMiAyLjcgMi42IDIuN2EyLjcg'
    b'Mi43IDAgMCAwIDIuNi0yLjd6TTEzNCAxOTkuMmMtMS0yLjItMy0zLjQtNC41LTIuNy0xLjUu'
    b'Ny0yIDMtMSA1LjJzMyAzLjQgNC41IDIuN2MxLjYtLjcgMi0zIDEtNS4yem02LjUgMjMuNGMt'
    b'MS40LTIuOC00LjEtNC40LTYuMi0zLjVzLTIuNyAzLjktMS40IDYuNyA0IDQuNCA2LjIgMy41'
    b'IDIuNy0zLjkgMS40LTYuN3ptNi44IDE3LjJjLjUtMy41LTEtNi44LTMuMi03LjItMi4zLS41'
    b'LTQuNCAyLTQuOSA1LjUtLjQgMy41IDEgNi43IDMuMyA3LjIgMi4yLjUgNC40LTIgNC44LTUu'
    b'NXptLTExIDIuNWMxLjQtMy4zLjktNi44LTEuMS03LjhzLTQuOC43LTYuMiA0LS45IDYuNyAx'
    b'LjIgNy44IDQuNy0uNyA2LjEtNHoiLz4KICAgIDxwYXRoIGZpbGw9IiM2YjE4YjUiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgZD0iTTEzMS4zIDIzNC44YzAtMS43LTEuMy0zLTIuOS0zcy0yLjkg'
    b'MS40LTIuOSAzIDEuMyAzIDMgMyAyLjgtMS4zIDIuOC0zem0tMi4zLTcuNWMwLTEuNS0xLjIt'
    b'Mi43LTIuNi0yLjdhMi43IDIuNyAwIDAgMC0yLjYgMi44YzAgMS40IDEuMiAyLjcgMi42IDIu'
    b'N3MyLjYtMS4zIDIuNi0yLjh6bTIuNC0xNC4zYzAtMi42LTEuMS00LjYtMi41LTQuNnMtMi41'
    b'IDItMi41IDQuNmMwIDIuNSAxLjEgNC42IDIuNSA0LjZzMi41LTIgMi41LTQuNnptNy44LTEu'
    b'MWMuMy0yLjUtLjUtNC43LTItNS0xLjMtLjEtMi43IDEuOC0zIDQuMy0uNCAyLjUuNSA0Ljcg'
    b'MS45IDQuOSAxLjMuMiAyLjctMS43IDMtNC4yem01NS0xMTBjMS4xLTMuNiAwLTcuMi0yLjMt'
    b'OC0yLjMtLjktNSAxLjMtNiA0LjktMSAzLjYgMCA3LjIgMi4zIDggMi4zLjkgNS0xLjMgNi00'
    b'Ljl6bS0xMC40IDE1LjljMy0yLjcgNC40LTYuMyAzLTguMS0xLjUtMS45LTUuMi0xLjItOC4z'
    b'IDEuNHMtNC4zIDYuMi0yLjkgOGMxLjUgMS45IDUuMiAxLjMgOC4yLTEuM3ptLTYtOC44YzMt'
    b'Mi4zIDQuMi01LjQgMi44LTdzLTUtMS04IDEuMmMtMy4xIDIuMy00LjQgNS40LTMgN3M1IDEg'
    b'OC4xLTEuMnptMjMuNS0xNS41YzItMS42IDIuOS0zLjggMi00LjktMS0xLTMuNS0uNy01LjYu'
    b'OXMtMi45IDMuNy0xLjkgNC44YzEgMS4xIDMuNC43IDUuNS0uOHoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiM2YjE4YjUiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTE4OSAxMDguNWMxLjQtMi4y'
    b'IDEuNS00LjUuMi01LjItMS4zLS43LTMuNS40LTQuOSAyLjZzLTEuNSA0LjUtLjIgNS4yYzEu'
    b'My43IDMuNS0uNSA0LjktMi42em0xNy43LTkuM2MyLjItMS45IDMtNC4zIDItNS41LTEuMi0x'
    b'LjItNC0uNi02LjIgMS4ycy0zIDQuMy0xLjkgNS41YzEuMiAxLjIgMy45LjYgNi4xLTEuMnpt'
    b'LTMyIDIxLjZjMiAwIDMuNi0xLjEgMy40LTIuMyAwLTEuMS0xLjktMi00LTEuOS0yIC4xLTMu'
    b'NiAxLjItMy40IDIuMy4xIDEuMiAyIDIgNCAyem0zOC43LTMzLjFjMS40LTIuMiAxLjUtNC41'
    b'LjItNS4yLTEuMi0uNy0zLjQuNC00LjggMi42cy0xLjUgNC41LS4yIDUuMmMxLjMuNyAzLjQt'
    b'LjQgNC44LTIuNnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmQyMDAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjZWY4YTEwIiBkPSJNNDQ2LjggMTUzLjRzNi40LTEwLjEgNC0xOS43'
    b'Yy0yLjUtOS41LTEzLTIuNy0xMi44LjcuMiAzLjMgNi44IDcuOSA3LjIgMTAgLjQgMi0uOCA4'
    b'LjMgMS42IDl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMjE3OTAwIiBmaWxsLXJ1bGU9ImV2ZW5v'
    b'ZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRo'
    b'PSIyLjMiIGQ9Ik0zMjQuOSA2OS4zczIzIC45IDIzLjEgMTUuOGMwIDIuMyAwIDUtLjggMTEu'
    b'NyA0LjYtMi41IDcuNi05LjMgNy0xMy43LjEtMTUuMS0yMC41LTI1LjUtMjkuMy0xMy44eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iIzIxNzkwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMi4zIiBkPSJN'
    b'MzEwLjMgNjguNnMxOC41LTMuOCAxOC43IDExYy4xIDE1LTYgMTcuMy02IDE3LjNzMTQuMy0z'
    b'IDE0LjQtMTguMWMwLTE1LjItMTguMy0yMS45LTI3LjEtMTAuMnoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNmN2RmNzMiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'bGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuNSIgZD0iTTM3My4zIDM5MHM4Ni44'
    b'LTI0LjYgMTEzLTEzMUM0NzEgMzY4LjEgMzc2IDQwMyAzNzYgNDAzbC0yLjgtMTN6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjOGMxODAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zODIuMiAz'
    b'OTYuNmMyLjcgMCA5LjMtNy40IDEzLjEtOC4yIDMuOC0uOCA0LjItNC43LS4xLTQuOC00LjQt'
    b'LjItOC4yIDUtOC4yIDVzLTMuOCAzLjItNy44IDMuNmMtNCAuNC0xLjQgNS40IDMgNC40eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iIzhjMTgwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9'
    b'IiM4YzE4MDAiIHN0cm9rZS13aWR0aD0iMi41IiBkPSJNNDMyLjIgMzU5LjNzLTkgNS4yLTcu'
    b'OCA2LjVjMS4zIDEuMyA5LjMtNSA5LjUtNSAuMS0uMiAzLjQtNC4yLTEuNy0xLjV6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjOGMxODAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik00MDAuNyAz'
    b'ODNzLTIuNy0xIDQuMi0zLjZjNy0yLjcgNi41LTUuOCA4LjgtNy4xIDIuMi0xLjMgNy00Ljcg'
    b'OC0yLjdzLTUgNi02LjUgNi40Yy0xLjQuNC04LjMgNi44LTEwLjMgNy4zLTIgLjYtMy40LjMt'
    b'NC4yLS4zeiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjOGMxODAwIiBzdHJv'
    b'a2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13aWR0aD0iMyIgZD0iTTQ0NS42IDM0NmMtNiA2'
    b'LjctNiA2LjUtNiA2LjUiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzhjMTgw'
    b'MCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuOCIgZD0ibTQ1NC41'
    b'IDMzNS4yLTUuNyA2LjkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzhjMTgw'
    b'MCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuNSIgZD0ibTQ2My40'
    b'IDMyMS02LjQgMTAuMiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjOGMxODAw'
    b'IiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13aWR0aD0iMi4zIiBkPSJtNDcwLjkg'
    b'MzA2LjYtNS4zIDEwLjVtOC42LTE4LTEuNiAzLjYiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iIzhjMTgwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9'
    b'IjEuNCIgZD0ibTQ3OCAyODktMS40IDQuNCIvPgogICAgPHBhdGggZmlsbD0iI2Y3ZGY3MyIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91'
    b'bmQiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMTYwLjMgMjE2czUyLTE0LjcgNjcuNi03OC41'
    b'Yy05LjEgNjUuNS02NiA4Ni4yLTY2IDg2LjJsLTEuNi03Ljd6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgtMS42NTUyOCAwIDAgMS43MDA2MiA1MjQuOCAyMC40KSIvPgogICAgPHBhdGggZmlsbD0i'
    b'IzhjMTgwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjUwLjcgMzk0LjRjLTIuNyAwLTku'
    b'Mi03LjUtMTMtOC4zLTMuOC0uOS00LjItNC44LjEtNSA0LjQgMCA4LjEgNS4xIDguMSA1LjFz'
    b'My44IDMuMyA3LjcgMy44YzQgLjQgMS40IDUuNC0yLjkgNC40eiIvPgogICAgPHBhdGggZmls'
    b'bD0iIzhjMTgwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiM4YzE4MDAiIHN0cm9r'
    b'ZS13aWR0aD0iMS41IiBkPSJNMTk1LjUgMTk3LjZzLTUuNCAzLjItNC42IDRjLjcuNyA1LjUt'
    b'MyA1LjYtMy4xLjEtLjEgMi0yLjUtMS0uOXoiIHRyYW5zZm9ybT0ibWF0cml4KC0xLjY1NTI4'
    b'IDAgMCAxLjcwMDYyIDUyNC44IDIwLjQpIi8+CiAgICA8cGF0aCBmaWxsPSIjOGMxODAwIiBm'
    b'aWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yMzIuNCAzODAuNnMyLjYtMS00LjItMy43LTYuNS02'
    b'LTguNy03LjJjLTIuMi0xLjMtNy00LjctOC0yLjdzNSA2IDYuNSA2LjRjMS40LjUgOC4yIDcg'
    b'MTAuMiA3LjUgMiAuNiAzLjMuMyA0LjItLjN6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiM4YzE4MDAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjgiIGQ9Im0yMDMuNSAxODkuNy0zLjUgMy45IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS42NTUy'
    b'OCAwIDAgMS43MDA2MiA1MjQuOCAyMC40KSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjOGMxODAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13aWR0aD0iMS43'
    b'IiBkPSJtMjA4LjkgMTgzLjItMy40IDQuMSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEuNjU1Mjgg'
    b'MCAwIDEuNzAwNjIgNTI0LjggMjAuNCkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9r'
    b'ZT0iIzhjMTgwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuNSIg'
    b'ZD0ibTIxNC4yIDE3NC43LTMuOCA2LjEiIHRyYW5zZm9ybT0ibWF0cml4KC0xLjY1NTI4IDAg'
    b'MCAxLjcwMDYyIDUyNC44IDIwLjQpIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiM4YzE4MDAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjQiIGQ9'
    b'Im0yMTguNyAxNjYuMS0zLjIgNi4zbTUuMi0xMC45LTEgMi4yIiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgtMS42NTUyOCAwIDAgMS43MDA2MiA1MjQuOCAyMC40KSIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjOGMxODAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13'
    b'aWR0aD0iLjgiIGQ9Im0yMjMgMTU1LjUtLjkgMi43IiB0cmFuc2Zvcm09Im1hdHJpeCgtMS42'
    b'NTUyOCAwIDAgMS43MDA2MiA1MjQuOCAyMC40KSIvPgogICAgPHBhdGggZmlsbD0iIzIxNzkw'
    b'MCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0i'
    b'cm91bmQiIHN0cm9rZS13aWR0aD0iMi4zIiBkPSJNNDkwLjQgMjM5LjNjLjUgNi43IDcgMTMg'
    b'NC40IDI0LjctMy4yIDEzLjMtMTQuOCA0NC43LTEyLjggNTAuMi0zLjQtNC43LTIuOC05LTMt'
    b'MTUuNi0uNC02LjUgOS40LTMwLjkgMTAuMy0zOS4xIDAtNy40LjctMTcuNSAxLjEtMjAuMnoi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiMyMTc5MDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuMyIgZD0i'
    b'TTQ5MC40IDIzOS40czEwLjcgMTMuNSAxMC4xIDI0LjJjLS41IDEwLjctNi41IDIzLjItNC41'
    b'IDI4LjdhMjEuNyAyMS43IDAgMCAxLTQuNi0xNC4yYy0uMy02LjUgNS4zLTEzLjggNC4xLTIw'
    b'LjktMS4xLTctNS4yLTE3LjgtNS0xNy44em0tMzQ5LjMgM2MtLjQgNi43LTUuNCAxMi43LTIu'
    b'OCAyNC4zIDMuMiAxMy4zIDE1IDMwIDEzIDQ5LjIgMy41LTQuNyA0LjUtMTAgNC44LTE2LjUu'
    b'Mi02LjUtMTMtMjguNS0xMy44LTM2LjggMC03LjQtLjgtMTcuNS0xLjItMjAuMnoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiMyMTc5MDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuMyIgZD0iTTE0MS4x'
    b'IDI0Mi42cy0xMC40IDEzLTkuOCAyMy43Yy4xIDcuMSAxMy4yIDM2LjggMTEuMiA0Mi40IDMu'
    b'NS00LjcgNC40LTQuMSA0LjMtMTEuMi0zLjgtMTguMy0xMC43LTI5LjktOS41LTM3IDEuMS03'
    b'LjEgNC0xOCAzLjgtMTh6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS1kYXNob2Zmc2V0PSIxIiBzdHJva2UtbGluZWNhcD0ic3F1YXJlIiBzdHJva2Ut'
    b'bGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuNyIgZD0ibTEwMCAxMjUuOCAyMiA2'
    b'OC4yaDcybC01OCA0Mi4yIDIyLjEgNjguMi01OC00Mi4xLTU4IDQyLjEgMjItNjguMkw2IDE5'
    b'NGg3MS44eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4xNjUxNiAwIDAgMS4xNjUzNCAyMDIgLTIz'
    b'LjYpIi8+CiAgPC9nPgo8L3N2Zz4K', 'MP')

MP = b64_MP
index.append("MP")
index.append("MNP")
index.append("Northern Mariana Islands")
catalog["MP"] = MP
catalog["MNP"] = MP
catalog["Northern Mariana Islands"] = MP
country["Northern Mariana Islands"] = ('MP', 'MNP', 0)
lookup["MP"] = ('MP', 'MNP', 'Northern Mariana Islands', 0)
lookup["Saipan Northern Mariana Islands"] = ('MP', 'MNP', 'Northern Mariana Islands', 0)
lookup["MNP"] = ('MP', 'MNP', 'Northern Mariana Islands', 0)
lookup["Northern Mariana Islands"] = ('MP', 'MNP', 'Northern Mariana Islands', 0)
details["MP"] = {"continent":"Oceania","capital":"Saipan","currency":"US Dollar","web":".mp","lang":"fil | tl | zh | ch-MP | en-MP","tz":"+10:00","altname":""}
#----------------------------------------------------------------------
b64_MQ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1xIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzIzMWYxZSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwYTY1MCIgZD0iTTAgMGg2NDB2'
    b'MjQwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2VmMTkyMyIgZD0ibTAgMCAzMjAgMjQwTDAgNDgw'
    b'eiIvPgo8L3N2Zz4K', 'MQ')

MQ = b64_MQ
index.append("MQ")
index.append("MTQ")
index.append("Martinique")
catalog["MQ"] = MQ
catalog["MTQ"] = MQ
catalog["Martinique"] = MQ
country["Martinique"] = ('MQ', 'MTQ', 0)
lookup["MQ"] = ('MQ', 'MTQ', 'Martinique', 0)
lookup["Fort-de-France Martinique"] = ('MQ', 'MTQ', 'Martinique', 0)
lookup["MTQ"] = ('MQ', 'MTQ', 'Martinique', 0)
lookup["Martinique"] = ('MQ', 'MTQ', 'Martinique', 0)
details["MQ"] = {"continent":"Americas","capital":"Fort-de-France","currency":"Euro","web":".mq","lang":"fr-MQ","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_MR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1yIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2NkMmEzZSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwNjIzMyIgZD0iTTAgNzJoNjQw'
    b'djMzNkgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmM0MDAiIGQ9Ik00NzAgMTU0LjZhMTUwIDE1'
    b'MCAwIDAgMS0zMDAgMCAxNTQuOSAxNTQuOSAwIDAgMC01IDM5LjIgMTU1IDE1NSAwIDEgMCAz'
    b'MTAgMCAxNTQuNCAxNTQuNCAwIDAgMC01LTM5LjJ6IiBjbGFzcz0ibXItc3QxIi8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZmYzQwMCIgZD0ibTMyMCA5My44LTEzLjUgNDEuNUgyNjNsMzUuMyAyNS42'
    b'LTEzLjUgNDEuNCAzNS4zLTI1LjYgMzUuMyAyNS42LTEzLjUtNDEuNCAzNS4zLTI1LjZoLTQz'
    b'LjZ6Ii8+Cjwvc3ZnPgo=', 'MR')

MR = b64_MR
index.append("MR")
index.append("MRT")
index.append("Mauritania")
catalog["MR"] = MR
catalog["MRT"] = MR
catalog["Mauritania"] = MR
country["Mauritania"] = ('MR', 'MRT', 0)
lookup["MR"] = ('MR', 'MRT', 'Mauritania', 0)
lookup["Nouakchott Mauritania"] = ('MR', 'MRT', 'Mauritania', 0)
lookup["MRT"] = ('MR', 'MRT', 'Mauritania', 0)
lookup["Mauritania"] = ('MR', 'MRT', 'Mauritania', 0)
details["MR"] = {"continent":"Africa","capital":"Nouakchott","currency":"Ouguiya","web":".mr","lang":"ar-MR | fuc | snk | fr | mey | wo","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_MS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW1zIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAxMjE2OSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTM4NC45IDExMWgy'
    b'MDUuNWwtLjMgMTQ2LjNjMS43IDU4LjctMzQuOSA5NS4yLTEwMi4zIDExMS43LTQ3LjktMTIt'
    b'MTAzLTM2LjUtMTAzLjItMTEwbC4zLTE0OHoiLz4KICA8cGF0aCBmaWxsPSIjMDBhMmJkIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS44IiBkPSJNMzg5LjQgMTE1LjRoMTk2LjRs'
    b'LS4yIDE0MC4yYzEuNiA1Ni4zLTMzLjQgOTEuMi05Ny44IDEwNy00NS44LTExLjQtOTguNS0z'
    b'NS05OC42LTEwNS40bC4yLTE0MS44eiIvPgogIDxwYXRoIGZpbGw9IiNhNTNkMDgiIGQ9Ik01'
    b'ODQuMyAyNzIuMmMtNy4yIDUzLjctNDguNiA3Ny4yLTk2LjUgODkuNy00Mi41LTExLjQtODgu'
    b'Mi0yOS42LTk3LTg5LjVsMTkzLjUtLjJ6Ii8+CiAgPHBhdGggZD0ibTQ4MCAxNDEuNS0uMy0x'
    b'Ny42IDE0IC4xLjEgMTcuNUg1MzJsLjEgMTMuNy0zOC4zLjItLjMgMTYxLjQtMTMuNi4xLS4y'
    b'LTE2MS43LTM4IC4ydi0xNHoiLz4KICA8cGF0aCBmaWxsPSIjZmY5YTA4IiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuOCIgZD0ibTQ0OSAyNzgu'
    b'OCAzNSAzNi4zYzEyLjEtMTMuMyAzLjctNjMtMTIuMi03Mi4xLTEuOSA1LjktNS4xIDEzLTgu'
    b'NiAxNS4yLTcuNSA1LjItMjYuMSAxMS4yLTE5LjkgMTUgMS40LTEuOSA1LjEtMy43IDYuOS42'
    b'IDIgNi45LTcuOCA3LjMtNy44IDcuM3MtNi4yLS44LTcuMy03Yy0xLTYuNCA5LjMtMTIuMiAx'
    b'MC4yLTEyLjYuOC0uMyAxNC4zLTQgMTYuNi0xNS45IDIuOS0xMS44IDUuOC0xMCA2LjMtMTAu'
    b'MiAxNy43IDEuNyAyOS4yIDMzLjMgMjkuOSA1NS41LjYgMjIuMi05IDM3LTEwLjggMzgtMS43'
    b'LjktNDItNDcuOS00Mi00Ny45bDMuOC0yLjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmOWEwOCIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii44IiBkPSJtNDc0LjYgMjQ1IC4yIDY1LjVt'
    b'LTQuMi02NC4yLjMgNTkuNG0tNC41LTUwLjguMiA0Ny4ybS0zLjctNDMuOS4yIDM5LjFtLTMu'
    b'OS0zNy4zdjMzbS00LTMwLjR2MjYuMW0tMy41LTI0djIwIi8+CiAgPGcgZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlPSIjZmZkZjAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13aWR0aD0i'
    b'MS44Ij4KICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjgiIGQ9Im00NDguNSAyODMgMzYgNDEu'
    b'MiIvPgogICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIxLjQiIGQ9Ik00ODYuMyAyNTdzMTYuNCAz'
    b'NS43IDEuMiA2NW0tNDMuMi00Ni42czEuMi0zLjEgMi43LTEuOG0tNS41LTcuM3MtNi42IDUu'
    b'Ny0zIDkuNSIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSIjMDA4MDIxIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik00OTQgMTc1LjRjMi4zLTIgMy42LTMuMyA1LjEtMyAx'
    b'LjUuMiAzLjUgMCA1LS40YTMxIDMxIDAgMCAxIDEyLS40YzEgLjIgMi41LjcgNC42IDIuNSAy'
    b'LjEgMS44IDUuMiA1IDQuMiAxMy42cy0uNyAxMi4zLTEuMiAxNy4yYy0uOCA4LjUtMi43IDE1'
    b'LjUtNiAxNSA0LjUgOCA1IDE1IDggMjAuNXM0LjggMTYuOCAzLjcgMjljLTEuMiAxMi4zLTQu'
    b'NCAzOS43IDUuMyA1OC4yLTEuNiAxLjEtNS41IDAtOS0zLjdzLTUtMy42LTcuOC0xLjRjLTgu'
    b'OCA2LjctMTcgMTQuOC0yOS4xIDYuNy0yLjgtMS44LTMuNi00LTEuNi05LjcgNS0xNCA3LjUt'
    b'MzMuNCA2LjctNDIuNFYxNzUuNHoiLz4KICA8cGF0aCBmaWxsPSIjZmZlMWNmIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik01MDIuMyAxNjYuOGE5LjYgOS42IDAgMCAx'
    b'LS4xIDYuOCA5IDkgMCAwIDAgLjUgOC40YzIuNy00IDYuNi0zLjIgOS01LjQgMi4yLTIuMyAy'
    b'LjctNC41IDQuNC01LTEuNy0xLjUtNC4zLTMuMi0zLjgtNy41LjYtNC40IDYuNy04IDEuMi0x'
    b'NC42YTggOCAwIDAgMC0xMy40IDEuMmMtLjMuOC4yIDIuNC0uNyAzLjRhOCA4IDAgMCAxLTIu'
    b'MSAyYy0uNS40LS44LjktLjIgMS42LjIuMy42LjMgMSAuNGwtLjggMS41Yy0uMy4zLS4yLjYu'
    b'MiAxLS41IDEuMy40IDEuNS0uMiAyLjUtLjYuOS0xLjIgMiAuNiAzIC42LjMgMyAuOCA0LjQu'
    b'N3ptLTIyLjUgMjNjLTMuMi44LTguNC0uNi0xMi4zLS4yLTEuOC4yLTMuMi0uNy0zLTIuNC4z'
    b'LTEuNy42LTQuNC4yLTYuOGEzMS42IDMxLjYgMCAwIDEgMy44LTE0LjggMzMgMzMgMCAwIDAg'
    b'My44LTExLjZjMC0xLjkuMi0zLjkgMS44LTUgMS4yLS43IDEuNC0xLjQgMS44LTIgMS0xLjUg'
    b'Mi0xLjggMi0xIC4xLjUgMCAxLS41IDEuNiAxLS44IDIuOC0xLjggMy4yLTIgLjQtLjQgMi40'
    b'LTEuOCAyLjUtLjQuOC0uNCAxLjQtLjQgMS42IDAgLjIuNSAwIC43LS4zIDEgLjYgMCAxLjIu'
    b'OSAwIDEuOC43LS4yIDEuMy44LjIgMS43LTEgMS0yLjQgMS42LTIuNyAyLjQtLjQuOC0zLjIg'
    b'Mi45LTQuMyAzLjMtMS4xLjUtMS4yIDEuMS0xLjIgMi43IDAgMTcuOC0yIDE2LjMtMiAyMC43'
    b'IDAgMS0uMyAyLjEuOCAxLjhhMTUgMTUgMCAwIDEgNC42LS45djEwem0uNyAzOC4yYzUuMi0y'
    b'LjYgMTEuMi0zLjYgMTQuMy00LjRhNjIuNCA2Mi40IDAgMCAwIDEwLjQtNC40YzIuNS0xLjMg'
    b'NC41LTMgNS45LTMuNWE2LjUgNi41IDAgMCAwIDMuOC0zLjIgNTAuNCA1MC40IDAgMCAwIDYu'
    b'OS0yMS44YzAtNC0xLTguNi01LTUuNGEyOS42IDI5LjYgMCAwIDAtOC44IDEzLjJjLTEuNiA2'
    b'LjQtMyA3LjktMy4zIDkuMS0uNCAxLjMtMS42IDEuMy0zLjIgMS42YTI2LjcgMjYuNyAwIDAg'
    b'MC0xMy42IDYuNCAxMzYgMTM2IDAgMCAxLTE0LjIgOS4yYy0zLjcgMi4xLTQuNCAyLjMtNS4y'
    b'IDQtLjggMS42LTEuNiAzLTIuMiAzLjYtLjguOC0xIDEuNi0uOCAyLjYuMS44LS4yIDQuMi0u'
    b'MyA1LjQgMCAxLjIuMyAxLjQuNyAxLjUuNCAwIDEtLjIgMS4zLTEuNi0uMiAxLjQgMS43IDEg'
    b'MS44LS4xIDAgMS41IDIgLjYgMi0uOCAwIDEgMS43LjMgMS43IDAgLjQtMS4zLjctMi41IDEu'
    b'Mi0zLjQuNi0xLjQgMS4zLTMuMiAyLjctNCAxLjUtMS4yLjgtMi40IDMuOS00em0zNy40IDk0'
    b'LjVjLjMgMS4zIDEgMi43IDEuMiAzLjYuMi44LS4yIDEuMS0uNCAxLjZhMzIuOCAzMi44IDAg'
    b'MCAwLTIuOCA4LjhjMCAxLjItMSAyLjQtMS4zIDMuMi0uNS44LS4zIDEuNS44IDIuMy40LjMg'
    b'Mi0uMiAyLjEtMSAuNy42IDEuNi40IDIuMS0uNS42LjUgMS41LjIgMi0uNy41LjMgMS4zLS4z'
    b'IDEuNi0uOC44LjQgMS42IDAgMS42LTEuNiAwLS40LjMtMSAuNS0xLjMuMi0uNC4zLTEuMS4z'
    b'LTEuNyAwLS43LjMtMiAuOS0yLjguNi0xIDEuNS0yLjUgMS4xLTQtLjQtMS40LTEtMS4zLTEu'
    b'NS0zLjItMS4zLTEuNC0zLTMuMi00LjgtMy40LTEuOCAwLTIuOCAxLjEtMy40IDEuNXptLTMy'
    b'LjkgOS45YzEuNyAxLjYgNS4zIDEuNiA3LjgtMS0uOS0uNC0zLTEuNC0zLjgtMmExMi40IDEy'
    b'LjQgMCAwIDEtNCAzeiIvPgogIDxwYXRoIGZpbGw9IiM4NzBmMDAiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTUwMS40IDE0OWMuNi00IDMuNS00IDUuMy0zLjUuOC4x'
    b'IDIuNi4zIDQuNC0uMiAzLjQtLjkgNiAuMyA1LjYgMy42IDEgLjcgMiAyLjMgMS43IDMuNy0u'
    b'MSAxLjQuMiAyIDEuNCAyLjEgMS4zLjIgNCAxLjggMi4yIDQgMS43IDEgMyAzLjcgMi4xIDUu'
    b'NC0uOSAxLjgtMy42IDIuMS00LjguNS0xLjMuNi0zLjMuNy00LjYtLjYtLjkgMS0zIC45LTMu'
    b'NSAwLS40LTEtMS0xLjQtMS45LTEuNy0uOS0uMy0xLTIuOC40LTMuMS0uMS0uOCAwLTEuNi4z'
    b'LTIgLjMtLjQgMC0xLjItLjgtMS44LS44LS43LTEuNS0zLS43LTQuNC0xLjQuNS00LjQtLjkt'
    b'NS0xLjgtLjctMS0xLjYtMS0yLjEtLjJ6Ii8+CiAgPGcgZmlsbD0ibm9uZSIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9Ii4zIj4KICAgIDxwYXRoIGQ9Ik01MDIuMyAxNjYuOGMyLjIt'
    b'LjMgMy0xLjYgNC42LTEuNm0tOS40LTQuNy41LjNjLjQuMyAxIC40IDEuNC40bS0xLjMtMy4x'
    b'IDEgLjZtNC4yLTkuN2MtMS4zLTEuMyAyLjItMy44IDYtLjIuOC44IDIuNS44IDMgLjZtLTMu'
    b'OCAxLjZjMS44LS40IDQuMy0uNCA1LjEgMS42LjggMiAyLjMuNiAzLjUgMyAxLjIgMi4zIDMg'
    b'NC44IDUgM20tNy40IDUuNGE0IDQgMCAwIDEtLjQtMy4yYy0uNy0uOC0uNC0yLjUgMC0zLjNt'
    b'LTQuNiAxLjdjMCAuNyAxIDIgMi40IDIuMm03LjIgMy4yYy0uOC0xLS43LTItLjUtMy4yIi8+'
    b'CiAgICA8cGF0aCBkPSJNNTEwLjkgMTUzYzAgMS4xLjYgMi41IDEuNiAzIC4zLjYgMS40IDIu'
    b'MiAzLjggMm0uNC05YTEwLjkgMTAuOSAwIDAgMC01LjItMi42bS04LjggMzUuNmMtMiAyLjct'
    b'My4yIDYuNC0yLjQgMTEuNiAxIDUuMiAyLjQgMTIuOC0xLjMgMTYuMm0xOC42IDEwLjFjLTIu'
    b'Ni0uNy02LjQtLjctOC41LjktMiAxLjUtNS42IDEuNi03LjkuNCIvPgogICAgPHBhdGggZD0i'
    b'TTUxMiAyMTkuNmMtMi4zLjQtMy4zIDIuMS0zLjMgNi40IDAgNC4yLTEgMTAuNC0uMiAxNi42'
    b'bS0uNi0yMS4xYy0xLjYuNC0zLjIuNC0yLjggNC41bS01LjEgMGMuMS0yLjQgMS00LjggMi42'
    b'LTQuM20xNC4xIDQuOWMwLTUuNi0xLjItNy4xLTIuOC03IDIuMiAwIDMuNy4zIDQuNyA5LjIu'
    b'NiA2LjggMiA5IDMuNyAxNC40IDQuMSAxMy42IDIgMzQuNSA0LjEgNDJtLTEyLjktNTdhNzEu'
    b'NCA3MS40IDAgMCAxLS40IDQ5LjNjNC44IDEzLjQgOS42IDIzLjEgMTAuNSAyOC42bS0yMy45'
    b'LTQ4Yy44LTIuOS0yLjItMy4yLjQtMTMuMyAxLjEtNC40IDEuMy03IC42LTguNCIvPgogICAg'
    b'PHBhdGggZD0iTTUwMC43IDI0Mi40Yy0xIDQuNCAzLjMgMTIuOCAxLjIgMTltLTUuNSAxLjFj'
    b'MCA0IC45IDkgLjcgMTMtLjIgMy45IDEuNCA1LjcgMy4yIDkuNCA2LjggMTMuNCAxMS4yIDIy'
    b'LjkgMTAuNyAzNS41LS4yIDIuNC42IDcuMi0xLjggOC42bS0xMi42IDMuNGMuNyAwIDEuNC0u'
    b'NCAyLjMtMi40YTY0LjggNjQuOCAwIDAgMCAyLjQtMjNtMS40IDkuNmMuNCAyLjYuNCA4LTEu'
    b'MyAxMi40Ii8+CiAgICA8cGF0aCBkPSJNNTA3LjEgMzA4LjdjMSA1LjYgMSAxMC43LjEgMTQu'
    b'M20tMi40IDBjLjIgMi4yIDEuMiA4LS41IDguNW05LjItMzUuM2M0LjMgNi43IDcuNiAyMy4y'
    b'IDExLjIgMjYuNm0tNy42LTIuNmMwLTEuOC0uMS00LjQtMS4yLTUuNk00NzEgMjM5LjRjLjEt'
    b'MS4yLS4xLTIuNCAxLjMtNC40bS0zLjMgNS4yYy4yLTQuNC4xLTQuOCAxLjQtNm0tMy4yIDYu'
    b'MWMwLTMuMi0uMy00LjMgMS02LjNtMTQuOS04OC44LTQuNSAzLjRtNS44LTIuNGMtLjUgMC0y'
    b'LjEgMS40LTUgMy42bTUuMS0xLjhjLTEgLjQtMi42IDItNC4yIDMuMm0tMi45LTMuNS0xLjYg'
    b'MS42TTUxNy41IDM0MWMtLjItLjItLjItMS4zLjMtMi40bTEuOSAxLjljLS40LS4zIDAtMS43'
    b'LjItMi42bTEuNyAxLjljLS40LS4yLS41LTEgMC0ybTEuNSAxLjJjLS4yIDAtLjMtLjYuMS0x'
    b'LjgiLz4KICA8L2c+CiAgPHBhdGggZD0iTTUwMC41IDE1Mi43Yy44IDEgMS43IDEgMS44IDEu'
    b'Ni4yLjguMy44LjQgMSAuMi4yLS40LjItLjYgMGgtMS40Yy0uNCAwLS44LS41LS42LS41LjMt'
    b'LjEuMy0uMi4yLS40IDAtLjMuMi0uNi40LS43bC0uMS0uM2MtLjItLjMtLjMtMS0uMS0uOHpt'
    b'LjUtMS4xYTYuNCA2LjQgMCAwIDEgMy40IDEuNmMuNy44LjEuNi0uMi42cy0xLS4yLTEuNC0u'
    b'NmE0LjYgNC42IDAgMCAwLTEuOS0xLjJjLS4zIDAtLjYtLjQgMC0uNHoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjMDEyMTY5IiBkPSJNMCAwaDMyMHYyNDBIMHoiLz4KICA8cGF0aCBmaWxsPSIjRkZG'
    b'IiBkPSJtMzcuNSAwIDEyMiA5MC41TDI4MSAwaDM5djMxbC0xMjAgODkuNSAxMjAgODlWMjQw'
    b'aC00MGwtMTIwLTg5LjVMNDAuNSAyNDBIMHYtMzBsMTE5LjUtODlMMCAzMlYweiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNDODEwMkUiIGQ9Ik0yMTIgMTQwLjUgMzIwIDIyMHYyMGwtMTM1LjUtOTku'
    b'NXptLTkyIDEwIDMgMTcuNS05NiA3Mkgwek0zMjAgMHYxLjVsLTEyNC41IDk0IDEtMjJMMjk1'
    b'IDB6TTAgMGwxMTkuNSA4OGgtMzBMMCAyMXoiLz4KICA8cGF0aCBmaWxsPSIjRkZGIiBkPSJN'
    b'MTIwLjUgMHYyNDBoODBWMHpNMCA4MHY4MGgzMjBWODB6Ii8+CiAgPHBhdGggZmlsbD0iI0M4'
    b'MTAyRSIgZD0iTTAgOTYuNXY0OGgzMjB2LTQ4ek0xMzYuNSAwdjI0MGg0OFYweiIvPgo8L3N2'
    b'Zz4K', 'MS')

MS = b64_MS
index.append("MS")
index.append("MSR")
index.append("Montserrat")
catalog["MS"] = MS
catalog["MSR"] = MS
catalog["Montserrat"] = MS
country["Montserrat"] = ('MS', 'MSR', 0)
lookup["MS"] = ('MS', 'MSR', 'Montserrat', 0)
lookup["Plymouth Montserrat"] = ('MS', 'MSR', 'Montserrat', 0)
lookup["MSR"] = ('MS', 'MSR', 'Montserrat', 0)
lookup["Montserrat"] = ('MS', 'MSR', 'Montserrat', 0)
details["MS"] = {"continent":"Americas","capital":"Plymouth","currency":"East Caribbean Dollar","web":".ms","lang":"en-MS","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_MT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW10IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjY2UwMDAwIiBkPSJNMzIwIDBo'
    b'MzIwdjQ4MEgzMjB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDMyMHY0ODBI'
    b'MHoiLz4KICA8L2c+CiAgPGcgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTEyLjQgLTMwLjgpIHNj'
    b'YWxlKDEuNTk4NikiPgogICAgPHBhdGggZmlsbD0iI2YxZWVlZSIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNMTA0LjggMTA4YzAgLjktLjkgMS41LTIgMS41LTEuMiAwLTItLjYtMi0xLjQg'
    b'MC0uOC44LTEuNSAyLTEuNSAxLjEgMCAyIC43IDIgMS41eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2MwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNNDAuNyAxMDF2MzcuMkg3OGMwIDYuMiA2'
    b'LjIgMTIuNCAxMi40IDEyLjR2MzcuMmgzNy4zdi0zNy4yYzYuMiAwIDEyLjQtNi4yIDEyLjQt'
    b'MTIuNGgzNy4yVjEwMUgxNDBjMC02LjItNi4yLTEyLjQtMTIuNC0xMi40VjUxLjRIOTAuNHYz'
    b'Ny4yYy02LjMgMC0xMi41IDYuMi0xMi41IDEyLjRINDAuN3oiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNmZmU2MDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTQyIDEwMi4yVjEzN2gzNy4yYzAg'
    b'Ni4yIDYuMiAxMi40IDEyLjQgMTIuNHYzNy4yaDM0Ljd2LTM3LjFjNi4yIDAgMTIuNC02LjIg'
    b'MTIuNC0xMi40SDE3NnYtMzQuOGgtMzcuMmMwLTYuMi02LjItMTIuNC0xMi40LTEyLjRWNTIu'
    b'Nkg5MS42djM3LjJjLTYuMiAwLTEyLjQgNi4yLTEyLjQgMTIuNEg0MnoiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiM3MDcwNzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTQzLjIgMTAzLjV2MzIu'
    b'MmgzNy4yYzAgNi4yIDYuMiAxMi40IDEyLjQgMTIuNHYzNy4yaDMyLjN2LTM3LjJjNi4yIDAg'
    b'MTIuNC02LjIgMTIuNC0xMi40aDM3LjJ2LTMyLjJoLTM3LjJjMC02LjItNi4yLTEyLjQtMTIu'
    b'NC0xMi40VjUzLjlIOTIuOFY5MWMtNi4yIDAtMTIuNCA2LjItMTIuNCAxMi40SDQzLjJ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjYTBhMGEwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik00NC41'
    b'IDEwNC43djI5LjhoMzcuMmMwIDYuMiA2LjIgMTIuNCAxMi40IDEyLjRWMTg0aDI5Ljd2LTM3'
    b'LjJjNi4yIDAgMTIuNC02LjIgMTIuNC0xMi40aDM3LjJ2LTI5LjhoLTM3LjJjMC02LjItNi4y'
    b'LTEyLjQtMTIuNC0xMi40VjU1LjFIOTQuMXYzNy4yYy02LjIgMC0xMi40IDYuMi0xMi40IDEy'
    b'LjRINDQuNHoiLz4KICAgIDxnIGZpbGwtcnVsZT0iZXZlbm9kZCI+CiAgICAgIDxwYXRoIGZp'
    b'bGw9IiNkMGQwZDAiIGQ9Ik05NC40IDg5LjJjMi4xIDIuMi40IDcuNS00IDExLjlzLTkuNiA2'
    b'LTExLjggNGMtMi4yLTIuMy0uNC03LjYgNC0xMnM5LjYtNiAxMS44LTMuOXoiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iZ3JheSIgZD0iTTkxLjcgOTEuOGMyLjIgMi4yIDEuNiA2LjMtMS4zIDku'
    b'M3MtNyAzLjUtOS4yIDEuM2MtMi4yLTIuMi0xLjYtNi4zIDEuMy05LjJzNy0zLjUgOS4yLTEu'
    b'NHoiLz4KICAgICAgPHBhdGggZmlsbD0iI2QwZDBkMCIgZD0ibTgwLjggOTguNC44LS44IDMu'
    b'NSAxLjctMS43LTMuNS45LS45IDMuNSA3LTctMy41em01LjItNS4yIDEtMSA1LjIgNS40LS45'
    b'Ljh6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgICA8cGF0'
    b'aCBmaWxsPSIjZDBkMGQwIiBkPSJNMTM5LjMgMTA1Yy0yLjIgMi4yLTcuNS40LTExLjgtNHMt'
    b'Ni4yLTkuNi00LTExLjhjMi4yLTIuMiA3LjUtLjQgMTEuOSA0czYgOS42IDQgMTEuOHoiLz4K'
    b'ICAgICAgPHBhdGggZmlsbD0iZ3JheSIgZD0iTTEzNi43IDEwMi40Yy0yLjIgMi4yLTYuMyAx'
    b'LjYtOS4yLTEuM3MtMy41LTctMS40LTkuMmMyLjItMi4yIDYuNC0xLjYgOS4zIDEuM3MzLjUg'
    b'NyAxLjMgOS4yeiIvPgogICAgICA8cGF0aCBmaWxsPSIjZDBkMGQwIiBkPSJtMTMwLjEgOTEu'
    b'NC45LjktMS44IDMuNSAzLjUtMS44IDEgMS03LjEgMy40IDMuNS03em01LjMgNS4zLjguOC01'
    b'LjIgNS4zLS45LS45eiIvPgogICAgPC9nPgogICAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgICAgPHBhdGggZmlsbD0iI2QwZDBkMCIgZD0iTTEyMy41IDE1MGMtMi4yLTIuMi0uNC03'
    b'LjUgNC0xMS45czkuNi02LjEgMTEuOC00YzIuMiAyLjIuNCA3LjUtNCAxMS45cy05LjYgNi4x'
    b'LTExLjggNHoiLz4KICAgICAgPHBhdGggZmlsbD0iZ3JheSIgZD0iTTEyNi4yIDE0Ny4zYy0y'
    b'LjItMi4yLTEuNi02LjMgMS4zLTkuMnM3LTMuNSA5LjItMS4zYzIuMiAyLjIgMS42IDYuMy0x'
    b'LjMgOS4ycy03IDMuNS05LjMgMS4zeiIvPgogICAgICA8cGF0aCBmaWxsPSIjZDBkMGQwIiBk'
    b'PSJtMTM3LjEgMTQwLjctLjkgMS0zLjUtMS44IDEuOCAzLjUtLjkuOC0zLjUtNyA3IDMuNXpN'
    b'MTMyIDE0NmwtMSAuOS01LjItNS4zLjktLjl6Ii8+CiAgICA8L2c+CiAgICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiPgogICAgICA8cGF0aCBmaWxsPSIjZDBkMGQwIiBkPSJNNzguNiAxMzQu'
    b'MmMyLjItMi4yIDcuNS0uNCAxMS44IDMuOXM2LjEgOS43IDQgMTEuOGMtMi4yIDIuMi03LjUu'
    b'NS0xMS45LTMuOXMtNi05LjctNC0xMS44eiIvPgogICAgICA8cGF0aCBmaWxsPSJncmF5IiBk'
    b'PSJNODEuMiAxMzYuOGMyLjItMi4yIDYuMy0xLjYgOS4yIDEuM3MzLjUgNyAxLjMgOS4yYy0y'
    b'LjEgMi4yLTYuMyAxLjYtOS4yLTEuM3MtMy41LTctMS4zLTkuMnoiLz4KICAgICAgPHBhdGgg'
    b'ZmlsbD0iI2QwZDBkMCIgZD0ibTg3LjggMTQ3LjgtLjktMSAxLjgtMy40LTMuNSAxLjctMS0u'
    b'OSA3LjEtMy41LTMuNSA3em0tNS4zLTUuMy0uOC0uOSA1LjItNS4yLjkuOHoiLz4KICAgIDwv'
    b'Zz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzcwNzA3MCIgc3Ryb2tlLXdpZHRo'
    b'PSIxcHQiIGQ9Ik0yNjkuMyA0MTQuNmMwIDQxLTM0LjEgNzQuNC03Ni4yIDc0LjRTMTE3IDQ1'
    b'NS43IDExNyA0MTQuNnMzNC4xLTc0LjQgNzYuMi03NC40IDc2LjIgMzMuMyA3Ni4yIDc0LjR6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCguMzQxOTEgMCAwIC4zNTAwMyA0MyAtMjUuNSkiLz4KICAg'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzcwNzA3MCIgc3Ryb2tlLXdpZHRoPSIxcHQi'
    b'IGQ9Ik0yNjkuMyA0MTQuNmMwIDQxLTM0LjEgNzQuNC03Ni4yIDc0LjRTMTE3IDQ1NS43IDEx'
    b'NyA0MTQuNnMzNC4xLTc0LjQgNzYuMi03NC40IDc2LjIgMzMuMyA3Ni4yIDc0LjR6IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCguMjYwNSAwIDAgLjI2NjY5IDU4LjYgOSkiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNkMGQwZDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTEwMC4zIDE0MC43YTEuMiAx'
    b'LjIgMCAxIDEtMi41IDAgMS4yIDEuMiAwIDAgMSAyLjUgMHptMTkuOCAwYTEuMiAxLjIgMCAx'
    b'IDEtMi41IDAgMS4yIDEuMiAwIDAgMSAyLjUgMHptLTEyIDB2MS4zaC0xLjZjLTEuNyAwLTEu'
    b'NyAxLjMgMCAxLjNoMS42djEuMmMwIDEuNCAxLjUgMS41IDEuNi4xdi0xLjRoMS43YzEuNyAw'
    b'IDEuNy0xLjIgMC0xLjJoLTEuNnYtMS4zYzAtMS4zLTEuNy0xLjMtMS43IDB6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZDBkMGQwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzcwNzA3'
    b'MCIgc3Ryb2tlLXdpZHRoPSIuMSIgZD0iTTEwMi44IDEyMi4zdi44cy0uNC41LTIuOS43Yy0y'
    b'LjUuMi0yLjkgMC0yLjkgMCAuMS43LjYgMS45LjQgMy4zLjEgMS43LS40IDMuMi0uNCAzLjIg'
    b'MCAuMS0uMy4yLS44LjEuNC0uNC40LTEuNC40LTMgMC0xLjQtMS41LTMuNy0xLjItNC4zLjMt'
    b'LjYgNy40LS44IDcuNC0uOHptOS44LTIuNiA2LjUtLjFzMSAyIC45IDNjMCAxLS40IDItLjgg'
    b'MS41LS41LS41LjItLjQuMy0xLjUgMC0xLjItLjgtMi4zLS44LTIuM3MtMS44LjctNC40LjZj'
    b'LTIuNi0uMi0xLjQtMS4yLTEuNy0xLjJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDBkMGQwIiBm'
    b'aWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzcwNzA3MCIgc3Ryb2tlLXdpZHRoPSIuMSIg'
    b'ZD0iTTExMy40IDEyMS42YzIuNC0uMSA0IC4yIDQgLjJzMSAyIDEgM2MtLjEgMS0uNCAyLS45'
    b'IDEuNS0uNC0uNC4yLS4zLjMtMS41IDAtMS4xLS44LTIuMy0uOC0yLjNzLTEuNy43LTQuMy42'
    b'Yy0yLjYtLjItMS44LS4zLTIuMS0uNC0uMyAwLS40LjgtNC4zLjktNCAwLTYtLjktNi0uOXMt'
    b'LjQuNi0yLjguOGgtM2MuMS42LjYgMS44LjUgMy4zIDAgMS42LS41IDMuMi0uNSAzLjJoLS43'
    b'Yy40LS4zLjMtMS40LjQtMi45IDAtMS41LTEuNi0zLjctMS4zLTQuNC40LS42IDIuMiAwIDIu'
    b'NS0uMy4zLS40LTEuNi0yLjctMS4yLTQuOC4zLTIuMSAyLjQtMS41IDQuOS0xLjUgMi41LjEg'
    b'OCAuOCA5LjQgMCAxLjQtLjcuOC0zLjQgMi01LjFhNC4xIDQuMSAwIDAgMSAzLjMtMS41Yy45'
    b'IDAgMiAzIDIgMy43bC0uMy40aC0uNHYuM2MtMSAuMS0xLjEtLjgtMS43LTEuNC0uMiAxIC44'
    b'IDQuNC44IDYuNiAwIDEuOC0uNyAyLjYtLjggMi41eiIvPgogICAgPHBhdGggZmlsbD0iI2Qw'
    b'ZDBkMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiM3MDcwNzAiIHN0cm9rZS13aWR0'
    b'aD0iLjEiIGQ9Ik0xMDUuNSAxMTguNGMwIC43LTMuMSAyLjQtMy40IDMtLjIuNy44IDEgLjUg'
    b'MS40LS4zLjQtLjYuMi0uNy4zbC0xLjItMi41czMtMS40IDIuOS0yYy0uMS0uNi0yLjItMS0y'
    b'LjYtMi40cy0uMi00LjMtLjUtNC45Yy0uMy0uNi00LTEuMi00LTIgMC0xIDMuOC0zLjQgNC4y'
    b'LTMuOC40LS40LjguNC40LjctLjQuNC0zLjMgMi43LTMuMyAzIDAgLjQgMi40LjggMy4yLjgu'
    b'OSAwIDEuMy0uNCAxLjMtLjggMC0uMy0uOS0uMy0uOS0xcy41LTEuMiAxLjMtMS4yYy40IDAg'
    b'MS4yLjUgMS4yIDEuMXMtLjcuNy0uOCAxLjFjLS4xLjUuOC44IDEuNi44czMuNiAyLjEgNCAy'
    b'LjVjLjUuMy45LjMuNS43LS40LjQtLjIuOC0uNi40YTEuNSAxLjUgMCAwIDEtLjQtLjdjMC0u'
    b'My0zLTEuOC0zLjUtMS41LS40LjQgMCA0LjggMCA1LjIgMCAuNy45LjcuOCAxLjh6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjYTdhN2E3IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0xMDAuMyAx'
    b'MDkuOWg1djUuMWgtNXoiLz4KICAgIDxyZWN0IHdpZHRoPSIzMC42IiBoZWlnaHQ9Ii40IiB4'
    b'PSIxMzguNiIgeT0iLTI1LjciIGZpbGw9ImdyYXkiIGZpbGwtcnVsZT0iZXZlbm9kZCIgcng9'
    b'Ii41IiByeT0iLjIiIHRyYW5zZm9ybT0ibWF0cml4KC41NTQ0MiAuODMyMjMgLS44ODIzNyAu'
    b'NDcwNTUgMCAwKSIvPgogICAgPHBhdGggZmlsbD0iI2QwZDBkMCIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2U9IiM3MDcwNzAiIHN0cm9rZS13aWR0aD0iMXB0IiBkPSJNMTgwLjcgNDIu'
    b'NWE3IDcgMCAxIDEtMTQuMiAwIDcgNyAwIDAgMSAxNC4yIDB6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCguMTE1NjMgMCAwIC4xMDM0NSA4MC43IDEwMS41KSIvPgogICAgPHBhdGggZmlsbD0iZ3Jh'
    b'eSIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMTE1LjkgMTEyLjVjMCAuMy0yIC43LTQuMS43'
    b'LTIuMiAwLTQuMS0uNC00LjEtLjcgMC0uMyAxLjkuNSA0IC41IDIuMyAwIDQuMi0uOCA0LjIt'
    b'LjV6Ii8+CiAgICA8cGF0aCBmaWxsPSIjYTdhN2E3IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0xMDAuNyAxMTVoNC4xdjEuNWgtNHoiLz4KICAgIDxwYXRoIGZpbGw9ImdyYXkiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgZD0iTTExNCAxMTEuNGMtLjQuOC0uNyAxLjMtLjggMS4yIDAgMCAu'
    b'Mi0uOC42LTEuNWwuOC0xLjJjLjEuMS0uMi44LS42IDEuNXptMSAyLS44LjVhMy4yIDMuMiAw'
    b'IDAgMSAuOC0uOWMuNS0uNC45LS42LjktLjVsLS44Ljh6Ii8+CiAgICA8cGF0aCBmaWxsPSJn'
    b'cmF5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Im0xMTQuNiAxMTIuNC41IDEuMi0uOC0xLS41'
    b'LTEuMi44IDF6bS0uNCAzLjJzLTEuMi4yLTIuOC4yLTIuOS0uMS0yLjktLjJsMi45LS4yYzEu'
    b'NiAwIDIuOCAwIDIuOC4yem0tOS40LS40YzAgLjEtLjkuMi0yIC4yLTEuMiAwLTIgMC0yLS4y'
    b'IDAgMCAuOC0uMiAyLS4yIDEuMSAwIDIgLjEgMiAuMnoiLz4KICAgIDxwYXRoIGZpbGw9IiNk'
    b'MGQwZDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSJncmF5IiBzdHJva2Utd2lkdGg9'
    b'Ii4xIiBkPSJNOTUuOCAxMjhzLjcgMS42IDMuNiAxLjZjMi44IDAgMy44LS41IDIuNy0xLjNz'
    b'LTMuNC0uNi0zIC4xYy4yLjgtLjkgMS0xLjEuNS0uMy0uNS0xLjMtMi4xLjUtMi4yIDEuOS0u'
    b'MSA1LjgtLjcgNi44LjRzLTEuMSAyIC41IDIuM2MxLjUuMiAxLjgtLjMgNC41LS40IDIuNy0u'
    b'MiAzLjguNSA0LjcuNCAxIDAgLjgtMS43IDAtMi0uNy0uNS0yLjEtLjYtMi41LTEtLjMtLjUt'
    b'MS4zIDAtMS4yLS42IDAtLjUgMS40LjMgMS40LjFsLjItLjJoLS4zbC4xLS4yLS4yLjEuMS0u'
    b'MnMtLjMuMi0uMyAwaC0uMmMuMi0uMi4xLS4yIDAtLjNoLS4zdi0uM2MtLjIgMC0uMiAwLS4z'
    b'LjJ2LS41YzAtLjEuMi0uMi41LS4yLjcgMCAxIC44IDEuMy44LjIgMCAuNS0uOCAxLjQtLjVs'
    b'MS41LjZjLjUuMy0uMy42IDAgMXMyLjEgMS43IDEuNiAzLjJjLS41IDEuNC0yIDEuNi0yIDIu'
    b'Mi0uMi42IDQuMy40IDUuNC42YTMgMyAwIDAgMSAxLjkgMS4ybC0yIC4xcy0xLS41LTMuNS0u'
    b'NmMtMi41IDAtMy40LTEtNC40LTEuMmwtNCAuMi0zLS4zYy0uNi0uMS00LjIgMS42LTQuMiAy'
    b'aC0yLjRzLjMtLjkgMS43LTFjMS4zLS4yIDIuNy0uOCAyLjYtMS4ybC40LTIuNmMwLS42LjYt'
    b'MSAuNS0xLjItLjEtLjQtMS43LS43LTMuMi0uNy0xLjUgMC0zLjEuMS0zLjQuNC0uMi40IDAg'
    b'MS41LjMgMS4zLjMgMC0uMS0uOC4yLS45YTYuOCA2LjggMCAwIDEgMi0uM2MuOCAwIDIuMS43'
    b'IDIuMSAxIDAgLjEuNC44LS4yIDEuMWE4LjIgOC4yIDAgMCAxLTMuMS40IDcuNSA3LjUgMCAw'
    b'IDEtMy0uOGMtLjQtLjMtLjctMS0uNy0xLjF6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIGQ9Ik0xMTQgMTI1LjVhLjMuMyAwIDEgMS0uNiAwIC4zLjMgMCAwIDEgLjYgMHoi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiNkMGQwZDAiIGQ9Im0xMjkuNSAxMjAuOCAxLjYuMyAyLjct'
    b'MS44LS4yIDEtMS40LjktLjguNC41LjguOSAxLjQtLjIgMS0xLjctMi45LTEuNi0uMy4yLS44'
    b'em0tMi43LTExLjggMy0xLjQtLjgtMS44LjQtLjIgMiA0LjQtLjMuMi0uOS0xLjktMyAxLjUt'
    b'LjQtLjh6bS00LjgtNS44IDIuOC0yLjYuNi42djQuNGwyLjItMiAuNS42LTIuOCAyLjYtLjYt'
    b'LjZ2LTQuNGwtMi4yIDItLjUtLjZ6bS0xMi40LTUgLjUtMy44aC44bC0uNSAzLjUgMyAuM3Yu'
    b'NWwtMy44LS41em0tNi4xLjYtLjctMy44LjgtLjIuNiAzLjQgMy0uNnYuNWwtMy43Ljd6bS0x'
    b'MS4zIDUuNS0uMy0uMyAyLTEuNiAxIDFhNS43IDUuNyAwIDAgMS0uOCAxLjIgNS43IDUuNyAw'
    b'IDAgMS0uOSAxIDUuMiA1LjIgMCAwIDEtMS40LjhjLS41LjEtMSAuMi0xLjMgMGExLjYgMS42'
    b'IDAgMCAxLTEtLjUgMS43IDEuNyAwIDAgMS0uMy0xYzAtLjQuMS0uOS40LTEuMy4yLS40LjYt'
    b'LjggMS0xLjFhNC44IDQuOCAwIDAgMSAxLjEtLjdsLjktLjJjLjIgMCAuNSAwIC43LjJsLS40'
    b'LjVhMS4zIDEuMyAwIDAgMC0uNi0uMWwtLjYuMWEzLjIgMy4yIDAgMCAwLS43LjVjLS4zLjIt'
    b'LjYuNC0uNy43YTIgMiAwIDAgMC0uNC42di41YzAgLjMuMS42LjMuOGwuNy41IDEtLjFhNC4x'
    b'IDQuMSAwIDAgMCAyLjEtMmwtLjQtLjYtMS40IDEuMXptLS4xIDI3LjctMy4yIDIuMy0yLjQt'
    b'My40LjQtLjMgMiAyLjcuOS0uNy0xLjYtMi4zLjMtLjIgMS43IDIuMyAxLjQtMSAuNS42em0t'
    b'NC43LTVjLjUtLjEuOC0uNCAxLS45di0xLjVhMi42IDIuNiAwIDAgMC0uOS0xLjNjLS4zLS4z'
    b'LS44LS40LTEuMi0uM2ExLjQgMS40IDAgMCAwLS44LjVjLS4xLjItLjMuNS0uMy44bC4xIDEu'
    b'MWMuMi42LjQgMSAuOCAxLjQuMy4zLjguNCAxLjMuMnptLjMuOGExLjcgMS43IDAgMCAxLTEu'
    b'Ny0uNCAzLjcgMy43IDAgMCAxLTEuMS0xLjhjLS4yLS42LS4yLTEtLjItMS42cy4yLS44LjQt'
    b'MS4xYTEuNiAxLjYgMCAwIDEgMS0uNyAxLjYgMS42IDAgMCAxIDEgLjFjLjQuMi43LjQgMSAu'
    b'OGE0LjUgNC41IDAgMCAxIC44IDMgMi4zIDIuMyAwIDAgMS0uNCAxLjFjLS4yLjMtLjUuNS0u'
    b'OC42em0uMy03LjhoLTR2LTIuOGwuMi0xLjIuNC0uN2EuOC44IDAgMCAxIC42LS4yYy4zIDAg'
    b'LjUuMS43LjQuMS4zLjMuNy4zIDEuM2EyLjUgMi41IDAgMCAxIC43LTEuMWwxLjEtMXYxbC0u'
    b'OC43LS42LjZhMS43IDEuNyAwIDAgMC0uMy40IDEuNiAxLjYgMCAwIDAgMCAuNHYuNGwtLjEg'
    b'MUg4OHYuOHptLTIuMi0uOXYtMS43YTQgNCAwIDAgMCAwLS45IDEgMSAwIDAgMC0uMi0uNC41'
    b'LjUgMCAwIDAtLjMtLjJjLS4yIDAtLjQuMS0uNS4zbC0uMiAxdjJoMS4zem0xMC43LTE2Ljl2'
    b'LTQuNWwuOC0uNSA0LjEgMi0uOC41LTEuMi0uNi0yLjEgMS4zdjEuNGwtLjguNHptLjctMi4z'
    b'IDEuOC0xLTEtLjZhOC4zIDguMyAwIDAgMS0uOS0uNWwuMS44djEuM3ptMTguNi0xLjJMMTIw'
    b'IDk3bC43LjUtLjMgNC42LS43LS42LjEtMS4zLTItMS41LTEuMy41LS43LS41em0yLjQtLjIg'
    b'MS43IDEuMnYtMS4yYTguNCA4LjQgMCAwIDEgLjItMSAzLjcgMy43IDAgMCAxLS43LjVsLTEu'
    b'Mi41em0xMC4zIDE0LjMgMy44LS45LjYgMi43LjIgMS4yLS4yLjdhLjguOCAwIDAgMS0uNS40'
    b'Yy0uMyAwLS42IDAtLjgtLjJhMi44IDIuOCAwIDAgMS0uNy0xLjIgMi41IDIuNSAwIDAgMSAw'
    b'IC41bC0uNC44LS44IDEuMi0uMi0xIC42LTEgLjQtLjZhMS42IDEuNiAwIDAgMCAuMi0uOCAz'
    b'LjcgMy43IDAgMCAwLS4xLS41bC0uMi0uOS0xLjcuNC0uMi0uOHptMi4zLjMuNCAxLjdjMCAu'
    b'My4yLjYuMy44IDAgLjIuMi4zLjMuNGwuNC4xYy4xIDAgLjMtLjIuMy0uNGEyLjEgMi4xIDAg'
    b'MCAwIDAtMWwtLjUtMS45LTEuMi4zeiIvPgogIDwvZz4KPC9zdmc+Cg==', 'MT')

MT = b64_MT
index.append("MT")
index.append("MLT")
index.append("Malta")
catalog["MT"] = MT
catalog["MLT"] = MT
catalog["Malta"] = MT
country["Malta"] = ('MT', 'MLT', 0)
lookup["MT"] = ('MT', 'MLT', 'Malta', 0)
lookup["Valletta Malta"] = ('MT', 'MLT', 'Malta', 0)
lookup["MLT"] = ('MT', 'MLT', 'Malta', 0)
lookup["Malta"] = ('MT', 'MLT', 'Malta', 0)
details["MT"] = {"continent":"Europe","capital":"Valletta","currency":"Euro","web":".mt","lang":"mt | en-MT","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_MU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW11IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMGEwNGQiIGQ9Ik0wIDM2MGg2NDB2MTIwSDB6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjMTUxZjZkIiBkPSJNMCAxMjBoNjQwdjEyMEgweiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2VlMjczNyIgZD0iTTAgMGg2NDB2MTIwSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZjZDAwIiBkPSJNMCAyNDBoNjQwdjEyMEgweiIvPgogIDwvZz4KPC9zdmc+Cg==', 'MU')

MU = b64_MU
index.append("MU")
index.append("MUS")
index.append("Mauritius")
catalog["MU"] = MU
catalog["MUS"] = MU
catalog["Mauritius"] = MU
country["Mauritius"] = ('MU', 'MUS', 0)
lookup["MU"] = ('MU', 'MUS', 'Mauritius', 0)
lookup["Port Louis Mauritius"] = ('MU', 'MUS', 'Mauritius', 0)
lookup["MUS"] = ('MU', 'MUS', 'Mauritius', 0)
lookup["Mauritius"] = ('MU', 'MUS', 'Mauritius', 0)
details["MU"] = {"continent":"Africa","capital":"Port Louis","currency":"Mauritius Rupee","web":".mu","lang":"en-MU | bho | fr","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_MV = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW12IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2QyMTAzNCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwN2UzYSIgZD0iTTEyMCAxMjBo'
    b'NDAwdjI0MEgxMjB6Ii8+CiAgPGNpcmNsZSBjeD0iMzUwIiBjeT0iMjQwIiByPSI4MCIgZmls'
    b'bD0iI2ZmZiIvPgogIDxjaXJjbGUgY3g9IjM4MCIgY3k9IjI0MCIgcj0iODAiIGZpbGw9IiMw'
    b'MDdlM2EiLz4KPC9zdmc+Cg==', 'MV')

MV = b64_MV
index.append("MV")
index.append("MDV")
index.append("Maldives")
catalog["MV"] = MV
catalog["MDV"] = MV
catalog["Maldives"] = MV
country["Maldives"] = ('MV', 'MDV', 0)
lookup["MV"] = ('MV', 'MDV', 'Maldives', 0)
lookup["Male Maldives"] = ('MV', 'MDV', 'Maldives', 0)
lookup["MDV"] = ('MV', 'MDV', 'Maldives', 0)
lookup["Maldives"] = ('MV', 'MDV', 'Maldives', 0)
details["MV"] = {"continent":"Asia","capital":"Male","currency":"Rufiyaa","web":".mv","lang":"dv | en","tz":"+05:00","altname":""}
#----------------------------------------------------------------------
b64_MW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW13IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZjQxNDA4IiBkPSJNMCAwaDY0'
    b'MHY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMyMTg3M2IiIGQ9Ik0wIDMyMGg2NDB2MTYw'
    b'SDB6Ii8+CiAgICA8cGF0aCBkPSJNMCAwaDY0MHYxNjBIMHoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNmMzE1MDkiIGQ9Ik0yMjAuNSAxNDFjMjIuMy00OS4yIDg0LjUtNzIuOCAxMzguOC01Mi41'
    b'YTk4LjQgOTguNCAwIDAgMSA1OCA1Mi41SDIyMC41em0tMjYgNi40YTMzMi4zIDMzMi4zIDAg'
    b'MCAxLTUyLjQtNy44Yy00LjEtMS4zLTQuMy0zLjYtMy44LTUuMy41LTEuNyAzLjEtMy42IDYu'
    b'Mi0zIDUuNiAxLjQgMjguOCA3IDUwIDE2LjF6bTEyNC42LTg1LjljLTQuMi0yMS01LjItNDQt'
    b'NC44LTQ4QzMxNC43IDkuNiAzMTcgOSAzMTkgOXM0LjcgMS44IDQuNyA0LjdjMCA1LjMtLjEg'
    b'MjctNC42IDQ4em0xMS42LjVhMjQ5IDI0OSAwIDAgMS0uMy00OC4yYy44LTMuOSAzLjItNC40'
    b'IDUuMS00LjIgMiAuMSA0LjUgMi4xIDQuMiA1LS41IDUuMy0yLjYgMjYuOS05IDQ3LjR6bTEw'
    b'LjQgMS4zYy0uMi0yMS4zIDMtNDQuMyA0LjEtNDggMS4xLTMuOSAzLjYtNC4yIDUuNS0zLjkg'
    b'MiAuMyA0LjMgMi41IDMuOCA1LjMtMSA1LjMtNS4yIDI2LjYtMTMuNCA0Ni42em0xMSAyLjJj'
    b'MS44LTIxLjIgNy4zLTQzLjggOC44LTQ3LjUgMS41LTMuNyA0LTMuOCA1LjgtMy40IDIgLjUg'
    b'NCAyLjggMy4zIDUuNi0xLjYgNS4xLTcuNyAyNi0xNy44IDQ1LjN6bTEwLjkgMy4yYzMuOS0y'
    b'MSAxMS41LTQzLjEgMTMuMy00Ni43IDEuOS0zLjUgNC4zLTMuNSA2LjItMi45IDEuOC42IDMu'
    b'NyAzLjIgMi43IDUuOEEyNjQgMjY0IDAgMCAxIDM2MyA2OC43em0xMC4xIDMuOGM1LjgtMjAu'
    b'NyAxNS41LTQyIDE3LjctNDUuNSAyLjItMy40IDQuNi0zLjEgNi40LTIuMyAxLjguNyAzLjQg'
    b'My40IDIuMSA2LTIuNSA0LjgtMTIuNSAyNC40LTI2LjIgNDEuOHptMTAgNC43YTI2Mi45IDI2'
    b'Mi45IDAgMCAxIDIyLTQzLjljMi40LTMuMiA0LjktMi43IDYuNi0xLjhhNC40IDQuNCAwIDAg'
    b'MSAxLjUgNi4xYy0zIDQuNi0xNC45IDIzLjQtMzAuMSAzOS42em05LjQgNS41YzkuNy0xOS40'
    b'IDIzLjMtMzkgMjYuMS00MiAyLjgtMyA1LjItMi4zIDYuOC0xLjNhNC40IDQuNCAwIDAgMSAx'
    b'IDYuMmMtMy41IDQuNC0xNy4yIDIyLjEtMzQgMzd6bTguOCA2LjJjMTEuNi0xOC42IDI3LTM3'
    b'IDMwLjEtMzkuNyAzLTIuOCA1LjQtMiA2LjktLjhhNC4zIDQuMyAwIDAgMSAuMyA2LjJjLTMu'
    b'OCA0LjEtMTkuMSAyMC43LTM3LjMgMzQuM3ptOC4zIDYuOWEyODQgMjg0IDAgMCAxIDMzLjgt'
    b'MzcuMmMzLjMtMi41IDUuNS0xLjUgNi45LS4zYTQuMyA0LjMgMCAwIDEtLjMgNi4zYy00LjEg'
    b'My44LTIxIDE5LjEtNDAuNCAzMS4yem03LjYgNy41QTI3OC40IDI3OC40IDAgMCAxIDQ1NC40'
    b'IDY5YzMuNi0yLjMgNS43LTEuMSA3IC4zIDEuMiAxLjMgMS41IDQuNC0xIDYuMmEzMDYgMzA2'
    b'IDAgMCAxLTQzLjIgMjcuOHptNi41IDcuOEEyOTcuMSAyOTcuMSAwIDAgMSA0NjQgNzkuNmMz'
    b'LjctMiA1LjctLjYgNi44LjkgMS4yIDEuNCAxLjEgNC41LTEuNCA2LjEtNC44IDMtMjQuMyAx'
    b'NS42LTQ1LjcgMjQuNXptNS45IDguM2EzMDcgMzA3IDAgMCAxIDQzLTI4LjFjNC0xLjcgNS45'
    b'LS4yIDYuOSAxLjMgMSAxLjYuNiA0LjYtMiA2YTMyMC44IDMyMC44IDAgMCAxLTQ4IDIwLjh6'
    b'bTUuNCA5LjZhMzEzLjQgMzEzLjQgMCAwIDEgNDUuOC0yNC40YzQuMS0xLjQgNS44LjMgNi42'
    b'IDEuOS45IDEuNi4zIDQuNi0yLjYgNS44LTUuMyAyLjItMjcgMTEuNC00OS44IDE2Ljd6bTQu'
    b'MiA5LjJhMzIwIDMyMCAwIDAgMSA0OC0yMC44YzQuMi0xIDUuNy44IDYuNCAyLjUuNiAxLjYt'
    b'LjMgNC42LTMuMiA1LjUtNS41IDEuOS0yOCA5LjMtNTEuMiAxMi44em0zLjQgOS44YTMyNC41'
    b'IDMyNC41IDAgMCAxIDQ5LjgtMTYuOWM0LjItLjYgNS42IDEuMiA2LjEgMyAuNSAxLjctLjcg'
    b'NC41LTMuNyA1LjMtNS43IDEuMy0yOC44IDctNTIuMiA4LjZ6TTMwNy44IDYyYTI1Mi40IDI1'
    b'Mi40IDAgMCAxLTkuNy00Ny40YzAtMy45IDIuMy00LjggNC4yLTUgMi0uMSA1IDEuNSA1LjIg'
    b'NC4zLjUgNS4zIDIuNiAyNi45LjQgNDguMXptLTExIDEuM2EyNTEgMjUxIDAgMCAxLTE0LjMt'
    b'NDYuNGMtLjQtNCAxLjgtNSAzLjctNS4zIDItLjMgNSAxIDUuNiAzLjhhMjYzIDI2MyAwIDAg'
    b'MSA1IDQ3Ljl6bS0xMSAyLjJBMjU5IDI1OSAwIDAgMSAyNjcgMjAuM2MtLjgtMy45IDEuMy01'
    b'LjEgMy4yLTUuNiAxLjktLjQgNSAuNiA1LjkgMy40IDEuNSA1LjEgNy43IDI2IDkuNiA0Ny4z'
    b'em0tMTAuNSAzQTI2NCAyNjQgMCAwIDEgMjUyLjUgMjVjLTEuMS0zLjguOC01LjIgMi42LTUu'
    b'OCAxLjktLjYgNS4xLjIgNi4yIDIuOCAyIDUgMTAuMiAyNS40IDE0IDQ2LjR6TTI2NS4yIDcy'
    b'YTI3MC40IDI3MC40IDAgMCAxLTI3LTQxLjVjLTEuNC0zLjcuNC01LjMgMi4yLTYgMS44LS44'
    b'IDUtLjIgNi40IDIuNCAyLjUgNC44IDEyLjUgMjQuNSAxOC40IDQ1LjF6bS0xMC4zIDVhMjc1'
    b'LjYgMjc1LjYgMCAwIDEtMzEtMzkuMmMtMS43LTMuNS0uMS01LjIgMS42LTYuMSAxLjctLjkg'
    b'NS0uNiA2LjYgMS45IDMgNC42IDE1IDIzLjMgMjIuOCA0My40em0tOS40IDUuNEEyODUuMiAy'
    b'ODUuMiAwIDAgMSAyMTEgNDUuN2MtMi4xLTMuNC0uNy01LjIgMS02LjMgMS41LTEgNS0xIDYu'
    b'NyAxLjQgMy40IDQuMyAxNy4xIDIyIDI2LjggNDEuNXptLTguNyA2YTI5Mi4yIDI5Mi4yIDAg'
    b'MCAxLTM3LjktMzMuOWMtMi40LTMuMi0xLjEtNSAuNC02LjJhNS41IDUuNSAwIDAgMSA2Ljgu'
    b'OGMzLjggNCAxOS4yIDIwLjcgMzAuNyAzOS4zem0tOC41IDdhMjk5IDI5OSAwIDAgMS00MS0z'
    b'MC43Yy0yLjgtMy0xLjctNS0uMy02LjNhNS41IDUuNSAwIDAgMSA2LjkuM2M0LjIgMy43IDIx'
    b'IDE5IDM0LjQgMzYuNnptLTcuNCA3QTMwNi42IDMwNi42IDAgMCAxIDE3Ny4yIDc1Yy0zLTIu'
    b'OC0yLjEtNC44LS44LTYuMiAxLjItMS40IDQuNS0yLjEgNi45LS4zYTI5MiAyOTIgMCAwIDEg'
    b'MzcuNiAzNHptLTcgOC4yYTMxMyAzMTMgMCAwIDEtNDYuMi0yMy44Yy0zLjMtMi41LTIuNi00'
    b'LjctMS41LTYuMSAxLjEtMS41IDQuMy0yLjUgNi45LS45IDQuOCAzLjEgMjQuMyAxNS41IDQw'
    b'LjggMzAuOHptLTYuMyA4LjhjLTIyLjItNy00NC45LTE3LjYtNDguNC0xOS45LTMuNi0yLjIt'
    b'My00LjQtMi4xLTZzNC0yLjggNi44LTEuNGM1IDIuNyAyNS44IDEzLjUgNDMuNyAyNy4zem0t'
    b'NS4zIDljLTIyLjgtNS4zLTQ2LjMtMTQtNTAuMS0xNi0zLjctMi0zLjUtNC4yLTIuNi01Ljgu'
    b'OC0xLjYgMy43LTMuMSA2LjYtMiA1LjMgMi4zIDI3IDExLjQgNDYuMSAyMy44em0tNC4yIDlh'
    b'MzI4LjUgMzI4LjUgMCAwIDEtNTEuNC0xMi4yYy00LTEuNi0zLjgtMy45LTMuMi01LjUuNy0x'
    b'LjcgMy41LTMuNCA2LjQtMi41IDUuNiAxLjkgMjggOS4zIDQ4LjIgMjAuMnoiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmMzE1MDkiIGQ9Ik0xOTQuNSAxNDcuNGEzMzIuNCAzMzIuNCAwIDAgMS01'
    b'Mi40LTcuOGMtNC4xLTEuMy00LjMtMy42LTMuOC01LjMuNS0xLjcgMy4xLTMuNiA2LjItMyA1'
    b'LjYgMS40IDI4LjggNyA1MCAxNi4xeiIvPgogICAgPHBhdGggZD0iTTEyOS40IDE0MS41aDM4'
    b'MS4ydjEyLjZIMTI5LjR6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'MW')

MW = b64_MW
index.append("MW")
index.append("MWI")
index.append("Malawi")
catalog["MW"] = MW
catalog["MWI"] = MW
catalog["Malawi"] = MW
country["Malawi"] = ('MW', 'MWI', 0)
lookup["MW"] = ('MW', 'MWI', 'Malawi', 0)
lookup["Lilongwe Malawi"] = ('MW', 'MWI', 'Malawi', 0)
lookup["MWI"] = ('MW', 'MWI', 'Malawi', 0)
lookup["Malawi"] = ('MW', 'MWI', 'Malawi', 0)
details["MW"] = {"continent":"Africa","capital":"Lilongwe","currency":"Malawi Kwacha","web":".mw","lang":"ny | yao | tum | swk","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_MX = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1teCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHJhZGlhbEdyYWRpZW50IHhsaW5rOmhy'
    b'ZWY9IiNteC1hIiBpZD0ibXgtYiIgY3g9Ijg0Mi4zIiBjeT0iMTAzLjciIHI9IjI1LjkiIGdy'
    b'YWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoLjE0MTUyIC4wMzU5NSAtLjAzNDUzIC4xNDE5OCAy'
    b'MTMuMSAxNjIuNCkiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIi8+CiAgICA8cmFk'
    b'aWFsR3JhZGllbnQgeGxpbms6aHJlZj0iI214LWEiIGlkPSJteC1jIiBjeD0iNjUxLjUiIGN5'
    b'PSI1NTAuNSIgcj0iMjUuOSIgZ3JhZGllbnRUcmFuc2Zvcm09Im1hdHJpeCgtLjEzNDQxIC0u'
    b'MDUzODQgLjA0OTY0IC0uMTI0ODkgMzk3LjkgLTI0LjMpIiBncmFkaWVudFVuaXRzPSJ1c2Vy'
    b'U3BhY2VPblVzZSIvPgogICAgPHJhZGlhbEdyYWRpZW50IHhsaW5rOmhyZWY9IiNteC1hIiBp'
    b'ZD0ibXgtZCIgY3g9IjM4MC44IiBjeT0iNzQwLjQiIHI9IjI1LjkiIGdyYWRpZW50VHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjA3NTM2IC4wMDI4MiAtLjAwMzQzIC4xNDgwNCA0MTIuNCAtMjAzLjYp'
    b'IiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIvPgogICAgPGxpbmVhckdyYWRpZW50'
    b'IGlkPSJteC1hIj4KICAgICAgPHN0b3Agb2Zmc2V0PSIwIiBzdG9wLWNvbG9yPSIjZmZmIi8+'
    b'CiAgICAgIDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iI2YxNTc3MCIvPgogICAgPC9s'
    b'aW5lYXJHcmFkaWVudD4KICA8L2RlZnM+CiAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0iTTQy'
    b'Ni43IDBINjQwdjQ4MEg0MjYuN3oiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjEzLjMg'
    b'MGgyMTMuNHY0ODBIMjEzLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzAwNjg0NyIgZD0iTTAgMGgy'
    b'MTMuM3Y0ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAi'
    b'IHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0zNTUuOCAyODkuNC4yIDQuNSAxLjctMS4xLTEuMy0z'
    b'Ljd6Ii8+CiAgPGNpcmNsZSBjeD0iMzU1LjYiIGN5PSIyODguMiIgcj0iMS40IiBmaWxsPSIj'
    b'ZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0z'
    b'NjEuMSAyOTYuNC0zLjItMy4xLTEuNSAxLjIgNC41IDIuNnoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik0zNjAuOSAy'
    b'OTguMmMtLjUtLjYtLjMtMS41LjMtMiAuNy0uNSAxLjYtLjQgMiAuMi41LjYuMyAxLjUtLjMg'
    b'Mi0uNy41LTEuNi40LTItLjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjY2EzZSIgc3Ryb2tlPSIj'
    b'YWE4YzMwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtMzg2LjMgMjQ5LjYgMy40IDMuMy40LTEu'
    b'Ny0zLjEtMnoiLz4KICA8Y2lyY2xlIGN4PSIzODUuOSIgY3k9IjI0OC43IiByPSIxLjQiIGZp'
    b'bGw9IiNmY2NhM2UiIHN0cm9rZT0iI2FhOGMzMCIgc3Ryb2tlLXdpZHRoPSIuMiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmY2NhM2UiIHN0cm9rZT0iI2FhOGMzMCIgc3Ryb2tlLXdpZHRoPSIuMyIg'
    b'ZD0iTTM5NS4yIDI1MS42IDM5MCAyNTNsLjUtMS43IDQuNC0uNHoiLz4KICA8Y2lyY2xlIGN4'
    b'PSIzOTYiIGN5PSIyNTAuOCIgcj0iMS40IiBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThj'
    b'MzAiIHN0cm9rZS13aWR0aD0iLjIiLz4KICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJva2U9'
    b'IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0zNzggMjc2LjgtMy4yLTQuOC41LS4z'
    b'IDMuNSA0LjJ6Ii8+CiAgPGNpcmNsZSBjeD0iMzc0LjUiIGN5PSIyNzAuOCIgcj0iMS40IiBm'
    b'aWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiLz4KICA8'
    b'cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjMi'
    b'IGQ9Im0zNzguMSAyNzcgNCAuNy4xLS41LTMuMy0xLjR6Ii8+CiAgPGNpcmNsZSBjeD0iMzgz'
    b'LjMiIGN5PSIyNzcuNyIgcj0iMS40IiBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAi'
    b'IHN0cm9rZS13aWR0aD0iLjIiLz4KICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNh'
    b'YThjMzAiIHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik0yODQuNiAyODhjMCAuOC0uNSAxLjItMSAx'
    b'LjJzLTEtLjUtMS0xLjIuNS0xLjMgMS0xLjMgMSAuNyAxIDEuNHoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0yODQu'
    b'NiAyOTAuMyAxIDUtMS4zLS41LS40LTQuM3oiLz4KICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBz'
    b'dHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik0yODUuNyAyODguNmMuNi43'
    b'LS40IDEuOS0xLjQgMi4yLTEgLjMtMi40LS4yLTIuNC0xLjJzMS42LS41IDItLjZjLjYtLjIg'
    b'MS4yLTEuMiAxLjgtLjR6Ii8+CiAgPGVsbGlwc2UgY3g9IjI3NyIgY3k9IjI5Ni4zIiBmaWxs'
    b'PSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiIHJ4PSIxLjYi'
    b'IHJ5PSIxLjEiLz4KICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0'
    b'cm9rZS13aWR0aD0iLjMiIGQ9Im0yNzkuNiAyOTYgNC44LS4yLS44LTEtNCAuNHoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIi'
    b'IGQ9Ik0yODAgMjk1LjRjLjUgMS4zLjUgMy0uOSAyLjctMS40LS4xLTEtMS40LTEuMi0xLjgt'
    b'LjItLjktMS0xLjctLjItMi41czIgLjQgMi4zIDEuNnoiLz4KICA8ZWxsaXBzZSBjeD0iMjY0'
    b'LjQiIGN5PSIyNjkuMiIgZmlsbD0iI2ZjY2EzZSIgc3Ryb2tlPSIjYWE4YzMwIiBzdHJva2Ut'
    b'd2lkdGg9Ii4yIiByeD0iLjkiIHJ5PSIxLjQiLz4KICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBz'
    b'dHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0yNjQuNCAyNzIuNC4xIDQu'
    b'Ni0xLjItMXYtMy44eiIvPgogIDxwYXRoIGZpbGw9IiNmY2NhM2UiIHN0cm9rZT0iI2FhOGMz'
    b'MCIgc3Ryb2tlLXdpZHRoPSIuMiIgZD0iTTI2Ni4yIDI3MWMuMyAxLTEuMyAxLjYtMi40IDEu'
    b'NC0xLS4yLTEuOS0uNy0xLjctMS43LjEtMSAxLjUtLjggMi0uNS40LjMgMS44LS44IDIuMS43'
    b'eiIvPgogIDxlbGxpcHNlIGN4PSIyNTYuMiIgY3k9IjI3Ni41IiBmaWxsPSIjZmNjYTNlIiBz'
    b'dHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiIHJ4PSIxLjYiIHJ5PSIuNyIvPgog'
    b'IDxwYXRoIGZpbGw9IiNmY2NhM2UiIHN0cm9rZT0iI2FhOGMzMCIgc3Ryb2tlLXdpZHRoPSIu'
    b'MyIgZD0ibTI1OS4xIDI3Ni41IDMuNi0uMyAxLjYgMS4yLTUuMy0uMnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik0y'
    b'NTcuOCAyNzQuNWMxIDAgMS42IDEuMSAxLjUgMi4zLS4yIDEuMS0xIDItMiAyLS45LS4yLS44'
    b'LTEtLjgtMS4yIDAtLjMuNS0uNy42LTEgMC0uNC0uMy0xLjMtLjEtMS42IDAtLjQuMy0uNS44'
    b'LS41em0tMy0yOC4zYy0uNC42LTEuMiAxLjEtMS42LjktLjQtLjMtLjItMS4yLjItMS44LjQt'
    b'LjcgMS0xIDEuNC0uOC40LjMuNCAxIDAgMS43eiIvPgogIDxwYXRoIGZpbGw9IiNmY2NhM2Ui'
    b'IHN0cm9rZT0iI2FhOGMzMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTI1MC43IDI1My41IDIt'
    b'NC44LS4yLS4zLTIuNCAzLjR6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjY2EzZSIgc3Ryb2tlPSIj'
    b'YWE4YzMwIiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJNMjUyLjQgMjQ4LjdjLTEtLjctMS4yLTEu'
    b'NS0xLTIuMy40LS43IDEuMi0uMiAxLjItLjJsLjguN2MuNC4yIDEgMCAxLjQuNi41LjYuMiAx'
    b'LjItLjEgMS40LS40LjEtMS41LjQtMi4zLS4yem0tOC41LS42Yy43LjQgMS4xIDEgLjkgMS41'
    b'LS4zLjUtMSAuNS0xLjggMC0uNy0uMy0xLTEtLjgtMS41LjItLjQgMS0uNSAxLjcgMHoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0i'
    b'LjMiIGQ9Im0yNDYgMjUwLjIgMy44IDIuMi0uMSAxLjgtNC4xLTMuNXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZmNjYTNlIiBzdHJva2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik0y'
    b'NDYgMjUwLjZjLS44IDEtMS42IDEtMi4zLjctLjctLjUtLjEtMS4yLS4xLTEuMmwuOC0uN2Mu'
    b'Mi0uNCAwLTEgLjctMS40LjctLjQgMS4yIDAgMS4zLjMuMS40LjMgMS41LS40IDIuM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjYWE4YzMwIiBkPSJtMzU2LjYgMjg5LjgtLjQuNC0uMyAxdi0xLjVs'
    b'LjUtLjMuMi40em0uMi0uOXMtLjMuNS0xLjEuNS0xLjItLjQtMS4zLS44Yy0uMS0uNC0uMS0u'
    b'Ny4yLTEuMi4yLS41LS40LjQtLjQuNHYxbC42LjYuNS4yaC40bC43LS4yLjQtLjN2LS4yem00'
    b'LjIgNy4zcy0uNC4yLS43LjFjLTEuOS0uNi0zLjUtMS44LTMuNS0xLjhsMy44IDIuNC40LS43'
    b'em0yLjQgMS4xczAgLjctLjggMWMtLjcuMy0xLjIuMi0xLjUtLjFzLS40LS42LS40LTEuMmwt'
    b'LjEuNi40LjguOC40LjUtLjEuNS0uMi40LS41LjMtLjUtLjEtLjJ6bTI0LjMtNDcuNi0uMS40'
    b'di43bC0uOS0xIC40LS41LjYuNHptLS41LTEuMmMwIC43LS45IDEuNi0xLjYgMS4zLS43LS4z'
    b'LTEuMi0xLS45LTEuOGwtLjIuMy4xIDEuMS43LjZoLjlsLjYtLjMuNC0uN3YtLjV6bTEwIDEu'
    b'OHMtLjEtLjQgMCAwLS42IDEuNy0xLjQgMS42Yy0uNy0uMS0xLS44LTEtMS40IDAtLjYtLjEu'
    b'Mi0uMS4ydi44bC41LjQuNi40LjYtLjIuNy0uMy4yLS42di0uOXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjYWE4YzMwIiBkPSJNMzkzLjggMjUxczAgLjQtLjQuN2wtMS4zLjcgMi44LS44LS4yLS43'
    b'LS45LjJ6bS0xNy4xIDIyLjUtLjEuNXYuOGwtMS42LTIuNS41LS4zIDEuMiAxLjV6bS0uOS0y'
    b'LjRjLS4yLjctMS40IDEtMiAuOC0uNS0uNC0xLTEuNi0uMy0ybC0uNC4yLS4xLjcuMi43LjYu'
    b'Ny41LjEuOC0uMi42LS40cy40LTEuMy4xLS42em01LjYgNS43czAgLjMtLjUuM2gtMS42bDIu'
    b'Ni42LjItLjYtLjctLjN6Ii8+CiAgPHBhdGggZmlsbD0iI2FhOGMzMCIgZD0iTTM4NC42IDI3'
    b'Ny41Yy4zLjgtLjUgMS43LTEuNSAxLjQtMS0uMy0xLjMtMS4zLTEtMS44bC0uMi42LjIuOC42'
    b'LjZoMS4zbC42LS43LjItLjctLjEtLjJ6bS05OSAxMS4xYy4zLjMtLjEgMS41LTEuMiAyLTEu'
    b'Mi40LTEuNyAwLTItLjQtLjMtLjQtLjMtLjgtLjMtLjhsLS4yLjIuMi42LjUuNSAxIC4yLjgt'
    b'LjEuNy0uNS40LS4zLjMtLjV2LS42bC0uMS0uM3oiLz4KICA8cGF0aCBmaWxsPSIjYWE4YzMw'
    b'IiBkPSJtMjg0LjYgMjkxLjEtLjMuNC0uMy44di0xLjRsLjUtLjMuMS41em0tMy44IDRzMCAu'
    b'My4yLjVsMSAuM2gtMS44bC0uMi0uN2guOHptLS42IDEuMnYuMmExLjQgMS40IDAgMCAxLS4x'
    b'LjVjLS4yLjUtLjMgMS0xIC45YTEuMiAxLjIgMCAwIDEtMS0xLjFjMC0uNC0uMi0uNi0uMi0u'
    b'NnYuNmwuNCAxIC43LjNoLjVsLjUtLjIuMi0uNi4xLS41di0uNXptLTQuNy0uMXMuMi44IDEu'
    b'Mi44IDEuMi0uMiAxLjItLjJ2LjNsLS4yLjJIMjc2bC0uMy0uMy0uMy0uNXYtLjN6bS05LjQt'
    b'MjUuNHYuNGMtLjEuMy0uNyAxLTEuOCAxLTEgMC0xLjUtLjMtMS44LS43LS4zLS4zLS40LS44'
    b'LS40LS44di41bC40LjcgMS4xLjVoMWwxLS4zLjUtLjUuMS0uNi0uMS0uMnptLTEuNyAyLjNz'
    b'LS40IDAtLjYuMmE0IDQgMCAwIDAtLjQuNHYtMS4zaDF2Ljd6bS00LjcgMy40LjUuM2MuNS4z'
    b'IDMuMS41IDMuMS41aC00LjFsLjEtLjhoLjR6bS0uNSAwLS4yLjZjLS4yLjUtLjcgMS42LTEu'
    b'NiAxLjQtLjktLjEtLjctLjgtLjctLjh2LS40bC0uMi43LjIuNC40LjIuNy4xLjQtLjIuNi0u'
    b'NS4yLS41LjItLjZ2LS4zem0tMi4yLjJzMCAuMi0uNy4yLTEuNy0uMy0xLjctLjNsLjQuNC41'
    b'LjJoMS4zbC4yLS41em0tMi0yOXMwIC41LS4zLjhjLS40LjMtMS4zLjUtMS44LjJzLTEuNS0x'
    b'LjMtMS41LTEuM2wuNC44LjcuNiAxIC4zIDEtLjIuNC0uNC4yLS4zLS4yLS40eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNhYThjMzAiIGQ9Ik0yNTIgMjQ5LjF2LjZsLS4yIDEuMS45LTItLjQtLjIt'
    b'LjMuNXptLTUuNCAxLjUuMi41Yy4yLjUgMi4zIDIuNiAyLjMgMi42bC0zLjMtMi45LjQtLjUu'
    b'NC4zem0tMSAuM3MtLjUuMy0xIC4zYy0uMyAwLTEgMC0xLS40LS4xLS41LjEtLjcuMS0uN2wt'
    b'LjMuNi4xLjQuNS4zaC43bC42LS4zLjItLjJ6bS0xLjUtMS40aC0uNWMtLjcgMC0xLjQtLjgt'
    b'MS40LS44bC41LjggMSAuNS40LS41eiIvPgogIDxwYXRoIGZpbGw9IiM5Y2ExNjgiIGQ9Ik0z'
    b'OTkuOSAyNDAuMmMtLjMgMy44LTQuMSA1LjgtNi4xIDcuMi0yIDEuNC0zIDMuMi0zIDMuMmwt'
    b'LjYgMi4yLS4zIDEuNS0uMS41Yy4xLjQuMyAxIC4zIDJsLS4xIDQuMyAyLjctMS45IDEuOS0u'
    b'Ny42LS4xcy0yLjIgMi4xLTMgNC40Yy0uOCAyLjMtMi40IDcuMi01LjMgOC44LTMgMS42LTQu'
    b'OCAxLTUuNyAxLjgtMSAuOC0xIDEtMSAxbC0xLjMgMS44LTEgMS4yLS45LjctLjYuNGE3LjUg'
    b'Ny41IDAgMCAxLS4yIDEuN2wtLjcgMi40cy42LS40IDEuMy0uNWgxLjNzLS41LjYtLjcgMS4z'
    b'Yy0uMi42LjEgNC42LTMuNiA3LTMuOCAyLjMtMTMuNCAyLTEzLjQgMmwtMS44LjctMS43IDEu'
    b'My0xLjYgMS43di40cy0xLjMgMS41LTIuMSAybC0yLjggMS45IDIuMi4xIDMuNSAxLjVzLTIu'
    b'MiAwLTMuNi41Yy0xLjUuNi04LjIgNC40LTExLjQgNC4zLTMuMy0uMS04LTQuOS04LTQuOWwt'
    b'Mi0xLjQtMy41LS43LTQuMy0uMnYtLjZsLjEtLjdzMS41LS4yIDMuOC4xYzIgLjIgMi43IDEg'
    b'NC40IDEuMSAxLjcuMiAzIDAgMy41LS4zLjctLjMgNS45LTQuNyA1LjktNC43bDUuOC0yIDIu'
    b'My4zIDEgLjIuOS4zLTEgMWE3LjMgNy4zIDAgMCAxLTEuNCAxLjFsLjcuNiAzLjctLjYgMS4y'
    b'LjMuMy4yYzAtLjMuMi0uOC42LTEuMy40LS42IDIuNS0yLjMgMy40LTIuOWwxLjQtMWMuMy0u'
    b'MyAxLjUtMy4zIDEuNS0zLjNsLjEtMS42IDQuMS00IDIuOC0yLjkgMS4yLTMuMy0uMi0uN3Mx'
    b'IDEgLjkgM2MtLjIgMi4yLS43IDIuOS0uNyAyLjlzMi44LTIgNC4zLTIuNmMxLjItLjUgMi0u'
    b'NSAyLjQtLjUuNC0uMiAxLjUtLjkgMi4xLTEuOC44LTEuMiAxLTEuNSAxLTJsLjItMi44LS4z'
    b'LTcgMi40LTUuNCAzLjUtMy4xLjctLjQtLjQgMS4ydjEuNXMxLjgtMi41IDIuNy0yLjlsLjUt'
    b'LjNhNyA3IDAgMCAwIC44LTJsLjMtM3YtM2wtLjUtMi4zLTEuNy00LjN2LTUuOGwtMS4yLTEu'
    b'NnMxLjEgMCAyLjUgMmExMy41IDEzLjUgMCAwIDEgMS45IDVsMy4zLTEwLjNzLjkgMS4yIDEu'
    b'NSAzLjNsLjggMy4zIDEuNC0yLjguMSAxYy4yIDEgMi4zIDIuMSAyIDZ6bS02Ny4zIDY1cy0u'
    b'Ny0xLjYtMy45LTMuMmMtMy4xLTEuNS01LjUtMS44LTUuNS0xLjh2MS4xbDUgMi4yIDIuNCAy'
    b'IDItLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzcxNzczMiIgZD0iTTM1NS40IDI5NS42Yy4zLS40'
    b'IDMtMi44IDQuNC0zLjVzMy4yLS44IDMuMi0uOGMxLjktLjQgMi4yLS4xIDYuNi0yLjUgNC4z'
    b'LTIuNCA1LjMtNS4yIDYuMi01LjkuOC0uNyAyLjMtLjggMi4zLS44bC0zLjQgMy45YTI4LjUg'
    b'MjguNSAwIDAgMS01LjggNC41IDE3LjggMTcuOCAwIDAgMS03LjYgMS44IDcuNyA3LjcgMCAw'
    b'IDAtNCAyYy0xLjMgMS0yIDIuMi0yIDIuMnMtLjItLjUgMC0uOXptMTItMTIuN2MtNCAzLjct'
    b'NS4zIDcuMi01LjMgNy4ybDUuNC00LjljMS45LTEuOCA0LjUtMi42IDUuNi0zLjcgMS4yLTEu'
    b'MSAxLjMtMiAyLTIuN2wxLjMtMXMtMS44LTEuNC05IDUuMXptLTguNSA4LjZzMS43LS44IDIu'
    b'NC0yLjNjLjUtMS4yLjItMS41IDEtMi44IDAgMCA0LjItNCA1LjctNS44IDIuNi0zLjEgMS40'
    b'LTUuNyAxLjQtNS43cy4zIDEuMy0uOCAyLjdjLTEgMS40LTYuNSA1LTcuMiA3LjItLjYgMi4y'
    b'LS4zIDIuMy0uNiAzLjQtLjYgMi42LTEuOSAzLjMtMS45IDMuM3ptLTIuOCAxMC41cy0yLjEt'
    b'MS40LTQuNS0xLjNjLTQuOS40LTkgMy40LTEyLjIgMy40LTMuMS4xLTQuNC0xLjUtNi45LTMu'
    b'Mi0yLjYtMS44LTkuMi0xLjUtOS4yLTEuNXYuM3M0LjQgMCA2LjQuNmMzLjYgMSA1LjYgNC44'
    b'IDkuNyA0LjYgNS41LS4zIDkuOS0zLjYgMTItMy42IDMuOCAwIDQuNy43IDQuNy43em0tMjQt'
    b'Mi40czMuNy42IDYuNi0xLjVjMy0yLjEgNi40LTUgOC4zLTUuMiAyIDAgNCAuNCA0IC40cy0y'
    b'LjUtMS00LjQtMWMtMiAwLTQgLjItNS44IDEuMy0xLjggMS4xLTIuNyAzLTQuNiA0LjNhMTIu'
    b'OCAxMi44IDAgMCAxLTQuMSAxLjd6bS0uNyA1Yy0uNSAwLTEuMS4zLTEuMy4zLS4yIDAtMS4z'
    b'LTEuMi0zLTItMS42LTEtNC0xLjQtNC0xLjRzLS4zIDAgLjMuMmwzLjggMS41YTguNiA4LjYg'
    b'MCAwIDEgMi42IDIuMWMuMS4zLjYuOSAxLjUuOCAxIDAgMS4zLS41IDEuMi0xIDAtLjMtLjYt'
    b'LjUtMS4xLS41em0yLjYtMy42czEuNS44IDQgLjhjNS4yLS4yIDguNi0zLjggMTItNSAzLjQt'
    b'MS40IDUuMi0uMyA1LjItLjNzLjEtLjIgMC0uMmE3IDcgMCAwIDAtMy45LTEuMmMtNS43IDAt'
    b'MTEuMiAzLjctMTMuNSA0LjctMi4zIDEtMy44IDEuMi0zLjggMS4yem01Ni0zOS45Yy0xLjgg'
    b'MS45LTQuNSA3LjctNS42IDkuMy0xLjIgMS42LTIuNyAyLTMuMyAyLjctLjYuNi0yLjcgMy41'
    b'LTMuMiA0LjEtLjUuNy0uNi41LTEgLjgtLjMuMy0uNS4zLjEuMi42LS4xLjgtLjUgMS42LTEu'
    b'NSAxLTEgLjktMS40IDIuMy0yLjcgMS40LTEuMiAzLjktMi42IDUuMS00LjIgMS4zLTEuNSAz'
    b'LjgtNy41IDUuMi05IDEuNC0xLjUgNC0yLjQgNC0yLjRzLTItLjYtNS4zIDIuN3ptLTkgMTEu'
    b'MXMtLjEtMSAxLjItMi42IDEuNy0xLjMgMi44LTMuNmMxLTIuMyAxLjUtNC41IDIuMy02Ljku'
    b'OS0yLjQgMi4zLTQuOCAyLjMtNC44cy0xLjMuMi0yLjcgMmEzNC41IDM0LjUgMCAwIDAtNC44'
    b'IDguN2MtMS4xIDMuNC0xLjEgNy4yLTEuMSA3LjJ6bS0xLjcgMi4ycy41LS4yLjUtMy4yYy4x'
    b'LTIuOS0uMS03IC43LTkgLjktMiA1LjQtNyA1LjQtN3MtMS45LjUtNC41IDIuNS0zLjcgNC43'
    b'LTMuNiA2LjdjLjIgMiAxLjMgNC4yIDEuNCA2LjFsLjEgNHptMTAuNS0yMC4xczEuMS00IDEu'
    b'Ni01IC41LTEuNSAyLjctNGMxLjMtMS41IDIuNi0yLjQgMy4xLTQuNC42LTIgLjYtNy43LjYt'
    b'Ny43cy0uNi41LTEuMSAxLjVjLS41IDEtLjEgNC43LTEgNi40LS44IDEuNy0yLjcgNS42LTMu'
    b'NyA2LjUgMCAwLS4yLTIuOS4yLTUuNy4zLTMgMS4zLTMuOCAxLjctNS43LjQtMS45LjItNi43'
    b'LjItNi43cy0xLjUgMS41LTIuMyAzLjRjLS44IDEuOC0xLjIgNS0xLjIgNy41cy41IDQuNS42'
    b'IDUuOWMuMSAxLjQuMiAyLS40IDMuNmwtLjYgMmEzNC44IDM0LjggMCAwIDEtLjcgMi42bC4z'
    b'LS4yem0tMy41LTIxLjZzMS40IDEuNyAxLjIgMy42Yy0uMyAyLTEgNC41LS4yIDYuNS43IDIg'
    b'MS45IDIuMiAyLjIgMy40LjMgMS4yLjMgMy40LjMgMy40cy42LTQuMy4yLTUuNWMtLjUtMS4x'
    b'LS43LS42LTEuMy0xLjhzMC00LjctLjQtNi43Yy0uNS0yLTItMi45LTItMi45eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM5Y2ExNjgiIGQ9Ik0zMDYuNyAzMDQuOHMuNC0xIDMuMS0yLjRhMzQgMzQg'
    b'MCAwIDEgNy4zLTNjLjMuMy0uMyAxLjgtLjMgMS44bC0yLjYuOC0yLjEgMS4yLTIuNSAxLjZo'
    b'LTIuOXoiLz4KICA8cGF0aCBmaWxsPSIjOWNhMTY4IiBkPSJNMzEzLjYgMjk3LjdjLTMuNC4x'
    b'LTUuMyAxLTYgMS0uMi4xLS43LjUtMS4yLjNhNC45IDQuOSAwIDAgMS0xLjUtMS41bC0uNy0u'
    b'Ny0uMiAyLjUtNS00LjQtLjYgMy0uNyAxLjMtNS00LjguMiAzLjctMS40LjEtMy42LTIuNS0x'
    b'IC40IDEuMiAyLjItNC42LjMtMSAuOGE2LjMgNi4zIDAgMCAwLTEgMXYuNGgxLjljLjQtLjIu'
    b'Ni0uNy43LS41LjIuMi4zIDEuMi45IDEuMS42IDAgMi43LTEuNyA0LjItMSAxLjcuOC0yLjIg'
    b'Mi0xLjggMy4xLjQgMS4yIDMuMi43IDQgLjMuNi0uMyAyLjctMyAzLjYtMiAxLjIgMS40LTIu'
    b'NSAyLjUtMS44IDMuOS42IDEuMyAyLjcgMSAzLjcuNCAxLS41IDMuNC00LjEgMy45LTMuNC45'
    b'IDEuNC0yIDIuNy0xLjMgMy43LjggMSAyLjMgMCAzLjQtLjhzMS41LTIuNSAzLTMuM2MxLjQt'
    b'LjggMS4zLS41IDEuNy0uNS40IDAgMS41LTEuMSAxLjUtMS4xbDMuNS0xLjUgMS42LjIuOS40'
    b'IDEuNy4yLjItMS40cy0yLTEtMy4zLTF6bS0yNy40IDAgLjctMS4zLS40LS42cy0xLjItLjct'
    b'Mi4zLTEuOGE2LjkgNi45IDAgMCAwLTItMS42TDI4MCAyOTFsLS44LTIuOC0uNS0uOS0xLjMu'
    b'Ni0xLjctNi4xLS4zLTEuMWgtLjdsLTEuNSAzLjYtMS41LTIuMy0uNC01LTEgMS0xLjMgMS40'
    b'LTIuMy00LjZzLS4xLS4xLS4zLjNjMCAuMy0uMyAxLjgtLjEgMi42YTI2LjIgMjYuMiAwIDAg'
    b'MS02LTUuMmwtMS0yLjUgMS0yIC41LTIuNi0yLjIuOS0uNC01LjctLjMtMS44LTIuNyAzLjgt'
    b'MS0xLjd2LTMuNmwtLjctLjItMSAycy0xLjEtMi0xLjYtMi41Yy4xLS44LjItMi45LS4zLTQu'
    b'NS0uNi0yLTEuMy0zLjEtMS00LjguMi0xLjYuOS0xLjguOC0yLjUgMC0uOC0xLjIuNS0uOC0u'
    b'NS40LTEgMy44LTMuMiAzLjEtNC40LS43LTEuMS00IDEuOS0zLjMtLjEuOC0yIDQtMiA0LjIt'
    b'NC45LjEtMS43LTMgMS4xLTMuMy4yLS4zLS44IDItMi42IDEuOS0zLjggMC0xIC40LTEuMi0u'
    b'Mi0xLjgtLjYtLjYtMi42IDIuMy0yLjYgMi4zbC0yLS43LS44IDMtLjYgMi41LTIuNi0xLjUu'
    b'NyAzLjEuNiAzLTIuNy0uNyAxLjQgMi42IDEuOSAyIDEuMSAxLjUuOS40IDEgMS4xLjUgMS43'
    b'LjYgMS45LjEgMS44djIuNGwtLjEuNHYxLjFjLS41IDAtMS40LS44LTEuNy0uMy0uMy42IDEu'
    b'NiAyIDEuMiAyLjQtLjMuNC0zLS41LTMuMi4zLS4yIDEgLjIgMi4yIDEuOCAyLjZzNS4zIDEu'
    b'MiA0LjcgMmMtLjYuNy00LjctMi4zLTQuNS0uMWEzLjggMy44IDAgMCAwIDIuNiAzLjRjMSAu'
    b'NCA1LjEgMCA0LjkgMS0uMy45LTMuMy0uNC0zLjYgMS0uMyAxLjQgMi4xIDEuNiAyLjYgMS42'
    b'czIuMi0uMSAyLjkuNGw0LjMgNC4xYTc1LjcgNzUuNyAwIDAgMCA0LjYgMy40Yy0uOCAwLTIu'
    b'NC0uMy0yLjYuMy0uMy43IDYgMyA0LjIgMy44LTEuOC43LTMuOC0yLTQuMy0uNC0uNiAxLjcg'
    b'MS4yIDMgMi4yIDMuNiAxIC42IDYuNy4xIDUuNiAxLjQtMS4xIDEuMy01LjMtLjgtNS4zLjdz'
    b'Mi43IDQgNC4yIDMuOWMxLjQgMCAzLTIuNCAzLjYtMS4xLjcgMS4yLTEgMS43LjMgMiAxLjQu'
    b'NCAyLjMtMS40IDQtMSAxLjUuMyA0IDEuMyA1LjQgMi41YTc5IDc5IDAgMCAxIDIuOSAyLjh6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iIzcxNzczMiIgZD0iTTMwOC40IDMwNC4xYzEgMCAxIC42IDEu'
    b'Mi42LjEgMCAxLjgtMS41IDMuMy0yLjNhMTcuNSAxNy41IDAgMCAxIDQtMS40bC4xLjJzLTIu'
    b'OC43LTQuMiAxLjdsLTMgMi4xYy0uMi4yLS44LjctMS43LjctMSAwLTEuNC0uNi0xLjQtLjkg'
    b'MC0uMi43LS43IDEuNy0uN3ptOC41LTQuM3MtLjkuMS0xLjMtLjNhNC4zIDQuMyAwIDAgMC0y'
    b'LjYtLjggNyA3IDAgMCAwLTQgMS44YzAgLjEtLjMuNi0xLjQgMS4zLjQuMSAxLjEtLjQgMi0x'
    b'YTcuNCA3LjQgMCAwIDEgMy42LTEuNGMxLS4yIDEuNy40IDIuMi43LjUuNCAxLjQuMyAxLjQu'
    b'M3YtLjZ6bS01MC41LTIwLjZ2LS43YTE2LjEgMTYuMSAwIDAgMS0yLjItMS4xYy0xLjYtMS01'
    b'LTMuOC01LTMuOGwyLjggMi43YzEuNCAxLjMgNCAyLjkgNCAyLjloLjR6bTM1LjYgMjUuMiAx'
    b'LjUtMi4xYy45LTEuNSAxLjctMiAxLjktMi4yLjEtLjItLjQtLjktLjctMS40bC0uMi0xLjJz'
    b'LjQuOCAxIDEuM2E5LjUgOS41IDAgMCAxIDEuMSAxczEuNC0uMiAxLjQtLjVjMC0uMiAwLS40'
    b'LS4yLS41LS4zLS4xLS41LjItMS4xIDAtMS4zLS42LTEuOC0yLjYtMi42LTIuNi0uOC0uMS0u'
    b'MiAyLS42IDItMS4xLjItMi00LjMtNS00LjUtMiAwLTIuMy4zLTIuNC43IDAgLjUgMi41IDMu'
    b'MSAxLjYgMy41LS44LjQtMy41LTQuMi01LjUtNC4yLTEuOSAwLTIgLjctMiAxLjEuMi40IDIu'
    b'Mi44IDEuOCAyLjItLjUgMS40LTIuNS0yLTQuMy0xLjktMS44LjItMiAuMy0yIC45LS4xLjUu'
    b'NiAxLjIuMyAxLjQtLjIuMi0xLjQuMS0yLjMuNy0uOS43LTIuMSAyLjQtMi4xIDIuNHMxLjIt'
    b'MS43IDIuNy0xLjlhNTAgNTAgMCAwIDEgNS42IDBsLTEuMS0uOGMtLjYtLjUtMS4xLTEuNi0x'
    b'LjEtMS42bDEuNyAxLjVjLjguNyAxLjkgMS4yIDEuOSAxLjJzMS43LjIgMS44LjRjLjEuMiAw'
    b'IC42LS44IDEuM2wtMS43IDEuNyAyLTEuNiAxLjUtMS4yIDEuNC4yYy4xIDAgMC0uNS0uOC0x'
    b'LjdsLTEuNi0yLjVzMSAuOSAyIDIuM2MxLjEgMS4zIDEgMiAxLjQgMiAuNCAwIDEgLjIgMS40'
    b'LjEuNCAwIC4zLjYtLjQgMS43cy0xLjIgMi41LTEuMiAyLjUuOC0xLjIgMS42LTJjLjctLjgg'
    b'MS4xLTEuNyAxLjUtMS44aDEuNWwtLjgtMS42Yy0uNi0xLS44LTIuNi0uOC0yLjZzLjYgMS40'
    b'IDEuNCAyLjVsMS4zIDEuOSAxLjQtLjEuMy4xYzAgLjUtLjIuNy0uNyAxLjhhMTcuNyAxNy43'
    b'IDAgMCAwLTEgMi4xek0yODAuNSAyOTJjMS4yLjUgMS43LjUgMS43LjVzLTEuNy0xLTIuMS0y'
    b'LjRjLS41LTEuNCAwLTQuNC0uOC00LjMtLjcgMC0xLjEgMi4xLTEuOCAxLjctLjgtLjQuMi00'
    b'LjQtLjYtNi0uOC0xLjctMi42LTIuOS0zLTIuMy0uNC42LS4zIDQuMi0xLjUgMy41LTEuMS0u'
    b'OC4xLTQtLjItNS4zLS40LTEuNS0xLjItMi41LTEuOS0yLjEtLjYuMy4zIDMtLjcgM3MtLjkt'
    b'MS45LTEuMy0yYy0uNS0uMi0uNi4zLS45IDAtLjItLjQgMC0xLjctLjYtMS42LS42LjEtLjUg'
    b'MS4yLS4zIDEuNy4xLjYuNSAxLjQuNyAxLjguMi40IDEgLjkgMSAxLjItLjEuMy0uNS42LTEg'
    b'LjZoLTEuOXMxLjQuNCAxLjkuNCAxLjQtLjIgMS43LjJjLjIuNSAxLjQgMiAxLjQgMnMuMy0u'
    b'OC40LTIuMmMuMi0xLjUgMC0yLjcgMC0yLjdzLjUgMS42LjQgMi43YzAgMS0uNCAzLS40IDNz'
    b'MS4xLjguOCAxYy0uMy4zLTEuNS4zLTIuOC4zLTEuNCAwLTMuMy0uNS0zLjMtLjVhMTMuNyAx'
    b'My43IDAgMCAwIDYuNyAxLjNsMS44IDJzLjktMS41IDEtM3YtM2wuNCAyLjhjMCAxLjMtLjQg'
    b'My42LS42IDMuOGE1IDUgMCAwIDEtMS45IDFsLTMuNS41czIuMi4zIDMuOCAwYzEuNS0uNCAx'
    b'LjctLjkgMi4yLS42bC44LjcgMS4zIDFjLjEuMS0uNy40LTEgLjdsLTEuNS43IDIuMi0uN2Ey'
    b'Mi4zIDIyLjMgMCAwIDAgMS4xLS40bC41LjItLjEtMS4yLS4zLTEuOHMuNS44LjcgMS42bC4x'
    b'IDEuNnMuMi4yIDEuNC42em0tMzEuMS0zNS42cy4zLTEuNy4zLTMuNmExNC4zIDE0LjMgMCAw'
    b'IDAtMS45LTUuOGwxLTEuNC0xLjIgMS0xLjItLjVhMyAzIDAgMCAxLS45LTFsMS4yLjhjLjYu'
    b'Mi43LjEuNy4xbC0uNS0yLTEuOS0xYy0xLjMtLjYtMi41LTEuOC0yLjUtMS44bDIuOCAxLjVj'
    b'MSAuNCAxLjYuNCAxLjYuNGwxLjYtLjYgMS43LTEuMXMtMSAuNi0xLjguN2wtMS42LjMtLjMt'
    b'Mi40LTEuMS0xLjFjLS45LTEuMi0xLjYtMi45LTEuNi0yLjlzMSAxLjIgMS43IDEuN2MuNy42'
    b'IDEuNCAxLjUgMS40IDEuNWwxLjYtMSAyLjgtMi0yLjcgMS4zLTEuNi43cy0uMi0xIDAtMS41'
    b'Yy4zLS40LjgtMS4yLjctMS42IDAtLjUtLjQtLjMtLjUtLjctLjItLjMuNC0yLjYuNC0yLjZs'
    b'LjEgMS4yYzAgLjUtLjIgMSAuNCAxIC42IDAgMy4yLTIuNyAzLjYtMy4yLjMtLjUuOC0xLjgt'
    b'LjYtMS4zLTEuNC42LTEgMS44LTIuMiAxLjctLjQgMC0uOC0xLjUtMS4yLTEuMi0uNC40LTEu'
    b'NCAxLjMtMS42IDIuNC0uMiAxIC4yIDIuNi0uNCAzLjEtLjYuNS0xLTEuOC0yLjItMS41LTEu'
    b'Mi4zLTEuNSAyLTEuMyAyLjYuMi42IDIuNyAzLjUgMiA0LS45LjMtMi45LTIuNi00LS42LTEg'
    b'MS45IDMuNCA0IDQgNC40LjUuNSAwIC42LjggMS42czEuOCAxLjIgMi40IDEuOGExMyAxMyAw'
    b'IDAgMSAyLjEgNS45bC0uMSAyLjd6bTExLjcgMTcuMXMtMS0xLjItLjctMy4zYy4zLTIgMS44'
    b'LTUuNyAxLjMtNi4ycy0yIDIuMi0yLjQgMS42Yy0uNC0uNi45LTQuMy4yLTUuOC0uNi0xLjUt'
    b'LjctMi41LTItMi4zLTEuMy4xLTEuOCA0LjQtMi41IDMuNi0uNi0uNy40LTIuNiAwLTMuNy0u'
    b'NS0xLS43LTEuMy0xLjMtMS4yLS43LjItMSAyLjItMS40IDIuMS0uNSAwLTEuMi0yLjMtMi4y'
    b'LTItLjkuMyAyLjMgNC41IDIuMyA0LjVzLjUtLjUuOC0xLjJsLjYtMS41cy4zIDEuMyAwIDEu'
    b'OWMtLjIuNS0uMyAxLjctLjMgMS43cy0uOC4zLTIuMSAwYTguOCA4LjggMCAwIDEtMi4zLS43'
    b'cy44LjYgMi4xIDFsMi43LjdhNDQuOSA0NC45IDAgMCAwIDIgMi43bC44LTIuMSAxLjMtMy41'
    b'LS42IDMuOS0uNyAzcy0xIDAtMi42LS4zbC0zLjYtLjggMy42IDEuMiAyLjguNyAxLjQgMS45'
    b'IDEtMS41IDEtMS44cy0uMyAxLjQtLjcgMi4zYTI3LjQgMjcuNCAwIDAgMS0uNyAxLjRsLTEu'
    b'OC4yaC0yLjVhMTkuNiAxOS42IDAgMCAwIDQuNS45czAgLjUuNyAxLjNhNC42IDQuNiAwIDAg'
    b'MCAxLjMgMS4zeiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMTQuNCAzMTAuOHMtLjYt'
    b'LjYtMS40LTFjLS45LS41LTEuMi0uNC0xLjItLjRsLS40LS4xLjgtMiA1LjUtNS4zLjktNS4z'
    b'aDMuNHY3LjJsMSAuNSA2LjIgMy43djEuNmwtMSAuNC0uNy40LTIuMy4yLTQtMy0xLjgtMS43'
    b'LTMgNC0yIC44eiIvPgogIDxwYXRoIGZpbGw9IiMwMTY4NDgiIGQ9Im0zMTguOCAyOTYuNy0u'
    b'MSAxYzAgLjkgMCA1LjItLjIgNS44LS4yLjYtMy4yIDEuOC00LjkgMy4zLTEuNyAxLjUtMS44'
    b'IDIuNi0xLjggMi42cy0uNSAwLTEuNi40Yy0xIC40LTEuNSAxLTEuNSAxcy42LTIuNiAzLjQt'
    b'NWMyLjctMi42IDQtMi44IDQuNC0zLjIuMy0uNCAwLTUgMC01LjUuMS0uNC41LS40LjctLjRo'
    b'MS42em03IDE1LjcuOC0xLjEgMS0uOC0xLjUtLjhjLTEuNS0uNi0yLjMtLjQtMy4zLTEuMmEx'
    b'My42IDEzLjYgMCAwIDEtMi4yLTJsLTEuNSAxLjIgMS43IDJjLjkuOCAyLjcgMS4xIDMuNSAx'
    b'LjZhOC44IDguOCAwIDAgMSAxLjYgMS4xeiIvPgogIDxwYXRoIGZpbGw9IiNjZDIwMmEiIGQ9'
    b'Ik0zMjEuNSAyOTYuNnMxLjcgMCAxLjkuMmwuMi42YzAgLjEgMCA0LS4yIDUuM2E4IDggMCAw'
    b'IDEtMS40IDNsLTQgMy43Yy0xLjIgMS4yLTIuNCAyLjgtMi40IDIuOGwtLjgtMWMtLjMtLjQt'
    b'LjctLjYtLjYtLjlhMTAgMTAgMCAwIDEgMy4zLTMuNGMyLTEuMyAzLjYtMi44IDQtNC45LjMt'
    b'MiAwLTUuNCAwLTUuNHoiLz4KICA8cGF0aCBmaWxsPSIjY2QyMDJhIiBkPSJNMzMyLjUgMzEw'
    b'cy0uNC0uNC0xLjgtLjRsLTEuNS4xcy0uOC0xLTItMS43Yy0xLjItLjgtMi4xLS43LTMuNS0x'
    b'LjYtMS4zLS44LTItMi4xLTItMi4xbDEtMnMxLjIgMS41IDIuNCAyLjRjMS4xLjkgMy43IDEu'
    b'NyA0LjYgMi40bDIuOCAyLjl6Ii8+CiAgPHBhdGggZmlsbD0iIzMwYzJkYyIgc3Ryb2tlPSIj'
    b'MDg3MmE3IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNMzQ1IDI4Ni40cy0zLjYtMS40LTMuNC0y'
    b'LjdjLjMtMS4yIDguMy0zLjMgOC4zLTMuM2wuMS0yLjFzLTEuMi0uMS0zLjIuNWMtMiAuNy01'
    b'LjIgMS42LTguNiAxLjZhMTczNS40IDE3MzUuNCAwIDAgMC0zNC40LTIuMmMtMy43LS4zLTYt'
    b'Ni02LTZsLTEuOC40cy41IDIuNy0uNCAzYTY1IDY1IDAgMCAxLTEzLjktNmwtLjYgMi42czcu'
    b'MyA0IDcuMSA1LjVjLS4yIDEuNC0yLjQgMS4zLTIuNCAxLjNsMSAxLjhjLjMgMCAxMiAuNiAx'
    b'Mi4zIDQuMSAwIDEuNS0zIDIuMy0zIDIuM2wxIDEuMnYuNnM2LjcgMCA4LjUgMWMxLjggMSAy'
    b'LjcgMi42IDUgMy44IDIuMiAxLjMgMTcuMyAxIDE5LjYuMyAyLjctLjcgNC4zLTMuNyA4Ljct'
    b'NSA0LjMtMS40IDUuNy0xLjQgNS43LTEuNHoiLz4KICA8Y2lyY2xlIGN4PSIyODQuNSIgY3k9'
    b'IjI4MC43IiByPSIyLjEiIGZpbGw9IiNmZmYiIHN0cm9rZT0iIzA4NzJhNyIvPgogIDxjaXJj'
    b'bGUgY3g9IjI5Ni40IiBjeT0iMjcwLjkiIHI9IjIuMSIgZmlsbD0iI2ZmZiIgc3Ryb2tlPSIj'
    b'MDg3MmE3Ii8+CiAgPGNpcmNsZSBjeD0iMzQ2LjUiIGN5PSIyODYuNiIgcj0iMi4xIiBmaWxs'
    b'PSIjZmZmIiBzdHJva2U9IiMwODcyYTciLz4KICA8cGF0aCBmaWxsPSIjZjhjODNjIiBkPSJN'
    b'Mjc1LjEgMjY3LjhjLS43IDEuNiAyIDQuNiA0IDUgMS44LjIgMi44LS4yIDMuMi0xLjFhMi44'
    b'IDIuOCAwIDAgMC0uNC0yLjVjLTEuMi0xLjctNi0zLTYuOC0xLjR6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTI4MSAyNzAuMmMwLTEtMS42LTEuOS0yLjYtMS45cy0yIDAtMS44LjVj'
    b'LjEuNiAyLjcgMS4zIDIuOCAxLjYgMCAuMy0uOC42LS40IDEgLjUuNCAxIC4xIDEuNC0uMi40'
    b'LS4zLjctLjQuNy0xeiIvPgogIDxwYXRoIGZpbGw9IiNmOGM4M2MiIGQ9Ik0yOTcuNyAyODgu'
    b'M2MuNCAxLjQtLjcgMi0yIDIuNy0xLjUuNi00LjMuMi01LS45LS42LTEuMSAxLTMgMi44LTMu'
    b'NCAxLjctLjQgMy44LjMgNC4yIDEuNnoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjk0'
    b'LjggMjg5Yy41IDAgLjYgMSAxIC44LjUgMCAxLS44LjgtMS4zLS4xLS42LTEtMS4zLTEuOC0x'
    b'LjItLjggMC0zIDItMi44IDIuNS4yLjUuOC41IDEuMi4zLjQtLjIgMS0xIDEuNi0xeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNmOGM4M2MiIGQ9Ik0zNDkuMiAyODFjMS4zIDEuNyAzLjYuMiA0LjIt'
    b'LjUuNi0uNiAyLjQtMS43IDEuNy0yLjgtLjgtMS4xLTItMS0zLTEtLjggMC0yLjYgMS40LTIu'
    b'OSAyLS4zLjUtLjYgMS42IDAgMi40eiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zNDku'
    b'NiAyODBzLjEtMS45IDEuOC0yYzEgMCAxIC4zIDEuOC43LjcuNCAxLS41IDEtLjVzMCAxLjMt'
    b'MS4xIDEuM2MtMS4yIDAtLjgtLjUtMi0uNy0xLS4yLTEuNSAxLjEtMS41IDEuMXoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjZjlhYTUxIiBzdHJva2U9IiM5NTMyMjAiIHN0cm9rZS1saW5lY2FwPSJy'
    b'b3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0ibTMy'
    b'MS45IDI3Ni40LS45LS42aC0yLjhsLTMuNC4xIDMuNCA5LjkgNCA1LjggMS42LjYgMy4xLS4y'
    b'LjYtMS42LTEuMi05LjUtNC40LTQuNXoiLz4KICA8cGF0aCBmaWxsPSIjZjlhYTUxIiBzdHJv'
    b'a2U9IiM5NTMyMjAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJy'
    b'b3VuZCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0ibTMxMC42IDI3NyAuMi0xLjEgMS44LS4xYTcu'
    b'MiA3LjIgMCAwIDEgMi4yLjFzMi4zIDIuOSAzLjEgNC43Yy44IDEuOCAxLjcgNC44IDIuNyA2'
    b'LjYgMSAxLjkgMy4yIDUgMy4yIDVoLTRsLTItLjYtNS42LTktMS42LTUuNnoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZjlhYTUxIiBzdHJva2U9IiM5NTMyMjAiIHN0cm9rZS1saW5lY2FwPSJyb3Vu'
    b'ZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTMwOC4y'
    b'IDI3NS44aDIuNmExNCAxNCAwIDAgMSAzLjkgNS40YzEgMi44LjUgMy4yIDEuOCA2LjIgMS40'
    b'IDIuOSAzLjIgNC45IDMuMiA0LjlzLTMuOS4yLTYtLjJjLTIuMy0uNC0zLS4zLTMuNi0xYTku'
    b'MiA5LjIgMCAwIDAtMS43LTEuM2gtMi4ybC41LTMuMS0uNi02LjkuMS0zLjUgMi0uNXptMjMu'
    b'NCAxLjgtMy43LTEuNS03LS40LjYgMy42YTMwLjIgMzAuMiAwIDAgMCAyLjYgNy43YzEuMSAy'
    b'IDIuMiA0LjQgMi44IDUgLjYuNSA0LjYtMS4xIDQuNi0xLjFsMi42LS40LS4zLTIuOC0uNC0x'
    b'IC42LTgtLjYtMS4yLTEuOC4xeiIvPgogIDxwYXRoIGZpbGw9IiNmOWFhNTEiIHN0cm9rZT0i'
    b'Izk1MzIyMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5k'
    b'IiBzdHJva2Utd2lkdGg9Ii41IiBkPSJNMzA3LjEgMjc3LjdjMCAuOCAxIC45IDEuMi44LjIg'
    b'MCAxLS4zIDEtMS41cy0uNy0yLjEtMi4yLTIuMmMtMS40IDAtMi41IDEuNy0yLjUgMyAwIDEu'
    b'MiAxLjIgMS44IDEuMiAyLjMgMCAwLTEuMiAxLjEtMS4xIDMuMSAwIDIgMS42IDMuNiAxLjYg'
    b'My42cy0xLjcgMS4zLTEuNyAyLjdjMCAxLjQgMS4zIDIuMyAyLjYgMi4zIDEuMiAwIDIuOC0u'
    b'OCAyLjgtMS44cy0xLTEuNy0xLjctMS43Yy0uOCAwLTEuMS41LTEuMS44bTI1LjYtMTAuOWMw'
    b'IC45LS42IDEtMSAxcy0xLjItLjQtMS4yLTEuNWMwLTEgMS40LTEuNiAyLjQtMS42LjkgMCAy'
    b'LjQgMS4yIDIuNCAyLjcgMCAxLjUtMSAyLjYtMSAyLjZzLjYuMy42IDIuMmMwIDItMS4yIDMu'
    b'My0xLjIgMy4zczEuNi42IDEuNiAyLjYtMS40IDIuNi0yLjMgMi42Yy0xIDAtMi42LS41LTIu'
    b'Ni0xLjkgMC0xLjMuOC0xLjggMS41LTEuOC42IDAgMS4zLjcgMS4zIDEuNSIvPgogIDxwYXRo'
    b'IGZpbGw9IiM5NTMyMjAiIGQ9Im0zMDkuNSAyODguNi40LjZjLjIuNC4zIDEgLjggMS40Ljgu'
    b'NyA3LjIgMSA5LjIgMSAyIDAgNy44LjIgOC45LS40IDEtLjcgMS4yLTEuOCAxLjktMi4zbC45'
    b'LS40LS45Ljd2MS40bC41LjhzLS4xLjQtLjguOGMtLjcuNC0xLjMuNS0yLjMuNi0xIC4xLTEz'
    b'LjIuMS0xNS4yLS4yLTItLjQtMS44LS4zLTIuNC0uN2E0LjMgNC4zIDAgMCAxLTEtMWwuMy0u'
    b'OC0uMy0xLjR6bTIwLTExLjggMSAuNXMtLjkuMy0xLjYgMi4zYy0uNyAyLS4xIDIuNS0uNiAy'
    b'LjctLjUuMi01LjggMC01LjggMGwtMS0yLjEgOC0zLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzIz'
    b'MWYyMCIgZD0iTTM0Ni40IDI3NnMtLjktLjMtMS4zLTFjLS40LS44LS44LTEuNy0uNS0yIC40'
    b'LS4xIDEgLjUgMSAxLjEgMCAuNi44IDIgLjggMnptMTAuNC0yLjhzLjcgMS4yIDEgMS4zbDEu'
    b'Mi42cy0xLjUgMC0yLS40YTguMyA4LjMgMCAwIDEtMS0xLjVoLjh6Ii8+CiAgPHBhdGggZmls'
    b'bD0iIzIzMWYyMCIgZD0iTTM2MCAyNzQuMnMtMSAuNS0xLjYuMmMtLjgtLjMtMS40LS43LTEt'
    b'MSAuMi0uNC40LS4zLjguMi40LjQgMS44LjYgMS44LjZ6bTUuMy00LjVzLS44LjYtMS4zLjYt'
    b'MS41LS4yLTEuNS0uNCAxLjMtLjQgMS42LS4zaDEuMnptLTgtMTAuNXMtMS4xLjQtMS41IDFj'
    b'LS40LjUtLjMgMS4yLjIgMS4ycy42LS43LjYtMWwuNy0xLjJ6bS01LjIgMi45cy0uOS41LTEg'
    b'MWMtLjMuNS0uNSAxLjYgMCAxLjZzLjctLjguNy0xLjJjMC0uNS4zLTEuNC4zLTEuNHoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjOGNiZWJmIiBzdHJva2U9IiMwNDUzNGUiIHN0cm9rZS13aWR0aD0i'
    b'LjUiIGQ9Im0zNDIuOCAyNjguNC0yLjkgM3M2LjYgMy43IDExLjcgMy41YzUtLjEgMTAuOC00'
    b'IDExLjItNSAuNC0uNyAwLTQuMy0uNi01LjQtLjctMS4xLTQuMi0zLjgtNS41LTMuNy0xLjMu'
    b'MS0zLjcgMS45LTUuOCA0LTIuMiAyLjEtMiAzLjktNSAzLjdsLTMuMS0uMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjMGM4NDg5IiBkPSJNMzQyIDI2OS42czcgMSA5LjEtLjhjMi0xLjggNC4zLTUu'
    b'MyA1LjctNiAxLjQtLjkgMi0uOSAyLS45bDEuNiAxLjEgMS44IDEuNS42IDMuNHYxLjhsLTIu'
    b'MiAxLjgtNCAxLjktNCAxLjItMy4yLS4xLTYuNy0yLTEuNy0xLjEtLjQtLjQgMS40LTEuNHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjMDQ1MzRlIiBkPSJNMzUyLjggMjY1LjVjMC0uNi40LS42IDEt'
    b'LjZzMSAuMiAxIC44LS41IDEuNC0xIDEuNGMtLjYgMC0xLTEtMS0xLjZ6bTIuOCAxLjhjMC0u'
    b'Ni40LS44IDEtLjguNyAwIDEuMy43IDEuMyAxLjJzLS41IDEtMS4xIDFjLS43IDAtMS4yLS45'
    b'LTEuMi0xLjR6bS0xIDQuMmMwLS43LjUtLjggMS4xLS44LjYgMCAxIC4zIDEgMWExLjIgMS4y'
    b'IDAgMCAxLTEuMSAxLjJjLS43IDAtMS0uNy0xLTEuNHptLTMuNy0xLjNjMC0uNy43LTEgMS4z'
    b'LTEgLjYgMCAxIC43IDEgMS40cy0uNCAxLjMtMSAxLjMtMS4zLTEtMS4zLTEuN3ptLTUuOS43'
    b'YTEuNCAxLjQgMCAxIDEgMyAwIDEuNCAxLjQgMCAwIDEtMyAweiIvPgogIDxwYXRoIGZpbGw9'
    b'IiM4Y2JlYmYiIGQ9Ik0zNTUuNiAyNjcuM2MwLS41LjctLjggMS0uOC41IDAgLjguNC44Ljhz'
    b'LS4zIDEtLjcgMWMtLjQgMC0xLS41LTEtMXptLTEgNGMwLS41LjYtLjggMS4yLS44czEgLjMg'
    b'MSAuOC0uNSAxLTEgMWMtLjYgMC0xLjEtLjQtMS4xLTF6bS0zLjctMS4yYzAtLjYgMS0uOSAx'
    b'LjUtLjkuNCAwIC4zLjQuMyAxIDAgLjctLjMgMS4yLS43IDEuMnMtMS0uNy0xLTEuM3ptMS44'
    b'LTQuN2MwLS41LjQtLjUuOC0uNXMuNi4xLjYuNy0uMyAxLS42IDFjLS40IDAtLjgtLjYtLjgt'
    b'MS4yem0tNy43IDUuMWMwLS42LjYtMS4zIDEuNC0xLjNzMS43LjMgMS43IDFjMCAuNi0xIDEu'
    b'OC0xLjggMS44LS45IDAtMS4zLS44LTEuMy0xLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzIzMWYy'
    b'MCIgZD0iTTM0Ny43IDI2OS40cy0xIC4xLTEuNS42LS41IDEtLjMgMS4yYy4zLjIuNy0uMy44'
    b'LS42IDAtLjIgMS0xLjIgMS0xLjJ6bTQuNy0xcy0xIC42LTEgMS4zYy0uMS42IDAgMSAuMiAx'
    b'IC4zIDAgLjUtLjkuNC0xLjItLjEtLjMuNC0xLjIuNC0xLjJ6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzIzMWYyMCIgZD0iTTM1My4yIDI2OS4zcy0uNiAwLTEgLjRjLS41LjUtLjkgMS0uNiAxIC4z'
    b'IDAgLjgtLjIuOC0uNSAwLS4yLjgtLjkuOC0uOXptMS01LjQtLjguNmMtLjIuMi0uNSAxLS4y'
    b'IDEgLjMuMi41IDAgLjgtLjUuMi0uNS4yLTEuMS4yLTEuMXptMy41IDIuM3MtLjkgMC0xLjIu'
    b'NWMtLjMuNC0uNS44IDAgLjguMyAwIC40LS4yLjYtLjUuMS0uNC42LS44LjYtLjh6bS0uNSA0'
    b'LjFzLS4yLjctLjggMWMtLjUuMy0uNy41LTEgLjEtLjEtLjQuMi0uNi40LS43bDEuNC0uNHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjMDQ1MzRlIiBkPSJNMzYyLjggMjY3LjVzLjQgMi0xLjMgM2Mt'
    b'MS43LjktNi40IDQuMi0xMC45IDMuOC00LjUtLjQtOS42LTMtOS42LTNsLS43LjQgMS4yLjUg'
    b'My40IDEuNCA0IDEuMiAyLjUuMSAyLjEtLjIgNC0xLjMgMy4zLTEuNyAxLjgtMS40LjQtLjZ2'
    b'LTEuOWwtLjItLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzIzMWYyMCIgZD0iTTI3NC45IDI0Mi4y'
    b'czEgLjkgMSAxLjZjLS4yLjgtLjQgMS4xLS43IDEtLjMtLjItLjMtMS0uMy0xLjN2LTEuM3pt'
    b'Ny43IDcuMXMtLjMgMS40LS45IDEuNWMtLjUuMS0uOS0uNC0uOC0uNy4xLS4yLjYgMCAuOC0u'
    b'MmwuOS0uNnptLTE2LjggMXMuNC44IDEgMWMuOCAwIDEtLjQgMS0uNi0uMS0uMi0uNC0uMi0u'
    b'OC0uMmwtMS4yLS4xem0zIDZzLjcuNiAxLjUuN2ExLjMgMS4zIDAgMCAwIDEuMy0uN2MwLS4y'
    b'LTEtLjItMS4zIDAtLjMuMy0xLjUgMC0xLjUgMHptNS4zIDQuNHMxLjQtLjIgMS42LS42Yy4y'
    b'LS40LjYtMSAuMy0xLjMtLjMtLjQtLjUuNS0uNy45LS4xLjMtMS4yIDEtMS4yIDF6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzhjYmViZiIgc3Ryb2tlPSIjMDQ1MzRlIiBzdHJva2Utd2lkdGg9Ii41'
    b'IiBkPSJNMjgyLjYgMjU3LjFzMS02LTQtMTAuNGMtNS00LjMtOC4xLTMuMi05LjgtMS42LTEu'
    b'NyAxLjYtMy4yIDYuNyAyIDExLjMgNS4zIDQuNSAxMS43IDMgMTEuNyAzbC4xLTIuM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjMGM4NDg5IiBkPSJNMjY3LjYgMjUwLjdzLS4xLTMuNCAxLjUtNC40'
    b'YzEuNS0xIDYuOC0xLjggOS4zIDMuMSAyLjYgNSAyLjcgNy40IDIgMTBoLTIuN2wtNC4zLTEu'
    b'OC0zLjUtMi42LTIuMy00LjN6Ii8+CiAgPHBhdGggZmlsbD0iIzA0NTM0ZSIgZD0iTTI4MiAy'
    b'NThzLS45IDEtMi43IDFjLTEuNy0uMi0xMC0yLjMtMTItOS44djEuN2wuMS41LjYgMS41IDEu'
    b'NyAyLjUgMi4yIDEuOSAyLjggMS40IDIgLjYgMi41LjRoMS41bDEuMy0xLjd6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzA0NTM0ZSIgZD0iTTI3Ny43IDI1NS45YzAtLjcuMy0uNy44LS43czEtLjIg'
    b'MSAuNGMwIC43LS40IDEuNi0xIDEuNi0uNCAwLS44LS43LS44LTEuM3ptLjMtNGMwLS40LjQt'
    b'LjggMS0uOC41IDAgLjkuNC45LjkgMCAuNC0uNC44LTEgLjgtLjUgMC0uOS0uNC0uOS0uOHpt'
    b'LTMuNyA0LjRjMC0uNC40LS43IDEtLjdzMSAuMyAxIC43YzAgLjMtMSAuOC0xLjUuOC0uNiAw'
    b'LS41LS41LS41LS44em0tLjQtNC42YzAtLjYuMy0uNC44LS40czEuMi4xIDEuMi43LS43IDEu'
    b'NC0xLjIgMS40LS44LTEuMi0uOC0xLjd6bS0zLjQuN2MwLS41LjMtMS4xLjktMS4xczEuMy42'
    b'IDEuMyAxLjFjMCAuNS0uNSAxLTEuMSAxLS42IDAtMS4xLS41LTEuMS0xem0uNi00YzAtLjYu'
    b'My0uNSAxLS41LjYgMCAxLjEuMiAxLjEuNyAwIC41LS43IDEuMi0xLjQgMS4yLS42IDAtLjct'
    b'MS0uNy0xLjV6bTMuNy0uNWMwLS40LjUtLjMgMS0uMy43IDAgMS4xLjQgMS4xIDFzLS43IDEt'
    b'MS4zIDFjLS42IDAtLjgtMS4yLS44LTEuNnoiLz4KICA8cGF0aCBmaWxsPSIjOGNiZWJmIiBk'
    b'PSJNMjcxIDI0OC4zYy4yLS40LjQtLjcuOC0uNy41IDAgLjkuMS45LjcgMCAuNC0uNC45LS44'
    b'LjktLjUgMC0xLS41LS44LTF6bS0uNiA0YzAtLjUuMi0xIC43LTFzMSAwIDEgLjUtLjUgMS4x'
    b'LTEgMS4xLS43LS4xLS43LS42em00LjQtNC4zYzAtLjQuMy0uNC44LS40cy44IDAgLjguNWMw'
    b'IC40LS40LjctLjguN3MtLjgtLjQtLjgtLjh6bS0uOSAzLjljMCAuNS41IDEgMSAxczEtLjUg'
    b'MS0xYzAtLjYtLjYtMS0xLTFzLTEgLjQtMSAxem00LjMtLjZjMCAuNS40LjkgMSAuOS41IDAg'
    b'LjktLjQuOS0uOXMtLjUtLjktMS0uOS0xIC40LTEgMXptLTQuMSA1YzAtLjUuNS0uOS45LS45'
    b'cy45LjMuOS43YzAgLjQtLjggMS0xLjIgMS0uNSAwLS42LS40LS42LS45em0zLjYtLjdjMC0u'
    b'NS40LS42IDEtLjYuNSAwIC44LjEuOC42IDAgLjYtLjUgMS0xIDFzLS44LS41LS44LTF6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzIzMWYyMCIgZD0iTTI3OC43IDI0OS40cy41LjcuNiAxLjN2MS4y'
    b'Yy0uMyAwLS42LS40LS43LS45LS4xLS41IDAtMS42IDAtMS42em0tMy4yLTMuM3MuNC41LjQg'
    b'MSAwIDEtLjMgMS0uMy0uNC0uMy0uOGwuMi0xLjJ6bS0zLjcuNXMuNC41LjQgMSAwIDEtLjMg'
    b'MS0uMy0uNC0uMy0uOGwuMi0xLjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzIzMWYyMCIgZD0ibTI3'
    b'MC41IDI0Ny4zIDEgLjRjLjMuNC41LjguMyAxLS4xLjItLjUtLjEtLjYtLjRsLS43LTF6bTIu'
    b'OCAzLjhzLjcgMCAxLjEuNWMuNC4zLjguNi41LjktLjIuMi0uNy0uMi0xLS41bC0uNi0uOXpt'
    b'LTMuNCAwIDEgLjNjLjMuMi40LjcuMi44LS4xLjEtLjQgMC0uNi0uNGwtLjYtLjh6bTguMyAy'
    b'LjUuMiAxLjRjMCAuNS4xIDEtLjIgMXMtLjMtLjctLjMtMWMwLS41LjMtMS40LjMtMS40eiIv'
    b'PgogIDxwYXRoIGZpbGw9IiMyMzFmMjAiIGQ9Im0yNzcuMyAyNTQuOS44LjVjLjMuMi4zLjYu'
    b'MS42bC0uNC0uNWE5LjIgOS4yIDAgMCAxLS41LS42em0tMy43LjIuOS4zYy4yLjIuMyAxIC4y'
    b'IDEuMSAwIC4xLS40IDAtLjYtLjNsLS41LTF6Ii8+CiAgPHBhdGggZmlsbD0iIzA0NTM0ZSIg'
    b'ZD0iTTI3Mi4xIDI0My44cy0zLjIuNy0zLjggMi45Yy0uNiAyLS43IDQuNC0uNyA0LjRsLS40'
    b'LTIuNy42LTEuNyAxLTEuNiAxLjQtMSAxLjMtLjQuNi4xem0xMC4yIDEyLjVzLjQtLjgtLjYt'
    b'My40Yy0xLTIuNS0zLTYtMy02bDEuNiAxLjggMS4yIDIgLjYgMS44LjUgMS43djEuNmwtLjMu'
    b'NnoiLz4KICA8cGF0aCBmaWxsPSIjMjMxZjIwIiBkPSJNMjg1LjYgMjUyLjJzMS4yLjcgMS4z'
    b'IDEuMWMuMS40LjIuNi0uMS43LS4zLjEtLjgtLjQtMS0uN2E2LjUgNi41IDAgMCAxLS4yLTEu'
    b'MXptLTQuOCAxMi44cy42LTEgMS4zLTEuM2MuNy0uNCAxLjItLjQgMS40LS4xLjIuMi0uNC43'
    b'LTEgLjlsLTEuNy42em04LjEgMy4xcy44LS40IDEuMy0xYy41LS41LjYtLjkuNC0xLS4yLS4z'
    b'LS44IDAtMS4xLjUtLjMuNC0uNiAxLjUtLjYgMS41em0tLjktLjdzLjMtMSAuNi0xLjRjLjMt'
    b'LjMuNi0uNSAxLS4zLjIuMiAwIC42LS4yLjlhNy44IDcuOCAwIDAgMS0xLjQuOHoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjOGNiZWJmIiBzdHJva2U9IiMwNDUzNGUiIHN0cm9rZS13aWR0aD0iLjUi'
    b'IGQ9Ik0zMDEuNSAyNjEuMnMtNS03LjItMTIuOC03LjZhNy40IDcuNCAwIDAgMC04IDdjLjIg'
    b'MS42IDIuNiA1LjIgMTAuOSA1LjggOC4zLjYgOS42LTMuOSAxMC00LjEuMy0uMi0uMS0xLS4x'
    b'LTF6Ii8+CiAgPHBhdGggZmlsbD0iIzBjODQ4OSIgZD0iTTI5NS42IDI1Ni4zczIgMS41IDMg'
    b'Mi44Yy44IDEuMiAxIDIuMi41IDIuMy0uNS4yLTUtNC04LjgtNC45LTMuNy0uOS02LjkgMC03'
    b'LjYgMS43cy0uNCA0LjUgMS4yIDUuNmMxLjggMSA5LjcgMi4zIDkuNyAyLjNsMy43LS41IDIu'
    b'My0xLjMuNS0xLjMuNi0xLjYuMi0uNy0xLjktMi0zLjQtMi41eiIvPgogIDxwYXRoIGZpbGw9'
    b'IiMwNDUzNGUiIGQ9Ik0yODkuMiAyNTcuM2MwIC40LS41LjctMSAuN3MtLjktLjMtLjktLjdj'
    b'MC0uNS40LS45IDEtLjlzMSAuNCAxIC45em0tNC42IDEuNmMwLS41LjYtLjQgMS0uNC42IDAg'
    b'MSAuMyAxIC44cy0uOCAxLjEtMS4zLjljLS42LS4zLS43LS44LS43LTEuM3ptNSAyLjdjMC0u'
    b'Ni40LTEgMS0xIC43IDAgMS4yLjQgMS4yIDFzLS44IDEuMi0xLjUgMS4yLS43LS42LS43LTEu'
    b'MnoiLz4KICA8cGF0aCBmaWxsPSIjOGNiZWJmIiBkPSJNMjg1LjggMjYyLjdjMC0uNS42LS42'
    b'IDEtLjYuNSAwIDEgLjUgMSAxcy0uNS45LTEgLjljLS40IDAtMS0uOC0xLTEuM3oiLz4KICA8'
    b'cGF0aCBmaWxsPSIjMDQ1MzRlIiBkPSJNMjkyLjUgMjY0LjVjMC0uNC4yLS44LjctLjguNCAw'
    b'IDEgLjMgMSAuNyAwIC40LS41LjktMSAuOWEuOC44IDAgMCAxLS43LS44em0zLTIuM2MwLS41'
    b'LjMtLjQuOC0uNHMxIC4yIDEgLjgtLjYuOC0xLjEuOGMtLjUgMC0uNy0uNi0uNy0xLjJ6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzhjYmViZiIgZD0iTTI4OSAyNTYuOWMwIC40LS4yLjYtLjcuNnMt'
    b'LjktLjItLjktLjZjMC0uNS4yLS42LjYtLjZzMSAuMSAxIC42em0tMi41IDEuOWMwIC41LS43'
    b'LjctMSAuNy0uNSAwLS44LS4yLS44LS43IDAtLjUuMy0uNi44LS42czEgLjEgMSAuNnptMSAz'
    b'LjhjMCAuNCAwIC43LS41LjdzLTEtLjMtMS0uN2MwLS40IDAtLjcuNS0uN3MxLjEuMyAxLjEu'
    b'N3ptNC0xLjNjMCAuNC0uNyAxLTEuMiAxLS40IDAtLjYtLjktLjYtMS4zcy40LS43LjgtLjcg'
    b'MSAuNiAxIDF6bTUuOCAxLjNjMCAuNC0uNy40LTEgLjQtLjUgMC0uOC0uNS0uOC0xIDAtLjQu'
    b'MS0uOCAxLS43LjUgMCAuOC44LjggMS4zem0tMy40IDEuN2MwIC41LS4zLjgtLjcuOGEuOC44'
    b'IDAgMCAxLS44LS44YzAtLjQuNC0uNi44LS42cy43LjIuNy42eiIvPgogIDxwYXRoIGZpbGw9'
    b'IiMyMzFmMjAiIGQ9Ik0yOTQuNCAyNjJzLjgtLjMgMS41LS4zYy42IDAgLjYuMy42LjQgMCAu'
    b'MS0uNS4zLS43LjJhODYuMiA4Ni4yIDAgMCAxLTEuNC0uNHptLTMuMyAyLjhzLjYtLjQgMS4x'
    b'LS41Yy41LS4xLjkgMCAuOC40IDAgLjMtLjIuMy0uNi4zbC0xLjMtLjJ6bS0yLjItNXMxLjQu'
    b'NiAxLjcgMS4xYy4zLjYuNC43LjEuOS0uMy4yLS42LS4yLS44LS41bC0xLTEuNXoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjMjMxZjIwIiBkPSJtMjg4LjUgMjYxLjYgMS42LS4zYy41IDAgLjYgMCAu'
    b'Ny4yIDAgLjItLjEuMy0uNS4zbC0xLjgtLjJ6bS0zLjQgMHMxLjIuMiAxLjUuNWMuMy4zLjMu'
    b'Ni4xLjcgMCAuMi0uNi4xLS44IDBsLS44LTEuMnoiLz4KICA8cGF0aCBmaWxsPSIjMjMxZjIw'
    b'IiBkPSJNMjg1IDI2My4zcy40LS43LjgtLjggMS0uMSAxIC4xYy4xLjItLjQuNS0uNy42bC0x'
    b'LjIuMXptLTEtNS4xIDEuMi4zYy40LjMuNS42LjQuNyAwIC4xLS41LjItLjggMC0uNS0uNC0u'
    b'Ny0xLS43LTF6bTIuNi0zczEuMi40IDEuNiAxYy40LjUuMy44LjEuOWwtLjktLjRjLS4zLS4z'
    b'LS44LTEuNC0uOC0xLjR6Ii8+CiAgPHBhdGggZmlsbD0iIzA0NTM0ZSIgZD0iTTMwMCAyNjMu'
    b'N3MtMi4zIDItNy43IDEuOWMtNS41LS4yLTEwLjQtMi41LTExLjYtNWwuNSAxLjIgMS4yIDEu'
    b'NiAzLjggMiA0LjMuOSAzLjMuMiAzLjItLjYgMi41LTEuMS40LS43LjItLjR6bS44LTIuNXMt'
    b'LjktMS4yLTIuMi0yLjNjLTEuMi0xLjItNi4yLTQuNC02LjItNC40bDQgMS44IDIuNyAyLjIg'
    b'MS44IDItLjEuN3oiLz4KICA8cGF0aCBmaWxsPSIjMjMxZjIwIiBkPSJNMzAxIDI1Ni40czEu'
    b'NC41IDEuNi44bC41LjZzLS4zIDEtLjYuNmwtLjgtLjktLjctMS4xem00LTIuMnMxLjMuNSAx'
    b'LjggMS4xYy41LjcuNCAxLjIuMiAxLjMtLjIgMC0xLS43LTEuMi0xYTQ3LjMgNDcuMyAwIDAg'
    b'MC0uNy0xLjR6Ii8+CiAgPHBhdGggZmlsbD0iIzIzMWYyMCIgZD0iTTMwNi40IDI1NHMxLjIu'
    b'OCAxLjQgMS4yYy4xLjQuNSAxIC4xIDEtLjMuMi0uOS0uNC0xLS44bC0uNi0xLjV6bTYuOCAx'
    b'LjVzMSAuNCAxIDEuMnYxLjNsLS43LS43di0uN2wtLjMtMXptMS44LjdzLjguNy45IDEuMmMw'
    b'IC41LjIuOC0uMyAxLS40IDAtLjYtLjUtLjYtMXYtMS4yem0tMTIuMyAxNXMuNi4yIDEuMiAw'
    b'Yy41LS4yIDEtLjcuOS0xLS4xLS40LS40LS43LS44LS4yLS40LjQtLjIuNi0uNS44bC0uNy4z'
    b'em02LjggMS44cy45LS4yIDEuNS0uOWMuNi0uNi45LTEgLjUtMS4yLS40LS4yLTEgMC0xIC41'
    b'bC0xIDEuNnptNS41LjEgMS4zLS45Yy41LS40LjctLjcuNC0xLS4zLS41LS42LS4yLS44IDBs'
    b'LS4yLjctLjYgMS4yeiIvPgogIDxwYXRoIGZpbGw9IiMyMzFmMjAiIGQ9Ik0zMTYuNyAyNzMu'
    b'MXMuOC0uOSAxLTEuNGMuMS0uNS4yLTEtLjEtMS0uNCAwLS44LjUtLjguOXYxLjV6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzhjYmViZiIgc3Ryb2tlPSIjMDQ1MzRlIiBzdHJva2Utd2lkdGg9Ii41'
    b'IiBkPSJNMjk5LjkgMjY0LjFjMC0yLjQgMy41LTggNy41LTggMS42IDAgNC45IDEgNy41IDIu'
    b'MSAyLjIgMSAzIDIgNC40IDIuNCAxLjUuNCAzLjcuMSAzLjcuMWw1LS41LTQgNS43LTEuNCAx'
    b'LjJzLTEuMiAyLjQtNC43IDMuOGMtMy42IDEuNC05LjUuNC0xMi4yLS4zLTIuNy0uNy02LTMu'
    b'Mi01LjgtNi41eiIvPgogIDxwYXRoIGZpbGw9IiMwNDUzNGUiIGQ9Ik0yOTkuOSAyNjQuMWgu'
    b'MmMwLS41LjItMS4zLjYtMi4xYTEyLjIgMTIuMiAwIDAgMSAyLjctMy44YzEuMS0xIDIuNS0x'
    b'LjggMy45LTEuOC44IDAgMiAuMiAzLjQuNmEyOS40IDI5LjQgMCAwIDEgNC4xIDEuNGMxIC41'
    b'IDEuOCAxIDIuNCAxLjUuNy40IDEuMy44IDIgMWE5IDkgMCAwIDAgMiAuMmwxLjgtLjEgNC40'
    b'LS41LTMuNiA1LjItMS40IDEuMnYuMWE5IDkgMCAwIDEtNC42IDMuN2MtMS4zLjQtMi44LjYt'
    b'NC41LjYtMi44IDAtNS45LS41LTcuNi0xYTguNCA4LjQgMCAwIDEtMy44LTIuMSA1LjcgNS43'
    b'IDAgMCAxLTEuOC00aC0uNWMwIDEuNy44IDMuMiAyIDQuNGE5IDkgMCAwIDAgNCAyLjNjMS43'
    b'LjQgNC44IDEgNy43IDFhMTQgMTQgMCAwIDAgNC43LS43IDkuNCA5LjQgMCAwIDAgNC45LTRo'
    b'LS4zbC4yLjEgMS40LTEuMyA0LjMtNi4yLTUuNi43aC0uMWExNC44IDE0LjggMCAwIDEtMy40'
    b'LS4xIDUuNSA1LjUgMCAwIDEtMS45LTFjLS42LS40LTEuNC0xLTIuNS0xLjRhMjkgMjkgMCAw'
    b'IDAtNC4yLTEuNWMtMS4zLS40LTIuNi0uNi0zLjQtLjZoLS4xYy0xIDAtMiAuMy0zIDFhMTEu'
    b'MiAxMS4yIDAgMCAwLTMuMyAzLjUgOC4zIDguMyAwIDAgMC0xLjQgMy43aC4zeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiMwYzg0ODkiIGQ9Ik0zMjQgMjY0LjljLS40LjMtMSAuMy0xLjQuMy0uNSAw'
    b'LTExLjYtNi43LTE1LTYuNC0zLjUuMy02LjggMS43LTYuOSA1LjMgMCAzLjUuOCAzLjUgMS41'
    b'IDQuNXM3LjUgMi41IDcuNSAyLjVoNC4xbDMuMy0uNCAzLTEuNiAxLjUtMS4zIDEuMS0xLjMg'
    b'MS4zLTEuNnoiLz4KICA8cGF0aCBmaWxsPSIjMDQ1MzRlIiBkPSJNMzA2LjUgMjYzYzAgLjgt'
    b'LjMgMS4zLTEgMS4zLS42IDAtMS4xLS4zLTEuMS0xcy40LTEgMS0xYy43IDAgMSAuMSAxIC44'
    b'em0xLjEtM2MwLS42LjYtLjggMS4yLS44LjcgMCAxLjIuMiAxLjIuOCAwIC42LS41IDEtMS4y'
    b'IDEtLjYgMC0xLjItLjQtMS4yLTF6bTYuNyAxLjhjMC0uNS40LS45IDEtLjkuNSAwIC45LjQu'
    b'OSAxcy0uNC44LTEgLjhhMSAxIDAgMCAxLTEtLjl6bTEuMyA0YzAtLjYuNS0xIDEtMSAuNiAw'
    b'IDEuMi4yIDEuMi44cy0uMiAxLjMtLjggMS4zYy0uNiAwLTEuNC0uNC0xLjQtMXptLTMuMiAy'
    b'LjdjMC0uNi41LTEgMS0xIC43IDAgMS4yLjQgMS4yIDEgMCAuNS0uNS45LTEgLjktLjcgMC0x'
    b'LjItLjQtMS4yLTF6bS02LTFjMC0uNi4zLTEgLjktMWExIDEgMCAxIDEgMCAxLjkgMSAxIDAg'
    b'MCAxLTEtMXoiLz4KICA8cGF0aCBmaWxsPSIjOGNiZWJmIiBkPSJNMzA2LjQgMjYzYzAgLjUt'
    b'LjQgMS0xIDFhMSAxIDAgMCAxLTEtMWMwLS42LjQtLjggMS0uOHMxIC4yIDEgLjd6bTMuMy0z'
    b'LjJjMCAuNS0uMi45LS44LjktLjUgMC0xLjMtLjQtMS4zLS45cy41LTEgMS0xYy42IDAgMSAu'
    b'NSAxIDF6bTYuNCAxLjdjMCAuNS0uNC45LTEgLjlzLS45LS40LS45LS45YzAtLjQuNC0uOCAx'
    b'LS44cy45LjQuOS44eiIvPgogIDxwYXRoIGZpbGw9IiMwNDUzNGUiIGQ9Ik0zMTIuNyAyNjQu'
    b'MmMwIC43LS4zIDEuMi0xIDEuMi0uNiAwLTEuMS0uMy0xLjEtMXMuMy0xIDEtMSAxIC4yIDEg'
    b'Ljh6Ii8+CiAgPHBhdGggZmlsbD0iIzhjYmViZiIgZD0iTTMwOCAyNjcuMmMwIC41LS40IDEt'
    b'MSAxcy0xLS41LTEtMSAuNi0uOCAxLjItLjguOC4zLjguOHptNC41LTNhMSAxIDAgMCAxLTEg'
    b'MSAxIDEgMCAwIDEtMS0xIDEgMSAwIDAgMSAxLTEgMSAxIDAgMCAxIDEgMXptNS4yIDEuM2Mw'
    b'IC42LS4zIDEtMSAxLS42IDAtMS4xLS40LTEuMS0xcy4yLS44LjgtLjhjLjYgMCAxLjMuMiAx'
    b'LjMuOHptLTMuMyAyLjdjMCAuNi0uNCAxLTEgMXMtMS4xLS40LTEuMS0xYzAtLjUuNS0uOCAx'
    b'LS44LjYgMCAxIC4zIDEgLjh6Ii8+CiAgPHBhdGggZmlsbD0iIzIzMWYyMCIgZD0iTTMxNC44'
    b'IDI2NXMxLjYtLjIgMS45IDBjLjMuNC4zLjguMSAxLS4xIDAtLjguMS0xLS4xIDAtLjMtMS0x'
    b'LTEtMXptLTEuNy01LjRzMS4zLjMgMS44LjljLjUuNS40IDEgLjQgMS4xLS4yLjEtLjYuMi0x'
    b'LS4ybC0xLjItMS44em0tMy43IDIuNnMxLjUuOCAxLjggMS4zYy4zLjQuNC44LjIgMS0uMS4y'
    b'LS44IDAtMS0uMyAwLS4zLTEtMi0xLTJ6Ii8+CiAgPHBhdGggZmlsbD0iIzIzMWYyMCIgZD0i'
    b'TTMwOC43IDI2My4zczEuNy4yIDIgLjVjLjUuNC44LjQuOC42IDAgLjMtLjMuNC0uNS40YTMu'
    b'NiAzLjYgMCAwIDEtMS4yLS41bC0xLTF6bS0xLjktNC44czEuNy4yIDIgLjVjLjQuMy41IDEg'
    b'LjEgMS4yLS40LjItLjgtLjItMS0uNWE4LjIgOC4yIDAgMCAwLTEtMS4yem0tMy42IDIuNXMx'
    b'LjUuOCAyIDEuNGMuMy40LjUuNyAwIDEtLjQgMC0uOS0uNy0uOS0xYTkgOSAwIDAgMC0xLjEt'
    b'MS40eiIvPgogIDxwYXRoIGZpbGw9IiMyMzFmMjAiIGQ9Im0zMDIuOCAyNjMgMS41LS4yYy41'
    b'IDAgMS4yLS4xIDEuMi4yIDAgLjQtLjYuNS0xIC40bC0xLjctLjR6bTguNiA1LjZzMS4xLS43'
    b'IDEuNy0uNmMuNS4xLjcuMS43LjQgMCAuNC0uNy4zLS45LjNsLTEuNS0uMXptLTYtLjlzLjQt'
    b'LjYuOS0uN2MuNCAwIC42IDAgLjcuMiAwIC4yLS40LjYtLjYuNmgtMXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjMDQ1MzRlIiBkPSJNMzIyLjYgMjY2LjZzLTEuNiAyLTQgM2ExNCAxNCAwIDAgMS03'
    b'LjIgMS4xIDE1LjIgMTUuMiAwIDAgMS0xMS4yLTUuMmwuNCAxLjEgMiAyLjYgMi4zIDEgMy41'
    b'IDEgMy4zLjNoMi41bDMtLjUgMS45LS43IDEuMy0uOCAxLS44IDEuMi0yem0tMy01LjlzLTEg'
    b'LjMtMy0uOS00LjMtMi44LTguOC0yLjhjLTQuNSAwLTUuOSAzLTYuMiAzLjJsMi0yLjYgMi0x'
    b'LjEgMS43LS4zaDEuNWwyIC42IDEuNy42IDIuMS43IDEuOCAxIDIuMiAxLjEgMSAuNXptNiAx'
    b'LjRoLTMuNGMtLjggMC0uOC4yLTEgLjRhNCA0IDAgMCAxLS4yLjRsLS44LTEuNyAzLjUtLjUg'
    b'MiAuNy0uMi42eiIvPgogIDxwYXRoIGZpbGw9IiMwYzg0ODkiIHN0cm9rZT0iIzA0NTM0ZSIg'
    b'c3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTMyMC43IDI4MC40Yy4yLjUuNiAxIDEuMSAxaDEuNmwz'
    b'LjYtLjMgMS4yLTEuNC44LTMuMiAxLTEuMiAzLjMtMS45IDIuOC0uOCAxLjktLjIgMi41LS44'
    b'IDEuOS0xIC44LTEuMi44LTEuOC0uOC0yLjUtMi0yLjctMy40LTEuM0gzMzVsLTMgMS4xLTUu'
    b'NSAxLjNzLTMgMS4zLTQuMyAzLjdjLTEuMyAyLjMtMS4yIDMtMS41IDYtLjIgMy4yIDAgNy4y'
    b'IDAgNy4yeiIvPgogIDxwYXRoIGZpbGw9IiM4Y2JlYmYiIGQ9Ik0zMjIuMiAyNzkuMmMxIDAg'
    b'LjItMS43IDEuNC0zLjggMS4yLTIgMi42LTQuNiAzLTQuNnMuNC40LjkuM2MuNC0uMiAxLjIt'
    b'LjggMS4yLTEgMC0uMiAwLTEuMyAxLTIgLjgtLjggMi4xLTEuOSAyLjctMiAuNi0uMSAxLS4z'
    b'IDEgMCAuMS4zLS4zLjcuMS44LjQuMiAxLjQuMSAxLjYtLjVsLjItMXMuNi0uNSAxLjgtLjNj'
    b'MS4yLjMgMS4zLjIgMS40LjcuMS40LS41LjUtLjQuOHYuNmMuMi4yLjQgMSAxLjIgMSAuOC0u'
    b'MSAxLjEtLjYgMS4xLS42bC4zLS40cy4yLS41LS4xLS43Yy0uMy0uMi0uMi0uNCAwLS4zLjQu'
    b'MSAxLjYgMS44IDIgMS4xLjQtLjcuNS0xLjcuMi0yYTkxLjIgOTEuMiAwIDAgMS0xLjktMi43'
    b'bC0zLTEtNCAuMy00IDIuMi0zLjYgMnMtLjIgMi45LS44IDIuM2MtLjctLjUtMS42LTItMS45'
    b'LTEuNS0uMy41LS45IDIuNy0xLjMgMy44LS4zIDEtMS40IDQuNC0xLjMgNS42LjEgMS4yLjgg'
    b'Mi45IDEuMiAyLjl6Ii8+CiAgPHBhdGggZmlsbD0iIzhjYmViZiIgZD0iTTMyNS44IDI3NC40'
    b'Yy0uMyAwLS43LjMtLjguNS0uMi4yLS4zLjUtLjIgMSAwIC4zLjcuNy43LjdoLjVsMS0uMy4z'
    b'LS44YzAtLjUtLjMtLjYtLjQtLjZhMjkgMjkgMCAwIDEtMS4xLS41em02LjItNWMtLjYtLjMt'
    b'LjguMS0xIC4zdi41cy4yLjguNCAxYy4zIDAgMS4xLjMgMS4zIDAgLjMtLjIuNS0uNC41LS45'
    b'cy0uNy0uNy0uNy0uN2wtLjUtLjN6bTUgMS4xYzAtLjItLjUtLjMtLjktLjItLjMgMC0uNy40'
    b'LS42IDEgLjIuNy44LjcgMS4yLjYuNS0uMS40LS44LjQtLjlsLS4xLS41em0tMTQuNCAxYzAg'
    b'LjMuNSAxIDEuMi45YTEuMyAxLjMgMCAwIDAgMS4yLTFjMC0uNC0uNC4zLTEgLjVzLS43LjIt'
    b'MSAwYy0uMi0uNC0uNC0uNC0uNC0uNHoiLz4KICA8cGF0aCBmaWxsPSIjMDQ1MzRlIiBkPSJN'
    b'MzI3LjMgMjc1LjVzMCAuNi0uNCAxYy0uNS4zLS44LjMtMSAuMy0uMyAwLS42IDAtLjgtLjNs'
    b'LS4zLS43cy41LjggMS4zLjZhMiAyIDAgMCAwIDEuMi0uOXptMTMuMy04LjNzMCAuNi0uNS45'
    b'Yy0uNS4zLS43LjMtMSAuMy0uMiAwLS42LS4xLS43LS40LS42LTEtLjMtMS41LS4zLTEuNXMu'
    b'NCAxLjYgMS4zIDEuNWEyIDIgMCAwIDAgMS4yLS44em0tMTEuOSAyLjlzLS40IDEuMi0xLjIg'
    b'MS4yYy0uOSAwLS44LS4yLS43LS40IDAtLjEuMy4yLjcgMCAuNCAwIDEuMi0uOCAxLjItLjh6'
    b'bTIuMy0uM3MwIDEgLjIgMS4yYy4zLjQuNy41IDEgLjVzLjYgMCAuOS0uNC4xLS44LjEtLjhs'
    b'LS4yLjVjLS4zLjMtLjUuMy0uOC4zcy0uNyAwLS44LS4zbC0uNC0xem00LjMtNC4zcy4yLjct'
    b'LjMgMS4yYy0uNS42LTEuNS4yLTEuNS4ycy44LjMgMS4yLS4yYy40LS40LjYtMS4yLjYtMS4y'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiMwNDUzNGUiIGQ9Ik0zMjEuNyAyODEuMXM1LjMgMCA1Ljct'
    b'LjhjLjQtLjctLjQtMy42IDIuNy01LjggMy4yLTIuMiA1LjctMi4yIDcuNC0yLjMgMS43LS4y'
    b'IDUuMy0xLjMgNi00LjUuMy0yLTIuMy0yLjItMy4zLTQtMS0yLTMuNi0xLjItMy44LTEuMi0u'
    b'MSAwLTMgMC00LjMgMS4zLS45LjgtLjggMS44LTEuMSAyLjItLjQuNS00IDAtNC4zLjYtLjQu'
    b'Ni4xIDEuNy0uMiAyLS4yLjMtMS0uOC0xLS44bC4yLTIuOCA0LjUtMi42IDUtMi44IDMuNS4x'
    b'IDMuNSAxLjggMS43IDJzLjMuOC41IDIuM2E1LjMgNS4zIDAgMCAxLS4yIDJjLS44IDIuOC0z'
    b'LjcgNC44LTYuNyA1YTE0IDE0IDAgMCAwLTcgMi41Yy0xLjQgMS0yLjEgNS4zLTIuMSA1Ljkg'
    b'MCAuNS02LjYuMS02LjYuMXYtLjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzIzMWYyMCIgZD0iTTMy'
    b'NCAyNzAuOGMtLjMuMy0uNy4yLS44IDAtLjItMSAuMy0yLjIuMy0yLjJ2MS42Yy4xLjIuNC4x'
    b'LjUuM3YuM3ptMy4yLS42Yy0uMi0uMS0uMS0xIDAtMS4zLjItLjMgMS43LTEuNCAxLjctMS40'
    b'bC0uNiAxLjVjLS4yLjQtLjcgMS4zLTEgMS4yem0tMS4yIDUuM2MtLjMgMC0uMy0uNC0uMy0x'
    b'czEtMS42IDEtMS42bC0uNCAxLjIuMiAxYzAgLjMtLjMuNC0uNS40eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiMyMzFmMjAiIGQ9Ik0zMjguNCAyNzRzLS41LjYtMSAuOWMtLjUuMy0xLjEuNy0xLjQu'
    b'Ni0uNCAwIC4xLS44LjMtLjlsMi4xLS42em00LjUtNi40cy0uNi41LS45IDEuMmMtLjMuNy0u'
    b'NCAxLjMtLjEgMS40LjMuMi43LS44LjgtMS4xbC4yLTEuNXoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'MjMxZjIwIiBkPSJNMzM0LjYgMjY5LjlzLS41LS40LTEuMi0uNmMtLjgtLjItMSAwLTEuMi4y'
    b'IDAgLjItLjYuNS0uMy43LjIuMi42LS4zLjgtLjMuMi0uMS41LS4zLjktLjJsMSAuMnptLTEt'
    b'NC41Yy4zLjMuNy0uMiAxLS42LjQtLjQuNy0xLjIuNy0xLjJsLTEgLjdjLS40LjMtLjkgMS0u'
    b'NyAxLjF6bTYuOS0uMXMtMSAuNC0xLjIuOGMtLjMuNC0uNy44LS40IDEgLjMuMy42LS4yLjgt'
    b'LjVsLjgtMS4zem0tMiA0LjZzLS4zLjYtLjkgMWMtLjUuNC0xLjIuNS0xLjMuMy0uMS0uMi4x'
    b'LS42LjMtLjdsLjgtLjJhNy4zIDcuMyAwIDAgMCAxLjEtLjR6Ii8+CiAgPGVsbGlwc2UgY3g9'
    b'IjMyOC44IiBjeT0iMjA3LjQiIGZpbGw9InVybCgjbXgtYikiIHJ4PSIyLjkiIHJ5PSI0LjMi'
    b'IHRyYW5zZm9ybT0icm90YXRlKDguNykiLz4KICA8cGF0aCBmaWxsPSIjZmNjYTNlIiBzdHJv'
    b'a2U9IiNhYThjMzAiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0yOTUuNCAyNDctMS43IDQuMiAx'
    b'LjQtLjIuNy0zLjh6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjY2EzZSIgc3Ryb2tlPSIjYWE4YzMw'
    b'IiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJNMjk2LjEgMjQ1LjFjLS42IDAtMS4xLjQtMS4yIDEg'
    b'MCAuNy40IDEuMyAxIDEuNC42IDAgMS4xLS40IDEuMi0xIDAtLjctLjMtMS4zLTEtMS40eiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmY2NhM2UiIHN0cm9rZT0iI2FhOGMzMCIgc3Ryb2tlLXdpZHRo'
    b'PSIuMyIgZD0ibTM2OS43IDI1NS44LTQuMiA0IDEuNy40IDIuOS0zLjh6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2ZjY2EzZSIgc3Ryb2tlPSIjYWE4YzMwIiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJN'
    b'MzcxLjYgMjU0LjFhMS41IDEuNSAwIDAgMC0yIC42Yy0uNS43LS4zIDEuNS40IDIgLjcuMyAx'
    b'LjYgMCAyLS43LjQtLjYuMi0xLjUtLjQtMS45eiIvPgogIDxwYXRoIGZpbGw9IiNmY2NhM2Ui'
    b'IHN0cm9rZT0iI2FhOGMzMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0ibTI2Mi44IDIzMyAyLjIg'
    b'NC45IDEtMS40LTIuNi0zLjd6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjY2EzZSIgc3Ryb2tlPSIj'
    b'YWE4YzMwIiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJNMjYxLjkgMjMwLjljLS42LjQtLjYgMS4z'
    b'LS4xIDEuOS40LjYgMS4zLjcgMS44LjIuNi0uNS42LTEuMy4xLTJhMS4zIDEuMyAwIDAgMC0x'
    b'LjgtLjF6Ii8+CiAgPHBhdGggZmlsbD0iI2FhOGMzMCIgZD0iTTI5Ni42IDI0NS4zcy4zLjEg'
    b'MCAwYy0uNSAwLTEuNC40LTEuNCAxYTEgMSAwIDAgMCAxIDFjLjUgMC0uMi4yLS4yLjJsLS43'
    b'LS4yLS4yLS40LS4yLS41LjEtLjYuNC0uNS41LS4yaC4zbC40LjJ6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2FhOGMzMCIgZD0iTTI5NS42IDI0OC4xcy0uMyAwLS41LjNhNDkuNCA0OS40IDAgMCAx'
    b'LS43IDEuMWwxLTIuMy40LjItLjIuN3ptNzYuNCA2LjRzLjMuNC0uMSAwYy0uNC0uMy0xLjgt'
    b'LjItMi4xLjUtLjQuOCAwIDEuNC42IDEuNy42LjItLjIgMC0uMiAwbC0uNy0uNS0uMS0uNnYt'
    b'LjdsLjUtLjYuNy0uM2guN2wuMy4yLjQuM3oiLz4KICA8cGF0aCBmaWxsPSIjYWE4YzMwIiBk'
    b'PSJNMzY5LjQgMjU3LjNzLS4zLS4yLS44IDBsLTEuNC45IDIuMy0yLjIuNS42LS42Ljd6bS0x'
    b'MDctMjYuN3MuNC0uMSAwIC4xYy0uNS4zLS44IDEuNC0uMyAyIC42LjUgMS4zLjQgMS43IDAg'
    b'LjQtLjUgMCAuMiAwIC4ybC0uNy40aC0uNmwtLjYtLjMtLjQtLjZ2LS44bC4yLS41LjMtLjMu'
    b'My0uMnoiLz4KICA8cGF0aCBmaWxsPSIjYWE4YzMwIiBkPSJNMjY0IDIzMy44cy0uMy4xLS4y'
    b'LjZsLjMgMS41LTEuMi0yLjcuNy0uMi40Ljh6Ii8+CiAgPGVsbGlwc2UgY3g9IjMzNy42IiBj'
    b'eT0iLTEyOC4xIiBmaWxsPSJ1cmwoI214LWMpIiByeD0iNC42IiByeT0iMy4xIiB0cmFuc2Zv'
    b'cm09InJvdGF0ZSg2Mi45KSIvPgogIDxwYXRoIGZpbGw9IiNlOTI3MzYiIGQ9Ik0yNjIuNiAy'
    b'NDEuMnMxIC4yIDEuNSAwIC42LS43LjctLjguMy0uNi4yLTFhMy44IDMuOCAwIDAgMC0xLTEu'
    b'NGwtMS0uMWMtLjEtLjEgMC0uNC0uMi0uNS0uMyAwLTEuNyAxLjYtMS41IDEuOC4zLjMuNCAw'
    b'IC41LjF2MS4xYzAgLjMuOC44LjguOHoiLz4KICA8cGF0aCBmaWxsPSIjZTkyNzM2IiBkPSJN'
    b'MjY0IDIzOC4xYy4xLjMuNyAxIC45IDEgLjIuMi44LjIgMSAwIC4zIDAgMS0uNyAxLTFhMS41'
    b'IDEuNSAwIDAgMC0uMS0uN2MtLjItLjMtLjEtMS0uNC0xLjEtLjIgMC0uMy0uMS0uNS0uM3Yt'
    b'LjdjLS4zLS4zLTIuNiAxLjEtMi40IDEuNC4yLjIuNCAwIC41LjF2MS4zeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNlOTI3MzYiIGQ9Ik0yNjkuMiAyMzcuNmMuMi0uNC4xLTEuNS0uMS0xLjhzLS42'
    b'LS4zLS43LS40YzAtLjEuMy0uMi4zLS41cy0yLjYuMS0yLjQuNGMuMi4zLjYuMS42LjMgMCAu'
    b'Mi0uNC40LS41LjZsLjMgMS4xYzAgLjIgMCAuNC4yLjVsLjYuMmgxLjRjLjEtLjEuMi0uMS4z'
    b'LS41em0yMiAxMi44cy4zLjcuOCAxaDFsLjYtLjVjLjItLjIuNC0xLjIuMy0xLjQgMC0uMi0u'
    b'NS0uNi0uNS0uOCAwLS4yLjMtLjIuMi0uNC0uMS0uMi0yLS4yLTIgLjIgMCAuMy4zLjIuMi4z'
    b'IDAgLjItLjUuNS0uNi43LS4yLjEgMCAxIDAgMXoiLz4KICA8cGF0aCBmaWxsPSIjZTkyNzM2'
    b'IiBkPSJNMjkzLjggMjQ5LjVjMCAuMi0uMiAxIDAgMS4xIDAgLjIuMy43LjUuOGgxLjJhMS4y'
    b'IDEuMiAwIDAgMCAuNC0uNmMuMS0uMy42LS43LjUtLjktLjEtLjItLjItLjItLjEtLjQgMC0u'
    b'Mi4zLS4yLjMtLjVzLTIuMS0xLTIuMi0uN2MwIC4zLjMuMi4yLjQgMCAuMi0uNy42LS44Ljh6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2U5MjczNiIgZD0iTTI5Ny4zIDI1Mi41Yy4zLS4yIDEtLjkg'
    b'MS0xLjEgMC0uNC0uMy0uNi0uMi0uN2wuNS0uMWMuMS0uMi0xLjYtMS42LTEuNy0xLjMgMCAu'
    b'My4zLjQuMi41bC0uNy4xYy0uMS4xLS41LjYtLjUuOCAwIC4yLS4zLjItLjIuNWwuMi40Yy4x'
    b'LjIuOC45IDEgLjloLjR6bTY2IDUuNXMwIC44LjQgMS4yYy4zLjMuNi4zLjguNGguN2EzIDMg'
    b'MCAwIDAgMS0xYzAtLjMtLjMtLjgtLjItMXMuMyAwIC4zLS4yYzAtLjMtMS42LTEuMS0xLjct'
    b'LjgtLjEuMi4yLjMgMCAuNGwtLjguMmMtLjIgMC0uNS44LS41Ljh6Ii8+CiAgPHBhdGggZmls'
    b'bD0iI2U5MjczNiIgZD0ibTM2NiAyNTguNS0uOC44YzAgLjIgMCAuNy4yLjggMCAuMi43LjYg'
    b'MSAuNS4xIDAgLjMgMCAuNS0uMi4yLS4xLjgtLjIuOC0uNGwuMS0uNGMuMS0uMS40IDAgLjYt'
    b'LjIuMi0uMi0xLjItMS43LTEuNC0xLjUtLjIuMiAwIC4zIDAgLjQtLjIgMC0uOSAwLTEgLjJ6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2U5MjczNiIgZD0iTTM2Ni40IDI2Mi4yaDEuNGwuNC0uNWMu'
    b'MSAwIC4xLjIuNC4yLjIgMCAwLTItLjMtMS44LS4yLjEtLjEuNS0uMi40LS4yIDAtLjMtLjMt'
    b'LjUtLjNhMi40IDIuNCAwIDAgMC0xIC4xcy0uMiAwLS4zLjJsLS4yLjR2MWMuMS4yIDAgLjIu'
    b'My4zeiIvPgogIDxwYXRoIGZpbGw9IiNmN2UyMDQiIGQ9Ik0yNjQuMiAyMzljLjIuNC0uMSAx'
    b'LjItLjMgMS40LS4xLjItMS4zLS4xLTEuMy0uMyAwLS4yLS4xLS42IDAtLjguMi0uMi42LS43'
    b'LjktLjYuMyAwIC42LjMuNy40em0uMy0xLjNjLS4yLjMgMCAuNi4yLjcuMS4yIDEgLjQgMS4y'
    b'LjMuMi0uMi42LTEuNS40LTEuNy0uMi0uMi0uNi0uMi0uNy0uMi0uMiAwLTEgLjYtMS4xLjl6'
    b'bTIuNy0xLjN2LjdjLjIuMS43LjUgMSAuNS4zIDAgLjUtMSAuNS0xLjEgMC0uMi0uMS0uMy0u'
    b'My0uNGwtMS4yLjJ6bTI2LjEgMTMuN2MwIC40LS43LjctLjkuNy0uMiAwLS43LTEtLjYtMSAu'
    b'MS0uMi4zLS41LjUtLjVzLjcgMCAuOS4ybC4yLjd6bTEuMS0uNmMtLjIuMS0uMy40LS4zLjYg'
    b'MCAuMi4zLjguNS45LjIgMCAxLjItLjUgMS4zLS43IDAtLjItLjItLjUtLjQtLjZsLTEtLjJ6'
    b'bTIuNCAxYy0uMiAwLS40LjMtLjQuNSAwIDAgMCAuNi4zLjguMi4yLjgtLjIuOS0uM3YtLjRj'
    b'MC0uMi0uOC0uNi0uOC0uNnptNjguNiA4LjJjLS4yLjItLjkuMi0xIDAtLjMgMC0uMy0xLS4x'
    b'LTEgLjEtLjEuNC0uMy42LS4yLjIgMCAuNi4zLjYuNmwtLjEuNnptMSAuMWMtLjMgMC0uNS4x'
    b'LS42LjMtLjEuMS0uMi43IDAgLjkuMS4xIDEuMi4yIDEuMyAwdi0uNWwtLjctLjd6bTEgMmgt'
    b'LjVjLS4xIDAtLjQuNC0uNC43IDAgLjIuNy4zLjguM2wuMy0uMi0uMS0uOHoiLz4KICA8ZWxs'
    b'aXBzZSBjeD0iNDM4LjYiIGN5PSItOTMiIGZpbGw9InVybCgjbXgtZCkiIHJ4PSIyLjIiIHJ5'
    b'PSI0LjUiIHRyYW5zZm9ybT0icm90YXRlKDQ3LjkpIi8+CiAgPHBhdGggZmlsbD0iI2E4YWM3'
    b'MSIgZD0iTTI4NS44IDE5OS4zcy0zLjguMy02LjUtLjEtMi03LjMtMi4xLTcuNWMwLS4yLTEu'
    b'Ni0xLjgtMS40LTMuMy4zLTEuNSA1LjItNS41IDUuOC01LjguNS0uMSAxLjUuMyAxLjUuM3Mx'
    b'LjItMS4yIDEuNi0xLjJjLjQgMCAuOS43LjggMS0uMi4zLTEuOSAxLjMtMiAyLS4yLjggMCAx'
    b'LjUtLjUgMi4zLS41LjctMS40IDEuNy0xLjUgMi40LS4xLjYtLjQgMS4xIDAgMS40LjUuMiAy'
    b'LjEgMCAzLjUtLjYgMS40LS43IDItMS41IDIuMS0xLjQuMiAwLS44IDEuNy0yLjMgMi40LTEu'
    b'NS42LTIuNSAxLjMtMy4zIDEuMiAwIDAtLjggMiAxLjggMi4yIDIuNiAwIDQtLjYgNC0uNmwt'
    b'MS41IDUuM3ptLTE1IDE2czIgLjggMiAzLTIuMSA0LjEtMiA4YzAgNCAuNiA0IDUuOCA4LjNh'
    b'NS43IDUuNyAwIDAgMSAxLjYgMi41Yy4zIDEuMyAxLjIgOC45IDYuMiA4LjlzNS44LTMuMyA1'
    b'LjgtMy4zbC0yLjItMy4xcy0xLjcuNS0yLjcuM2EzLjQgMy40IDAgMCAxLTIuMy0yLjFjLS42'
    b'LTEuMi0uNy00LjEtMS42LTUuNC0yLTMuMi01LjgtMy43LTUuOS03IDAtMy40IDIuMy0zLjcg'
    b'MS43LTcuNy0uNy00LTUuNC01LjgtNS40LTUuOGwtMS45LS44LS43IDQgMS42LjJ6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2YxYTcyMCIgZD0iTTI4NC43IDE4Ny42YzEuNy0uNC43LTQuOC43LTQu'
    b'OGwtMS4yIDFzLjggMSAuOCAyLS4zIDEuOC0uMyAxLjh6Ii8+CiAgPHBhdGggZmlsbD0iI2E4'
    b'YWM3MSIgZD0ibTI4Ny44IDIzMS41LS45LS43Yy0uNi0uNC0zLjItMi42LTIuOC04LjkuNS03'
    b'LjIgMTEtMTEgMTEuNi0xMy44LjgtMy4yIDMuMS00LjUtNS4yLTExbC0yIDIuMiAzLjUgMi42'
    b'cy43LS40LjguNmMwIDEtMSAxLjctMS4yIDIuNS0uMi43LTUuNCA0LjMtNS44IDQuNmwtMyAy'
    b'LjRzLTEuMyAxLjMtMi41IDQuMWMtMS4zIDIuOC0uNyA2LjQtLjcgNi40czAgNy42IDguMiA5'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiM3ODczMmUiIGQ9Im0yODIuNyAyMzUuNS42IDIuNy0xLjcu'
    b'NmgtLjdsLS41LjItMS4zIDEuMmgtLjNzLS4yIDAtLjMtLjhjMC0uOC0uMi0xLjUtLjItMS41'
    b'bDEuNi43aC42bC4zLS4xLjctMS41IDEuMi0xLjV6bS00LjguNS0uOC0xLTEtLjkgMS4yLS42'
    b'aDEuMmwtLjIgMS41LS40IDF6bTIuNy00LjNzLjguMyAxIDFsLjYgMS4yLTItLjItMS40LS40'
    b'IDEtMS40LjgtLjJ6bS0uNyAxMS45cy0uNC0uMy0uNy0uOWwtLjQtMS42IDEuMy0uMyAxLjUu'
    b'N2guNGwtLjMuOC0xLjUgMS4zaC0uM3ptNS00LjFzLTEtLjQtMS4yLTFjLS4yLS41LS40LS40'
    b'LS40LS40bC0uMyAxLjUtLjUgMS41LjIuMiAxLjEtLjMuOS0uOS4zLS42em0tNC43IDQuOCAx'
    b'LjQuN2MuOC41IDEuMi41IDEuMi41bC42LS42LjctMS4zdi0uMWwtMyAuMy0uOS41em00LjQt'
    b'MS4yIDIuNy0xLjYuMS0xLjQtLjUtLjRoLTEuNWwtLjUgMS44LS4zIDEuNnptLTEuOCAyLjVz'
    b'MS44LjggNS0uNGMxLjQtLjUgMS43LTEuMiAxLjctMS4ybC0xLjMtLjUtMS4yIDEtNC4yIDF6'
    b'bS0yLjUtMjAuMy0uNC0xLjRjLS4yLS44LS4xLTEuMS0uMS0xLjFsLjkuNSAxLjMgMS0xIC43'
    b'LS43LjN6bTIuMiAzLjctLjktMWExMi40IDEyLjQgMCAwIDEtLjYtMS4ybDEgLjIgMS4xLjYt'
    b'LjUgMS40aC0uMXoiLz4KICA8cGF0aCBmaWxsPSIjYzZjN2E2IiBkPSJNMjc2LjYgMTg3Yy0u'
    b'Mi43LS40IDEuOS41IDIgLjQuMiAyLjMgMCA0LjUtMi40IDEtMS4yIDEtMi40IDEtMi40bC41'
    b'LTEuM3MtLjktLjYtMi4yLjJjLTEuMy44LTQuMyA0LTQuMyA0eiIvPgogIDxjaXJjbGUgY3g9'
    b'IjI4Mi41IiBjeT0iMTgzLjYiIHI9Ii40IiBmaWxsPSIjMWMyNDJmIi8+CiAgPHBhdGggZmls'
    b'bD0iI2E4YWM3MSIgZD0iTTI3OS43IDE4NGExNy43IDE3LjcgMCAwIDAtMS43IDEuN3MxLjQt'
    b'LjQgMi42LTEuNWMuNi0uNiAyLS44IDIuNi0uNy40LjEuMi0uNCAwLS41LS4zLS4zLTEuNC0u'
    b'NC0xLjYtLjNsLTEuOSAxLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzc4NzMyZSIgZD0iTTI4NC4x'
    b'IDIyNC41di0yLjJsLS45LjgtLjggMS4xIDEuMy41LjQtLjJ6bS00LjUtMi42di0yLjNjMC0x'
    b'IC41LTMuMS41LTMuMWwuNiAxLjQgMS41IDIuNC41LjQtMS4zIDEtMS40LjQtLjQtLjJ6bTQu'
    b'NS0uNi4zLTFjLjEtLjYuNS0xLjQuNS0xLjR2LjFhMjUgMjUgMCAwIDAtMiAxLjdsLjguN2gu'
    b'NW0tMy43LTZzLjItLjYgMS0xLjVsMS4zLTEuOC42IDIuNC40IDJ2LjRsLS43LjJjLS4yIDAt'
    b'MS42IDAtMS44LS4zbC0uOC0xLjN6bTQuOCAyLjkuOC0uOSAxLTEtMy4yLjYuNSAxIC44LjN6'
    b'bS0yLTYuN3MuMyAwIDEuMi0xYy44LS44IDEuMy0uNyAxLjMtLjdsLjMgMy40LTEuNi0uNS0x'
    b'LjItMS4yeiIvPgogIDxwYXRoIGZpbGw9IiM3ODczMmUiIGQ9Im0yODcuMyAyMTYuMiAyLTIt'
    b'My4zLTEgLjYgMi4zem0xLjQtNS4yLjItMy4zcy0uNy4zLTEuNSAxbC0xLjIuOS40LjYgMSAu'
    b'N2gxem0yLjgtMy4yVjIwNXMtLjUuOC0xIDEuMmwtLjkuOC45LjZoMXptMS4yIDMuNSAxLjYt'
    b'MS4zYTYuNSA2LjUgMCAwIDAgMS41LTEuN2wtNC4yLS4zLjIgMS43IDEgMS42em0tOS42LTEz'
    b'LjgtLjIgMS44aDMuNWwtLjktMS4yLTEtLjYtMS0xem02LjYgMTYuMmMuMiAwIDEuMS0uOCAx'
    b'LjYtMS4yLjQtLjUgMS4yLTEgMS4yLTFsLTMuMy0uM3YyLjJsLjUuM3ptNi4zLTUuOXMuNC0x'
    b'LjMuMy0yLjZjMC0xLjItLjItMS44LS4yLTEuOGwtMi41IDEuNy40IDEuMiAxIDEgMSAuNXoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjNzg3MzJlIiBkPSJNMjkxLjggMjA0LjhzLjctMSAuOC0xLjR2'
    b'LS40aDJsMS4xLjJoLjJsLS45IDEuMS0xLjIuNy0xLjUuMi0uNS0uNHptNC0yLTEuMy0yYy0u'
    b'NC0uNy0uOC0xLS44LTFsLTEgMi43di4zaDN6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0i'
    b'bTI3MS42IDIyMi4yLS4zLjhzMS4zLS43IDIuMy0uN2MxIDAgMi4xIDEuMyAyLjEgMS4zbC4y'
    b'LS45cy0xLjMtMS4zLTIuMi0xLjNjLS44LS4xLTIgLjgtMiAuOHptLjctNS44LjMuNGMwIC4x'
    b'LjEtMSAxLjQtMS41IDEuNC0uNiAyLS4xIDItLjFzLS4yLS44LS44LTFjLS42LS4xLTEuMSAw'
    b'LTEuOC41YTMuNyAzLjcgMCAwIDAtMS4xIDEuN3ptNC40IDQuNHMtLjYtMS40LTEuNi0xLjZj'
    b'LTEuMS0uMy0yLjUuNS0yLjUuNWwtLjIuN3MxLjUtLjggMi41LS40YzEuMS41IDEuNSAxLjcg'
    b'MS41IDEuN2wuMy0xem0tNS01LjEuNC41cy0uMi0xLjQuNS0yLjFhNC45IDQuOSAwIDAgMSAx'
    b'LjEtMWwtLjYtLjNzLS45LjUtMS4yIDEuMWEzLjIgMy4yIDAgMCAwLS4yIDEuOHptLS41LTIu'
    b'M2MuMy0uOCAxLjItMSAxLjItMWwtLjMtLjNoLS41cy0uNS4zLS45IDFjLS4zLjktLjMgMi0u'
    b'MyAybC42LjNzLS4xLTEuNC4yLTJ6bTcuOC0xOS4yYy45LS40IDEuNS0uMyAxLjUtLjNzLTEu'
    b'MyAxLjMtLjcgMi45Yy0uNyAxLjMtLjkgMi4zLS45IDIuM2guN2wuNC0xLjhjLjggMS4zIDIg'
    b'MiAyIDJoMXMwLTEuMy40LTIuNGguMWE1IDUgMCAwIDAgMiAxLjV2LS40cy0xLjEtLjYtMS43'
    b'LTEuNWwtLjEtLjFhNC4yIDQuMiAwIDAgMSAxLjgtMS43bC43LjYuMi0uMi0uNS0uN2gtLjZs'
    b'LTEuOCAxLjdhOS4yIDkuMiAwIDAgMS0uOC0xLjVsLS40LS4ycy0xLjEuMS0yIDEuN2MtLjIt'
    b'MS4yIDEuMS0yLjQgMS4xLTIuNHYtLjVsLTIuNC42Yy0xIC4zLTEuNyAxLjItMS43IDEuMnYu'
    b'OHMxLTEuMSAxLjctMS42em0xLjUgMi4yYy42LTEgMi0xLjUgMi0xLjVzMCAuNy43IDEuN2Mt'
    b'LjUuOS0uOCAyLjItLjggMi4ycy0xLS42LTEuOS0yYTEuNiAxLjYgMCAwIDEtLjItLjNsLjIt'
    b'LjF6bS03LjYgMjEuMXYuOHMuOC0uOSAyLTFjMS4yIDAgMi4zIDEgMi4zIDFzMC0xLS4yLTEu'
    b'MmMtLjEgMC0xLjEtLjYtMi0uNnMtMi4xIDEtMi4xIDF6bTIxLjQtMTEuMi0uNS0xIC42LS4z'
    b'YTEyLjUgMTIuNSAwIDAgMCAxLjctMS42bC0uNC0uNmgtMS42bC0xLjQtLjEuNS0xLjcuNi0x'
    b'LjQtLjYtLjVzLjIuNS0uOC42Yy0xIC4xLTIuOC0uOC0yLjgtLjh2LjRsMi41LjdjLjYgMCAx'
    b'LS4xIDEuMi0uM2wtLjUgMS4zLS4zIDEgLjIuMnYuOGwxLjQuMSAxLjYuMXMtLjggMS0xLjcg'
    b'MS41YTIuMyAyLjMgMCAwIDEtLjMgMGwtMS0xLjUtLjEuNS43IDEuMmE1IDUgMCAwIDEtMS41'
    b'LS4xbC0uNC40djIuNWwtMS44LS42LS4zLjN2LS4xbC0uNC40cy0uNCAxLjQtLjMgMy4xdi4x'
    b'YTQuOSA0LjkgMCAwIDEtMi40LTEuM2wtLjQuM3MtLjMgMS40IDAgMy4yYy0xLjMtLjMtMi41'
    b'LTEuNS0yLjUtMS41bC0uNS41YTYwIDYwIDAgMCAwIC43IDQuNyA0LjkgNC45IDAgMCAxLS43'
    b'IDBjLTEuNCAwLTIuMy0xLjMtMi4zLTEuM2wtLjQgMXMuNiAyLjcgMiA0bC40LjJjLTEuMyAx'
    b'LTIuOCAxLjItMi44IDEuMnYuOWE0NC43IDQ0LjcgMCAwIDAgMi4yIDEuNSA0LjggNC44IDAg'
    b'MCAxLTEuNiAxbC4yLjUgMS44LTEuMyAxLjguNXYtLjVsLTEuNS0uMy4xLS4xYy41LS40IDEu'
    b'NC0xLjggMS40LTEuOHYtMXMtLjUgMC0xLjEtLjZjMS44LTEuMiAxLjktMS44IDEuOS0xLjhs'
    b'LjQtLjZzLS43LS4zLTEuMS0xLjJsMi45LS43LjItLjJzLS43LTEuMi0xLTIuNmwzIC42LjQt'
    b'LjQtLjUtMi40YzEuOCAwIDMuMi4yIDMuMi4ybC4zLS4zcy0xLTEuOS0xLTNhNC44IDQuOCAw'
    b'IDAgMCAxIDBoM2wuMy0uNXMtMS40LTEtMS43LTEuNXptLTEwLjUgMTUuNXMtLjUgMS0xLjQg'
    b'MmwtLjIuMmE0LjYgNC42IDAgMCAxLS41LS4yYy0xLjEtLjYtMS40LTEuMy0xLjQtMS4zbDIu'
    b'NS0xLjYgMSAuOXptLjktMy4yLTIgMmE0LjEgNC4xIDAgMCAxLS40LS41Yy0uOC0xLjItMi0y'
    b'LjEtMS44LTMuOCAwIDAgLjcgMS4yIDIuMiAxYTE0IDE0IDAgMCAwIDEtLjFjLjQgMSAxIDEu'
    b'NCAxIDEuNHptMi0yLjUtMi43LjdhNS4zIDUuMyAwIDAgMS0uMS0uNWMtLjUtMS42LS41LTQt'
    b'LjUtNHMxIC44IDIuNiAxLjJsLjcgMi42em0tLjUtM2MtLjItMS40LjEtMi45LjEtMi45cy44'
    b'LjggMi4zIDFjLjEgMS41LjMgMi4xLjMgMi4xbC0yLjctLjF6bTUuOC0yLjJzLTEgLjQtMi44'
    b'LjFhMTUuMyAxNS4zIDAgMCAxIDAtLjUgMjMgMjMgMCAwIDEgMC0zbDIuMy43YTEwIDEwIDAg'
    b'MCAwIC41IDIuN3ptMC0zLjFoLS4yVjIwNXMxIC4zIDEuNy4yYy4yLjQgMCAuNS41IDEuMi40'
    b'LjcgMS4xIDEuMyAxLjEgMS4zcy0yLjMuMi0zLjIgMHptLTcuNiAxOC42LS4xLS41cy0xIC43'
    b'LTEuMiAxLjRhMS42IDEuNiAwIDAgMS0uMy0uMWwtMi0uOC4yLjQgMS44LjhoLjJsLS41IDEu'
    b'NC4yLjMuNS0xLjcgMS4yLjEtLjIuOC0uNCAxLjUuNS4zaDJsLS4zLS40LS43LS4xaC0xLjFs'
    b'LjMtMS4yLjMtLjgtLjMtLjctMSAuMmEzIDMgMCAwIDEgLjktLjl6bS0xMS4zLTEuM2MxLjMg'
    b'MCAyLjMuOSAyLjMuOXYtLjZzLTEtMS40LTIuMS0xLjRjLTEuMiAwLTIuNSAxLjItMi41IDEu'
    b'MnYxLjJzMS0xLjMgMi4zLTEuM3ptMTMuMyAxOS40Yy0xLjMuNi0yLjcuNi0yLjcuNmwuOC0x'
    b'LjVjMi41LS44IDMtMi40IDMtMi40bC0uMi0uN3MtLjYgMS42LTIuNiAyLjRjLjQtMS4yLjct'
    b'My4yLjctMy4ybC0uNy0uMnMtMSAxLjMtMiAxLjZhNy43IDcuNyAwIDAgMCAuOC0yLjdsLS4z'
    b'LS41cy0uNy42LTEuNy44YTEuOCAxLjggMCAwIDEtLjYgMGMuNi0uOCAxLjctMy4yIDEuNy0z'
    b'LjJsLS4yLS41cy0uOCAyLjEtMS43IDMuMmExMC42IDEwLjYgMCAwIDEtLjMuNGMtMS0uMy0y'
    b'LjItMS0yLjItMWwuMS4zcy44LjYgMS44IDFhMjcuMyAyNy4zIDAgMCAxLTEuMyAxLjJ2MWwz'
    b'IC40Yy0xIDEuNi0yIDIuMS0yIDIuMWwuNS43czEuMyAwIDMuNy0uNmMtLjYgMS4yLTEuMiAx'
    b'LjgtMS4yIDEuOHMyLjIuMiAzLjctLjYgMi0xLjYgMi0xLjZsLS40LS40cy0uNCAxLTEuNyAx'
    b'LjZ6bS02LjktNCAxLjItMS41YzEuNi4zIDItLjEgMi0uMXMuMy44LS42IDIuM2MtMS4xIDAt'
    b'Mi42LS44LTIuNi0uOHptMS40IDMgMS4zLTEuNi4zLS4zYzEuNSAwIDIuMy0xLjMgMi4zLTEu'
    b'M3MuMiAxLjItLjUgMi43Yy0xLjkuNy0zLjQuNS0zLjQuNXptLTEuOS05LjhjMS41IDAgMy4z'
    b'LjcgMy4zLjdsLS4yLS43LTIuOS0uNmEzLjYgMy42IDAgMCAxIDEuNi0xLjZsLS41LS4zcy0u'
    b'Ni4xLTEuNCAxLjVhNC4xIDQuMSAwIDAgMC0uMi40IDQgNCAwIDAgMC0uMyAwIDUgNSAwIDAg'
    b'MC0yLjQuN2wuMi40czEuMS0uNSAyLjMtLjVhMjUuNyAyNS43IDAgMCAwLS43IDIuNGwuMy42'
    b'IDEtM3ptLTMtNi4yLS4zLS43cy0xLjUtLjYtMi43IDBjLTEuMS41LTIgMS45LTIgMS45bC41'
    b'LjlzLjgtMS41IDEuOS0xLjljMS0uMyAyLjYtLjIgMi42LS4yem0zIDIuNC0xLS42cy0xLjcu'
    b'NS0yLjIgMS4xYy0uNi42LTEuMSAyLjEtMSAyLjUuMi41LjcuNy43LjdzLjMtMS41IDEuMS0y'
    b'LjNjLjgtLjggMi40LTEuNCAyLjQtMS40em0tMy45LS41YTQuNSA0LjUgMCAwIDEgMi0xbC0u'
    b'Ny0uNXMtMS41LjItMi4yLjljLS44LjctMS44IDIuMS0xLjggMi4xbC45LjlzMS4yLTEuOCAx'
    b'LjgtMi40em01LjItNDQuN3YtLjFjLjgtMSAxLjYtMSAxLjktMWguNmE5LjMgOS4zIDAgMCAw'
    b'LS44IDIuNWMtLjIgMS0uNyAxLjItMSAxLjktLjQuNy0xLjEgMS44LTEuMiAyLjggMCAxIC4z'
    b'IDEuNi41IDEuNy4zLjEuOC0uNC43LS43IDAtLjMtLjMgMC0uNCAwLS4yIDAtLjItLjMtLjMt'
    b'LjktLjEtLjYuNy0yLjIgMS0yLjguMy0uNSAxLTEuMSAxLTJsLjctMi41YzAtLjEtLjQtLjIt'
    b'MS4zLS4zLS42IDAtMS41LjUtMS45IDEuMi0uNC42LTEuNyAxLjEtMS43IDEuMXMxLjQgMCAy'
    b'LjItMXoiLz4KICA8cGF0aCBmaWxsPSIjNzg3MzJlIiBkPSJNMjg1LjIgMTk0LjVoLTIuNWwu'
    b'NyAyem0tMy0uMS0uNS0uNGExLjUgMS41IDAgMCAwLS4zLS4zbC0uOS41LS41IDEuOS4zLjMg'
    b'Mi0yem0tLjMgNS0xLjgtMi43LTEgMi4yLjUuMiAxLjIuMmgxLjF6bTcuNCA0NC43YTkgOSAw'
    b'IDAgMS00LjggMS41IDYuNyA2LjcgMCAwIDEtMy40LTEgNCA0IDAgMCAxLTEuNS0xLjdjLS42'
    b'LTEuMS0uOC0yLjUtMS00LS4zLTEuMy0uNS0yLjYtMS4xLTMuNi0uOC0xLjMtMi40LTIuMS0z'
    b'LjgtMy4zYTcuMyA3LjMgMCAwIDEtMi44LTUuMiA4LjEgOC4xIDAgMCAxIDAtLjhjMC0xLjcu'
    b'NS0zLjIgMS00LjVzMS4yLTIuNSAxLjItMy41di0uNWMtLjMtLjctMS0xLjQtMS41LTEuOXMt'
    b'MS4yLS44LTEuMi0uOGwtMS0uMi0uMS4zIDEgLjJ2LS4xLjFsMS4zIDFjLjUuNCAxIDEgMS4x'
    b'IDEuNWExLjkgMS45IDAgMCAxIDAgLjRjMCAxLS41IDItMSAzLjNhMTEuNyAxMS43IDAgMCAw'
    b'LTEuMiA0Ljd2LjhhNy43IDcuNyAwIDAgMCAzIDUuNWMxLjUgMS4xIDMgMiAzLjcgMy4yLjgg'
    b'MS4yIDEgMyAxLjMgNSAuMi44LjQgMS43LjggMi41cy45IDEuNSAxLjYgMmE3IDcgMCAwIDAg'
    b'My43IDFjMi43IDAgNC45LTEuNiA0LjktMS42bC0uMi0uM3oiLz4KICA8cGF0aCBmaWxsPSIj'
    b'Nzg3MzJlIiBkPSJNMjg3LjIgMjM5LjJhMi42IDIuNiAwIDAgMS0xLjMuNGMtLjUgMC0xLjEt'
    b'LjItMS43LS44YTQgNCAwIDAgMS0xLjItMi4zYy0uMi0uOS0uMy0yLTEtMy4zLS41LTEuNS0y'
    b'LTIuNi0zLjUtMy43LTEuMy0xLjEtMi42LTIuMi0yLjktMy40YTMuMyAzLjMgMCAwIDEgMC0u'
    b'N2MwLTEgLjQtMiAuOC0zLjFhMTAuOCAxMC44IDAgMCAwIC45LTQuOGMtLjItMi0xLjctMy41'
    b'LTMuMi00LjVhMTQuMSAxNC4xIDAgMCAwLTIuOC0xLjRsLS4xLjNoLjJjLjUuMyAxLjguOSAz'
    b'IDEuOCAxLjMgMSAyLjQgMi4yIDIuNiAzLjh2LjhjMCAxLjUtLjQgMi43LS45IDMuOXMtLjkg'
    b'Mi4yLS45IDMuMmwuMS44Yy4zIDEuMyAxLjYgMi40IDMgMy42IDEuNSAxIDMgMi4yIDMuNSAz'
    b'LjUuNiAxLjMuNyAyLjQuOSAzLjIuMiAxIC40IDEuNyAxLjIgMi41LjcuNyAxLjQuOSAyIC45'
    b'YTIuOCAyLjggMCAwIDAgMS40LS40bC0uMS0uM3oiLz4KICA8cGF0aCBmaWxsPSIjYThhYzcx'
    b'IiBkPSJNMjk2LjQgMjMxLjZzMS43LjQgMS42IDEuOGExMy4zIDEzLjMgMCAwIDEtLjggMy40'
    b'bC0yLjQtMi4yIDEuMy0xLjIuNS0uNy0uMi0xLjF6Ii8+CiAgPHBhdGggZmlsbD0iI2Y4Yzgz'
    b'YyIgc3Ryb2tlPSIjOTc3YzJlIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNMjY2LjQgMjE0LjVz'
    b'LTEuNy42LTIuMS0uMWMtLjQtLjgtLjItMS40LS4yLTEuNSAwLS4yLTEtLjMtMS0xLjMuMS0x'
    b'IDEuNC0uOSAxLjYtLjkuMyAwIC40LTEuNSAxLjMtMS40LjggMCAxLjIgMSAxLjIgMWwtLjgg'
    b'NC4yeiIvPgogIDxwYXRoIGZpbGw9IiNmOGM4M2MiIHN0cm9rZT0iIzk3N2MyZSIgc3Ryb2tl'
    b'LXdpZHRoPSIuMyIgZD0iTTI2OC4zIDIxNXMtMS41LjgtMiAwYy0uNC0uNyAwLTEuNi0uMS0x'
    b'LjgtLjItLjEtMS0uNC0uOS0xLjMuMi0uOSAxLjEtLjYgMS40LS44LjMtLjEuNi0xLjQgMS41'
    b'LTEuMi45LjMgMSAxIDEgMWwtMSA0LjF6Ii8+CiAgPHBhdGggZmlsbD0iI2Y4YzgzYyIgc3Ry'
    b'b2tlPSIjOTc3YzJlIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNMjcwLjggMjE1LjNzLS41IDEt'
    b'MS41LjhjLTEtLjItLjctMS43LS45LTItLjEtLjMtLjktLjUtLjgtMS40LjItMSAxLjEtLjkg'
    b'MS41LTEgLjMtLjEuNy0xLjYgMS40LTEuNC43LjMgMS4zIDEuMSAxLjIgMS41IDAgMC0xLjUu'
    b'NS0xLjcgMS41LS4yIDEgLjggMiAuOCAyeiIvPgogIDxwYXRoIGZpbGw9IiNhZjcwMjkiIGQ9'
    b'Im0yOTMuNyAyMzEuMi0yLjItMi42Yy0uOS0xLjMtMi4zLTIuNy0yLjMtMi43bC0yLjItMS4x'
    b'LTEuNC0yLjQtLjItMi44LjYtMS42LjgtMS4ycy00LjYgMS43LTIuMiAxMC41YzEgMy44IDMu'
    b'NSA0LjMgMy41IDQuM2w0LjMtLjNoMS4zeiIvPgogIDxwYXRoIGZpbGw9IiM4MTZjMmEiIGQ9'
    b'Ik0yOTEuNiAyMDEuN2MuNCAwIC42LjIuOC40bC4yLjZ2LjRjLTEuNiAzLjQtNC44IDUtNy44'
    b'IDdhMTMuOCAxMy44IDAgMCAwLTMuOCA0IDEyIDEyIDAgMCAwLTEuNiA2LjhjLjEgNSAyIDcu'
    b'OCA0LjIgOS4zYTkuNyA5LjcgMCAwIDAgNS4yIDEuNWguNGwxLjQtLjFhMzUuOCAzNS44IDAg'
    b'MCAxIDMtLjJsMS44LjEuOS40YS44LjggMCAwIDEgLjIuNWMwIC40LS4zLjgtLjYgMS4ybC0x'
    b'IC43LjIuM2E0IDQgMCAwIDAgMS0uOGMuNC0uNC43LS45LjctMS40IDAtLjIgMC0uNS0uMy0u'
    b'Ny0uMi0uMy0uNi0uNC0xLjEtLjVsLTEuOC0uMWMtMiAwLTQuNS4zLTQuNS4zdi4yLS4yYTYu'
    b'OCA2LjggMCAwIDEtLjMgMCA5LjQgOS40IDAgMCAxLTUtMS41Yy0yLjEtMS40LTQtNC00LTl2'
    b'LS40YzAtMi43LjUtNC43IDEuNS02LjMgMS40LTIuNCAzLjctMy44IDYtNS4zYTE0IDE0IDAg'
    b'MCAwIDUuNS01Ljd2LS41YzAtLjIgMC0uNi0uMi0uOC0uMi0uMy0uNS0uNS0xLS41di4zeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0yOTcuOCAyMzIuN3MtMSAyLTEuNCAyYy0uMiAw'
    b'IDEgLjMgMS4zLjhsLS4zLjVzLTEuMi0uOS0yLTF2LS42bDEuMS0uN2E0IDQgMCAwIDAgLjkt'
    b'MS43bC40Ljd6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjY2EzZCIgZD0ibTMwMiAyMzQtMi43Ljgt'
    b'MS4zLTFzMC0xLS41LTEuNWwtMS42LTFjLS42LS4yLTIuNS0uMi0yLjUtLjJsLTUtNS4zIDIg'
    b'LjIgMi44LS40IDIuNy0uMiAxLjQuMiAxLjYuNC44LjcuOC44LjggMS4zLjYgMS42LjIgMS43'
    b'djEuOXoiLz4KICA8cGF0aCBmaWxsPSIjYWY3MDI5IiBkPSJNMzAyLjIgMjMzLjhzLTEgLjMt'
    b'Mi4yLjNjLTEuMyAwLTItLjItMi0uMmwtLjIuOWMtLjIuOS0uNSAxLjMtLjUgMS4zdjMuMmwy'
    b'LjYuNSAxLjQtLjUuNy0zLjUuMi0yeiIvPgogIDxwYXRoIGZpbGw9IiNmY2NhM2QiIGQ9Ik0z'
    b'MDEuNSAyMzIuNXYxLjJsLjYuMnYtMS4yem0tMi41LTMwLS4zLTIuMS0uOC0xLjUtMS4xLTEu'
    b'NS0xLjItMS4zLS42LS41LS4zLS41LTIuOS4yLTEuNCAxLjdzMy44IDIuOCA1LjMgNS44YTcg'
    b'NyAwIDAgMSAyLjggMS43bC4xLS4yLjQtMS44eiIvPgogIDxwYXRoIGZpbGw9IiNhZjcwMjki'
    b'IGQ9Ik0yOTYuMyAyMDVjMCAyLjItLjUgMy4yLS44IDMuN2wxLjgtMiAxLjItMi4yYTcgNyAw'
    b'IDAgMC0yLjgtMS43Yy40LjcuNiAxLjQuNiAyLjF6Ii8+CiAgPHBhdGggZmlsbD0iIzgxNmMy'
    b'YSIgZD0ibTMwMC4zIDIzNy45LTEuNC0xLjZjLS42LS42LTEuMy0xLTEuMy0xbC0uMi40aC4x'
    b'bDEuMi44YTE3LjYgMTcuNiAwIDAgMSAxLjMgMS42bC4zLS4yeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiM2ZjViMjQiIGQ9Ik0zMDIgMjM1LjVzLS4zIDEtMS4zIDEuOGMtMSAxLTIuMiAxLjUtMi4y'
    b'IDEuNWwyLjggMSAxLjktMS43LTEuMi0yLjZ6Ii8+CiAgPHBhdGggZmlsbD0iIzQwNDExOCIg'
    b'ZD0ibTMwMi40IDIzNy44LS4yLjMtLjUuNS0uNC41LjYtMyAuNiAxdi40eiIvPgogIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzc4NzMyZSIgc3Ryb2tlLXdpZHRoPSIuMiIgZD0iTTI4'
    b'NS44IDE5OS4zcy0zLjguMy02LjUtLjEtMi03LjMtMi4xLTcuNWMwLS4yLTEuNi0xLjgtMS40'
    b'LTMuMy4zLTEuNSA1LjItNS41IDUuOC01LjguNS0uMSAxLjUuMyAxLjUuM3MxLjItMS4yIDEu'
    b'Ni0xLjJjLjQgMCAuOS43LjggMS0uMi4zLTEuOSAxLjMtMiAyLS4yLjggMCAxLjUtLjUgMi4z'
    b'LS41LjctMS40IDEuNy0xLjUgMi40LS4xLjYtLjQgMS4xIDAgMS40LjUuMiAyLjEgMCAzLjUt'
    b'LjYgMS40LS43IDItMS41IDIuMS0xLjQuMiAwLS44IDEuNy0yLjMgMi40LTEuNS42LTIuNSAx'
    b'LjMtMy4zIDEuMiAwIDAtLjggMiAxLjggMi4yIDIuNiAwIDQtLjYgNC0uNmwtMS41IDUuM3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjYWI2ZDI5IiBzdHJva2U9IiM0ZDJhMTUiIHN0cm9rZS13aWR0'
    b'aD0iLjQiIGQ9Ik0zMTguNyAxNzAuNnMtNy0xLjMtNyA0LjVjLjEgMS45LjUgMi41IDIgMyAx'
    b'LjUuMyA0LjQuNSA3IDIuNyAyLjUgMi4zIDIuNyA0IDIuNyA1LjMgMCAxLjQtLjcgMi42LS43'
    b'IDIuNmwxLjYgNy43IDEuNiA1LjcgNC44LTIuNyAyLjgtOC41LTMuNi0xNS4yLTExLjItNS4x'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiM0ZDJhMTUiIGQ9Ik0zMjUuNiAyMDBzMi41LTEgMy0zYy4z'
    b'LS41LTIuNC0yLjktMi40LTIuOS0uMSAwIDEuMy43IDIgMS4zLjYuNiAxLjEuOSAxLjMuOC4y'
    b'LS4xIDEuMy0yLjcuOS0zLjMtLjQtLjYtMS4xLTItMi4xLTIuNi0xLS43LTIuNC0uNi0yLjQt'
    b'LjZzMS45LS42IDIuOCAwYzEgLjUgMSAxIDEuMS45LjEtLjMtLjItMi45LS42LTMuNy0uNC0x'
    b'LS44LTEuMy0yLTEuNi0xLjEtLjItMi4zLS4xLTIuMy0uMXMxLjYtLjkgMi44LS42YzEuMy4z'
    b'IDEuMyAxIDEuNC44IDAtLjEtLjYtMi40LTEtM2E2LjcgNi43IDAgMCAwLTIuMS0xLjhsLTEu'
    b'OC0uMmgtLjZzMS0uNiAyLjEtLjVjMS4yLjEgMS4zLjUgMS40LjQuMiAwLS4xLS4yLS44LS43'
    b'cy00LjItMi00LjItMmgtMy4zczAtLjggMS0xYy45LS4xIDEuMS4xIDEtLjEgMC0uMy0yLjYt'
    b'LjgtMi42LS44SDMxNmwtMyAuM3MuMi0uNS43LS45Yy4zLS4zLjktLjUgMS4zLS42IDEtLjMt'
    b'LjYtMS4xLS42LTEuMWwuOS0xLjMgMy45LjMgOC4yIDQuOCAzLjkgMy4zIDIuNCA2LjItLjcg'
    b'MTAuOC01LjUgNC41LTIuNC4zLjUtMi4zeiIvPgogIDxwYXRoIGZpbGw9IiNkMmE1NjciIGQ9'
    b'Ik0zMTguNCAxNzMuM3MtLjItLjctLjItMS43LjItLjkuMi0uOS0yLjctLjMtNC42IDEuMmMt'
    b'MS45IDEuNS0uOCA0LjEtLjggNC4xcy44LS44IDEuOS0xLjJjMS0uNCAzLS4zIDMtLjMuMi0u'
    b'Mi0uNC0xLTEuMS0xLjEtLjgtLjItMi4xLS4yLTIuMS0uMnMuOC0uNSAyLjItLjRjMS40LjEg'
    b'MS42LjUgMS42LjV6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIgZD0ibTMyNi43IDIwMC45'
    b'LTEuOC42IDEgNy41IDcuMiAxMi4xIDMuNy0uNiAxLjMtMi4zIDEgLjVjLjQuNCAxLjggMi44'
    b'IDMgMy4zIDEuMS40IDEuNy4yIDIuNyAxIDEgMSA0LjkgNi42IDUgNi44LjMuMi0uMS0yLjQt'
    b'LjEtMi40bC0xLjItMy40LTEuNC0yLjQtLjMtLjZoMmwxLjIuOCAyIDEuNS45IDEuMi41IDEu'
    b'Mi4yIDEgLjUgMS42IDEgMi4zIDEuMyAyLjEuNC0uOS0uNi0yLjUtMi02LTEtMiAxLjkgMS4y'
    b'Yy40LjEgMS44IDIuMiAxLjggMi4ybC45IDIuMi42IDIgLjQgMS43LjcgMS45IDEtLjctLjEt'
    b'MS4zLTEtNC4yLS40LTQuNXMuNiAwIDEuMi43YTkgOSAwIDAgMSAxLjIgMi4zbC41IDQuMS43'
    b'IDMuOCAxLjIgMy44IDEuMiAyLjQuOSAxLjN2LTJsLTEuNi0xNiAuMi0uNnMuMi0uMS44Ljdj'
    b'LjUuNyAxIDEuOSAxIDEuOWwuNSAyLjUuMiAxLjcuMyAzLjMuNSAzLjUgMS42IDMuOC45IDIg'
    b'LjUtMi40LS44LTE3LjEuNC0uNXMuOS43IDEuMiAxLjNsLjggMSAuNiAzLjguNCAxMC43LjQg'
    b'Mi44IDMuMi0yOC4yIDItLjQuMi0uNi0xLjUtMS0zLjItNS0yLjEtNC45LTMuOC03LTYuNi04'
    b'LTUuMi00LjNhMjAgMjAgMCAwIDAtMS45LTEuM2wuNC0xIDEtMS43LS4xLS4xaC0uOWwtMi4y'
    b'LjQtMi4yLS43LTQuNC0zLTQuNi0yLjMtMi44LTEtNi42LTEuNi02LjYtMWgtM2wtMi42LjVz'
    b'LTEuNC42LTEuOCAxLjVjLS41LjgtLjUgMS40LS40IDIuNi4yIDEuMyAxIDEuOSAyLjggMi43'
    b'IDEuOC43IDYuMiAzLjYgNi4yIDMuNmwyIDIuMS44IDEgLjIuOCAxLjQgMTEuMS0yLjggNi0y'
    b'IDF6Ii8+CiAgPHBhdGggZmlsbD0iI2FiNmQyOSIgZD0iTTMzMy44IDIxOC4yczEuMiAyIDIu'
    b'OS41YzEuNy0xLjYtLjgtNi0uNy02LjMgMC0uMy43LS4zLjctLjNsMS4zIDIuMnMuNyAxLjMu'
    b'NCAzLjJjLS4yIDItMi4xIDMuNy0yLjEgMy43bC0yLjItLjUtLjMtMi41eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM0ZDJhMTUiIGQ9Im0zNzUuMyAyNDQuMi0xLjYtNC41LS40LTMuNWMwLS42LS4z'
    b'LTcuOS0uNS05LjMgMC0xLjQgMC0zLS4yLTMuMWwtMS42LTIuMi0uNy0uNy41LS4zcy42LjYu'
    b'Ny4zYy4yLS40IDAtMi0uNi00LjUtLjctMi41LTMuOS04LjMtMy45LTguM2wuNC4yLjkgMSAx'
    b'LjggMS41IDQuMSAxLjUgMi4yLjMgMS40IDIuOXMxIDQuOSAxIDcuNGMwIDIuNC0uMiA0LjUt'
    b'MS4yIDctMSAyLjQtMS4yIDEwLjMtMS4zIDExLjUtLjEgMS4zLS42IDIuNS0uNiAyLjVsLS41'
    b'LjN6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIgZD0iTTM3NS4zIDIzMS4ycy44LTEgMS4y'
    b'LTIuNGMuNC0xLjQuNS0xMi40LS44LTEzLjdhMTAgMTAgMCAwIDAtNC0yLjNjLS4yIDAgMSAz'
    b'LjUgMSAzLjVsLjggMS40LjYgMS44Yy4xIDEgLjkgMy4xIDEgNmwuMiA1Ljd6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzRkMmExNSIgZD0iTTM2OS4zIDIzOHMuNS01LjEuMy05Yy0uMy0zLjctLjYt'
    b'NC4yLTEtNC45YTMyLjMgMzIuMyAwIDAgMS0yLjUtNi4zYy0uOS0zLjItMS41LTUuNi0yLTYu'
    b'Mi0uNi0uNi0xLjctMi0yLTEuNi0uMy4zLS4zIDEuMS0uMyAxLjFsLTEuNS0uNC0uNC0xIC41'
    b'LTEuNnYtLjdsLS4zLTEuMSAyIDEuNiA0LjIgMi44IDIgOC42IDIgNS4zLjIgOS0uMiA4LTEt'
    b'My41em0yLjQtMjQuN3MxIDEgMS43IDEuNGMuNy40IDEuOCAxLjEgMS42IDEuMmE4IDggMCAw'
    b'IDEtMi0uOGwtMS4yLS44di0xeiIvPgogIDxwYXRoIGZpbGw9IiM0ZDJhMTUiIGQ9Ik0zNjMu'
    b'NyAyMzZzLjgtMS44LjctNC4xYTQ5IDQ5IDAgMCAwLTEuNi04LjZjLS40LS43LTItMS43LTMu'
    b'NS00LjhzLTEuMy0zLjgtMi4zLTVjLTEtMS0yLTIuNC0yLTIuNGwuMy0zLjMgMy42IDEuOCAx'
    b'LjYuOCAxLjggOC43IDEuNiAyLjUuNyAzLjUuOSA4IC40IDYuNi0uMi41LTItNC4yem0tNC4y'
    b'LTMuN3MuMS0yLjUtLjUtNC44Yy0uNy0yLjMtMS4xLTQtMS45LTQuOC0uNy0uNy0yLjUtMi42'
    b'LTQuMS01LTEuNi0yLjUtMy45LTUtMy45LTV2LTMuM2wyIDEuNWE1Ny4xIDU3LjEgMCAwIDEg'
    b'Mi40IDEuMmwxIDMuNyAxLjIgMi43IDEuOCAyLjQgMS4yIDEuMS43IDQgLjQgMi4zIDEgMy4y'
    b'LS40IDEuNy0uOS0uOXptLTMgMC0xLS45cy42LS42LjMtMmMtLjMtMS4yLS42LTIuNC0xLjIt'
    b'My43LS42LTEuMi0uNy0yLTEtMi4zYTEyMSAxMjEgMCAwIDAtNC41LTRjLTEtMS0yLjctMi42'
    b'LTMuNy0zLjMtMS0uNi0xLjgtLjgtMS44LS44bC0uNS00czEuMyAxLjggMi4xIDJhNTQuNyA1'
    b'NC43IDAgMCAwIDIuMS44bDIuOCA1IDEgMS4zIDIuNiAyIDEgMi4yLjkgMi41IDEgMy40LjEg'
    b'Mi0uMi0uMXptLTUuNS0xcy0xLjctMi0yLTMuMmMtLjItMS4yLjItMS4yLS4zLTIuNi0uNS0x'
    b'LjQtMi4zLTMuNS0zLjctNC42LTEuNC0xLjItMy40LTIuOC0zLjMtMy44LjEtLjkuNC0xIC40'
    b'LTFsLjguOCA0LjUgNC43IDEuNCAyLjUgMSAzLjEuNyAxLjUuNyAxLjgtLjIuN3ptMTYtMjMu'
    b'M3MzLjEgMy44IDQgLjNjLjMtMS42LTEuMi00LjYtMS4yLTQuNnMtMi44LTUtMy44LTYuMmwt'
    b'NS43LTcuMy0zLjUtMS42IDEuMiAyczIuNiAyLjYgNS45IDguNGMzLjMgNS43IDIuNyA4Ljkg'
    b'Mi43IDguOWguNXptLTE3LjgtMjNzNi4xIDUuMiAxMCAxMC44YzQgNS43IDUuNSA5LjQgNC43'
    b'IDEwLjItMSAuNy0zLjQtLjQtNC40LTItMS0xLjYtMS44LTQuNC01LjUtOC42LTMuNy00LjIt'
    b'NS41LTQuOC01LjUtNC44bC0yLjctNC4zIDMuNC0xLjN6bS0zLjIgMTIuNXMzLjYgMyA2IDUu'
    b'NGEzNy40IDM3LjQgMCAwIDEgMy40IDQuMmwxLjQgMS40cy0uOS0xLjUtLjQtMmMuNS0uNiAx'
    b'LjEtLjMgMS4xLS4zbC0xMS41LTEydjMuM3ptLS43LjNzMS4yIDIuMyAzIDQuMWE0NjQuNiA0'
    b'NjQuNiAwIDAgMCA0LjEgNGwuOCAyLjlzLTUuMi00LTUuMi0zIDEuMiAzIDEuMiAzbC0xLjYt'
    b'MS0yLjItMy4xLTEuMy0yLjgtMS41LTMuOCAyLjctLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzRk'
    b'MmExNSIgZD0iTTMyOS41IDIxMC4yczIuNyAyLjQgNC4yIDBjMS41LTIuMy4zLTUgLjMtNXMz'
    b'LjkgNS42IDUgLjNjLjItMS0yLjQtNC42LTIuNC00LjZsMS0uOSAxLjkgMy4zczEuOC0uOCAx'
    b'LjgtMy0xLjktNS4zLTEuOS01LjNsMS44IDJzMy42IDAgMy43LTJjMC0yLjItMy00LjUtMy00'
    b'LjVzMi40LjEgMi40LTEuM2MwLTEuNC0zLjQtMi40LTMuNC0zLjMgMC0uOSAxLTIuNCAyLjUt'
    b'MS41IDEuNS44IDMuNSAxLjQgNC40LS4yLjgtMS42LS4xLTItLjEtMmwtMi4xLS40LTMuNC0x'
    b'LjgtMi43LTEtMi44LS40IDEgMiAuOCA1Ljh2Mi42bC41IDUuOC0xLjQgNC43LS43LjktLjUu'
    b'Ni0xLjIgMi42LTEuNiAxLjgtMi4yIDIuNy0yIDIuMXoiLz4KICA8cGF0aCBmaWxsPSIjYWI2'
    b'ZDI5IiBkPSJNMzQ4LjggMjIwLjlzLS43LTEuNy0yLjItMi45YTcuOCA3LjggMCAwIDAtMy44'
    b'LTEuMmw0IDQuMiAyLS4xem01LjYgMXMtMS4zLTIuNi0yLjgtNC4yYy0xLjUtMS42LTIuNS0z'
    b'LjYtMy0zLjZoLS42bC40IDMuMyAyLjcgMi43czIuNiAyIDMuMyAxLjh6bTQuNi0uMnMtLjYt'
    b'My0yLjItNmMtMS41LTIuOC0zLjEtNC0zLjEtNGwuNCAzIDEuMiAzIDIgMyAxLjcgMXptMy44'
    b'LTEuN3MxLTYuMiAwLThjLS45LTEuNi0yLjctMi0yLjctMmwtLjYgMSAuNiA0LjMgMS41IDMu'
    b'NCAxLjIgMS4zem0zLjctMTAuM3MuOS40IDIgMi41YTQwIDQwIDAgMCAxIDIuNiA4LjZjMCAu'
    b'My0uNS4yLS43LjItLjItLjEtMy45LTYtMy45LTZsLS42LTUuNGguNnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZDJhNTY3IiBkPSJNMzQwLjQgMjE2LjhzMi0uNCAyLTFjMC0uOC0yLjQtMi4yLTIu'
    b'Mi0zLjMgMC0uNSAyIC4xIDIuMS0uMy4xLS40LTItMy42LTEuMy00LjQuNi0uOCAyLjQgMy41'
    b'IDIuNCAzLjVzMSAyIC43IDMuMmMtMS4yIDMuNi0zLjcgMi4zLTMuNyAyLjN6bTQuNi00LjRj'
    b'LjEtLjMgMy4xLjQgMy4xLjIuMi0uNy0yLjctMy0yLjctM3MtLjYtMS4yLS40LTEuNGMuMi0u'
    b'MiAyIC4yIDIgMCAuMi0uMy0yLTMuMi0yLTMuN3MuNiAwIC42IDAgMS43IDEuNyAyLjYgMy4y'
    b'YzEgMS40IDEuOCAyLjYgMS41IDQuOS0uNCAyLjUtNSAuNi00LjctLjJ6bTEzLjYtNC42cy0u'
    b'NS0yLS4yLTIuM2wxLjEtLjVzLTEuNi0xLTIuNC0xYy0uNyAwLS44LS4yLTEgMC0uMi40IDEu'
    b'MyAyLjQgMS4zIDIuNGwxLjIgMS40eiIvPgogIDxwYXRoIGZpbGw9IiNkMmE1NjciIGQ9Ik0z'
    b'NDkuNCAyMDkuNHM0LjcgMS4yIDQuOS44Yy4yLS4zLTMuNy00LTMuNy00cy0uMy0uNi0uMi0u'
    b'OGMwLS4yIDEuNy0uMyAyLjIuMXMwIDEuMi4xIDEuNWMuMi4zIDEuNyAyLjUgMiAyLjEuMi0u'
    b'My0uNC0zLS4zLTMuMy4yLS4yIDEuOCAxLjYgMi4zIDEuOS40LjMgMyAyLjMgMy4zIDEuNC4z'
    b'LTEgLjQtMS4xLjMtMS43IDAtLjYuOSAyLjYtLjMgMy0xLjIuNC0yLjYtLjQtMi42LS40bC0x'
    b'LjEtLjgtLjYtLjdzLjcgMi41LS4yIDIuN2MtLjguMy0xLjcuMi0xLjcuMmwtMi0uMi0yLjQt'
    b'MS44em0xMC43LTMuMnM1IDMgNS40IDIuNWMuNS0uNS0xLjItNy41LTEtOC4yLjMtLjYgNCA3'
    b'LjkgMi4yIDktMS40IDEtMiAuMy0yIC4zbC0yLjUtMS4zLTItMi4zem0xMy44IDEyLjYgMSAu'
    b'NS43LjItMS40LjItLjMtMXptLTQuOC0xNi40LjcuMy43LjNzLS40LjMtLjYuMmgtLjRsLS40'
    b'LS44em0tMS40LTIuNXMuNS4zIDEuMS0uMmMuNy0uNC43LS44LjYtMSAwLS4yLTEtLjItMS40'
    b'LS41LS4zLS4yLS4zLS42LS4zLS42aC0xLjFsLS40LjEgMS41IDIuMnptNC4zIDE0LjRzMS41'
    b'IDEgMiAxYy40IDAgMS4xLjUgMSAuNiAwIC4xLTEuMi4yLTEuOC0uMS0uNi0uMy0uNy0uMS0u'
    b'Ny0uMWwtLjUtMS40em0tOC4xLTIyLjVoLjZjLjMgMCAuNS0uMi42IDAgLjIuMiAwIDEuMi0u'
    b'MyAxLjVsLTEgLjVhNDguNCA0OC40IDAgMCAxLTEuNi0yLjJsMS43LjJ6bS03LjEtNi40aDEu'
    b'NWMuNSAwIDEgLjMgMS41LjYuNC4zLjkgMy4zLjYgMy44LS4yLjYtMy42LTItMy43LTIuMSAw'
    b'LS4zLTEuNS0yLjUtMS41LTIuNWwxLjYuMnptLTMuMi0xLjRzMi41LjIgMi4yLTEuM2EzLjIg'
    b'My4yIDAgMCAwLTEuMy0yLjNsLTIuOSAyLjEgMiAxLjV6bS02LjUtMi44cy43LjQgMS40IDBj'
    b'LjctLjIgMi42LTIuNyA0LTMgMS40LS4zIDEuNy0uMyAyIDAgLjIuNCAwIDEuOC0uMiAyLjIt'
    b'LjMuNC00LjQgMi00LjQgMmwtMS41LS4xYTkuNiA5LjYgMCAwIDEtMS4zLS41di0uNnptLS43'
    b'LTQuNWMtLjctMS40LTEuNy0yLTIuMi0xLjktLjQuMSAxLjQgMS41IDEuNyAzLjUuMyAyIC4y'
    b'IDMuMy4yIDMuNGwuOC4xLjItLjcuMS0uNXYtLjVsLS4xLTEtLjItLjktLjItLjYtLjMtLjl6'
    b'bS01LjgtMmExNS40IDE1LjQgMCAwIDAtNS41LTMuN2MtLjIgMCA0IDIuNSA1IDQgLjkgMS43'
    b'LjkgMy45IDEuMyA0LjIuNC4zLjgtLjIuOS0uMiAwIDAgLjMtLjUuMi0uN2wtLjItMS0uNy0x'
    b'LS40LS44LS42LS44em0tNS41LTIuM2MtMi40LTItNi42LTMtMTAtMy0zLjUtLjItNS4zLjIt'
    b'NC44IDJzMiAyLjggNSAyLjhjMi45IDAgMy42LS4zIDUuMi4yYTkuNyA5LjcgMCAwIDEgMy42'
    b'IDJjLjUuNS0xLjEtMS41LTIuNi0yLjYtMS41LTEuMi0yLjUtMS43LTIuNS0xLjdzLS4zLS43'
    b'IDEuNy0uNGMyIC4zIDQuNyAxLjYgNS41IDMuMy43IDEuNy42IDIuNi42IDMgMCAuMy43LS4y'
    b'LjctLjJsLjMtLjlzMC0uNi0uMy0xLjRjLS40LS43LS41LTEtMS40LTItLjktMS4xLTEtMS0x'
    b'LTF6bS05LjYgMjguNWMxLjUgMCA0LjgtMi44IDUuMi02LjcuNS00LTEuOS0xMS45LTIuNS0x'
    b'Mi43LS41LS45IDEtLjQgMS43LjRhMjUgMjUgMCAwIDEgMi41IDEwLjZjMCA0LjItLjggNS4z'
    b'LTMgNy41LTIuMiAyLTQgMS44LTQgMS44bC4xLS45em01LjEgMTEuNnMuNyAxIDEuNi42YzEu'
    b'NS0uNSAzLjgtMS43IDMuOC0zLjggMC0xLjQtMS44LTIuNy0xLjktMy4ydi0xbDEuNi40LjUg'
    b'Mi4ycy42LjcgMS4zLjRjLjYtLjIgMi41LTEuNiAyLjItMy0uMy0xLjItMi0yLjktMi4yLTMu'
    b'NS0uMi0uNyAwLTEuMiAwLTEuMmwxLjYuMi40IDJzLjQuNiAxLjMuNGMuOC0uMSAyLjQtMS43'
    b'IDItMi41bC0xLjUtMi42di0uOWwuNS40cy42LjIgMS44LS4xYzEuMS0uNCAyLjMtMS4yIDIu'
    b'My0ycy0xLTEuNi0xLTJ2LS42aC44bDEgMS4yLjEgMS40LS4zIDEuMi0xLjQgMS42LTEuNC42'
    b'aC0uNGwuOCAxLjQtLjIgMi0xLjMgMS4yLTEuNyAxLS4xIDEuOS0xIDItMiAxLjJoLS43bC0u'
    b'MiAxLjItMS40IDItMi4zIDEuNS0xLjcuMy0xLTEuNC4xLS41eiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNkMmE1NjciIGQ9Ik0zNDMuNCAxOTEuNHM0IDEuMSAzLjgtMS40YzAtMS4zLTMuOC00LjUt'
    b'NC01LS4zLS42LS4yLTEuMy0uMi0xLjNsMS45IDEuOHMyLjUuNiAzLjItLjljLjctMS40LjEt'
    b'Mi4zIDAtMi4zbC42LS4xIDEuMS4yLS4xIDIuMi0xLjMgNS41cy4zIDIuMi0xLjQgMi4zYy0x'
    b'LjcuMi0zLjYtMS0zLjYtMXptMy43IDI5LjVzMC0xLjEtLjgtMmMtLjktLjctMi41LTEuNC0y'
    b'LjgtMS42YTYzIDYzIDAgMCAwIDIuOCAzLjVoLjh6bTUuNi4ycy0yLTIuNC0yLjMtMy4zYy0u'
    b'NS0uOC0xLjUtMi42LTIuMy0yLjctLjggMCAuOCAzIC44IDNsMy4yIDIuOWguNnptNS40IDAt'
    b'Mi4xLTQuMmMtLjQtLjktMS4zLTMuNC0yLjMtNC4xLTEtLjcuMSAxLjEuMSAxLjFsMS4xIDMu'
    b'MyAxLjkgMi45IDEuMyAxem0zLjktMi40cy0uMS0yLjctLjUtNC42Yy0uMy0xLjgtMS43LTMu'
    b'NC0xLjgtMy4zdjMuM2wyLjMgNC42em04LjEgMi0yLTQuN2MtLjUtMS42LTEuOC00LjEtMi00'
    b'LjJsLjQgMyAxLjcgNC43IDIgMS4yem03LTguNXMtMS4yLTEuMi0zLjktMi4zYy0yLjctMS01'
    b'LjQtMS4yLTUuNC0xLjJsLjMuNCAxLjMgMSAyLjggMS41IDMuNy45IDEuMy0uM3oiLz4KICA8'
    b'cGF0aCBmaWxsPSIjMjAyMDIwIiBkPSJNMzQ4LjIgMjEzLjhzMCAyLjQgMS4zIDMuOGMxLjIg'
    b'MS41IDQgNCA0LjYgNC42LjYuNSAxIDMuNCAxLjkgNS44LjggMi40IDEgNC40IDEuNCA1LjEu'
    b'NC43IDEuMSAxLjguNSAxLjctLjUtLjEtMS0uOC0xLjQtMS43LS4zLS45LS4yLS45LS4yLTIg'
    b'MC0xLjMtMS44LTcuNS0yLjctOC4xLS45LS43LTQuOC00LTYuNC02LjMtMS41LTIuMy0xLjIt'
    b'Mi44LTEuMi0yLjhoMi4yeiIvPgogIDxwYXRoIGZpbGw9IiMyMDIwMjAiIGQ9Ik0zNTQuNiAy'
    b'MjkuM2MtLjgtMS43LTEtMy4zLTEuMi00LjNhMTYgMTYgMCAwIDAtNC40LTQuMmMtLjYtLjMt'
    b'MS45IDAtMi40LS4zbC0zLjctNHMtLjUuNS0uMy42Yy4xLjEgMy40IDMuNyA0LjYgNC44IDEu'
    b'MiAxLjIgMS45IDMuNyAyLjcgNS43LjkgMiAuNSAxLjYuNiAyLjUuMSAxIC43IDEuNSAxLjMg'
    b'MS41LjYgMCAuOC0uMi42LS40YTEwLjMgMTAuMyAwIDAgMS0yLjItMy41Yy0uNy0xLjctMS41'
    b'LTQuOS0yLjUtNmwtLjMtLjMgMS4zLS4yYy44IDAgNC4xIDMgNC40IDQgLjMuOCAwIDEuMiAx'
    b'LjQgNC4yczIgMy43IDIgMy43aC4ycy0xLjItMi0yLTMuOHptLTUuMi0xOS45czIuNSAxLjUg'
    b'My4yIDEuN2E5LjggOS44IDAgMCAwIDEuMi4zcy40IDQuNCAyLjEgNi44YzEuOCAyLjUgMy4y'
    b'IDMuNCAzLjIgMy40czAgNC44IDEuNCA4YzEuMyAzLjMgMS41IDcuMyAxLjIgOC0uMy42LTEu'
    b'NC0yLTItNC4zbC0yLTYuMmExMyAxMyAwIDAgMC0yLjUtNC40Yy0uOC0uNy0uMi0uNi4zLS4y'
    b'LjQuNCAxLjcgMiAyLjUgNC41czEuMSA1IDEuNSA1Yy41IDAgLjgtLjMuOC0uOSAwLS40LS42'
    b'LTEuOC0xLTQuMWExNyAxNyAwIDAgMC0xLjItNC43Yy0uNC0uNi0xLS43LTIuNC0zLjRhMjAu'
    b'MyAyMC4zIDAgMCAxLTIuNS01LjNjLS4yLTEuMiAwLTEtLjItMS4zLS4yLS4xLS40IDAtMS42'
    b'LS42LTEuMS0uNi0yLTIuMy0yLTIuM3oiLz4KICA8cGF0aCBmaWxsPSIjMjAyMDIwIiBkPSJN'
    b'MzU1LjcgMjA4LjVzMS40IDEuMiAyLjMgMS41Yy44LjQgMiAuNCAyIC40cy0uMyA0LjIgMS4z'
    b'IDYuOSAzLjMgNC4yIDMuMyA0LjIuMyAxIC44IDYuOGwuNyA4LjNjLjEgMi4zLjIgMTAuNi0u'
    b'MSAxMC4zLTEuMy0xLS4yLTUuNC0uOS03LjMtLjYtMS44LTEuNi0yLjEtMi44LTcuNC0xLjIt'
    b'NS4yLS40LTYuNC0xLjMtOC4zLS45LTItMi0yLjItMi0yLjJzMS42LjQgMi4zIDJjLjYgMS42'
    b'LjcgNiAxLjMgOC4yIDEuMiA0LjkgMi45IDcuNCAyLjkgNy40cy0uNC02LjItLjgtOS43Yy0u'
    b'NS0zLjUtLjUtNi40LTEuMS03LjctLjctMS40LTIuMS0yLjQtMy00LjItLjgtMS44LTEuMS01'
    b'LjMtMS41LTYuMi0uNC0uOS0uNi0uNi0xLjItLjgtMi0uOC0yLjItMi4yLTIuMi0yLjJ6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzIwMjAyMCIgZD0iTTM2MC4xIDIwNi4yczEuMyAxLjUgMy4xIDIu'
    b'NmMxLjggMSAyLjguNyAzIDEgLjMuMi0uMyAzLjggMS42IDcuMiAxLjkgMy40IDIuNiAzLjUg'
    b'Mi42IDRsLjYgMTMuOWMuMyAzLjQuNSAxNC44LS45IDE0LjhzLS4xLTguNS0uOC0xMC40Yy0u'
    b'Ny0yLS43LTEuNC0xLjMtMy0uNy0xLjYtLjctNy44LTEuOC0xMS41LS44LTIuOC0xLjYtMy4y'
    b'LTEuNi0zLjJzMS40LjcgMiAzYy42IDIuMi44IDEwIDEuNSAxMS4xLjggMS4zIDEuOCAyLjgg'
    b'MiA0YTE1NyAxNTcgMCAwIDAtLjQtMTUuNmMtLjMtMS0zLjUtNi42LTMuNy05LjctLjMtMy4y'
    b'LS40LTMuNS0uNy0zLjctLjItLjMtMS4xIDAtMi42LTEuNS0xLjUtMS40LTIuNi0zLTIuNi0z'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiMyMDIwMjAiIGQ9Ik0zNjcuMyAyMDhjMC0uMyAxIDEuNyAz'
    b'LjcgMi44IDIuOSAxLjIgNS42IDEgNiAxLjMuMy4zIDIgNC41IDIuMSAxMC4yLjEgNS42LTEg'
    b'NS4xLTEuOCAxMC0uOSA0LjktMSAxNC44LTEuNSAxNi4zLS4yLjUtLjUuOC0uOCAxLjctLjMg'
    b'MSAuMiAyLjgtLjcgMi44LS44IDAtMS0xLjQtMS0yLjEgMC0uOCAxLTMuNSAxLTYuMnMtLjYt'
    b'My0xLTYuMmMtLjQtMy4zLS40LTEzLjUtLjgtMTQuNS0uMy0xLTIuMS0zLjEtMi4xLTMuMXMx'
    b'LjkgMS4yIDIuNCAyLjZjLjQgMS4zLjUgMTIuNyAxIDE1IC41IDIuNC4zLS41LjUtMS44cy45'
    b'LTcgLjgtMTBjLS4xLTMtMS40LTkuNC0yLjQtMTAuNSAwIDAgLjUuNiAxLjEgMiAwIC4xLjQu'
    b'NS44LjdsMSAuNXMtLjYgMC0xLS4zYy0uNC0uMS0uNi0uNC0uNi0uNGEyMy45IDIzLjkgMCAw'
    b'IDEgMS4zIDhjLjEgNS4yLS43IDE2LjQuMSAxNi41LjguMi43LTYgMS41LTExLjIuOC01IDIt'
    b'NS44IDEuNi05LjktLjMtNC4xLTEuNC04LjYtMi4zLTkuMi0uOS0uNS0zLjQtLjMtNS42LTEu'
    b'OC0yLjItMS40LTMuNC0yLjktMy4zLTMuMnptLTM1LjggNS43cy44LjQgMS43IDBjMS0uNSAz'
    b'LjUtMi41IDMuNS0zLjN2LTEuNnMwIC4zLjcuNGMuOC4xIDIuOC0xLjQgMy0yLjRhOCA4IDAg'
    b'MCAwLS4xLTMuMWMtLjItLjQuNi4zIDEgMCAuNC0uNCAyLjQtMS43IDIuNC0zIDAtMS40LTEu'
    b'MS0yLjYtMS4xLTIuNnMxIC4yIDEuNiAwYy41LS4xIDIuNS0xLjMgMi40LTIuNCAwLTEuMi0u'
    b'Ny0zLTIuMy0zLjIgMCAwIDEuMi4zIDIuMy0uMSAxLS40IDEuNS0xIDEuNS0yLjMgMC0xLjIt'
    b'Mi4zLTQtMi42LTQuMi0uNC0uMiAyLjQuOCAzLS4zLjgtMS4xLjktMS45LjctMi41LS4yLS43'
    b'LS44LS44LS44LS44czEuMi4zIDIuOC0uNSAzLTIgMy44LTEuOWMuOCAwLTIuMyAxLjctMi41'
    b'IDIuNiAwIC40LjkgMSAyLjMgMiAwIC4xIDAgLjIuMi4zLjcuMyAzIC40IDMuMy41LjIuMi0y'
    b'LjQuMS0yLjIuM2EzNC4xIDM0LjEgMCAwIDEgNS43IDUuNGMuMSAwIC41LjQgMSAuNWwxLjMu'
    b'M2gtMS42YTY1LjMgNjUuMyAwIDAgMSAzLjMgNC43YzAgLjEuNC42LjkuOC41LjIgMSAuMSAx'
    b'LjEuMi4xLjItMS40IDAtMS4zLjJhODIgODIgMCAwIDEgMy4zIDZzLTMtNS4zLTYuNy05LjVj'
    b'LTMuOC00LjItNC43LTQuNy00LjgtNC40LS4yLjQgMi43IDQuMSA0LjMgNi43IDEuNiAyLjYg'
    b'MyA1LjkgMyA1LjlzLTMuNy03LjgtOS0xMi42Yy01LjItNC44LTUuOC01LjUtNi4zLTUuNC0u'
    b'Ni4yLTEgMy44LS43IDQuNS4zLjcgNC4yIDMuNiA3LjQgNy41IDMuMyAzLjggNy41IDEwLjQg'
    b'Ny41IDEwLjRzLTMtNC43LTgtMTAtNi45LTYuNi03LjMtNi41Yy0uNCAwLS40IDEtMSAxLjgt'
    b'LjYuNy0xLjguNi0xLjggMXM0LjIgNC4zIDUgNC43Yy45LjUgMS40LjMgMiAuNmwxLjQgMS0x'
    b'LjYtLjVjLS42LS4yLTEuMy0uMy0xLjMgMHMzLjUgNC4zIDQgNC42Yy42LjMgMSAuMSAxLjcu'
    b'NC44LjMgMiAxLjEgMiAxLjFzLTEuMy0uNy0yLjEtLjhjLS45LS4yLTEuMiAwLTEuMi4yczIu'
    b'NiAzLjYgMi41IDMuNmMtLjEgMC00LTQuNi03LjMtNy41LTMuMy0zLTQuOC0zLjYtNS0zLjUt'
    b'LjIuMSAwIDEtLjkgMS4zLS44LjMtMS41LjQtMS41LjcgMCAuMyAzIDMgNSA1LjRhMTQ5LjQg'
    b'MTQ5LjQgMCAwIDEgNCA0LjVsLTQuNS00LjNjLTIuMy0yLjItMy41LTMtMy44LTMtLjIuMi0u'
    b'MiAxLjMgMCAxLjYuMi4zIDQuNiA1LjQgNC40IDUuNS0uMS4yLTUtNi01LjQtNi0uMyAwLS41'
    b'LjctLjggMS0uNC40LTEuOC40LTEuOCAxIDAgLjQgNyA3LjMgNi45IDcuNSAwIDAtNS44LTUt'
    b'Ni00LjctLjIuMyAyLjQgNSAyLjIgNS4yLS4xIDAtMy40LTUtMy43LTUtLjMgMC0uMi42LTEg'
    b'MS4zLTEgLjgtMiAuNC0yIC44IDAgLjMgNC44IDUuNyA0LjcgNS44LS4yLjEtNS01LjEtNS00'
    b'LjgtLjEgMC0uNC4zLS4yLjcuMyAxLjMgMS40IDMuNiAxLjMgMy44IDAgMC0xLjYtMy4yLTIt'
    b'My0uNCAwLS40LjctMS4yIDEuMS0uNy41LTEuMy40LTEuMy43IDAgLjMuOCAxIDEuMiAxLjcu'
    b'NC43LjcgMi40LjcgMi40cy0uNS0xLjQtMS4xLTIuM2MtLjctLjktMS4zLTEuNS0xLjktMS41'
    b'cy0uOC41LS44LjVsLS41LTEuMnoiLz4KICA8cGF0aCBmaWxsPSIjMjAyMDIwIiBkPSJNMzc3'
    b'IDIxMnMxLjUgMCAxLjctLjRjLjItLjMtLjYgMC0yLTEuNnMtNS0xMi4xLTktMTcuNGMtNi42'
    b'LTguNy0xMi43LTEyLjctMTIuNy0xMi43czcuMyA0LjIgMTMgMTIuNGM1LjYgOC40IDcgMTQu'
    b'OSA4LjYgMTYuNiAxLjYgMS43IDMuMiAyIDMgMi41IDAgLjUtLjMuOC0uOSAxbC0yIC4xLjIt'
    b'LjR6bS00OC0yLjIuMy4xYy4zIDAgMi4zLTEuOSAyLjItMi41IDAgMC0xLS4zLTEuNi0xLS43'
    b'LS44LS45LTEuOS0uOS0xLjlzLjcgMS4zIDEuMiAxLjZjLjYuNCAxLjQuNiAxLjguMy4zLS4y'
    b'IDMuMi0yLjQgMy0zLjIgMCAwLS45IDAtMS44LS42LS44LS42LTEtMi0xLTJzLjYgMS4xIDEu'
    b'NSAxLjVjLjguNCAxLjcuMyAyIDAgLjItLjMgMi0zIDEuOC0zLjcgMCAwLTEgMC0xLjgtLjUt'
    b'LjktLjYtMS4zLTIuMi0xLjMtMi4ycy42IDEuMyAxLjcgMS41YzEuMS4zIDItLjQgMi4yLTEu'
    b'Mi4yLS44LjgtMy43LS4yLTQuNSAwIDAtMS40LjUtMi40IDAtMS0uNi0xLjQtMS45LTEuNC0x'
    b'LjlzLjkgMS4yIDIgMS40YzEuMi4xIDEuNy0uNSAxLjktMWE1LjkgNS45IDAgMCAwLS4xLTNj'
    b'LS40LTEtMS4xLS44LTEuMy0yLjIgMCAwLS4zLjUtMS44LjVzLTIuMy0xLjYtMi4zLTEuNiAx'
    b'LjIgMSAyLjQgMWExLjkgMS45IDAgMCAwIDEuNi0xLjljMC0uNy0uNi0xLjQtMS0yLjEtLjIt'
    b'LjgtLjMtMS43LS41LTEuNi0uMiAwLS41LjgtMiAuNi0xLjUtLjMtMS44LTEuMy0xLjgtMS4z'
    b'czEgLjcgMiAuN2MuOCAwIDEuMy0uNSAxLjMtMSAwLS42LS4zLTEuNy0yLjItMy4zYTU4LjEg'
    b'NTguMSAwIDAgMC0zLjUtMi43IDIxLjggMjEuOCAwIDAgMCA2LjYgNS4zczEuNy42IDIgMGMu'
    b'MS0uNi4xLTEuNC0uNS0yLjQtLjUtMS0yLTIuNi0yLTIuNnMxLjYgMS4zIDIuMyAyLjdjLjgg'
    b'MS4zLjQgMi4yLjUgMi42IDAgLjMgMy4zIDEuNiA0IDEuMS44LS40LjUtMS40LS4yLTIuM2wt'
    b'MS0xLjhzLjcuOCAxLjIgMS44Yy42IDEgMSAxLjcuOCAyLjEtLjIuNS0uNi43LS42LjlsMi4z'
    b'IDEuM2MxIC42IDIuMyAxIDIuNS44LjItLjQuMy0xLjEuMi0yLjItLjEtMS0uNy0yLjctLjct'
    b'Mi43cy43IDEuNi44IDIuNy0uMSAyIC4xIDIuNGMuMy40IDEuMS41IDEuMS41cy0uNi40LTIg'
    b'MGMtMS41LS40LTcuNy0zLjYtOC0zLjMtLjMuNCAyLjkgMi4zIDQuMyAzLjcgMS41IDEuMyAy'
    b'LjIgMi44IDIuMiAyLjhzLTEuMS0xLTIuMi0xLjZjLTEuMS0uNi00LjQtMi4zLTQuNy0yLS4y'
    b'LjIgMS4zLjUgMS40LjcuMS4zLTEgMS4zLTEgMS44IDAgLjQgNC43IDMuNyA0LjUgNC0uMS40'
    b'LTEuMiAxLjMtMS40IDEuMi0uMSAwLTIuNS0xLjgtMi41LTEuNnMxLjQgMS41IDEuNCAxLjdj'
    b'MCAuMy0xIC44LS44IDEuNC4yLjYgMi42IDIuNiAyLjYgMy4zIDAgLjctMS40IDEuMy0xLjEg'
    b'MS43bDEuNSAycy0xLjQtLjktMS44LTEuNGMtLjQtLjQtMS4zLTEuNS0xLjUtMS4zLS4xLjEt'
    b'MSAyLTEgMi41LjIuNCAxLjMgMSAxLjUgMi4zLjIgMS4xLS4yIDIuNC0uMyAyLjQgMCAwLTEu'
    b'Ni0yLTItMi4xLS4yIDAtLjYuMS0uOS42cy0xLjIgMi4xLTEgMi40YzAgLjMgMS42LjcgMS42'
    b'IDEuOWEzLjQgMy40IDAgMCAxLTEgMi4zbC0yLjEtMi40Yy0uMiAwLTIuMiAyLjMtMi4zIDIu'
    b'NiAwIC4yIDEuNCAxLjMgMS4yIDEuNy0uMy40LTEuMy0uMi0xLjguMWwtMS43LjdjLS4yIDAt'
    b'LjUtLjYtLjUtLjZ6Ii8+CiAgPHBhdGggZmlsbD0iIzIwMjAyMCIgZD0ibTM1NSAxODAgLjUt'
    b'MWMuMy0uMyAxLjUtMS43IDEtMi0uNC0uMi0yIC4zLTMgLjItMSAwLTEuNy4yLTQuNi0yLjMg'
    b'MCAwLTkuMy02LjQtMjMuNi03LjMtNC42LS4yLTYuNiAxLjQtNi44IDIuMiAwIC4yIDEuMi0x'
    b'LjggNS43LTEuNyAyIDAgMTYuNSAxLjEgMjQgNyAuNC4zIDIuOSAyLjcgNS4yIDIuNCAyLjMt'
    b'LjIgMi44LS41IDIuNy0uMiAwIC40LS43IDEuMi0uOSAxLjZhOS4yIDkuMiAwIDAgMC0uMyAx'
    b'LjF6bS0yNSAydi0uMmMtLjItLjQtMS4xLTEuNy0yLjctMy4xYTM3LjQgMzcuNCAwIDAgMC04'
    b'LTQuM2MtLjMtLjEgNiAyLjkgNy43IDQuNWwzIDN6Ii8+CiAgPHBhdGggZmlsbD0iI2QyYTU2'
    b'NyIgZD0iTTMzMCAxOTIuMnMtLjQtLjYtMS43LTEuNGE5LjkgOS45IDAgMCAwLTIuNS0xLjFs'
    b'MyAuN2E0LjggNC44IDAgMCAxIDEuMSAxLjh6bS0uOC01LjNzLS40LS42LTIuMS0xLjItMi4y'
    b'LS41LTIuMi0uNSAxLjYtLjcgMi44IDBhMi43IDIuNyAwIDAgMSAxLjUgMS42em0tMS00LjVz'
    b'LS40LS44LTItMS4zYy0xLjUtLjYtMi42LS43LTIuNi0uN3MxLjYtLjQgMy4yLjJjMS41LjYg'
    b'MS40IDEuOCAxLjQgMS44em0tMi0yLjhzLS40LS42LTMuMy0xLjNjLTMtLjctNC0uNy00LS43'
    b'czQuMS0uNCA1LjIuMWMxLjEuNSAyLjIgMS45IDIuMiAxLjl6bS01LjMtM3MtMS44LS42LTMu'
    b'NS0uNy00LjQuMS00LjQuMSA1LS44IDYuMy0uNWMxLjQuMyAxLjYgMSAxLjYgMXoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5NzdjMmUiIHN0cm9rZS13aWR0aD0iLjMi'
    b'IGQ9Ik0zMDQuNSAyMzguNHMuOSAxLjYgMi42IDEuNmMxLjguMSAzLjEgMi42IDMuMSAyLjZs'
    b'LTEuOSAxLjktNC42LjItMS41LTIuNCAyLjMtMy45em0wLTEuNmMuMi0uMy0xLjMtMy4zLTIu'
    b'NC0zLjgtMS0uNS40IDEgLjIgMS42LS4zLjYtLjQgMS40LS4zIDEuNSAwIDAgLjkgMS40LjQg'
    b'Mi0uNC41IDIuMi0xLjMgMi4yLTEuM3oiLz4KICA8cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJv'
    b'a2U9IiM5NzdjMmUiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0zMDMuOCAyNDEuNHMuOC40IDEu'
    b'NC4yYy43LS4yIDEuMy0uOSAxLjMtLjltLTMuNi0uNXMyLjYtMS45IDIuNC0yLjljLS4yLTEt'
    b'LjctMS0xLS45YTcgNyAwIDAgMC0yLjEgMS43Yy0uMS4zLjcgMi4xLjcgMi4xeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNmOGM4M2MiIHN0cm9rZT0iIzk3N2MyZSIgc3Ryb2tlLXdpZHRoPSIuMyIg'
    b'ZD0iTTMwMSAyNDEuNXMuNiAxLjMgMS40IDEuM2MuOCAwIDItLjcgMi0xLjIuMS0uNS0uOC0x'
    b'LjUtMS4zLTEuNy0uNi0uMy0xLjkuNC0xLjkuNGwtLjEgMS4yeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNmOGM4M2MiIHN0cm9rZT0iIzk3N2MyZSIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTMwMy40'
    b'IDIzOS44YzAgLjQtMS43IDEuMi0yLjMgMS4yLS41IDAtMS42LTEuMy0xLjItMS41bDEuNS0u'
    b'NGMuNC0uMi41LS44LjctLjguMyAwIDEgLjEgMS4xLjUuMi41LjQuNi4yIDF6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2Y4YzgzYyIgc3Ryb2tlPSIjOTc3YzJlIiBzdHJva2Utd2lkdGg9Ii4zIiBk'
    b'PSJNMzAxLjggMjQwLjlzLTIuNiAzLjQtMy43IDMuM2MtMS0uMi41LTUgLjUtNWwxLjIuNmMu'
    b'OS4yIDEuNy42IDIgMXoiLz4KICA8cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5Nzdj'
    b'MmUiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0yOTcuMiAyMzguNHMzLjMuNiAzLjQgMS4xYy4y'
    b'LjYtMS41IDEuMy0yLjUgMS4zLS45IDAtLjktMi40LS45LTIuNHoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjMjAyMjIwIiBkPSJNMjg5IDI0My40cy41IDEuNiAxLjkgMS43YzEuNCAwIDIuOC0xLjUg'
    b'Mi44LTEuNWwtMy40LTEuMy0xLjMgMS4xeiIvPgogIDxwYXRoIGZpbGw9IiM0YjQxMzkiIGQ9'
    b'Im0yODkgMjQzLjQuNC45Yy4zLjQuNy44IDEuNS45aC4xYzEuNCAwIDIuNy0xLjYgMi43LTEu'
    b'NmwtMy40LTEuNC0xLjQgMS4yaC4xbDEuMy0xIDMuMyAxLjN2LS4xbC0uMi4yYy0uNC40LTEu'
    b'NCAxLjItMi40IDEuMmgtLjFhMS44IDEuOCAwIDAgMS0xLjQtLjggMi44IDIuOCAwIDAgMS0u'
    b'My0uNnYtLjFsLS4xLS4xeiIvPgogIDxwYXRoIGZpbGw9IiMyMDIyMjAiIGQ9Ik0yOTAgMjQz'
    b'cy41IDEuMiAyLjQgMS4yIDMuMy0xLjUgMy4zLTEuNWwtMy0yLjMtMi43IDIuNnoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjNGI0MTM5IiBkPSJNMjkwIDI0M3MuNSAxLjIgMi40IDEuM2MyIDAgMy40'
    b'LTEuNSAzLjQtMS41bC0zLTIuNS0zIDIuN2guMmwyLjgtMi41IDIuOSAyLjN2LS4xYTUgNSAw'
    b'IDAgMS0zLjIgMS40IDMgMyAwIDAgMS0yLS42IDIuMiAyLjIgMCAwIDEtLjMtLjQgMS4xIDEu'
    b'MSAwIDAgMS0uMS0uMWgtLjF6Ii8+CiAgPHBhdGggZmlsbD0iIzRiNDEzOSIgZD0iTTI5MC4y'
    b'IDI0My4zcy45LjYgMS44LjdjMSAwIDIuMi0uMyAyLjItLjNsLTEuMS40LS44LjEtLjgtLjEt'
    b'LjYtLjMtLjYtLjR2LS4yeiIvPgogIDxwYXRoIGZpbGw9IiMyMDIyMjAiIGQ9Ik0yOTIuNCAy'
    b'NDEuNnMuOCAyIDIuNiAxLjhjMS43LS4yIDEuNy0xLjIgMS43LTEuMmwtMi0yLjgtMi4zIDIu'
    b'MnoiLz4KICA8cGF0aCBmaWxsPSIjNGI0MTM5IiBkPSJtMjkyLjQgMjQxLjYuNSAxYy40LjQg'
    b'MSAxIDEuOCAxbC4zLS4xYy44LS4xIDEuMy0uNCAxLjUtLjcuMy0uMy4zLS42LjMtLjZsLTIt'
    b'My0yLjUgMi40aC4xbDIuNC0yLjEgMS45IDIuN2MwIC4yLS4zIDEtMS44IDEuMWgtLjJhMi4y'
    b'IDIuMiAwIDAgMS0xLjctLjggNCA0IDAgMCAxLS40LS42di0uMmExLjUgMS41IDAgMCAxLS4x'
    b'LS4xaC0uMXoiLz4KICA8cGF0aCBmaWxsPSIjNGI0MTM5IiBkPSJNMjkyLjYgMjQyczEgMS4z'
    b'IDIgMS4zYTMgMyAwIDAgMCAxLjUtLjR2LjFsLS41LjMtLjguMWgtLjhsLS43LS41LS42LS45'
    b'em0tMy4yIDJzLjguOSAxLjUuOWE0LjcgNC43IDAgMCAwIDEuOS0uNmguMWwtLjIuMS0uOC40'
    b'LS45LjMtLjctLjEtLjYtLjQtLjMtLjR2LS4yeiIvPgogIDxwYXRoIGZpbGw9IiNmOGM4M2Mi'
    b'IHN0cm9rZT0iIzk3N2MyZSIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTI5NyAyMzguM2MuOC0u'
    b'MiAyLjQgMiAyLjQgMy4ycy0uNSAyLjctMS4zIDIuNy0yLjYtMS43LTMtMi41Yy0uNC0uOS0u'
    b'OC0xLjQtLjUtMS45LjMtLjQgMi40LTEuNSAyLjQtMS41em0tOCAuMnMtMS40LTEtMS45LS41'
    b'LS4zIDIuMyAwIDIuNmMuNC40IDItLjggMi0uOGwtLjItMS4zeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNmOGM4M2MiIHN0cm9rZT0iIzk3N2MyZSIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTI4OC44'
    b'IDIzOS43cy0xLjguMi0xLjggMSAuOSAxLjYgMSAxLjhjLjIuMSAxLjgtLjcgMS44LS43bC0x'
    b'LTIuMXoiLz4KICA8cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5NzdjMmUiIHN0cm9r'
    b'ZS13aWR0aD0iLjMiIGQ9Ik0yODkuNSAyNDEuMXMtMS44LjYtMS44IDEuMi44IDEuNyAxLjMg'
    b'MS43IDEtMSAxLjItMS4zYy4zLS4yLS43LTEuNi0uNy0xLjZ6bS44LTUuMXMtLjMtLjUtMS0u'
    b'MmMtLjguMy0xLjYgMS0xLjUgMi4zLjEgMS4xLjYgMiAuNiAybDIuNy0xLS44LTMuMXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5NzdjMmUiIHN0cm9rZS13aWR0aD0i'
    b'LjMiIGQ9Ik0yOTAuNSAyMzhzLTIuMi44LTIuMyAxLjdjLS4xLjkuNSAxLjcgMSAyIC43IDAg'
    b'Mi42LTEuOCAyLjYtMS44bC0xLjMtMS44eiIvPgogIDxwYXRoIGZpbGw9IiNmOGM4M2MiIHN0'
    b'cm9rZT0iIzk3N2MyZSIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTI5Mi41IDI0MS43cy0yLjIg'
    b'MS41LTIuNSAxLjVjLS4zIDAtMS4yLTEuMi0xLTIgLjItLjggMS43LTEuMyAyLjMtMS42LjYt'
    b'LjIgMS4yIDIuMSAxLjIgMi4xem0yLTguMnMtLjctLjYtMi0uNWMtMS40LjEtMi40IDItMi42'
    b'IDIuOC0uMi45IDAgMi42LjUgMi44LjUuMyAzLjMtMiAzLjMtMmwuOC0zeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNmOGM4M2MiIHN0cm9rZT0iIzk3N2MyZSIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0i'
    b'TTI5MS44IDI0MC4zYy0xLS4xLTEuOC0xLjUtMS43LTIuMy4yLS44IDItMi4yIDMtMiAxIC4x'
    b'LjggMi41LjggMi41cy0xLjIgMS45LTIuMSAxLjh6Ii8+CiAgPHBhdGggZmlsbD0iI2Y4Yzgz'
    b'YyIgc3Ryb2tlPSIjOTc3YzJlIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNMjk0LjcgMjQwcy0u'
    b'NCAxLjItMS40IDEuN2MtMSAuNC0xLjUgMC0yLS43LS42LS44LjItMS4yLjYtMS42LjUtLjQg'
    b'MS43LS43IDEuNy0uN2wxLjEgMS40eiIvPgogIDxwYXRoIGZpbGw9IiNmOGM4M2MiIHN0cm9r'
    b'ZT0iIzk3N2MyZSIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTI5My4yIDIzNy4ycy0xIC44LS40'
    b'IDEuOCAxIDEuNCAxLjggMS41Yy44LjEgMS4zLS4yIDEuOS0uOS42LS43IDEuNS0xIDEuNC0y'
    b'LS4xLS45LS40LTEuNi0xLTEuOC0uNS0uMy0yLjIgMC0zLjcgMS40eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiMyMDIyMjAiIGQ9Ik0yOTYuMiAyMzNzLTEtLjUtMS45IDBjLS44LjUtMS40IDEuNS0x'
    b'LjUgMi40bC4yIDIuM3MxLjItLjQgMi0xYy43LS42IDEtLjguOC0xLjEgMC0uMi0uNC0uNC0u'
    b'NC0xLjIgMC0xLjQuOC0xLjUuOC0xLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzRiNDEzOSIgZD0i'
    b'TTI5Ni4yIDIzM3MtMS4yLS4zLTEuOS4xYTMuMiAzLjIgMCAwIDAtMS4zIDEuOWMtLjMuOC0u'
    b'MSAxLS4xIDF2LTEuNGMuNC0uOCAxLTEuNSAxLjYtMS43LjgtLjMgMS43IDAgMS43IDB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2Y4YzgzYyIgc3Ryb2tlPSIjOTc3YzJlIiBzdHJva2Utd2lkdGg9'
    b'Ii4zIiBkPSJtMzI4LjggMjU3IDEuNi0uOCAyLTEuMi40IDIuMi0xLjggMS40aC0xLjVsLS45'
    b'LS43LjItMXoiLz4KICA8cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5NzdjMmUiIHN0'
    b'cm9rZS13aWR0aD0iLjMiIGQ9Ik0zMjYuNCAyNTcuMmgxYzEuMSAwIDEuMi0uMyAxLjQtLjMu'
    b'Mi4xLjUgMS4zLjUgMS4zbC0uNC43LTEuNS45LTEuMy0uOC0uMS0xLjhoLjR6bTEyLjEtLjhz'
    b'LS4zLS41LS45LTFsLTIuMi0xLjl2NWwyLjMtLjEgMS4xLTEuNS0uMy0uNXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5NzdjMmUiIHN0cm9rZS13aWR0aD0iLjMiIGQ9'
    b'Ik0zMjYuNCAyNTcuMnMtLjQtLjUtMS4zLS40Yy0xIDAtMiAuOS0yLjEgMS41LS4xLjcgMCAy'
    b'LjYuNSAzIC41LjQgMS4yLjUgMi4yLjMgMS0uMyA2LjQtMy42IDYuNC0zLjZsLTEuNC4zYy0u'
    b'Ny4yLTEuNC0uMS0xLjQtLjFzLS43LjgtMS42IDFjLS44IDAtMS0uNS0xLjItLjlsLS4xLTEu'
    b'MXoiLz4KICA8cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5NzdjMmUiIHN0cm9rZS13'
    b'aWR0aD0iLjMiIGQ9Im0zMzAgMjU4LjktMS4yLjUtMS4zLjYuNCAxLjYgMi4zLjUgMS40LTEu'
    b'MXYtMS42bC0xLjctLjV6bTEwLjQtMS4yLS44LS44Yy0uNC0uNC0xLS41LTEtLjVsLTEuMyAx'
    b'LjV2MWwxLjIuNy45LjIgMS4xLS44LS4xLTEuM3oiLz4KICA8cGF0aCBmaWxsPSIjZjhjODNj'
    b'IiBzdHJva2U9IiM5NzdjMmUiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0zMzIuNiAyNTdzLTEg'
    b'LjQtMS41LjhsLTEuMiAxYzAgLjIgMS4xIDEuNCAxLjEgMS40bDEuMi4xIDIuNS0xLjctLjIt'
    b'MS42aC0xLjl6bTkuNSAyLS41LS43Yy0uNC0uNC0xLS42LTEuMi0uNi0uMyAwLTEuMyAxLjUt'
    b'MS4zIDEuNXYuNGwuOCAxIDEuNi41IDEuMS0xLjItLjUtLjl6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'I2Y4YzgzYyIgc3Ryb2tlPSIjOTc3YzJlIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9r'
    b'ZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Im0zMzggMjYwLjggMS4y'
    b'LjJzMCAuMy4zLjVjLjMuMy4zIDAgLjMgMHMuMiAxLjIgMS40IDJjMCAwIDEuNC42IDIgLjIu'
    b'OC0uNC43IDAgLjcgMGwyLTIuNHMwLS41LS41LS41YzAgMCAuNC0xLjYtMS0yLTEuMi0uMi0y'
    b'LjIuMi0yLjIuMnMtMSAxLjgtMS42IDEuNmEyLjQgMi40IDAgMCAxLS44LS41bC0uNy0uOXMt'
    b'LjQuMS0uOS0uMmMtLjUtLjMtLjktMS4xLS45LTEuMXMtLjctLjEtMS0uNGwtLjUtLjgtMS45'
    b'IDEuNHMwIC41LTEuMSAxLjMtMS43LjgtMS43LjgtLjQgMS43LTEuNiAxLjRjLTEuMi0uMy0y'
    b'LTEuNi0yLTEuNnMtLjktLjItMS40LjZjLS42LjctLjkgMS0uOSAxLjcgMCAuOC41IDEuOCAx'
    b'IDIuMi4zLjMgMS41IDEuMyAzIC42IDEuNC0uOC45LTIgLjktMmwuOC0uNWMuOS0uNiAxLjgt'
    b'MS41IDIuNS0xLjciLz4KICA8cGF0aCBmaWxsPSIjZjhjODNjIiBzdHJva2U9IiM5NzdjMmUi'
    b'IHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0zMzUuOCAyNTAuOHYzLjJzLjQgMi45LS4yIDMuN2Mt'
    b'LjYgMS0yLjkuNy0zLjIgMC0uMy0uOC0uMi0zLjItLjItMy4ybDMuNi0zLjd6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2Y4YzgzYyIgc3Ryb2tlPSIjOTc3YzJlIiBzdHJva2UtbGluZWNhcD0icm91'
    b'bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0zMzMu'
    b'MyAyNjAuNXMtLjUuOCAxIDFjLjQgMCAuNy0uMi45LS40LjQtLjQuMy0uOC4zLS44cy0uMiAx'
    b'LjIgMS4yIDEuMmMxLjQuMSAxLjMtMS4zIDEuMy0xLjMiLz4KICA8cGF0aCBmaWxsPSIjMjAy'
    b'MjIwIiBkPSJNMzIxLjIgMjYzLjFzLS44LTEuNC4xLTEuOWMxLS41IDEuNSAwIDIuMSAwIC42'
    b'IDAgLjQtMS40LjMtMS43YTMuNyAzLjcgMCAwIDAtLjctMS4yYy0uMi0uMi0zLjUuMi0zLjQg'
    b'Mi4zIDAgMi4xIDEuNiAyLjUgMS42IDIuNXptNSA1LjJzLTEtMS41LS40LTIuNGMuNS0uOSAx'
    b'LS4zIDEuMi0uNC4zIDAgLjQtLjYgMC0xLjYtLjUtMS0xLjEtMS40LTEuNC0xLjUtLjQgMC0y'
    b'LjMgMS40LTIgMy4yYTMuNSAzLjUgMCAwIDAgMi42IDIuN3ptMTguMi0xLjhzMy41IDEuNSAz'
    b'LjctMmMuMi0yLTEuNS0zLjMtMi0zLjMtLjQgMC0uNy4zLTEuMyAxLS43LjgtMS4xIDEuMy0u'
    b'OSAxLjYuMy4zIDEuMy0uMyAxLjguOC43IDItMS4zIDEuOS0xLjMgMS45eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM0YjQxMzkiIGQ9Ik0zMjYuMiAyNjguM3MtMi43LS42LTIuNy0zLjNjMC0xLjgg'
    b'Mi0yLjYgMi0yLjZzLTEuOCAxLTEuOCAyLjZjLS4xIDIuNyAyLjUgMy4zIDIuNSAzLjN6bS01'
    b'LTUuMnMtMS42LS4zLTEuNy0yLjZjLS4yLTIuMyAzLjUtMi4yIDMuNS0yLjJzLTMuNS4yLTMu'
    b'NCAyLjRjLjIgMi4yIDEuNiAyLjQgMS42IDIuNHptMjMuMiAzLjRzLjcuMyAxLjUuMyAxLjgt'
    b'LjMgMi0xLjZjLjQtMS4zLjMtMi0uNi0zLjEtLjYtLjktMS4yLS44LTEuMi0uOHMuNiAwIDEg'
    b'LjhjLjYuOCAxLjMgMS42LjggMy4xcy0yIDEuNS0yLjUgMS41YTUuNSA1LjUgMCAwIDEtMS0u'
    b'MnoiLz4KICA8cGF0aCBmaWxsPSIjOTA0NzIwIiBkPSJtMzAyLjYgMTkyLjQtLjYtLjIuNC0x'
    b'IDEuOS0uNyAxLjgtLjEgMi0uMS44LjYgMSAyLjMtMy42IDIuMi0uNi4yLS4yLTEtLjYtMS40'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiMyMDIwMjAiIGQ9Im0zMzcgMjQ1LjUtLjMtNS41LTE0Ljgg'
    b'NC42IDUuOCA1LjV6Ii8+CiAgPHBhdGggZmlsbD0iI2QyYTU2NyIgZD0ibTMwOS40IDIzNS45'
    b'LTEuMi0xLTEuNC0uOGgtMS4xbC0uMi4zLjIuNSAxLjMgMS42IDIuMyAxLjIuOC43LjUuMi0x'
    b'LjEtMi43em0tLjMgMi4zLjguMi45IDEgLjUgMSAuNyAxLjMuMi44LTEuNi0uMy00LjgtMS41'
    b'LjQtMS4yLjgtLjcuNy0uMyAxLS4yeiIvPgogIDxwYXRoIGZpbGw9IiNkMmE1NjciIGQ9Ik0z'
    b'MTIuMiAyNDIuMmguOGwuNi0uNS0uMy0xLjguMy01LjgtMy45LTQuNi0uOCAyLjYgMS4xIDQu'
    b'Ny45IDIuOHoiLz4KICA8cGF0aCBmaWxsPSIjYWI2ZDI5IiBkPSJNMzA5LjQgMjMxLjdzLS4y'
    b'LjQuMSAyYy4zIDEuNS45IDQuOSAyLjIgNy4ybC0xLjMtMS45cy0yLTQuNi0xLjctOC4yYy4z'
    b'LTMuNS43LjguNy44em0yLjkgMi45cy0uOSAxLTEgMS45djIuMnMwLTEgLjgtMS4zYy45LS4z'
    b'LjcgMi4zLjggMi42bC41LTQuNy0xLjEtLjd6bS40IDkuNi00LjQtMWMtMi4zLTEtMy41LTEu'
    b'OC0zLjQtMi4zIDAtLjYgNCAuMSA0LjYuMmwyLjQgMWgxbDEuOS0uOC4yIDItMi4zIDF6bS03'
    b'LjMtLjhzMSAuOC41IDFhNC40IDQuNCAwIDAgMS0yLjMuM2w0LjIgMSAuOS0uNy0zLjMtMS42'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNkMmE1NjciIGQ9Ik0zMDQuMiAyNDIuMmMuMi0uMi4zLjcg'
    b'MS44LjggMS41LjIgMi4yLS4yIDIuMi0uMmwuNy40LjguMi0uNyAxLjEtMi44LS44LTEuNS0u'
    b'OC0uNS0uN3oiLz4KICA8cGF0aCBmaWxsPSIjYWI2ZDI5IiBkPSJtMzE0IDI0MC4zLjggMSAu'
    b'NS0yLjR2LTIuNWwtMS42LTF6Ii8+CiAgPHBhdGggZmlsbD0iIzRkMmExNSIgZD0ibTMwOS43'
    b'IDIzNi4xLTEuMy0yLjEtMS43LTMuMSAxLTEuOCAxLjMgMS44cy0uNCAxLjMtLjEgMi41Yy4y'
    b'IDEuMi44IDIuNy44IDIuN3oiLz4KICA8cGF0aCBmaWxsPSIjZDJhNTY3IiBkPSJNMzAwLjgg'
    b'MjQ0cy42LS45IDEuOS0xYTcuNiA3LjYgMCAwIDEgMi40LjJsMi42IDEuNC42LjktNS0uNy0y'
    b'LjUtLjh6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIgZD0ibTMxNCAyMzUgLjIgNGMwIDEg'
    b'LjcgMiAuNiAyLjMtLjIuNC0uNC42LTEgLjktLjYuMi0yIDAtMiAwczEuMy0uMiAxLjQtLjVj'
    b'MC0uMi0uNC0xLjQtLjUtMi40IDAtMSAuMS0yLjItLjMtMi4yLS4zIDAtLjcuNC0uOC42IDAg'
    b'MCAuNC0zLjguOC00LjIuNC0uNCAxLjYgMS42IDEuNiAxLjZ6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'I2FiNmQyOSIgZD0iTTMwNC43IDI0M3MtLjUtLjQtLjUtLjhjMC0uMy42IDEuNiAzLjQgMS41'
    b'IDIuOCAwIDIuNi0uMiAyLjYtLjJoMS4zcy0uMyAxLjMtLjUgMS40YTYxIDYxIDAgMCAwLTIu'
    b'MiAxLjRsLS43LjR2LS4ybC0uMy0yLjEtMi40LTEtLjctLjR6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzhmNDYyMCIgZD0iTTMwOS43IDIzNi4xcy0zLjItMy4zLTQuMy01LjVjLTEtMi4yLS40LTUu'
    b'Mi0uNC01LjJsMyA0cy0uNC43LS4zIDJjLjIgMS4yIDIgNC43IDIgNC43eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNhYjZkMjkiIGQ9Ik0zMDcuNiAyNDguM2MwLS4zLS4yLTEgLjQtMS44IDItMi40'
    b'IDYuOC00IDYuOC00djIuOGwtNi4yIDNoLTF6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIg'
    b'ZD0iTTMwOCAyNDZjLjMtLjEgMS40LTEgMS40LTEuMyAwLS40LS43LS40LTIuMS0uNy0xLjUt'
    b'LjMtMi42LTEtMi42LTFzMS43IDEuNCAyLjQgMS43Yy43LjIuNi41LjUuN2wuNC42em04LjMu'
    b'N3MtLjktMS4zLTEuMi0yLjFjLS4zLS44LS4zLTIuMS0uMy0yLjJsLTEgLjctMiAuN3MyIDAg'
    b'MiAuNmMwIC43LTMgMS0zIDEgMCAuMSAyLjQtLjQgMi4zLjEtLjIuNi0xLjIuNy0yLjUgMS4y'
    b'bC0yLjMgMS0uNy41cy42LjQgMS41LjNjLjkgMCAyLjktLjUgMi45LS41bDMuOC0xLjUuNS4y'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNhYjZkMjkiIGQ9Ik0zMTYuMyAyNDYuN3MtMS0uMy0xLjgt'
    b'NC44LS42LTUuNy0uNi01LjdsMS44IDEuMyAxLjcgMy0xLjEgNi4yeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiM4ZjQ2MjAiIGQ9Ik0zMTYuOSAyMzkuM3MtLjkgMi41LS45IDRjMCAxLjQtLjEgMi40'
    b'LjMgMy40czEuOCAyLjMgMS44IDIuM2wuNy0uNi4zLTIgLjEtMy40LTIuMy0zLjd6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzIwMjAyMCIgZD0iTTMxOS40IDI0Mi43cy40IDYuMy0xLjIgNi41Yy0u'
    b'NyAwLTEuOS0yLjQtMS45LTIuNSAwIDAgMS40IDIuMyAyIDIuMSAxLS40LjYtNi42LjYtNi42'
    b'bC41LjV6bS0zLjEgNHMtLjMgMC0uNy0uOGMtLjQtLjcgMCAuNi0zLjQgMS44LTMuNCAxLjIt'
    b'NC42LjUtNC42LjVzMS4xIDEgNC41IDAgMy4xLTEuMyAzLjYtMS40aC42eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNhYjZkMjkiIGQ9Ik0zMTAgMjM4LjdzLjYuNSAxLjIgMS43YTM2My4zIDM2My4z'
    b'IDAgMCAwIDEgMmguMnMtLjQtMS4zLTEtMi4ybC0yLjItMy4xLjggMS42eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM4ZjQ2MjAiIGQ9Ik0zMDggMjQ2LjVzLjMtMS4xIDAtMS40Yy0uMy0uMi0uNyAw'
    b'LTMtLjJhMzQgMzQgMCAwIDEtNC4yLS45czEuNiAxIDMgMS40bDMuNS44LjUuMS4yLjJ6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzIwMjAyMCIgZD0ibTMwOCAyNDYuNS0uMi0uNWMtLjMtLjMtLjcu'
    b'MS0zLjUtLjctMi44LS43LTMuNS0xLjMtMy41LTEuM3MxIDEgMy40IDEuNWwzLjggMXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjYWI2ZDI5IiBkPSJNMzA5LjMgMjM4LjJzLTIuMS4xLTIuOC43Yy0u'
    b'Ny41LTEuNiAyLTEuNiAybDEuMy4xcy0uMS0xLjIuNS0xLjljLjctLjYgMS43LS43IDIuNi0u'
    b'OXoiLz4KICA8cGF0aCBmaWxsPSIjOGY0NjIwIiBkPSJNMzA1LjMgMjM0LjJzLjggMS4yIDEu'
    b'NyAxLjVjLjkuNCAxLjguOCAyLjIgMS4yLjQuNC45IDEuOC45IDEuOHMtMy0xLjMtMy43LTJh'
    b'OS42IDkuNiAwIDAgMS0xLjEtMi41eiIvPgogIDxwYXRoIGZpbGw9IiM4ZjQ2MjAiIGQ9Ik0z'
    b'MDguMiAyMzVzLS4zLS41LTEuMS0uOS0xLjQtLjMtMS43LS4xLS4xLjItLjEuMmwxIDEuNy43'
    b'LS4ycy0xLjYtMS0xLjMtMS4zYy44LS43IDIuNS41IDIuNS41eiIvPgogIDxwYXRoIGZpbGw9'
    b'IiMyMDIwMjAiIGQ9Im0zMTYuMyAyMzEuMSAxNy04LjcgOCAxMS4xLTE0LjcgNC03LjcuNi0z'
    b'LjgtMi43eiIvPgogIDxwYXRoIGZpbGw9IiM0ZDJhMTUiIGQ9Im0zMzkgMjM1LjkgMjEgMTgu'
    b'Mi0yLjMgMS42LTUtMS40LTEwLjItMTAuMS0zLjgtMy44eiIvPgogIDxwYXRoIGZpbGw9IiM0'
    b'ZDJhMTUiIGQ9Im0zNjYgMjUwLjUtMTItOS4xLTE1LjMtMTEuNS40IDUuNSAxNy40IDE2IDUu'
    b'NyAyLjcgMy0uOCAxLjQtMS42LS42LTEuMnoiLz4KICA8cGF0aCBmaWxsPSIjODAzZjFkIiBk'
    b'PSJNMzM5IDIzNy42czYgNi45IDEwLjYgMTAuNCA5IDcuMyAxMCA2LjdjLjgtLjUuNS0xIC41'
    b'LTFsLTIxLjMtMTcuNS4xIDEuNHoiLz4KICA8cGF0aCBmaWxsPSIjNGQyYTE1IiBkPSJtMzUz'
    b'LjggMjU1LjEtMi4xIDEuNy0yLjUtMS0xMy0xMy4yLjctMi41IDEuOC4zeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiMyMDIwMjAiIGQ9Ik0zNjYgMjUwLjVzLTEuNiAzLjgtNSAyLjljLTMuNC0uOS0y'
    b'Mi0xOC41LTIyLTE4LjV2MS44czE4LjggMTcuMyAyMi41IDE4YzMuNi43IDYuNi0yLjUgNi4y'
    b'LTIuOGE0My43IDQzLjcgMCAwIDAtMS43LTEuNHoiLz4KICA8cGF0aCBmaWxsPSIjODAzZjFk'
    b'IiBkPSJNMzM2LjkgMjQwLjRzNiA3LjcgOS4xIDEwLjVjMy4yIDIuOSA2IDUgNy4yIDQuOCAx'
    b'LjMtLjItLjctMS43LS43LTEuN2wtOS4xLTktNC43LTQuNnMtMS44LS43LTEuOCAweiIvPgog'
    b'IDxwYXRoIGZpbGw9IiMyMDIwMjAiIGQ9Ik0zMzguNCAyNDAuNHMxNS4yIDE1LjUgMTYuNCAx'
    b'NS45YzIuNS43IDYuMi0yIDYuMi0ybC0xLjMtLjctLjIuNXMtLjcgMS42LTQgLjljLTMuMi0u'
    b'Ny0xNi42LTE1LjEtMTYuNi0xNS4xbC0uNS41eiIvPgogIDxwYXRoIGZpbGw9IiM0ZDJhMTUi'
    b'IGQ9Im0zNDQgMjU1LjMtNS41LTYuNC0xLjItMi4xLS4zLTIuNyAxMSAxMS4xLTEuNSAxLTEu'
    b'NC0uNHoiLz4KICA8cGF0aCBmaWxsPSIjMjAyMDIwIiBkPSJNMzU0LjEgMjU1LjVzLTEuMyAy'
    b'LTMuMiAxLjZhNS40IDUuNCAwIDAgMS0yLjgtMS43TDMzNy41IDI0NWwtLjMtMS42czExLjcg'
    b'MTIuMyAxMy43IDEyLjhjMS42LjQgMi43LTEuNCAyLjctMS40bC41Ljd6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzIwMjAyMCIgZD0iTTM0OC4yIDI1NS4xcy0uNSAxLjYtMiAxLjRjLTEuNi0uMy0y'
    b'LS45LTItLjlsLTYuNi03LjctLjEtMnM2LjggOS4zIDguMyA5LjhjMS42LjUgMi0xIDItMWwu'
    b'NC40eiIvPgogIDxwYXRoIGZpbGw9IiNiMDcyMjkiIGQ9Ik0zNDEuMyAyMzQuOXM2LjMgNS40'
    b'IDYuOCA1LjZjLjUuMyAyLjcuNCAyLjguNy4yLjMtMS40IDAtMS41LjMtLjEuNCAzLjIgMyAz'
    b'LjcgMy4xLjUgMCAzLjIgMCAzLjEuNCAwIC4zLTEuOCAwLTEuOS40IDAgLjQgMi45IDIuNyAz'
    b'LjQgMi44LjUgMCAzLjkgMCAzLjkuNCAwIC4zLTIuNyAwLTIuNy41LjEuNiA0LjYgMy40IDQu'
    b'NCAzLjgtLjIuNC01LjQtMy41LTUuNS0zLjMtLjIuMi0uNCAxLjQtLjcgMS42LS4zLjIgMC0x'
    b'LjYtLjItMi40LS4zLS44LTMuNC0zLjEtMy43LTIuOS0uMy4zIDAgMS43LS40IDEuN3MuMS0x'
    b'LjctLjItMi4zYTE2IDE2IDAgMCAwLTMuNi0zYy0uNCAwLS4xIDEuMy0uNCAxLjUtLjMuMi0u'
    b'Mi0xLjUtLjYtMi0uNC0uNS03LTYuNS02LjctN3oiLz4KICA8cGF0aCBmaWxsPSIjNGQyYTE1'
    b'IiBkPSJNMzMwLjUgMjUyLjNzMCAyLjQtMSAyLjhjLTEuMS4zLTMuMS00LjQtMy4xLTQuNGwt'
    b'LjUtNC40IDMuMSAzIDEuNSAzem04LjQtMS4yVjI1MGMwLS42LS4zLTEuNS0uMy0xLjVsLS4y'
    b'LTIuNC0uNi0xLjctLjQtMWgtLjdsLTEuNyAxLjItLjUgMS42LjggMyAuOCAyLjcgMS4zLjQg'
    b'MS41LTF6Ii8+CiAgPHBhdGggZmlsbD0iIzRkMmExNSIgZD0iTTMzNi44IDI1NS4zYy4zLS4x'
    b'LS40LTMuNC0uNC0zLjRsLTItNC44LS41LTEuNy0xLjUtLjYtMSAxLjIuMiAxLjlzMS41IDMu'
    b'MiAyLjIgNC4zYy44IDEuMSAyLjMgMy4zIDMgMy4xeiIvPgogIDxwYXRoIGZpbGw9IiMyMDIw'
    b'MjAiIGQ9Ik0zMzUgMjQ1YTYgNiAwIDAgMSAxLjQgMi42czEuMyAzLjYgMS4xIDRjLS4yLjMt'
    b'MSAuMy0xIC4zczEuOCAxLjggMi4zIDEuNmMuNS0uMi4zLTIgLjEtMi40LS4xLS40LS43IDAt'
    b'MS0uNS0uMS0uNC0uOC0yLjctLjgtNC4ydi0yLjdjLjItLjMgMS41IDMgMS41IDQuN2wuNi43'
    b'LS42LTMuMi0uNy0yLjNjMC0uMi4zLS44LjMtMS41di0xcy42LjUuOS41Yy4zIDAgLjctLjQu'
    b'OC0yIC4yLTEuNS0uMS02LS4xLTZsLTYuOCA5IDIgMi41eiIvPgogIDxwYXRoIGZpbGw9IiMy'
    b'MDIwMjAiIGQ9Ik0zMzUgMjQ0LjNzLS4zIDIuNC42IDQuOGwxLjMgM2MuMi4zLjIgMi45LS4x'
    b'IDMuMiAwIDAtMS44LTQuNC0yLjQtNi42LS41LTIuMS0uNy0zLTEtMy4ybC0uOC0uMiAyLjQt'
    b'MXoiLz4KICA8cGF0aCBmaWxsPSIjNGQyYTE1IiBkPSJNMzM0LjQgMjU3Yy4yIDAgMC0xIDAt'
    b'MWwtLjItMi4zLTIuNC00LjktMi42LTIuMy0xLjQtMi0uMiA0czIgNCAzLjEgNWMxLjMgMS4y'
    b'IDMuMyAzLjYgMy43IDMuNXoiLz4KICA8cGF0aCBmaWxsPSIjMjAyMDIwIiBkPSJNMzI0Ljcg'
    b'MjQ2cy40IDEuMS40IDEuOHYxLjRsMS44IDMuNWMuOSAxLjUgMS43IDMuMSAyLjQgMi44Ljct'
    b'LjQgMS0xLjUgMS0xLjcuMS0uMS0uOCAxLjMtMS4yIDEuMWE0MCA0MCAwIDAgMS0yLjMtNi42'
    b'bC0xLS44YTE4LjQgMTguNCAwIDAgMS0xLjEtMS40em03IDUuNS0xLjctMy4xYy0uNS0xLTEu'
    b'Mi0xLjctMS40LTEuNy0uMiAwLS41LTItLjUtMnMuNyAxLjMgMS42IDEuN2MxIC41IDEuNS44'
    b'IDIgLjdsLjIgMi0uMiAyLjR6Ii8+CiAgPHBhdGggZmlsbD0iIzVjM2ExZCIgZD0iTTMyNy40'
    b'IDI0OC4zcy41IDEuNCAxLjQgMi43Yy44IDEuMyAyLjMgMi45IDIuMyAyLjlzLTEuNi0xLjYt'
    b'Mi41LTIuOGExNCAxNCAwIDAgMS0xLjQtMi44aC4yeiIvPgogIDxwYXRoIGZpbGw9IiMyMDIw'
    b'MjAiIGQ9Ik0zMzIgMjQ2LjdzLjUtMS4yLjgtMS4zbDEuMi0uM3MtLjctLjEtMS4yLS44bC0x'
    b'LjMtMS4zLjQgMiAuMSAxLjd6bS0uNC40czIgNCAyLjQgNS41Yy41IDEuMy40IDMuNC40IDMu'
    b'NHMtLjItMS41LS42LTIuN2wtMi40LTVjLS4xLS4zLjItMS4yLjItMS4yeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM0ZDJhMTUiIGQ9Im0zMzQuMiAyNDQuNC41LTYtLjUtMi4yLTIuNy02cy0uMS44'
    b'LS44LjhhNi4yIDYuMiAwIDAgMS0zLjEtMS44IDkuMiA5LjIgMCAwIDAtLjIgNC44bDUuMyA5'
    b'LjkgMS41LjV6Ii8+CiAgPHBhdGggZmlsbD0iIzhiNDQxZiIgZD0iTTMyMy44IDI0OC4zcy44'
    b'IDEgMS4zIDFjLjQtLjIuMy0yLjEtLjMtMy4yLS42LTEtNy05LjYtOC0xMC4xczcgMTIuMyA3'
    b'IDEyLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzhiNDQxZiIgc3Ryb2tlPSIjNWMzYTFkIiBzdHJv'
    b'a2Utd2lkdGg9Ii4xIiBkPSJNMzI4LjEgMjQ0LjhjLjIuNC42IDMuMS0uNSAzLjQtMS41LjMt'
    b'OC41LTkuNC05LjYtMTAuNyAwIDAtNC40LTIuOC00LjUtMy41LS4xLS43IDQuNyAxIDQuNyAx'
    b'bDkuNSA5IC41Ljh6Ii8+CiAgPHBhdGggZmlsbD0iIzIwMjAyMCIgZD0iTTMyMy44IDI0OC4z'
    b'cy0uOC0xLjMtLjktMi4zYzAtMS0uNC0xLjUtLjQtMS45IDAtLjMtNS4yLTcuNy01LjctOC4y'
    b'LS42LS41LTIuMy0xLjQtMi4zLTEuNGExNS41IDE1LjUgMCAwIDAgLjMgMi40czEuNiAzIDQg'
    b'NS43YTQ1OC40IDQ1OC40IDAgMCAwIDUgNS44eiIvPgogIDxwYXRoIGZpbGw9IiM0ZDJhMTUi'
    b'IGQ9Ik0zMzEuNiAyNDdjLjctLjMuNC0yLjcuMS0zLjVhNDU4LjQgNDU4LjQgMCAwIDAtNC40'
    b'LTkuNGwtMS4zLjQtMi4zLTEuOC0xLjQtMS41cy41IDIuMS40IDMuMXYxLjZsMy4zIDUuOSA1'
    b'LjYgNS4zem00LjctNS4yIDEtMS4zLS41LTQuNC0yLjgtOS40cy0uNy4xLTEuNC0uM2MtLjYt'
    b'LjQtMS40LTEuMy0xLjQtMS4zbC43IDUuNyAyLjkgOCAuMiAyLjMgMS4zLjd6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzIwMjAyMCIgZD0iTTMyNy43IDI0NHMtMi44LTMtMy43LTQuNWwtMS43LTNz'
    b'LS44LjMtMS44IDBjLTEtLjUtMi4yLTEuOC0yLjItMS44cy0uOCAxLjUgMy4yIDUuNmM0LjYg'
    b'NC42IDYuMiAzLjcgNi4yIDMuN3oiLz4KICA8cGF0aCBmaWxsPSIjOGI0NDFmIiBkPSJNMzM0'
    b'LjQgMjQ1YzEuMi0uNCAxLjEtNS40IDAtOC43LTEtMy4zLTIuOS02LjItMi45LTYuMnMyLjMg'
    b'NS40IDIuOCA3LjVjLjQgMi4yIDAgMy43LS40IDMuNi0uNC0uMS0uNC0xLjMtMS4zLTMuNC0x'
    b'LTItMS42LTIuNi0xLjYtMi42czMuMyA4LjggMi4zIDguNmMtLjktLjItNS4zLTkuOS01LjUt'
    b'MTAuMi0uMi0uMi0uNC40LS40LjRzNCAxMi4yIDcgMTF6Ii8+CiAgPHBhdGggZmlsbD0iIzRk'
    b'MmExNSIgZD0ibTMzNyAyMjEuMyAyIDQuMi42IDQuNC4yIDMuN3MwIDcuNC0uOCA3LjZjLTEg'
    b'LjEtMS40LS43LTEuNC0uOWEyNzI5IDI3MjkgMCAwIDEtMS43LTguM2wtMS43LTguNS42LS42'
    b'LjItMS4yIDEuMy0uMS43LS4zeiIvPgogIDxwYXRoIGZpbGw9IiM4YjQ0MWYiIGQ9Ik0zMzEu'
    b'NiAyNDdjLjggMCAwLTIgMC0ycy0uNiAxLTEuMi4zYy0uNS0uNy0xLjMtMy4xLTEuMy0zLjFs'
    b'LS41LTEuNXMtLjYgMS42LTEuMyAxLjYtNC42LTYuNC00LjYtNi40bC0uNC42czUuNCAxMS4x'
    b'IDkuMyAxMC42eiIvPgogIDxwYXRoIGZpbGw9IiMyMDIwMjAiIGQ9Ik0zMjkuMSAyNDIuMnMu'
    b'Ny0xLjYuNC0zYy0uMy0xLjUtMi4yLTUuMS0yLjItNS4xcy0uNi4xLTEuNC0uMmE5LjYgOS42'
    b'IDAgMCAxLTIuMi0xLjIgMzguMyAzOC4zIDAgMCAwIDUuNCA5LjV6bTMuMS0yLjNzLS41LTMu'
    b'NC0yLTYuNmMtMS42LTMuMS0yLjYtNC4xLTIuNi00LjF2My41czEuNS41IDIuNiAyLjRjMSAy'
    b'IDIgNC44IDIgNC44em00LjMtNS44cy0uMy0zLjctLjgtNS44bC0xLjItNXMwLS4yLjMtLjRo'
    b'LjZjLjguMyAxLjEgMi4yIDEuMSAyLjJsLS4xLTMuMS0uMy0uNWgtMS40cy4zIDEtLjEgMS4z'
    b'Yy0uMy4zLS42LS4yLS43LS4zbC0uMi40LjQgMi0uMSAxLjdzLjUgMi4yIDEuMiAzLjVjLjYg'
    b'MS40IDEuMyA0IDEuMyA0em0zLjMtLjVzLjYtNS4zLS42LTguN2MtMS4yLTMuNC0yLjItNC4y'
    b'LTIuMi00LjJsLS42LjZzMS44IDMgMi40IDUuNmwxIDYuN3ptLTUuNCAyLjdzLS42LTQuMS0x'
    b'LjMtNi44YTgyLjggODIuOCAwIDAgMS0xLTMuNmwtMS4xLTFzLjcgMi43LjYgMy42bC0uMSAx'
    b'LjRzLjUgMS40IDEuMyAyLjZhMjUuNSAyNS41IDAgMCAxIDEuNiAzLjh6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzkwNDcyMCIgZD0iTTMzNy4yIDI0Mi45YzEgMCAuMS02LS4zLTcuNS0uNC0xLjYt'
    b'My04LjgtMy04LjhzMyAxMC4zIDIuOCAxMC44Yy0uMy44LTEuNS0zLjEtMS43LTMtLjIgMCAy'
    b'LjIgNi45IDEuMyA3LS44IDAtMS4zLTEuNS0xLjMtMS41bC4xIDEuNXMuNiAxLjQgMi4xIDEu'
    b'NXoiLz4KICA8cGF0aCBmaWxsPSIjOTA0NzIwIiBkPSJNMzM4LjUgMjM5LjljLjcgMC0uMi01'
    b'LjctLjctOC4ybC0yLTcuNXMxLjUgMy41IDIuMyA3LjVjLjggNCAxLjQgOSAuNiA5LjItLjgg'
    b'MC0xLjItLjgtMS4yLS44di0uOXMuMy43IDEgLjd6Ii8+CiAgPHBhdGggZmlsbD0iIzMxMjMx'
    b'NyIgZD0iTTMyOC44IDI0Ni41YzAgLjQgMCAyLjQtMSAyLjItMS0uMS0yLjktMS45LTMuMy0z'
    b'IDAgMCAyLjIgMi41IDMgMi40LjggMCAuOC0yLjUuNi0zLjIgMC0uNi42IDEuNi42IDEuNnoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZDJhNTY3IiBkPSJNMzM0LjEgMjE5LjVzMS40LjkgMi40LjNh'
    b'NCA0IDAgMCAwIDEuOC0zYzAtLjggMC0xLjUtLjctMi40LS43LS45IDEgLjcgMSAyLjMgMCAx'
    b'LjYgMCA0LjMtMi41IDUtMi41LjUtMS40LS4yLTEuNC0uMmwtLjYtMnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjOGY0NjIwIiBkPSJNMzMyLjEgMjE0LjdzMS42IDIuNiAyLjIgNWMuNyAyLjMuNSAz'
    b'LjIuMiAzLjMtLjQgMC0uNi0uMy0uNy0uOSAwLS42LTEuNy03LjQtMS43LTcuNHoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjMWUyMTIxIiBkPSJtMzA0LjEgMjE4IDEwLjYgMTUuMyAxMy4yLTE1LTgu'
    b'My04LjZ6Ii8+CiAgPHBhdGggZmlsbD0iIzRkMmExNSIgZD0ibTMxNy41IDIwOC41LS42IDIu'
    b'NCAxLjMgNC4xIDIuMiAyLjMgMi41IDEuNy42LTIgLjYtMi4yLjctLjIgMS42LjYgMS0xLjUg'
    b'MS44LTMuMS0uNC0xLjItLjQtLjktMi43LTQuNi0uOSAxLjctLjguNS0xLjYtLjgtMS44IDIu'
    b'NC0yLjMtMXoiLz4KICA8cGF0aCBmaWxsPSIjNWMzODE4IiBkPSJNMzIzIDIxOXMuNC0uMy42'
    b'LTEuNmMuMi0xLjIuMi00LjktLjEtNi40LS4zLTEuNS0xLjMtNC40LTEuNS00LjItLjIuMyAx'
    b'LjUgMy4zIDEuMyA3LS4zIDMuNi0uMiA0LjYtMSA1LS43LjMuNi4yLjYuMnoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjNWMzODE4IiBkPSJNMzIzLjYgMjEyLjhzMS43IDIuNSAyLjUgMS42Yy45LS45'
    b'LjUtNCAwLTUuM2wtMS4yLTMgLjUtLjYuOSAzLjRjLjMgMS40IDEuMyA1LjIuMSA2LTEuMS42'
    b'LTIuOC0xLjUtMi44LTEuNXYtLjZ6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIgZD0iTTMx'
    b'Ny45IDIxNC42cy42LTEgMS40LTFjLjggMCAxIC4zIDEgLjNsLjYgMiAxLjIgMi4yIDEgMS0u'
    b'NS42LS45LjItMi41LTEuNC0uNy0xLS42LTN6Ii8+CiAgPHBhdGggZmlsbD0iI2QyYTU2NyIg'
    b'ZD0iTTMyMiAyMzYuM2MtLjguNS0yLjctLjUtMy43LTEuNGwtNi44LTYuNy0uOC0zLjIgMi4y'
    b'LjYgMy45LTEuNy43LTEuMyA0LjYtMi40IDIuNi0xLjQgNS41LS4xIDEuNC0yLjdzMS44IDMu'
    b'MiAyLjEgNC41Yy40IDEuNC4zIDUuNC0uMiA1LjctLjUuMy0yLjMtMS4yLTIuNi0xLjMtLjIt'
    b'LjEgMS40IDUuNyAwIDYtMS4zLjItMy42LTIuMi0zLjYtMi4yczEgNS4yLS4yIDUuMmExMCAx'
    b'MCAwIDAgMS01LTIuNnMxLjMgNC4zIDAgNXoiLz4KICA8cGF0aCBmaWxsPSIjOGY0NjIwIiBk'
    b'PSJtMzIxIDIyOS42IDEuMSAxLjdjLjMuNCAwIDIuOS0uMiAzLjQtLjMuOS0xLjYtMS4yLTIu'
    b'My0zbC0yLjItMy44YzAtLjQgMy41IDEuNyAzLjUgMS43em0xMC44LTEyLjlzMiA4LjEgMSA4'
    b'LjRjLTEgLjMtMy42LTIuNi00LTNsLTQtNi40LS44LS44LjItLjQgMS43LjYgNiAxLjZ6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIgZD0iTTMxNy45IDIzMi4zYy0uNC4zLTEuMy0xLTEu'
    b'Ny0xLjRsLTMtMy4zYTExLjUgMTEuNSAwIDAgMS0yLjItMi41YzAtLjMtLjgtMS4xLS44LTEu'
    b'MWwuNy0xaC45czUuNCA0LjIgNS43IDVjLjQuNi42IDQuMS40IDQuM3ptOCAwYy0uMi4zLTMu'
    b'Ny0yLjMtNS4yLTQuNC0xLjUtMi4yLTMtNC0zLjUtNWwtLjYtMS45IDEgLjJzOC44IDEwLjgg'
    b'OC40IDExLjJ6bTEuMy0zLjdjLS4yLjMtMS43LS45LTIuNy0yLjEtMS0xLjMtLjQtMi45LS40'
    b'LTIuOXMzLjMgNC44IDMuMSA1em0yLS41Yy0uNS4zLTIuNS0yLjItNC4yLTUtMS4zLTItMS42'
    b'LTIuMy0xLjgtMi41LS41LS4zLTEuNC0uNC0xLjQtLjRsLS4yLS4zIDEtLjIuNi0uOCAxLTEu'
    b'MyA0LjMgOC41czEgMS45LjcgMnoiLz4KICA8cGF0aCBmaWxsPSIjYWI2ZDI5IiBkPSJNMzE4'
    b'LjMgMjM0LjljMCAuMyAwIC42LTEuMi41YTIxIDIxIDAgMCAxLTkuOS03LjhsLTMtNSAxLjEt'
    b'MS40IDkuNiAxMSAzLjQgMi43eiIvPgogIDxwYXRoIGZpbGw9IiM4ZjQ2MjAiIGQ9Ik0zMTgu'
    b'MyAyMzQuOWMwIC41LS41LjYtMS4xLjUtLjYtLjItMy0xLTYuOS01LjNhMzMuMyAzMy4zIDAg'
    b'MCAxLTUuMy03LjRsLS4yLTEuOCAxLjItLjUgNi41IDEwIDUuOCA0LjV6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzRkMmExNSIgZD0iTTMyNC42IDIzMC42cy0yLTEuNS0zLjItM2EyNCAyNCAwIDAg'
    b'MS0zLjgtNS43Yy4xLS43IDEuMi0uNyAxLjItLjd2LTEuOGwuMi0uNiAxLjkuOCAyLjMgMi45'
    b'LjkgMS4xczEuNSAzLjcgMS4yIDRjLS4zLjMtMi40LTItMi43LTEuNy0uMy4zIDIuNCA0LjQg'
    b'MiA0Ljd6bS0zLjctMXMuNyAxIC40IDEuN2MtLjMuNy0uNSAxLTEuNS0uNGExNiAxNiAwIDAg'
    b'MC0yLjMtM2MwIC4xLjEgMi4zLS4zIDIuMy0uNSAwLTItMS45LTMtMy4zbC0yLjUtMy45di0y'
    b'bC0uMS0yLjUuMy45LjQuNyAzLjYgNC4yIDEtLjcgMi4xIDQgMiAyem0tMTMuNS02LjFzMi44'
    b'IDQuOCA1LjMgNy41YTE3LjQgMTcuNCAwIDAgMCA1LjYgMy45bC04LjQtOS45LTIuNS0xLjV6'
    b'bTIxLjIgMi44YTEyIDEyIDAgMCAxLTMtMy40Yy0xLTEuNi0xLjktNC0xLjgtNSAwLTEgLjQt'
    b'My40LjQtMy40czIuOCAzIDMuNCA0LjNjLjUgMS40IDEuNyAzLjMgMS40IDMuNS0uMi4yLTIu'
    b'MS0xLjMtMi40LTEtLjIuNCAyLjMgNC44IDIgNXptMy4yLTNjLS4zLjEtMS44LTEuNi0yLjEt'
    b'Mi42YTE0LjggMTQuOCAwIDAgMS0uNi0zLjJsLTEuMi0zdi0zLjNsMS40LS4yIDEuOSAyLjdz'
    b'LjcgMS41LjcgMy43YzAgMi4zLjMgNS42IDAgNS44em0tMjIuNSA4YTQxLjggNDEuOCAwIDAg'
    b'MS00LTZsLTEtMi45LjUuNHMuOCAzLjIgNC43IDcuMWM0IDQgNC45IDQuMiA0LjkgNC4ycy43'
    b'IDIuMi40IDNjMCAwLTIuOS0yLjYtNS41LTUuN3oiLz4KICA8cGF0aCBmaWxsPSIjMjAyMDIw'
    b'IiBkPSJNMzEzLjYgMjM1LjlzLTMuNC0zLTYtNi40YTQ2LjYgNDYuNiAwIDAgMS00LjQtNi42'
    b'bDEuMi0xYTQ2LjMgNDYuMyAwIDAgMCA5LjIgMTR6bTQuNy0xLTYtNi4xYy0yLTIuMi0zLTQu'
    b'NC0zLTQuNGwxLjYuNnMuNyAxLjcgMiAzLjVsNS40IDYuNHptLS44LTdzLTIuMS0yLjYtMy4x'
    b'LTQuMmwtMi0zLjhzMi44IDMuMyAzLjYgMy41Yy45LjIuOSAwIC45IDBzLS40IDEuMi0uMSAy'
    b'LjJsLjcgMi4zem0uOS0xMC42cy4zIDEuOS4xIDNjLS4yIDEtLjggMS0uOCAxYTE1LjcgMTUu'
    b'NyAwIDAgMCA0IDRsLTEuOC0yLjdjLS41LTEtMS4zLTItMS0yLjguNC0xIDIuMS42IDIuNiAx'
    b'bDIuNiAyLjhzLS44LTIuNS0xLjgtMy40YTUzLjYgNTMuNiAwIDAgMC00LTIuOXoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjMjAyMDIwIiBkPSJtMzI3IDIyMi44LTEuNy00LjItMS42LTUuMnYyLjhj'
    b'LS4xIDEuMi0uNSAzLTEgMy4zLS42LjItLjcuMy0xLjcgMC0xLS4yLjcuNS43LjVzMSAwIDEu'
    b'NC0uNWMuNC0uNS41LTEuNSAxLTEuNC40LjIgMSAxLjcgMS4zIDIuNGwxLjYgMi4zeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiMyMDIwMjAiIGQ9Ik0zMjMuNyAyMTMuNHMyIDIuMyAzIDEuM2MuOC0x'
    b'IC4zLTQgLjMtNHMxLjIuNSAxLjYuMmMuNC0uNC4yLTEuNS4yLTEuNXMyLjMgMy4yIDMuMyA1'
    b'LjNjMS4xIDIgMS42IDUuOCAxLjYgNS44cy0xLjgtMy0yLjctNS44Yy0uOS0yLjYtMi4xLTMu'
    b'OC0yLjMtMy41YTUuMyA1LjMgMCAwIDAtLjMgM2MuMiAxIDEgMi4xIDEuNSAzLjVsMS4xIDMu'
    b'NC0xLjYtMi41Yy0uNy0uOC0xLjMtMS4yLTEuNy0xLjYtLjQtLjQtMS0xLjItMS43LTEuNC0u'
    b'Ni0uMy0xLjgtLjktMS44LS40cy0uMy0xLS4zLTFsLS4yLS44eiIvPgogIDxwYXRoIGZpbGw9'
    b'IiMxNzE3MTciIGQ9Ik0zMTYuOCAyMjMuM2EyNyAyNyAwIDAgMCA0LjIgNi4zcy0yLTEuOC0y'
    b'LjgtM2ExNS41IDE1LjUgMCAwIDEtMS40LTMuM3oiLz4KICA8cGF0aCBmaWxsPSIjOGY0NjIw'
    b'IiBkPSJNMzMwLjIgMjIzLjljLS4zIDAtMS4zLS4zLTEuNCAwIDAgLjQuNiAxLjggMS4zIDIu'
    b'NS43LjcgMSAuNyAxLjEuNi4yIDAgMC0uNy0uMi0xLjR2LTEuN2MtLjEtLjMtLjggMC0uOCAw'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNkMmE1NjciIGQ9Im0zMDYgMjA5LjQtMS4zLjctMS40IDMg'
    b'LjQgNS4zIDIuMSAzYy44IDEuMiAzLjUgNC4yIDQuMiA0IC43LS4yIDEuNC0yLjMgMS41LTMu'
    b'NGwuMi0zLjIgMS44IDIuM2MxLjEgMS4zIDIgMi40IDIuNiAyLjMuNSAwIDItMy4yIDItMy42'
    b'LjEtLjQtMy44LTEwLTMuOC0xMGwtMS44LTEtNi42LjZ6Ii8+CiAgPHBhdGggZmlsbD0iI2Fi'
    b'NmQyOSIgZD0ibTMxNC44IDIxNy40IDEgMy43Yy41IDEuMiAwIDIuMy4zIDIuMy4yIDAgMi4z'
    b'LTIuNyAyLjMtNCAwLTEuMiAwLTIuNS0uNS02LjNzLjItNSAuMi01bC0xLjItMS0yIDQuMi0u'
    b'MSA2LjF6bS03LTIuMi43IDVjLjMgMS4yIDEgMy4zIDEuNCAzLjIuNCAwIDEuNi0zLjMgMS43'
    b'LTQuNCAwIDAtLjktMS42LS44LTUuNSAwLTQtLjQtNC40LS40LTQuNGwtMi42IDYuMXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjNDUzOTJkIiBkPSJNMzAyLjUgMjA3LjVzLTMuMSA0LjYtMyA3YzAg'
    b'Mi41LjQgMiAxLjEgNC4yLjcgMi4zIDEuMSA1LjYgMS4yIDUuOSAwIC4yLjUtLjIuNS0uNWwu'
    b'Mi0xNi42eiIvPgogIDxwYXRoIGZpbGw9IiNhYjZkMjkiIGQ9Ik0zMDIuNSAyMDhzLTIuNyA0'
    b'LjMtMi41IDYuNmMuMiAyLjMuNSAyLjMgMS4zIDQuNC44IDIgLjggNS40LjggNS40czEtLjIg'
    b'MS45LS45YzEtLjcgMS44LTIuMSAxLjgtMi4xbC0xLTIuMWE4IDggMCAwIDEtLjYtMmwtLjgt'
    b'MSAuMi00LjEuNy0zdi0xbC0xLjgtLjF6Ii8+CiAgPHBhdGggZmlsbD0iI2RiYWQ2YyIgZD0i'
    b'TTMxNy4yIDIxNS4zcy0xLjMtLjMtMS45LS42Yy0uNi0uMy0uOC0xLjEtLjgtMS4xbC40LS44'
    b'IDIuMyAyLjV6Ii8+CiAgPHBhdGggZmlsbD0iI2QyYTU2NyIgZD0iTTMwMyAyMDguNXMtMiA0'
    b'LjMtMS43IDcuMiAxLjkgNi42IDIgNi43Yy4yIDAgMC0uMy4xLTF2LTguN2wuOS0yLjh2LTEu'
    b'NWwtMS4zLjF6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIgZD0iTTMwNy44IDIwOS41cy4z'
    b'IDEuMi4xIDEuOGMtLjIuNS0xLjIgMS4yLTEuNiAyLS41LjgtMSAyLjgtMSAyLjhzLjQtMS4x'
    b'IDEtMS44Yy43LS43IDEtMS4yIDEtLjguMi40LjQgMiAuMyAyLjMtLjEuMy0uNy44LTEgMi0u'
    b'NCAxLjMgMCAyLjQgMCAyLjRsLjUtMi4yYy4yLS42LjctMSAuNy0xbDEgMi40czAtMS4xLjMt'
    b'MmMuMS0uOCAxLTIgMS4zLTIgLjMgMCAuOC0uMS0uMy0uNy0uNC0uMi0uMS00LjIuMS00LjQu'
    b'My0uMiAxLjktLjIgMS43LS44YTExIDExIDAgMCAwLTEuNi0yLjJjLS4xLS4xLTIuNSAyLjIt'
    b'Mi41IDIuMnoiLz4KICA8cGF0aCBmaWxsPSIjZGJhZDZjIiBkPSJtMzE3IDIxOC4xLTEuNS0u'
    b'M2MtLjUgMC0uNi0uNi0uNi0uNmwuMi0uNiAxLjIuNy43Ljh6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzhmNDYyMCIgZD0iTTMwNC40IDIxOC42YzAgLjQtLjMuOS0uNSAxLjUtLjMuNy0uNCAxLjYt'
    b'LjQgMS42bC0uNC0zLjMtLjMtMi40Yy0uMiAwLS43LjctLjcuN3MwLTEuNi4zLTIuM2MuMy0u'
    b'Ny41LTEuOC4zLTItLjMtLjEtLjguMy0xIC43YTMwLjggMzAuOCAwIDAgMC0uOCAxLjNzLjMt'
    b'MS4zLjYtMS45Yy4zLS41IDEuOC0yLjIgMi0yLjguNC0uNy40LTEuNC40LTEuNGgxczEgLjgg'
    b'MSAxLjVjMCAuNC0xIC45LTEgMSAwIDAtLjgtLjEtMSAzLjItLjIgMy40LjYgMy4yLjUgNC42'
    b'em05LjQtOC43cy4yIDEuOCAwIDIuNGMtLjIuNi0uNyAxLTEuMSAxLjgtLjQuNy0uNCAyLjQt'
    b'LjQgMi40bC41LTEuNC43LTFjLjEgMCAuNi43LjggMS43bC44IDIuNXMtLjItMS4yLjEtMS4y'
    b'LjUtLjEuOS4ybC45LjhzMC0uNS0uNy0xLjFjLS42LS43LTEtLjYtMS4xLTEuNS0uMi0xLS4z'
    b'LTEuOC0uMi0yLjIgMC0uMy41LjMuOS43bDEuNSAxLjQtLjctMXYtM2MwLTEgMC0xLjkuNC0y'
    b'LjEuMy0uMy40LTEuNi4yLTEuOC0uMS0uMi0zLjUgMi40LTMuNSAyLjR6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzFlMjEyMSIgZD0iTTMyNC42IDIwNi4xYTIzLjcgMjMuNyAwIDAgMCAxLjUgNy4x'
    b'cy0xLTItMS42LTMuNi0uOS0zLjUtMS4zLTMuNmMtLjQtLjItMSAuOC0xIDEuNXMuNSAzLjMg'
    b'MS4xIDQuMmMuNiAxLTEtMS4yLTEuMy0yLjNsLS43LTIuMnMtLjQgMS0uMyAyYy4yIDEuMSAx'
    b'LjEgMi43IDEuMSAyLjdsLTEtMS0uNi0uN3MwIDEuNS40IDIuMWwxLjIgMS43LTEuMy0xLS40'
    b'LS44cy4yIDIuMS42IDMuM2wxLjUgM3MtMS4yLTEtMi0yLjljLS44LTEuOC0xLjItNy4zLTEt'
    b'OC4xbDEuMS0xLjljLjYtLjggMS4zLTQuNyAxLjMtNC43cy45IDMuNiAxLjUgNC4zYy42Ljcg'
    b'MS4yIDEgMS4yIDF6bS04LjYtMSAuOCAxLjMuNiAxcy0xIDEuMS0yLjMgMmMtMS4yIDEtMi44'
    b'IDItMy4xIDEuNS0uNC0uNS0uNC0xLS40LTFzMS40LS44IDIuNC0xLjhhNi42IDYuNiAwIDAg'
    b'MCAxLjYtMi4yYy4yLS42LjUtLjkuNS0uOXptLTEwLjkgMy41cy4yIDIuMiAxLjIgMi4yYy45'
    b'IDAgMy43LTIuOSAzLjktMyAuMi0uMS40LS44LjQtMWwtLjItLjhzLTMgMy00IDMuMmMtLjkg'
    b'MC0xLjMtLjYtMS4zLS42em0uMS0zLS4zIDJjMCAuNS4yLjkuMi45cy0yLjIuNy0yLjUgMGMt'
    b'LjQtLjYtLjEtMS42LS4xLTEuNmgxLjVjLjYtLjIgMS4yLTEuMyAxLjItMS4zem0yMC4zLTMu'
    b'MSAxLjUgMy4yIDEuNCAyLjhzLTEuNC0xLjctMS45LTJsLTEuMi0xIC4yLTEuMXYtMnoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZGJhZDZjIiBkPSJNMzAyLjEgMjA3aDEuM2MuNSAwIC44LS4yLjgt'
    b'LjJsLjktMS4ycy0uNSAxLjQtLjIgMi41Yy4zIDEgMSAxLjEgMS4yIDEuMWE0IDQgMCAwIDAg'
    b'Mi4yLTEuMWMuOS0xIDIuMS0xLjkgMi4xLTEuOXMtLjMgMS4zLjIgMi43Yy41IDEuMyAxLjIg'
    b'MS4zIDIuMi40IDEtLjggMi0yLjIgMi42LTIuOGwuNy0xIDEuMS0xIDEtNS40LS41LS43LTEu'
    b'NC43LTEuNy0uNy0uNS0uNy0xIDEuNy0xIC42LS41LjEtMS4yLjMtLjUtMS4xLS4zLS44LS42'
    b'LS4zLTIuNCAyLjUtMS40LS4xLTEuMyAyLjItMSAxLjMtMSAyLjQuMi41eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM4ZjQ2MjAiIGQ9Ik0zMTMuOSAyMDEuNXMuMiAxLjMtLjUgMy42LTEuNiAzLjkt'
    b'MS42IDMuOSAyLjQtMS41IDMuNi00LjJjMS4xLTIuNi45LTUuNy45LTUuN2wtMi40IDIuNHpt'
    b'My0yLjVzLjIuNCAwIDIuNGwtLjggNCAuNiAxLjJjLjQuNyAxLjIgMS44IDEuNyAxLjYuNi0u'
    b'MiAxLjYtLjkgMi4yLTIuMi42LTEuNCAxLjEtMi43IDEuNC0yLjkuMi0uMi4zLjEuNC4yIDAg'
    b'LjEuMyAxLjMuOSAxLjguNS41IDEuMyAxLjMgMS42IDEgLjQtLjIuOC0uOS43LTEuMmwtMS4z'
    b'LTQtMS42LTQtMS0xLjYtMi44LjMtMiAzLjR6Ii8+CiAgPHBhdGggZmlsbD0iI2FiNmQyOSIg'
    b'ZD0iTTMyMS43IDE5NS4zcy44IDEuNy45IDMuNmMwIDEuOC0uNCAzLjgtLjQgMy44cy4yLTIu'
    b'MyAwLTMuN2MtLjMtMS40LS43LTIuMy0uNy0yLjdsLjItMXoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'NGQyYTE1IiBkPSJNMzI1LjYgMjAyLjZ2Mi4zYy0uMi44LTEuMy0uNS0yLTMtLjYtMi41LS41'
    b'LTMtMS00LjNsLS45LTIuMiAxLjUtLjMgMi40IDcuNXptLTcgNC42czIuOC0xLjUgMy4xLTYu'
    b'MmMuMi0yLjEtMS4yLTUuNy0xLjItNS43czAgMy44LTEgNi4yYTYwLjkgNjAuOSAwIDAgMS0x'
    b'LjkgNHMuNy0uMiAxLS42bC44LTEuMXMuMS43LS4xIDEuNmwtLjYgMS44em0tMi4zLTguMXMt'
    b'LjEgMS0xLjMgMmMtMSAuOS0zLjEgMS45LTMuMSAxLjlzMS41LTEuNCAyLTIuNmMuNi0xLjIu'
    b'MS0yIC4xLTJzLS4yLjYtLjggMS4xYy0uNi41LTEuNi42LTEuNi42czAtLjYuNy0xLjNjMC0u'
    b'MSAwLS40LjItLjcuMy0xIDEuMS0yLjMgMS4xLTIuM3MuNyAxLjQgMS4zIDJsMS40IDEuM3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjMWUyMTIxIiBkPSJNMzI0LjcgMTkzLjZhMTcuNiAxNy42IDAg'
    b'MCAwIC45IDlzLTEuNC0yLjItMS43LTNjLS40LTEtLjQtMi4zLS43LTNhMy4yIDMuMiAwIDAg'
    b'MC0xLTFjLS4zLS4yLTEtLjEtMS0uMXMuOC0uNC44LTEuMXYtMWwxLjQuM2gxLjN6bS02IDku'
    b'OHMxLjQtMiAxLjgtNC42Yy40LTIuNiAwLTMuNSAwLTMuNXMtLjYgMC0xLjEtLjVjLS41LS41'
    b'LTEuMy0xLjgtMS4zLTEuOHMuMiAxLjQgMCAzYy0uNCAxLjYtMS44IDMtMS44IDNzLjguNCAx'
    b'LjQgMGMxLjUtLjkgMS40LTIuNSAxLjQtMi41cy4zLjIuMyAyLjItLjcgNC43LS43IDQuN3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjOGY0NjIwIiBkPSJNMzAxLjIgMjA2LjljLS4zIDAgMS0yIDEu'
    b'OC0zLjRsMi4xLTMuNHMuMy4zLjguM2EzLjYgMy42IDAgMCAwIDIuNC0xLjcgNyA3IDAgMCAw'
    b'IDEtMi41YzAtLjMtLjEgMS44IDEgMyAxIDEuMS45IDEgMS4zIDEgMCAwIDAgMS40LS40IDIu'
    b'N2wtLjggMy4zcy4yLTIuNS0uMy0zLjJjLS40LS44LS42IDAtMSAxLS4zLjktMS4xIDEuNS0x'
    b'LjEgMS41cy42LTEuMSAxLTIuM2MuNC0xLjIuMi0xLjIgMC0xLjIgMCAwLS4yLS4xLS42LjQt'
    b'LjUuNS0uOS42LS45LjZzLjUtLjQuNy0xYTYgNiAwIDAgMSAxLTEuOGMuMi0uMy40LS43LjQt'
    b'MSAwLS4yIDAtLjctLjItLjdzLS41LjMtMS40IDEuMmwtMS4zIDEuMy0uOSAyLjZhMTcgMTcg'
    b'MCAwIDEtMSAyLjhsLS42LjQuOS0yLjQgMS0zLjRjLS4yLS4zLS43LS4zLS44IDBsLTIgMi44'
    b'Yy0xIDEuNC0xIDMuMS0xLjIgMy4ybC0xLS4xeiIvPgogIDxwYXRoIGZpbGw9IiM4NzRmMjAi'
    b'IGQ9Ik0zMjUuNyAxOTIuMWMwIC4yIDAgMS4yLTEgMS41YTMuNSAzLjUgMCAwIDEtMi4zLS4y'
    b'Yy0uMiAwLS4yLTEuNC0uMi0xLjRsMy41LjF6Ii8+CiAgPHBhdGggZmlsbD0iI2IyNzEyOSIg'
    b'ZD0iTTMwNiAxOTUuNHMtLjIuOS0uOCAyYy0uNSAxLjItMS40IDIuMi0xLjMgMi40IDAgLjEu'
    b'Ni43IDEuNC42LjggMCAxLjEtNC44IDEuMS00LjhsLS4xLS4yaC0uM3oiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZGJhZDZjIiBkPSJNMzE4LjQgMTkyLjdzLS4zIDYuNC0yLjEgNi40LTIuNy0zLjIt'
    b'Mi43LTMuMi0uMSA0LjMtMi40IDQuM2MtMSAwLTIuMS0zLjQtMS45LTQgMCAwLS40IDIuMy0x'
    b'LjUgMy4yLTIuMiAxLjctMy41LjktMy42LjYgMC0uMyAxLjgtMiAyLTQuNiAwIDAgLjQuMSAx'
    b'LS42cy43LTEuNiAxLjMtMS41Yy41LjIgMy0xIDMtMWwxLjQtMS43cy4yLjUgMS4yLS4yYTMu'
    b'NiAzLjYgMCAwIDAgMS4zLTEuN2wyLjcgMi4zLjMgMS43eiIvPgogIDxwYXRoIGZpbGw9IiNi'
    b'MjcxMjkiIGQ9Im0zMTEuNCAxODYuNiAyLjcgMy44LjYtLjVjLjQuNS42LjkuNCAxLjItLjQg'
    b'MS0xLjMgMi4zLS41IDMuNyAwIDAtLjMtLjguMS0xLjhzLjctMS40IDEtMS4zYy4yIDAgLjYg'
    b'NS44IDEgNS44LjMgMCAuOS0yLjcuOS00LjUgMC0xLjguMy0uMy41IDAgLjIuNCAxLjggMyAz'
    b'LjEgMi42IDEuNC0uNCAxLjItMi44IDEuMi0zLjMgMC0uNi0xLTMuNy0xLTMuN2wtNi4xLTMu'
    b'OS0uNSAxLjZjLS4zIDEtMy40LjMtMy40LjN6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIg'
    b'ZD0iTTMyMCAxODZzLjQuNCAxIDEuOS43IDYuNC0uMSA2LjRjLS44IDAtMi4zLTEtMi42LTEu'
    b'Ni0uMy0uNyAwLTMuMS0uNC0zLjhhOC4xIDguMSAwIDAgMS0xLjItMi43bC4xLTIgMS40LS41'
    b'IDEuOSAyLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzRkMmExNSIgZD0ibTMxOS42IDE4NC41IDIu'
    b'NiAzLjkgMi4zIDMuMyAxLjIuNGEyLjUgMi41IDAgMCAxLTMuMi41Yy0uOS0uNS0uNC0yLTEu'
    b'NS00LjUtMS4yLTIuNS0zLjItMy42LTMuMi0zLjZsLjctLjcgMS4xLjd6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzFlMjEyMSIgZD0iTTMxOC4yIDE4Mi40czIuMyAxLjUgMy4xIDMuMmMuOSAxLjcg'
    b'MS4zIDIuNyAyLjMgNC4zIDEgMS42IDIuMSAyLjEgMiAyLjIgMCAuMS0uNy4zLTEuMiAwYTQu'
    b'NyA0LjcgMCAwIDEtMS40LTEuNiAzNSAzNSAwIDAgMC0yLjQtNC4yYy0uNS0uNy0yLjMtMi0y'
    b'LjMtMS45IDAgLjEuNS41IDEuNSAyLjFhNyA3IDAgMCAxIDEuMiAzLjFsLTEuMS0yYy0xLTEu'
    b'NS0yLjgtMy4zLTIuOS0zLS4xLjIgMSAxLjkgMS41IDIuOWwxLjMgMy4zLTEuOC0zYy0xLTEu'
    b'NS0xLjItMS4zLTEuNi0xLjhsLTEuNC0xLjhzMSAuMyAxLjgtLjNjMS0uNiAxLjQtMS41IDEu'
    b'NC0xLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIgZD0iTTMxMi4zIDE4Ni43czEuNS4z'
    b'IDIuMy4yaDEuMXMuNS42LjUgMS40YzAgLjctLjUgMi4xLS44IDIuMi0uMiAwLS4yLTEuMy0u'
    b'NS0xLjhsLTIuNi0yeiIvPgogIDxwYXRoIGZpbGw9IiNiMjcxMjkiIGQ9Ik0zMTMuMSAxOTAu'
    b'NnMuNSAxLjYuMSAzLjljLS40IDIuMi0xLjcgNC42LTIgNC42LS4zIDAtLjItMi42LS40LTRh'
    b'MzguOCAzOC44IDAgMCAwIDAtLjRsLS41IDEuNi40LTIuNi0uMS0uOCAxLjYtMiAuOS0uM3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjOGY0NjIwIiBkPSJNMzEwLjMgMTkyLjNjLS41LjUtMS4yLjQt'
    b'MS44LjYtLjYuMi0uOSAxLS45IDFzLjUtLjMuNy0uMmMuMy4xLjUuMS4xIDEuMi0uNSAxLjEt'
    b'Mi4yIDMtMi4xIDMgMCAwIDItMS41IDIuNS0yLjUuNy0uOS42LTEuNC44LTEuOCAwLS4zLjgt'
    b'LjcgMS0uNy4xIDAgLjUgMCAuNi43bC42IDIuNi44LTIuNmMuMi0xIC4yLTIuOS4yLTIuOWwt'
    b'LjYtLjFjLS41LS4xLTEuNS0xLTEuNS0xcy4yIDItLjUgMi43eiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNkYmFkNmMiIGQ9Ik0zMTguMyAxODAuOHMuNiAxLjUtLjcgMi42Yy0uNC4zLS43LjUtMS40'
    b'LjZhNC41IDQuNSAwIDAgMS0xLjctLjZsLTQtMS42LTItLjYtMS0uMy4yLTEuMWgzbDMgMS4y'
    b'IDEuMy41IDEuMS4yaC45bC43LS4yLjQtLjMuMi0uNHoiLz4KICA8cGF0aCBmaWxsPSIjYWI2'
    b'ZDI5IiBkPSJNMzE4LjMgMTgwLjhjMCAuMy0uMyAxLjEtLjYgMS4zLS4zIDAtLjguMy0yIDAt'
    b'MS4xLS4yLTIuMy0xLTMuNi0xLjMtMS4zLS40LTIuMy0uNy0zLjMtLjdzLS41LS40LS41LS40'
    b'IDIuMy0uMyA0LjMuNWMyIC43IDIuOSAxLjIgNCAxLjIgMS40IDAgMS43LS42IDEuNy0uNnoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjNGQyYTE1IiBkPSJNMzA3LjYgMTc5LjZoLjljLjQgMCAuNy0u'
    b'My43LS4zczAgLjUtLjIuN2MtLjMuMi0xIC4xLTEuMi4xbC0uMi0uNXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZGJhZDZjIiBkPSJNMzE1LjMgMTg0LjRzMS4zIDEuMyAxIDIuNGwtMi43LTEuMi00'
    b'LjItMS43LTIuMy0uNy0uMy0uNC42LS44LjItLjggMi44LjQgMyAxIDEuOSAxLjh6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2RiYWQ2YyIgZD0iTTMxMi40IDE4Ni4zczIuNCAzLjEgMS44IDQuMWwt'
    b'NS42LTMuNS0yIDMuMy00LjctMi4zczMuOC0zIDQuMi0zLjVsLjUtLjcgMiAuNCAzLjQgMSAu'
    b'NCAxLjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2FiNmQyOSIgZD0iTTMxMSAxODEuNnMyIC41IDMu'
    b'MyAxLjJjMS4zLjYgMyAuOCAzIC44cy0uNi43LTIgLjhjLS40IDAtMS40LS44LTItMS4zLS43'
    b'LS40LTIuNi0xLTIuNi0xbC4zLS41eiIvPgogIDxwYXRoIGZpbGw9IiM0ZDJhMTUiIGQ9Ik0z'
    b'MDcuNiAxODAuNnMxLjQuMyAyLjIuN2MxIC4zIDEgLjIgMS4yLjEuMyAwIC4zLS4yLjMtLjJz'
    b'LjIgMS0uNSAxLTEtLjMtMS44LS43Yy0xLS40LTEuNSAwLTEuNSAwdi0xeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNhYjZkMjkiIGQ9Ik0zMTUuNCAxODZzMSAuNy45LjljLS4yIDAtLjcuMy0xLjYu'
    b'NGEzLjQgMy40IDAgMCAxLTItLjRjLS42LS4yLTEtMS4zLTIuNS0yYTE4IDE4IDAgMCAwLTIu'
    b'OC0uOWwtMS4zLS4yIDEtLjQgMy4yLjYgMi44LjkgMS43LjguNi40em0tNS40IDIgLjYgMi42'
    b'LS40IDEuNS0uOC42LS44LS4zLS4zLS41cy40LS42IDAtMS4xYy0uMy0uNi0yLTEuMi0yLTEu'
    b'MnMuNy0xLjMgMS40LTEuNmMuOC0uMy40LTEuMi40LTEuMmwxLjkgMS4yeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiM0ZDJhMTUiIGQ9Ik0zMDYuOCAxODIuOHMuNS40IDEuNS41Yy41IDAgMS4zLjIg'
    b'Mi4yLjVsMS0uMy0uNS40Yy45LjIgMiAuNyAyLjUuOWE1LjggNS44IDAgMCAxIDIgMS4zbC0y'
    b'LTFhMTcuNCAxNy40IDAgMCAwLTMtLjljLTItLjMtNC0uMi00LjMtLjQtLjQgMCAuMS0uMS40'
    b'LS4zLjItLjIuMi0uNy4yLS43eiIvPgogIDxwYXRoIGZpbGw9IiNhYjZkMjkiIGQ9Ik0zMTQg'
    b'MTg5LjhzLjcuNyAwIC45Yy0uNi4yLTIuNC4yLTMuMi0uN2wtLjYtMS4yYTE0IDE0IDAgMCAw'
    b'LTIuNC0xLjdjLS43LS41LjMtLjUuMy0uNWwzLjYgMS41YTEzIDEzIDAgMCAxIDIuMyAxLjd6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iIzRkMmExNSIgZD0iTTMxNCAxODkuOXMtMS4yLTEuOC00Ljkt'
    b'My4zbDEuMi0uMmgtMmEyNCAyNCAwIDAgMC0uOC0uM2MtMi0uNi0yLS42LTIuMi0uOC0uMS0u'
    b'My0uNCAwLS42LjNsLS43IDFhNSA1IDAgMCAxIDIuNS0uMWMxLjEuMyAxIC43IDEgMS0uMS41'
    b'LTEuNCAyLTEuMyAyLjEuMiAwIDEtMS41IDItMS4zIDEgLjMgMS4yLjggMS4yLjhzMC0uNi0u'
    b'Mi0uOGMtLjItLjItMS4zLTEuMy0xLTEuMy4zIDAgMS42LjMgMy4zIDEuMiAxLjguOSAyIDEu'
    b'MSAyLjYgMS43eiIvPgogIDxwYXRoIGZpbGw9IiNkYmFkNmMiIGQ9Ik0zMDguMSAxODdzMi44'
    b'LjggMi43IDMuOGMtLjEgMy0yLjMgMi40LTIuNSAxLjMtLjItMSAuMy41IDEgLjQuOS0uMiAx'
    b'LTEgMS0yLjIgMC0xLS4zLTEuNi0xLTIuMmExMiAxMiAwIDAgMC0xLjItMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjNmMzZjE4IiBkPSJNMjk2IDE3OS45cy40LjItLjQgMi4zYy0uOCAyLjEtMS4z'
    b'IDIuOC0yLjUgNC4yLTIuMiAyLjQtMy4yIDIuNS0zIDMuNS4zIDEgMS4xLjggMS4zLjguMiAw'
    b'IDQuMy02IDQuMy02bC45LTMuNS0uMi0xLS4zLS4zeiIvPgogIDxwYXRoIGZpbGw9IiNkYmFk'
    b'NmMiIGQ9Ik0zMDYuMSAxNzUuNnMxLjIgMS44LjggNWMtLjMgMy40LTQuNyA2LjMtNC43IDYu'
    b'M2wtNi40IDQuNC0yLjctLjJoLS44Yy0uNC0uMS0uOC0uNS0uOS0uNWwtLjUtMS4yLjktMSAy'
    b'LjMtMi4zIDEuNC0ycy43LTEuMy44LTIuNWMwLTEuMS0uMi0xLjctLjItMS43bC41LjguMyAx'
    b'LjgtLjIgMiAxLjYtMS4yIDIuMi0xcy43IDAgMS0xLjNjLjUtMS4yLjktMyAuOS0zLjhsLS4x'
    b'LTEuOGguM2MuMiAwIC43IDEuMi43IDEuN2wuNCAyLjggMS0xIDEtMS41Yy4yLS41LjQtMS4z'
    b'LjQtMS44eiIvPgogIDxwYXRoIGZpbGw9IiM5MDQ3MjAiIGQ9Ik0zMDYuOCAxOTIuMnMuNS40'
    b'LjMgMS42Yy0uMiAxLjItMS4xIDEuOC0xLjYgMS44VjE5NGwtMS40LTEuMi0xLjUtLjQuMy0u'
    b'M2MuMS0uMiAxLjctLjggMS43LS44bDIuMi45eiIvPgogIDxwYXRoIGZpbGw9IiNhYjZkMjki'
    b'IGQ9Ik0zMDUuNyAxOTIuMnMuNS40IDEuMi4zYy43LS4yIDEtMS4zLjYtMS44LS40LS40LS4y'
    b'IDEtLjcgMS4zLS40LjEtMS0xLjItMS41LTEuMy0uNy0uMS0xLjYuMy0xLjkuNy0uMi40IDEg'
    b'MCAxIDBsLjcuM2guNWwuMS41eiIvPgogIDxwYXRoIGZpbGw9IiM5MDQ3MjAiIGQ9Ik0yOTYu'
    b'NSAxODcuNnMuOC4zIDEuNy4xbDMuMS0xIDEuOC0xLjNjLjctLjcgMy4xLTIuMiAzLjQtNS4x'
    b'LjItMy0uNC00LjctLjQtNC43czMuNSAzLjguNSA4LjJjLTIgMi44LTMuOCAzLjctMy44IDMu'
    b'N3MzLjQtMSAzLjctLjJjLjMuOC0uMSAyLS4yIDIuMyAwIDAgMS45LjQgMi4yIDEuNC4xLjYt'
    b'Mi4yLS43LTQtLjItMS44LjQtMi41IDEuNC0yLjUgMS40cy0uNC0uNS0yLS41Yy0xLjUgMC0y'
    b'LjIuNy0zLjEuNy0xIDAtMy43LS42LTQuMi0xLjRsMS44LTIuMmMuOC0xLjYgMi0xLjIgMi0x'
    b'LjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2FiNmQyOSIgZD0iTTMwMy44IDE3OS43czEuMy0xLjMg'
    b'MS44LTIuM2MuNC0xIC41LTEuOC41LTEuOHMuMiAxLS42IDIuMy0xLjcgMi0xLjcgMnYtLjJ6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iIzkwNDcyMCIgZD0iTTMwMy40IDE3Ni43czEuMSA0LjQgMCA2'
    b'LjFjLTEuMyAxLjgtNi41IDQuMS02LjUgNC4xczQtMi4xIDUuMi00LjYgMS4xLTQuNSAxLjEt'
    b'NC41bC4yLTF6Ii8+CiAgPHBhdGggZmlsbD0iIzFlMjEyMSIgZD0iTTI5OC4yIDE4Ny43czEu'
    b'NyAwIDIuNi0uNmMxLS41IDIuMy0xLjcgMi4zLTEuN3MtMS4yIDEtMS42IDFjLS4zIDAtLjYt'
    b'LjUtLjUtLjkgMCAwLS4zLjgtMSAxLjQtLjguNS0xLjguOC0xLjguOHptMy45LTUuNHMxLjQt'
    b'MS40IDEuNC00LjRjMC0zLTEuMi0yLjUtMS4yLTIuNXMxIC43LjcgM2MtLjIgMi4zLTEgNC0x'
    b'IDR6bTEuNy4zczEuNi0uMyAyLjEtMS4zLjYtMi43LjYtMi43LS4yIDEuNy0uNyAyLjNjLS40'
    b'LjYtMiAxLjctMiAxLjd6bS0xIDkuNXMuOC0xLjUgMS45LTEuMWMxIC40IDEgMS4yIDEgMS4y'
    b'cy0uNC0uNi0xLjItLjdjLS43IDAtMS42LjYtMS42LjZ6bS0yLjktMi43IDMuNy0xIDMtMXMt'
    b'MS4yIDEuMy0zIDIuM2MtMS42IDEtMyAxLTMgMXMzLjItMS40IDMuNC0yYzAgMC0zIC45LTQg'
    b'Ljd6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI5Ni4yIDE4NS44YTIuNiAyLjcgNjcu'
    b'OCAwIDEtMyA0LjQiLz4KICA8cGF0aCBmaWxsPSIjZjE2ZTE2IiBkPSJNMjk2LjEgMTg2LjFh'
    b'Mi4zIDIuNCA2Ny44IDAgMS0yLjcgMy44Ii8+CiAgPHBhdGggZD0iTTI5NSAxODcuNGExIDEg'
    b'MCAxIDEtLjggMS40Ii8+CiAgPHBhdGggZmlsbD0iI2Q1ZDNjYSIgZD0iTTI5NS4yIDE4OC42'
    b'YS4zLjMgMCAxIDEtLjYtLjEuMy4zIDAgMCAxIC4zLS4zLjMuMyAwIDAgMSAuMy40eiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNhYjZkMjkiIGQ9Ik0yOTYuOCAxODQuMnMxLjYtMS41IDEuOS0zLjVj'
    b'LjMtMiAuMS0zLjIuMS0zLjJsLjkgMSAuMyAxLjQtLjUgMi42IDEuNi0uOGMuNi0uOCAxLjUt'
    b'NC4yIDEuMi02LjMgMCAwIC40IDEtLjIgMy44LS42IDIuOS0xIDMuMi0zLjIgNC40YTkuNiA5'
    b'LjYgMCAwIDAtMy44IDQuMiAxOSAxOSAwIDAgMS0yLjMgM2wxLjYtMi42Yy44LTEuOCAxLjct'
    b'Mi44IDEuNy0yLjhsLjctMS4yeiIvPgogIDxwYXRoIGZpbGw9IiM5MDQ3MjAiIGQ9Ik0yOTYu'
    b'MSAxODUuNHMuNy0yIC43LTMuMS0uNy0yLjQtLjctMi40IDEtLjEgMSAyLjJjLjEgMi40LS40'
    b'IDIuNi0xIDMuM3oiLz4KICA8cGF0aCBmaWxsPSIjNGQyYTE1IiBkPSJNMjk5LjIgMTgyLjhz'
    b'LjctMS43LjctM2MwLTEuMS0xLTIuMy0xLTIuM3MxLjEuMyAxLjIgMi40Yy4xIDIuMi0uMiAy'
    b'LjItMSAzeiIvPgogIDxwYXRoIGZpbGw9IiNhYjZkMjkiIGQ9Ik0yOTIuMSAxOTFzLS42LS44'
    b'LS41LTEuM2MwLS42IDAtLjcgMS40LTIuMmExMyAxMyAwIDAgMCAyLjUtM2MuMy0uOSAxLjUt'
    b'MyAuNi00LjYgMCAwIC42IDIuNC0uOCA0LjNhMTUuNyAxNS43IDAgMCAxLTMuMyAzLjdjLTEu'
    b'MS44LTEuMyAxLjItMS4yIDEuNyAwIC41LjEgMSAuMyAxIC40LjMgMSAuMyAxIC4zeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiM2YzQxMTkiIGQ9Ik0zMDUuNSAxOTUuNnMuMyAwIC41LS4zLjItMS0u'
    b'My0xLjZhMy4zIDMuMyAwIDAgMC0xLjctMS4xbC0yLS40cy40LjggMS4zIDEuM2MuNC4yIDEu'
    b'MiAwIDEuNi40LjUuNC42IDEuNy42IDEuN3oiLz4KICA8cGF0aCBmaWxsPSIjNmM0MTE5IiBk'
    b'PSJNMzA1LjUgMTk1LjZzMS41LS41IDEuNi0ybC0uMS0xLjJzLjIuNS44LjdsLjYtLjJzLTEg'
    b'Mi44LTMgMi43eiIvPgogIDxwYXRoIGZpbGw9IiNiZjgwMmQiIGQ9Im0yOTQuOCAxOTUuMy44'
    b'LjguOSAxIDMuNy0xIDEuMi0xLjItMS0xLjZoLTIuN2wtMyAyeiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNmOWM4M2EiIHN0cm9rZT0iIzhmNDYyMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0ibTMwMy44'
    b'IDE5NC0uNy0uOS0uNy0uNmMtLjYtLjMtMi44LS4zLTIuOC0uM2wtMS42LjNzLS41LjUtMS4z'
    b'LjNhMjIgMjIgMCAwIDEtMi42LTFsLTEuOS0uN3MtMS4zLS42LTEuNi0uNWMtLjMuMS0xLjUg'
    b'MS4zLTEuNSAxLjNzLS4yLjcuMy43Yy40IDAtLjcuMi0uNy4ycy0yLjggMS42LTMuMiA0LjRj'
    b'LS41IDIuNyA0LjYgNi44IDYuNSA0LjcgMCAwLTIuOC0yLTIuMi0zLjcuNS0xLjcgMS44LTIu'
    b'OCA0LTMgMi4xIDAgMi4zLS4zIDMuMi0xIDEtLjYgMi43LTEgNCAuMyAxLjMgMS40LTUgMi43'
    b'LTUgMi43bC43IDFzNy43LTIuNyA3LTQuMXoiLz4KICA8cGF0aCBmaWxsPSIjZmNmM2Q4IiBk'
    b'PSJNMjg5LjQgMjAwLjdzLTMuMS0uOC0yLjktMy43Yy4zLTIuOCAzLTMuOSAzLjQtNCAuNC0u'
    b'Mi4zLTEuNi44LTEuOGEyLjQgMi40IDAgMCAxIDIgLjVsMS40LjhzLTUuNSAyLjQtNS41IDUu'
    b'NmMwIDIuMS44IDIuNS44IDIuNXoiLz4KICA8cGF0aCBmaWxsPSIjZmRlYWFmIiBkPSJNMzAz'
    b'LjggMTkzLjhzLS40LjItLjUgMGMtLjYtMS0yLTEuNC0zLTEuMy0xLjUgMC0yLjQuNS0zLjQu'
    b'NXMtLjctLjEtMS44LS4yYy0xLjEgMC0zLjUtMS44LTQtMS42LS42LjItLjguOC0uOCAxLjEu'
    b'MS40LTEgLjQtMSAuMS0uMi0uMi43LTEuNyAxLjctMS43IDIuNiAwIDQuNiAxLjcgNS44IDEu'
    b'NyAxLjMgMCAxLjctLjcgMy40LS43czMuNS44IDMuNiAyeiIvPgogIDxwYXRoIGZpbGw9IiM1'
    b'MTM2MjUiIGQ9Ik0yOTUuMiAxOTUuOHMxLjMtLjIgMi4yLS42bDIuMi0uOC0yIDEuMi0yIC41'
    b'LS40LS4zeiIvPgogIDxwYXRoIGZpbGw9IiNmOWM4M2EiIGQ9Ik0yOTAuOCAyMDIuM2MtLjIg'
    b'MC0xLjMgMC0zLTEuMS0xLjgtMS4yLTIuMy0zLjItMi4zLTMuMnMtLjQtMS45IDEuNC0zLjhj'
    b'MS44LTEuOSAyLjEtMS4zIDIuMi0xLjIuMSAwIDAgLjEgMCAuMWwtMS43IDEuMy0uNyAxLjMt'
    b'LjcgMS4ydjEuNGwuOCAxLjUgMi41IDEuNSAxLjUgMXoiLz4KICA8cGF0aCBmaWxsPSIjOGI1'
    b'MTIyIiBkPSJNMjg5LjggMTkxLjR2LS4yLjMtLjMuMy0uM2wtLjMuMmguMnYtLjJsLS4yLjIu'
    b'Mi0uMmgtLjJhLjMuMyAwIDAgMCAwIC4ybC4yLS4yaC0uMi4yLS4yLjItLjIuMmwtLjItLjEu'
    b'Mi4xLS4yLS4xLS4xLjFhNC42IDQuNiAwIDAgMC0uNC41bC0uMi42di4xYzAgLjMuMi41LjQu'
    b'NmgxLjRhLjMuMyAwIDAgMCAuMS0uNC4zLjMgMCAwIDAtLjMtLjJsLS43LjFhLjguOCAwIDAg'
    b'MS0uMyAwdi0uMmEuNS41IDAgMCAxIDAtLjIgMyAzIDAgMCAxIC4zLS41bC4yLS4xdi0uMWwu'
    b'MS0uMmEuMy4zIDAgMCAwLS4zLS4yLjMuMyAwIDAgMC0uMi4zLjMuMyAwIDAgMCAuMy4yeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmOWM4M2EiIGQ9Im0yOTUuMSAxOTQuMS0zLjggMS4xYy0uMy4y'
    b'IDEuMiAwIDIuNCAwbDEuMy4xLjktLjJjMS40LS41IDQuNC0xLjYgNC43LS4zLjIgMS00LjEg'
    b'Mi00LjEgMnYuNWwzLjQtLjkgMS45LTEgLjUtLjktMS43LTEuMkgyOThsLTEuMi4zLTEuNy41'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiM4ZjQ2MjAiIGQ9Ik0yODkuNyAxOTkuNWMuMy44LjkgMiAx'
    b'LjYgMi4zIDAgMCAuMSAwIDAgMCAwIC4xLS41LjUtMS43LjEtMS4yLS4zLTMtLjctNC4xLTR2'
    b'LjdsLjcgMS4zIDEuMSAxLjIgMS45IDEuMSAxLjIuMyAxLS4yLjYtLjQtMS4xLTEtMS40LTIu'
    b'My4yIDF6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjY2EzZCIgZD0iTTMwMi4xIDIzMi42djEuMmgt'
    b'Ljd2LTEuNXptLTQuNy0zNC40LTEuMi0xLjQtLjguMSAxLjIgMS44eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiM4MTZjMmEiIGQ9Im0zMDIgMjM1LjUtMS43LTFhMTAgMTAgMCAwIDAtMi40LS42di4z'
    b'aC4ybDIuMS42YTE0LjMgMTQuMyAwIDAgMSAxLjcgMWwuMS0uM3ptMC0zLjFoLTNhNCA0IDAg'
    b'MCAwLTEuMy43bC4xLjJhMy44IDMuOCAwIDAgMSAyLjYtLjcgMjMgMjMgMCAwIDEgMS40LjF2'
    b'LS4zem0tLjQtMi43LTIuNiAxLjQtMS42IDEuMi4yLjIuNS0uNGExNi41IDE2LjUgMCAwIDEg'
    b'Mi42LTEuNmwxLS41LS4xLS4zem0tMS43LTIuN3MwIC43LS4zIDEuMmE4LjYgOC42IDAgMCAx'
    b'LS42LjggODYuMyA4Ni4zIDAgMCAxLTIuNSAyLjZsLjIuM2EyMjAuNCAyMjAuNCAwIDAgMCAy'
    b'LjUtMi43bC43LS44Yy4zLS42LjMtMS4zLjMtMS40aC0uM3ptLTIuMS0xLjJhNC4yIDQuMiAw'
    b'IDAgMS0uMiAyLjJsLTEgMi4yLS40LjktLjIuMy4yLjJzMS4zLTIuMiAxLjctMy41Yy4yLS41'
    b'LjItMSAuMi0xLjVhNCA0IDAgMCAwIDAtLjloLS40em0tMi4xLS4zYTguNyA4LjcgMCAwIDAg'
    b'MCAxLjJjMCAuNiAwIDEuMi0uMiAxLjdsLS43IDEuOC0uMyAxIC4zLjEgMS0yLjhjLjItLjUu'
    b'Mi0xLjIuMi0xLjh2LTEuMmgtLjN6bS0xLjYgMHYxLjJsLS4zIDJhNTIuMiA1Mi4yIDAgMCAw'
    b'LS41IDIuNWguM2wuMi0uOC4zLTEuN2MuMy0xIC4zLTMuMi4zLTMuMmgtLjN6bS0xLjguM2Ex'
    b'MyAxMyAwIDAgMCAwIDIuOSAxNCAxNCAwIDAgMC0uNCAyLjVoLjNhMjMuMyAyMy4zIDAgMCAx'
    b'IC40LTIuNGwuMS0xLjR2LTEuNmgtLjR6bS0xLjMuMnYuMmE5IDkgMCAwIDEtLjMgMi4ybC0u'
    b'NiAxLjktLjIgMWguM2wuOC0yLjlhOC45IDguOSAwIDAgMCAuMy0yLjJ2LS4yaC0uM3ptLTEu'
    b'NiAwdi43YzAgLjYgMCAxLjQtLjQgMmE1LjUgNS41IDAgMCAxLTEuMyAxLjYgOS44IDkuOCAw'
    b'IDAgMS0uNy40bC0uMi4yLjEuM3MxLjctMSAyLjQtMi4zYy40LS43LjUtMS42LjUtMi4ydi0u'
    b'N2gtLjR6bS0uOS0uM3YuMmE2LjcgNi43IDAgMCAxLTEgMS45Yy0uMy40LS45LjgtMS4zIDEu'
    b'MWExMi4xIDEyLjEgMCAwIDEtLjguNWwuMi4zczEuNC0uOCAyLjEtMS43YTggOCAwIDAgMCAx'
    b'LjEtMi4yaC0uM3ptLTEuNS0uN3YuMWE2LjIgNi4yIDAgMCAxLTEgMS4zYy0uMS4yLS41LjQt'
    b'LjkuNmwtLjYuNC4xLjMuNy0uNCAxLS43LjctLjkuMy0uNi0uMy0uMXptLS43LTEtLjMuMy0u'
    b'OSAxYTYuNSA2LjUgMCAwIDEtLjUuNGwtLjQuMy4xLjMuNy0uNGMuNy0uNiAxLjUtMS43IDEu'
    b'NS0xLjdsLS4yLS4yem0tLjQtLjYtLjIuMi0uOS42YTIgMiAwIDAgMS0uOC4zdi40bC42LS4z'
    b'Yy43LS4zIDEuNS0xIDEuNS0xbC0uMi0uMnptLS4yLS43LS44LjQtLjYuM2ExLjkgMS45IDAg'
    b'MCAxLS40LjJ2LjNjLjIgMCAuMyAwIC41LS4ybDEuNC0uNy0uMS0uM3ptLS40LTEuMy0uNS41'
    b'LS45LjN2LjNhMiAyIDAgMCAwIDEuMi0uNSAzLjggMy44IDAgMCAwIC41LS40bC0uMy0uMnpt'
    b'LjEtMi4yLS42LjVjLS4zLjMtLjYuNi0uNyAxYS42LjYgMCAwIDEtLjEgMHYuNWwuMi0uMmEu'
    b'OC44IDAgMCAwIC4yLS4yYzAtLjIuNC0uNi43LS45YTcuOSA3LjkgMCAwIDEgLjUtLjVsLS4y'
    b'LS4yem0xMC43LTEyLjhoMS42bC4xLS4ydi0uMWgtLjF2LjMtLjFoLS4yLjEtLjF2LS4ybC4x'
    b'LjF2LS4xLjEtLjFoLTEuNXYuM3ptMC0xaC4yYy4yIDAgLjQgMCAuNi0uMi40LS4xLjctLjQg'
    b'MS0uNmwuNS0uM2EuOC44IDAgMCAxIC4zIDB2LS40bC0uNi4yLTEgLjctLjguMy0uMS4zem0w'
    b'LTEuNS43LS4yIDEuMi0uOGMuNC0uMy43LS40IDEtLjR2LS4zYy0uMyAwLS41IDAtLjguMmwt'
    b'MS4yLjdhMyAzIDAgMCAxLTEgLjV2LjN6bS0uNi0xLjQgMS41LTEgMS42LTEuMi0uMS0uMy0x'
    b'LjcgMS4yYy0uNS41LTEuMS45LTEuNSAxbC4yLjR6bS0xLTEuNSAzLjItMi4zLS4yLS4zLTMu'
    b'MiAyLjMuMS4zem0tMS41LTEuNmEyMC43IDIwLjcgMCAwIDEgMy40LTIuM2wtLjItLjItMS41'
    b'IDEtMS45IDEuMy4yLjJ6bS0xLTFhMTIzLjcgMTIzLjcgMCAwIDEgMi42LTEuOGwuOC0uNS0u'
    b'MS0uM2E3LjYgNy42IDAgMCAwLS44LjUgMTEzIDExMyAwIDAgMC0yLjcgMmwuMS4yeiIvPgog'
    b'IDxwYXRoIGZpbGw9IiM3ODczMmUiIGQ9Im0yOTQuNSAxOTUuNC4xLjFhMTcuMyAxNy4zIDAg'
    b'MCAxIDIuNSAyLjVjMSAxLjIgMS44IDIuNyAxLjggNC4xdi41YTkuNSA5LjUgMCAwIDEtMi41'
    b'IDVjLTIgMi4zLTQuOCA0LjQtNyA2LjRhMTggMTggMCAwIDAtMyAzLjEgNi4xIDYuMSAwIDAg'
    b'MC0xLjIgMy43IDYuNCA2LjQgMCAwIDAgMS4xIDMuNCA0LjQgNC40IDAgMCAwIDMuOSAyYzEu'
    b'OCAwIDMuOC0uNyA1LjYtLjcgMS42IDAgMyAuNCA0LjQgMS45IDEuMyAxLjQgMS43IDMuNiAx'
    b'LjcgNS43IDAgMS42LS4yIDMtLjQgNC4yYTI1LjYgMjUuNiAwIDAgMS0uNCAxLjhoLjNzLjgt'
    b'Mi44LjgtNmMwLTIuMS0uNC00LjUtMS44LTZhNS44IDUuOCAwIDAgMC00LjYtMS45Yy0xLjkg'
    b'MC0zLjkuNi01LjYuNmE0IDQgMCAwIDEtMy42LTEuOCA2IDYgMCAwIDEtMS0zLjN2LS4xYzAt'
    b'MS42LjctMyAxLjktNC4zIDEuOC0yIDQuNS00IDctNi4yIDIuMy0yLjIgNC40LTQuNSA0Ljct'
    b'Ny41di0uNWMwLTEuOC0xLjEtMy41LTIuMy00LjhhMTcuMiAxNy4yIDAgMCAwLTIuMy0yLjJs'
    b'LS4xLjN6Ii8+CiAgPHBhdGggZmlsbD0iI2E4YWM3MSIgZD0ibTI5Mi4xIDE5OC40LS40LS4z'
    b'LS4zLjEuNi41em0xIDEtLjMtLjNoLS4xbC4yLjR6Ii8+CiAgPHBhdGggZmlsbD0iIzc4NzMy'
    b'ZSIgZD0ibTI5NC41IDIwMS0uMi0uNC0uMi4yLjMuM3ptMSAxLjUtLjEtLjNoLS4zbC40LjV6'
    b'bS43IDEuNS0uMi0uNHYuNHptMCAxLjV2LS40bC0uMi0uMXYuNXptMCAxdi0uNWwtLjEtLjF2'
    b'LjZ6TTI4NCAyMjEuMWwuMS0uN2MuMS0uMy0uMy4xLS4zLjF2LjVsLjIuMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJtMjg0IDIyMi4xLS4zLjEuMS41LjEtLjJ2LS40eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM3ODczMmUiIGQ9Ik0yODQgMjIzLjl2LS40aC0uMnYuNnoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNMjg0IDIyNC45di0uNGgtLjF2LjR6bS4zIDEuNHYtLjRsLS4y'
    b'LjEuMS40em0uNCAxLjQtLjEtLjVoLS4ybC4yLjZ6Ii8+CiAgPHBhdGggZmlsbD0iI2E4YWM3'
    b'MSIgZD0ibTI4NS42IDIyOS43LS4yLS4zaC0uMmwuMy4zem0xLjUgMS40LS41LS4zYy0uMy0u'
    b'My0uMS4yLS4xLjJsLjQuMmguMnptOS44LjgtLjQtLjNjLS4yIDAgMCAwIC4yLjQuMS4zLjIt'
    b'LjEuMi0uMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMjk3LjcgMjMyLjUtLjMtLjN2'
    b'LjNoLjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2E4YWM3MSIgZD0iTTI5Ny45IDIzM2MtLjEtLjIt'
    b'LjIuMS0uMi4xbC4yLjN2LS41em0wIDEuM3YtLjVjMC0uMi0uMSAwLS4xIDB2LjVoLjF6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTI5Ny40IDIzNS43LjItLjRoLS4ydi40em0tMTQu'
    b'OC01MnMuNS0uMi4xLjRsLjMtLjVoLS41eiIvPgogIDxwYXRoIGZpbGw9IiNmOWM4M2EiIGQ9'
    b'Im0yOTQuNiAxOTUgLjQuM2gtLjVsLjEtLjN6Ii8+CiAgPHBhdGggZmlsbD0iIzhmNDYyMCIg'
    b'ZD0ibTI5NSAxOTUuMy0uNy4xYy0uMiAwIC4yLS4yLjItLjJsLjQuMXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjOTc3YzJlIiBkPSJNMzAxIDIzOS4xcy4zIDAgLjUtLjMtLjEuNC0uMS40bC0uMy4x'
    b'LS4yLS4yeiIvPgo8L3N2Zz4K', 'MX')

MX = b64_MX
index.append("MX")
index.append("MEX")
index.append("Mexico")
catalog["MX"] = MX
catalog["MEX"] = MX
catalog["Mexico"] = MX
country["Mexico"] = ('MX', 'MEX', 0)
lookup["MX"] = ('MX', 'MEX', 'Mexico', 0)
lookup["Mexico City Mexico"] = ('MX', 'MEX', 'Mexico', 0)
lookup["MEX"] = ('MX', 'MEX', 'Mexico', 0)
lookup["Mexico"] = ('MX', 'MEX', 'Mexico', 0)
details["MX"] = {"continent":"Americas","capital":"Mexico City","currency":"Mexican Peso","web":".mx","lang":"es-MX","tz":"-06:00","altname":""}
#----------------------------------------------------------------------
b64_MY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW15IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgY2xpcC1wYXRoPSJ1cmwoI215LWEp'
    b'Ij4KICAgIDxwYXRoIGZpbGw9IiNDMDAiIGQ9Ik0wIDBoNjQwdjQ4MEgwVjBaIi8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjQzAwIiBkPSJNMCAwaDY0MHYzNC4zSDB6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNMCAzNC4zaDY0MHYzNC4zSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjQzAw'
    b'IiBkPSJNMCA2OC42aDY0MHYzNC4zSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJN'
    b'MCAxMDIuOWg2NDBWMTM3SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjQzAwIiBkPSJNMCAxMzcu'
    b'MWg2NDB2MzQuM0gweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMTcxLjRoNjQw'
    b'djM0LjNIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNDMDAiIGQ9Ik0wIDIwNS43aDY0MFYyNDBI'
    b'MHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDI0MGg2NDB2MzQuM0gweiIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI0MwMCIgZD0iTTAgMjc0LjNoNjQwdjM0LjNIMHoiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDMwOC42aDY0MHYzNC4zSDB6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjQzAwIiBkPSJNMCAzNDIuOWg2NDBWMzc3SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJNMCAzNzcuMWg2NDB2MzQuM0gweiIvPgogICAgPHBhdGggZmlsbD0iI0MwMCIg'
    b'ZD0iTTAgNDExLjRoNjQwdjM0LjNIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0w'
    b'IDQ0NS43aDY0MFY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDYiIGQ9Ik0wIC41aDMy'
    b'MHYyNzQuM0gwVi41WiIvPgogICAgPHBhdGggZmlsbD0iI0ZDMCIgZD0ibTIwNy41IDczLjgg'
    b'NiA0MC43IDIzLTM0LTEyLjQgMzkuMiAzNS41LTIwLjgtMjguMSAzMCA0MS0zLjItMzguMyAx'
    b'NC44IDM4LjMgMTQuOC00MS0zLjIgMjguMSAzMC0zNS41LTIwLjggMTIuMyAzOS4zLTIzLTM0'
    b'LjEtNiA0MC43LTUuOS00MC43LTIzIDM0IDEyLjQtMzkuMi0zNS41IDIwLjggMjgtMzAtNDEg'
    b'My4yIDM4LjQtMTQuOC0zOC4zLTE0LjggNDEgMy4yLTI4LjEtMzAgMzUuNSAyMC44LTEyLjQt'
    b'MzkuMyAyMyAzNC4xIDYtNDAuN1ptLTMzLjMgMS43YTcxLjEgNzEuMSAwIDAgMC0xMDAgNjUg'
    b'NzEuMSA3MS4xIDAgMCAwIDEwMCA2NSA4MCA4MCAwIDAgMS04My4yIDYuMiA4MCA4MCAwIDAg'
    b'MS00My40LTcxLjIgODAgODAgMCAwIDEgMTI2LjYtNjVaIi8+CiAgPC9nPgogIDxkZWZzPgog'
    b'ICAgPGNsaXBQYXRoIGlkPSJteS1hIj4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KPC9zdmc+Cg==', 'MY')

MY = b64_MY
index.append("MY")
index.append("MYS")
index.append("Malaysia")
catalog["MY"] = MY
catalog["MYS"] = MY
catalog["Malaysia"] = MY
country["Malaysia"] = ('MY', 'MYS', 0)
lookup["MY"] = ('MY', 'MYS', 'Malaysia', 0)
lookup["Kuala Lumpur Malaysia"] = ('MY', 'MYS', 'Malaysia', 0)
lookup["MYS"] = ('MY', 'MYS', 'Malaysia', 0)
lookup["Malaysia"] = ('MY', 'MYS', 'Malaysia', 0)
details["MY"] = {"continent":"Asia","capital":"Kuala Lumpur","currency":"Malaysian Ringgit","web":".my","lang":"ms-MY | en | zh | ta | te | ml | pa | th","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_MZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW16IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Im16LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgY2xpcC1wYXRoPSJ1cmwo'
    b'I216LWEpIiB0cmFuc2Zvcm09InNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjMDA5'
    b'YTAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0wIDBoNzY4djE2MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMCAxNjBoNzY4djE2SDB6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0wIDE3Nmg3Njh2MTYwSDB6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0wIDMz'
    b'Nmg3Njh2MTZIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmNhMDAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgZD0iTTAgMzUyaDc2OHYxNjBIMHoiLz4KICAgIDxwYXRoIGZpbGw9InJlZCIgZmls'
    b'bC1ydWxlPSJldmVub2RkIiBkPSJNMCAwdjUxMmwzMzYtMjU2TDAgMHoiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNmZmNhMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTE5OC41IDMzMy01MS4y'
    b'LTM3LjVMOTYuMSAzMzNsMTkuOS02MC4zLTUxLjUtMzcuMSA2My41LjIgMTkuMy02MC40IDE5'
    b'LjQgNjAuNSA2My41LS4zLTUxLjUgMzcuMXoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWNhcD0icm91bmQi'
    b'IHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJNMTAyLjgg'
    b'MjkwLjloMzdjMyAzLjMgOS41IDQuNyAxNS44IDAgMTEuNi02LjQgMzQgMCAzNCAwbDQuNC00'
    b'LjctMTAuNy0zNS4yLTMuOS00LjJzLTguMy01LTI0LTMuM2MtMTUuNyAxLjctMjEuMi0uNS0y'
    b'MS4yLS41cy0xMy43IDEuNi0xNy42IDMuNmwtNC40IDQuNC05LjQgMzkuOXoiLz4KICAgIDxw'
    b'YXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBz'
    b'dHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0iTTExMC4zIDI4'
    b'MS44czM1LjItNC40IDQ1LjQgOS4xYy01LjcgNC0xMC44IDQuMy0xNi4yLjMuOC0xLjUgMTIu'
    b'Ni0xMy44IDQyLjctOS43Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iMS4yIiBkPSJtMTQ4IDI0Ni42LS4zIDM4LjhtMzEuNy0zOC4zTDE4'
    b'NiAyNzgiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxp'
    b'bmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEu'
    b'MSIgZD0ibTExNyAyNDYuNi0zLjcgMTYiLz4KICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS1saW5lam9p'
    b'bj0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJtNzguOSAyOTUuMSA4LjYgMTAuMmMx'
    b'IC42IDIgLjYgMi45IDBsMTIuOC0xNS40IDUuNC02LjdjLjktMSAxLjEtMi4xIDEtM2wxMC40'
    b'LTkuMyAyLjIuMmMtMS0uMi0xLjctLjctMS0xLjhsMi40LTEuOCAxLjggMi4zcy0yLjYgMy40'
    b'LTIuOSAzLjRoLTIuOGwtNS40IDQuOSAyLjQgMiAzLjUgOS44IDQuNC0zLjEtMi44LTEwIDYu'
    b'MS02LjctMi4zLTMuNiAxLjYtMnMyMS4zIDEzLjQgMjkuNiA5LjhjLjIgMCAuNS05LjYuNS05'
    b'LjZzLTIyLjItMi4zLTIyLjctNi43IDUtNSA1LTVsLTIuNC0zLjIuNS0xLjggMy45IDQuOCA4'
    b'LjctNy40IDUxLjUgNTguNmMyLjgtMS4xIDMuNC0xLjggMy42LTQuNkwxNTUgMjQxLjVsMy44'
    b'LTQuMWMuOC0uOSAxLTEuMiAxLTIuNmw2LTUuMWE3LjMgNy4zIDAgMCAxIDMuOCAzTDE4NiAy'
    b'MTljLjQuNCAxLjcuOCAyLjYuNGwyNi45LTI1LjktMjkuMyAyMC43LTEtLjdjMC0uOSAxLTEg'
    b'MC0yLjYtMS4yLTEuNC0yLjkgMS4zLTMuMSAxLjMtLjMgMC00LjMtMS40LTUuMi0zLjJsLS4y'
    b'IDQuNy03LjUgNy01LjctLjMtOC4yIDgtMSAzIDEuMyAyLjdzLTQuNCAzLjgtNC40IDMuNmMw'
    b'LS4zLS45LTEuMi0xLTEuM2wzLjgtMy40LjUtMi4zLTEuMi0yYy0uNC4zLTUuMiA1LjQtNS41'
    b'IDQuOGwtMTQtMTUuNS44LTIuOS04LjctOS41Yy0zLjItMS4xLTguMy0xLjMtOS4zIDUuNy0u'
    b'OCAxLjYtNy40LjItNy40LjJsLTMuNi44TDg1LjIgMjQxbDExLjMgMTMuNiAyMy4yLTI5LjMu'
    b'Ny04LjMgNC44IDUuNGMxLjcuMiAzLjIuMyA0LjctLjVsMTMuNyAxNS4zLTIuMyAyLjMgMiAy'
    b'LjIgMi40LTEuNi45IDEuM2MtMS4xLjYtMiAxLjUtMy4xIDIuMS0xLjgtMS4yLTMuNi0yLjct'
    b'My41LTVsLTcuNyA2LjQtLjMgMS4yLTIyLjkgMTktMiAuMy0uNSA2IDE0LjktMTIuNHYtMS44'
    b'bDEuNSAxLjMgMTEuNi05LjNzLjggMSAuNSAxLTEwLjMgOS4zLTEwLjMgOS4zbC0uMiAxLTEu'
    b'OCAxLjYtMS0uOC0xNCAxMi40aC0ybC03LjcgNy43Yy0yIC4yLTMuNy40LTUuNCAxLjVsLTEz'
    b'LjggMTIuMnoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'MZ')

MZ = b64_MZ
index.append("MZ")
index.append("MOZ")
index.append("Mozambique")
catalog["MZ"] = MZ
catalog["MOZ"] = MZ
catalog["Mozambique"] = MZ
country["Mozambique"] = ('MZ', 'MOZ', 0)
lookup["MZ"] = ('MZ', 'MOZ', 'Mozambique', 0)
lookup["Maputo Mozambique"] = ('MZ', 'MOZ', 'Mozambique', 0)
lookup["MOZ"] = ('MZ', 'MOZ', 'Mozambique', 0)
lookup["Mozambique"] = ('MZ', 'MOZ', 'Mozambique', 0)
details["MZ"] = {"continent":"Africa","capital":"Maputo","currency":"Mozambique Metical","web":".mz","lang":"pt-MZ | vmw","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_NA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5hIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Im5hLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgY2xpcC1wYXRoPSJ1cmwoI25hLWEpIj4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0w'
    b'IDBoNjQwdjQ4MEgweiIvPgogICAgPHBhdGggZmlsbD0iIzM2NjJhMiIgZD0ibS0yNi40LjIu'
    b'OCAzNDUuNkw1MTIuNSAwLTI2LjQuMnoiLz4KICAgIDxwYXRoIGZpbGw9IiMzOGExMDAiIGQ9'
    b'Ik02NjYuNCA0NzkuNiA2NjUgMTIwLjMgMTIyLjMgNDc5LjhsNTQ0LS4yeiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2M3MDAwMCIgZD0ibS0yNiAzNzEuOC40IDEwOC4yIDExNy41LS4xTDY2NS40'
    b'IDk1LjRsLS43LTk0LjEtMTE2LTFMLTI2IDM3MS43eiIvPgogICAgPHBhdGggZmlsbD0iI2Zm'
    b'ZTcwMCIgZD0ibTIxOS42IDE3Mi0yMS44LTEzLjItMTIuNiAyMi4xLTEyLjItMjIuMi0yMiAx'
    b'Mi45LjYtMjUuNC0yNS40LjIgMTMuMi0yMS44LTIyLjEtMTIuNSAyMi4yLTEyLjMtMTIuOC0y'
    b'MiAyNS40LjYtLjEtMjUuNSAyMS43IDEzLjJMMTg2LjMgNDRsMTIuMiAyMi4yIDIyLTEyLjkt'
    b'LjYgMjUuNCAyNS40LS4yLTEzLjIgMjEuOCAyMi4xIDEyLjUtMjIuMiAxMi4zIDEyLjggMjIt'
    b'MjUuNC0uNnoiLz4KICAgIDxwYXRoIGZpbGw9IiMzNjYyYTIiIGQ9Ik0yMzIuNCAxMTIuNGMw'
    b'IDI1LjYtMjAuOSA0Ni4zLTQ2LjYgNDYuM3MtNDYuNi0yMC43LTQ2LjYtNDYuMyAyMC44LTQ2'
    b'LjIgNDYuNi00Ni4yIDQ2LjYgMjAuNyA0Ni42IDQ2LjJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZlNzAwIiBkPSJNMjIyLjMgMTEyLjRhMzYuNSAzNi41IDAgMSAxLTczIDAgMzYuNSAzNi41'
    b'IDAgMCAxIDczIDB6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'NA')

NA = b64_NA
index.append("NA")
index.append("NAM")
index.append("Namibia")
catalog["NA"] = NA
catalog["NAM"] = NA
catalog["Namibia"] = NA
country["Namibia"] = ('NA', 'NAM', 0)
lookup["NA"] = ('NA', 'NAM', 'Namibia', 0)
lookup["Windhoek Namibia"] = ('NA', 'NAM', 'Namibia', 0)
lookup["NAM"] = ('NA', 'NAM', 'Namibia', 0)
lookup["Namibia"] = ('NA', 'NAM', 'Namibia', 0)
details["NA"] = {"continent":"Africa","capital":"Windhoek","currency":"Namibia Dollar | Rand","web":".na","lang":"en-NA | af | de | hz | naq","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_NC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5jIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwOTU0MyIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2VkNDEzNSIgZD0iTTAgMGg2NDB2'
    b'MzIwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMzVhZCIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+'
    b'CiAgPGNpcmNsZSBjeD0iMjQwIiBjeT0iMjQwIiByPSIxNTcuMyIgZmlsbD0iI2ZhZTYwMCIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjUuMyIvPgogIDxwYXRoIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSI2LjQiIGQ9Ik0yMTMuMyAyNjMuNWg1My4zTTIxMy4zIDIyNGg1'
    b'My4zTTI0MCA4My4yVjM1MiIvPgogIDxwYXRoIGQ9Ik0xNzYuNiAzODQuNGM2NC4yIDI2LjMg'
    b'MTI0LjQgMS43IDEyNC40IDEuN3MtMjIuNy0yNC42LTM0LjMtMzQuMmMtMTEuNC05LjQtNDQu'
    b'OC05LTU2LjIgMGE0ODguNyA0ODguNyAwIDAgMC0zMy45IDMyLjV6Ii8+CiAgPGVsbGlwc2Ug'
    b'Y3g9IjI0MCIgY3k9IjMxMi41IiByeD0iMTcuNiIgcnk9IjI1LjYiLz4KICA8ZWxsaXBzZSBj'
    b'eD0iMjQwIiBjeT0iMjQzLjciIHJ4PSIyMS4zIiByeT0iMTMuNSIvPgogIDxjaXJjbGUgY3g9'
    b'IjI0MCIgY3k9IjE4MS4zIiByPSIyMS4zIi8+CiAgPHBhdGggZD0iTTI2NS42IDEwMS45czEu'
    b'OCAzLTIgMTBjLTE4LjYgMzMuNS0zNy4zIDM0LjItNDAuOCAzNy4xLTQgMy4yLTUuNiAzLTUu'
    b'NiAzIC4zLTIuOS41LTE0LjYuNy0xNS43IDIuOS0xNS43IDI2LjUtMTUuNSA0NS0zMS41IDIu'
    b'OS0yLjUgMi43LTMgMi43LTN6bS02Mi40IDcyczQuMyAxMiA0LjggMjRjMSAxOS4yIDE5LjQg'
    b'MTkuNyAzMiAxOS43di0xMC43Yy05LjUgMC0xNy43LTEuNC0yNC41LTE1LjRhMTIyLjcgMTIy'
    b'LjcgMCAwIDAtMTIuMy0xNy42em0tLjUgMTU0LjZzNi43LTguMyAxNC42LTI3LjdjNC0xMC4x'
    b'IDEzLjgtMTYgMjIuNy0xNnYtMTVjLTIwLjMgMC0zMCA3LjUtMzEgMTguNmEzMjkgMzI5IDAg'
    b'MCAxLTYuMyA0MC4xeiIvPgogIDxwYXRoIGQ9Ik0yNzYuOCAxNzMuOXMtNC4zIDEyLTQuOCAy'
    b'NGMtMSAxOS4yLTE5LjQgMTkuNy0zMiAxOS43VjIwN2M5LjUgMCAxNy43LTEuNCAyNC41LTE1'
    b'LjUgMy42LTYuMiA3LjctMTIuMSAxMi4zLTE3LjZ6bS41IDE1NC43cy02LjctOC40LTE0LjYt'
    b'MjcuOGMtNC0xMC4xLTEzLjgtMTYtMjIuNy0xNlYyNzBjMjAuMyAwIDMwIDcuNSAzMSAxOC42'
    b'YTMyOSAzMjkgMCAwIDAgNi4zIDQweiIvPgo8L3N2Zz4K', 'NC')

NC = b64_NC
index.append("NC")
index.append("NCL")
index.append("New Caledonia")
catalog["NC"] = NC
catalog["NCL"] = NC
catalog["New Caledonia"] = NC
country["New Caledonia"] = ('NC', 'NCL', 0)
lookup["NC"] = ('NC', 'NCL', 'New Caledonia', 0)
lookup["Noumea New Caledonia"] = ('NC', 'NCL', 'New Caledonia', 0)
lookup["NCL"] = ('NC', 'NCL', 'New Caledonia', 0)
lookup["New Caledonia"] = ('NC', 'NCL', 'New Caledonia', 0)
details["NC"] = {"continent":"Oceania","capital":"Noumea","currency":"CFP Franc","web":".nc","lang":"fr-NC","tz":"+11:00","altname":""}
#----------------------------------------------------------------------
b64_NE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5lIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzBkYjAyYiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MzIw'
    b'SDB6Ii8+CiAgPHBhdGggZmlsbD0iI2UwNTIwNiIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+CiAg'
    b'PGNpcmNsZSBjeD0iMzIwIiBjeT0iMjQwIiByPSI2OCIgZmlsbD0iI2UwNTIwNiIvPgo8L3N2'
    b'Zz4K', 'NE')

NE = b64_NE
index.append("NE")
index.append("NER")
index.append("Niger")
catalog["NE"] = NE
catalog["NER"] = NE
catalog["Niger"] = NE
country["Niger"] = ('NE', 'NER', 0)
lookup["NE"] = ('NE', 'NER', 'Niger', 0)
lookup["Niamey Niger"] = ('NE', 'NER', 'Niger', 0)
lookup["NER"] = ('NE', 'NER', 'Niger', 0)
lookup["Niger"] = ('NE', 'NER', 'Niger', 0)
details["NE"] = {"continent":"Africa","capital":"Niamey","currency":"CFA Franc BCEAO","web":".ne","lang":"fr-NE | ha | kr | dje","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_NF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5mIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xOTQuOCAwaDI1MC40djQ4MEgxOTQuOHoiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMxOTgyMDAiIGQ9Ik0wIDBoMTk0Ljh2NDgwSDB6bTQ0NS4yIDBI'
    b'NjQwdjQ4MEg0NDUuMnoiLz4KICAgIDxwYXRoIGZpbGw9IiMxOTgyMDAiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJv'
    b'a2Utd2lkdGg9Ii43IiBkPSJNMzEzLjUgMzUxLjN2NTIuNmwyMS4zLjJzLTYuOC00NS44LTMu'
    b'MS01MmMzLjctNiA3LjItNS4yIDcuMi01LjJzMTMuOSA0LjIgMTUuNCAzLjVjMS41LS42LS4y'
    b'LTUuMiA3LjItNC42IDIuNC0uOSAxLjEtNSAzLjMtNS4yIDIuMi0uMyA0NC41IDExLjggNTMu'
    b'Ny40LTIuNC02LjQtMTAuNy0uNS0xMi45LS4yLTIgMC0xMC4zLTQtMTUuMSAwLTQuNC0zLjMt'
    b'MjQuNC01LjUtMjQuNC01LjUtMi42LTIuNiA0Ny42IDEuMyA1MC41LS43IDUuOS01LjktMTEt'
    b'NS4yLTEzLjYtMy4zYTE0LjggMTQuOCAwIDAgMC0xNC4yLS42Yy0xLjctNC4xLTE4LTIuNC0y'
    b'Ny0zLjUtMy0xLjctMi41LTIuNy0uNS0zLjggMTkgLjggMzcuOCAzLjMgNTYuOCAyLjUgNS4x'
    b'LTYuNy02LjUtOS4zLTEzLjYtMy41LTQuMi03LTEyLjctLjMtMTguNC0xLTUuNy0uNi0zLTcu'
    b'NiA0LjItNi41IDcuMiAxIDIwLjEtLjQgMjIuNS0zLjdzLTEuNC02LjctMTMuMy0zLjVjLTQt'
    b'NC0xMyAwLTE3LjEgMS4zLTUuNi0zLjEtMTguNS0uNS0yMi44LjYtNC4zLTIuNiAyMi41LTcg'
    b'MjIuNS03IDEwLjQtLjIgMTYuMy0yIDE5LjUtMi44IDE1LjctOC40LS4yLTkuMy04LjQtMy4y'
    b'LTUuMS00LTEwIC4zLTE0LjYgMS44YTM4LjIgMzguMiAwIDAgMS0xMy40IDJjMC0uNiAxMi42'
    b'LTguMyAxMi42LTguM3MxNS4zLTEuMSAxOC40LTEuNWMzLS41IDE4LjgtOC41LTIuNy0zLjEt'
    b'Ny40LjYtMTEuOC4yLTE0LjcuNC0xNi41LTEuNyAxLjYtMy4zIDEuNi0zLjNzMjMuNC0yLjEg'
    b'MjMuNy0zLjNjLjQtOS0xOS4xLTQuOC0xOS4zLTQuOCAwLTYuNS0xOC4yLjItMTguMiAwLTMu'
    b'NS0yIDItNC4xIDItNC4xIDQuOC0xLjIgMTItMS42IDEzLjktMy4xIDAgMCAxMy42LS4xIDE1'
    b'LjItMy43LTMuMy05LjMtMjguOCAxLjYtMzIuMiAzLjItNC42IDAgMy03LjQgMy4zLTcuNi4y'
    b'LS4zIDIxLTEuMSAzMC45LTE0LjUuNy04LjEtMTEuNiA0LjYtMTEuNiA0LjYtMS0xMC42LTEz'
    b'LjQuNy0yMC42IDEuNS03LjMgMS03LjUtMy4zLTIuNS00IDUtLjYgMTAuOC0uMSAxMy42LTcu'
    b'OCAyLjktNy43IDExLjQuNCAxMy0yLjQgMS41LTIuOS0zLjEtNS4zLTMuMS01LjNzNi40LTYu'
    b'Ni00LTYuM2MtMTAuMi4yLTIzLjYtMS40LTIzLjYtMS40czEwLjctNC4xIDIwLjgtNGMxMCAu'
    b'MyA0LjYtNy4xLTUtNy4xLTkuNyAwLTE0LjctMy4zLTE0LjctMy4zbDE2LjQtNi4yLTEtNC42'
    b'czkuNi03LjctNC01LjlsLTE1LjIgMi0yNy40IDQuMWMtLjIgMC03LjQtMi4yLS40LTRzMzEu'
    b'OC02LjcgMzUuNS01LjRjMy43IDEuMy0uNC05LjItMTMuNi0xMC41LTEzLjEtMS4zLTIxLjMg'
    b'My4zLTIxLjMgMy4zcy04LjUtMy4xLS42LTUuN2M3LjktMi43IDIwLjQuOSAyMC40LjlzMTQt'
    b'NC4yIDIuNC02Yy0xMS42LTEuNy0xNS4zIDEuNi0yMC42IDEuOC0yLjEtMi43IDE4LjItMy4z'
    b'IDE5LjUtNS41LTIuMi00LTE0LjggMC0yMi4yIDAtMy0xLjMtMy4zLTMuNS4zLTQuOCA3LjUt'
    b'LjMgMTQuNi4xIDIyLjEtLjItLjItNCAwLTguNy0uMi0xMi44LTkuNi0xLjctMjAuOCAxLjMt'
    b'MjYuMSAxIDEuNC00LjMgMjItNS41IDI0LjMtNi43IDQuOC02LTIwLjEgMC0yMC40IDAtNC4z'
    b'LS42LTQtMy40LTEuMy01IDYuNC0uNyAyMC42IDEgMTkuNi0zLjQtLjgtNC0xMC0xLjktMTMu'
    b'Ni0xLTMuOC45LTkuMy4yLTkuMy4yLTIuMy0zLjIgMjEuNS0xLjkgMjEuMy00LjQtLjMtMi44'
    b'LTE1LjEtLjgtMjAuMi0uNi0zLjktMi43IDE5LTQuNSAxOS4zLTQuOC45LTcuMy0xNS4zIDAt'
    b'MTguNCAwLTMgMC0xLjUtNC42LTEuNS00LjZzNi4zLTIuOSA2LjEtMy4zYTIyIDIyIDAgMCAw'
    b'LTUuMi0yYy0uNSAwIDAtNSAwLTVzNS4yLTQgNC44LTUuMWMtLjUtMS4xLTYuMi45LTYuMi45'
    b'di00LjRzNC4yLS40IDQuNi0yLjRjLjUtMi01LTIuMi01LTIuMmwtMi4yLTIzLTIgMjEuNS03'
    b'LjIgMXM1IDIuOSA2IDUuOGMuOCAyLjgtNi4yIDItNi4yIDJzNS43IDQuOCA2LjEgNi41Yy41'
    b'IDEuOC03LjkgMi4yLTcuOSAyLjJzNyA1IDcuNSA3LjljLjQgMi44IDAgNC40IDAgNC40cy0x'
    b'MS42LTEwLjEtMTktNy4zYy00IDIgOC44IDMgMTcuMiAxMC4zIDAgMS43LTIwLjUtNS0yMS4y'
    b'LS44LjQgMS4xIDIxLjkgNC4yIDIzLjQgNy03LjguMy0yNC0xLjctMjMuNC45LTEuNyAzIDE1'
    b'LjIgMS4zIDIyLjMgMy43IDIuMSAyLjQgMS45IDQuNC0xLjcgNC42LTYuOS0zLjMtMjIuMS01'
    b'LjctMjIuMi0xLjUuMSAxIDE1LjguNCAyMS41IDQuMS03LjYgMS44LTMzLjQtMy41LTMzLjUt'
    b'MSAuNyAxLjMgNC44IDYuNSAxMS44IDYuMyA3LS4yIDIzLjMgMi44IDI0LjQgNSAxIDIuMi0y'
    b'MS4xLTQuNi0yOS40LS42LTguNCA0IDIzLjkgMS41IDI5LjEgNi4zIDUuMyA0LjktMTAuNS0u'
    b'NC0xMC41LS40cy0yMi0zLTI1LjItMS41Yy0zLjMgMS41LTcgNS03IDVzMi4yIDQuNCA0LjQg'
    b'My41YzIuMi0uOS0uNyAyLjctLjcgMi43czMwLjcgNy40IDM3LjUgMTRjNi44IDYuNi0zOS0x'
    b'MC4zLTM5LTEwLjNzLTE4LjUgNi44IDEgNy4yYy0yLjIgMy4zIDEuMiA1LjMgMS4yIDUuM3Mz'
    b'Mi40IDYuOCAzNS43IDEyYzMuMyA1LjMtMjIuMS01LTI3LjktNy45LTUuNy0yLjgtMjEuOSAx'
    b'LjgtMjEuNyAyLjkuMyAxIDggMi42IDguMSA0LjYuMyAyLTkuNCAyLjYtOS40IDQuNCAwIDEu'
    b'NyA0MSAxMC4zIDUyIDE5LjVzLTMyLjItMTEtMzIuMi0xMSAyLjQgMy4zIDAgNC4yYy0yLjUu'
    b'OS0xMS0xMi4zLTI1LTQuMi0yLjYgMy40IDEyLjIgNiAxNiA2LjQtMS4zIDMuMy0yLjQgNC40'
    b'IDIuOCA3LjdzLTEwLjMtNC44LTEwLjMtNC40bDEuMSA1LjdjLTQuOC00LTEwLjctNS4xLTE2'
    b'LjItMS4xIDAgMC0uMiA0IDUuNSA2LjQtMy4xIDYuMyAzLjUgNC4zIDE0IDEwLjMtMTUuNi00'
    b'LjEtMTYuOSAzLjUtNS43IDUuMnM0MS45IDIuOSA0OS4xIDEyLjNjNy4zIDkuNC0xMC4zLTMu'
    b'Ni0xMi4zLTQtLjQuMy0uOCA0LjktLjggNC45LTQuNy0yLjctOS01LjItMTQuNi02LjMtLjUu'
    b'OS0uMyAyLjEtLjggMy01LTMuNy05LjUtNi4yLTE2LjktNi42bC0uOSAzLjVzLTYuMS03Ljct'
    b'MTguMiAwYy02LjcgNC45IDI1LjUgMS44IDMwLjcgNy41IDUuMyA1LjcgMS4xIDYuNiAxLjEg'
    b'Ni42bC0xMy4xLTQuOXMtMTUuNi0yLjgtMjAgLjcgNjQgMTIgNjYgMjEuNWMxLjQgNS0xNi01'
    b'LjQtMzEuMS05LjlsLTEuOCA1cy02LTYtMTIuNy03Yy0uMiAwIDEuMyA2IDEuMyA2cy0xNi44'
    b'LTgtMjUuNC0zLjhjLTguNSA0LjIgMjkuOCA2LjQgMzMuMyAxMC4zIDMuNSA0LTExLjYtMi42'
    b'LTEzIDAtMS4yIDIuNy0xOS45LTQuOC0xOS42LTEuMy4yIDMuNSAyLjYgNS41IDIuNiA1LjVz'
    b'MzguOCAzLjcgNDAuMSA4LjNjMS4zIDQuNi0yMS41LTIuNi0yMS41LTIuNnMtMi4yIDMuMy0u'
    b'NCA0LjhjMS43IDEuNi0xMy4yLTguNy0xMS44LTItNC45LTEuOS0xNy40LTcuOC0xNS42LTMu'
    b'MiAxLjcgNC42IDM1LjMgMTEuMiAzNS4zIDExLjJzLTE0LjcgMS0xNCA0LjhjLTE5LTExLjUt'
    b'MTguNS00LjItMTgtNCAuNC4yLTI0LjQtNi4xLTUuNyA0czEwIDguMyAxMC4zIDguNWMuMi4y'
    b'IDIgNSAxLjUgNS0uNCAwLTEyLjctNi41LTE2LjktNy00LjEtLjQtMjMuOSA1LjUtMi44IDE0'
    b'LjhzMzQtMi4yIDQ1LjYtMWMxMS42IDEuNCAxNyAzLjQgMTYgNy0xLjEgMy44LTExLjktMTIu'
    b'MS0yMy4yIDEuNy0xMy0yLjYtMjEuNy00LTE1IDUuNC0yMS03LjktMzQgMi40LTcuNCA2LjYg'
    b'MjYgLjggNDItNi40IDQyLTYuNHM0LjUgOC4xIDEwLjggMi40YzYuNC01LjcgNi42IDIuMiA2'
    b'LjggMi4ybDYuMi0yLjZoMS41eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0'
    b'cm9rZS13aWR0aD0iLjgiIGQ9Ik0zMTYgMzIwLjJ2LTMuN3MtOC4yLTEuNS0xMi4zLS43Yy0y'
    b'LjMtMS4zLTQuNi0zLjEtNy41LTEuNi0uNSAxLjIgNS4zIDQuMyA3LjIgNC4zYTQxLjEgNDEu'
    b'MSAwIDAgMCAxMi43IDEuN3ptMCA2cy04LjMtMy4xLTExLjYuNGMuNSAzLjcgOS43IDUuNSAx'
    b'MS43IDQuNSAxLjktMSAwLTQuOC0uMS01em0xNCAxLjR2Mi42czkuOCAxLjkgMTEuNi0uMmMx'
    b'LjctMi4xLTgtMy41LTExLjctMi40em0tLjUtMTAuMi4zIDIuOXM4LjYgMS45IDExLjktMi44'
    b'YzMuMy00LjctNy41IDAtMTIuMi0uMXptLjQtMTB2MnM2LjUgMSA4LTEuOGMxLjQtMi44LTcu'
    b'OCAwLTgtLjJ6bS0xMy40LTZjLTEtMS4zLTQuNS00LjgtMTMuOC01LjgtNi41IDAgMTEuNyA5'
    b'LjUgMTMuOCA1Ljl6bTEzLjItOS43LS4yIDIuN3MyMi02LjYgMjcuMS02LjFjNC42LTEuMyA1'
    b'LjYtNC41IDUuNC00LjUtNC0yLjktMjIuOSAyLjMtMzIuMyA3Ljl6bS41LTcuOC0uMyAyLjZz'
    b'MTUuNS0zIDE5LjctNmM0LjEtMy0xOS4yIDMuNS0xOS40IDMuNHptLS42LTcuNnYyLjZzMTAu'
    b'My0uNCAxMi41LTIuNGMxLjMtMi4xLTkuMi0uMy0xMi41LS4yem0yMS42IDIxLjdzNS40Ljgg'
    b'Ni40LS44Yy0uMi0yLjgtNi40IDEtNi40Ljh6TTMzMCAyNjYuNmwuMSA1LjdzMjQuOS03Ljkg'
    b'MjYuNS05LjNjMS41LTEuNSA1LTYtMjYuNiAzLjZ6bS0uNy03Ljl2NC4yczEwLS44IDE0LjYt'
    b'NC41YzQuNi0zLjgtMTQuNi40LTE0LjYuM3ptLTEyLTkuMy42IDMuNy0zMi45LTEwLjZjLjEg'
    b'MC0xLjYtNS40IDMyLjMgNi45em0uNS0xMy4zYzAgLjQgMCAzLjYtLjIgMy41IDAgMC0yMi44'
    b'LTkuNS0yMy43LTguNy0zLTcgMjQgNS40IDI0IDUuMnptMTEuMSA2IC40IDMuMXMxNC0yLjkg'
    b'MTQuOC00LjNjLjgtMS40LTE1LjIgMS4yLTE1LjIgMS4xem0uMyA3LjRjLjIuNy40IDMuMy40'
    b'IDMuM3M1LjYtLjUgNi41LTEuOGMuOC0xLjMtNi45LTEuNS02LjktMS41em0tLjgtMTd2M3Mx'
    b'NS40LTMgMTctNC40YzEuNy0xLjUtMTcuMyAxLjQtMTcgMS40em0wLTguNWMwIC4yLS41IDMu'
    b'MS0uMSAzLjFzMTguNi0zIDIxLjUtNS43YzIuOC0yLjUtMjEgMi45LTIxLjMgMi42em0tLjIt'
    b'MTQuOXYzLjNzMTEuOC0yLjUgMTQtNWMyLjItMi41LTE0IDItMTQgMS43em0tMi0yMS42LjIg'
    b'NC44czE2LTIuMiAxOC4yLTQuOGMyLjMtMi43LTE4LjUgMC0xOC40IDB6bS03LjQtMzYuNXYz'
    b'cy03LjUtLjMtNS43LTEuNiA1LjctMS4xIDUuNy0xLjR6bTcgNCAuMiA0LjJzOS43LTEgMTAu'
    b'NC0yLjVjLjgtMS41LTEwLjQtMS42LTEwLjYtMS42em0tLjYgNnMuMiAyLjYuNCAyLjYgMy45'
    b'LS4zIDQuNy0xLjNjLjgtMS00LjctMS01LTEuM3ptLTguMiAxMS44YzAgLjMuMyA0IDAgMy44'
    b'cy0yMS4yLTYuMS0yMy4yLTZjLTEuOSAwLTIuNC00LjkgMjMuMiAyLjJ6bTEuNyA2LjljMCAu'
    b'Ny41IDQuNi0uMyA0LjQtLjctLjItMTQuMy00LjUtMTIuOS01LjggMS40LTEuMyAxMy4yIDEu'
    b'NyAxMy4yIDEuNHptLTEuMiAyOSAuMSAzLjVzLTIzLjctNy4yLTI0LjUtOC40Yy0uOC0xLjIt'
    b'My4xLTYuOCAyNC40IDQuOXptMSA4LjV2My4zbC0zMi4yLTExLjNzLTIuNi04LjQgMzIuMSA4'
    b'eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpv'
    b'aW49InJvdW5kIiBzdHJva2Utd2lkdGg9Ii44IiBkPSJtMjgwLjMgMzI4LjctLjIgMy41cy02'
    b'LjItMS44LTguMi01LjNjMy42LTEgOC41IDEuOSA4LjQgMS44eiIvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'NF')

NF = b64_NF
index.append("NF")
index.append("NFK")
index.append("Norfolk Island")
catalog["NF"] = NF
catalog["NFK"] = NF
catalog["Norfolk Island"] = NF
country["Norfolk Island"] = ('NF', 'NFK', 0)
lookup["NF"] = ('NF', 'NFK', 'Norfolk Island', 0)
lookup["Kingston Norfolk Island"] = ('NF', 'NFK', 'Norfolk Island', 0)
lookup["NFK"] = ('NF', 'NFK', 'Norfolk Island', 0)
lookup["Norfolk Island"] = ('NF', 'NFK', 'Norfolk Island', 0)
details["NF"] = {"continent":"Oceania","capital":"Kingston","currency":"Australian Dollar","web":".nf","lang":"en-NF","tz":"+11:00","altname":""}
#----------------------------------------------------------------------
b64_NG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5nIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0'
    b'ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDg3NTMiIGQ9Ik00MjYuNiAwSDY0MHY0ODBI'
    b'NDI2LjZ6TTAgMGgyMTMuM3Y0ODBIMHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'NG')

NG = b64_NG
index.append("NG")
index.append("NGA")
index.append("Nigeria")
catalog["NG"] = NG
catalog["NGA"] = NG
catalog["Nigeria"] = NG
country["Nigeria"] = ('NG', 'NGA', 0)
lookup["NG"] = ('NG', 'NGA', 'Nigeria', 0)
lookup["Abuja Nigeria"] = ('NG', 'NGA', 'Nigeria', 0)
lookup["NGA"] = ('NG', 'NGA', 'Nigeria', 0)
lookup["Nigeria"] = ('NG', 'NGA', 'Nigeria', 0)
details["NG"] = {"continent":"Africa","capital":"Abuja","currency":"Naira","web":".ng","lang":"en-NG | ha | yo | ig | ff","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_NI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1uaSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGxpbmVhckdyYWRpZW50IGlkPSJuaS1m'
    b'IiB4MT0iNDk4LjciIHgyPSI1MDAuNiIgeTE9IjI4OS4xIiB5Mj0iMjgzLjQiIGdyYWRpZW50'
    b'VW5pdHM9InVzZXJTcGFjZU9uVXNlIj4KICAgICAgPHN0b3Agb2Zmc2V0PSIwIiBzdG9wLWNv'
    b'bG9yPSIjNTEwMDAwIi8+CiAgICAgIDxzdG9wIG9mZnNldD0iLjMiIHN0b3AtY29sb3I9IiM4'
    b'YTAwMDAiLz4KICAgICAgPHN0b3Agb2Zmc2V0PSIxIiBzdG9wLWNvbG9yPSIjYTAwIi8+CiAg'
    b'ICA8L2xpbmVhckdyYWRpZW50PgogICAgPGxpbmVhckdyYWRpZW50IGlkPSJuaS1nIiB4MT0i'
    b'NTAxLjQiIHgyPSI1MDIuOSIgeTE9IjI5MS40IiB5Mj0iMjg3LjQiIGdyYWRpZW50VW5pdHM9'
    b'InVzZXJTcGFjZU9uVXNlIj4KICAgICAgPHN0b3Agb2Zmc2V0PSIwIiBzdG9wLWNvbG9yPSIj'
    b'ZmYyYTJhIi8+CiAgICAgIDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0icmVkIi8+CiAg'
    b'ICA8L2xpbmVhckdyYWRpZW50PgogICAgPGxpbmVhckdyYWRpZW50IGlkPSJuaS1iIiB4MT0i'
    b'NDg0LjgiIHgyPSI0ODQuOCIgeTE9IjMxMS43IiB5Mj0iMzE3LjYiIGdyYWRpZW50VW5pdHM9'
    b'InVzZXJTcGFjZU9uVXNlIj4KICAgICAgPHN0b3Agb2Zmc2V0PSIwIiBzdG9wLWNvbG9yPSIj'
    b'RjVGNTQ5Ii8+CiAgICAgIDxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iIzk3QzkyNCIv'
    b'PgogICAgPC9saW5lYXJHcmFkaWVudD4KICAgIDxsaW5lYXJHcmFkaWVudCBpZD0ibmktYSI+'
    b'CiAgICAgIDxzdG9wIG9mZnNldD0iMCIgc3RvcC1jb2xvcj0iIzAyNSIvPgogICAgICA8c3Rv'
    b'cCBvZmZzZXQ9Ii41IiBzdG9wLWNvbG9yPSIjMDRhIi8+CiAgICAgIDxzdG9wIG9mZnNldD0i'
    b'MSIgc3RvcC1jb2xvcj0iIzAyNSIvPgogICAgPC9saW5lYXJHcmFkaWVudD4KICAgIDxsaW5l'
    b'YXJHcmFkaWVudCB4bGluazpocmVmPSIjbmktYSIgaWQ9Im5pLWgiIHgxPSI0NDQuNSIgeDI9'
    b'IjYzNC40IiB5MT0iMzE3LjUiIHkyPSIzMTcuNSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNl'
    b'T25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVudCB4bGluazpocmVmPSIjbmktYiIgaWQ9Im5p'
    b'LXYiIHgxPSI0ODQuOCIgeDI9IjQ4NC44IiB5MT0iMzExLjciIHkyPSIzMTcuNiIgZ3JhZGll'
    b'bnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVudCB4bGluazpo'
    b'cmVmPSIjbmktYSIgaWQ9Im5pLW8iIHgxPSI0NDQuNSIgeDI9IjYzNC40IiB5MT0iMzE3LjUi'
    b'IHkyPSIzMTcuNSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5l'
    b'YXJHcmFkaWVudCB4bGluazpocmVmPSIjbmktYSIgaWQ9Im5pLXAiIHgxPSI0NDQuNSIgeDI9'
    b'IjYzNC40IiB5MT0iMzE3LjUiIHkyPSIzMTcuNSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNl'
    b'T25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVudCB4bGluazpocmVmPSIjbmktYSIgaWQ9Im5p'
    b'LXEiIHgxPSI0NDQuNSIgeDI9IjYzNC40IiB5MT0iMzE3LjUiIHkyPSIzMTcuNSIgZ3JhZGll'
    b'bnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVudCB4bGluazpo'
    b'cmVmPSIjbmktYSIgaWQ9Im5pLXIiIHgxPSI0NDQuNSIgeDI9IjYzNC40IiB5MT0iMzE3LjUi'
    b'IHkyPSIzMTcuNSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiLz4KICAgIDxsaW5l'
    b'YXJHcmFkaWVudCB4bGluazpocmVmPSIjbmktYiIgaWQ9Im5pLXUiIHgxPSI0ODQuOCIgeDI9'
    b'IjQ4NC44IiB5MT0iMzExLjciIHkyPSIzMTcuNiIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNl'
    b'T25Vc2UiLz4KICAgIDxsaW5lYXJHcmFkaWVudCB4bGluazpocmVmPSIjbmktYSIgaWQ9Im5p'
    b'LXgiIHgxPSI5OC45IiB4Mj0iMTI1IiB5MT0iMTQ0MC4yIiB5Mj0iMTQ0MC4yIiBncmFkaWVu'
    b'dFRyYW5zZm9ybT0ic2NhbGUoNC40NTcxNSAuMjI0MzYpIiBncmFkaWVudFVuaXRzPSJ1c2Vy'
    b'U3BhY2VPblVzZSIvPgogICAgPGxpbmVhckdyYWRpZW50IHhsaW5rOmhyZWY9IiNuaS1hIiBp'
    b'ZD0ibmktaiIgeDE9IjQ0NC41IiB4Mj0iNjM0LjQiIHkxPSIzMTcuNSIgeTI9IjMxNy41IiBn'
    b'cmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIvPgogICAgPGxpbmVhckdyYWRpZW50IHhs'
    b'aW5rOmhyZWY9IiNuaS1hIiBpZD0ibmktbCIgeDE9IjQ0NC41IiB4Mj0iNjM0LjQiIHkxPSIz'
    b'MTcuNSIgeTI9IjMxNy41IiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIvPgogICAg'
    b'PGxpbmVhckdyYWRpZW50IHhsaW5rOmhyZWY9IiNuaS1hIiBpZD0ibmktbSIgeDE9IjQ0NC41'
    b'IiB4Mj0iNjM0LjQiIHkxPSIzMTcuNSIgeTI9IjMxNy41IiBncmFkaWVudFVuaXRzPSJ1c2Vy'
    b'U3BhY2VPblVzZSIvPgogICAgPGxpbmVhckdyYWRpZW50IHhsaW5rOmhyZWY9IiNuaS1hIiBp'
    b'ZD0ibmktaSIgeDE9IjQ0NC41IiB4Mj0iNjM0LjQiIHkxPSIzMTcuNSIgeTI9IjMxNy41IiBn'
    b'cmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIvPgogICAgPGxpbmVhckdyYWRpZW50IHhs'
    b'aW5rOmhyZWY9IiNuaS1iIiBpZD0ibmktcyIgeDE9IjQ4NC44IiB4Mj0iNDg0LjgiIHkxPSIz'
    b'MTEuNyIgeTI9IjMxNy42IiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIvPgogICAg'
    b'PGxpbmVhckdyYWRpZW50IHhsaW5rOmhyZWY9IiNuaS1hIiBpZD0ibmkteSIgeDE9IjQ3Ljki'
    b'IHgyPSI2MS43IiB5MT0iMzA1NC4yIiB5Mj0iMzA1NC4yIiBncmFkaWVudFRyYW5zZm9ybT0i'
    b'c2NhbGUoOS4xMjQwNSAuMTA5NikiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIi8+'
    b'CiAgICA8Y2xpcFBhdGggaWQ9Im5pLWMiPgogICAgICA8cGF0aCBkPSJtNTAwIDIyNi40LTYz'
    b'LjcgMTEwLjNoMTI3LjR6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8cGF0aCBm'
    b'aWxsPSIjMDA2N2M2IiBkPSJNMCAwaDY0MHY0ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZm'
    b'IiBkPSJNMCAxNjBoNjQwdjE2MEgweiIvPgogIDxwYXRoIGZpbGw9IiNjOGE0MDAiIGQ9Im0y'
    b'NDggMjM5LjUgOCAuNXYtMS4ybC0zLS4yLjItMy44IDMuMy0yLjQuMS0xLjUtMy41IDIuNWMt'
    b'LjEtLjgtLjYtMS43LTEuNC0yLS44LS4yLTEuNi0uMi0yLjMuMy0uOC42LTEgMS42LTEgMi41'
    b'bC0uNCA1LjN6bTEuMi0xLjEuMy00Yy4xLS42LjItMS40LjgtMS44YTEgMSAwIDAgMSAxLjUu'
    b'NWMuNCAxIC4yIDIuMS4xIDMuMmwtLjEgMi4yLTIuNi0uMXptLS4yLTExLjIgNy44IDEuOCAx'
    b'LjgtNy42YTE5OCAxOTggMCAwIDEtMS4xLS4ybC0xLjUgNi40LTIuNC0uNSAxLjQtNS44LTEu'
    b'MS0uMy0xLjQgNS44LTItLjUgMS40LTYuMi0xLjItLjItMS43IDcuM3ptMi44LTEwLjUgNy42'
    b'IDIuNy40LTEuMS0zLTEgMS4yLTMuNWMuMi0xIC40LTItLjEtM2EyLjUgMi41IDAgMCAwLTIt'
    b'MWMtMSAwLTEuNi43LTIgMS41LS42IDEtMSAyLjItMS4zIDMuNGwtLjggMnptMS41LS43IDEu'
    b'Mi0zLjRjLjMtLjYuNi0xLjMgMS4zLTEuNWExIDEgMCAwIDEgMS4yLjljLjIgMS0uMyAyLS42'
    b'IDNsLS43IDEuOS0yLjQtLjl6bTIuNy05IDQuMyAyLjZjLjguNCAxLjguNiAyLjcuMmE2LjUg'
    b'Ni41IDAgMCAwIDIuNC0zYy40LTEgLjgtMi4yLjItMy4yLS42LTEtMS43LTEuNC0yLjctMmwt'
    b'Mi43LTEuNi0uNiAxIDQgMi40Yy43LjQgMS4yIDEgMS4xIDEuOWE2IDYgMCAwIDEtMS4yIDIu'
    b'NWMtLjQuNi0xLjIgMS4xLTIgMS0uOC0uMi0xLjUtLjgtMi4yLTEuMmwtMi43LTEuNS0uNiAx'
    b'em01LjgtOS4zIDYuMyA0LjggMy0zLjhjLjYtLjkgMS0yIC43LTNhMi41IDIuNSAwIDAgMC0y'
    b'LTEuNGMtLjUgMC0xIC4zLTEuMi40LjItLjktLjUtMS43LTEuMi0xLjktMS0uMy0yIC4zLTIu'
    b'NiAxbC0yIDIuNS0xIDEuNHptMS42LS4zYy43LTEgMS40LTIgMi4yLTIuOC40LS40IDEtMSAx'
    b'LjUtLjYuNS4yLjcuOS40IDEuMy0uNC45LTEgMS41LTEuNiAyLjNsLS44IDEuMS0xLjctMS4z'
    b'em0yLjYgMiAyLjMtM2MuNC0uNCAxLTEgMS42LS44LjYuMSAxIC43LjggMS4zLS4zIDEtMS4x'
    b'IDEuOC0xLjggMi43bC0xIDEuMy0yLTEuNXptMy0xMC4yIDUuNSA1LjggNC43LTQuNS0uOC0u'
    b'OC0zLjggMy42aC0uMWwtNC43LTV6bTctNi4yIDQuOSA2LjMgMS0uNy01LTYuM3ptNy4yLTQu'
    b'OWE2LjcgNi43IDAgMCAwLTIgMS44IDMuNiAzLjYgMCAwIDAtLjEgNC4yIDQuMSA0LjEgMCAw'
    b'IDAgMS42IDEuNSAzLjYgMy42IDAgMCAwIDIgLjQgNi41IDYuNSAwIDAgMCAyLjctMSA1LjQg'
    b'NS40IDAgMCAwIDItMmMuNC0uOC41LTEuNi4zLTIuNGwtMSAuNGMuMiAxLjYtLjggMi40LTIg'
    b'My0xLjggMS4yLTMuNSAxLjEtNC42LS41LTEuMS0xLjkgMC0zLjQgMS42LTQuNCAxLjEtLjcg'
    b'Mi4yLTEuMiAzLjItLjVsLjktLjhhMy4yIDMuMiAwIDAgMC0yLS42Yy0uOSAwLTEuNy40LTIu'
    b'NiAxem05LjUtNC43LS45IDkgMS4zLS41LjItMi44IDQtMS42IDIuMiAxLjggMS4yLS41LTYu'
    b'OC01LjktMS4yLjV6bTEgMSAyLjcgMi4yLTMgMS4yLjMtMy41em0xNi41LTYgLjUgOCA0LjMt'
    b'LjJjMS4yLS4yIDIuNC0uNCAzLjEtMS40IDEtMSAxLjItMi43LjctNC4xYTMuNSAzLjUgMCAw'
    b'IDAtMi43LTIuNGMtMS4yLS4yLTIuNCAwLTMuNiAwbC0yLjMuMnptMS4yIDEuMSAzLjUtLjFh'
    b'MyAzIDAgMCAxIDEuOC41Yy44LjYgMS4zIDEuNSAxLjIgMi41YTIuNyAyLjcgMCAwIDEtMiAy'
    b'LjRjLS42LjItMS4zLjItMS45LjNsLTIuMi4xLS40LTUuN3ptMTAtMS41LS41IDggNy44LjR2'
    b'LTEuMWwtNi42LS40LjEtMi40IDYgLjN2LTEuMWwtNS45LS4zLjEtMi4yIDYuNC40di0xLjJs'
    b'LTcuNS0uNHptMjAuOCAzLjMtMi45IDcuNSAxIC40IDIuNC02di0uMmwuMi4zIDIuOCA4IDEu'
    b'My41IDIuOS03LjUtMS0uNC0yLjMgNi0uMS4yLS4yLS4zLTIuNy04ek0zNTMgMTc2bC0zLjcg'
    b'Ny0xLS41IDMuNi03LjF6bTYgMy41YTYuNyA2LjcgMCAwIDAtMi40LTEgMy42IDMuNiAwIDAg'
    b'MC00IDEuNSA0LjEgNC4xIDAgMCAwLS42IDIuMWMwIC43LjEgMS40LjYgMi4xLjQuNyAxIDEu'
    b'MyAyIDJhNiA2IDAgMCAwIDIuNyAxIDMuNSAzLjUgMCAwIDAgMi4yLS43bC0uOC0uOWMtMS40'
    b'IDEtMi41LjMtMy42LS40LTEuOC0xLjItMi41LTIuOC0xLjQtNC41IDEuMi0xLjggMy4xLTEu'
    b'MyA0LjctLjMgMSAuNyAyIDEuNSAxLjggMi43bDEgLjRhMy4yIDMuMiAwIDAgMC0uMy0yYy0u'
    b'NC0uOC0xLTEuNC0xLjktMnptNy42IDUuNy04LjMgMy40IDEgLjkgMi42LTEgMy4zIDIuOC0u'
    b'NyAyLjcgMSAuOSAyLjEtOC44LTEtLjl6bS0uMyAxLjQtLjggMy40LTIuNS0yIDMuMy0xLjR6'
    b'bTYuNCA0LjItNi4yIDUgLjcgMSAyLjUtMiAyLjQgMy0uNyA0IC45IDEuMS44LTQuMmMuNy41'
    b'IDEuNy44IDIuNS40LjctLjQgMS40LTEgMS40LTEuOCAwLTEuMS0uNy0yLTEuMy0yLjhsLTMt'
    b'My43em0tLjIgMS42IDIuNiAzLjJjLjQuNi45IDEuNC40IDItLjMuNi0xLjEuNi0xLjYuMi0x'
    b'LS43LTEuNi0xLjctMi40LTIuNmwtMS0xLjEgMi0xLjd6bTkuNSAxMS4xLTkgLjQuNyAxLjIg'
    b'Mi44LS4xIDIuMiAzLjgtMS42IDIuMy43IDEuMiA0LjktNy42LS43LTEuMnptLS43IDEuMi0y'
    b'IDMtMS41LTIuOCAzLjUtLjJ6bTUuOSA5LjRjLS41LTEuMy0xLjMtMi43LTIuNy0zLjRhMy44'
    b'IDMuOCAwIDAgMC00LjUgMWMtMSAxLTEgMi41LS43IDMuOS4zIDEuNSAxIDMgMiA0LjFsLS42'
    b'LjIuNCAxLjEgMy44LTEuMy0xLjUtNC4xLS44LjMgMSAzLTEuMi41YTcgNyAwIDAgMS0yLjEt'
    b'My44Yy0uMy0xLjEtLjMtMi40LjUtMy4yIDEtMSAyLjYtMS4zIDMuNy0uNXMxLjcgMi4xIDIg'
    b'My40Yy4zLjkuMiAxLjktLjQgMi42LS4yIDAgMCAuMy4xLjRsLjMuNWEyLjggMi44IDAgMCAw'
    b'IDEuMS0yLjIgNyA3IDAgMCAwLS40LTIuNXptMi4zIDYuMy00LjUuOGE0LjEgNC4xIDAgMCAw'
    b'LTEuOS44IDIuNSAyLjUgMCAwIDAtLjggMS41djIuNGMuMyAxIC42IDEuNyAxIDIuMy4zLjYu'
    b'NyAxIDEuMiAxYTQgNCAwIDAgMCAyIDBsNC41LS44LS4yLTEuMS00LjQuOGMtMiAuNC0yLjYt'
    b'LjYtMy0yLjQtLjMtMS44IDAtMyAxLjktMy4zbDQuNC0uOS0uMi0xLjF6bTIuNCAxMy42LTgu'
    b'My0zLjYuMSAxLjQgMi42IDEgLjMgNC40LTIuNCAxLjUuMSAxLjMgNy43LTQuNy0uMS0xLjN6'
    b'bS0xLjIuNy0zIDEuOS0uMi0zLjIgMy4yIDEuM3ptLTEzNi41IDIwLTEuMi4zIDEuMyA0Ljkg'
    b'MS4yLS4zem0xMzEuNiAwIDEuMi4zLTEuMyA0LjktMS4yLS4zem0tMTE5LjIgMjAuNS05IDEg'
    b'LjggMS4xIDIuOC0uMyAyLjQgMy42LTEuNCAyLjUuOCAxIDQuMy03LjgtLjctMS4xem0tLjcg'
    b'MS4zLTEuNyAzLTEuOC0yLjYgMy41LS40em00LjEgMy42LTUuNyA1LjMuOC44IDQuOC00LjUt'
    b'Mi42IDcgMSAuOSA2LjgtMi00LjcgNC4zLjguOCA1LjctNS4zLTEuMi0xLjItNyAyIDIuNi02'
    b'Ljd6bTguMyA4LjQtNC44IDYuNSA2LjIgNC42LjctLjktNS4zLTQgMS41LTIgNC43IDMuNy43'
    b'LTEtNC43LTMuNSAxLjMtMS43IDUgMy44LjctMS02LTQuNXptNy44IDUuOC0zLjcgNyAxIC42'
    b'IDEuNS0yLjggMy40IDEuOC44IDQgMS4zLjctLjktNC4yYy45LjMgMiAuMSAyLjUtLjYuNS0u'
    b'Ni45LTEuMy42LTIuMS0uMi0xLTEuMy0xLjYtMi4xLTIuMWwtNC40LTIuM3ptLjUgMS41IDMu'
    b'NiAyYy42LjQgMS4zLjkgMS4yIDEuNiAwIC43LS43IDEtMS4zLjktMS4yLS4yLTIuMi0uOS0z'
    b'LjItMS40bC0xLjUtLjggMS4yLTIuM3ptOC42IDMuMi0zIDcuNCAxIC41IDMtNy40em03LjIg'
    b'Mi41YTYuNyA2LjcgMCAwIDAtMi42LS40IDMuNiAzLjYgMCAwIDAtMy40IDIuNiA0LjEgNC4x'
    b'IDAgMCAwIDAgMi4xYzAgLjguNCAxLjQgMSAyYTYgNiAwIDAgMCAyLjQgMS4zIDUuNCA1LjQg'
    b'MCAwIDAgMi45LjIgMy40IDMuNCAwIDAgMCAyLTEuMmwtMS0uNmMtMSAxLjMtMi4zIDEtMy42'
    b'LjUtMi0uNy0zLjEtMi0yLjUtNCAuNy0yIDIuNy0yIDQuNC0xLjUgMS4yLjQgMi4zIDEgMi40'
    b'IDIuMWwxLjIuMmEzLjIgMy4yIDAgMCAwLS45LTIgNS40IDUuNCAwIDAgMC0yLjMtMS4zem04'
    b'IDEuOC01LjIgNy4zIDEuMy4yIDEuNi0yLjMgNC40LjcuOSAyLjYgMS4zLjItMy04LjUtMS4z'
    b'LS4yem0uNSAxLjMgMS4yIDMuNC0zLjItLjUgMi0yLjl6bTE4LjMtMS4yYy0xIC4xLTEuNy40'
    b'LTIuNC45YTMuNiAzLjYgMCAwIDAtMS43IDMuOWMuMS43LjQgMS4zIDEgMiAuNC41IDEgLjgg'
    b'MS44IDEgLjcuMiAxLjcuMiAyLjggMCAxLS4yIDItLjYgMi42LTEuMmEzLjQgMy40IDAgMCAw'
    b'IDEuMS0yaC0xLjJjLS4zIDEuNi0xLjUgMi0yLjggMi4yLTIuMS40LTMuNy0uMy00LjEtMi4z'
    b'LS40LTIuMSAxLjMtMy4xIDMtMy41IDEuMy0uMiAyLjUtLjMgMy4yLjdsMS0uNGEzLjIgMy4y'
    b'IDAgMCAwLTEuNi0xLjMgNS40IDUuNCAwIDAgMC0yLjcgMHptNS4zLTEgMi4zIDcuNyA3LjUt'
    b'Mi4yLS40LTEuMS02LjMgMS45LS43LTIuNCA1LjctMS43LS4zLTEtNS43IDEuNi0uNi0yIDYt'
    b'MS44LS4zLTEuMS03LjIgMi4xem04LjctMi43IDMuMyA3LjMgMS0uNS0yLjgtNiA3LjggMy41'
    b'aC41bDEtLjUtMy40LTcuMy0xIC41IDIuOCA2LTgtMy42LTEuMi42em04LjgtNC4xLjYgMSAy'
    b'LjgtMmguMmwzLjcgNS43IDEtLjctMy43LTUuNnYtLjFsMi45LTItLjYtLjl6bTgtNS42IDUu'
    b'NCA2IC45LS45LTIuMS0yLjMgMi44LTIuNiA0IC42IDEuMi0xLTQuMy0uNmMuNS0uNy43LTEu'
    b'OC4yLTIuNi0uNC0uNy0xLTEuMy0xLjktMS4yLTEgMC0yIC44LTIuNyAxLjRsLTMuNSAzLjN6'
    b'bTEuNi4xIDMtMi44Yy42LS40IDEuNC0uOSAyLS41LjcuMy43IDEuMS4zIDEuNi0uNiAxLTEu'
    b'NSAxLjctMi40IDIuNmwtMS4xIDEtMS44LTJ6bTcuNy05LjQgMy42IDguMy44LTEtMS0yLjYg'
    b'Mi43LTMuNCAyLjcuNi45LTEtOC44LTItLjkgMS4xem0xLjQuMyAzLjUuNy0yIDIuNS0xLjUt'
    b'My4yem0yLjEtNC44IDYuNyA0LjMgMy41LTUuNC0xLS42LTIuNyA0LjMtLjEuMmgtLjFsLTUu'
    b'Ny0zLjh6Ii8+CiAgPGcgY2xpcC1wYXRoPSJ1cmwoI25pLWMpIiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCguOCAwIDAgLjggLTgwIDApIj4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im01MDAgMjI2'
    b'LjQtMzEuNSA1NC41LTE1LjQgMjYuN2g5My44bC0xNC43LTI1LjQtMzIuMi01NS44eiIvPgog'
    b'ICAgPGcgaWQ9Im5pLWUiPgogICAgICA8ZyBpZD0ibmktZCI+CiAgICAgICAgPHBhdGggZmls'
    b'bD0iIzE3YzBlYiIgc3Ryb2tlPSIjMTdjMGViIiBzdHJva2Utd2lkdGg9Ii4xIiBkPSJtNTAw'
    b'IDIyNi40LTIuNCA0IDIuNCA1NSAyLjQtNTV6IiBvcGFjaXR5PSIuNiIvPgogICAgICAgIDxw'
    b'YXRoIGZpbGw9IiNmZmYiIGQ9Ik01MDAgMjc3LjVoLS4xbC4xIDMgLjEtM2gtLjF6Ii8+CiAg'
    b'ICAgIDwvZz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjbmktZCIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoNzIgNTAwIDI4NS41KSIvPgogICAgICA8'
    b'dXNlIHhsaW5rOmhyZWY9IiNuaS1kIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFu'
    b'c2Zvcm09InJvdGF0ZSgxNDQgNTAwIDI4NS41KSIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9'
    b'IiNuaS1kIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InJvdGF0ZSgt'
    b'MTQ0IDUwMCAyODUuNSkiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjbmktZCIgd2lkdGg9'
    b'IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoLTcyIDUwMCAyODUuNSki'
    b'Lz4KICAgIDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI25pLWUiIHdpZHRoPSIxMDAlIiBo'
    b'ZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0icm90YXRlKDggNTAwIDI4NS41KSIvPgogICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjbmktZSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNm'
    b'b3JtPSJyb3RhdGUoMTYgNTAwIDI4NS41KSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjbmkt'
    b'ZSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoMjQgNTAw'
    b'IDI4NS41KSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjbmktZSIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoMzIgNTAwIDI4NS41KSIvPgogICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjbmktZSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNm'
    b'b3JtPSJyb3RhdGUoNDAgNTAwIDI4NS41KSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjbmkt'
    b'ZSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoNDggNTAw'
    b'IDI4NS41KSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjbmktZSIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoNTYgNTAwIDI4NS41KSIvPgogICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjbmktZSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNm'
    b'b3JtPSJyb3RhdGUoNjQgNTAwIDI4NS41KSIvPgogICAgPHBhdGggZmlsbD0icmVkIiBkPSJN'
    b'NTAwIDI2NS44YTQ0LjIgNDQuMiAwIDAgMC0yOSAxMC44TDQ1Ni40IDMwMmE0NSA0NSAwIDAg'
    b'MC0uOCA4LjNoNWEzOS40IDM5LjQgMCAwIDEgNzguNyAwaDVhNDUgNDUgMCAwIDAtLjctOC4z'
    b'TDUyOSAyNzYuNmE0NC4zIDQ0LjMgMCAwIDAtMjktMTAuOHoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNmNjAiIGQ9Ik01MDAgMjY2LjdhNDMuNSA0My41IDAgMCAwLTMwLjMgMTIuMmwtMTIgMjAu'
    b'OWE0My42IDQzLjYgMCAwIDAtMS4zIDEwLjRoNC4zYTM5LjQgMzkuNCAwIDAgMSA3OC42IDBo'
    b'NC4zYTQzLjkgNDMuOSAwIDAgMC0xLjMtMTAuNWwtMTItMjAuOGE0My41IDQzLjUgMCAwIDAt'
    b'MzAuMy0xMi4yeiIvPgogICAgPHBhdGggZmlsbD0iI2ZmMCIgZD0iTTUwMCAyNjcuNWE0Mi43'
    b'IDQyLjcgMCAwIDAtMzIgMTQuM2wtOC43IDE1YTQyLjcgNDIuNyAwIDAgMC0yIDEzLjVoMy4z'
    b'YTM5LjQgMzkuNCAwIDAgMSA3OC43IDBoMy41YzAtNC43LS44LTkuMi0yLjEtMTMuNGwtOC44'
    b'LTE1LjFhNDIuNiA0Mi42IDAgMCAwLTMxLjktMTQuM3oiLz4KICAgIDxwYXRoIGZpbGw9IiMw'
    b'ZjAiIGQ9Ik01MDAgMjY4LjNhNDIgNDIgMCAwIDAtMzQuOSAxOC42bC0yLjggNC45YTQxLjgg'
    b'NDEuOCAwIDAgMC00LjMgMTguNWgyLjdhMzkuNCAzOS40IDAgMCAxIDc4LjYgMGgyLjdhNDEu'
    b'OCA0MS44IDAgMCAwLTQuMy0xOC41bC0yLjgtNWE0MiA0MiAwIDAgMC0zNC45LTE4LjZ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjMGNmIiBkPSJNNTAwIDI2OWE0MS4yIDQxLjIgMCAwIDAtNDEu'
    b'MiA0MS4zaDEuOWEzOS40IDM5LjQgMCAwIDEgNzguNiAwaDEuOUE0MS4yIDQxLjIgMCAwIDAg'
    b'NTAwIDI2OXoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMGYiIGQ9Ik01MDAgMjY5LjhhNDAuNCA0'
    b'MC40IDAgMCAwLTQwLjQgNDAuNGgxLjRhMzkgMzkgMCAxIDEgNzggMGgxLjRBNDAuNCA0MC40'
    b'IDAgMCAwIDUwMCAyNzB6Ii8+CiAgICA8cGF0aCBmaWxsPSJwdXJwbGUiIGQ9Ik01MDAgMjcw'
    b'LjdhMzkuNiAzOS42IDAgMCAwLTM5LjYgNDAuM2guOHYtLjhhMzguOCAzOC44IDAgMSAxIDc3'
    b'LjYuOGguOHYtLjhhMzkuNiAzOS42IDAgMCAwLTM5LjYtMzkuNnoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiM1MTAwMDAiIGQ9Ik01MDAuNCAyODguMWMtLjcgMC0xLjItLjUtMS44LS42YTIuMiAy'
    b'LjIgMCAwIDAtLjcgMi4xYy4zLjEuMy40LjkuOXMuNS43LjQgMmMwIC40LjEgMS41LjYgMS42'
    b'LjUuMSAxLS4zIDEuMS0xLjIuMS0uNy40LTEuMi43LTEuNi4zLTEuOS0uMi0yLjYtMS4yLTMu'
    b'MnoiLz4KICAgIDxwYXRoIGZpbGw9InJlZCIgZD0iTTQ5Ny4yIDI4My41Yy0uNiAwLTEuNiAx'
    b'LTIgLjUtLjItLjMtLjMtLjkgMC0xLjRhNC44IDQuOCAwIDAgMSAyLjItMi4zYzIuMy0xLjQg'
    b'My45LTEgNSAxIDEuMSAxLjggMi4yIDMuOCAyLjMgNS40IDAgLjUuMyAxLjQtLjIgMS45LTEu'
    b'MyAxLjQtNC42LTEuNS02LjUtMS0uNi4xLTEuNC42LTIgLjItLjQtLjMgMC0xIC4zLTEuMy42'
    b'LS41IDEuNS0yLjQgMS40LTMuMiAwLS40IDAgLjItLjUuMnoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'InVybCgjbmktZikiIGQ9Ik00OTcgMjgyLjZjLTEuMi40LTEgMS0xLjYgMS41LjIuMS44LjMg'
    b'MS40LS4zLjItLjIuNS0uMy43LS4zbC0uNy43YTUuMiA1LjIgMCAwIDAtMS40IDEuOGMtLjMu'
    b'OC0uNCAxLjctLjMgMS44IDAgMCAuNC44IDEuNSAxLjIgMiAuOCAyLjQgMi41IDQuNSAyLjUg'
    b'MS42IDAgMS40LTEuMSAyLjctLjkgMSAuMiAxLjctLjcuNi0xLjJhMTQgMTQgMCAwIDAtNS40'
    b'IDBjLS40LTQgMC0yLjYtLjEtNC40LS4xLTEuNy0uNy0xLjggMC0zLjMtLjUgMS0xLjIuOC0y'
    b'IC44eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmMmEyYSIgZD0ibTUwMSAyNzkuOC0uMS42LjMg'
    b'MSAuMiAxYzAgLjMuNC40LjcuNi40LjMgMCAxIC4zIDEuMS4yIDAgLjUtMSAuNS0xLjJ2LS43'
    b'YTE1LjMgMTUuMyAwIDAgMC0uNS0uOSAzLjYgMy42IDAgMCAwLS4yLS4zIDQuMiA0LjIgMCAw'
    b'IDAtLjgtLjkgNCA0IDAgMCAwLS4zLS4ybC0uMi0uMXoiLz4KICAgIDxwYXRoIGZpbGw9InVy'
    b'bCgjbmktZykiIGQ9Im01MDEuMyAyODcuNC0yLS43Yy0xLjMtLjQtMi42LTEuMi0zLjUtLjgt'
    b'LjMuMS0uMy40LS40LjkgMCAuNS0uNSAxLjMgMCAxIC42LS40IDIuNC44IDMgMS4xLjMuMiAx'
    b'IC42IDEuMSAxIC4yLjYgMCAxLjggMCAyLjQgMCAuNS4yIDEuOC43IDIgLjYuMSAxLjEtLjQg'
    b'MS4zLTEuMy4zLS45LjQtMS40LjgtMS45cy44LS44IDEuMy0uOWMuNiAwIDEuNC41IDEuNC0u'
    b'MiAwLS40LS40LS44LS4yLTEuNC4xLS41LS40LS40LS45LS42bC0yLjctLjZ6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjOTEwMDAwIiBkPSJNNDk4LjQgMjg4LjljLS40LS4yLTIuMy0xLjUtMy0x'
    b'LS4zIDAtLjQgMC0uNC0uM2wuMi0uOWMwLS4zLjItLjguNS0xIC43LS42IDIuMy41IDMuMS44'
    b'bC0uNCAyLjR6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmYzYTNhIiBkPSJNNTAxLjggMjkxLjRj'
    b'LjktMS42IDEuNS0xLjQgMi42LTEuNC40IDAgLjUtLjMuNC0uNy0uMy42LTEuNyAwLTIuNS4z'
    b'LTEuNS43LTEuMiAzLjctMiA0IC44LjcgMS4xLTEuNyAxLjUtMi4yeiIvPgogICAgPGcgZmls'
    b'bD0idXJsKCNuaS1oKSI+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im00NTMuMSAzMDcu'
    b'Ni0xMCAxNy4zSDU1N2wtMTAtMTcuMmgtOTMuOHoiLz4KICAgICAgPGcgaWQ9Im5pLW4iIGZp'
    b'bGw9InVybCgjbmktaSkiPgogICAgICAgIDxwYXRoIGlkPSJuaS1rIiBmaWxsPSJ1cmwoI25p'
    b'LWopIiBkPSJNNDQ5LjcgMzIxLjRhMzYgMzYgMCAwIDAtNC43LjNsLS41LjljMi40LS4zIDQu'
    b'Ny0uNyA3LjItLjcgMy4yIDAgNi4yLjggOS43LjhoNC42YzMuNSAwIDYuNC0uOCA5LjctLjgg'
    b'My4zIDAgNi4zLjggOS44LjhoNC42YzMuNSAwIDYuNC0uOCA5LjctLjggMy4zIDAgNi4zLjgg'
    b'OS44LjhoNC41YzMuNSAwIDYuNS0uOCA5LjgtLjggMy4zIDAgNi4zLjggOS44LjhoNC41YzMu'
    b'NSAwIDYuNS0uOCA5LjgtLjggMi42IDAgNSAuNSA3LjUuN2wtLjUtMWEzOCAzOCAwIDAgMC00'
    b'LjQtLjJoLTQuNWMtMy41IDAtNi41LjctOS44LjgtMy4zIDAtNi4zLS44LTkuOC0uOEg1MjJj'
    b'LTMuNSAwLTYuNS43LTkuOC44LTMuMyAwLTYuMy0uOC05LjgtLjhINDk4Yy0zLjUgMC02LjUu'
    b'Ny05LjguOC0zLjMgMC02LjMtLjgtOS44LS44aC00LjVjLTMuNSAwLTYuNS43LTkuOC44LTMu'
    b'MyAwLTYuMi0uOC05LjctLjhoLTQuNnoiLz4KICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiNu'
    b'aS1rIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB5PSItMS4xIiBmaWxsPSJ1cmwoI25p'
    b'LWwpIi8+CiAgICAgICAgPHVzZSB4bGluazpocmVmPSIjbmktayIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgeT0iLTIuMiIgZmlsbD0idXJsKCNuaS1tKSIvPgogICAgICA8L2c+CiAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI25pLW4iIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHk9Ii0zLjMiIGZpbGw9InVybCgjbmktbykiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIj'
    b'bmktbiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeT0iLTYuNyIgZmlsbD0idXJsKCNu'
    b'aS1wKSIvPgogICAgICA8cGF0aCBmaWxsPSJ1cmwoI25pLXEpIiBkPSJNNDUzLjIgMzA3LjV2'
    b'LjJoOTMuN2wtLjEtLjJoLTkzLjZ6bS0uMi4zLS4xLjNINTQ3bC0uMS0uM2gtOTR6bS0uMi40'
    b'LS4yLjNoOTQuOGwtLjItLjNoLTk0LjR6bS0uMy41LS4zLjVoOTUuNmwtLjMtLjVoLTk1em0t'
    b'LjQuNy0uMy41aDk2LjRsLS4zLS41aC05NS44em0tLjQuNy0uMi40aDk3bC0uMi0uNGgtOTYu'
    b'NnptLS40LjctLjIuNEg1NDlsLS4zLS40aC05Ny40em0tLjQuNy0uMy42aDk4LjhsLS4zLS42'
    b'SDQ1MXoiLz4KICAgICAgPHBhdGggZmlsbD0idXJsKCNuaS1yKSIgZD0iTTQ1Ny40IDMxMi4z'
    b'YzMuNC43IDMuNyAwIDMuNyAwem04MS41IDBzLjMuNyAzLjcgMHoiLz4KICAgIDwvZz4KICAg'
    b'IDxnIGZpbGw9IiNjY2QxMWUiPgogICAgICA8ZyBpZD0ibmktdCI+CiAgICAgICAgPHBhdGgg'
    b'ZmlsbD0idXJsKCNuaS1zKSIgZD0iTTUzMC42IDI5N2MtMS43IDAtMi4yLjktMi4yLjktMi43'
    b'IDEwLjYtMTEuOCAyMS4zLTIyLjYgMjEuM2gtOFYzMzBoNjEuNGwtNi4yLTExYy05LjctMS40'
    b'LTE3LjYtMTEuMy0yMC4xLTIxLjEgMCAwLS42LS45LTIuMy0uOXoiLz4KICAgICAgICA8cGF0'
    b'aCBmaWxsPSIjOTdjOTI0IiBkPSJNNTMwLjYgMjk3LjVjLS44IDAtMS4yLjEtMS41LjNsLS4z'
    b'LjNhMzMuNiAzMy42IDAgMCAxLTguNCAxNC43Yy00IDQuMS05IDYuOS0xNC42IDYuOWgtNy43'
    b'djkuOUg1NTlsLTUuNy0xMGMtNC43LS43LTktMy4yLTEyLjQtNi44YTMzLjYgMzMuNiAwIDAg'
    b'MS04LjQtMTQuN2wtLjMtLjNhMi44IDIuOCAwIDAgMC0xLjYtLjN6Ii8+CiAgICAgICAgPHBh'
    b'dGggZmlsbD0iI2VkZTcxZiIgZD0iTTUzMC42IDI5Ny41aC40djEwLjhhMTMgMTMgMCAwIDEt'
    b'MiA2LjRjLS41IDEuNi0xIDEtMi4zIDIuOWEyNS40IDI1LjQgMCAwIDEtNS4yIDEuMmMtMi41'
    b'LjQtOCAuOC0xMC45LjFhMjMgMjMgMCAwIDAgOS44LTYgMzAuNiAzMC42IDAgMCAwIDIuMS0y'
    b'LjUgMzMuNyAzMy43IDAgMCAwIDMtNC40bDEtMmEzMy45IDMzLjkgMCAwIDAgMS4zLTIuOSAy'
    b'OS44IDI5LjggMCAwIDAgMS0zbC4zLS4zLjYtLjIgMS0uMXoiLz4KICAgICAgICA8cGF0aCBm'
    b'aWxsPSIjYzZjYjI0IiBkPSJNNTMwIDI5OC45Yy0uNSA2LTIuMyAxMy4yLTYuNyAxNy44LTEu'
    b'NiAxLjMtMy43IDIuNi01LjYgMi4zIDYuNy01LjUgMTAuOC0xNCAxMi4yLTIwLjF6Ii8+CiAg'
    b'ICAgICAgPHBhdGggZmlsbD0iIzllY2IzNCIgZD0iTTUyNC41IDMwOS4zYy0xIDIuNy00Ljgg'
    b'Ni43LTguOCAxMGgtMi45YzIuNS0uMiA4LjMtNSAxMS43LTEweiIvPgogICAgICA8L2c+CiAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI25pLXQiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHg9Ii0xNS4zIi8+CiAgICAgIDxnIGZpbGw9IiNjNmNiMjQiPgogICAgICAgIDxwYXRoIGZp'
    b'bGw9InVybCgjbmktdSkiIGQ9Ik01MDIuMiAyOThjMi44IDEwLjUgMTEuOCAyMS4yIDIyLjYg'
    b'MjEuMmg4LjFWMzMwaC02NS44di0xMC44aDhjMTAuOCAwIDE5LjktMTAuNyAyMi42LTIxLjMg'
    b'MCAwIC42LS44IDIuMy0uOCAxLjcgMCAyLjIuOCAyLjIuOHoiLz4KICAgICAgICA8cGF0aCBm'
    b'aWxsPSIjOTdjOTI0IiBkPSJNNTAwIDI5Ny41Yy44IDAgMS4yLjIgMS41LjNsLjMuM2EzMy42'
    b'IDMzLjYgMCAwIDAgOC40IDE0LjdjNCA0LjEgOSA2LjkgMTQuNiA2LjloNy43djkuOWgtNjV2'
    b'LTEwaDcuN2M1LjUgMCAxMC42LTIuNyAxNC42LTYuOGEzMy42IDMzLjYgMCAwIDAgOC4zLTE0'
    b'LjdsLjMtLjNhMyAzIDAgMCAxIDEuNi0uM3oiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjZWRl'
    b'NzFmIiBkPSJNNDk5LjMgMjk3LjVhMy40IDMuNCAwIDAgMC0uMyAwbC0uNi4zLS4zLjNhMjgu'
    b'OSAyOC45IDAgMCAxLTEgMyAzNC4yIDM0LjIgMCAwIDEtMS4yIDMgMzQuMiAzNC4yIDAgMCAx'
    b'LTEgMS45IDMzLjYgMzMuNiAwIDAgMS0zIDQuNCAzMC43IDMwLjcgMCAwIDEtMi4xIDIuNCAy'
    b'MyAyMyAwIDAgMS05LjggNi4xYzIuOC43IDQgMCA2LjUtLjQgMi0uMyA0LjItLjYgNi0xLjIg'
    b'MS41LTIgMS0xLjMgMS41LTIuOSAxLjItMi4yIDMtNC4yIDMuNC02LjcgMS42LTMgMS45LTgu'
    b'NiAxLjktMTAuMnoiLz4KICAgICAgICA8cGF0aCBkPSJNNDk5LjMgMjk4LjljLS40IDYtMi4z'
    b'IDEzLjItNi43IDE3LjgtMS42IDEuMy0zLjYgMi42LTUuNiAyLjMgNi44LTUuNSAxMC45LTE0'
    b'IDEyLjMtMjAuMXoiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjOWVjYjM0IiBkPSJNNDkzLjgg'
    b'MzA5LjNhMzEgMzEgMCAwIDEtOC44IDEwaC0yLjhjMi41LS4yIDguMi01IDExLjYtMTB6Ii8+'
    b'CiAgICAgICAgPHBhdGggZmlsbD0iI2VkZTcxZiIgZD0ibTUwMSAyOTcuNi41LjIuNC4zYTMy'
    b'LjMgMzIuMyAwIDAgMCAxIDMgMzMuNiAzMy42IDAgMCAwIDEuMiAzbDEgMS45YTMzLjYgMzMu'
    b'NiAwIDAgMCAzIDQuNCAzMC43IDMwLjcgMCAwIDAgMi4xIDIuNCAyNCAyNCAwIDAgMCA5Ljgg'
    b'Ni41Yy03LjMgMC0xMC40LS42LTEzLTRhMTkgMTkgMCAwIDEtNC4yLTdjLS41LTItMi02LjUt'
    b'MS45LTEwLjd6Ii8+CiAgICAgICAgPHBhdGggZD0iTTUwMS41IDI5OC45Yy40IDYgMi4yIDEy'
    b'IDYuNiAxNi42IDEuNiAxLjQgMy42IDIuNiA1LjYgMi4zYTMxLjEgMzEuMSAwIDAgMS0xMi4y'
    b'LTE4Ljl6Ii8+CiAgICAgIDwvZz4KICAgICAgPGcgaWQ9Im5pLXciPgogICAgICAgIDxwYXRo'
    b'IGZpbGw9InVybCgjbmktdikiIGQ9Ik00ODQuOCAyOTdjLTEuOCAwLTIuMy45LTIuMy45LTIu'
    b'NSA5LjgtMTEuOCAyMi4zLTIxLjUgMjMuOGwtNC44IDguM2g0OXYtMTEuM2MtOC44LTIuNC0x'
    b'NS45LTExLjctMTguMi0yMC44IDAgMC0uNS0uOC0yLjMtLjh6Ii8+CiAgICAgICAgPHBhdGgg'
    b'ZmlsbD0iIzk3YzkyNCIgZD0iTTQ4NC44IDI5Ny41Yy0uOCAwLTEuMy4yLTEuNi4zbC0uMy4z'
    b'YTQzLjQgNDMuNCAwIDAgMS04LjEgMTVjLTMuNCA0LjMtOS43IDguNi0xNCA5bC00LjMgNy41'
    b'aDQ4di0xMC43YTIzLjIgMjMuMiAwIDAgMS05LjUtNiAzMy42IDMzLjYgMCAwIDEtOC40LTE0'
    b'LjhsLS4zLS4zYTIuOSAyLjkgMCAwIDAtMS41LS4zeiIvPgogICAgICAgIDxwYXRoIGZpbGw9'
    b'IiM5M2JjMzAiIGQ9Ik00ODMuNCAyOTguOWMtLjYgOS01LjYgMjAuNS0xMS4zIDIyLjQtMS45'
    b'LjctNS4xLjktNi4yIDFhMzYgMzYgMCAwIDAgMTcuNi0yMy40eiIvPgogICAgICAgIDxwYXRo'
    b'IGZpbGw9IiNlZGU3MWYiIGQ9Ik00ODQuOCAyOTcuNWgtLjV2MTAuOGMwIDIuMy45IDQuMiAy'
    b'IDYuNGwuMi41Yy41IDEuMS44IDEuNSAyLjMgMi43YTIyIDIyIDAgMCAwIDE0LjggNGMtMS4x'
    b'LS45LTIuMy0xLjctMy40LTIuNGw0LjUtLjVhMjMgMjMgMCAwIDEtOS43LTYuMiAzMC41IDMw'
    b'LjUgMCAwIDEtMS40LTEuNWwtLjYtLjhhMzUgMzUgMCAwIDEtMy4yLTQuNSAzNC4yIDM0LjIg'
    b'MCAwIDEtMS0yIDM0IDM0IDAgMCAxLTEuNi0zLjkgMzEuNyAzMS43IDAgMCAxLS42LTJsLS4z'
    b'LS4zYTIuMiAyLjIgMCAwIDAtLjYtLjIgMy42IDMuNiAwIDAgMC0xLS4xeiIvPgogICAgICAg'
    b'IDxwYXRoIGQ9Ik00ODUuNCAyOTguOWMuNSA2IDIuMyAxMy4yIDYuNyAxNy44IDEuNiAxLjMg'
    b'My42IDIuNiA1LjYgMi4zYTM4LjUgMzguNSAwIDAgMS0xMi4zLTIwLjF6Ii8+CiAgICAgICAg'
    b'PHBhdGggZmlsbD0iIzllY2IzNCIgZD0iTTQ4OS42IDMwNy4zYTM1IDM1IDAgMCAwIDE0LjYg'
    b'MTQuOWgyLjVjLTQuNC0yLjQtMTEuNS01LjgtMTctMTV6Ii8+CiAgICAgIDwvZz4KICAgICAg'
    b'PHVzZSB4bGluazpocmVmPSIjbmktdyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0i'
    b'LTE1LjQiIGZpbGw9IiNjNmNiMjQiLz4KICAgIDwvZz4KICAgIDxwYXRoIGZpbGw9IiNmZmYi'
    b'IGQ9Ik01NTYuNSAzMjQuN2MtLjYuMi00LjQtLjItNi40IDBsLTEuMy4zaC0zLjNjLTMuNiAw'
    b'LTYuNyAxLTEwLjEgMS0zLjQgMC02LjUtMS0xMC0xSDUyMmMtMy42IDAtNi43IDEtMTAuMSAx'
    b'LTMuNCAwLTYuNS0xLTEwLTFoLTMuNGMtMy42IDAtNi43IDEtMTAgMS0zLjUgMC02LjUtMS0x'
    b'MC4xLTFINDc1Yy0zLjYgMC02LjYgMS0xMCAxLTMuNSAwLTYuNS0xLTEwLjEtMWgtMy40Yy0y'
    b'LjggMC02LjIuNi04LjkuOGwtNi4zIDEwLjloMTI3LjR6Ii8+CiAgICA8cGF0aCBmaWxsPSJ1'
    b'cmwoI25pLXgpIiBkPSJNNTQ4IDMyMy4xaC0uNmMtMy4yLjEtNS42IDEuMS0xMS4yIDEuMXMt'
    b'Ni4yLTEtMTIuNi0uOGMtNiAwLTguNCAxLjItMTEuNyAxLjItMy4yIDAtOC40LS43LTEyLjUt'
    b'LjMtNCAuNC04LjggMS4zLTEyIDEuMy0zLjkgMC03LjgtLjctMTEuOC0uMy00LjEuNC02IDEu'
    b'NS0xMS4xIDEuNS00LjQgMC05LS43LTEyLjgtLjctMy40IDAtNy4yIDEtMTAgMS40bC0uOSAx'
    b'LjVjMi4zLS4zIDguNi0xLjMgMTAuOC0xLjMgMi40IDAgMTAuNy41IDE1LjMuMyA0LjctLjEg'
    b'NS4yLTEuMiAxMC43LTEuMiAzLjggMCA2LjYuNCAxMC41LjQgMi41IDAgNC43LTEuMiA4LjQt'
    b'MS4ybDIuOC0uMWMzLjEtLjUgOC40IDAgMTIgLjIgMy4zLjIgNS41LS42IDktLjdsNC40LS4x'
    b'YzMuNS0uMiA2LjQuNiA5LjcuNiAzLjItLjIgNi40LTEgOS44LTFsNC41LS4yYzIuMyAwIDUu'
    b'OSAwIDguMy41bC0uOC0xLjRjLTIuNC0uMS01LjMtLjctOC4yLS43eiIvPgogICAgPGcgaWQ9'
    b'Im5pLUEiPgogICAgICA8cGF0aCBpZD0ibmkteiIgZmlsbD0idXJsKCNuaS15KSIgZD0iTTQ1'
    b'MC4zIDMzNC44Yy0zLjQgMC02LjQuOC05LjYuOWEzMS44IDMxLjggMCAwIDEtMy42LS4zbC0u'
    b'NS44aDZjMy41IDAgNi40LS44IDkuNi0uOSAzLjMuMSA2LjIgMSA5LjcgMWg0LjVjMy40IDAg'
    b'Ni40LS45IDkuNi0xIDMuMy4xIDYuMyAxIDkuNyAxaDQuNWMzLjUgMCA2LjQtLjkgOS43LTEg'
    b'My4yLjEgNi4xIDEgOS42IDFoNC41YzMuNCAwIDYuNC0uOSA5LjctMSAzLjIuMSA2LjIgMSA5'
    b'LjYgMWg0LjVjMy41IDAgNi40LS45IDkuNi0xIDMuMy4xIDYuMiAxIDkuNyAxaDQuNWwxLjgt'
    b'LjEtLjUtLjhjLTEgLjEtMi4xLjMtMy4yLjMtMy4zIDAtNi4yLTEtOS43LTFoLTQuNWMtMy40'
    b'IDAtNi40IDEtOS42IDEtMy4zLS4xLTYuMi0xLTkuNy0xaC00LjVjLTMuNCAwLTYuNCAxLTku'
    b'NiAxLTMuMy0uMS02LjItMS05LjctMWgtNC41Yy0zLjUgMC02LjQgMS05LjYgMS0zLjMtLjEt'
    b'Ni4yLTEtOS43LTFoLTQuNWMtMy40IDAtNi40IDEtOS42IDEtMy4zLS4xLTYuMi0xLTkuNy0x'
    b'aC00LjV6Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI25pLXoiIHdpZHRoPSIxMDAlIiBo'
    b'ZWlnaHQ9IjEwMCUiIHk9Ii0xLjMiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjbmkteiIg'
    b'd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeT0iLTIuNiIvPgogICAgPC9nPgogICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjbmktQSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeT0iLTMu'
    b'OSIvPgogICAgPHVzZSB4bGluazpocmVmPSIjbmktQSIgd2lkdGg9IjEwMCUiIGhlaWdodD0i'
    b'MTAwJSIgeT0iLTcuNyIvPgogICAgPHBhdGggZmlsbD0iIzk3YzkyNCIgZD0ibTQ0My45IDMy'
    b'NC43LTIuNSA0LjJjMi45LS41IDcuMS0xLjcgMTAuNy0xLjcgMy42IDAgOCAuOSAxMi40IDEg'
    b'NSAwIDctMS4yIDExLTEuNiA0LjEtLjQgOCAuNSAxMiAuNiAzLjEgMCA3LjktMS4xIDEyLTEu'
    b'NSA0LS41IDcuNy4zIDEyLjUuMyA0LjkuMSA1LjctMS4yIDExLjYtMS4zIDYuNC0uMSA3IC45'
    b'IDEyLjYuOSA0LjIuMiA3LjktLjkgMTEuNy0xLjEgMy44LS4zIDUuNSAwIDguMyAwbC0xLjkt'
    b'My4yLTEwMS4zIDIuM3oiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im01NTAgMzI0LjYg'
    b'NCAuM2E5MS40IDkxLjQgMCAwIDAgMi45LjNsLS40LS41Yy0uNi4yLTQuNC0uMi02LjQgMHoi'
    b'Lz4KICA8L2c+CiAgPHBhdGggZmlsbD0iI2M4YTQwMCIgZD0ibTMyMCAxNzkuOS0yNS43IDQ0'
    b'LjVMMjY4IDI3MGgxMDRsLTI1LjctNDQuNkwzMjAgMTgwem0wIDIuNCAyNS4yIDQzLjcgMjQu'
    b'NyA0Mi44aC05OS44bDI1LjItNDMuOHoiLz4KPC9zdmc+Cg==', 'NI')

NI = b64_NI
index.append("NI")
index.append("NIC")
index.append("Nicaragua")
catalog["NI"] = NI
catalog["NIC"] = NI
catalog["Nicaragua"] = NI
country["Nicaragua"] = ('NI', 'NIC', 0)
lookup["NI"] = ('NI', 'NIC', 'Nicaragua', 0)
lookup["Managua Nicaragua"] = ('NI', 'NIC', 'Nicaragua', 0)
lookup["NIC"] = ('NI', 'NIC', 'Nicaragua', 0)
lookup["Nicaragua"] = ('NI', 'NIC', 'Nicaragua', 0)
details["NI"] = {"continent":"Americas","capital":"Managua","currency":"Cordoba Oro","web":".ni","lang":"es-NI | en","tz":"-06:00","altname":""}
#----------------------------------------------------------------------
b64_NL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5sIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzIxNDY4YiIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MzIw'
    b'SDB6Ii8+CiAgPHBhdGggZmlsbD0iI2FlMWMyOCIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+Cjwv'
    b'c3ZnPgo=', 'NL')

NL = b64_NL
index.append("NL")
index.append("NLD")
index.append("Netherlands")
catalog["NL"] = NL
catalog["NLD"] = NL
catalog["Netherlands"] = NL
country["Netherlands"] = ('NL', 'NLD', 0)
lookup["NL"] = ('NL', 'NLD', 'Netherlands', 0)
lookup["Amsterdam Netherlands"] = ('NL', 'NLD', 'Netherlands', 0)
lookup["NLD"] = ('NL', 'NLD', 'Netherlands', 0)
lookup["Netherlands"] = ('NL', 'NLD', 'Netherlands', 0)
details["NL"] = {"continent":"Europe","capital":"Amsterdam","currency":"Euro","web":".nl","lang":"nl-NL | fy-NL","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_NO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5vIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2VkMjkzOSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTE4MCAwaDEyMHY0'
    b'ODBIMTgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDE4MGg2NDB2MTIwSDB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzAwMjY2NCIgZD0iTTIxMCAwaDYwdjQ4MGgtNjB6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzAwMjY2NCIgZD0iTTAgMjEwaDY0MHY2MEgweiIvPgo8L3N2Zz4K', 'NO')

NO = b64_NO
index.append("NO")
index.append("NOR")
index.append("Norway")
catalog["NO"] = NO
catalog["NOR"] = NO
catalog["Norway"] = NO
country["Norway"] = ('NO', 'NOR', 0)
lookup["NO"] = ('NO', 'NOR', 'Norway', 0)
lookup["Oslo Norway"] = ('NO', 'NOR', 'Norway', 0)
lookup["NOR"] = ('NO', 'NOR', 'Norway', 0)
lookup["Norway"] = ('NO', 'NOR', 'Norway', 0)
details["NO"] = {"continent":"Europe","capital":"Oslo","currency":"Norwegian Krone","web":".no","lang":"no | nb | nn | se | fi","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_NP = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5wIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Im5wLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMC0xNmg1MTJ2NTEy'
    b'SDB6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBjbGlwLXBhdGg9InVybCgj'
    b'bnAtYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDAgMTUpIHNjYWxlKC45Mzc1KSI+CiAgICA8'
    b'ZyBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgICA8cGF0aCBmaWxsPSIjY2UwMDAwIiBzdHJv'
    b'a2U9IiMwMDAwNjMiIHN0cm9rZS13aWR0aD0iMTMuOCIgZD0iTTYuNSA0ODkuNWgzNzguOEwx'
    b'MzcuNCAyMzguMWwyNTcuMy4zTDYuNi05LjV2NDk5eiIvPgogICAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJtMTgwLjcgMzU1LjgtMjcgOSAyMS4yIDE5LjgtMjguNS0xLjggMTEuNyAyNi4y'
    b'LTI1LjUtMTIuMy41IDI4LjYtMTguOC0yMC45LTEwLjcgMjYuNi05LjItMjYuMy0yMC4zIDIw'
    b'LjYgMS44LTI3LjdMNDkgNDA5bDEyLjYtMjUtMjkuMy42IDIxLjUtMTguMy0yNy4zLTEwLjUg'
    b'MjctOUwzMi4yIDMyN2wyOC40IDEuOEw0OSAzMDIuNmwyNS42IDEyLjMtLjUtMjguNiAxOC44'
    b'IDIwLjkgMTAuNy0yNi42IDkuMSAyNi4zIDIwLjQtMjAuNi0xLjkgMjcuNyAyNy0xMS40LTEy'
    b'LjcgMjUgMjkuNC0uNi0yMS41IDE4LjN6bS0zMi40LTE4NC43LTExLjMgOC40IDUuNiA0LjZh'
    b'OTMuOCA5My44IDAgMCAwIDMwLjctMzZjMS44IDIxLjMtMTcuNyA2OS02OC43IDY5LjVhNzAu'
    b'NiA3MC42IDAgMCAxLTcxLjUtNzAuM2MxMCAxOC4yIDE2LjIgMjcgMzIgMzYuNWw0LjctNC40'
    b'LTEwLjYtOC45IDEzLjctMy42LTcuNC0xMi40IDE0LjQgMS0xLjgtMTQuNCAxMi42IDcuNCA0'
    b'LTEzLjUgOSAxMC44IDguNS0xMC4zIDQuNiAxNCAxMS44LTguMi0xLjUgMTQuMyAxNC4yLTEu'
    b'Ny02LjcgMTMuMiAxMy43IDR6Ii8+CiAgICA8L2c+CiAgPC9nPgo8L3N2Zz4K', 'NP')

NP = b64_NP
index.append("NP")
index.append("NPL")
index.append("Nepal")
catalog["NP"] = NP
catalog["NPL"] = NP
catalog["Nepal"] = NP
country["Nepal"] = ('NP', 'NPL', 0)
lookup["NP"] = ('NP', 'NPL', 'Nepal', 0)
lookup["Kathmandu Nepal"] = ('NP', 'NPL', 'Nepal', 0)
lookup["NPL"] = ('NP', 'NPL', 'Nepal', 0)
lookup["Nepal"] = ('NP', 'NPL', 'Nepal', 0)
details["NP"] = {"continent":"Asia","capital":"Kathmandu","currency":"Nepalese Rupee","web":".np","lang":"ne | en","tz":"+05:45","altname":""}
#----------------------------------------------------------------------
b64_NR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW5yIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Im5yLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTU0LjcgMEg2Mjh2'
    b'NTEySC01NC43eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI25yLWEpIiB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSg1MS4zKSBzY2FsZSguOTM3NSkiPgogICAgPHBhdGggZmls'
    b'bD0iIzAwMjE3MCIgZD0iTS0xNDAgMEg4ODR2NTEySC0xNDB6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjZmZiMjBkIiBkPSJNLTE0MCAyMzQuMUg4ODRWMjc4SC0xNDB6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJtMTYxLjggNDM4LTMzLTMzLTEwLjUgNDUuNC0xMi00NS0zMS45IDM0'
    b'IDEyLjEtNDVMNDIgNDA3LjlsMzMtMzMtNDUuNC0xMC42IDQ1LTEyLTM0LTMxLjggNDUgMTJM'
    b'NzIgMjg4bDMzIDMzIDEwLjYtNDUuNCAxMiA0NSAzMS44LTM0LTEyIDQ1IDQ0LjUtMTMuNS0z'
    b'MyAzMyA0NS40IDEwLjUtNDUgMTIgMzQgMzItNDUtMTIuMnoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'NR')

NR = b64_NR
index.append("NR")
index.append("NRU")
index.append("Nauru")
catalog["NR"] = NR
catalog["NRU"] = NR
catalog["Nauru"] = NR
country["Nauru"] = ('NR', 'NRU', 0)
lookup["NR"] = ('NR', 'NRU', 'Nauru', 0)
lookup["Yaren Nauru"] = ('NR', 'NRU', 'Nauru', 0)
lookup["NRU"] = ('NR', 'NRU', 'Nauru', 0)
lookup["Nauru"] = ('NR', 'NRU', 'Nauru', 0)
details["NR"] = {"continent":"Oceania","capital":"Yaren","currency":"Australian Dollar","web":".nr","lang":"na | en-NR","tz":"+12:00","altname":""}
#----------------------------------------------------------------------
b64_NU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW51IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZlZGQwMCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAxMjE2OSIgZD0iTTAgMGgzMjB2'
    b'MjQwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTM3LjUgMCAxMjIgOTAuNUwyODEg'
    b'MGgzOXYzMWwtMTIwIDg5LjUgMTIwIDg5VjI0MGgtNDBsLTEyMC04OS41TDQwLjUgMjQwSDB2'
    b'LTMwbDExOS41LTg5TDAgMzJWMHoiLz4KICA8cGF0aCBmaWxsPSIjYzgxMDJlIiBkPSJNMjEy'
    b'IDE0MC41IDMyMCAyMjB2MjBsLTEzNS41LTk5LjV6bS05MiAxMCAzIDE3LjUtOTYgNzJIMHpN'
    b'MzIwIDB2MS41bC0xMjQuNSA5NCAxLTIyTDI5NSAwek0wIDBsMTE5LjUgODhoLTMwTDAgMjF6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTEyMC41IDB2MjQwaDgwVjB6TTAgODB2ODBo'
    b'MzIwVjgweiIvPgogIDxwYXRoIGZpbGw9IiNjODEwMmUiIGQ9Ik0wIDk2LjV2NDhoMzIwdi00'
    b'OHpNMTM2LjUgMHYyNDBoNDhWMHoiLz4KICA8Y2lyY2xlIGN4PSIxNjAiIGN5PSIxMjAiIHI9'
    b'IjQwLjgiIGZpbGw9IiMwMTIxNjkiLz4KICA8cGF0aCBmaWxsPSIjZmVkZDAwIiBkPSJtMTYw'
    b'IDc5LjIgMjQgNzMuOC02Mi44LTQ1LjZoNzcuNkwxMzYgMTUzTTY2LjcgOTguM2wxNCA0My40'
    b'TDQzLjkgMTE1aDQ1LjdsLTM3IDI2LjhtMjAwLjctNDMuNSAxNC4xIDQzLjQtMzYuOS0yNi44'
    b'aDQ1LjdsLTM3IDI2LjhNMTYwIDE3OC4zbDE0LjEgNDMuNC0zNy0yNi44aDQ1LjdsLTM3IDI2'
    b'LjhNMTYwIDE4LjNsMTQuMSA0My40LTM3LTI2LjhoNDUuN2wtMzcgMjYuOCIvPgo8L3N2Zz4K', 'NU')

NU = b64_NU
index.append("NU")
index.append("NIU")
index.append("Niue")
catalog["NU"] = NU
catalog["NIU"] = NU
catalog["Niue"] = NU
country["Niue"] = ('NU', 'NIU', 0)
lookup["NU"] = ('NU', 'NIU', 'Niue', 0)
lookup["Alofi Niue"] = ('NU', 'NIU', 'Niue', 0)
lookup["NIU"] = ('NU', 'NIU', 'Niue', 0)
lookup["Niue"] = ('NU', 'NIU', 'Niue', 0)
details["NU"] = {"continent":"Oceania","capital":"Alofi","currency":"New Zealand Dollar","web":".nu","lang":"niu | en-NU","tz":"-11:00","altname":""}
#----------------------------------------------------------------------
b64_NZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ueiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGcgaWQ9Im56LWIiPgogICAgICA8ZyBp'
    b'ZD0ibnotYSI+CiAgICAgICAgPHBhdGggZD0iTTAtLjN2LjVsMS0uNXoiLz4KICAgICAgICA8'
    b'cGF0aCBkPSJNLjIuMyAwLS4xbDEtLjJ6Ii8+CiAgICAgIDwvZz4KICAgICAgPHVzZSB4bGlu'
    b'azpocmVmPSIjbnotYSIgdHJhbnNmb3JtPSJzY2FsZSgtMSAxKSIvPgogICAgICA8dXNlIHhs'
    b'aW5rOmhyZWY9IiNuei1hIiB0cmFuc2Zvcm09InJvdGF0ZSg3MiAwIDApIi8+CiAgICAgIDx1'
    b'c2UgeGxpbms6aHJlZj0iI256LWEiIHRyYW5zZm9ybT0icm90YXRlKC03MiAwIDApIi8+CiAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI256LWEiIHRyYW5zZm9ybT0ic2NhbGUoLTEgMSkgcm90'
    b'YXRlKDcyKSIvPgogICAgPC9nPgogIDwvZGVmcz4KICA8cGF0aCBmaWxsPSIjMDAyNDdkIiBm'
    b'aWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogIDxnIHRyYW5zZm9y'
    b'bT0idHJhbnNsYXRlKC0xMTEgMzYuMSkgc2NhbGUoLjY2ODI1KSI+CiAgICA8dXNlIHhsaW5r'
    b'OmhyZWY9IiNuei1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSIjZmZmIiB0'
    b'cmFuc2Zvcm09Im1hdHJpeCg0NS40IDAgMCA0NS40IDkwMCAxMjApIi8+CiAgICA8dXNlIHhs'
    b'aW5rOmhyZWY9IiNuei1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSIjY2Mx'
    b'NDJiIiB0cmFuc2Zvcm09Im1hdHJpeCgzMCAwIDAgMzAgOTAwIDEyMCkiLz4KICA8L2c+CiAg'
    b'PGcgdHJhbnNmb3JtPSJyb3RhdGUoODIgNTI1LjIgMTE0LjYpIHNjYWxlKC42NjgyNSkiPgog'
    b'ICAgPHVzZSB4bGluazpocmVmPSIjbnotYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIg'
    b'ZmlsbD0iI2ZmZiIgdHJhbnNmb3JtPSJyb3RhdGUoLTgyIDUxOSAtNDU3LjcpIHNjYWxlKDQw'
    b'LjQpIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNuei1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0'
    b'PSIxMDAlIiBmaWxsPSIjY2MxNDJiIiB0cmFuc2Zvcm09InJvdGF0ZSgtODIgNTE5IC00NTcu'
    b'Nykgc2NhbGUoMjUpIi8+CiAgPC9nPgogIDxnIHRyYW5zZm9ybT0icm90YXRlKDgyIDUyNS4y'
    b'IDExNC42KSBzY2FsZSguNjY4MjUpIj4KICAgIDx1c2UgeGxpbms6aHJlZj0iI256LWIiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9IiNmZmYiIHRyYW5zZm9ybT0icm90YXRl'
    b'KC04MiA2NjguNiAtMzI3LjcpIHNjYWxlKDQ1LjQpIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9'
    b'IiNuei1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSIjY2MxNDJiIiB0cmFu'
    b'c2Zvcm09InJvdGF0ZSgtODIgNjY4LjYgLTMyNy43KSBzY2FsZSgzMCkiLz4KICA8L2c+CiAg'
    b'PGcgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTExMSAzNi4xKSBzY2FsZSguNjY4MjUpIj4KICAg'
    b'IDx1c2UgeGxpbms6aHJlZj0iI256LWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZp'
    b'bGw9IiNmZmYiIHRyYW5zZm9ybT0ibWF0cml4KDUwLjQgMCAwIDUwLjQgOTAwIDQ4MCkiLz4K'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI256LWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IGZpbGw9IiNjYzE0MmIiIHRyYW5zZm9ybT0ibWF0cml4KDM1IDAgMCAzNSA5MDAgNDgwKSIv'
    b'PgogIDwvZz4KICA8cGF0aCBmaWxsPSIjMDEyMTY5IiBkPSJNMCAwaDMyMHYyNDBIMHoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMzcuNSAwIDEyMiA5MC41TDI4MSAwaDM5djMxbC0x'
    b'MjAgODkuNSAxMjAgODlWMjQwaC00MGwtMTIwLTg5LjVMNDAuNSAyNDBIMHYtMzBsMTE5LjUt'
    b'ODlMMCAzMlYweiIvPgogIDxwYXRoIGZpbGw9IiNjODEwMmUiIGQ9Ik0yMTIgMTQwLjUgMzIw'
    b'IDIyMHYyMGwtMTM1LjUtOTkuNXptLTkyIDEwIDMgMTcuNS05NiA3Mkgwek0zMjAgMHYxLjVs'
    b'LTEyNC41IDk0IDEtMjJMMjk1IDB6TTAgMGwxMTkuNSA4OGgtMzBMMCAyMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNMTIwLjUgMHYyNDBoODBWMHpNMCA4MHY4MGgzMjBWODB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0iTTAgOTYuNXY0OGgzMjB2LTQ4ek0xMzYuNSAw'
    b'djI0MGg0OFYweiIvPgo8L3N2Zz4K', 'NZ')

NZ = b64_NZ
index.append("NZ")
index.append("NZL")
index.append("New Zealand")
catalog["NZ"] = NZ
catalog["NZL"] = NZ
catalog["New Zealand"] = NZ
country["New Zealand"] = ('NZ', 'NZL', 0)
lookup["NZ"] = ('NZ', 'NZL', 'New Zealand', 0)
lookup["Wellington New Zealand"] = ('NZ', 'NZL', 'New Zealand', 0)
lookup["NZL"] = ('NZ', 'NZL', 'New Zealand', 0)
lookup["New Zealand"] = ('NZ', 'NZL', 'New Zealand', 0)
details["NZ"] = {"continent":"Oceania","capital":"Wellington","currency":"New Zealand Dollar","web":".nz","lang":"en-NZ | mi","tz":"+12:00","altname":""}
#----------------------------------------------------------------------
b64_OM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LW9tIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'Im9tLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGNsaXAtcGF0aD0idXJsKCNv'
    b'bS1hKSI+CiAgICA8cGF0aCBmaWxsPSIjZWYyZDI5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0tMy4zLTIxLjZINjk5djU1M0gtMy4zeiIvPgogICAgPHBhdGggZmlsbD0iIzAwOTAyNSIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMTc0LjYgMzE3LjNoNTM1LjdWNTI1SDE3NC42eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMTc0LjYt'
    b'MzUuNGg1NjQuOXYxOTBoLTU2NXoiLz4KICAgIDxnIHN0cm9rZT0iI2VmMmQyOCI+CiAgICAg'
    b'IDxnIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'LjE5ODQ4IDAgMCAuMTc3NDQgMTExLjMgLTEzLjQpIj4KICAgICAgICA8cmVjdCB3aWR0aD0i'
    b'MTM4LjIiIGhlaWdodD0iODUiIHg9IjE3LjciIHk9IjQ2Ny43IiBzdHJva2Utd2lkdGg9IjEu'
    b'NCIgcng9IjExLjMiIHJ5PSIxMS44Ii8+CiAgICAgICAgPHJlY3Qgd2lkdGg9IjEzMS4xIiBo'
    b'ZWlnaHQ9Ijc4IiB4PSIyMS4zIiB5PSI0NzEuMyIgc3Ryb2tlLXdpZHRoPSIxLjMiIHJ4PSIx'
    b'MC43IiByeT0iMTAuOSIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS4zIiBkPSJt'
    b'NjUgMzk2IDkuNy41LjQgNS44IDggNS4zIDYuMi02LjcgNy41IDUuMy03IDUuOCAxLjcgOCA4'
    b'LjgtLjVWNDMwbC03LS40LTMuNiA2LjYgOCA3LjUtNi4yIDYuMi02LjctNi42LTkuNyAyLjYu'
    b'NSA5LjctMTAuNiAxLTEuNC05LjQtOC44LTQuOC00LjkgNi42LTcuNS00LjkgNC40LTcuNS01'
    b'LjMtNC44SDM0bC0uNC0xMy43IDcuNS45IDUuMy04LTYuMi02LjIgOC03IDUuNyA1LjcgOS43'
    b'LTEuOEw2NSAzOTZ6IiB0cmFuc2Zvcm09Im1hdHJpeCguNjgxMDggMCAwIC41ODUyIDM4IDI2'
    b'MC43KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSI2OC45IiBjeT0iNDI2LjgiIHN0cm9rZS13'
    b'aWR0aD0iMS4zIiByeD0iMTEuMSIgcnk9IjkuOSIgdHJhbnNmb3JtPSJtYXRyaXgoLjY1ODE5'
    b'IDAgMCAuNzAyMjQgMzguOCAyMDkuNikiLz4KICAgICAgICA8cGF0aCBzdHJva2Utd2lkdGg9'
    b'IjEuMyIgZD0ibTM5IDQ3NC44LTEwLjcgMTAuNm0xNy44LTEwLjYtMTAuNyAxMC42bTE3Ljct'
    b'MTAuNi0xMC42IDEwLjZtMTcuNy0xMC42LTEwLjYgMTAuNm0xNy43LTEwLjYtMTAuNiAxMC42'
    b'bTE3LjctMTAuNi0xMC42IDEwLjZtMTcuNy0xMC42LTEwLjYgMTAuNm0xNy43LTEwLjZMNzgg'
    b'NDg1LjRtMTcuNy0xMC42TDg1IDQ4NS40bTE3LjgtMTAuNkw5MiA0ODUuNG0xNy43LTEwLjYt'
    b'MTAuNiAxMC42bTE3LjctMTAuNi0xMC42IDEwLjZtLTE3LjctMTAuNkw3OCA0ODUuNG00Ni0x'
    b'MC42LTEwLjYgMTAuNm0xNy43LTEwLjYtMTAuNiAxMC42bTE3LjctMTAuNi0xMC42IDEwLjZt'
    b'MTcuNy0xMC42LTEwLjYgMTAuNm0wLTEwLjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAuNiAx'
    b'MC42bS0xNy43LTEwLjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAuNiAxMC42bS0xNy43LTEw'
    b'LjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAuNyAxMC42'
    b'TTg1IDQ3NC44bDEwLjYgMTAuNm0tMTcuOC0xMC42IDEwLjcgMTAuNm0tMTcuNy0xMC42IDEw'
    b'LjYgMTAuNm0tMTcuNy0xMC42IDEwLjYgMTAuNm0tMTcuNy0xMC42IDEwLjYgMTAuNk04NSA0'
    b'NzQuOGwxMC42IDEwLjZtLTQ2LTEwLjYgMTAuNSAxMC42bS0xNy43LTEwLjYgMTAuNyAxMC42'
    b'bS0xNy44LTEwLjZMNDYgNDg1LjRtLTE3LjgtMTAuNkwzOSA0ODUuNG0wIDQ5LjYtMTAuNiAx'
    b'MC43TTQ2IDUzNWwtMTAuNyAxMC43TTUzLjIgNTM1bC0xMC43IDEwLjdNNjAuMiA1MzVsLTEw'
    b'LjYgMTAuN002Ny4zIDUzNWwtMTAuNiAxMC43TTc0LjQgNTM1bC0xMC42IDEwLjdNODEuNSA1'
    b'MzUgNzEgNTQ1LjdNODguNiA1MzUgNzggNTQ1LjdNOTUuNyA1MzUgODUgNTQ1LjdtMTcuNy0x'
    b'MC43TDkyIDU0NS43bTE4LTEwLjctMTAuNyAxMC43TTExNyA1MzVsLTEwLjYgMTAuN004OC42'
    b'IDUzNSA3OCA1NDUuN200Ni0xMC43LTEwLjYgMTAuN20xNy43LTEwLjctMTAuNiAxMC43bTE3'
    b'LjctMTAuNy0xMC42IDEwLjdtMTcuNy0xMC43LTEwLjYgMTAuN20wLTEwLjcgMTAuNiAxMC43'
    b'TTEyNy42IDUzNWwxMC42IDEwLjdNMTIwLjUgNTM1bDEwLjYgMTAuN00xMTMuNCA1MzVsMTAu'
    b'NiAxMC43TTEwNi4zIDUzNWwxMC42IDEwLjdNOTkuMiA1MzVsMTAuNyAxMC43TTkyIDUzNWwx'
    b'MC43IDEwLjdNODUgNTM1bDEwLjYgMTAuN003OCA1MzVsMTAuNiAxMC43TTcwLjkgNTM1bDEw'
    b'LjYgMTAuN002My44IDUzNWwxMC42IDEwLjdNNTYuNyA1MzVsMTAuNiAxMC43TTg1LjEgNTM1'
    b'bDEwLjYgMTAuN20tNDYtMTAuNyAxMC41IDEwLjdNNDIuNSA1MzVsMTAuNyAxMC43TTM1LjQg'
    b'NTM1bDEwLjcgMTAuN00yOC40IDUzNSAzOSA1NDUuNyIvPgogICAgICA8L2c+CiAgICAgIDxn'
    b'IGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgdHJhbnNmb3JtPSJtYXRyaXgoLjE5'
    b'ODQ4IDAgMCAuMTc3NDQgMTkuMSAtMTQpIj4KICAgICAgICA8cmVjdCB3aWR0aD0iMTM4LjIi'
    b'IGhlaWdodD0iODUiIHg9IjE3LjciIHk9IjQ2Ny43IiBzdHJva2Utd2lkdGg9IjEuNCIgcng9'
    b'IjExLjMiIHJ5PSIxMS44Ii8+CiAgICAgICAgPHJlY3Qgd2lkdGg9IjEzMS4xIiBoZWlnaHQ9'
    b'Ijc4IiB4PSIyMS4zIiB5PSI0NzEuMyIgc3Ryb2tlLXdpZHRoPSIxLjMiIHJ4PSIxMC43IiBy'
    b'eT0iMTAuOSIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS4zIiBkPSJtNjUgMzk2'
    b'IDkuNy41LjQgNS44IDggNS4zIDYuMi02LjcgNy41IDUuMy03IDUuOCAxLjcgOCA4LjgtLjVW'
    b'NDMwbC03LS40LTMuNiA2LjYgOCA3LjUtNi4yIDYuMi02LjctNi42LTkuNyAyLjYuNSA5Ljct'
    b'MTAuNiAxLTEuNC05LjQtOC44LTQuOC00LjkgNi42LTcuNS00LjkgNC40LTcuNS01LjMtNC44'
    b'SDM0bC0uNC0xMy43IDcuNS45IDUuMy04LTYuMi02LjIgOC03IDUuNyA1LjcgOS43LTEuOEw2'
    b'NSAzOTZ6IiB0cmFuc2Zvcm09Im1hdHJpeCguNjgxMDggMCAwIC41ODUyIDM4IDI2MC43KSIv'
    b'PgogICAgICAgIDxlbGxpcHNlIGN4PSI2OC45IiBjeT0iNDI2LjgiIHN0cm9rZS13aWR0aD0i'
    b'MS4zIiByeD0iMTEuMSIgcnk9IjkuOSIgdHJhbnNmb3JtPSJtYXRyaXgoLjY1ODE5IDAgMCAu'
    b'NzAyMjQgMzguOCAyMDkuNikiLz4KICAgICAgICA8cGF0aCBzdHJva2Utd2lkdGg9IjEuMyIg'
    b'ZD0ibTM5IDQ3NC44LTEwLjcgMTAuNm0xNy44LTEwLjYtMTAuNyAxMC42bTE3LjctMTAuNi0x'
    b'MC42IDEwLjZtMTcuNy0xMC42LTEwLjYgMTAuNm0xNy43LTEwLjYtMTAuNiAxMC42bTE3Ljct'
    b'MTAuNi0xMC42IDEwLjZtMTcuNy0xMC42LTEwLjYgMTAuNm0xNy43LTEwLjZMNzggNDg1LjRt'
    b'MTcuNy0xMC42TDg1IDQ4NS40bTE3LjgtMTAuNkw5MiA0ODUuNG0xNy43LTEwLjYtMTAuNiAx'
    b'MC42bTE3LjctMTAuNi0xMC42IDEwLjZtLTE3LjctMTAuNkw3OCA0ODUuNG00Ni0xMC42LTEw'
    b'LjYgMTAuNm0xNy43LTEwLjYtMTAuNiAxMC42bTE3LjctMTAuNi0xMC42IDEwLjZtMTcuNy0x'
    b'MC42LTEwLjYgMTAuNm0wLTEwLjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAuNiAxMC42bS0x'
    b'Ny43LTEwLjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAu'
    b'NiAxMC42bS0xNy43LTEwLjYgMTAuNiAxMC42bS0xNy43LTEwLjYgMTAuNyAxMC42TTg1IDQ3'
    b'NC44bDEwLjYgMTAuNm0tMTcuOC0xMC42IDEwLjcgMTAuNm0tMTcuNy0xMC42IDEwLjYgMTAu'
    b'Nm0tMTcuNy0xMC42IDEwLjYgMTAuNm0tMTcuNy0xMC42IDEwLjYgMTAuNk04NSA0NzQuOGwx'
    b'MC42IDEwLjZtLTQ2LTEwLjYgMTAuNSAxMC42bS0xNy43LTEwLjYgMTAuNyAxMC42bS0xNy44'
    b'LTEwLjZMNDYgNDg1LjRtLTE3LjgtMTAuNkwzOSA0ODUuNG0wIDQ5LjYtMTAuNiAxMC43TTQ2'
    b'IDUzNWwtMTAuNyAxMC43TTUzLjIgNTM1bC0xMC43IDEwLjdNNjAuMiA1MzVsLTEwLjYgMTAu'
    b'N002Ny4zIDUzNWwtMTAuNiAxMC43TTc0LjQgNTM1bC0xMC42IDEwLjdNODEuNSA1MzUgNzEg'
    b'NTQ1LjdNODguNiA1MzUgNzggNTQ1LjdNOTUuNyA1MzUgODUgNTQ1LjdtMTcuNy0xMC43TDky'
    b'IDU0NS43bTE4LTEwLjctMTAuNyAxMC43TTExNyA1MzVsLTEwLjYgMTAuN004OC42IDUzNSA3'
    b'OCA1NDUuN200Ni0xMC43LTEwLjYgMTAuN20xNy43LTEwLjctMTAuNiAxMC43bTE3LjctMTAu'
    b'Ny0xMC42IDEwLjdtMTcuNy0xMC43LTEwLjYgMTAuN20wLTEwLjcgMTAuNiAxMC43TTEyNy42'
    b'IDUzNWwxMC42IDEwLjdNMTIwLjUgNTM1bDEwLjYgMTAuN00xMTMuNCA1MzVsMTAuNiAxMC43'
    b'TTEwNi4zIDUzNWwxMC42IDEwLjdNOTkuMiA1MzVsMTAuNyAxMC43TTkyIDUzNWwxMC43IDEw'
    b'LjdNODUgNTM1bDEwLjYgMTAuN003OCA1MzVsMTAuNiAxMC43TTcwLjkgNTM1bDEwLjYgMTAu'
    b'N002My44IDUzNWwxMC42IDEwLjdNNTYuNyA1MzVsMTAuNiAxMC43TTg1LjEgNTM1bDEwLjYg'
    b'MTAuN20tNDYtMTAuNyAxMC41IDEwLjdNNDIuNSA1MzVsMTAuNyAxMC43TTM1LjQgNTM1bDEw'
    b'LjcgMTAuN00yOC40IDUzNSAzOSA1NDUuNyIvPgogICAgICA8L2c+CiAgICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRoPSIxLjMiIGQ9Ik01'
    b'MzguNiA1MzEuNWMxLjcgMTY2LjYgMjQuOCAyMDIgMy41IDIwMnMtMzEuOS05Mi4xLTMxLjkt'
    b'MjA1LjUgMTQuMi0yMDUuNSAzNS41LTIwNS41LTkgMzEuOS03LjEgMjA5eiIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoLS4zMjEzNiAtLjEyNjg0IC0uMjAxNTggLjIwMjIxIDM0NS45IDYxLjQpIi8+'
    b'CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjIiIGQ9Im01NDUuNyA3NzkuNS02MC4zIDE3LjdjNTYuNyA2MC4zIDEyMC41IDg1'
    b'IDEzOC4yIDc0LjQgMTcuNy0xMC42LTMxLjktMzUuNC03OC05MnoiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC0uMTk4NDggMCAwIC4xNzc0NCAxNDUuMyAtMTMuNCkiLz4KICAgICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjEuMyIgZD0ibTU0'
    b'Ny4zIDc4Ni45LTUxIDE0LjdjNTYuNyA2MC4zIDExMi44IDc3LjQgMTI3LjMgNzAgMTQuNi03'
    b'LjMtMzAuMy0yOC03Ni4zLTg0Ljd6IiB0cmFuc2Zvcm09Im1hdHJpeCgtLjE5MzM0IDAgMCAu'
    b'MTcwNjIgMTQyLjggLTguMSkiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjgiIGQ9Ik0zNTMuMSA2MzQuMmMuMiAxLjMuOCA3LjEgMS4zIDkuNCAwIDMuMi4z'
    b'IDUuNi42IDguMS44IDIuMi43IDQuMiAzLjEgNWE5LjkgOS45IDAgMCAwIDUgNC40IDI3Ljcg'
    b'MjcuNyAwIDAgMCA2LjMgMy44IDExLjYgMTEuNiAwIDAgMCA3LjUuNmMyLjItMS41IDMuOC0z'
    b'LjEgNS42LTQuNC40LTIgLjgtNC45IDEuMy02LjlhMzIuNiAzMi42IDAgMCAwLTEuMyA4LjJj'
    b'LjIgMyAxLjMgNC40IDIuNSA2LjgiIHRyYW5zZm9ybT0ibWF0cml4KC0uMTM5NzggMCAwIC4x'
    b'MjQxNCAxMjMgMjAuNCkiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRo'
    b'PSIxLjgiIGQ9Im0zODkuNCA2ODEuNy42LS42Yy0xLjUgMS41LS45LjggMi41LTEuMyAyLjQt'
    b'MS4yIDUtMS44IDguMS0yLjRoOC44YzMuNCAwIDUuNy41IDguMSAxLjIgMS44IDEuOCA0LjQg'
    b'Mi44IDYuMyA0LjRhMTEgMTEgMCAwIDEgMy43IDVjMS43IDEuNyAyLjggNC4zIDQuNCA1LjYu'
    b'NyAyLjkgMi4xIDIuOCAzLjEgNS0zIC4yLTUuMy42LTYuOSAyLjUtMi42IDEuMyAyLjItMS4z'
    b'IDMuMi0yLjUgMi0uNiAyLjUtMS4yIDUuNi0xLjIgMi44LTEgNC42LjcgNy41IDEuMiAxLjcg'
    b'MSAyLjIgMS4zIDQuNCAxLjMiIHRyYW5zZm9ybT0ibWF0cml4KC0uMTM5NzggMCAwIC4xMjQx'
    b'NCAxMjQuOSAxOS43KSIvPgogICAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2Utd2lkdGg9'
    b'IjEuOCIgZD0iTTQzOC4xIDcyNC45YzEuMyAwIDcuMSAxLjEgOS40IDAgMi42LS43IDQtMiA1'
    b'LjYtNC40LjgtMS43IDAgMyAwIDUgLjMgMy43IDEuNCAzLjcgMy4yIDYuMiAxLjggMS4yIDMu'
    b'NyAyLjggNS42IDMuOGExOCAxOCAwIDAgMCA1LjYgMy4xYzIgMSA0LjEgMS44IDUuNiAzLjEg'
    b'Mi4xIDEuNSAyIDMuMyAzLjIgNS43LS4zIDMtLjggNC44LTIuNSA2LjItLjggMi4xLTIuNCA0'
    b'LjItMy44IDUuNi0xLjUgMy0zLjMgNC4zLjYgNSAyLjIgMSAzLjQuMiA1LjcgMCIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLS4xMzk3OCAwIDAgLjEyNDE0IDEyNyAxOC4yKSIvPgogICAgICA8cGF0'
    b'aCBmaWxsPSJub25lIiBzdHJva2Utd2lkdGg9IjEuOCIgZD0iTTQ4MC42IDc3MS43YzEuNi0u'
    b'NCA3LTIuMiA5LjQtMy4xaDguOGMzLjMuMyA0IDEuMyA2LjggMi41IDEuOSAxLjkgMy4xIDMu'
    b'MiA1LjcgNC40IDEuMyAxLjcgNCA0LjcgNSA2LjlhMjUuNSAyNS41IDAgMCAxIDEuMiA4YzAg'
    b'My43LTEgNC40LTEuMiA3LjZhMTkuMyAxOS4zIDAgMCAxLTMuOCA3LjVjLS4zLjgtLjUgMS0x'
    b'LjIgMS4yIiB0cmFuc2Zvcm09Im1hdHJpeCgtLjEzOTc4IDAgMCAuMTI0MTQgMTI3LjQgMTcu'
    b'OCkiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIyLjMiIGQ9Ik01'
    b'MzguMSA4MThjLjQgMCAxLjIgMiAyLjUgMy43IDIuOSAzIDMuMiAzLjIgNy41IDMuMiA0LS4y'
    b'IDMuNS0xLjYgNi4zLTIuNSAxLjMtMiAyLjktMy42IDQuNC02LjMgMS0xLjYgMS45LTQuMSAz'
    b'LTUuNiAxLjItMS45IDIuNi0zLjMgMy44LTUgMS4yLS41IDEuNi0xIDMuMi0xLjMtMy42LjYt'
    b'NCAxLjktNi4zIDMuOGE1OC45IDU4LjkgMCAwIDAtMy4xIDUuNmMtLjQgMi43LTEuMiA0Ljgt'
    b'MS4zIDguMSAwIDMuNSAwIDUuOSAxLjMgOC44IDEuNSAxLjUgMi41IDMuMSA0LjQgNC40YTM2'
    b'LjcgMzYuNyAwIDAgMSA0LjMgNWw1LjcgMy43YzEuOCAxLjEgMy45IDIuMiA2LjggMi41IDMu'
    b'Ny0uMyA0LjgtMS4zIDcuNS0yLjUgMi40LTEuNyA0LjItMi44IDYuMy00LjRhMjEgMjEgMCAw'
    b'IDAgNC40LTVjMy4zLS44IDUuNS0uNSA3LjUgMS4zYTE2LjUgMTYuNSAwIDAgMSA0LjMgNC40'
    b'YzEgLjUgMi44IDIgMy44IDIuNSIgdHJhbnNmb3JtPSJtYXRyaXgoLS4wOTkyNCAwIDAgLjA5'
    b'Nzk5IDEwOS41IDM4LjgpIi8+CiAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZS13aWR0'
    b'aD0iMS45IiBkPSJNNTAzLjggODM2LjFjLS44LjMtMy44IDIuNC01IDMuMS0uOCAyLjctMi4x'
    b'IDQuMS0yLjUgNy0uNyAyLjYtLjcgNS42LS43IDguNy43IDMuMiAyIDUuNSAzLjIgOCAyIDEu'
    b'NCAzIDIuNCA1LjYgMy44IDIuNS40IDUgLjcgOC4xLjcgMiAuNiA1LjYuOSA3LjUgMCAyLjgt'
    b'LjQgNC45LTEuNSA2LjktMi41IDIuMy0xLjMgMy43LTIuNiA2LjItMy44IDEuMy0xLjggMy4y'
    b'LTMuNSA1LTUuNiAxLjYtMi4xIDIuNy0zLjMgMy44LTUuNi0xIDIuNi0yLjMgNS0zLjEgNy41'
    b'LTEuNSAyLjYtMi4zIDMuNi0yLjUgNi44LTEgMi42LS43IDUuOC0uNyA4LjguMyAyIC40IDUu'
    b'OCAxLjMgNy41djEuOSIgdHJhbnNmb3JtPSJtYXRyaXgoLS4xMjMzOCAwIDAgLjEyMjI5IDEx'
    b'MS40IDE5LjMpIi8+CiAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZS13aWR0aD0iMS4y'
    b'IiBkPSJNNTQxLjMgNzk5LjJ2LjdjMC0xLjcgMC0uOS0uNyAyLjUtMS4xIDEuNC00IDEuOC02'
    b'LjIgMS4yLTItMS43LTItMy01LjYtMy43LTMuNi4yLTUgMS4yLTcgMi41YTkuNSA5LjUgMCAw'
    b'IDAtNSA0LjNjLS43IDIuMS0xLjEgMy42IDEuMyA0LjRhMTUuMiAxNS4yIDAgMCAwIDcgMi41'
    b'YzIuOCAwIDQuOS0uMyA2LjIgMS4zIDIgMiAxLjggMy4yIDEuOCA2LjguNyAxLjEuOCA0LjQg'
    b'MS4zIDUuN2ExMC42IDEwLjYgMCAwIDAgNS42IDEuMmMuNy0yIDEuNC01LjQgMS45LTcuNS41'
    b'LTIuMi42LTUuNCAxLjktNi45YTE2LjYgMTYuNiAwIDAgMSA0LjMtNC40IDggOCAwIDAgMSAz'
    b'LjgtMi40Yy0yLjUgMS4yLTIuOCAyLjYtMy4xIDUuNiAyLjEgMSAyLjcgMS44IDYuMiAxLjkg'
    b'My41LS4zIDQuMy0xLjIgNS42LTMuMi4zIDMuMiAxLjMgNC4yIDIgNyAxLjIgMS44IDEuNyAz'
    b'LjcgMyA2LjItLjUgMy0xLjcgMy4xLTEuOCA2LjgtLjggMi41LS44IDQuOC0yLjUgNi4zLS44'
    b'IDEtMS40IDEuMS0zLjIgMS4yIDMuNiAwIDUuOC0uNCA4LjItMS44IDEuOC0xLjIgMy4yLTIu'
    b'NiA1LTMuOGEyMy45IDIzLjkgMCAwIDEgNy41LTMuOGMyLjkgMCA1LS4zIDYuMiAxLjMgMS44'
    b'IDEuMyAzIDMuNSAzLjggNi4zLjUgMy4yLjggNS40LS43IDcuNS0xIDIuNC0xLjMgMy4zIDAg'
    b'Ni4yIDEuNSAyIDMuNiAyLjMgNyAzLjEgMi4zLS4xIDQuNi0uNiA2LjItMS4yIiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgtLjE5ODQ4IDAgMCAuMTc3NDQgMTQ1LjMgLTEzLjQpIi8+CiAgICAgIDxn'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRoPSIxLjMiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC0uMTk4NDggMCAwIC4xNzc0NCAxNDUuMyAtMTMuNCkiPgogICAgICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIGQ9Ik01MzEuNSAzNTkuNmMwLTE2NS4yIDgtMjk5LjQgMTcuNy0yOTkuNCA5'
    b'LjggMCAxNy43IDEzNC4yIDE3LjcgMjk5LjRoLTM1LjR6IiB0cmFuc2Zvcm09Im1hdHJpeCgx'
    b'LjQyMTYgLS43MzQyMyAuNDYxNjEgLjg5Mzc1IC03MTYuOCA1NDEpIi8+CiAgICAgICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0iTTUzMS41IDM1OS42YzAtMTY1LjIgOC0yOTkuNCAxNy43LTI5'
    b'OS40IDkuOCAwIDE3LjcgMTM0LjIgMTcuNyAyOTkuNCIgdHJhbnNmb3JtPSJtYXRyaXgoMS4x'
    b'MzczIC0uNTg3MzkgLjQ0NTMyIC44NjIyMSAtNTU0LjggNDcxLjgpIi8+CiAgICAgICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0iTTU2My40IDMwMS4yYy4yIDE4LjkgMCA0MC4yIDAgNjAuMkg1'
    b'MzVjMC0yMC0uMi00MS4zIDAtNjAuMmgyOC40eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS40MjE2'
    b'IC0uNzM0MjMgLjQ1ODg5IC44ODg0OSAtNzE2LjcgNTQxLjQpIi8+CiAgICAgICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZiIgZD0iTTU1OS44IDMwNC43Yy4yIDE5IDAgMzMuMSAwIDUzLjJoLTIxLjJj'
    b'MC0yMC0uMi0zNC4zIDAtNTMuMmgyMS4yeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS40MjE2IC0u'
    b'NzM0MjMgLjQ1ODg5IC44ODg0OSAtNzE2LjcgNTQxLjQpIi8+CiAgICAgICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTU0Mi4xIDMxMS44aDE0LjJ2MzloLTE0LjJ6bTAgMCAxNC4yIDM5bS0x'
    b'NC4yIDAgMTQuMi0zOW0tMTQuMi0xOTguNGgxNC4yIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjQy'
    b'MTYgLS43MzQyMyAuNDU4ODkgLjg4ODQ5IC03MTYuNyA1NDEuNCkiLz4KICAgICAgICA8Y2ly'
    b'Y2xlIGN4PSI1NDUuNyIgY3k9IjkyLjEiIHI9IjMuNSIgZmlsbD0iI2VmMDAwMCIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoMS42MDQ2IC40NTM3NSAtLjM2MjE1IDEuNTc4NyAtNzM0LjkgLTE3MC44'
    b'KSIvPgogICAgICA8L2c+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlLXdpZHRoPSIxLjMiIGQ9Ik01MzguNiA1MzEuNWMxLjcgMTY2LjYgMjQu'
    b'OCAyMDIgMy41IDIwMnMtMzEuOS05Mi4xLTMxLjktMjA1LjUgMTQuMi0yMDUuNSAzNS41LTIw'
    b'NS41LTkgMzEuOS03LjEgMjA5eiIgdHJhbnNmb3JtPSJtYXRyaXgoLjMyMTM2IC0uMTI2ODQg'
    b'LjIwMTU4IC4yMDIyMSAtMTgxLjUgNjAuOCkiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0ibTU0NS43IDc3OS41'
    b'LTYwLjMgMTcuN2M1Ni43IDYwLjMgMTIwLjUgODUgMTM4LjIgNzQuNCAxNy43LTEwLjYtMzEu'
    b'OS0zNS40LTc4LTkyeiIgdHJhbnNmb3JtPSJtYXRyaXgoLjE5ODQ4IDAgMCAuMTc3NDQgMTku'
    b'MSAtMTQpIi8+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjMiIGQ9Im01NDcuMyA3ODYuOS01MSAxNC43YzU2LjcgNjAuMyAx'
    b'MTIuOCA3Ny40IDEyNy4zIDcwIDE0LjYtNy4zLTMwLjMtMjgtNzYuMy04NC43eiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoLjE5MzM0IDAgMCAuMTcwNjIgMjEuNiAtOC44KSIvPgogICAgICA8cGF0'
    b'aCBmaWxsPSJub25lIiBzdHJva2Utd2lkdGg9IjEuOCIgZD0iTTM1My4xIDYzNC4yYy4yIDEu'
    b'My44IDcuMSAxLjMgOS40IDAgMy4yLjMgNS42LjYgOC4xLjggMi4yLjcgNC4yIDMuMSA1YTku'
    b'OSA5LjkgMCAwIDAgNSA0LjQgMjcuNyAyNy43IDAgMCAwIDYuMyAzLjggMTEuNiAxMS42IDAg'
    b'MCAwIDcuNS42YzIuMi0xLjUgMy44LTMuMSA1LjYtNC40LjQtMiAuOC00LjkgMS4zLTYuOWEz'
    b'Mi42IDMyLjYgMCAwIDAtMS4zIDguMmMuMiAzIDEuMyA0LjQgMi41IDYuOCIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoLjEzOTc4IDAgMCAuMTI0MTQgNDEuNCAxOS43KSIvPgogICAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2Utd2lkdGg9IjEuOCIgZD0ibTM4OS40IDY4MS43LjYtLjZjLTEu'
    b'NSAxLjUtLjkuOCAyLjUtMS4zIDIuNC0xLjIgNS0xLjggOC4xLTIuNGg4LjhjMy40IDAgNS43'
    b'LjUgOC4xIDEuMiAxLjggMS44IDQuNCAyLjggNi4zIDQuNGExMSAxMSAwIDAgMSAzLjcgNWMx'
    b'LjcgMS43IDIuOCA0LjMgNC40IDUuNi43IDIuOSAyLjEgMi44IDMuMSA1LTMgLjItNS4zLjYt'
    b'Ni45IDIuNS0yLjYgMS4zIDIuMi0xLjMgMy4yLTIuNSAyLS42IDIuNS0xLjIgNS42LTEuMiAy'
    b'LjgtMSA0LjYuNyA3LjUgMS4yIDEuNyAxIDIuMiAxLjMgNC40IDEuMyIgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoLjEzOTc4IDAgMCAuMTI0MTQgMzkuNSAxOSkiLz4KICAgICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlLXdpZHRoPSIxLjgiIGQ9Ik00MzguMSA3MjQuOWMxLjMgMCA3LjEgMS4x'
    b'IDkuNCAwIDIuNi0uNyA0LTIgNS42LTQuNC44LTEuNyAwIDMgMCA1IC4zIDMuNyAxLjQgMy43'
    b'IDMuMiA2LjIgMS44IDEuMiAzLjcgMi44IDUuNiAzLjhhMTggMTggMCAwIDAgNS42IDMuMWMy'
    b'IDEgNC4xIDEuOCA1LjYgMy4xIDIuMSAxLjUgMiAzLjMgMy4yIDUuNy0uMyAzLS44IDQuOC0y'
    b'LjUgNi4yLS44IDIuMS0yLjQgNC4yLTMuOCA1LjYtMS41IDMtMy4zIDQuMy42IDUgMi4yIDEg'
    b'My40LjIgNS43IDAiIHRyYW5zZm9ybT0ibWF0cml4KC4xMzk3OCAwIDAgLjEyNDE0IDM3LjQg'
    b'MTcuNikiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIxLjgiIGQ9'
    b'Ik00ODAuNiA3NzEuN2MxLjYtLjQgNy0yLjIgOS40LTMuMWg4LjhjMy4zLjMgNCAxLjMgNi44'
    b'IDIuNSAxLjkgMS45IDMuMSAzLjIgNS43IDQuNCAxLjMgMS43IDQgNC43IDUgNi45YTI1LjUg'
    b'MjUuNSAwIDAgMSAxLjIgOGMwIDMuNy0xIDQuNC0xLjIgNy42YTE5LjMgMTkuMyAwIDAgMS0z'
    b'LjggNy41Yy0uMy44LS41IDEtMS4yIDEuMiIgdHJhbnNmb3JtPSJtYXRyaXgoLjEzOTc4IDAg'
    b'MCAuMTI0MTQgMzcgMTcuMikiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLXdp'
    b'ZHRoPSIyLjMiIGQ9Ik01MzguMSA4MThjLjQgMCAxLjIgMiAyLjUgMy43IDIuOSAzIDMuMiAz'
    b'LjIgNy41IDMuMiA0LS4yIDMuNS0xLjYgNi4zLTIuNSAxLjMtMiAyLjktMy42IDQuNC02LjMg'
    b'MS0xLjYgMS45LTQuMSAzLTUuNiAxLjItMS45IDIuNi0zLjMgMy44LTUgMS4yLS41IDEuNi0x'
    b'IDMuMi0xLjMtMy42LjYtNCAxLjktNi4zIDMuOGE1OC45IDU4LjkgMCAwIDAtMy4xIDUuNmMt'
    b'LjQgMi43LTEuMiA0LjgtMS4zIDguMSAwIDMuNSAwIDUuOSAxLjMgOC44IDEuNSAxLjUgMi41'
    b'IDMuMSA0LjQgNC40YTM2LjcgMzYuNyAwIDAgMSA0LjMgNWw1LjcgMy43YzEuOCAxLjEgMy45'
    b'IDIuMiA2LjggMi41IDMuNy0uMyA0LjgtMS4zIDcuNS0yLjUgMi40LTEuNyA0LjItMi44IDYu'
    b'My00LjRhMjEgMjEgMCAwIDAgNC40LTVjMy4zLS44IDUuNS0uNSA3LjUgMS4zYTE2LjUgMTYu'
    b'NSAwIDAgMSA0LjMgNC40YzEgLjUgMi44IDIgMy44IDIuNSIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'LjA5OTI0IDAgMCAuMDk3OTkgNTUgMzguMikiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjkiIGQ9Ik01MDMuOCA4MzYuMWMtLjguMy0zLjggMi40LTUgMy4x'
    b'LS44IDIuNy0yLjEgNC4xLTIuNSA3LS43IDIuNi0uNyA1LjYtLjcgOC43LjcgMy4yIDIgNS41'
    b'IDMuMiA4IDIgMS40IDMgMi40IDUuNiAzLjggMi41LjQgNSAuNyA4LjEuNyAyIC42IDUuNi45'
    b'IDcuNSAwIDIuOC0uNCA0LjktMS41IDYuOS0yLjUgMi4zLTEuMyAzLjctMi42IDYuMi0zLjgg'
    b'MS4zLTEuOCAzLjItMy41IDUtNS42IDEuNi0yLjEgMi43LTMuMyAzLjgtNS42LTEgMi42LTIu'
    b'MyA1LTMuMSA3LjUtMS41IDIuNi0yLjMgMy42LTIuNSA2LjgtMSAyLjYtLjcgNS44LS43IDgu'
    b'OC4zIDIgLjQgNS44IDEuMyA3LjV2MS45IiB0cmFuc2Zvcm09Im1hdHJpeCguMTIzMzggMCAw'
    b'IC4xMjIyOSA1MyAxOC42KSIvPgogICAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2Utd2lk'
    b'dGg9IjEuMiIgZD0iTTU0MS4zIDc5OS4ydi43YzAtMS43IDAtLjktLjcgMi41LTEuMSAxLjQt'
    b'NCAxLjgtNi4yIDEuMi0yLTEuNy0yLTMtNS42LTMuNy0zLjYuMi01IDEuMi03IDIuNWE5LjUg'
    b'OS41IDAgMCAwLTUgNC4zYy0uNyAyLjEtMS4xIDMuNiAxLjMgNC40YTE1LjIgMTUuMiAwIDAg'
    b'MCA3IDIuNWMyLjggMCA0LjktLjMgNi4yIDEuMyAyIDIgMS44IDMuMiAxLjggNi44LjcgMS4x'
    b'LjggNC40IDEuMyA1LjdhMTAuNiAxMC42IDAgMCAwIDUuNiAxLjJjLjctMiAxLjQtNS40IDEu'
    b'OS03LjUuNS0yLjIuNi01LjQgMS45LTYuOWExNi42IDE2LjYgMCAwIDEgNC4zLTQuNCA4IDgg'
    b'MCAwIDEgMy44LTIuNGMtMi41IDEuMi0yLjggMi42LTMuMSA1LjYgMi4xIDEgMi43IDEuOCA2'
    b'LjIgMS45IDMuNS0uMyA0LjMtMS4yIDUuNi0zLjIuMyAzLjIgMS4zIDQuMiAyIDcgMS4yIDEu'
    b'OCAxLjcgMy43IDMgNi4yLS41IDMtMS43IDMuMS0xLjggNi44LS44IDIuNS0uOCA0LjgtMi41'
    b'IDYuMy0uOCAxLTEuNCAxLjEtMy4yIDEuMiAzLjYgMCA1LjgtLjQgOC4yLTEuOCAxLjgtMS4y'
    b'IDMuMi0yLjYgNS0zLjhhMjMuOSAyMy45IDAgMCAxIDcuNS0zLjhjMi45IDAgNS0uMyA2LjIg'
    b'MS4zIDEuOCAxLjMgMyAzLjUgMy44IDYuMy41IDMuMi44IDUuNC0uNyA3LjUtMSAyLjQtMS4z'
    b'IDMuMyAwIDYuMiAxLjUgMiAzLjYgMi4zIDcgMy4xIDIuMy0uMSA0LjYtLjYgNi4yLTEuMiIg'
    b'dHJhbnNmb3JtPSJtYXRyaXgoLjE5ODQ4IDAgMCAuMTc3NDQgMTkuMSAtMTQpIi8+CiAgICAg'
    b'IDxnIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRoPSIxLjMiIHRyYW5zZm9ybT0i'
    b'bWF0cml4KC4xOTg0OCAwIDAgLjE3NzQ0IDE5LjEgLTE0KSI+CiAgICAgICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTUzMS41IDM1OS42YzAtMTY1LjIgOC0yOTkuNCAxNy43LTI5OS40IDku'
    b'OCAwIDE3LjcgMTM0LjIgMTcuNyAyOTkuNGgtMzUuNHoiIHRyYW5zZm9ybT0ibWF0cml4KDEu'
    b'NDIxNiAtLjczNDIzIC40NjE2MSAuODkzNzUgLTcxNi44IDU0MSkiLz4KICAgICAgICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNNTMxLjUgMzU5LjZjMC0xNjUuMiA4LTI5OS40IDE3LjctMjk5'
    b'LjQgOS44IDAgMTcuNyAxMzQuMiAxNy43IDI5OS40IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjEz'
    b'NzMgLS41ODczOSAuNDQ1MzIgLjg2MjIxIC01NTQuOCA0NzEuOCkiLz4KICAgICAgICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNNTYzLjQgMzAxLjJjLjIgMTguOSAwIDQwLjIgMCA2MC4ySDUz'
    b'NWMwLTIwLS4yLTQxLjMgMC02MC4yaDI4LjR6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjQyMTYg'
    b'LS43MzQyMyAuNDU4ODkgLjg4ODQ5IC03MTYuNyA1NDEuNCkiLz4KICAgICAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJNNTU5LjggMzA0LjdjLjIgMTkgMCAzMy4xIDAgNTMuMmgtMjEuMmMw'
    b'LTIwLS4yLTM0LjMgMC01My4yaDIxLjJ6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjQyMTYgLS43'
    b'MzQyMyAuNDU4ODkgLjg4ODQ5IC03MTYuNyA1NDEuNCkiLz4KICAgICAgICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNNTQyLjEgMzExLjhoMTQuMnYzOWgtMTQuMnptMCAwIDE0LjIgMzltLTE0'
    b'LjIgMCAxNC4yLTM5bS0xNC4yLTE5OC40aDE0LjIiIHRyYW5zZm9ybT0ibWF0cml4KDEuNDIx'
    b'NiAtLjczNDIzIC40NTg4OSAuODg4NDkgLTcxNi43IDU0MS40KSIvPgogICAgICAgIDxjaXJj'
    b'bGUgY3g9IjU0NS43IiBjeT0iOTIuMSIgcj0iMy41IiBmaWxsPSIjZWYwMDAwIiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjYwNDYgLjQ1Mzc1IC0uMzYyMTUgMS41Nzg3IC03MzQuOSAtMTcwLjgp'
    b'Ii8+CiAgICAgIDwvZz4KICAgICAgPGcgZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCguMTk4NDggMCAwIC4xNzc0NCAxOS4xIC0xNCkiPgogICAg'
    b'ICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS4zIiBkPSJNMzA1LjYgMzk2LjljMCAxMjQgLjUg'
    b'MTcwLjctNS42IDE3Ny4xLTUuOCA2LjktMTY3LjEgMC0xNjcuMSAzNS40czEzMi44IDcxIDE3'
    b'Mi43IDcxYzUzLjIgMCA3OS43LTM1LjUgNzkuNy0xMDYuNFYzOTdoLTc5Ljd6IiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxLjMzMzMgMCAwIDEgLTE0MS43IDApIi8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlLXdpZHRoPSIxLjMiIGQ9Ik0yNjUuOCAzOTYuOXYxNy43YTMyMS4xIDMyMS4xIDAgMCAw'
    b'IDEwNi4yIDB2LTE3LjdhMzIxLjEgMzIxLjEgMCAwIDEtMTA2LjIgMHoiIHRyYW5zZm9ybT0i'
    b'bWF0cml4KDEgMCAwIC45OTk5OSAwIDM1LjQpIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdp'
    b'ZHRoPSIxLjMiIGQ9Ik0yNjUuOCAzOTYuOXYxNy43YTMyMS4xIDMyMS4xIDAgMCAwIDEwNi4y'
    b'IDB2LTE3LjdhMzIxLjEgMzIxLjEgMCAwIDEtMTA2LjIgMHoiIHRyYW5zZm9ybT0ic2NhbGUo'
    b'MSAuOTk5OTkpIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIxLjMiIGQ9Ik0yNjUu'
    b'OCAzOTYuOXYxNy43YTMyMS4xIDMyMS4xIDAgMCAwIDEwNi4yIDB2LTE3LjdhMzIxLjEgMzIx'
    b'LjEgMCAwIDEtMTA2LjIgMHoiIHRyYW5zZm9ybT0ibWF0cml4KDEgMCAwIC45OTk5OSAwIDE3'
    b'LjcpIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIxLjMiIGQ9Ik0yNjUuOCAzOTYu'
    b'OXYxNy43YTMyMS4xIDMyMS4xIDAgMCAwIDEwNi4yIDB2LTE3LjdhMzIxLjEgMzIxLjEgMCAw'
    b'IDEtMTA2LjIgMHoiIHRyYW5zZm9ybT0ibWF0cml4KDEgMCAwIC45OTk5OSAwIDUzLjEpIi8+'
    b'CiAgICAgICAgPGVsbGlwc2UgY3g9IjI1Ni45IiBjeT0iMjEwLjgiIHN0cm9rZS13aWR0aD0i'
    b'NC40IiByeD0iOC45IiByeT0iMjYuNiIgdHJhbnNmb3JtPSJtYXRyaXgoLjU0NTQ1IDAgMCAu'
    b'MTQzODMgMTMwLjUgMzk0LjMpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjI5Mi4zIiBjeT0i'
    b'MjQ2LjMiIHN0cm9rZS13aWR0aD0iNC40IiByeD0iOC45IiByeT0iMjYuNiIgdHJhbnNmb3Jt'
    b'PSJtYXRyaXgoLjU0NTQ1IDAgMCAuMTQzODMgMTMwLjUgMzkxLjEpIi8+CiAgICAgICAgPGVs'
    b'bGlwc2UgY3g9IjMyNy44IiBjeT0iMjY0IiBzdHJva2Utd2lkdGg9IjQuNCIgcng9IjguOSIg'
    b'cnk9IjI2LjYiIHRyYW5zZm9ybT0ibWF0cml4KC41NDU0NSAwIDAgLjE0MzgzIDEzMC41IDM5'
    b'MC41KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSIzNjMuMiIgY3k9IjI2NCIgc3Ryb2tlLXdp'
    b'ZHRoPSI0LjQiIHJ4PSI4LjkiIHJ5PSIyNi42IiB0cmFuc2Zvcm09Im1hdHJpeCguNTQ1NDUg'
    b'MCAwIC4xNDM4MyAxMzAuNSAzOTAuNSkiLz4KICAgICAgICA8ZWxsaXBzZSBjeD0iMzk4LjYi'
    b'IGN5PSIyNDYuMyIgc3Ryb2tlLXdpZHRoPSI0LjQiIHJ4PSI4LjkiIHJ5PSIyNi42IiB0cmFu'
    b'c2Zvcm09Im1hdHJpeCguNTQ1NDUgMCAwIC4xNDM4MyAxMzAuNSAzOTEuMSkiLz4KICAgICAg'
    b'ICA8ZWxsaXBzZSBjeD0iNDM0LjEiIGN5PSIyMTAuOCIgc3Ryb2tlLXdpZHRoPSI0LjQiIHJ4'
    b'PSI4LjkiIHJ5PSIyNi42IiB0cmFuc2Zvcm09Im1hdHJpeCguNTQ1NDUgMCAwIC4xNDM4MyAx'
    b'MzAuNSAzOTQuMykiLz4KICAgICAgICA8cGF0aCBzdHJva2Utd2lkdGg9IjEuMyIgZD0iTTI2'
    b'NS44IDQ4NS40IDM3MiA1ODEuMW0tOTUuNi05NS43IDk1LjcgODVNMjkwLjUgNDg5bDgxLjYg'
    b'NzAuOW0tNzEtNzEgNzEgNjAuM00zMTEuOCA0ODlsNjAuMiA0OS42TTMyMi40IDQ4OWw0OS42'
    b'IDM5bS0zOS0zOSAzOSAyOC4zTTM0My44IDQ4OWwyOC40IDIxLjJNMzU0LjMgNDg5bDE3Ljgg'
    b'MTQuMk0zNjUgNDg5bDcgN20tMTA2LjIgMEwzNzIgNTkxLjhtMC0xMDYuM0wyNTUgNTkxLjdt'
    b'MTA2LjMtMTA2LjMtMTAyLjcgOTIuMm04OC42LTg4LjYtODEuNSA3MC44bTcwLjgtNzAuOC03'
    b'MC44IDYwLjJNMzI2IDQ4OWwtNjAuMiA0OS42bTQ5LjYtNDkuNi00OS42IDM5bTM5LTM5LTM5'
    b'IDI4LjNNMjk0IDQ4OWwtMjguMyAyMS4ybTE3LjctMjEuMi0xNy43IDE0LjJtNy0xNC4yLTcg'
    b'N20xMDYuMyAwTDI1NSA2MDIuNW0xMTctOTUuN0wyNTUgNjEzbTExNy05NS43TDI1NSA2MjMu'
    b'Nm0xMTctOTUuN0wyNTUgNjM0LjRtMTE3LTk1LjdMMjU1IDY0NC45bTExNy05NS43TDI1NSA2'
    b'NTUuNW0xMTctOTUuN0wyNTUgNjY2LjFtMTE3LTk1LjZMMjU1IDY3Ni44bTExNy05NS43LTEw'
    b'OS45IDk5LjJNMzcyIDU5MS43bC05OS4yIDg4LjZtOTUuNi03NC40LTc4IDcwLjlNMzY1IDYy'
    b'MGwtNjMuOCA1Ni43bTU2LjctMzktMzIgMjguM20tNjAuMS0xNTkuNCAxMDIuNyA5Mi4xbS0x'
    b'MDIuNy04MS41IDEwMi43IDkyLjJNMjY1LjggNTI4bDk5LjIgODguNW0tOTkuMi03OCA5OS4y'
    b'IDg4LjdtLTk5LjItNzggOTUuNiA4NW0tOTkuMi03Ny45IDk1LjcgODVNMjYyLjIgNTY3bDg4'
    b'LjYgNzhtLTkyLjEtNzEgODguNiA3OE0yNTUgNTgxbDg1IDc0LjRtLTg1LTYzLjggODEuNSA3'
    b'MC45TTI1NSA2MDIuM2w3MSA2My43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIx'
    b'LjMiIGQ9Ik0yNjUuOCAzOTYuOXYxNy43YTMyMS4xIDMyMS4xIDAgMCAwIDEwNi4yIDB2LTE3'
    b'LjdhMzIxLjEgMzIxLjEgMCAwIDEtMTA2LjIgMHoiIHRyYW5zZm9ybT0ibWF0cml4KDEgMCAw'
    b'IC45OTk5OSAwIDcwLjkpIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRoPSIxLjMiIGQ9'
    b'Im0yNTUuMSA2MTMgNjMuOCA1Ni43bS02My44LTQ2IDU2LjcgNDkuNW0tNTYuNy0zOSA0OS42'
    b'IDQyLjZtLTQ5LjYtMzIgMzUuNSAzMk0yNTUgNjU1LjVsMjguNCAyNC44TTI1NSA2NjYuMWwx'
    b'Ny43IDE0LjIiLz4KICAgICAgICA8ZWxsaXBzZSBjeD0iMjU2LjkiIGN5PSIyMTAuOCIgc3Ry'
    b'b2tlLXdpZHRoPSI0LjQiIHJ4PSI4LjkiIHJ5PSIyNi42IiB0cmFuc2Zvcm09Im1hdHJpeCgu'
    b'NTQ1NDUgMCAwIC4xNDM4MyAxMzAuNSA0NDcuNSkiLz4KICAgICAgICA8ZWxsaXBzZSBjeD0i'
    b'MjkyLjMiIGN5PSIyNDYuMyIgc3Ryb2tlLXdpZHRoPSI0LjQiIHJ4PSI4LjkiIHJ5PSIyNi42'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCguNTQ1NDUgMCAwIC4xNDM4MyAxMzAuNSA0NDQuMykiLz4K'
    b'ICAgICAgICA8ZWxsaXBzZSBjeD0iMzI3LjgiIGN5PSIyNjQiIHN0cm9rZS13aWR0aD0iNC40'
    b'IiByeD0iOC45IiByeT0iMjYuNiIgdHJhbnNmb3JtPSJtYXRyaXgoLjU0NTQ1IDAgMCAuMTQz'
    b'ODMgMTMwLjUgNDQzLjYpIi8+CiAgICAgICAgPGVsbGlwc2UgY3g9IjM2My4yIiBjeT0iMjY0'
    b'IiBzdHJva2Utd2lkdGg9IjQuNCIgcng9IjguOSIgcnk9IjI2LjYiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KC41NDU0NSAwIDAgLjE0MzgzIDEzMC41IDQ0My42KSIvPgogICAgICAgIDxlbGxpcHNl'
    b'IGN4PSIzOTguNiIgY3k9IjI0Ni4zIiBzdHJva2Utd2lkdGg9IjQuNCIgcng9IjguOSIgcnk9'
    b'IjI2LjYiIHRyYW5zZm9ybT0ibWF0cml4KC41NDU0NSAwIDAgLjE0MzgzIDEzMC41IDQ0NC4z'
    b'KSIvPgogICAgICAgIDxlbGxpcHNlIGN4PSI0MzQuMSIgY3k9IjIxMC44IiBzdHJva2Utd2lk'
    b'dGg9IjQuNCIgcng9IjguOSIgcnk9IjI2LjYiIHRyYW5zZm9ybT0ibWF0cml4KC41NDU0NSAw'
    b'IDAgLjE0MzgzIDEzMC41IDQ0Ny41KSIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0i'
    b'MS4zIiBkPSJtMTEzLjQgNjUyIDEyNy41LTc0LjRtLTEzNC42IDcwLjggMTIwLjUtNzAuOG0t'
    b'MTI0IDYzLjcgMTA5LjgtNjMuN005OS4yIDYzNC4zbDk1LjctNTYuN005MiA2MjcuMmw4OC42'
    b'LTQ5LjZtLTg1IDM5IDYwLjItMzUuNU05MiA2MDkuNGw0Ni0yOC4zbS00NiAxNy43IDMyLTE3'
    b'LjdtMCA3NC40IDEyMC40LTcwLjlNMTM0LjcgNjU5IDI0OCA1OTEuN20tMTAyLjcgNzAuOSAx'
    b'MDYuMy02My44bS05NS43IDY3LjMgODguNi01My4xTTE3MCA2NjYuMWw3OC00Nm0tNjcuNCA0'
    b'OS42IDY3LjMtMzltLTU2LjcgNDIuNSA1My4yLTMxLjltLTM5IDMyIDQyLjUtMjQuOW0tMjgu'
    b'MyAyOC40TDI0OCA2NTltLTE0IDE3LjggMTcuNy0xMC42Ii8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlLXdpZHRoPSIxLjMiIGQ9Ik0yNjUuOCAzOTYuOXYxNy43YTMyMS4xIDMyMS4xIDAgMCAw'
    b'IDEwNi4yIDB2LTE3LjdhMzIxLjEgMzIxLjEgMCAwIDEtMTA2LjIgMHoiIHRyYW5zZm9ybT0i'
    b'bWF0cml4KDAgMSAtLjk5OTk5IDAgNjU1LjUgMzA4LjMpIi8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlLXdpZHRoPSIxLjMiIGQ9Im00OS42IDYyMy42IDQyLjUtMzUuNG0tNDIuNSAxMC42IDQy'
    b'LjUgNDIuNSIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS4zIiBkPSJtMjYwLjEg'
    b'Mzg4IDUuNiAyNi42YzM1LjUgNS45IDY1LjMgNS45IDEwMC44IDBsMTEuMS0yNi42Yy0zNS40'
    b'IDUuOS04MiA1LjktMTE3LjUgMHoiIHRyYW5zZm9ybT0ibWF0cml4KDAgLjYzMzMzIC0uOCAw'
    b'IDQyMy44IDQxNi4zKSIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS4zIiBkPSJN'
    b'MjU4LjcgMzUwLjh2LTE3LjljLTEwLjcuMi0xNy44LTEwLjUtMTcuOC0yMS4ybC0zNS40LjFj'
    b'MCAxMC42LTcgMjEuMy0xNy43IDIxLjN2MTcuN2g3MC45eiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'MS40OTgzIDAgMCAxIC0xNS42IDUzLjEpIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRo'
    b'PSIxLjQiIGQ9Ik0yOTYgMzQzLjdoNDUuNlYzNjVIMjk2em0zLjktMjEuM2gzNy45djIxLjNo'
    b'LTM4em0wLTIxLjJoMzcuOXYyMS4yaC0zOHptMy44LTI4LjRIMzM0djI4LjRoLTMwLjN6bS0x'
    b'LjMtMjQuOGgzM3YyNC44aC0zM3oiLz4KICAgICAgICA8ZWxsaXBzZSBjeD0iMjM3LjQiIGN5'
    b'PSIxNjEuMiIgc3Ryb2tlLXdpZHRoPSIxLjMiIHJ4PSI0Mi41IiByeT0iMzMuNyIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoMS4wMzMzIDAgMCAxIDc1LjMgNjMuOCkiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2Utd2lkdGg9IjEuMyIgZD0iTTI1OC43IDE1OS40YzAgOS4zIDEwLjYgMjQuOCAxMC42'
    b'IDI0LjgtNy43IDYuMi0yMC4yIDEwLjctMzEuOSAxMC43cy0yNi4zLTIuNi0zMS45LTEwLjdj'
    b'MCAwIDEwLjYtMTUuNCAxMC42LTI0LjdzLTEwLjYtMjEuMy0xMC42LTIxLjNhNTQuNiA1NC42'
    b'IDAgMCAxIDMyLTEwLjZjMTEuNiAwIDI0IDQuNSAzMS44IDEwLjYgMCAwLTEwLjYgMTItMTAu'
    b'NiAyMS4zeiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wMzMzIDAgMCAxIDc1LjMgNjMuOCkiLz4K'
    b'ICAgICAgICA8cGF0aCBzdHJva2Utd2lkdGg9IjEuMyIgZD0iTTI1MS42IDE1OS40YzAgOS4z'
    b'IDEwLjYgMjguNCAxMC42IDI4LjQtNy43IDYtMTMgNy0yNC44IDdzLTE5LjIgMS4xLTI0Ljgt'
    b'N2MwIDAgMTAuNi0xOSAxMC42LTI4LjRzLTEwLjYtMjQuOC0xMC42LTI0LjhjNy43LTYgMTMt'
    b'NyAyNC44LTcgMTEuNyAwIDE3LjEgMSAyNC44IDcgMCAwLTEwLjYgMTUuNS0xMC42IDI0Ljh6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjAzMzMgMCAwIDEgNzUuMyA2My44KSIvPgogICAgICAg'
    b'IDxjaXJjbGUgY3g9IjE5NC45IiBjeT0iMTY2LjUiIHI9IjEwLjYiIHN0cm9rZS13aWR0aD0i'
    b'MS4zIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjAzMzMgMCAwIDEgNzUuMyA2MC4yKSIvPgogICAg'
    b'ICAgIDxjaXJjbGUgY3g9IjE5NC45IiBjeT0iMTY2LjUiIHI9IjEwLjYiIHN0cm9rZS13aWR0'
    b'aD0iMS4zIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjAzMzMgMCAwIDEgMTYzLjIgNjAuMikiLz4K'
    b'ICAgICAgICA8Y2lyY2xlIGN4PSIxOTQuOSIgY3k9IjE2Ni41IiByPSIxMC42IiBzdHJva2Ut'
    b'd2lkdGg9IjEuMyIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wMzMzIDAgMCAxIDExOS4zIDYwLjIp'
    b'Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMTk0LjkiIGN5PSIxNjYuNSIgcj0iMTAuNiIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjMiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDMzMyAwIDAgMSAxMTkuMyAy'
    b'NC44KSIvPgogICAgICAgIDxjaXJjbGUgY3g9IjE5NC45IiBjeT0iMTY2LjUiIHI9IjEwLjYi'
    b'IHN0cm9rZS13aWR0aD0iMS4zIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjA3MDIgMCAwIDEgODAg'
    b'MjI2LjgpIi8+CiAgICAgICAgPGNpcmNsZSBjeD0iMTk0LjkiIGN5PSIxNjYuNSIgcj0iMTAu'
    b'NiIgc3Ryb2tlLXdpZHRoPSIxLjMiIHRyYW5zZm9ybT0ibWF0cml4KDEuMDcwMiAwIDAgMSAx'
    b'NDAuNiAyMjYuOCkiLz4KICAgICAgICA8cGF0aCBzdHJva2Utd2lkdGg9IjEuMyIgZD0iTTIx'
    b'Mi42IDMxMS44aDQ5LjZsLTI0LjggMzEuOS0yNC44LTMxLjl6IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgxLjA3MDIgMCAwIDEgNjQuOCA1My4xKSIvPgogICAgICAgIDxjaXJjbGUgY3g9IjE5NC45'
    b'IiBjeT0iMTY2LjUiIHI9IjEwLjYiIHN0cm9rZS13aWR0aD0iMS4zIiB0cmFuc2Zvcm09Im1h'
    b'dHJpeCgxLjQyNyAwIDAgMS4zMzMzIDQwLjcgMTY3LjcpIi8+CiAgICAgIDwvZz4KICAgICAg'
    b'PGcgZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiB0cmFuc2Zvcm09Im1hdHJpeCgu'
    b'MTk4NDggMCAwIC4xNzc0NCAxOC44IC0xOS4xKSI+CiAgICAgICAgPHJlY3Qgd2lkdGg9Ijgx'
    b'LjUiIGhlaWdodD0iMjEuMyIgeD0iMjYyLjIiIHk9IjUyNC40IiBzdHJva2Utd2lkdGg9IjEu'
    b'MiIgcng9IjQuMyIgcnk9IjMuNyIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS4y'
    b'IiBkPSJNMzY4LjUgNTA2LjdjLTkuOCAwLTE3LjcgOC4zLTE3LjcgMTguNXYxNi4xYTE4IDE4'
    b'IDAgMCAwIDE3LjcgMTguNSAxOCAxOCAwIDAgMCAxNy43LTE4LjV2LTE2YTE4IDE4IDAgMCAw'
    b'LTE3LjctMTguNnptMCA3Yy01LjkgMC0xMC42IDYuNy0xMC42IDE0Ljl2OS4zYzAgOC4yIDQu'
    b'NyAxNC44IDEwLjYgMTQuOCA1LjkgMCAxMC42LTYuNiAxMC42LTE0Ljh2LTkuM2MwLTguMi00'
    b'LjctMTQuOC0xMC42LTE0Ljh6bS05Mi4xLTMuNWMtNiAwLTEwLjYgNi42LTEwLjYgMTQuOXYx'
    b'Ni40YzAgOC4yIDQuNyAxNC44IDEwLjYgMTQuOCA1LjkgMCAxMC42LTYuNiAxMC42LTE0LjhW'
    b'NTI1YzAtOC4zLTQuNy0xNC45LTEwLjYtMTQuOXptMC03YTE4IDE4IDAgMCAwLTE3LjcgMTgu'
    b'NXYyMy4yYTE4IDE4IDAgMCAwIDE3LjcgMTguNWM5LjggMCAxNy43LTguMyAxNy43LTE4LjV2'
    b'LTIzLjJhMTggMTggMCAwIDAtMTcuNy0xOC42eiIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13'
    b'aWR0aD0iMS4yIiBkPSJNMjQ4IDUxNy4zYy01LjkgMC0xMC42IDYuNi0xMC42IDE0Ljh2My45'
    b'YzAgOC4yIDQuNyAxNC44IDEwLjYgMTQuOCA2IDAgMTAuNy02LjYgMTAuNy0xNC44di0zLjlj'
    b'MC04LjItNC44LTE0LjgtMTAuNy0xNC44em0wLTdhMTggMTggMCAwIDAtMTcuNyAxOC41djEw'
    b'LjZhMTggMTggMCAwIDAgMTcuNyAxOC41YzkuOCAwIDE3LjgtOC4zIDE3LjgtMTguNXYtMTAu'
    b'NmExOCAxOCAwIDAgMC0xNy44LTE4LjZ6Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlLXdpZHRo'
    b'PSIuOSIgZD0iTTQ3OC40IDIzNy40Yy02IDAtMTAuNyA2LjYtMTAuNyAxNC44djE2LjVjMCA4'
    b'LjEgNC44IDE0LjggMTAuNyAxNC44IDUuOCAwIDEwLjYtNi42IDEwLjYtMTQuOXYtMTYuNGMw'
    b'LTguMi00LjgtMTQuOC0xMC42LTE0Ljh6bTAtN2ExOCAxOCAwIDAgMC0xNy44IDE4LjRWMjcy'
    b'YTE4IDE4IDAgMCAwIDE3LjcgMTguNmM5LjkgMCAxNy44LTguMyAxNy44LTE4LjZ2LTIzLjJh'
    b'MTggMTggMCAwIDAtMTcuNy0xOC41eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS44IDAgMCAxLjEx'
    b'NzYgLTY1NS41IDI0Mi4yKSIvPgogICAgICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjkiIGQ9'
    b'Ik00NzguNCAyMzcuNGMtNiAwLTEwLjcgNi42LTEwLjcgMTQuOHYxNi41YzAgOC4xIDQuOCAx'
    b'NC44IDEwLjcgMTQuOCA1LjggMCAxMC42LTYuNiAxMC42LTE0Ljl2LTE2LjRjMC04LjItNC44'
    b'LTE0LjgtMTAuNi0xNC44em0wLTdhMTggMTggMCAwIDAtMTcuOCAxOC40VjI3MmExOCAxOCAw'
    b'IDAgMCAxNy43IDE4LjZjOS45IDAgMTcuOC04LjMgMTcuOC0xOC42di0yMy4yYTE4IDE4IDAg'
    b'MCAwLTE3LjctMTguNXoiIHRyYW5zZm9ybT0ibWF0cml4KDEuOCAwIDAgMS4xMTc2IC00MjUu'
    b'MiAyNDUuNykiLz4KICAgICAgICA8cmVjdCB3aWR0aD0iNDIuNSIgaGVpZ2h0PSIyMS4zIiB4'
    b'PSIzNzUuNiIgeT0iNTI0LjQiIHN0cm9rZS13aWR0aD0iMS4yIiByeD0iMi4zIiByeT0iMy43'
    b'Ii8+CiAgICAgICAgPHJlY3Qgd2lkdGg9IjI0LjgiIGhlaWdodD0iMjguNCIgeD0iMzM2LjYi'
    b'IHk9IjUyMC45IiBzdHJva2Utd2lkdGg9IjEuMiIgcng9IjEuMyIgcnk9IjQuOSIvPgogICAg'
    b'ICAgIDxyZWN0IHdpZHRoPSIyNC44IiBoZWlnaHQ9IjI4LjQiIHg9IjIxOS43IiB5PSI1MjAu'
    b'OSIgc3Ryb2tlLXdpZHRoPSIxLjIiIHJ4PSIxLjMiIHJ5PSI0LjkiLz4KICAgICAgICA8cmVj'
    b'dCB3aWR0aD0iNDkuNiIgaGVpZ2h0PSIzNS40IiB4PSIxNDEuNyIgeT0iNTE3LjMiIHN0cm9r'
    b'ZS13aWR0aD0iMS4yIiByeD0iMi42IiByeT0iNi4xIi8+CiAgICAgICAgPHJlY3Qgd2lkdGg9'
    b'IjQ2LjEiIGhlaWdodD0iMzUuNCIgeD0iNDUwIiB5PSI1MjAuOSIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjIiIHJ4PSIyLjUiIHJ5PSI2LjEiLz4KICAgICAgPC9nPgogICAgPC9nPgogIDwvZz4KPC9z'
    b'dmc+Cg==', 'OM')

OM = b64_OM
index.append("OM")
index.append("OMN")
index.append("Oman")
catalog["OM"] = OM
catalog["OMN"] = OM
catalog["Oman"] = OM
country["Oman"] = ('OM', 'OMN', 0)
lookup["OM"] = ('OM', 'OMN', 'Oman', 0)
lookup["Muscat Oman"] = ('OM', 'OMN', 'Oman', 0)
lookup["OMN"] = ('OM', 'OMN', 'Oman', 0)
lookup["Oman"] = ('OM', 'OMN', 'Oman', 0)
details["OM"] = {"continent":"Asia","capital":"Muscat","currency":"Rial Omani","web":".om","lang":"ar-OM | en | bal | ur","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_PA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InBhLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGNsaXAtcGF0aD0idXJsKCNw'
    b'YS1hKSI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0ODBIMHoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTkyLjUgMGg0Nzcu'
    b'MnY0ODBIOTIuNHoiLz4KICAgIDxwYXRoIGZpbGw9IiNkYjAwMDAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgZD0iTTMyMyAzLjZoMzU4djIyMS43SDMyM3oiLz4KICAgIDxwYXRoIGZpbGw9IiMw'
    b'MDAwYWIiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMuMiAyMjUuM2gzMTkuOVY0ODBIMy4y'
    b'em0yMTEuNi00Ny42LTQyLTI5LjQtNDEuNyAyOS42IDE1LjUtNDhMMTA1IDEwMGw1MS42LS40'
    b'IDE2LTQ4IDE2LjMgNDcuOWg1MS42bC00MS41IDMwIDE1LjkgNDh6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZDgwMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Im01MTYuOSA0MTMuOS00Mi40'
    b'LTI3LjctNDIuMSAyOCAxNS42LTQ1LjYtNDItMjggNTItLjUgMTYuMi00NS40IDE2LjQgNDUu'
    b'M2g1MmwtNDEuOCAyOC41IDE2IDQ1LjR6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'PA')

PA = b64_PA
index.append("PA")
index.append("PAN")
index.append("Panama")
catalog["PA"] = PA
catalog["PAN"] = PA
catalog["Panama"] = PA
country["Panama"] = ('PA', 'PAN', 0)
lookup["PA"] = ('PA', 'PAN', 'Panama', 0)
lookup["Panama City Panama"] = ('PA', 'PAN', 'Panama', 0)
lookup["PAN"] = ('PA', 'PAN', 'Panama', 0)
lookup["Panama"] = ('PA', 'PAN', 'Panama', 0)
details["PA"] = {"continent":"Americas","capital":"Panama City","currency":"Balboa | US Dollar","web":".pa","lang":"es-PA | en","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_PE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI0Q5MTAyMyIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTIxMy4zIDBoMjEz'
    b'LjR2NDgwSDIxMy4zeiIvPgo8L3N2Zz4K', 'PE')

PE = b64_PE
index.append("PE")
index.append("PER")
index.append("Peru")
catalog["PE"] = PE
catalog["PER"] = PE
catalog["Peru"] = PE
country["Peru"] = ('PE', 'PER', 0)
lookup["PE"] = ('PE', 'PER', 'Peru', 0)
lookup["Lima Peru"] = ('PE', 'PER', 'Peru', 0)
lookup["PER"] = ('PE', 'PER', 'Peru', 0)
lookup["Peru"] = ('PE', 'PER', 'Peru', 0)
details["PE"] = {"continent":"Americas","capital":"Lima","currency":"Sol","web":".pe","lang":"es-PE | qu | ay","tz":"-05:00","altname":""}
#----------------------------------------------------------------------
b64_PF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBmIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InBmLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGNsaXAtcGF0aD0idXJsKCNw'
    b'Zi1hKSI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0ODBIMHoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik04MCAwaDQ4MHY0ODBIODB6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjMDgzZDljIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzA4M2Q5YyIgc3Ry'
    b'b2tlLXdpZHRoPSIycHQiIGQ9Ik0yNzcuMyAzNDAuOHMxMC44LTguOCAyMS40LTguOCAxMy40'
    b'IDcuMyAyMC44IDcuOWM3LjMuNiAxMy40LTcuMyAyMi41LTcuNiA5LjEtLjMgMjAuNSA2LjQg'
    b'MjAuNSA2LjRsLTM5LjggMTItNDUuNC0xMHptLTIyLjktMTMgMTM1LjQuN3MtMTEuNy0xMi43'
    b'LTI1LjUtMTNjLTEzLjgtLjItMTAgNi0yMC41IDYuOC0xMC42LjktMTMuMi02LjQtMjIuOS02'
    b'LjItOS42LjMtMTUuMiA2LjItMjIuNSA2LjUtNy40LjMtMTYuNy03LjMtMjIuMy03LTUuNi4z'
    b'LTI1LjUgOC43LTI1LjUgOC43bDMuOCAzLjZ6bS0xNy4zLTE2IDE2NyAuNWMyLjctMy44LTgu'
    b'Mi0xMi45LTE4LjEtMTMuNy04LjIuMy0xNCA4LjUtMjAuOCA4LjgtNi44LjMtMTQuNC04LjUt'
    b'MjItOC4yLTcuNi4zLTE1LjUgOC4yLTIzLjEgOC4yLTcuNyAwLTEzLjItOC41LTIyLjktOC41'
    b'cy0xNCA5LjMtMjEuNCA4LjhjLTcuMy0uNi0xMy44LTkuNC0yMC44LTkuNHMtMTguNyAxMC41'
    b'LTIxIDEwYy0yLjQtLjcgMi45IDQuMyAzLjEgMy40eiIvPgogICAgPHBhdGggZmlsbD0icmVk'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJy'
    b'b3VuZCIgc3Ryb2tlLXdpZHRoPSIyLjUiIGQ9Im0zMDEuMyAyMTguOSAzOC40IDEwLjJ2LTU0'
    b'LjhjLTE3LjYgMS0zMi4yLTMzLjQtMS4yLTM1LjctMzAuNS00LjQtMzQgMy41LTM3LjUgMTJs'
    b'LjMgNjguM3oiLz4KICAgIDxwYXRoIGZpbGw9IiMwODNkOWMiIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlPSIjMDgzZDljIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13aWR0'
    b'aD0iNSIgZD0ibTI3NyAyNTguNyA4Ni43LjMiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9IjQiIGQ9'
    b'Im0yODEuMSAyMzggMTAuMyAxMy43bS0xMC4zIDAgMTEuMS0xMy41TTI4NyAyMzdsLS4zIDgu'
    b'NW0xMC44LTcuNiAxMC4zIDEzLjhtLTEwLjMgMCAxMS4xLTEzLjVtLTUuMi0xLjItLjMgOC41'
    b'bTExLjEtNy42IDEwLjMgMTMuOG0tMTAuMyAwIDExLjEtMTMuNW0tNS4yLTEuMi0uMyA4LjVt'
    b'MTEuNy03LjYgMTAuMiAxMy44bS0xMC4yIDAgMTEuMS0xMy41bS01LjMtMS4yLS4yIDguNW0x'
    b'MS03LjYgMTAuMyAxMy44bS0xMC4yIDAgMTEuMS0xMy41TTM1NCAyMzdsLS4zIDguNSIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2VmN2QwOCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtMjE4Ljcg'
    b'MjU5LjYgMzYuOS4zdi0yMy4xbC00Mi4yLTIuMSA1LjMgMjQuOXptLTEuOC0zMiAzOS4zIDMu'
    b'OS0uMy0xNi40LTM4LjQtMTUuMy0uNiAyNy45em04LTMyLjcgMzAuMSAxNC42IDQuMy00LjVz'
    b'LTIuOC0xLjktMi42LTMuN2MwLTEuNyAyLjgtMiAyLjgtNCAwLTEuNy0zLTItMy4xLTMuNy0u'
    b'Mi0yIDIuNC00IDIuNC00bC0yNy4yLTIzLjctNi44IDI5em0xOTggNjVoLTM5bC0uMy0yMi42'
    b'IDQyLjgtMy4yLTMuNSAyNS44ek0zODQuMiAyMzJsNDYuMy01LjYtMTAtMjYuNy0zNi42IDE1'
    b'LjYuMyAxNi43em0zMy43LTM5LjZMMzg0LjUgMjEwYy0uNS0yLS45LTMuOC0zLjItNS4zIDAg'
    b'MCAyLTEuMiAyLTMuMnMtMi42LTIuNC0yLjYtMy41IDIuNC0yLjIgMi42LTQuOWMtLjMtMS44'
    b'LTIuNi00LjQtMi4yLTQuOWwyNi0xOS44IDEwLjggMjR6bS03Mi40IDM5LjEgMTYuNy0uNy4z'
    b'LTYuNy0xNyA3LjR6bS01MS0uNS0xNy41LS41di03bDE3LjYgNy41em0wLTItMTcuNS05di0x'
    b'MS44cy0yIC4zLTEuOC0yYy4xLTQuOSAxMi45IDguOSAxOS40IDEzLjRsLS4xIDkuNHptNTEt'
    b'MS4xdi03LjdzMTUuOC0xNC4yIDE5LjEtMTYuOWMwIDMtMS44IDUuMi0xLjggNS4ydjExLjJs'
    b'LTE3LjMgOC4yek0yNDMgMTYzLjhsMTcuOCAxOS43Yy40LTEuOCA0LjUtMi4xIDguNi0xLjgg'
    b'NCAuMyA3LjMtLjMgNy4zIDIuNnMtMiAyLjUtMiA0LjYgMyAxLjkgMyA0LjUtMi4yIDIuMS0y'
    b'LjIgNC4xYzAgMS43IDIuNCAxLjggMi40IDEuOGwxNi42IDE2LjF2LTE3LjJsLTM0LjItNTMu'
    b'Ny0xNy4zIDE5LjN6bTI3LjQtMjAuNCAyMy4zIDQ3LjVzLjItNDMuOCA0LjEtNDYuMWwtNi41'
    b'LTEyLTIwLjkgMTAuNnptMTAxIDEuOS0yNiA0Ni4yVjE3MnMyLjItMy4yLTEuMi0zYy0zLjQu'
    b'My03LjUtLjItNy41LS4ybDEwLjQtMzYuNiAyNC4zIDEzek0zOTggMTY1Yy0uMy41LTE3LjUg'
    b'MTgtMTcuNSAxOC0uOC0yLTYtMS0xMS0xLTQuOSAwLTUuNiAxLjYtNS4zIDIuOS41IDMuMyAy'
    b'LjIuOCAyLjIgNCAwIDMuMS0yLjQgMi0yLjcgNC4yLjMgMi43IDMuOCAyIDEuNyA0bC0xOS45'
    b'IDE5LjJ2LTE4LjJsMzcuMS01Ny42TDM5OCAxNjV6Ii8+CiAgICA8cGF0aCBmaWxsPSJyZWQi'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJv'
    b'dW5kIiBzdHJva2Utd2lkdGg9IjIuNSIgZD0iTTMwOS44IDI2OC40Yy04LjMgMTMuOC0zMC42'
    b'IDkuNy0zNS45IDAtMS41LS40LS42LTU5LjUtLjYtNTkuNXMtMi41LTEuMS0yLjYtM2MtLjEt'
    b'MS44IDMuNC0yIDMuNC00LjNzLTMuNi0xLjQtMy43LTMuOGMwLTIuMiAzLjktMiAzLjctNC0u'
    b'Mi0yLjQtNC4zLTItNC41LTQuMiAwLTEuNyAzLTMuMiAzLjgtNGE2MS4zIDYxLjMgMCAwIDEt'
    b'Mi44IDBsLTYuNC4xYy00LjYgMCAwIDEgMCAzLjYgMCAxLjctMi4zIDIuOS0yLjUgNC4zLS4x'
    b'IDEuNiAzLjIgMi42IDMuMyA0LjUgMCAxLjYtMy4zIDEuNy0zLjIgMy4zLjIgMi41IDMgMy4x'
    b'IDIuOSA0LjcgMCAxLjUtMy42IDIuMS0zLjcgMy4zLjIgMi40LjYgNjAuOC42IDYwLjggNS43'
    b'IDI5LjggMzguOCAzNy4zIDQ4LjItMS44em0yMS45IDBjOC4zIDEzLjggMzAuNiA5LjcgMzUu'
    b'OCAwIDEuNi0uNC43LTU5LjUuNy01OS41czIuNS0xLjEgMi42LTNjLjEtMS44LTMuMi0yLTMu'
    b'Mi00LjNzMy40LTEuNCAzLjQtMy44YzAtMi4yLTMuNS0yLTMuMy00LjIuMi0yLjMgMy0yIDMu'
    b'MS00LjIuMS0xLjktMS43LTMtMi42LTMuOGgyLjdsNi40LjFjNC41IDAgMCAxIDAgMy42IDAg'
    b'MS43IDIuMyAyLjkgMi41IDQuMyAwIDEuNi0zLjIgMi42LTMuMyA0LjUgMCAxLjYgMy4zIDEu'
    b'NyAzLjIgMy4zLS4yIDIuNS0zIDMuMS0zIDQuNy4xIDEuNSAzLjcgMi4xIDMuNyAzLjNsLS41'
    b'IDYwLjhjLTUuNyAyOS44LTM4LjkgMzcuMy00OC4yLTEuOHoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiMwODNkOWMiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDgzZDljIiBzdHJva2Ut'
    b'd2lkdGg9IjJwdCIgZD0iTTMwMS43IDI5NS42SDMzOWMuMy0uMy04LjQtMTMtMTguNi0xMi0x'
    b'MS41LjMtMTkuMyAxMi0xOC43IDEyem0xMTguOS0xaC01MXM2LjYtMy44IDguNC03LjRjMy4z'
    b'IDEuOCAyLjQgMy42IDkgMy45IDYuNi4zIDEyLjktNy41IDE5LjItNy4yIDYuMy4zIDE0LjQg'
    b'MTEgMTQuNCAxMC44em0tMjAxIDBoNTFzLTYuNi0zLjgtOC40LTcuNGMtMy4zIDEuOC0yLjQg'
    b'My42LTkgMy45LTYuNi4zLTEzLTcuNS0xOS4yLTcuMi02LjMuMy0xNC40IDExLTE0LjQgMTAu'
    b'OHptMy44LTE2IDM2LjMuM3MtMi4zLTUtMi42LTExLjFjLTkuNC0zLjItMTcgNy0yMy44IDcu'
    b'My02LjcuMy0xMy43LTcuMy0xMy43LTcuM2wzLjggMTAuOHptMTk0IDAtMzYuNC4zczIuMy01'
    b'IDIuNi0xMS4xYzkuNC0zLjIgMTcgNyAyMy44IDcuMyA2LjcuMyAxMy43LTcuMyAxMy43LTcu'
    b'M2wtMy44IDEwLjh6TTMxMSAyNzlsMTguNC0uNXMuMy01LjYtOS4zLTUuNi04LjggNi40LTku'
    b'MSA2LjF6bS0xMS4yLTcuOWExNyAxNyAwIDAgMCA4LjItNy42bC0xMi42LjNzLTUuOCAzLjUt'
    b'OC43IDcuM2gxMy4xem00MC44IDBhMTcgMTcgMCAwIDEtOC4yLTcuNmwxMi42LjNzNS44IDMu'
    b'NSA4LjcgNy4zaC0xMy4xeiIvPgogICAgPHBhdGggZmlsbD0iI2RlMjAxMCIgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBkPSJNLTQwIDM2MGg3MjB2MTIwSC00MHptMC0zNjBoNzIwdjEyMEgtNDB6'
    b'Ii8+CiAgPC9nPgo8L3N2Zz4K', 'PF')

PF = b64_PF
index.append("PF")
index.append("PYF")
index.append("French Polynesia")
catalog["PF"] = PF
catalog["PYF"] = PF
catalog["French Polynesia"] = PF
country["French Polynesia"] = ('PF', 'PYF', 0)
lookup["PF"] = ('PF', 'PYF', 'French Polynesia', 0)
lookup["Papeete French Polynesia"] = ('PF', 'PYF', 'French Polynesia', 0)
lookup["PYF"] = ('PF', 'PYF', 'French Polynesia', 0)
lookup["French Polynesia"] = ('PF', 'PYF', 'French Polynesia', 0)
details["PF"] = {"continent":"Oceania","capital":"Papeete","currency":"CFP Franc","web":".pf","lang":"fr-PF | ty","tz":"-10:00","altname":""}
#----------------------------------------------------------------------
b64_PG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGQ9Im0xLjYgMC0uNSA0ODBoNjQwTDEuNiAweiIvPgogICAgPHBhdGggZmls'
    b'bD0icmVkIiBkPSJtNjQwLjYgNDgwIC41LTQ4MEgxLjFsNjM5LjUgNDgweiIvPgogIDwvZz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmMwIiBzdHJva2U9IiNmYzAiIHN0cm9rZS13aWR0aD0iMS4xIiBk'
    b'PSJtMTc4IDU0LTMuOC0uMmMtMS4yLTIuOC00LjUtMy44LTYuNi0yLjZBMzMzIDMzMyAwIDAg'
    b'MSAxNTYgNTFsNy4xIDMuMUMxNjUgNTkgMTcxIDYwIDE3MSA2MGMtLjYgOC44LTguOS0xLjEt'
    b'MTUuOSAzLjktNSAzLTUgNi41LTcuNyAxMi4zLS45IDEuNi00LjQgNS44LTQuNCA1LjhsNS45'
    b'LS41TDE0NyA4NGw3LTEtMS41IDEuNGMxIC4yIDgtMS43IDgtMS43TDE2MCA4NWw4LTIuOXMx'
    b'LjYgMS4zIDMgMS45bDEtNCA0IDEgMS00YzYgOCA4IDE2IDE5IDE4bC0xLTRhMjYyLjIgMjYy'
    b'LjIgMCAwIDEgOC43IDRsLjktMS43YzQuOCAzLjQgOC43IDMuMyAxMS40IDMuN2wtMi01IDIg'
    b'MS0zLTggMyAxLTQtNiAxLjUtMS0uNS0zYzYgMiAxNCA1IDE1IDEyIDEgMTEtMTEgMTQtMTkg'
    b'MTMgNiA1IDE3IDMgMjItMiAyLTIgMy01IDQtOCAxIDMgMyA3IDMgMTEtMSA5LTEzIDEyLTIx'
    b'IDEzIDkgNSAyNS0xIDI2LTE0IDAtMTEtNy0xNi0xMC0yMWwtMS01LjQgMyAxLjRzLTEuOC0z'
    b'LjMtMi00YzAgMC0zLjEtOC41LTQuMi0xMC40bDIuMi40LTguMi0xMC4zIDIuMy0uMlMyMTUu'
    b'NiA0NCAyMTMgNDNsMy0xYy02LTMtMTMtMS0xOSAzbDEtMy0xLjguMnYtMy41TDE5OCAzNmwt'
    b'My0xIDItNS0zIDEgMS01cy0yLjIgMS0zLjYuOWE1MS43IDUxLjcgMCAwIDAgMS42LTMuNGMt'
    b'MS0xLjUgMC00LjUgMC00LjUtNyAxLTggMi0xMiA4LTYgMTEtNCAxNi0zIDI3eiIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoMi4yMTk4OSAwIDAgMi4yMTE5NCAxLjEgMCkiLz4KICA8cGF0aCBmaWxs'
    b'PSJyZWQiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSJyZWQiIHN0cm9rZS13aWR0aD0i'
    b'MS40IiBkPSJNMjE1LjggNzAuNGMuNS45IDYuMiAzLjYgMTAuNCA2LTEuMS00LjYtOS40LTUu'
    b'Ni0xMC40LTZ6IiB0cmFuc2Zvcm09Im1hdHJpeCgyLjIxOTg5IDAgMCAyLjIxMTk0IDEuMSAw'
    b'KSIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTE3NSAz'
    b'OTktMTQuMi05LTE5IDkuMSA0LjMtMTYuMi0xNC41LTE1LjEgMTYuNy0xIDEwLTE4LjQgNi4x'
    b'IDE1LjUgMjAuNyAzLjgtMTMgMTAuNnptMzYuMi03OS02LjYtMy02LjMgMy42IDEtNy4yLTUu'
    b'NC00LjkgNy4xLTEuMyAzLTYuNiAzLjUgNi40IDcuMi44LTUgNS4yem0zMi00NS4yLTE0LjUt'
    b'Ny0xMy45IDcuOCAyLjMtMTUuNy0xMS44LTEwLjggMTUuNy0yLjggNi42LTE0LjQgNy42IDE0'
    b'IDE1LjggMS44LTExIDExLjV6bS02NS44LTYzLTE3LTguNS0xNi41IDkuMSAyLjgtMTguNi0x'
    b'My44LTEzIDE4LjctMyA4LTE3IDguNyAxNi43IDE4LjggMi4zLTEzLjMgMTMuNHptLTYwLjgg'
    b'NjUuNC0xNy0xMC0xNyAxMC4zIDQuMy0xOS4zLTE1LjEtMTMgMTkuNy0xLjggNy43LTE4LjMg'
    b'Ny45IDE4LjIgMTkuOCAxLjYtMTQuOSAxM3oiLz4KPC9zdmc+Cg==', 'PG')

PG = b64_PG
index.append("PG")
index.append("PNG")
index.append("Papua New Guinea")
catalog["PG"] = PG
catalog["PNG"] = PG
catalog["Papua New Guinea"] = PG
country["Papua New Guinea"] = ('PG', 'PNG', 0)
lookup["PG"] = ('PG', 'PNG', 'Papua New Guinea', 0)
lookup["Port Moresby Papua New Guinea"] = ('PG', 'PNG', 'Papua New Guinea', 0)
lookup["PNG"] = ('PG', 'PNG', 'Papua New Guinea', 0)
lookup["Papua New Guinea"] = ('PG', 'PNG', 'Papua New Guinea', 0)
details["PG"] = {"continent":"Asia","capital":"Port Moresby","currency":"Kina","web":".pg","lang":"en-PG | ho | meu | tpi","tz":"+10:00","altname":""}
#----------------------------------------------------------------------
b64_PH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBoIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwMzhhOCIgZD0i'
    b'TTAgMGg2NDB2MjQwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0iTTAgMjQwaDY0'
    b'MHYyNDBIMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDE1LjcgMjQwIDAgNDgwVjAi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZmNkMTE2IiBkPSJNMjYuNyA0Mi40IDQxIDU1bDE2LjYtOS4y'
    b'LTcuNCAxNy41IDE0IDEzLTE5LTEuNi04LjEgMTcuMi00LjMtMTguNUwxNCA3MWwxNi4zLTEw'
    b'em0zMjMuOCAxNzIuMy40IDE5IDE4IDYuMy0xOCA2LjItLjQgMTktMTEuNS0xNS4xLTE4LjIg'
    b'NS41IDEwLjgtMTUuNi0xMC44LTE1LjYgMTguMiA1LjV6TTM3LjIgMzg4LjFsOCAxNy4yIDE5'
    b'LTEuNi0xMy45IDEzIDcuNCAxNy41LTE2LjYtOS4xLTE0LjQgMTIuNCAzLjYtMTguN0wxNCA0'
    b'MDlsMTguOS0yLjR6bTExNC4yLTI0OS02LjIgNi4yIDMuMSA0Ny0zIC4zLTUuNy00Mi45LTUu'
    b'MSA1IDcuNiAzOC40YTQ3LjUgNDcuNSAwIDAgMC0xNy4yIDcuMWwtMjEuNy0zMi40SDk2bDI2'
    b'LjQgMzQuM2E0OCA0OCAwIDAgMC0yLjQgMmwtMzEuMS0zNS41aC04Ljh2OC44bDM1LjQgMzEt'
    b'MiAyLjUtMzQuMy0yNi4zdjcuMWwzMi41IDIxLjdjLTMuNCA1LjItNS45IDExLTcuMSAxNy4y'
    b'TDY2LjMgMjIzbC01LjEgNSA0Mi45IDUuN2MtLjIgMS0uMyAyLjEtLjMgMy4xbC00Ny0zLTYu'
    b'MiA2LjIgNi4yIDYuMiA0Ny0zLjEuMyAzLjEtNDIuOSA1LjcgNSA1IDM4LjQtNy42YTQ3LjUg'
    b'NDcuNSAwIDAgMCA3LjEgMTcuMmwtMzIuNSAyMS43djcuMmwzNC4zLTI2LjNhNDggNDggMCAw'
    b'IDAgMiAyLjRsLTM1LjQgMzF2OC44SDg5bDMxLTM1LjQgMi41IDJMOTYgMzEyLjJoNy4ybDIx'
    b'LjctMzIuNWM1LjEgMy40IDExIDUuOSAxNy4yIDcuMWwtNy42IDM4LjQgNSA1IDUuNy00Mi45'
    b'YzEgLjIgMiAuMyAzLjEuM2wtMyA0NyA2LjEgNi4yIDYuMy02LjItMy4xLTQ3IDMtLjMgNS43'
    b'IDQzIDUuMS01LjEtNy42LTM4LjRhNDcuNSA0Ny41IDAgMCAwIDE3LjItNy4xbDIxLjcgMzIu'
    b'NWg3LjJsLTI2LjQtMzQuM2E0OCA0OCAwIDAgMCAyLjQtMmwzMS4xIDM1LjRoOC44di04Ljhs'
    b'LTM1LjQtMzEgMi0yLjQgMzQuMyAyNi4zdi03LjJsLTMyLjUtMjEuN2MzLjQtNS4xIDUuOS0x'
    b'MSA3LjEtMTcuMmwzOC4zIDcuNiA1LjEtNS00Mi45LTUuN2MuMi0xIC4zLTIgLjMtMy4xbDQ3'
    b'IDMgNi4yLTYuMS02LjItNi4yLTQ3IDMtLjMtMyA0Mi45LTUuNy01LTUtMzguNCA3LjVhNDcu'
    b'NSA0Ny41IDAgMCAwLTcuMS0xNy4ybDMyLjUtMjEuN3YtNy4xbC0zNC4zIDI2LjNhNDggNDgg'
    b'MCAwIDAtMi0yLjRsMzUuNC0zMXYtOC45SDIxNGwtMzEgMzUuNWE0OCA0OCAwIDAgMC0yLjUt'
    b'MmwyNi40LTM0LjNoLTcuMkwxNzggMjAwLjJjLTUuMS0zLjQtMTEtNS45LTE3LjItNy4xbDcu'
    b'Ni0zOC4zLTUtNS01LjcgNDIuOC0zLjEtLjMgMy00N3oiLz4KPC9zdmc+Cg==', 'PH')

PH = b64_PH
index.append("PH")
index.append("PHL")
index.append("Philippines")
catalog["PH"] = PH
catalog["PHL"] = PH
catalog["Philippines"] = PH
country["Philippines"] = ('PH', 'PHL', 0)
lookup["PH"] = ('PH', 'PHL', 'Philippines', 0)
lookup["Manila Philippines"] = ('PH', 'PHL', 'Philippines', 0)
lookup["PHL"] = ('PH', 'PHL', 'Philippines', 0)
lookup["Philippines"] = ('PH', 'PHL', 'Philippines', 0)
details["PH"] = {"continent":"Asia","capital":"Manila","currency":"Philippine Peso","web":".ph","lang":"tl | en-PH | fil | ceb | tgl | ilo | hil | war | pam | bik | bcl | pag | mrw | tsg | mdh | cbk | krj | sgd | msb | akl | ibg | yka | mta | abx","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_PK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBrIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InBrLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTUyLjMgMGg2ODIu'
    b'NnY1MTJILTUyLjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0IiBjbGlwLXBhdGg9InVybCgjcGstYSki'
    b'IHRyYW5zZm9ybT0idHJhbnNsYXRlKDQ5KSBzY2FsZSguOTM3NSkiPgogICAgPHBhdGggZmls'
    b'bD0iIzBjNTkwYiIgZD0iTS05NSAwaDc2OHY1MTJILTk1eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZD0iTS05NSAwSDk3LjV2NTEySC05NXoiLz4KICAgIDxnIGZpbGw9IiNmZmYiPgog'
    b'ICAgICA8cGF0aCBkPSJtNDAzLjcgMjI1LjQtMzEuMi02LjYtMTYuNCAyNy4zLTMuNC0zMS42'
    b'LTMxLTcuMiAyOS0xMy0yLjctMzEuNyAyMS40IDIzLjYgMjkuMy0xMi40LTE1LjkgMjcuNiAy'
    b'MSAyNHoiLz4KICAgICAgPHBhdGggZD0iTTQxNS40IDMwNmExMjEuMiAxMjEuMiAwIDAgMS0x'
    b'NjEuMyA1OS40IDEyMi4xIDEyMi4xIDAgMCAxLTU5LjUtMTYyLjFBMTE4LjYgMTE4LjYgMCAw'
    b'IDEgMjY2IDEzOWExNTYuMiAxNTYuMiAwIDAgMC0xMS44IDEwLjlBMTEyLjMgMTEyLjMgMCAw'
    b'IDAgNDE1LjUgMzA2eiIvPgogICAgPC9nPgogIDwvZz4KPC9zdmc+Cg==', 'PK')

PK = b64_PK
index.append("PK")
index.append("PAK")
index.append("Pakistan")
catalog["PK"] = PK
catalog["PAK"] = PK
catalog["Pakistan"] = PK
country["Pakistan"] = ('PK', 'PAK', 0)
lookup["PK"] = ('PK', 'PAK', 'Pakistan', 0)
lookup["Islamabad Pakistan"] = ('PK', 'PAK', 'Pakistan', 0)
lookup["PAK"] = ('PK', 'PAK', 'Pakistan', 0)
lookup["Pakistan"] = ('PK', 'PAK', 'Pakistan', 0)
details["PK"] = {"continent":"Asia","capital":"Islamabad","currency":"Pakistan Rupee","web":".pk","lang":"ur-PK | en-PK | pa | sd | ps | brh","tz":"+05:00","altname":""}
#----------------------------------------------------------------------
b64_PL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBsIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik02NDAgNDgwSDBWMGg2NDB6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZGMxNDNjIiBkPSJNNjQwIDQ4MEgwVjI0MGg2NDB6Ii8+CiAgPC9nPgo8L3N2'
    b'Zz4K', 'PL')

PL = b64_PL
index.append("PL")
index.append("POL")
index.append("Poland")
catalog["PL"] = PL
catalog["POL"] = PL
catalog["Poland"] = PL
country["Poland"] = ('PL', 'POL', 0)
lookup["PL"] = ('PL', 'POL', 'Poland', 0)
lookup["Warsaw Poland"] = ('PL', 'POL', 'Poland', 0)
lookup["POL"] = ('PL', 'POL', 'Poland', 0)
lookup["Poland"] = ('PL', 'POL', 'Poland', 0)
details["PL"] = {"continent":"Europe","capital":"Warsaw","currency":"Zloty","web":".pl","lang":"pl","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_PM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'PM')

PM = b64_PM
index.append("PM")
index.append("SPM")
index.append("Saint Pierre and Miquelon")
catalog["PM"] = PM
catalog["SPM"] = PM
catalog["Saint Pierre and Miquelon"] = PM
country["Saint Pierre and Miquelon"] = ('PM', 'SPM', 0)
lookup["PM"] = ('PM', 'SPM', 'Saint Pierre and Miquelon', 0)
lookup["Saint-Pierre Saint Pierre and Miquelon"] = ('PM', 'SPM', 'Saint Pierre and Miquelon', 0)
lookup["SPM"] = ('PM', 'SPM', 'Saint Pierre and Miquelon', 0)
lookup["Saint Pierre and Miquelon"] = ('PM', 'SPM', 'Saint Pierre and Miquelon', 0)
details["PM"] = {"continent":"Americas","capital":"Saint-Pierre","currency":"Euro","web":".pm","lang":"fr-PM","tz":"-03:00","altname":""}
#----------------------------------------------------------------------
b64_PN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBuIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwMjQ3ZCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAxMjE2OSIgZD0iTTAgMGgzMjB2'
    b'MjQwSDBaIi8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTM3LjUgMCAxMjIgOTAuNUwyODEg'
    b'MGgzOXYzMWwtMTIwIDg5LjUgMTIwIDg5VjI0MGgtNDBsLTEyMC04OS41TDQwLjUgMjQwSDB2'
    b'LTMwbDExOS41LTg5TDAgMzJWMFoiLz4KICA8cGF0aCBmaWxsPSIjYzgxMDJlIiBkPSJNMjEy'
    b'IDE0MC41IDMyMCAyMjB2MjBsLTEzNS41LTk5LjVabS05MiAxMCAzIDE3LjUtOTYgNzJIMFpN'
    b'MzIwIDB2MS41bC0xMjQuNSA5NCAxLTIyTDI5NSAwWk0wIDBsMTE5LjUgODhoLTMwTDAgMjFa'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTEyMC41IDB2MjQwaDgwVjBaTTAgODB2ODBo'
    b'MzIwVjgwWiIvPgogIDxwYXRoIGZpbGw9IiNjODEwMmUiIGQ9Ik0wIDk2LjV2NDhoMzIwdi00'
    b'OHpNMTM2LjUgMHYyNDBoNDhWMFoiLz4KICA8cGF0aCBmaWxsPSIjZjdlMDE3IiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00MTAuMSAyNTIuM2E1Ni41IDU2LjUgMCAw'
    b'IDAtMTkgMjcuOGMtNS43IDI3LjMtMTMuMyAzMy40LTI1IDI3LjUgMCAxNC43IDEyLjkgMTUu'
    b'OCAxOC41IDcuMyAwIDEzLjcgNSAyNS42IDE2LjIgMzUuOCA0LjggNC4zIDUuNyAxLjQgMy40'
    b'LTMuNC0yLjItNC43LTIuMi0yMC02LjctMjguOCA3LjIgNS4xIDE3LjggMi4yIDE3LTEyLTku'
    b'MyA1LjQtMTguNSA1LjItMTkuNS03LjctMS4xLTE1IDQuNy0zNyAxNS4xLTQ2LjV6bS0xMS0x'
    b'MDguNmMuNy01LjUtLjUtMTEtNC41LTE0LjUtNy42LTYuNy0xNS4xLTQuNS0yMC43IDEtOC4z'
    b'LTQuNi0xMi44IDExLjQtMjIuMiA4LjcgMS41IDUuMiA0IDcuNCA4LjggNS42LTUgNC41IDAg'
    b'MTAtNS45IDE1LjQgMTAuNiAzLjQgMTYuMi0yLjUgMTUuOC0xMi43YTkuNiA5LjYgMCAwIDAg'
    b'MTMuNy0uN2MtNS42LTEuOC01LjYtNi43LTMuNC0xMS4yIDMuNC02LjggMTkuMy02LjUgMTgu'
    b'NCA4LjR6Ii8+CiAgPHBhdGggZmlsbD0iIzMzNzMyMSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'd2lkdGg9Ii40IiBkPSJNNDIzLjYgMjIyLjFjLTEyIDYuNC0zMy44IDMuNy0zNS45LTEyLTIt'
    b'MTUuNSAxMy4xLTIyLjUgMTcuMi0yNC41IDYuMy0zLjIgMTEuMyAyLjUgOS4yIDkgNy0yLjQg'
    b'OC42LTEwLjYgNS4yLTE1LjMgOS4zLjcgMTcuOC02LjMgMjEuNC0xNi4yLTMuMiAzLTEyIDEt'
    b'MTkuMy41IDIuMi0yLjUgMi4yLTcuMyAxLjUtOS44LTcuNiA3LjktMTguNyA0LjMtMzMuMyAy'
    b'N2ExMDIzLjMgMTAyMy4zIDAgMCAwIDkuNi0zNy4xYy44LTE1LTE1LTE1LjItMTguNC04LjQg'
    b'My43IDQuMiAxLjcgOSAuNCAxNi41LTEuNiA4LjctNSAyOS03LjkgMzUuOC0uOS0xMC42LTcu'
    b'OS0xMS4zLTkuMi0xNi41LTIgMS40LTMuMiA1LTIuNyA3LjUtMi41LTIuNy0xMS4xLjctMTQu'
    b'My0zLjQtMy4zIDYuNyAyIDEzLjUgNy43IDE2LjUtMy4zLjItNCA0LjEtNy43IDQuMSA0Ljkg'
    b'NS43IDkuOSA4IDE1LjYgOC40IDUuOC40IDEwIDIuNiAxMy41IDkuNiA1LjcgMTEuMyAyNy4y'
    b'IDE4LjYgNDcuNCA4LjN6Ii8+CiAgPHBhdGggZmlsbD0iI2Y3ZTAxNyIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9Ii40IiBkPSJNNDUzLjQgMjA4LjRjLTYuOCAxOC43LTI1LjMgMzIt'
    b'MzMuNiAzNC0xNC4yIDMuNS00My4yIDE3LjYtNTEgMjQuOGE5IDkgMCAwIDEtMy4yLTEuM2Mt'
    b'My44LTIuNy03LTExLjUtLjItMTkgMjEuMi0xOS44IDQ0LTExLjIgNTguMi0yNC44LTEyIDYu'
    b'My0zMy44IDMuNi0zNS44LTEyYTU1IDU1IDAgMCAwIDU0LjUtMTYuMiA5Ny43IDk3LjcgMCAw'
    b'IDEgMTEgMTQuNXoiLz4KICA8cGF0aCBmaWxsPSIjMzM3MzIxIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iLjQiIGQ9Ik00MTAuMSAyNTIuM2MtMTAuNyA5LTE2LjIgMzEuNC0xNS4x'
    b'IDQ2LjUuMyA0LjIgMS41IDcgMy4zIDguOC44LTguNiA2LjctMzAuNyAyMi00MC42IDEyLjgt'
    b'OC4zIDMyLjktMjcgNDAuMy00OC41YTE3LjIgMTcuMiAwIDAgMC03LjktOS4yYy03LjQgMjAu'
    b'Mi0yNy4xIDI5LjktNDIuNiA0M3oiLz4KICA8cGF0aCBmaWxsPSIjMzE2ZDNhIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00NDYuNSAxOTkuN2E1MC4zIDUwLjMgMCAw'
    b'IDEtMjAuOSAxNi44IDExIDExIDAgMCAwIDIuNS02LjggNzYuOSA3Ni45IDAgMCAxLTQwLjQu'
    b'NSA1NSA1NSAwIDAgMCA1NC42LTE2LjIgMjEgMjEgMCAwIDEgNC4yIDUuN3oiLz4KICA8cGF0'
    b'aCBmaWxsPSIjMzM3MzIxIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik0z'
    b'NjUuNCAyNDdjLTE3LjIgMTYtNS44IDMwLjIgMSAzMy4zLTEuOSAxMS4zIDguNyAxMCA4LjUg'
    b'MTkuNCA0LjMtMi40IDUuNC05IDQuNy0xNC4yIDUuNSA1LjkgMTkuMi0uNyAyMi4xIDEwLjIg'
    b'MS45LTEyLTcuNC0yNC0xOC45LTIyLjggNC44LTQuMyAyLTExLjMtMi41LTEzLjEtLjkgOC44'
    b'LTEwLjggOC44LTE0LjYgNi0zLjktMi42LTctMTEuNC0uMy0xOC45eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNmN2UwMTciIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0iTTQwMi43'
    b'IDM0OS42Yy0xLjggMS0xLjcgMy41LS41IDUgMi4zIDMuMi0xLjcgMTAuNCA2IDExLjkgMi4y'
    b'LjUgNC0xIDQuOC0zLjUgMi40LTcuMS01LjItNy45LTUuOS0xMS4zLS42LTMuNC0yLjgtMy00'
    b'LjQtMi4xeiIvPgogIDxwYXRoIGZpbGw9IiNmN2UwMTciIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIuNCIgZD0iTTQwOS4yIDM2Mi45Yy0yLjUgMS4yLTQuOCAyLjgtMy43IDExIC40'
    b'IDMuMy4yIDExLjQtMi44IDExLjUgMS44IDEgNS43IDIgNy4zLS4yIDEuNSAyLjYgNSAxLjgg'
    b'Ni4zLTEuMyAxLjggMS40IDQuMy0xIDQuMy0zLjIgMS41IDEgNC43LS40IDMuOS01LjMgMiAu'
    b'NyA0LjQtLjcgNS4zLTEuOS0yLjgtLjYtMTAtNC40LTExLjYtNy40LTEuNy0zLjEtNi00LjYt'
    b'OS0zLjJ6Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lk'
    b'dGg9Ii40IiBkPSJNMzcwIDEzNC43YzEuMi0xLjYgMi41LTMuMiA0LTQuNm0zOSAzNC41YzIt'
    b'MS4xIDUtMS4zIDguNC0xTTQxMCAzODUuMmMtLjgtMS4xLTEuMS01LjgtLjYtOC43bTYuOSA3'
    b'LjRjLTEuMy0xLTMuNi00LjMtNC03LjFtOC4zIDMuOWExOSAxOSAwIDAgMS02LjMtOC45bTEw'
    b'LjIgMy42Yy0xLjktLjQtNy42LTQuMS0xMC04Ii8+CiAgPHBhdGggZmlsbD0iI2Y3ZTAxNyIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii40IiBkPSJNNTI4LjUgMjQ3LjJjMjcuNyAy'
    b'My4yIDI5LjUgNDEuNyAyNS4zIDUyLjUtMi4zLTEwLjEtMTMuOC0yNS45LTI1LjgtMzB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzMzNzMyMSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii40'
    b'IiBkPSJNNDc4LjkgMjM0aDUxLjR2NjFjMCA1MS45LTI4LjggODIuNS01OC4yIDk4LjhBMTA4'
    b'LjMgMTA4LjMgMCAwIDEgNDE0IDI5NXYtNjFoMzZjMCAzLjIuNCA4IDQgMTIuNyA4LjYtLjgg'
    b'MTguMi03LjIgMjQuOS0xMi42eiIvPgogIDxwYXRoIGZpbGw9IiMwMDZlYzciIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0iTTUzMC4zIDIzNHY2MWMwIDE1LjYtMi42IDI5'
    b'LjQtNyA0MS4zTDQ3MiAyNDIuNmwtNTEgOTMuN2MtNC41LTEyLTcuMS0yNS43LTcuMS00MS4z'
    b'di02MXoiLz4KICA8cGF0aCBmaWxsPSIjZjdlMDE3IiBkPSJNNTI0LjggMzMxLjlhMTE2IDEx'
    b'NiAwIDAgMS0zLjggMTBMNDcyIDI1MWwtNDguNyA5MWMtMS4zLTIuOC0yLjktNy4zLTMuOC0x'
    b'MGw1Mi43LTk3LjZ6Ii8+CiAgPHBhdGggZmlsbD0iI2Y3ZTAxNyIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9Ii40IiBkPSJtNDk1LjMgMzY1LjMgNSAyLjNhMzYgMzYgMCAwIDAgMi4y'
    b'LTE5LjhjLTIuOSA3LjQtMTIuOCA3LjItMTUuNSAxMS43IDEuNi44IDMuMiAyIDQuNSAyLjkt'
    b'My40IDMuNC0xMS4zIDktMTUuOCAxMC40di00OC40YzAtMy40LTEuMi02LjItMS4yLTl2LTEw'
    b'YzAtMi4zLS40LTUuNi0yLjQtNS42cy0yLjUgMy4zLTIuNSA1LjZ2MTBjMCAyLjgtMS4xIDYt'
    b'MS4xIDl2NDguNGMtMi41LTcuMi0xMi4yLTQuOC0xNi43LTEyYTE0IDE0IDAgMCAxIDUuNC0u'
    b'MmMtMy40LTExLjUtMTIuNy0xMi40LTE0LjQtMTUuOCAwIDQuOC0yIDE1LjggMS4xIDIwLjYu'
    b'Ny0uOSAxLjgtMS44IDMtMi41IDMuOSA4LjMgMjEuMSA4LjMgMjUuMiAyMi4xIDMuMy01IDE1'
    b'LTExIDIzLjItMTkuN3oiLz4KICA8cGF0aCBmaWxsPSIjZjdlMDE3IiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00NzIuMSAzMjVjMy44IDAgMTYtMS4yIDIwLjQtMS4y'
    b'IDEuMiAwIDIuMS0xLjggMi4xLTMuOSAwLTItLjktMy44LTItMy44LTQuNSAwLTE2LjYtMS4y'
    b'LTIwLjUtMS4yLTMuOCAwLTE2IDEuMi0yMC40IDEuMi0xLjIgMC0yLjEgMS43LTIuMSAzLjgg'
    b'MCAyLjEgMSAzLjkgMiAzLjkgNC41IDAgMTYuNyAxLjIgMjAuNSAxLjJ6bS0yLjUtMTkuOGMt'
    b'LjgtLjctMS44LTEtMy0xLTIuNiAwLTQuNyAxLjgtNC43IDQuMSAwIDIuNCAyLjEgNC4zIDQu'
    b'NyA0LjMgMi41IDAgNC42LTIgNC42LTQuMyAwLTEuOCAyLjYtMS44IDIuNiAwIDAgMy43LTMu'
    b'MiA2LjctNy4yIDYuN3MtNy4zLTMtNy4zLTYuN2MwLTMuNiAzLjMtNi42IDcuMy02LjZhOCA4'
    b'IDAgMCAxIDMuMy44YzAgLjYtLjMgMS43LS4zIDIuN3oiLz4KICA8cGF0aCBmaWxsPSIjZjdl'
    b'MDE3IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00NTEuNyAzMjMuOGMx'
    b'LjEgMCAyLTEuOCAyLTMuOSAwLTItLjktMy44LTItMy44Ii8+CiAgPHBhdGggZmlsbD0iI2Y3'
    b'ZTAxNyIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii40IiBkPSJNNDUzLjQgMzIzLjhj'
    b'MS4xIDAgMi0xLjggMi0zLjkgMC0yLS45LTMuOC0yLTMuOG0xMS4xIDguNGMxLjQgMCAyLjUt'
    b'MiAyLjUtNC42IDAtMi41LTEtNC42LTIuNS00LjZtMi42IDkuNGMxLjUgMCAyLjYtMi4xIDIu'
    b'Ni00LjggMC0yLjctMS4xLTQuOC0yLjYtNC44bTguNyA5LjdjMS41IDAgMi42LTIuMiAyLjYt'
    b'NC45cy0xLjItNC45LTIuNi00LjltMi43IDkuNmMxLjQgMCAyLjYtMiAyLjYtNC43IDAtMi42'
    b'LTEuMi00LjctMi42LTQuN20xMi4xIDguNmMxLjIgMCAyLjEtMS43IDIuMS0zLjlzLS45LTQt'
    b'Mi00bS00My43IDQ3YzEuMy0uOSAzLTEuNiA0LjgtMm00MS4xIDIuNC0xLjQtMW0zLjggM2Mz'
    b'LjItMy40IDUuOC03LjMgNy4zLTExLjciLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00NjEuOCAyNzcuMmMwLTEuMi45LTEuNiAy'
    b'LTIuNCAxLjItMSAxLjctMS40IDIuOS0xLjRoMTQuOGMxIDAgMS4zLjMgMS4zIDEuM3YyMGMw'
    b'IDEtLjIgMS40LTEuMyAxLjRoLTE5Ljd2LTE5LjIiLz4KICA8cGF0aCBmaWxsPSIjZTVlNWU1'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00NzcuOCAyOTcuOGMyIDAg'
    b'MS42IDAgMy0xLjRzMS4zLTEuMyAxLjMtMi42di0xOC40YzAtMS0uMy0xLjItMS4zLTEuMmgt'
    b'MTMuN2MtMSAwLTEuNS40LTIuNyAxLjMtMSAuOC0xLjggMS4yLTEuOCAyLjJ2MjAuMXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9'
    b'Ik00NzkuMyAyOTcuNGMwIDEtLjMgMS4zLTEuNCAxLjNoLTE0LjhjLTEuMSAwLTEuMy0uMy0x'
    b'LjMtMS4zdi0yMC4xYzAtMSAuMi0xLjMgMS4zLTEuM2gxNC44YzEuMSAwIDEuNC4zIDEuNCAx'
    b'LjN6Ii8+CiAgPHBhdGggZmlsbD0iIzk2ODc3ZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lk'
    b'dGg9Ii40IiBkPSJNNTA4IDIyMi4zYzIuOCAzLjIgMy44IDcuNSAyLjIgMTEuOEg1MDZjMS44'
    b'LTUuNS43LTEwLjYtNy0xMS4zLTExLjQtMS0yNC44IDIxLjItNDQuOSAyMy45LTUuOC03LTUu'
    b'NS0yMC4zIDItMjYuNmE4MiA4MiAwIDAgMC0xNy43LTI4LjYgNTUgNTUgMCAwIDAtMTAuNy0u'
    b'N2MzLTYuNCAxMS4zLTEzIDE4LjEtMTUuN2E4MiA4MiAwIDAgMSAzLjQtNC41Yy43LTguNyA0'
    b'Mi00LjcgNTAuNy43IDAgOS44IDMuOSA0Mi4yIDguMiA1MXoiLz4KICA8cGF0aCBkPSJNNDU4'
    b'IDIyOC4yYy0xLTE1LTcuMS0yNy40LTE1LjctMzUuOGEyMy41IDIzLjUgMCAwIDAgMTgtM2M3'
    b'LjUtNSAyNy0xMy42IDM0LTkuOS42IDEuMyAxIDQgLjUgNS45LTEuNy00LjUtMjAuNCAyLjQt'
    b'MjUuNyA0LjYtNSAyLjMtNy4zIDUuNS01LjUgMTIuNi0zLTIuNS0yLTQuOC01LTYuNiAxLjIg'
    b'Mi45IDIuMiA4LjIgMi42IDEyLjUtMS4yLTMtMy4yLTkuNi03LjYtMTMuNWE3NC4yIDc0LjIg'
    b'MCAwIDEgNS42IDM0LjhjMyAwIDkuOC0zIDEyLjQtNS0yLjMgMy4zLTkuMiA1LjctMTMuNSA2'
    b'LjZhMjIgMjIgMCAwIDAtMy4zIDExLjhjLS4zLTQuMiAxLTE0LjMgMy4xLTE1em01MC01Ljlj'
    b'LTMuOC00LjItMTAuNy02LjQtMTkuNi00YTI4IDI4IDAgMCAxIDYuOC0yLjNjLS4zLTIuMy0y'
    b'LjQtMTIuNS0yLjgtMTVsMi41LTFjMS4zIDYuMSAyLjggMTMuMSAzLjggMTYgLjguMSAyLjYu'
    b'NSA0LjIgMS4zLS43LTIuNC00LjUtMTkuNC00LjQtMjEuMmwzLjQtMS44YTEzOCAxMzggMCAw'
    b'IDAgNiAyOHoiLz4KICA8cGF0aCBmaWxsPSIjOTY4NzdkIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iLjQiIGQ9Ik01MDYgMjM0YzEuNy01LjMuNi0xMC41LTctMTEuMi02LS41LTEy'
    b'LjQgNS4zLTIwIDExLjN6bS00OS45LTQ4LjVhNDUgNDUgMCAwIDEtMTQuOC0xLjVjLjItMSAu'
    b'Ni0yIDEuMS0zLjJhNDcgNDcgMCAwIDAtOC41IDYuOGM1LjQgMS4yIDE2LjYgMS43IDIyLjIt'
    b'Mi4xeiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIuNCIgZD0iTTQ1NiAyMjBjMS4yIDMuNyAyIDcuMiAyLjEgMTAuM20tMTIuNC01NS4yYy0y'
    b'IDMtMy44IDYuMi00LjQgOWE0Ny42IDQ3LjYgMCAwIDAgMTQuOCAxLjQiLz4KICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00MzguNCAx'
    b'OTEuNWMxLjQuMyAyLjguNSA0IC45IDQgMS4xIDEyLjMgMS4xIDE4LTMgNS42LTQgMjEtMTYu'
    b'NyAzOC4zLTE4Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'd2lkdGg9Ii40IiBkPSJNNDMzLjkgMTg3LjZjNS40IDEuMiAxNi42IDEuNyAyMi4yLTIuMWE3'
    b'Ni4xIDc2LjEgMCAwIDEgMzguNC0xNC44Ii8+CiAgPHBhdGggZmlsbD0iIzMzNzMyMSIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii40IiBkPSJNNTI4LjUgMjQ3LjJjMTkgMTMgMzMg'
    b'MjUuNyAzNyA0NnMxMS43IDI1LjcgMjEuMiAyMC4zYy0yLjIgMTEuNy0xNCAxMy0yMy45IDQg'
    b'MSAxMy42LTQuNSAyOS44LTE4LjUgMzUuNy0uOS04LjEgNC41LTE0LjYgMy0yMS4yLS43LTMt'
    b'MS05LjcgMi45LTEyLjktNy41IDIuNS0xOS4yLTIuMi0yMC4zLTEzLjMgOC42IDQgMTkuNiA0'
    b'LjcgMjMuOS02LjEgNC4yLTEwLjggMi40LTI5LjMtMjUuMy01Mi41em0yMy45LTEwNS42YzUu'
    b'OS0xNS4zIDIxLjItMTMuNyAyNi40LTcuMiAxNS4xLTguNiAxNy4yIDEwLjggMzAgNy0uMiAz'
    b'LjYtNC41IDctOS4yIDYuNyA1IDQuNS0yIDExLjMgOC41IDE1LjQtOSA0LjUtMjEuNi0uMi0y'
    b'NS0xMi43LTMgNS45LTEzLjUgNS45LTE3LjggMS4yIDkuMi0yLjUgOC42LTExIDMuNC0xNC41'
    b'LTUuMy0zLjQtMTQuNS0yLTE2LjMgNC4xem0tNDUuNyAzMy44YTgyLjIgODIuMiAwIDAgMCAy'
    b'Mi4zIDM0LjhjMTAuOCAxMCAyNy4xIDcuNCAzNi4zLTIgLjIgMTguOC0xOS40IDIwLjMtMzAu'
    b'MiAxNC40LTQuOC0yLjYtOC43LTEuMy00LjEgMyA3IDYuMiAyMi4zIDExIDQwLjQgMTQuOCAz'
    b'MS41IDYuOCAyMC4zIDMxLjggMTEgMzEuNiAyLjcgMCA0LjktMi45IDEtNi4zLTI3LjQtMjQu'
    b'Ny04My0xNS04Mi4yLTcwLTUuOCAxNC41LTMwIDguOC0xOC43LTguMyAzLjYgMi45IDEwIDMu'
    b'MSAxMS43LTEuNCAxLjQtMy41LjUtOS42LTUuOC0xNC45IDEgMCAzLjMgMCAzLTIuNi4zIDEu'
    b'NiAxLjcgMy44IDUuMyAzIDEgMS43IDIgMi43IDMuNSAyLjEuMyAwIDEuMS0uNS44LTIuMS4y'
    b'IDMgMy44IDQuMSA1LjcgMy45eiIvPgogIDxwYXRoIGZpbGw9IiNmN2UwMTciIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0iTTUzNSAyMjIuNmMxMy4xIDguNSAyOCA4LjUg'
    b'NDEuNS03LjIgNC4zLTUgMTEtOS4zIDE1LjgtOS43IDQuOC0uNSA0LjUtNSA4LjEtNi0yLjIt'
    b'LjYtMy4xLTMuMy02LjUtMyA4LjUtMi45IDYtOS43IDEwLjEtMTMtMy40IDEuMy04LjYtMy43'
    b'LTEzLjUgMi43IDEuMy0zLS41LTYuNC0xLjctNy44LjUgMy40LTYuNiA0LTggMTIuNi0uNyA0'
    b'LjgtMy40IDQuNi0zLjgtMi45LS4zLTUuNC0zLTIwLjUtNi0yOC4yLTMuMi03LjYtNC0xOC4y'
    b'LjMtMTkuN2E3LjcgNy43IDAgMCAwLTIuNi0yLjhjLTUuMy0zLjQtMTQuNS0yLTE2LjMgNC01'
    b'LjggMTUuNCAxMC42IDI0LjIgOS4zIDQwLjktMi41LTEyLjQtMjIuNi0xNS42LTIyLjQtMjcu'
    b'OC02LjUgMy01LjYgOC40LTMuMSAxMi43LTQtNi4zLTEzLjMgNC0yMS4yLTQuNS0xIDExLjMg'
    b'OSAxNS41IDE3LjEgMTYtNCA3LjIgMS40IDEzLjMgNi44IDE1LjMuMi0xMi42IDI2LjEtNy41'
    b'IDI2LjQgMTQuMi4yIDE4LjUtMTkuNyAyMC0zMC4zIDE0LjJ6bTM2LjQgMTcuOGMzMS41IDYu'
    b'OCAyMC4zIDMxLjggMTEgMzEuNi01LjktLjItMTEuNS01LjEtMTEuOC05LjQtNi44IDMuNi01'
    b'IDEwLjcuMiAxMy41LTE0LjItMS42LTIwLjIgNy43LTIwLjUgMTggMi42LTQuOCAxMC40LTUg'
    b'MTMuNC00czEwLjUgMS41IDEzLjUtMmMtMi41IDIuMiAxLjYgNy4yLTIgMTEgMTItLjQgMTcu'
    b'MS0xMS41IDE1LTE2LjMgMTUuNC0xNCAxMi41LTM2LjgtMTguOC00Mi40em0tMjQuMSAxMDcu'
    b'MmMyIDEuMiAxLjggNCAuNCA1LjctMi44IDMuNCAxLjQgMTEuNS03LjIgMTMtMi41LjMtNC40'
    b'LTEuMy01LjItNC4yLTIuNC04IDYuMS04LjYgNy0xMi4zIDEtMy44IDMuMy0zLjMgNS0yLjJ6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2Y3ZTAxNyIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'Ii40IiBkPSJNNTM5LjYgMzYyLjFjMi43IDEuNCA1LjEgMy40IDMuNyAxMi40LS43IDMuNy0u'
    b'OCAxMi44IDIuNSAxMy0yIDEtNi40IDEuOS04LS41LTEuOSAyLjgtNS43IDEuOC03LTEuOC0y'
    b'LjIgMS42LTQuOC0xLjMtNC43LTMuNy0xLjggMS01LjMtLjctNC4yLTYtMi4yLjYtNC45LTEt'
    b'NS44LTIuNCAzLjEtLjYgMTEuMi00LjUgMTMuMy03LjggMi0zLjQgNy00LjggMTAuMi0zLjJ6'
    b'Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii40'
    b'IiBkPSJNNTM3LjcgMzg3YzEtMS4yIDEuNS02LjUgMS05LjdtLTggNy45YzEuNS0xIDQuMi00'
    b'LjUgNC44LTcuN20tOS41IDRhMjIgMjIgMCAwIDAgNy40LTkuN20tMTEuNSAzLjdjMi0uNCA4'
    b'LjYtNC4zIDExLjQtOC42Ii8+CiAgPHBhdGggZmlsbD0iI2Y3ZTAxNyIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9Ii40IiBkPSJNNTAxLjIgMTk1LjhjLS40IDIzIDkuMiAzNC44IDIy'
    b'LjYgNDIuNC01LTMtMi44LTEzLjEtOS41LTE2LjQgMS42LS4xIDQgMi4xIDggMS4yLTItNC4y'
    b'LTUtMTAuOC0xMi40LTExLjcgMi0uMiA2IC41IDguOC0uNS0zLjgtNi0xNC0zLjEtMTcuNS0x'
    b'NXptLTIuNC0yMmMtLjgtLjMtMS41LTEuMS0yLjEtMi4yLTMuNi44LTUtMS41LTUuMy0zIC4z'
    b'IDIuNi0yIDIuNS0zIDIuNiA2LjMgNS4yIDcuMiAxMS4zIDUuOCAxNC44LTEuOCA0LjUtOCA0'
    b'LjMtMTEuNyAxLjQtLjUgOS42IDEyIDEyLjcgMTYuNS43IDAgMiAyLjYgMS44IDMuMiA0LjUg'
    b'My4yLTUuMi44LTEyLjctMy40LTE4Ljh6Ii8+CiAgPHBhdGggZmlsbD0iIzMzNzMyMSIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii40IiBkPSJNNDc5IDEyOGEyNyAyNyAwIDAgMS04'
    b'LTE4LjljLjItNSAyLjItMTAuMyA5LjUtOC0yLjMgMC0uNyA0LjQtMyA0LjkgMS44LjcgNC40'
    b'LS45IDQuOC0yIC40IDEuNiAzLjQgMS4yIDMuNiAzIDEuMS0uOS0uMS01LjMtMS44LTYuMiAx'
    b'LjItLjcgMi00LjIgMS40LTUuOS0xLjIuMi0yLjkgMS44LTMuMiA0LjEuNi0xLjgtLjEtNi4z'
    b'LTMuMy03LS45IDEuMi0xLjEgNC4zLjEgNi0yLjktLjctNy4yIDEuMi04LjIgMy43LjItMyAu'
    b'Ni03LjMgMi41LTEwIC42LS44LTEtMi40LTIuMS0uMy0yLjItNC4zLTgtNi41LTEwLjctNC40'
    b'LTIuNiAyLjItNi0xLTguMiAyLjQtMi4xIDMuNC05LjQgMy43LTkgNy4zLjIgMi4yLS4zIDUu'
    b'NS0xLjQgNi43LTIuNiAyLjkgMS4zIDUgMiA3LjYtLjUtOC41IDEzLjEtMjUuMiAyNi44LTE4'
    b'LjdhMzAuMiAzMC4yIDAgMCAwLTIuNyAxMS42Yy0uNiA3LjcuNiAxOC41IDggMjQuOXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjYzgxMDJlIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQi'
    b'IGQ9Ik00ODMgMTAxLjFjMC0yIDMuNS00LjcgOC4yLTQuNiA1LjcgMCAxMCA1LjIgMTQuNiA0'
    b'LjdzMi40IDIgMS40IDIuOGMtMSAuNi0xLjUgMS42LTEuMiAyLjkuMyAxLjItLjIgMi0yIC45'
    b'LTQuMS0yLjYtOC4yIDEtMTMuNi0xLTQuNS0xLjctNy4yLTIuNy03LjQtNS43eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM5Njg3N2QiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0i'
    b'TTQ1OS44IDE1NC40YTM0LjMgMzQuMyAwIDAgMC0xNS0xNi43bC0uMi0zLjhhNTAgNTAgMCAw'
    b'IDAgMTAuMS03LjZjMTcgOCA0MC0zLjQgNTAuNi0xNS4zbDQgMi40LTIgMi43LTIuMS0xLjFh'
    b'MTI5LjYgMTI5LjYgMCAwIDEtMTUuMiAxNC4yYzMuOSAxIDkuMyAxLjcgMTAuOCAxLjYgOS40'
    b'LTYuOCAxNi45LTEyLjkgMjAuNS0xMy4zbDMgNC0yLjcgMi0yLjEtMS4zYTEwOC43IDEwOC43'
    b'IDAgMCAwLTI2LjIgMzguOGMtNi4zLTEuNC0yOC45LS41LTMzLjUtNi42eiIvPgogIDxwYXRo'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0iTTQ5MCAx'
    b'MjkuMmMtMS41LS40LTIuOC0uOC0zLjUtMS4yYTIyLjcgMjIuNyAwIDAgMS0xMi4xIDMuNCIv'
    b'PgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIg'
    b'ZD0iTTQ2MC43IDE1MS45Yy0xLjUtOC40IDEtMTcuOCA1LjItMjAuNmEzMy42IDMzLjYgMCAw'
    b'IDAgMzQuOC0uNSIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIuNCIgZD0iTTQ2MC43IDE0Ny41YzcuMi0uMiAyMyAxIDI2LjcgMS41IDMuOS42'
    b'IDEwLjMgMi4yIDkuNCA0LjFtLTMyLjgtNi44IDIuMS0yLTItMi4xLTIuMSAyeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiMzMzczMjEiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0i'
    b'TTQ2OSAxMDQuM2MtMi42LTMuNi05LjgtNC44LTExLjMgMC0uNyAyLjItMS43IDQuNS0zLjQg'
    b'NS41cy0xLjMgNC4xLS42IDUuNGMxLjggMy4zLjIgNi41IDMuNyA4LjYgMC0yLjYgMy45LTUu'
    b'MyA3LjEtNiAzLjMtLjYgOC4zLTMuNiA5LTYuOC42LTMuNCAxLjgtNi00LjUtNi43eiIvPgog'
    b'IDxwYXRoIGZpbGw9IiM5Njg3N2QiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIg'
    b'ZD0iTTQ1Mi43IDEzNi44aDF2Ni4xbC41LjMgNS4zLTMgLjUuNy01LjQgMy4xdi42bDUuNCAz'
    b'LS41LjgtNS40LTNjLS4xLjEtLjMuMy0uNS4zdjYuMmgtLjl2LTYuMmEyIDIgMCAwIDEtLjUt'
    b'LjNsLTUuMyAzLjEtLjUtLjggNS4zLTN2LS43bC01LjMtMyAuNS0uOCA1LjMgMyAuNS0uM3oi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjOTY4NzdkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0i'
    b'LjQiIGQ9Ik00NjAuNyAxNTEuOGExMC43IDEwLjcgMCAxIDEgLjktMTQgMjQgMjQgMCAwIDAt'
    b'MS4yIDUuNyA3LjMgNy4zIDAgMSAwLTcuMyA4YzMuNCAwIDYuMy0yLjMgNy4yLTUuNCAwIDEu'
    b'NCAwIDQuNi40IDUuN3oiLz4KICA8cGF0aCBmaWxsPSIjMzM3MzIxIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iLjQiIGQ9Ik00NDguNiAxNjJjLS42LS44LTEuOS0zLTEuNy00LjVh'
    b'NiA2IDAgMCAxIDMuOCAxLjVjLS4xLTEuMi0uNi0zLjYtLjMtNC44IDEuMi41IDMuOCAyIDQu'
    b'NyAzLjYtLjItMS4xLS43LTQtLjItNS44IDEuMy44IDMuNiAyLjkgNCA0LjQuMi0yLjMgMS02'
    b'IDEuNi03IDEgMSAyLjYgMiAzLjYgMy40LjItMS45IDEuMi00IDIuNS00LjUgMSAxIDIuNiAz'
    b'LjcgMyA2LjYgMS0uMyAyLjMtMiAyLjktMyAuNSAxIDEuMSAyLjUuNyA0LjUgMS4zLTEuMiAy'
    b'LjgtMi43IDMtNC4xIDEgLjcgMi43IDIuNCAzLjEgNC4yLS4yLTEuNSAwLTQuMS0uNS01LjYg'
    b'MS42IDEgMyAyLjUgMy4zIDQuMi41LTEuNiAxLjUtNC40IDIuNC01IC45IDEuOCAxLjggNCAx'
    b'LjcgNS43LjYtMS4xIDEuNC0zLjIgMi4zLTMuNi44IDEuMi43IDQgLjUgNS40LjgtMS4xIDIu'
    b'My0yLjUgMy4yLTMgMCAuOC4yIDIuMSAwIDMuMWExNCAxNCAwIDAgMCAzLjItNS4yYzEuNi44'
    b'IDMuMiAzLjUgMy4zIDQuOSAxLjItLjUgMy40LTIuNSA0LTMuNiAwIC44LjQgMyAwIDQuNi43'
    b'LS43IDEuMy0yIDEuNy0yLjYuNCAxLjEgMCAzLjgtLjQgNS4zYTYgNiAwIDAgMSAzLjQtMS41'
    b'IDIwIDIwIDAgMCAxLTIuNSA3LjhjLTEwLjgtMy0zMy41LTQuMS01Ni4zLTUuNHoiLz4KICA8'
    b'cGF0aCBmaWxsPSIjZjdlMDE3IiBkPSJNNDg2LjQgMTAyLjNjMC0uOSAxLjgtMi43IDUuMS0y'
    b'LjcgNCAwIDcuNyAzIDEwLjkgMi43IDMuMi0uMiAxLjYuOSAxIDEuMS0uOC4zLTEuMS43LTEg'
    b'MS4yLjMuNiAwIC45LTEuNC40LTIuOC0xLTUuNy40LTkuNC0uNC0zLjItLjctNS4xLTEtNS4y'
    b'LTIuM3oiLz4KICA8cGF0aCBmaWxsPSIjZjdlMDE3IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iLjQiIGQ9Ik00NTIuMSAxNjguOGMtMy4zIDQtNi43IDMuNC03LjQuOC0uNy0yLjYg'
    b'MS44LTMuOC45LTYuMXMxLjUtMy4zIDIuNi0yLjMgNC44LTIuMiA2LjMgMS4yYzEuNiAzLjQg'
    b'Mi44IDUuNyAyIDctMSAxLjQtMy43LjctNC40LS42em0xNC42LTYuMWMtLjYtMS41IDIuOS00'
    b'LjQgNC43LTIuMyAxLjggMiA0LjYtMi4yIDYuMiAxIDEuNiAzLjIgMiA0LjkgMi45IDYuNy43'
    b'IDEuOC00LjMgMi43LTUuOSAxLjIuMiAxLTQuNCAxLjktNS42LTEuMmwtMi4zLTUuNHptMjMu'
    b'NCAxLjljLS44LTEuNiAzLjMtMy45IDUuNS0xIC41LTEuMiA0LjYtMS40IDQuOSAybC41IDYu'
    b'OWMuMSAxLjMtMi41IDIuNi00LjMtLjktMy40LjctNC45LTEuMi01LjMtMy4xLS40LTItLjgt'
    b'My0xLjMtNHoiLz4KICA8cGF0aCBmaWxsPSIjMzM3MzIxIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iLjQiIGQ9Ik00NTQuMyAxNjIuM2MtLjUtMS4xIDMtMy40IDUuMi0xLjcgMi4z'
    b'IDEuNyA1LjUtMS40IDcgMS42IDIuNyA2LjIgMi44IDYuNiAyIDcuOC0uOCAxLjItNC41Ljct'
    b'NS40LTEtLjEgMS4yLTMuMyAxLTQuOS4xLTEuOC0xLTMuMS00LjgtMy45LTYuOHptMjMuNy4z'
    b'Yy0uNy0xLjggNC42LTMuMyA3LS4yIDEuMS0xLjEgMy43LTEuMiA1LjEgMi4yIDEuNSAzLjMg'
    b'MS43IDUuMS43IDYtLjguNi0zLjUgMS00LjQtLjUtMS4zLjgtNS4xLjEtNi0yLS44LTIuMS0x'
    b'LjUtNC0yLjMtNS41em0yMi41IDMuNGMwLTEuNyAyLjgtMi40IDMuOSAwIDEgMi4yIDQuNS4x'
    b'IDQuOCA0IDAgLjctLjQgMy41LTEuNSA0LjktMSAxLjMtNi4zIDAtNi43LTIuOWwtLjUtNnoi'
    b'Lz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjQi'
    b'IGQ9Ik00NTIuMSAxNjguOGMtMS4yLTEuNy0yLjktNC40LTUtMS41bTE2LjEgMS43Yy0uOC0u'
    b'OS0xLjctMi41LTItMy43bTEzLjQgNGMtLjgtLjYtMi0xLjctMi42LTIuOW0xLjYtM2MyIC4y'
    b'IDMuMyAyIDMuOSAyLjkuNi44IDIgMi40IDMgMi41bTUuOSAxLjNjLS43LTEtMS40LTItMS41'
    b'LTIuOG0uMS00LjljLjYgMSAxLjEgMS43IDEuNSAyLjZtMTAuMSA2LjZhOS4zIDkuMyAwIDAg'
    b'MC0zLjUtMy45bTMuMS0yLjNjLjEgMy4zIDQuNSAzLjYgNC43IDZtMy41LTUuNGMuNC44LjYg'
    b'MS42LjYgMyIvPgo8L3N2Zz4K', 'PN')

PN = b64_PN
index.append("PN")
index.append("PCN")
index.append("Pitcairn")
catalog["PN"] = PN
catalog["PCN"] = PN
catalog["Pitcairn"] = PN
country["Pitcairn"] = ('PN', 'PCN', 0)
lookup["PN"] = ('PN', 'PCN', 'Pitcairn', 0)
lookup["Adamstown Pitcairn"] = ('PN', 'PCN', 'Pitcairn', 0)
lookup["PCN"] = ('PN', 'PCN', 'Pitcairn', 0)
lookup["Pitcairn"] = ('PN', 'PCN', 'Pitcairn', 0)
details["PN"] = {"continent":"Oceania","capital":"Adamstown","currency":"New Zealand Dollar","web":".pn","lang":"en-PN","tz":"-08:00","altname":""}
#----------------------------------------------------------------------
b64_PR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXByIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InByLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTM3LjMgMGg2ODIu'
    b'N3Y1MTJILTM3LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNwci1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoMzUpIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjZWQwMDAwIiBkPSJNLTM3'
    b'LjMgMGg3Njh2NTEyaC03Njh6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLTM3LjMg'
    b'MTAyLjRoNzY4djEwMi40aC03Njh6bTAgMjA0LjhoNzY4djEwMi40aC03Njh6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjMDA1MGYwIiBkPSJtLTM3LjMgMCA0NDAuNyAyNTUuN0wtMzcuMyA1MTFW'
    b'MHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xNTYuNCAzMjUuNSAxMDkgMjkwbC00'
    b'Ny4yIDM1LjggMTcuNi01OC4xLTQ3LjItMzYgNTguMy0uNCAxOC4xLTU4IDE4LjUgNTcuOCA1'
    b'OC4zLjEtNDYuOSAzNi4zIDE4IDU4eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'PR')

PR = b64_PR
index.append("PR")
index.append("PRI")
index.append("Puerto Rico")
catalog["PR"] = PR
catalog["PRI"] = PR
catalog["Puerto Rico"] = PR
country["Puerto Rico"] = ('PR', 'PRI', 0)
lookup["PR"] = ('PR', 'PRI', 'Puerto Rico', 0)
lookup["San Juan Puerto Rico"] = ('PR', 'PRI', 'Puerto Rico', 0)
lookup["PRI"] = ('PR', 'PRI', 'Puerto Rico', 0)
lookup["Puerto Rico"] = ('PR', 'PRI', 'Puerto Rico', 0)
details["PR"] = {"continent":"Americas","capital":"San Juan","currency":"US Dollar","web":".pr","lang":"en-PR | es-PR","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_PS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXBzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InBzLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTExOCAwaDY4Mi43'
    b'djUxMkgtMTE4eiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgY2xpcC1wYXRo'
    b'PSJ1cmwoI3BzLWEpIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgxMTAuNikgc2NhbGUoLjkzNzUp'
    b'Ij4KICAgIDxnIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRoPSIxcHQiPgogICAg'
    b'ICA8cGF0aCBkPSJNLTI0NiAwSDc3OHYxNzAuN0gtMjQ2eiIvPgogICAgICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNLTI0NiAxNzAuN0g3Nzh2MTcwLjZILTI0NnoiLz4KICAgICAgPHBhdGgg'
    b'ZmlsbD0iIzA5MCIgZD0iTS0yNDYgMzQxLjNINzc4VjUxMkgtMjQ2eiIvPgogICAgICA8cGF0'
    b'aCBmaWxsPSJyZWQiIGQ9Im0tMjQ2IDUxMiA1MTItMjU2TC0yNDYgMHY1MTJ6Ii8+CiAgICA8'
    b'L2c+CiAgPC9nPgo8L3N2Zz4K', 'PS')

PS = b64_PS
index.append("PS")
index.append("PSE")
index.append("Palestine")
catalog["PS"] = PS
catalog["PSE"] = PS
catalog["Palestine"] = PS
country["Palestine"] = ('PS', 'PSE', 0)
lookup["PS"] = ('PS', 'PSE', 'Palestine', 0)
lookup["East Jerusalem Palestine"] = ('PS', 'PSE', 'Palestine', 0)
lookup["PSE"] = ('PS', 'PSE', 'Palestine', 0)
lookup["Palestine"] = ('PS', 'PSE', 'Palestine', 0)
details["PS"] = {"continent":"Asia","capital":"East Jerusalem","currency":"No universal currency","web":".ps","lang":"ar-PS","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_PT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1wdCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9InJlZCIgZD0iTTI1NiAwaDM4NHY0ODBI'
    b'MjU2eiIvPgogIDxwYXRoIGZpbGw9IiMwNjAiIGQ9Ik0wIDBoMjU2djQ4MEgweiIvPgogIDxn'
    b'IGZpbGw9IiNmZjAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'bGluZWNhcD0icm91bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0i'
    b'LjYiPgogICAgPHBhdGggZD0iTTMzOS41IDMwNi4yYy0zMi4zLTEtMTgwLTkzLjItMTgxLTEw'
    b'OGw4LjEtMTMuNWMxNC43IDIxLjMgMTY1LjcgMTExIDE4MC42IDEwNy44bC03LjcgMTMuNyIv'
    b'PgogICAgPHBhdGggZD0iTTE2NC45IDE4Mi44Yy0yLjkgNy44IDM4LjYgMzMuNCA4OC40IDYz'
    b'LjggNDkuOSAzMC4zIDkyLjkgNDkgOTYgNDYuNGwxLjUtMi44Yy0uNiAxLTIgMS4zLTQuMy42'
    b'LTEzLjUtMy45LTQ4LjYtMjAtOTIuMS00Ni40LTQzLjYtMjYuNC04MS40LTUwLjctODcuMy02'
    b'MWE2LjMgNi4zIDAgMCAxLS42LTMuMWgtLjJsLTEuMiAyLjItLjIuM3ptMTc1LjMgMTIzLjhj'
    b'LS41IDEtMS42IDEtMy41LjgtMTItMS4zLTQ4LjYtMTkuMS05MS45LTQ1LTUwLjQtMzAuMi05'
    b'Mi01Ny42LTg3LjQtNjQuOGwxLjItMi4yLjIuMWMtNCAxMi4yIDgyLjEgNjEuNCA4Ny4yIDY0'
    b'LjYgNDkuOCAzMC44IDkxLjggNDguOSA5NS41IDQ0LjJsLTEuMyAyLjN6Ii8+CiAgICA8cGF0'
    b'aCBkPSJNMjU2LjIgMjA3LjJjMzIuMi0uMyA3Mi00LjQgOTUtMTMuNmwtNS04Yy0xMy41IDcu'
    b'NS01My41IDEyLjUtOTAuMyAxMy4yLTQzLjQtLjQtNzQuMS00LjUtODkuNS0xNC44bC00LjYg'
    b'OC42YzI4LjIgMTIgNTcuMiAxNC41IDk0LjQgMTQuNiIvPgogICAgPHBhdGggZD0iTTM1Mi41'
    b'IDE5My44Yy0uOCAxLjMtMTUuOCA2LjQtMzcuOCAxMC4yYTM4MS4yIDM4MS4yIDAgMCAxLTU4'
    b'LjYgNC4zIDQxNi4xIDQxNi4xIDAgMCAxLTU2LjItMy42Yy0yMy4xLTMuNi0zNS04LjYtMzku'
    b'NS0xMC40bDEuMS0yLjJjMTIuNyA1IDI0LjcgOCAzOC43IDEwLjJBNDExLjUgNDExLjUgMCAw'
    b'IDAgMjU2IDIwNmEzOTEuOCAzOTEuOCAwIDAgMCA1OC4zLTQuM2MyMi41LTMuNyAzNC44LTgu'
    b'NCAzNi42LTEwLjVsMS42IDIuN3ptLTQuNC04LjFjLTIuNCAyLTE0LjYgNi4zLTM2IDkuN2Ez'
    b'ODguMiAzODguMiAwIDAgMS01NS44IDRjLTIyIDAtNDAuMS0xLjYtNTMuOC0zLjYtMjEuOC0y'
    b'LjgtMzMuNC04LTM3LjYtOS40bDEuMy0yLjJjMy4zIDEuNyAxNC40IDYuMiAzNi41IDkuM2Ez'
    b'ODUgMzg1IDAgMCAwIDUzLjYgMy40IDM4NCAzODQgMCAwIDAgNTUuNC00YzIxLjUtMyAzMy4x'
    b'LTguNCAzNC45LTkuOGwxLjUgMi42ek0xNTAuMyAyNDZjMTkuOCAxMC43IDYzLjkgMTYgMTA1'
    b'LjYgMTYuNCAzOCAuMSA4Ny40LTUuOCAxMDUuOS0xNS42bC0uNS0xMC43Yy01LjggOS01OC44'
    b'IDE3LjctMTA1LjggMTcuNC00Ny0uNC05MC43LTcuNi0xMDUuMy0xN3Y5LjUiLz4KICAgIDxw'
    b'YXRoIGQ9Ik0zNjIuOCAyNDQuNXYyLjVjLTIuOCAzLjQtMjAuMiA4LjQtNDIgMTJhNDM0IDQz'
    b'NCAwIDAgMS02NS40IDQuNCA0MDAgNDAwIDAgMCAxLTYyLTQuMyAxNTUgMTU1IDAgMCAxLTQ0'
    b'LjQtMTJ2LTIuOWM5LjcgNi40IDM1LjkgMTEuMiA0NC43IDEyLjYgMTUuOCAyLjQgMzYuMSA0'
    b'LjIgNjEuNyA0LjIgMjYuOSAwIDQ4LjQtMS45IDY1LTQuNCAxNS43LTIuMyAzOC04LjIgNDIu'
    b'NC0xMi4xem0wLTl2Mi41Yy0yLjggMy4zLTIwLjIgOC4zLTQyIDExLjlhNDM0IDQzNCAwIDAg'
    b'MS02NS40IDQuNSA0MTQgNDE0IDAgMCAxLTYyLTQuMyAxNTUgMTU1IDAgMCAxLTQ0LjQtMTJ2'
    b'LTNjOS43IDYuNSAzNiAxMS4yIDQ0LjcgMTIuNmE0MDggNDA4IDAgMCAwIDYxLjcgNC4zYzI2'
    b'LjkgMCA0OC41LTIgNjUtNC41IDE1LjctMi4yIDM4LTguMSA0Mi40LTEyem0tMTA3IDY4Ljhj'
    b'LTQ1LjYtLjItODQuNy0xMi40LTkzLTE0LjRsNiA5LjRhMjQ5LjggMjQ5LjggMCAwIDAgODcu'
    b'NCAxNC4zYzM0LjctMSA2NS0zLjcgODYuMy0xNC4xbDYuMi05LjhjLTE0LjUgNi45LTY0IDE0'
    b'LjYtOTMgMTQuNiIvPgogICAgPHBhdGggZD0iTTM0NC45IDI5Ny4zYTE0MyAxNDMgMCAwIDEt'
    b'Mi44IDRjLTEwIDMuNi0yNiA3LjQtMzIuNiA4LjRhMjk1LjUgMjk1LjUgMCAwIDEtNTMuNyA1'
    b'Yy00MC40LS42LTczLjUtOC41LTg5LTE1LjNsLTEuMy0yLjEuMi0uNCAyLjEuOWEyODYuNSAy'
    b'ODYuNSAwIDAgMCA4OC4yIDE0LjVjMTguOCAwIDM3LjUtMi4xIDUyLjYtNC44IDIzLjItNC43'
    b'IDMyLjYtOC4yIDM1LjUtOS44bC43LS40em01LjMtOC44YTI4Ny4yIDI4Ny4yIDAgMCAxLTIg'
    b'My41Yy01LjQgMi0yMCA2LjItNDEuMyA5LjItMTQgMS45LTIyLjcgMy44LTUwLjYgNC4zYTM0'
    b'Ny40IDM0Ny40IDAgMCAxLTk0LjItMTRMMTYxIDI4OWEzOTAgMzkwIDAgMCAwIDk1LjQgMTRj'
    b'MjUuNS0uNSAzNi40LTIuNCA1MC4zLTQuMyAyNC44LTMuOCAzNy4zLTggNDEtOS4xYTIuOSAy'
    b'LjkgMCAwIDAgMC0uMmwyLjYtMXoiLz4KICAgIDxwYXRoIGQ9Ik0zNTAuOCAyMzcuNmMuMSAz'
    b'MC0xNS4zIDU3LTI3LjYgNjguOGE5OS4zIDk5LjMgMCAwIDEtNjcuOCAyOC4yYy0zMC4zLjUt'
    b'NTguOC0xOS4yLTY2LjUtMjcuOWExMDEgMTAxIDAgMCAxLTI3LjUtNjcuNGMxLjgtMzIuOCAx'
    b'NC43LTU1LjYgMzMuMy03MS4zYTk5LjYgOTkuNiAwIDAgMSA2NC4yLTIyLjcgOTguMiA5OC4y'
    b'IDAgMCAxIDcxIDM1LjZjMTIuNSAxNS4yIDE4IDMxLjcgMjAuOSA1Ni43ek0yNTUuNiAxMzVh'
    b'MTA2IDEwNiAwIDAgMSAxMDYgMTA1LjIgMTA1LjYgMTA1LjYgMCAxIDEtMjExLjQgMGMtLjEt'
    b'NTggNDcuMy0xMDUuMiAxMDUuNC0xMDUuMiIvPgogICAgPHBhdGggZD0iTTI1NS45IDEzNC41'
    b'YzU4LjIgMCAxMDUuNiA0Ny40IDEwNS42IDEwNS42UzMxNC4xIDM0NS43IDI1NiAzNDUuN3Mt'
    b'MTA1LjYtNDcuNC0xMDUuNi0xMDUuNmMwLTU4LjIgNDcuNC0xMDUuNiAxMDUuNi0xMDUuNnpN'
    b'MTUyLjYgMjQwYzAgNTYuOCA0Ni43IDEwMy4zIDEwMy4zIDEwMy4zIDU2LjYgMCAxMDMuMy00'
    b'Ni41IDEwMy4zLTEwMy4zcy00Ni43LTEwMy4zLTEwMy4zLTEwMy4zUzE1Mi42IDE4My4yIDE1'
    b'Mi42IDI0MHoiLz4KICAgIDxwYXRoIGQ9Ik0yNTYgMTQzLjNhOTcgOTcgMCAwIDEgOTYuNyA5'
    b'Ni43IDk3LjEgOTcuMSAwIDAgMS05Ni43IDk2LjhjLTUzIDAtOTYuNy00My42LTk2LjctOTYu'
    b'OGE5Ny4xIDk3LjEgMCAwIDEgOTYuNy05Ni43ek0xNjEuNiAyNDBjMCA1MiA0Mi42IDk0LjQg'
    b'OTQuNCA5NC40czk0LjQtNDIuNSA5NC40LTk0LjRjMC01Mi00Mi42LTk0LjQtOTQuNC05NC40'
    b'YTk0LjggOTQuOCAwIDAgMC05NC40IDk0LjR6Ii8+CiAgICA8cGF0aCBkPSJNMjYwLjMgMTM0'
    b'aC05LjF2MjEyLjNoOXoiLz4KICAgIDxwYXRoIGQ9Ik0yNTkuMyAxMzIuOGgyLjN2MjE0Ljdo'
    b'LTIuMlYxMzIuOHptLTkgMGgyLjR2MjE0LjdoLTIuM1YxMzIuOHoiLz4KICAgIDxwYXRoIGQ9'
    b'Ik0zNjEuNiAyNDQuMnYtNy44bC02LjQtNi0zNi4zLTkuNi01Mi4yLTUuMy02MyAzLjItNDQu'
    b'OCAxMC42LTkgNi43djcuOWwyMi45LTEwLjMgNTQuNC04LjVoNTIuM2wzOC40IDQuMiAyNi42'
    b'IDYuNHoiLz4KICAgIDxwYXRoIGQ9Ik0yNTYgMjIzLjhjMjQuOSAwIDQ5IDIuMyA2OC4zIDYg'
    b'MTkuOCA0IDMzLjcgOSAzOC41IDE0LjV2Mi44Yy01LjgtNy0yNC41LTEyLTM5LTE1LTE5LTMu'
    b'Ni00My02LTY3LjktNi0yNi4xIDAtNTAuNSAyLjYtNjkuMyA2LjItMTUgMy0zNS4xIDktMzcu'
    b'NiAxNC44di0yLjljMS4zLTQgMTYuMy0xMCAzNy4zLTE0LjMgMTguOS0zLjcgNDMuMy02LjEg'
    b'NjkuNi02LjF6bTAtOS4xYTM4MyAzODMgMCAwIDEgNjguMyA2YzE5LjggNCAzMy43IDkgMzgu'
    b'NSAxNC42djIuN2MtNS44LTYuOS0yNC41LTEyLTM5LTE0LjktMTktMy43LTQzLTYtNjcuOS02'
    b'YTM3NiAzNzYgMCAwIDAtNjkuMiA2LjJjLTE0LjUgMi43LTM1LjQgOC45LTM3LjcgMTQuN3Yt'
    b'Mi44YzEuNC00IDE2LjYtMTAuMyAzNy4zLTE0LjMgMTktMy43IDQzLjMtNi4yIDY5LjctNi4y'
    b'em0tLjYtNDYuMmMzOS4zLS4yIDczLjYgNS41IDg5LjMgMTMuNWw1LjcgMTBjLTEzLjYtNy40'
    b'LTUwLjYtMTUtOTQuOS0xNC0zNi4xLjMtNzQuNyA0LTk0IDE0LjRsNi44LTExLjRjMTUuOS04'
    b'LjMgNTMuMy0xMi41IDg3LjEtMTIuNSIvPgogICAgPHBhdGggZD0iTTI1NiAxNzYuN2EzNTQg'
    b'MzU0IDAgMCAxIDYxLjMgNC4zYzE2IDMgMzEuMyA3LjQgMzMuNSA5LjhsMS43IDNjLTUuMy0z'
    b'LjQtMTguNi03LjMtMzUuNi0xMC41cy0zOC43LTQuMy02MS00LjJjLTI1LjMtLjEtNDUgMS4y'
    b'LTYxLjggNC4yYTEwOC45IDEwOC45IDAgMCAwLTMzLjMgMTAuM2wxLjctMy4xYzYtMyAxNS4z'
    b'LTYuNyAzMS4xLTkuNiAxNy41LTMuMiAzNy40LTQuMSA2Mi40LTQuMnptMC05YzIxLjQtLjIg'
    b'NDIuNiAxIDU5LjEgNGE5NiA5NiAwIDAgMSAzMC42IDEwbDIuNSA0Yy00LjItNC43LTIwLTku'
    b'Mi0zNC4xLTExLjYtMTYuNC0yLjktMzYuNy00LTU4LjEtNC4yYTM2MSAzNjEgMCAwIDAtNTku'
    b'NSA0LjQgOTcuMyA5Ny4zIDAgMCAwLTI5LjYgOS4xbDIuMi0zLjNjNS44LTMgMTUuMi01Ljgg'
    b'MjctOC4xYTM1NyAzNTcgMCAwIDEgNTkuOS00LjR6TTMwOC40IDI4NGEyNzYuNCAyNzYuNCAw'
    b'IDAgMC01Mi41LTRjLTY1LjUuOC04Ni42IDEzLjUtODkuMiAxNy4zbC01LThjMTYuOC0xMiA1'
    b'Mi40LTE4LjggOTQuNi0xOC4yIDIxLjkuNCA0MC44IDEuOSA1Ni42IDVsLTQuNSA4Ii8+CiAg'
    b'ICA8cGF0aCBkPSJNMjU1LjYgMjc4LjljMTguMi4zIDM2IDEgNTMuMyA0LjJsLTEuMiAyLjJj'
    b'LTE2LTMtMzMuMi00LTUyLTQtMjQuMy0uMi00OC43IDIuMS03MCA4LjItNi43IDEuOS0xNy44'
    b'IDYuMi0xOSA5LjhsLTEuMi0yYy40LTIuMiA3LTYuNiAxOS42LTEwIDI0LjQtNyA0Ny4yLTgu'
    b'MyA3MC41LTguNHptLjgtOS4yYTMyNyAzMjcgMCAwIDEgNTcuMyA1bC0xLjMgMi4zYTI5OSAy'
    b'OTkgMCAwIDAtNTYtNC45Yy0yNC4yIDAtNDkuOSAxLjgtNzMuMyA4LjYtNy41IDIuMi0yMC42'
    b'IDctMjEgMTAuN2wtMS4yLTIuMmMuMi0zLjQgMTEuNS03LjkgMjEuNy0xMC44IDIzLjUtNi45'
    b'IDQ5LjMtOC42IDczLjgtOC43eiIvPgogICAgPHBhdGggZD0ibTM0OS40IDI5MC41LTcuOCAx'
    b'Mi4zLTIyLjctMjAuMS01OC42LTM5LjUtNjYuMi0zNi4zLTM0LjMtMTEuNyA3LjMtMTMuNiAy'
    b'LjUtMS4zIDIxLjMgNS4zIDcwLjQgMzYuMyA0MC42IDI1LjZMMzM2IDI3MmwxMy45IDE2eiIv'
    b'PgogICAgPHBhdGggZD0iTTE1OC42IDE5NS41YzYtNCA1MC4yIDE1LjYgOTYuNiA0My42IDQ2'
    b'LjEgMjggOTAuMyA1OS42IDg2LjMgNjUuNWwtMS4zIDIuMS0uNi41Yy4xLS4xLjgtMSAwLTMu'
    b'MS0yLTYuNS0zMy40LTMxLjUtODUuMy02Mi45LTUwLjctMzAuMS05Mi45LTQ4LjMtOTctNDMu'
    b'MWwxLjMtMi42ek0zNTEgMjkwLjRjMy44LTcuNi0zNy4yLTM4LjUtODguMS02OC42LTUyLTI5'
    b'LjUtODkuNi00Ni45LTk2LjUtNDEuN0wxNjUgMTgzYzAgLjEgMC0uMi40LS41IDEuMi0xIDMu'
    b'My0xIDQuMi0xIDExLjguMiA0NS41IDE1LjcgOTIuOCA0Mi44IDIwLjggMTIgODcuNiA1NSA4'
    b'Ny4zIDY3IDAgMSAuMSAxLjItLjMgMS44bDEuNy0yLjZ6Ii8+CiAgPC9nPgogIDxnIHRyYW5z'
    b'Zm9ybT0idHJhbnNsYXRlKDAgMjYuNykgc2NhbGUoMS4wNjY2NykiPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii43IiBkPSJNMTgwLjYgMjEx'
    b'YTU4LjcgNTguNyAwIDAgMCAxNy41IDQxLjcgNTkgNTkgMCAwIDAgNDEuOCAxNy42IDU5LjQg'
    b'NTkuNCAwIDAgMCA0Mi0xNy40IDU5IDU5IDAgMCAwIDE3LjQtNDEuOHYtNzkuMmwtMTE4Ljct'
    b'LjJWMjExeiIvPgogICAgPHBhdGggZmlsbD0icmVkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iLjUiIGQ9Ik0xODMgMjExLjFhNTYuNCA1Ni40IDAgMCAwIDE2LjggNDAgNTcgNTcg'
    b'MCAwIDAgNDAuMiAxNi44IDU2LjkgNTYuOSAwIDAgMCA0MC4yLTE2LjYgNTYuNCA1Ni40IDAg'
    b'MCAwIDE2LjctNDB2LTc3SDE4M3Y3Ni44bTkxLTUzLjd2NDguOWwtLjEgNS4xYTMzLjIgMzMu'
    b'MiAwIDAgMS0xMCAyNCAzNCAzNCAwIDAgMS0yNCAxMGMtOS40IDAtMTcuNy00LTIzLjktMTAu'
    b'MmEzNCAzNCAwIDAgMS0xMC0yNHYtNTRsNjggLjJ6Ii8+CiAgICA8ZyBpZD0icHQtZSI+CiAg'
    b'ICAgIDxnIGlkPSJwdC1kIiBmaWxsPSIjZmYwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iLjUiPgogICAgICAgIDxwYXRoIHN0cm9rZT0ibm9uZSIgZD0iTTE5MC4yIDE1NC40Yy4x'
    b'LTUuNSA0LTYuOCA0LTYuOC4xIDAgNC4zIDEuNCA0LjMgNi45aC04LjMiLz4KICAgICAgICA8'
    b'cGF0aCBkPSJtMTg2LjggMTQ3LjctLjcgNi4zaDQuMmMwLTUuMiA0LTYgNC02IC4xIDAgNCAx'
    b'LjEgNC4xIDZoNC4ybC0uOC02LjRoLTE1em0tMSA2LjRoMTdjLjMgMCAuNi4zLjYuNyAwIC41'
    b'LS4zLjgtLjYuOGgtMTdjLS4zIDAtLjYtLjMtLjYtLjggMC0uNC4zLS43LjctLjd6Ii8+CiAg'
    b'ICAgICAgPHBhdGggZD0iTTE5MiAxNTRjMC0zLjMgMi4zLTQuMiAyLjMtNC4yczIuMyAxIDIu'
    b'MyA0LjJIMTkybS01LjgtOWgxNi4zYy4zIDAgLjYuNC42LjggMCAuMy0uMy42LS42LjZoLTE2'
    b'LjNjLS4zIDAtLjYtLjMtLjYtLjcgMC0uMy4zLS42LjYtLjZ6bS40IDEuNUgyMDJjLjMgMCAu'
    b'Ni4zLjYuNyAwIC40LS4zLjctLjYuN2gtMTUuNWMtLjQgMC0uNi0uMy0uNi0uNyAwLS40LjIt'
    b'LjcuNi0uN3ptNS0xMC42aDEuMnYuOGguOXYtLjhoMS4zdi45aC45di0xaDEuMnYyYzAgLjQt'
    b'LjIuNi0uNS42aC00LjRjLS4zIDAtLjYtLjItLjYtLjV2LTJ6bTQuNiAyLjcuMyA2LjRoLTQu'
    b'M2wuMy02LjVoMy43Ii8+CiAgICAgICAgPHBhdGggaWQ9InB0LWEiIGQ9Ik0xOTEgMTQxLjZ2'
    b'My40aC00di0zLjRoNHoiLz4KICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiNwdC1hIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxMC42Ii8+CiAgICAgICAgPHBhdGggaWQ9InB0'
    b'LWIiIGQ9Ik0xODYuMyAxMzloMS4ydjFoLjl2LTFoMS4ydjFoLjl2LTFoMS4ydjJjMCAuNC0u'
    b'Mi42LS41LjZoLTQuM2EuNi42IDAgMCAxLS42LS42di0yeiIvPgogICAgICAgIDx1c2UgeGxp'
    b'bms6aHJlZj0iI3B0LWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjEwLjYiLz4K'
    b'ICAgICAgICA8cGF0aCBmaWxsPSIjMDAwIiBzdHJva2U9Im5vbmUiIGQ9Ik0xOTMuOSAxNDAu'
    b'NmMwLS42LjktLjYuOSAwdjEuNmgtLjl2LTEuNiIvPgogICAgICAgIDxwYXRoIGlkPSJwdC1j'
    b'IiBmaWxsPSIjMDAwIiBzdHJva2U9Im5vbmUiIGQ9Ik0xODguNiAxNDIuOGMwLS42LjgtLjYu'
    b'OCAwdjEuMmgtLjh2LTEuMiIvPgogICAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3B0LWMiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjEwLjYiLz4KICAgICAgPC9nPgogICAgICA8'
    b'dXNlIHhsaW5rOmhyZWY9IiNwdC1kIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB5PSI0'
    b'Ni4zIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3B0LWQiIHdpZHRoPSIxMDAlIiBoZWln'
    b'aHQ9IjEwMCUiIHRyYW5zZm9ybT0icm90YXRlKC00NS4yIDMxMi44IDE4MCkiLz4KICAgIDwv'
    b'Zz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3B0LWQiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEw'
    b'MCUiIHg9IjQ1LjciLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3B0LWUiIHdpZHRoPSIxMDAl'
    b'IiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAgMCAxIDQ3OS44IDApIi8+'
    b'CiAgICA8ZyBpZD0icHQtZiIgZmlsbD0iI2ZmZiI+CiAgICAgIDxwYXRoIGZpbGw9IiMwMzki'
    b'IGQ9Ik0yMzIuNiAyMDIuNGE4LjMgOC4zIDAgMCAwIDIuMiA1LjcgNy4yIDcuMiAwIDAgMCA1'
    b'LjMgMi40YzIuMSAwIDQtMSA1LjMtMi40YTguMyA4LjMgMCAwIDAgMi4yLTUuN3YtMTAuOGgt'
    b'MTV2MTAuOCIvPgogICAgICA8Y2lyY2xlIGN4PSIyMzYuMSIgY3k9IjE5NS43IiByPSIxLjUi'
    b'Lz4KICAgICAgPGNpcmNsZSBjeD0iMjQ0LjQiIGN5PSIxOTUuNyIgcj0iMS41Ii8+CiAgICAg'
    b'IDxjaXJjbGUgY3g9IjI0MC4yIiBjeT0iMTk5LjciIHI9IjEuNSIvPgogICAgICA8Y2lyY2xl'
    b'IGN4PSIyMzYuMSIgY3k9IjIwMy45IiByPSIxLjUiLz4KICAgICAgPGNpcmNsZSBjeD0iMjQ0'
    b'LjQiIGN5PSIyMDMuOSIgcj0iMS41Ii8+CiAgICA8L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9'
    b'IiNwdC1mIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB5PSItMjYiLz4KICAgIDx1c2Ug'
    b'eGxpbms6aHJlZj0iI3B0LWYiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii0yMC44'
    b'Ii8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNwdC1mIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIx'
    b'MDAlIiB4PSIyMC44Ii8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNwdC1mIiB3aWR0aD0iMTAw'
    b'JSIgaGVpZ2h0PSIxMDAlIiB5PSIyNS44Ii8+CiAgPC9nPgo8L3N2Zz4K', 'PT')

PT = b64_PT
index.append("PT")
index.append("PRT")
index.append("Portugal")
catalog["PT"] = PT
catalog["PRT"] = PT
catalog["Portugal"] = PT
country["Portugal"] = ('PT', 'PRT', 0)
lookup["PT"] = ('PT', 'PRT', 'Portugal', 0)
lookup["Lisbon Portugal"] = ('PT', 'PRT', 'Portugal', 0)
lookup["PRT"] = ('PT', 'PRT', 'Portugal', 0)
lookup["Portugal"] = ('PT', 'PRT', 'Portugal', 0)
details["PT"] = {"continent":"Europe","capital":"Lisbon","currency":"Euro","web":".pt","lang":"pt-PT | mwl","tz":"±00:00","altname":""}
#----------------------------------------------------------------------
b64_PW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXB3IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InB3LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTcwLjMgMGg2NDB2'
    b'NDgwaC02NDB6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZS13aWR0aD0iMXB0IiBjbGlwLXBhdGg9InVybCgjcHctYSkiIHRy'
    b'YW5zZm9ybT0idHJhbnNsYXRlKDcwLjMpIj4KICAgIDxwYXRoIGZpbGw9IiM0YWFkZDYiIGQ9'
    b'Ik0tMTczLjQgMGg4NDYuM3Y0ODBoLTg0Ni4zeiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZGUw'
    b'MCIgZD0iTTMzNS42IDIzMi4xYTEzNS45IDEzMC4xIDAgMSAxLTI3MS43IDAgMTM1LjkgMTMw'
    b'LjEgMCAxIDEgMjcxLjcgMHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'PW')

PW = b64_PW
index.append("PW")
index.append("PLW")
index.append("Palau")
catalog["PW"] = PW
catalog["PLW"] = PW
catalog["Palau"] = PW
country["Palau"] = ('PW', 'PLW', 0)
lookup["PW"] = ('PW', 'PLW', 'Palau', 0)
lookup["Melekeok Palau"] = ('PW', 'PLW', 'Palau', 0)
lookup["PLW"] = ('PW', 'PLW', 'Palau', 0)
lookup["Palau"] = ('PW', 'PLW', 'Palau', 0)
details["PW"] = {"continent":"Oceania","capital":"Melekeok","currency":"US Dollar","web":".pw","lang":"pau | sov | en-PW | tox | ja | fil | zh","tz":"+09:00","altname":""}
#----------------------------------------------------------------------
b64_PY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXB5IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwMzhhOCIgZD0i'
    b'TTAgMzE5LjdoNjQwVjQ4MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDE2MGg2'
    b'NDB2MTYwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2Q1MmIxZSIgZD0iTTAgMGg2NDB2MTYwSDB6'
    b'Ii8+CiAgPGcgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiB0cmFuc2Zvcm09InRyYW5zbGF0'
    b'ZSgtMTE2LjQpIHNjYWxlKDEuNDU0NTUpIj4KICAgIDxjaXJjbGUgY3g9IjMwMCIgY3k9IjE2'
    b'NSIgcj0iNDIuMiIgc3Ryb2tlLXdpZHRoPSIxLjEiLz4KICAgIDxjaXJjbGUgY3g9IjMwMCIg'
    b'Y3k9IjE2NSIgcj0iMzQuNyIgc3Ryb2tlLXdpZHRoPSIuNSIvPgogICAgPGNpcmNsZSBjeD0i'
    b'MzAwIiBjeT0iMTY1IiByPSIyNi42IiBzdHJva2Utd2lkdGg9Ii40Ii8+CiAgPC9nPgogIDxw'
    b'YXRoIGQ9Im0yODcuMyAyNjMuNy03LjEgNC4yLTIuMi0zLjdhNi4yIDYuMiAwIDAgMS0uNy0x'
    b'LjYgMiAyIDAgMCAxIC4xLTEuM2MuMi0uNC41LS43IDEtMSAuNC0uMi43LS4zIDEuMS0uM2Ey'
    b'LjMgMi4zIDAgMCAxIDEuMS4ybC44LjZ2LTEuM2wuMy0uNSAxLjUtMi4zIDEuNCAyLjUtMS40'
    b'IDIuNC0uMy44LjEuNi4xLjIgMy0xLjd6bS01LjUuMy0uNi0xLS40LS41YS43LjcgMCAwIDAt'
    b'LjUtLjIuOC44IDAgMCAwLS41LjFsLS40LjZjMCAuMi4xLjUuNC45bC41IDF6bS02LjctNS41'
    b'LTIuMi02LjUgMS43LS42IDEuMyA0LjEgMS4zLS40LTEuMy0zLjggMS42LS41IDEuMyAzLjcg'
    b'MS41LS41LTEuNC00LjIgMS44LS41IDIuMiA2LjZ6bS0yLjktOS43LS40LTQuMmMtLjItMSAw'
    b'LTEuNi40LTIuMS40LS42IDEtLjkgMS44LTEgLjggMCAxLjUuMSAyIC42LjUuNC44IDEuMiAx'
    b'IDIuMmwuMSAxLjQgMy0uNC40IDIuNnptMy4zLTMtLjEtLjZjMC0uNS0uMi0uOC0uNC0xYS44'
    b'LjggMCAwIDAtLjctLjIgMSAxIDAgMCAwLS42LjRjLS4yLjEtLjIuNS0uMiAxbC4xLjd6bS0z'
    b'LjUtMTIuNS4zLTIuNiA0LjguNmE0LjIgNC4yIDAgMCAxIDEuNC40Yy40LjIuOC40IDEgLjgu'
    b'NC4zLjUuNy42IDEgLjIuNi4yIDEuMi4xIDEuOWwtLjIgMS4zYy0uMS41LS4zLjgtLjUgMS4x'
    b'YTMgMyAwIDAgMS0xLjggMS4zaC0xLjRsLTQuOS0uNS4zLTIuNSA1IC41Yy40IDAgLjggMCAx'
    b'LS4yLjQtLjIuNS0uNi42LTFhMS40IDEuNCAwIDAgMC0uMy0xYy0uMi0uNC0uNi0uNS0xLS42'
    b'em0xLTYgMS43LTQuNmMuMi0uOC42LTEuMyAxLjEtMS41YTIgMiAwIDAgMSAxLjYtLjJjLjUu'
    b'Mi44LjUgMSAuOS4yLjMuMy42LjMgMSAuMy0uNS43LS44IDEuMS0xYTIgMiAwIDAgMSAxLjQg'
    b'MCAyLjIgMi4yIDAgMCAxIDEuNSAxLjh2MWwtLjMgMS0xLjUgNC4yem00LTEuNC40LTEuMWMw'
    b'LS40LjEtLjcgMC0uOCAwLS4yLS4yLS40LS40LS41YS43LjcgMCAwIDAtLjYgMGMtLjIuMi0u'
    b'NC40LS41LjhsLS40IDF6bTMgMSAuNS0xLjJjLjEtLjQuMi0uNyAwLTFhLjguOCAwIDAgMC0u'
    b'NC0uNC43LjcgMCAwIDAtLjcgMGwtLjUuOS0uNCAxLjJ6bS0zLTkuNiAxLjMtMi4yIDUuNCAz'
    b'LjIgMi0zLjQgMS44IDEtMy40IDUuNnptNS03LjYgMS42LTIgNi40IDUuMy0xLjYgMnptMTEu'
    b'MS00LjMgMi4yLTFjLjMuNi40IDEuMi41IDEuN2EzLjEgMy4xIDAgMCAxLS4zIDEuNSA0LjUg'
    b'NC41IDAgMCAxLTEuMiAxLjUgNCA0IDAgMCAxLTIgMS4xIDMuNSAzLjUgMCAwIDEtMiAwIDQu'
    b'NyA0LjcgMCAwIDEtMi0xLjZjLTEtMS0xLjQtMi0xLjMtMy4xYTQuMiA0LjIgMCAwIDEgMS42'
    b'LTIuOSA0LjIgNC4yIDAgMCAxIDIuMy0xYy43LS4xIDEuNSAwIDIuMy41bC0xLjQgMS45YTEu'
    b'OSAxLjkgMCAwIDAtLjYtLjMgMS41IDEuNSAwIDAgMC0uNyAwIDEuNSAxLjUgMCAwIDAtLjYu'
    b'NCAxLjUgMS41IDAgMCAwLS42IDEuNGMwIC40LjQuOS44IDEuNC42LjcgMS4xIDEuMSAxLjYg'
    b'MS4yLjQgMCAuOCAwIDEuMi0uNC40LS4zLjYtLjYuNi0xcy0uMS0uOC0uNC0xLjN6bTguOC0z'
    b'LjItMi41IDEuNC4zIDEuNC0yLjMgMS4yLTEuMi04LjcgMi41LTEuMyA2LjYgNS44LTIuNCAx'
    b'LjN6bS0xLjMtMS4zLTIuMi0yLjIuNiAzem03LjgtOC41IDMuOC0uNmE0LjYgNC42IDAgMCAx'
    b'IDEuOCAwYy41LjEgMSAuMyAxLjMuN3MuNy43LjkgMS4yYy4yLjQuNCAxIC40IDEuNS4yLjku'
    b'MiAxLjYuMSAyYTMuNCAzLjQgMCAwIDEtLjYgMS40IDIuNyAyLjcgMCAwIDEtMSAuOSA2IDYg'
    b'MCAwIDEtMS41LjVsLTMuNy42em0yLjkgMS40LjggNC41LjYtLjFjLjUtLjEuOS0uMiAxLS40'
    b'LjMtLjEuNC0uNC41LS43di0xLjRjLS4yLS45LS41LTEuNC0uOC0xLjctLjMtLjMtLjgtLjQt'
    b'MS41LS4zem03LjgtMi44IDYuOC4zdjEuOGwtNC4zLS4yLS4xIDEuMyA0IC4yLS4xIDEuNy00'
    b'LS4ydjEuNmw0LjQuMi0uMSAxLjktNy0uM3ptMTAgLjggMi40LjYtMS41IDYgNCAxLS42IDIt'
    b'Ni4zLTEuNnptMTMuMiA0LjQgMy43IDIuMmMuOC40IDEuMyAxIDEuNCAxLjYuMi42IDAgMS4z'
    b'LS4zIDJhMi41IDIuNSAwIDAgMS0xLjcgMS4zYy0uNi4xLTEuNCAwLTIuMy0uNmwtMS4yLS43'
    b'LTEuNiAyLjYtMi4yLTEuM3ptLjQgNC40LjYuMyAxIC4zYS44LjggMCAwIDAgLjYtLjQgMSAx'
    b'IDAgMCAwIDAtLjdjMC0uMy0uMi0uNS0uNi0uOGwtLjYtLjN6bTcuMiA5LjYtMi4xLTItMS4y'
    b'LjctMi0xLjcgOC00IDIgMi0zLjQgOC4xLTItMS44em0uOC0xLjcgMS40LTIuOC0yLjcgMS42'
    b'em0xIDUuNSA2LjktNC43IDIuMyAzLjUgMSAxLjctLjEgMS4yYTIuMyAyLjMgMCAwIDEtMSAx'
    b'LjFjLS4zLjMtLjcuNC0xIC40YTIuMyAyLjMgMCAwIDEtMS4yLS4yYy0uMiAwLS41LS4zLS44'
    b'LS41bC4yLjctLjIuNmEzLjMgMy4zIDAgMCAxLS4yLjZsLTEuMyAyLjMtMS42LTIuMyAxLjMt'
    b'Mi42LjMtLjdhMSAxIDAgMCAwLS4yLS43bC0uMS0uMi0yLjggMnptNS41LS42LjcuOS40LjRj'
    b'LjIuMi4zLjIuNS4yYS44LjggMCAwIDAgLjUtLjEuOC44IDAgMCAwIC4zLS42YzAtLjIgMC0u'
    b'NS0uMy0uOWwtLjctLjl6bTIuNiAxMi40LTEtMi44LTEuNS4yLTEtMi41IDguOS0uMSAxIDIu'
    b'Ni02LjUgNi0xLTIuNnptMS41LTEuMiAyLjQtMi0zLjEuM3ptMi4xIDkgMS43LS4yLjYgMy45'
    b'LTMuNS41YTggOCAwIDAgMS0xLjMtMS44IDYuOCA2LjggMCAwIDEtLjYtMiA1IDUgMCAwIDEg'
    b'LjEtMi41IDQgNCAwIDAgMSAxLjMtMS42IDQuOSA0LjkgMCAwIDEgMi4yLS45IDUgNSAwIDAg'
    b'MSAyLjQuMiAzLjYgMy42IDAgMCAxIDEuNyAxLjRjLjQuNi42IDEuMy44IDIuMnYyYTIuNyAy'
    b'LjcgMCAwIDEtLjYgMS4zYy0uMy40LS43LjYtMS4yLjlsLS44LTIuNGMuMy0uMS41LS4zLjct'
    b'LjZzLjEtLjYgMC0xYTEuNyAxLjcgMCAwIDAtLjctMS4yYy0uNC0uMy0xLS40LTItLjJhMyAz'
    b'IDAgMCAwLTEuNy43Yy0uNC40LS41IDEtLjQgMS41IDAgLjMuMS42LjMuOGwuNS44aC44em01'
    b'LjQgMTItLjIgMi42LTUtLjRhNC4yIDQuMiAwIDAgMS0xLjMtLjQgMyAzIDAgMCAxLTEtLjgg'
    b'MyAzIDAgMCAxLS42LTEuMSA1LjEgNS4xIDAgMCAxLS4yLTEuOGwuMi0xLjMuNS0xLjJhMyAz'
    b'IDAgMCAxIC44LS44IDIuNiAyLjYgMCAwIDEgMS0uNCA0LjkgNC45IDAgMCAxIDEuNC0uMmw1'
    b'IC41LS4zIDIuNS01LS40Yy0uNSAwLS45IDAtMS4xLjNhMS40IDEuNCAwIDAgMC0uNSAxYzAg'
    b'LjQgMCAuOC4zIDEgLjIuMy41LjUgMSAuNXptLTkuMSA4LjguOS0yLjgtMS4yLS44LjgtMi41'
    b'IDcgNS42LTEgMi42LTguOC40LjktMi41em0xLjkgMCAzIC4xLTIuNS0xLjh6bTMgNi44LTEu'
    b'NSAyLjRoLTMuM2wxLjUgMi45LTEuNCAyLjQtMi41LTUuMi0zLTEuOCAxLjQtMi4yIDMgMS44'
    b'eiIvPgogIDxnIGZpbGw9IiMwMDliM2EiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIu'
    b'MSI+CiAgICA8cGF0aCBkPSJNMzI4LjEgMjExLjNzMjMuNCAxMC4xIDE5LjMgMzAuOWMtNCAy'
    b'MC44LTE3IDIwLjYtMjIuMiAyMy01IDIuMi04LjYgNS41LTEwLjYgNS0yLS40LTQuNy0yLTQu'
    b'Ny0ycy0uMiAzLjUgMy45IDRjNC4xLjcgOS41LTUuMyAxMi02IDIuNi0uNiAxOC41LTIuNCAy'
    b'Mi40LTIzLjUgNC41LTIyLjYtMjAtMzAuNy0yMC0zMS40eiIvPgogICAgPHBhdGggZD0iTTMz'
    b'OS45IDIxNS44YTMuMi44IDc1LjEgMCAxLTEuNSAwIDMuMi44IDc1LjEgMSAxIDEuNSAweiIv'
    b'PgogICAgPHBhdGggZD0iTTMzOS4xIDIxNmEzLjMuNyA2My4zIDEgMS0xLjQuNSAzLjMuNyA2'
    b'My4zIDAgMSAxLjQtLjV6bS0yLjMgMS41YTMuMS44IDE3IDAgMS0uMiAxLjYgMy4xLjggMTcg'
    b'MCAxIC4yLTEuNnoiLz4KICAgIDxwYXRoIGQ9Ik0zMzcuMSAyMTYuN2EzLjMuNyAzNC4yIDEg'
    b'MS0uNyAxLjMgMy4zLjcgMzQuMiAxIDEgLjctMS4zeiIvPgogICAgPHBhdGggZD0iTTMzOC4x'
    b'IDIxNi4zYTMuMy43IDQ2LjIgMSAxLTEgMSAzLjMuNyA0Ni4yIDAgMSAxLTF6Ii8+CiAgICA8'
    b'cGF0aCBkPSJtMzM5LjcgMjE5LjItMSAuNmMtLjMgMC0uNi0uMy0xLjIgMHMtMSAuOS0xLjEg'
    b'MS4yYy0uMS4zLjIuNS45LjEuNy0uMy45LS45IDEuMi0xLjFsMS4zLS43LjgtMS4zYy4zLS40'
    b'IDEuMi0xIDEuNi0xLjguMy0uNi4yLTEuMS0uMi0uOWEzIDMgMCAwIDAtMS4yIDEuM2MtLjIu'
    b'NCAwIDEtLjMgMS40bC0uOCAxLjJ6bTcuMyAyLjRhMSA0LjgtMS42IDEgMS0yLjItLjUgMSA0'
    b'LjgtMS42IDEgMSAyLjIuNXoiLz4KICAgIDxwYXRoIGQ9Ik0zNDUuOCAyMjEuNWE1IDEgNzcu'
    b'NSAxIDEtMi4yLjEgNSAxIDc3LjUgMSAxIDIuMSAweiIvPgogICAgPHBhdGggZD0iTTM0MiAy'
    b'MjIuN2E0LjcgMS4xIDM1IDEgMS0uNyAyLjIgNC43IDEuMSAzNSAxIDEgLjctMi4yeiIvPgog'
    b'ICAgPHBhdGggZD0iTTM0Mi44IDIyMS42YTUgMSA1MC45IDAgMS0xLjQgMS42IDUgMSA1MC45'
    b'IDEgMSAxLjQtMS41eiIvPgogICAgPHBhdGggZD0iTTM0NC4zIDIyMS41YTUuMSAxIDYxLjgg'
    b'MSAxLTEuOCAxIDUuMSAxIDYxLjggMSAxIDEuOC0xeiIvPgogICAgPHBhdGggZD0ibTM0NS42'
    b'IDIyNi40LTEuOC40Yy0uMyAwLS42LS43LTEuNS0uNS0uOS4yLTEuNy44LTIgMS4yLS4yLjQu'
    b'MS44IDEuMi42IDEuMi0uMiAxLjYtMSAyLjItMSAuNS0uMiAxLjQtLjQgMi0uNC4yLS40IDEt'
    b'MS4yIDEuNS0xLjYuNS0uNSAyLTEgMi43LTEuOC43LS44LjctMS42IDAtMS41YTQuOCA0Ljgg'
    b'MCAwIDAtMiAxLjNjLS41LjYtLjQgMS41LS45IDJsLTEuNCAxLjN6bTUuMSA0LjlhMSA0Ljgg'
    b'OC43IDEgMS0yLTEgMSA0LjggOC43IDEgMSAyIDF6Ii8+CiAgICA8cGF0aCBkPSJNMzQ5LjYg'
    b'MjMxYTEgNS0yIDEgMS0yLS4zIDEgNS0yIDEgMSAyIC4zeiIvPgogICAgPHBhdGggZD0iTTM0'
    b'NS43IDIzMS40YTQuNyAxLjEgNDYgMSAxLTEgMiA0LjcgMS4xIDQ2IDEgMSAxLTJ6Ii8+CiAg'
    b'ICA8cGF0aCBkPSJNMzQ2LjcgMjMwLjVhNSAxIDYxLjggMSAxLTEuNyAxLjMgNSAxIDYxLjgg'
    b'MSAxIDEuNy0xLjN6Ii8+CiAgICA8cGF0aCBkPSJNMzQ4LjEgMjMwLjdhNS4xIDEgNzIuNSAx'
    b'IDEtMS45LjcgNS4xIDEgNzIuNSAxIDEgMi0uN3oiLz4KICAgIDxwYXRoIGQ9Ik0zNDguNSAy'
    b'MzUuOGgtMS43Yy0uMyAwLS41LS44LTEuNC0uOGEzLjMgMy4zIDAgMCAwLTIuMS44Yy0uNC40'
    b'LS4xLjggMSAuOHMxLjctLjUgMi4zLS42aDJsMS44LTEuMmMuNi0uNCAyLjEtLjYgMy0xLjMu'
    b'Ny0uNi45LTEuNC4zLTEuNGE1IDUgMCAwIDAtMi4zLjljLS41LjQtLjYgMS4zLTEuMiAxLjct'
    b'LjQuMi0xLjYgMS4xLTEuNyAxbTIuNSA2LjRhMSA0LjggMzEuMyAwIDEtMS40LTEuNyAxIDQu'
    b'OCAzMS4zIDAgMSAxLjQgMS43Ii8+CiAgICA8cGF0aCBkPSJNMzUwLjEgMjQxLjNhMSA1IDIw'
    b'LjYgMCAxLTEuOC0xLjEgMSA1IDIwLjYgMCAxIDEuOCAxLjFtLTMuNy0xLjJhNC44IDEgNzAg'
    b'MCAxLTEuOCAxLjUgNC44IDEgNzAgMCAxIDEuOC0xLjUiLz4KICAgIDxwYXRoIGQ9Ik0zNDcu'
    b'NiAyMzkuN2ExIDUuMS00LjkgMCAxLTIgLjUgMSA1LjEtNC45IDEgMSAyLS41Ii8+CiAgICA8'
    b'cGF0aCBkPSJNMzQ5IDI0MC40YTEgNS4yIDUuNSAxIDEtMi0uMSAxIDUuMiA1LjUgMSAxIDIg'
    b'LjEiLz4KICAgIDxwYXRoIGQ9Ik0zNDcuMyAyNDUuM3MtMS40LS41LTEuNi0uN2MtLjMtLjIt'
    b'LjEtLjgtMS0xLjNhMy4xIDMuMSAwIDAgMC0yLjIgMGMtLjUgMC0uNC42LjYgMSAxIC42IDEu'
    b'OC4yIDIuMy40bDEuOC45Yy41LS4yIDEuNi0uMyAyLjItLjQuNi0uMSAyLjEuNCAzLjIgMCAu'
    b'OS0uMyAxLjMtMSAuNy0xLjJhNC41IDQuNSAwIDAgMC0yLjMgMGMtLjcuMS0xLjEgMS0xLjgg'
    b'MS0uNSAwLTEuOS40LTIgLjNtMSA3LjdhMS4zIDUuNSA0OC41IDEgMS0xLjEtMi40IDEuMyA1'
    b'LjUgNDguNSAxIDEgMSAyLjQiLz4KICAgIDxwYXRoIGQ9Ik0zNDcuMyAyNTEuOWExLjIgNS44'
    b'IDM3LjUgMSAxLTEuNS0yIDEuMiA1LjggMzcuNSAxIDEgMS41IDIiLz4KICAgIDxwYXRoIGQ9'
    b'Ik0zNDMuNyAyNDkuMmExLjMgNS41LTMuNSAxIDEtMi40IDEgMS4zIDUuNS0zLjUgMSAxIDIu'
    b'NC0xIi8+CiAgICA8cGF0aCBkPSJNMzQ1LjEgMjQ5LjJhMS4yIDUuOSAxMS42IDAgMS0yLjMt'
    b'LjIgMS4yIDUuOSAxMS42IDEgMSAyLjMuMSIvPgogICAgPHBhdGggZD0iTTM0Ni4zIDI1MC40'
    b'YTEuMiA2IDIyLjEgMSAxLTIuMS0uOCAxLjIgNiAyMi4xIDEgMSAyLjEuOCIvPgogICAgPHBh'
    b'dGggZD0iTTM0MyAyNTUuM2ExNi4zIDE2LjMgMCAwIDEtMS42LTEuNGMtLjItLjMuMS0xLS43'
    b'LTEuOHMtMS44LTEtMi40LTFjLS42LjEtLjYuNy4zIDEuNiAxIDEgMiAuOCAyLjQgMS4yLjYu'
    b'NCAxLjQgMS4xIDEuNyAxLjZsMi42LjRjLjcgMCAyLjIgMS4xIDMuNSAxLjEgMSAwIDEuOC0u'
    b'NSAxLjItMWE1LjMgNS4zIDAgMCAwLTIuNi0xYy0uOCAwLTEuNS44LTIuMi42bC0yLjMtLjNt'
    b'LTIuMyA3LjNhMS40IDYgNzkuOCAxIDEgLjMtMi45IDEuNCA2IDc5LjggMSAxLS4zIDIuOSIv'
    b'PgogICAgPHBhdGggZD0iTTM0MC41IDI2MWExLjMgNi40IDY4LjUgMCAxLS41LTIuNiAxLjMg'
    b'Ni40IDY4LjUgMCAxIC41IDIuNyIvPgogICAgPHBhdGggZD0iTTMzOC40IDI1Ni40YTEuNCA2'
    b'IDI2LjIgMCAxLTIuOC0uNSAxLjQgNiAyNi4yIDEgMSAyLjguNSIvPgogICAgPHBhdGggZD0i'
    b'TTMzOS45IDI1Ny4yYTEuMyA2LjUgNDEuOCAwIDEtMi4zLTEuNSAxLjMgNi41IDQxLjggMCAx'
    b'IDIuMyAxLjUiLz4KICAgIDxwYXRoIGQ9Ik0zNDAuMyAyNTkuMWExLjMgNi41IDUyLjcgMSAx'
    b'LTEuNi0yIDEuMyA2LjUgNTIuNyAwIDEgMS42IDIiLz4KICAgIDxwYXRoIGQ9Ik0zMzQuNCAy'
    b'NjEuN2ExOC4xIDE4LjEgMCAwIDEtLjctMi4yYy0uMS0uNC42LS44LjMtMmE0LjMgNC4zIDAg'
    b'MCAwLTEuOS0yLjNjLS41LS4zLS45LjItLjUgMS42LjQgMS40IDEuNCAxLjkgMS43IDIuNmwu'
    b'OCAyLjQgMi4yIDEuOWMuNi41IDEuNSAyLjQgMi43IDMuMSAxIC43IDIgLjUgMS44LS4yYTYu'
    b'MiA2LjIgMCAwIDAtMi0yLjRjLS43LS42LTEuOC0uMy0yLjUtLjgtLjQtLjUtMi0xLjYtMi0x'
    b'LjciLz4KICAgIDxwYXRoIGQ9Ik0zMzAuOCAyNjhhMS44IDYuMSA4OSAwIDEgMC0zLjUgMS44'
    b'IDYuMSA4OSAwIDEgMCAzLjUiLz4KICAgIDxwYXRoIGQ9Ik0zMzAgMjYyLjVhMS43IDYuMyAz'
    b'Ny42IDAgMS0yLjctMi4yIDEuNyA2LjMgMzcuNiAxIDEgMi42IDIuMiIvPgogICAgPHBhdGgg'
    b'ZD0iTTMzMC44IDI2NS4zYTEuNyA2LjIgNjYuNSAwIDEtMS4yLTMuMyAxLjcgNi4yIDY2LjUg'
    b'MCAxIDEuMiAzLjNtMS43LTUzLjRhMy44LjggNDEuMSAwIDEtMS41LjggMy44LjggNDEuMSAx'
    b'IDEgMS41LS44bS0xLjkgMS41YTMuOS44IDguMiAwIDEgLjMgMS42IDMuOS44IDguMiAxIDEt'
    b'LjMtMS42Ii8+CiAgICA8cGF0aCBkPSJNMzMxLjQgMjEyLjRhNCAuNyAyNi44IDEgMS0uOCAx'
    b'LjMgNCAuNyAyNi44IDAgMSAuOC0xLjNNMzAzLjcgMjYyczUuMSAxLjEgOS42IDIuN2M0LjUg'
    b'MS43IDExLjMgNy4yIDEzLjEgNy42IDIgMCA0LjktLjcgNi0zLjYtMy4yLjgtNSAyLjEtOCAu'
    b'NS0xLjEtLjQtNC42LTMuNi04LjUtNS4zLTMuOC0xLjctMTEuNS0zLjYtMTEuNS0zLjZsLS43'
    b'IDEuN201LjUtNDYuNSA1LjktMy4xLTYuNSAxLjctLjggMS4xIDEuNC4zIi8+CiAgICA8cGF0'
    b'aCBkPSJNMzE0LjggMjE3Yy0yLjMtLjUtNS44LTEuMy04LTEuNCAxLjUtMS43IDMuNi00Ljcg'
    b'NS02LjQtMSAxLjctMi4zIDQtMi44IDUuNSAxLjUuOSA0IDEuNiA1LjggMi4yIi8+CiAgICA8'
    b'cGF0aCBkPSJNMzA4LjEgMjE1LjlhMzE0LjQgMzE0LjQgMCAwIDEgNS4zLTQuMWwtNi4xIDIu'
    b'Ny0uNiAxLjNoMS40Ii8+CiAgICA8cGF0aCBkPSJNMzEzLjcgMjE2LjljLTIuMy0uNS01Ljgt'
    b'MS4zLTgtMS41IDEuNC0xLjcgMy41LTQuNyA0LjgtNi42LS44IDEuOC0yLjIgNC4xLTIuNyA1'
    b'LjggMS42LjkgNC4xIDEuNiA2IDIuMyIvPgogICAgPHBhdGggZD0ibTMwNy4zIDIxNi4yIDYu'
    b'MS0yLjYtNi42IDEuMS0uOSAxIDEuMy41Ii8+CiAgICA8cGF0aCBkPSJNMzEzIDIxN2MtMi4z'
    b'LS4zLTYtLjctOC4yLS42IDEuMy0yIDMtNS4zIDQuMS03LjMtLjYgMS45LTEuNyA0LjQtMiA2'
    b'LjEgMS43LjggNC4zIDEuMiA2LjEgMS43Ii8+CiAgICA8cGF0aCBkPSJtMzA2LjYgMjE2LjIg'
    b'NC4yLTUtNS4zIDMuOS0uMyAxLjMgMS40LS4yIi8+CiAgICA8cGF0aCBkPSJNMzEzIDIxNy4z'
    b'Yy0yLjUgMC02LjQtLjMtOC44IDAgMS4yLTIuMyAyLjctNiAzLjYtOC4zLS40IDIuMS0xLjMg'
    b'NS0xLjQgNi45IDEuOC42IDQuNiAxIDYuNiAxLjQiLz4KICAgIDxwYXRoIGQ9Im0zMDUuOCAy'
    b'MTcuNCA1LTQuOS02LjEgMy41LS40IDEuNGgxLjUiLz4KICAgIDxwYXRoIGQ9Ik0zMTEuOSAy'
    b'MTcuNGMtMi43IDAtNi44LS4xLTkuNS4yIDEuOC0yLjUgNC4yLTYuNiA1LjYtOS4xLTEgMi4z'
    b'LTIuNCA1LjQtMyA3LjUgMS45LjcgNC44IDEgNi45IDEuNCIvPgogICAgPHBhdGggZD0ibTMw'
    b'NCAyMTcuOCA2LjYtNS41LTcuNCAzLjktLjggMS42aDEuNiIvPgogICAgPHBhdGggZD0iTTMx'
    b'MSAyMTcuNmMtMi43LjQtNi45LjgtOS40IDEuNSAxLjMtMi43IDMuMS03IDQuMi05LjctLjYg'
    b'Mi40LTEuNyA1LjYtMiA3LjggMiAuNCA1IC4zIDcuMS40Ii8+CiAgICA8cGF0aCBkPSJtMzAz'
    b'LjIgMjE4LjkgNS03LTYuMyA1LjctLjMgMS43IDEuNi0uNCIvPgogICAgPHBhdGggZD0iTTMw'
    b'OS40IDIxOC40Yy0yLjYuMy02LjguNS05LjQgMSAxLjUtMi42IDMuNS02LjggNC44LTkuNC0u'
    b'OCAyLjMtMiA1LjUtMi40IDcuNyAyIC41IDUgLjUgNyAuNyIvPgogICAgPHBhdGggZD0ibTMw'
    b'Mi4zIDIxOS42IDYuNC01LjUtNy4zIDMuOS0uNyAxLjZoMS42Ii8+CiAgICA8cGF0aCBkPSJN'
    b'MzA4LjcgMjE4LjdjLTIuNy42LTYuOSAxLjMtOS40IDIuMSAxLjItMi43IDIuOC03LjEgMy44'
    b'LTkuOC0uNSAyLjQtMS40IDUuNi0xLjYgNy44IDIgLjMgNSAwIDcuMi0uMSIvPgogICAgPHBh'
    b'dGggZD0ibTMwMS4yIDIyMCA0LTcuNy01LjQgNi42LS4xIDEuNyAxLjUtLjciLz4KICAgIDxw'
    b'YXRoIGQ9Ik0zMDguNyAyMTkuMWMtMyAuOC03LjQgMS44LTEwIDIuOCAxLTMuMSAyLjEtOCAy'
    b'LjktMTEuMS0uMyAyLjctLjkgNi4zLS44IDguOCAyLjMuMiA1LjUtLjMgNy44LS41Ii8+CiAg'
    b'ICA8cGF0aCBkPSJtMzAwLjQgMjIxLjcgNS4yLTcuNi02LjYgNi4xLS4zIDIgMS43LS41Ii8+'
    b'CiAgICA8cGF0aCBkPSJNMzA3LjUgMjIwYy0yLjguOS03LjIgMi4xLTkuOCAzLjMuOC0zLjIg'
    b'MS44LTguMSAyLjQtMTEuMi0uMSAyLjctLjUgNi4zLS4zIDguNyAyLjIuMSA1LjQtLjYgNy43'
    b'LS44Ii8+CiAgICA8cGF0aCBkPSJtMjk5LjQgMjIyLjggMy45LTguNC01LjYgNy4ydjJsMS43'
    b'LS44Ii8+CiAgICA8cGF0aCBkPSJNMzA2LjQgMjIxLjJjLTIuOC42LTcuMyAxLjUtMTAgMi40'
    b'IDEuMS0zIDIuNS04IDMuNC0xMS0uNCAyLjctMS4xIDYuNC0xLjEgOC43IDIuMi4zIDUuNC0u'
    b'MSA3LjctLjIiLz4KICAgIDxwYXRoIGQ9Im0yOTguNCAyMjMuNiA2LjQtNi42LTcuNSA0Ljkt'
    b'LjYgMS44IDEuNy0uMSIvPgogICAgPHBhdGggZD0iTTMwNS4yIDIyMi4zYy0yLjkuNC03LjMu'
    b'OC0xMCAxLjUgMS4zLTMgMy03LjggNC0xMC44LS42IDIuNy0xLjUgNi4zLTEuNyA4LjcgMi4y'
    b'LjUgNS40LjQgNy43LjYiLz4KICAgIDxwYXRoIGQ9Im0yOTcuMiAyMjMgNC4zLTguMy01Ljkg'
    b'N3YxLjlsMS42LS43Ii8+CiAgICA8cGF0aCBkPSJNMzA1LjUgMjIxLjNjLTMgMS4zLTggMy0x'
    b'MC45IDQuNiAxLTMuNyAyLTkuNSAyLjYtMTMuMSAwIDMuMS0uNSA3LjQtLjMgMTAuMSAyLjUg'
    b'MCA2LTEuMSA4LjYtMS42Ii8+CiAgICA8cGF0aCBkPSJtMjk2LjYgMjI1LjQgNS4yLTkuNC02'
    b'LjkgOC0uMiAyLjIgMS45LS44Ii8+CiAgICA8cGF0aCBkPSJNMzA0LjMgMjIyLjVjLTMgMS40'
    b'LTcuOCAzLjQtMTAuNiA1LjEuOC0zLjYgMS41LTkuNSAyLTEzIDAgMy0uMiA3LjMuMSAxMCAy'
    b'LjUtLjMgNi0xLjUgOC41LTIuMSIvPgogICAgPHBhdGggZD0ibTI5NS41IDIyNi44IDMuOC0x'
    b'MC4xLTUuNyA5IC4yIDIuMyAxLjctMS4yIi8+CiAgICA8cGF0aCBkPSJNMzAzIDIyMy4zYy0z'
    b'IDEuNS03LjggMy41LTEwLjYgNS4zLjctMy43IDEuNC05LjUgMS45LTEzLjEgMCAzLS4yIDcu'
    b'My4yIDEwIDIuNS0uMyA2LTEuNiA4LjUtMi4yIi8+CiAgICA8cGF0aCBkPSJtMjk0LjcgMjI4'
    b'IDUuOC04LjktNy40IDcuMy0uMyAyLjIgMS45LS42Ii8+CiAgICA8cGF0aCBkPSJNMzAyLjcg'
    b'MjIyLjhjLTIuNyAyLjItNyA1LjQtOS40IDcuOCAwLTMuOC0uNS05LjUtLjgtMTMgLjYgMi45'
    b'IDEuMyA3IDIuMyA5LjUgMi40LS45IDUuNS0zIDgtNC4yIi8+CiAgICA8cGF0aCBkPSJtMjk1'
    b'IDIyOC41LjYtMTAuNy0yLjggMTAuNC44IDIgMS40LTEuNyIvPgogICAgPHBhdGggZD0iTTMw'
    b'MiAyMjMuOGMtMi44IDIuMi03IDUuMy05LjUgNy43IDAtMy43LS41LTkuNS0uOC0xMyAuNyAz'
    b'IDEuMyA3IDIuMyA5LjUgMi40LS44IDUuNS0zIDgtNC4yIi8+CiAgICA8cGF0aCBkPSJtMjk0'
    b'LjMgMjMwLjMgMi43LTEwLjUtNC43IDkuNi4zIDIuMiAxLjctMS4zIi8+CiAgICA8cGF0aCBk'
    b'PSJNMzAxLjYgMjI0Yy0yLjUgMi42LTYuNiA2LjQtOC45IDktLjQtMy43LTEuNS05LjYtMi4y'
    b'LTEzLjIgMSAzIDIuMSA3LjEgMy40IDkuNSAyLjMtMS4xIDUuNC0zLjYgNy43LTUuMiIvPgog'
    b'ICAgPHBhdGggZD0ibTI5NC4zIDIzMS42LjUtMTEuMS0yLjcgMTAuOC44IDIgMS40LTEuNyIv'
    b'PgogICAgPHBhdGggZD0iTTMwMC44IDIyNmMtMi43IDIuMi03IDUuNS05LjYgOCAwLTMuOC0u'
    b'Ny05LjgtMS0xMy41LjcgMyAxLjUgNy4zIDIuNSA5LjkgMi41LTEgNS43LTMuMSA4LjEtNC41'
    b'Ii8+CiAgICA8cGF0aCBkPSJtMjkzLjUgMjMyLjkgMy44LTEwLjUtNS44IDkuMy4yIDIuMyAx'
    b'LjgtMS4xIi8+CiAgICA8cGF0aCBkPSJNMzAwLjggMjI2Yy0yLjUgMi41LTYuMyA2LjQtOC41'
    b'IDkuMS0uNC0zLjgtMS41LTkuOC0yLjEtMTMuNCAxIDMgMiA3LjIgMy4yIDkuNiAyLjMtMS4y'
    b'IDUuMS0zLjcgNy40LTUuMyIvPgogICAgPHBhdGggZD0ibTI5My42IDIzMy40LS40LTExLTEu'
    b'OCAxMSAxIDEuOSAxLjItMS45Ii8+CiAgICA8cGF0aCBkPSJNMjk5LjYgMjI2LjhjLTIuNCAy'
    b'LjYtNi4xIDYuNS04LjIgOS4zLS41LTQtMS44LTkuOC0yLjUtMTMuNSAxIDMgMi4zIDcuMiAz'
    b'LjUgOS42IDIuMi0xLjIgNS0zLjggNy4yLTUuNCIvPgogICAgPHBhdGggZD0ibTI5MyAyMzQu'
    b'NSAxLjItMTEuMi0zLjMgMTAuNi43IDIuMiAxLjQtMS42Ii8+CiAgICA8cGF0aCBkPSJNMjk5'
    b'IDIyNy4yYy0yIDIuOS01LjUgNy03LjQgMTAtLjgtMy44LTIuNS05LjUtMy41LTEzIDEuMyAy'
    b'LjggMi44IDYuOCA0LjIgOS4xIDIuMS0xLjQgNC43LTQuMiA2LjgtNiIvPgogICAgPHBhdGgg'
    b'ZD0ibTI5MyAyMzUuNi0uOC0xMS4zLTEuNCAxMS4yIDEgMiAxLjEtMiIvPgogICAgPHBhdGgg'
    b'ZD0iTTI5OC45IDIyNy45Yy0yIDMtNS4zIDcuMy03IDEwLjQtMS0zLjgtMy05LjUtNC4yLTEz'
    b'IDEuNCAyLjggMy4xIDYuOCA0LjcgOSAyLTEuNSA0LjUtNC41IDYuNS02LjQiLz4KICAgIDxw'
    b'YXRoIGQ9Im0yOTMuNiAyMzYuNiAxLjItMTEuMy0zLjIgMTAuNi42IDIuMyAxLjQtMS42Ii8+'
    b'CiAgICA8cGF0aCBkPSJNMjk4LjQgMjI5Yy0xLjcgMy4xLTQuNSA4LTYgMTEuMy0xLjMtMy42'
    b'LTMuOC05LTUuMy0xMi40IDEuNyAyLjYgMy43IDYuMyA1LjUgOC40IDEuOS0xLjggNC01LjIg'
    b'NS44LTcuNCIvPgogICAgPHBhdGggZD0ibTI5My4zIDIzNy42LTMuMi0xMC44IDEgMTEuMyAx'
    b'LjUgMS42LjYtMi4xIi8+CiAgICA8cGF0aCBkPSJNMjk4LjQgMjMwLjJjLTEuOCAzLjItNC44'
    b'IDgtNi4zIDExLjMtMS4zLTMuNi0zLjgtOS01LjQtMTIuMyAxLjcgMi42IDMuOCA2LjMgNS42'
    b'IDguMyAyLTEuOCA0LjItNS4xIDYtNy4zIi8+CiAgICA8cGF0aCBkPSJtMjkzLjQgMjM5LjYt'
    b'MS4yLTExLjMtMSAxMS4zIDEuMSAyIDEuMS0yIi8+CiAgICA8cGF0aCBkPSJNMjk4LjYgMjMx'
    b'LjJjLTEuOSAzLjEtNSA3LjktNi41IDExLjEtMS4zLTMuNi0zLjctOS01LjItMTIuNCAxLjcg'
    b'Mi42IDMuNyA2LjQgNS41IDguNCAyLTEuNyA0LjMtNSA2LjItNy4xIi8+CiAgICA8cGF0aCBk'
    b'PSJtMjkzLjMgMjQwLjUtMi4xLTExLS4xIDExLjIgMS4zIDEuOC45LTIiLz4KICAgIDxwYXRo'
    b'IGQ9Ik0yOTcuOCAyMzIuOGMtMiAzLTUuMyA3LjUtNyAxMC43LTEuMS0zLjctMy4zLTkuNC00'
    b'LjYtMTIuOCAxLjUgMi43IDMuNCA2LjYgNSA4LjggMi4xLTEuNiA0LjYtNC43IDYuNi02Ljci'
    b'Lz4KICAgIDxwYXRoIGQ9Im0yOTIuMyAyNDEuNyAxLTExLjMtMy4xIDEwLjcuNyAyLjIgMS40'
    b'LTEuNiIvPgogICAgPHBhdGggZD0iTTI5Ny45IDIzM2MtMS43IDMuMy00LjYgOC4zLTYgMTEu'
    b'Ni0xLjQtMy41LTQtOC44LTUuNy0xMiAxLjggMi40IDQgNiA1LjggOCAyLTEuOSA0LTUuMyA1'
    b'LjktNy41Ii8+CiAgICA8cGF0aCBkPSJtMjkyIDI0Mi43LTMuNS0xMC42IDEuMyAxMS4yIDEu'
    b'NSAxLjYuNi0yLjIiLz4KICAgIDxwYXRoIGQ9Ik0yOTcuNCAyMzMuOWMtMS4yIDMuNi0zLjIg'
    b'OS00IDEyLjctMi0zLjItNS41LTcuOC03LjYtMTAuNyAyLjEgMi4xIDQuOSA1LjIgNyA2Ljcg'
    b'MS42LTIuMyAzLjItNiA0LjYtOC43Ii8+CiAgICA8cGF0aCBkPSJtMjk1IDI0My41LTMuNy0x'
    b'MC40IDEuNiAxMS4yIDEuNSAxLjQuNi0yLjIiLz4KICAgIDxwYXRoIGQ9Ik0yOTcuNCAyMzVj'
    b'LTEuMiAzLjYtMy4yIDkuMS00IDEyLjctMi0zLjItNS40LTcuNy03LjYtMTAuNSAyLjEgMiA0'
    b'LjkgNSA3IDYuNiAxLjYtMi4zIDMuMi02LjEgNC42LTguOCIvPgogICAgPHBhdGggZD0ibTI5'
    b'NSAyNDUuMy00LjgtOS43IDIuOCAxMC44IDEuNyAxLjIuNC0yLjMiLz4KICAgIDxwYXRoIGQ9'
    b'Ik0yOTcgMjM1LjljLS43IDMuNy0yIDkuNS0yLjUgMTMuMi0yLjMtMi45LTYuMy03LTguNy05'
    b'LjQgMi4zIDEuNyA1LjQgNC40IDcuNyA1LjUgMS4zLTIuNSAyLjQtNi41IDMuNS05LjMiLz4K'
    b'ICAgIDxwYXRoIGQ9Im0yOTUuNCAyNDYuOC0yLjYtMTAuOS40IDExLjMgMS40IDEuNy44LTIi'
    b'Lz4KICAgIDxwYXRoIGQ9Ik0yOTcgMjM3Yy0uNCAzLjktMS4yIDkuOC0xLjIgMTMuNS0yLjYt'
    b'Mi41LTYuOS02LTkuNS04LjEgMi40IDEuNCA1LjcgMy42IDguMSA0LjQgMS0yLjYgMS44LTYu'
    b'OCAyLjYtOS43Ii8+CiAgICA8cGF0aCBkPSJtMjk1LjUgMjQ3LjYtNi45LTcuOCA1LjIgOS41'
    b'IDIgLjYtLjMtMi4zIi8+CiAgICA8cGF0aCBkPSJNMjk3LjIgMjM4LjRjLS40IDMuOC0xLjIg'
    b'OS43LTEuMyAxMy40LTIuNi0yLjUtNi45LTYtOS41LTguMiAyLjUgMS40IDUuOCAzLjcgOC4x'
    b'IDQuNSAxLjEtMi42IDEuOC02LjggMi43LTkuNyIvPgogICAgPHBhdGggZD0iTTI5Ni4zIDI0'
    b'OS40IDI5MSAyNDBsMy4zIDEwLjcgMS43IDEuMS4zLTIuMyIvPgogICAgPHBhdGggZD0iTTI5'
    b'Ny41IDI0MGMtLjMgMy44LS44IDkuNy0uOCAxMy41YTExNyAxMTcgMCAwIDAtOS44LTcuNmMy'
    b'LjYgMS4yIDYgMy4zIDguMyA0IDEtMi43IDEuNi03IDIuMy0xMCIvPgogICAgPHBhdGggZD0i'
    b'bTI5NyAyNTEuMi02LjYtOC4zIDQuOCA5LjggMS44Ljh2LTIuMyIvPgogICAgPHBhdGggZD0i'
    b'TTI5Ny42IDI0MS44Yy0uMyAzLjgtLjggOS43LS43IDEzLjUtMi43LTIuNC03LjEtNS42LTku'
    b'OS03LjYgMi42IDEuMyA2IDMuMyA4LjQgNCAxLTIuNyAxLjUtNyAyLjItMTAiLz4KICAgIDxw'
    b'YXRoIGQ9Im0yOTcuNSAyNTIuNi00LjUtMTAgMi41IDExIDEuNiAxLjMuNC0yLjMiLz4KICAg'
    b'IDxwYXRoIGQ9Ik0yOTcuNyAyNDIuOWMuMiAzLjkuMiA5LjguNiAxMy42YTEzNCAxMzQgMCAw'
    b'IDAtMTAuNC02LjJjMi42LjkgNi4xIDIuNCA4LjYgMi44LjctMi45LjgtNy4xIDEuMi0xMC4y'
    b'Ii8+CiAgICA8cGF0aCBkPSJtMjk4LjMgMjUyLjItOC4zLTUuNyA3IDcuOCAyIC4xLS43LTIu'
    b'MiIvPgogICAgPHBhdGggZD0iTTI5OCAyNDMuM2MuMyAzLjkuNyA5LjggMS4zIDEzLjUtMy0x'
    b'LjktNy44LTQuMy0xMC44LTUuOCAyLjcuOCA2LjMgMi4yIDguOCAyLjUuNS0yLjkuNC03LjEu'
    b'Ny0xMC4yIi8+CiAgICA8cGF0aCBkPSJtMjk5LjMgMjU0LjMtNy04IDUuMyA5LjYgMS45Ljct'
    b'LjMtMi4zIi8+CiAgICA8cGF0aCBkPSJNMjk4LjYgMjQ0LjhjLjUgMy44IDEgOS43IDEuOSAx'
    b'My40LTMtMS43LTgtMy44LTExLTUuMSAyLjcuNiA2LjQgMS44IDguOCAyIC40LTMgLjItNy4y'
    b'LjMtMTAuMyIvPgogICAgPHBhdGggZD0ibTMwMC42IDI1NS43LTguMy01LjkgNyA4IDIgLjEt'
    b'LjctMi4yIi8+CiAgICA8cGF0aCBkPSJNMjk4LjkgMjQ2LjRjLjcgMy44IDEuNyA5LjcgMi43'
    b'IDEzLjMtMy4xLTEuNS04LjItMy4xLTExLjMtNC4xIDIuOC4zIDYuNSAxLjIgOSAxIC4yLTIu'
    b'OS0uMy03LS40LTEwLjIiLz4KICAgIDxwYXRoIGQ9Im0zMDEuNiAyNTYuOS03LTguMiA1LjIg'
    b'OS43IDIgLjgtLjItMi4zIi8+CiAgICA8cGF0aCBkPSJNMjk5LjMgMjQ3LjRjMS4xIDMuNyAy'
    b'LjYgOS41IDQgMTMtMy4zLTEtOC40LTItMTEuNi0yLjYgMi44IDAgNi41LjMgOS0uMSAwLTMt'
    b'MS03LjEtMS40LTEwLjIiLz4KICAgIDxwYXRoIGQ9Im0zMDIgMjU2LjktOS43LTIgOS4xIDQu'
    b'NSAxLjktLjctMS40LTEuOCIvPgogICAgPHBhdGggZD0iTTMwMCAyNDguNmMxIDMuNyAyLjUg'
    b'OS40IDMuOCAxMi45LTMuMi0xLTguMy0yLTExLjUtMi42IDIuOCAwIDYuNS4zIDkgMCAwLTMt'
    b'MS03LjItMS4zLTEwLjMiLz4KICAgIDxwYXRoIGQ9Im0zMDMuNSAyNTcuOS05LjItNC41IDgu'
    b'MiA2LjcgMi0uMi0xLTIiLz4KICAgIDxwYXRoIGQ9Ik0yOTkuNSAyNDkuMmMxLjggMy40IDQu'
    b'NSA4LjcgNi41IDExLjctMy40LS4yLTguNiAwLTExLjggMCAyLjctLjUgNi40LTEgOC43LTIt'
    b'LjctMi45LTIuNC02LjctMy40LTkuNyIvPgogICAgPHBhdGggZD0ibTMwNSAyNTguOS05LjYt'
    b'Mi42IDkgNSAxLjgtLjUtMS4zLTIiLz4KICAgIDxwYXRoIGQ9Ik0zMDAuNCAyNTAuN2MxLjkg'
    b'My4zIDQuNiA4LjYgNi43IDExLjYtMy40LS4yLTguNiAwLTExLjguMiAyLjYtLjcgNi40LTEu'
    b'MiA4LjYtMi4yLS42LTIuOS0yLjQtNi43LTMuNC05LjYiLz4KICAgIDxwYXRoIGQ9Im0zMDYu'
    b'MSAyNTkuNy04LjktNS4zIDcuOCA3LjRoMmwtLjktMi4xIi8+CiAgICA8cGF0aCBkPSJNMzAx'
    b'LjIgMjUxLjVjMi4xIDMuMSA1LjMgOCA3LjYgMTAuOWE5MCA5MCAwIDAgMC0xMS42IDEuN2My'
    b'LjYtMSA2LjItMiA4LjQtMy4zLTEtMi44LTMuMS02LjUtNC40LTkuMyIvPgogICAgPHBhdGgg'
    b'ZD0ibTMwNi44IDI2MC41LTkuNi0uMyA5LjUgMi45IDEuNy0xLjEtMS42LTEuNW01LjYtNDYu'
    b'NiA2LjktMS4xLTYuOS4xLTEuMi42IDEuMi40Ii8+CiAgICA8cGF0aCBkPSJNMzE2LjIgMjE1'
    b'LjRjLTItLjYtNS0xLjYtNy4xLTJsNy40LTMuNWMtMS41IDEtMy44IDIuMi01IDMuMiAxLjIu'
    b'OCAzLjMgMS42IDQuNyAyLjMiLz4KICAgIDxwYXRoIGQ9Im0zMTIgMjE0LjEgNi44LTEuOC03'
    b'IC45LTEgLjcgMS4zLjIiLz4KICAgIDxwYXRoIGQ9Ik0zMTYuNSAyMTUuOWMtMi40LS4zLTYt'
    b'LjctOC4zLS43IDEuOC0xLjYgNC4yLTQuMSA1LjctNS43LTEgMS41LTIuNiAzLjQtMy4zIDQu'
    b'OCAxLjYuNyA0LjEgMS4xIDUuOSAxLjYiLz4KICAgIDxwYXRoIGQ9Im0zMDkuNiAyMTQuNiA3'
    b'LS44LTYuOC0uMi0xLjMuNiAxIC40Ii8+CiAgICA8cGF0aCBkPSJtMzE0LjcgMjE2LjEtNy41'
    b'LTEuMyA2LjktMy44Yy0xLjQgMS0zLjQgMi40LTQuNCAzLjQgMS4zLjYgMy41IDEuMiA1IDEu'
    b'NyIvPgogICAgPHBhdGggZD0ibTMwOSAyMTQuNiA2LjEtMi43LTYuNyAxLjgtLjguOGgxLjQi'
    b'Lz4KICAgIDxwYXRoIGQ9Ik0zMTQuNSAyMTYuOWMtMS43LS43LTQuNS0yLTYuMi0yLjVsNC40'
    b'LTQuOGMtLjggMS4zLTIgMy0yLjYgNC40IDEuMiAxIDMgMiA0LjQgMi45Ii8+CiAgICA8cGF0'
    b'aCBkPSJtMzA5LjMgMjE1IDQuOC0yLTUuMi42LS42IDEgMSAuNG0tNCA0NC42aC05LjhsMTAg'
    b'Mi41IDEuNi0xLTEuOC0xLjUiLz4KICAgIDxwYXRoIGQ9Im0zMDcuMSAyNjAuMi0xMC0yLjMg'
    b'OS42IDQuNyAyLS42LTEuNi0xLjgiLz4KICAgIDxwYXRoIGQ9Im0zMDguOCAyNjAuOS0xMC0u'
    b'NSAxMCAzIDEuNy0xLTEuNy0xLjUiLz4KICAgIDxwYXRoIGQ9Ik0zMDIuNSAyNTMuOWMyLjUg'
    b'Mi44IDYuNCA3LjQgOS4xIDkuOS0zLjMuNS04LjMgMS44LTExLjQgMi43IDIuNC0xLjIgNi0y'
    b'LjYgOC00LTEuNC0yLjYtNC02LTUuNy04LjYiLz4KICAgIDxwYXRoIGQ9Im0zMTAuMSAyNjEu'
    b'NC0xMC0zLjMgOS40IDUuNiAyLS40LTEuNC0yIi8+CiAgICA8cGF0aCBkPSJNMzAzLjQgMjU0'
    b'LjVjMi44IDIuNiA3IDYuNyAxMCA5LTMuMi45LTggMi44LTExIDQgMi4zLTEuNCA1LjYtMy4y'
    b'IDcuNC01LTEuNi0yLjQtNC41LTUuNS02LjQtOCIvPgogICAgPHBhdGggZD0ibTMxMSAyNjIt'
    b'OS41IDEuOSAxMCAuNiAxLjQtMS4zLTItMS4yIi8+CiAgICA8cGF0aCBkPSJtMzA5IDI2MS40'
    b'LTkuOC44IDEwLjEgMS43IDEuNi0xLjItMi0xLjMiLz4KICAgIDxwYXRoIGQ9Im0zMTAuOCAy'
    b'NjItMTAuMi0xLjcgMTAgNCAxLjgtLjctMS42LTEuN3oiLz4KICAgIDxwYXRoIGQ9Im0zMTIu'
    b'NSAyNjIuNS0xMCAuMiAxMC4yIDIuMyAxLjYtMS4xLTEuOC0xLjR6Ii8+CiAgICA8cGF0aCBk'
    b'PSJNMzA1LjcgMjU2YzIuOCAyLjYgNyA2LjggOS45IDkuMi0zLjMuNy04LjMgMi40LTExLjMg'
    b'My40IDIuNC0xLjMgNS44LTIuOSA3LjctNC41LTEuNi0yLjUtNC40LTUuNy02LjMtOC4yeiIv'
    b'PgogICAgPHBhdGggZD0ibTMxMy45IDI2Mi45LTEwLjItMi42IDkuOCA1IDEuOS0uNi0xLjUt'
    b'MS44eiIvPgogICAgPHBhdGggZD0iTTMwNi42IDI1Ni41YzMgMi40IDcuNiA2LjIgMTAuNyA4'
    b'LjItMy4yIDEuMS03LjggMy41LTEwLjYgNC45IDIuMi0xLjcgNS4zLTMuNyA3LTUuNS0xLjgt'
    b'Mi40LTUtNS4zLTctNy42eiIvPgogICAgPHBhdGggZD0ibTMxNC44IDI2My40LTkuMyAyLjZo'
    b'MTBsMS4zLTEuNS0yLTF6Ii8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiNmZWRmMDAiIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNCIgZD0ibTMyNy42IDI0OS41LTcuNi01LjMtNy42'
    b'IDUuMyAyLjktOC40LTYuNy01LjJoOC42bDIuOC04LjQgMi44IDguNGg4LjZsLTYuNyA1LjIg'
    b'Mi45IDguNHoiLz4KPC9zdmc+Cg==', 'PY')

PY = b64_PY
index.append("PY")
index.append("PRY")
index.append("Paraguay")
catalog["PY"] = PY
catalog["PRY"] = PY
catalog["Paraguay"] = PY
country["Paraguay"] = ('PY', 'PRY', 0)
lookup["PY"] = ('PY', 'PRY', 'Paraguay', 0)
lookup["Asuncion Paraguay"] = ('PY', 'PRY', 'Paraguay', 0)
lookup["PRY"] = ('PY', 'PRY', 'Paraguay', 0)
lookup["Paraguay"] = ('PY', 'PRY', 'Paraguay', 0)
details["PY"] = {"continent":"Americas","capital":"Asuncion","currency":"Guarani","web":".py","lang":"es-PY | gn","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_QA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXFhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzhkMWIzZCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMHY0ODBoMTU4'
    b'LjRsOTcuOC0yNi43LTk3LjgtMjYuNiA5Ny43LTI2LjctOTcuNy0yNi43IDk3LjctMjYuNi05'
    b'Ny43LTI2LjcgOTcuOC0yNi43LTk3LjgtMjYuNiA5Ny43LTI2LjctOTcuNy0yNi43IDk3Ljct'
    b'MjYuNi05Ny43LTI2LjcgOTcuOC0yNi43LTk3LjgtMjYuNkwyNTYuMSA4MGwtOTcuNy0yNi43'
    b'IDk3LjgtMjYuNkwxNTguMyAwSDB6Ii8+Cjwvc3ZnPgo=', 'QA')

QA = b64_QA
index.append("QA")
index.append("QAT")
index.append("Qatar")
catalog["QA"] = QA
catalog["QAT"] = QA
catalog["Qatar"] = QA
country["Qatar"] = ('QA', 'QAT', 0)
lookup["QA"] = ('QA', 'QAT', 'Qatar', 0)
lookup["Doha Qatar"] = ('QA', 'QAT', 'Qatar', 0)
lookup["QAT"] = ('QA', 'QAT', 'Qatar', 0)
lookup["Qatar"] = ('QA', 'QAT', 'Qatar', 0)
details["QA"] = {"continent":"Asia","capital":"Doha","currency":"Qatari Rial","web":".qa","lang":"ar-QA | es","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_RE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXJlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'RE')

RE = b64_RE
index.append("RE")
index.append("REU")
index.append("Réunion")
catalog["RE"] = RE
catalog["REU"] = RE
catalog["Réunion"] = RE
country["Réunion"] = ('RE', 'REU', 0)
lookup["RE"] = ('RE', 'REU', 'Réunion', 0)
lookup["Saint-Denis Réunion"] = ('RE', 'REU', 'Réunion', 0)
lookup["REU"] = ('RE', 'REU', 'Réunion', 0)
lookup["Réunion"] = ('RE', 'REU', 'Réunion', 0)
details["RE"] = {"continent":"Africa","capital":"Saint-Denis","currency":"Euro","web":".re","lang":"fr-RE","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_RO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXJvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjMDAzMTljIiBkPSJNMCAwaDIx'
    b'My4zdjQ4MEgweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZGUwMCIgZD0iTTIxMy4zIDBoMjEz'
    b'LjR2NDgwSDIxMy4zeiIvPgogICAgPHBhdGggZmlsbD0iI2RlMjExMCIgZD0iTTQyNi43IDBI'
    b'NjQwdjQ4MEg0MjYuN3oiLz4KICA8L2c+Cjwvc3ZnPgo=', 'RO')

RO = b64_RO
index.append("RO")
index.append("ROU")
index.append("Romania")
catalog["RO"] = RO
catalog["ROU"] = RO
catalog["Romania"] = RO
country["Romania"] = ('RO', 'ROU', 0)
lookup["RO"] = ('RO', 'ROU', 'Romania', 0)
lookup["Bucharest Romania"] = ('RO', 'ROU', 'Romania', 0)
lookup["ROU"] = ('RO', 'ROU', 'Romania', 0)
lookup["Romania"] = ('RO', 'ROU', 'Romania', 0)
details["RO"] = {"continent":"Europe","capital":"Bucharest","currency":"Romanian Leu","web":".ro","lang":"ro | hu | rom","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_RS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI5MDAiIGhl'
    b'aWdodD0iNjAwIj48cGF0aCBmaWxsPSIjYzYzNjNjIiBkPSJNMCAwSDkwMFY2MDBIMHoiLz48'
    b'cGF0aCBmaWxsPSIjMGM0MDc2IiBkPSJNMCAyMDBIOTAwVjYwMEgweiIvPjxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Ik0wIDQwMEg5MDBWNjAwSDB6Ii8+PC9zdmc+', 'RS')

RS = b64_RS
index.append("RS")
index.append("SRB")
index.append("Serbia")
catalog["RS"] = RS
catalog["SRB"] = RS
catalog["Serbia"] = RS
country["Serbia"] = ('RS', 'SRB', 0)
lookup["RS"] = ('RS', 'SRB', 'Serbia', 0)
lookup["Belgrade Serbia"] = ('RS', 'SRB', 'Serbia', 0)
lookup["SRB"] = ('RS', 'SRB', 'Serbia', 0)
lookup["Serbia"] = ('RS', 'SRB', 'Serbia', 0)
details["RS"] = {"continent":"Europe","capital":"Belgrade","currency":"Serbian Dinar","web":".rs","lang":"sr | hu | bs | rom","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_RU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXJ1IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0'
    b'ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDM5YTYiIGQ9Ik0wIDE2MGg2NDB2MzIwSDB6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDUyYjFlIiBkPSJNMCAzMjBoNjQwdjE2MEgweiIvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'RU')

RU = b64_RU
index.append("RU")
index.append("RUS")
index.append("Russia")
catalog["RU"] = RU
catalog["RUS"] = RU
catalog["Russia"] = RU
country["Russia"] = ('RU', 'RUS', 0)
lookup["RU"] = ('RU', 'RUS', 'Russia', 0)
lookup["Moscow Russia"] = ('RU', 'RUS', 'Russia', 0)
lookup["RUS"] = ('RU', 'RUS', 'Russia', 0)
lookup["Russia"] = ('RU', 'RUS', 'Russia', 0)
details["RU"] = {"continent":"Europe | Asia","capital":"Moscow","currency":"Russian Ruble","web":".ru","lang":"ru | tt | xal | cau | ady | kv | ce | tyv | cv | udm | tut | mns | bua | myv | mdf | chm | ba | inh | tut | kbd | krc | av | sah | nog","tz":"+02:00 | +12:00","altname":""}
#----------------------------------------------------------------------
b64_RU_AD = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iMTAwMCIgaGVpZ2h0PSI1MDAiIHZpZXdCb3g9Ii0xOTY2IDAgMzkzMiAx'
    b'OTY2IiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4KPHJlY3QgeD0iLTE5NjYiIHdpZHRoPSIz'
    b'OTMyIiBoZWlnaHQ9IjE5NjYiIGZpbGw9IiMyOTY5MTIiLz4KPGcgZmlsbD0iI0ZERkMwMiI+'
    b'CjxwYXRoIGlkPSJzdGFyIiBkPSJNMCA0ODhsMjIuOTYgNzAuNjdoNzQuM0wzNy4xNSA2MDIu'
    b'MzQgNjAuMTEgNjczIDAgNjI5LjMzLTYwLjExIDY3M2wyMi45Ni03MC42Ni02MC4xMS00My42'
    b'N2g3NC4zWiIvPgo8cGF0aCBpZD0iYXJyb3ciIGQ9Ik0wIDc4MSAzMiA5NjMgMTEgOTgzdjY4'
    b'N2wyMiAyM3YxNzFMMCAxODMxbC0zMyAzM1YxNjkzbDIyLTIzVjk4M2wtMjEtMjBaIi8+Cjx1'
    b'c2UgeGxpbms6aHJlZj0iI3N0YXIiIHk9Ii0zOTIiLz4KPGcgaWQ9ImhhbGYiPgo8dXNlIHhs'
    b'aW5rOmhyZWY9IiNzdGFyIiB4PSI0ODYiLz4KPHVzZSB4bGluazpocmVmPSIjc3RhciIgeD0i'
    b'NDg2IiB5PSItMzE0Ii8+Cjx1c2UgeGxpbms6aHJlZj0iI3N0YXIiIHg9IjkyMyIgeT0iLTkz'
    b'Ii8+Cjx1c2UgeGxpbms6aHJlZj0iI3N0YXIiIHg9IjEyNzEiIHk9IjI1NSIvPgo8dXNlIHhs'
    b'aW5rOmhyZWY9IiNzdGFyIiB4PSIxNDk0IiB5PSI2OTMiLz4KPHVzZSB4bGluazpocmVmPSIj'
    b'YXJyb3ciIHRyYW5zZm9ybT0icm90YXRlKDQwLDAsMTMyNikiLz4KPC9nPgo8dXNlIHhsaW5r'
    b'OmhyZWY9IiNoYWxmIiB0cmFuc2Zvcm09InNjYWxlKC0xLDEpIi8+CjwvZz4KPC9zdmc+', 'RU_AD')

RU_AD = b64_RU_AD
index.append("RU_AD")
index.append("Russia Adygeya Respublika")
catalog["RU_AD"] = RU_AD
catalog["Russia Adygeya Respublika"] = RU_AD
country["Russia Adygeya Respublika"] = ('RU_AD', '', 1)
lookup["RU_AD"] = ('RU_AD', '', 'Russia Adygeya Respublika', 1)
lookup["Adegea"] = ('RU_AD', '', 'Russia Adygeya Respublika', 1)
lookup["Russia Adygeya Respublika"] = ('RU_AD', '', 'Russia Adygeya Respublika', 1)
details["RU_AD"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Adegea"}
regional["RU_AD"] = ('RU_AD', 'Russia Adygeya Respublika', 1)
regional["Russia Adygeya Respublika"] = ('RU_AD', 'Russia Adygeya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_AL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMjAwIiBoZWlnaHQ9IjYwMCIgdmll'
    b'd0JveD0iMCAwIDIwMCAxMDAiPgo8cmVjdCBmaWxsPSJ3aGl0ZSIgd2lkdGg9IjIwMCIgaGVp'
    b'Z2h0PSIxMDAiLz4KPHJlY3QgZmlsbD0iIzMzOTlGRiIgeT0iNjciIHdpZHRoPSIyMDAiIGhl'
    b'aWdodD0iNCIvPgo8cmVjdCBmaWxsPSIjMzM5OUZGIiB5PSI3NSIgd2lkdGg9IjIwMCIgaGVp'
    b'Z2h0PSIyNSIvPgo8L3N2Zz4=', 'RU_AL')

RU_AL = b64_RU_AL
index.append("RU_AL")
index.append("Russia Altay Respublika")
catalog["RU_AL"] = RU_AL
catalog["Russia Altay Respublika"] = RU_AL
country["Russia Altay Respublika"] = ('RU_AL', '', 1)
lookup["RU_AL"] = ('RU_AL', '', 'Russia Altay Respublika', 1)
lookup["Altai Republic"] = ('RU_AL', '', 'Russia Altay Respublika', 1)
lookup["Russia Altay Respublika"] = ('RU_AL', '', 'Russia Altay Respublika', 1)
details["RU_AL"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+06:00","altname":"Altai Republic"}
regional["RU_AL"] = ('RU_AL', 'Russia Altay Respublika', 1)
regional["Russia Altay Respublika"] = ('RU_AL', 'Russia Altay Respublika', 1)
#----------------------------------------------------------------------
b64_RU_ALT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc1MjciIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iNjAiIHZpZXdCb3g9IjAgMCAxMjAgNjAiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'QWx0YWlfS3JhaS5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2Fw'
    b'ZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2Rp'
    b'cG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4bGluaz0i'
    b'aHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8'
    b'ZGVmcyBpZD0iZGVmczUzMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJuYW1lZHZp'
    b'ZXc1MjkiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2NjYiIGJvcmRl'
    b'cm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2NhcGU6cGFnZW9w'
    b'YWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZyBpbmtz'
    b'Y2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiIGlkPSJnNTMz'
    b'Ij4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjYwIiBwcmVzZXJ2ZUFzcGVjdFJh'
    b'dGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0eSIgeGxp'
    b'bms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdB'
    b'QUFIZ0FBQUE4Q0FJQUFBQWl6K24vQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4K'
    b'QUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJt'
    b'SkxSMFFBL3dEL0FQK2d2YWVUQUFBUApTVWxFUVZSNDJ1MmJlWFJiMVozSGYvZHRrcDZlZHNu'
    b'eXJuaUpMVy94RXN2WVNSbzdEa2xLS0ZzQ0RKVE9jQ0F6WVZpbUNkUENERzJnCkdRNlVOa05i'
    b'OWlXVWNNb01wVE1RWUFJaFpEQ0pBM2JpeEZ1Y2VJOGp2TXVMOXZWSmI1cy9uQVluQkE3dEdT'
    b'UnlqcjcvU2ZycG5QcysKK3VsM3YvZDM3MFd3VTRLL1Z1ODhXNWp0R29ha3ZvR3dKSUlrNkNU'
    b'b3BKS2drNkNUb0pOS2drNkNUaW9KT2drNkNUcXBlSWo0cWcvawpPSXNraVpOSUVuRVJVZkZk'
    b'Zm9hZ2duS2thWjNXVkpnTHF0bVlpR0VzanJGcEdxTjlQblBjcFFwSHY2T2d0YVEzd0tsU1pI'
    b'TmhuZzRMCnRGSG1uR2ROR0JKRGd2SzdNR0tXeE9XY0FBQUJXaGJRMFBZc0E3WThvOUNXcG1C'
    b'NUtSaU52dENtWUxuQTdiYlVMTFZPVnpwNGNqN1MKT3BvMTd0UjV3cG9RdS9qckNTNGRKdG04'
    b'SEdkeDdJS2hrRGhIWWJGVStVekNLVXNJMlplbUNSZzJ2RFQxUUVQRjl1dDN5bSswbGRTbQo0'
    b'eGdvWlBoZ3kyVHFyTTgwNzUvdG1NWXd4SE5DVWFVcDQrYlNiZGMvOGM3YTJ0TmxtVHlHVGVT'
    b'a1JFazg4Umt0eDFsT0pDOFpTbUd4CmhJT2UzbURWajNsNzFoVnJOaXpWaFZUMmFKV0thdlg0'
    b'K1BsNWxpU3g5QkpUcnlNTGt5UmplYXJUSFoyWURCa01jcDJHY2lvdHNxb1MKM1FaajI2SFIw'
    b'azhHWm02dHRyeCtQR0VaWGE3dEFZQWd4M3hWcUo5VEE4QVNlaFFISVNHVXczSlNlVVBwczli'
    b'cnB1dFhhZFJVTUN3QwpRRS9QM054Y3hKTE5MTTNYaEhsSjd3bWx6SGk5Z1ZoK3JxWmdxU1lj'
    b'NFQ5dGRSQmkxQmtBallZU3E0dis1WnFmMEZWcEhyTW1NYUFSClNLMXJWejVXdGlNczBFR2U0'
    b'YVVMTXAwVjVHR0I5bkdhTGJtdnRxKzNrVGlYRU5CVFcxY0VXT0dRZFhPMzMyZ2Y5Y3VrcUZ3'
    b'SVpLVXEKaXF5NlVJanZPV0EzN2oxWk1ES3paTktkdS85MDkxc0RMbmMwSjF1Vm42ZldpbjR0'
    b'SGpuZDZ6b1QwSFJhMXAzeG9QQUREWWtwSFFoSgpCT0ovV3Zqa1Zha0h0bmJzN3ZRc0QvUDB3'
    b'a2NoUVJrVHFUem03TzdxclN1TnJRQ1FrSXdPeThuOGVzdjRWTWdRbnV5VWxtd3BHaXFnCnFR'
    b'YzducDJmY25VZi9kd3k0TEM1QXFRZ0xnU25UWHRUMyt1YVBqeDBxakRObDZtN1hmK0hXcHVK'
    b'a1J2MkhFOVhNUDRVdldTMmFGd1oKV3NPVU4rNmdwWE1iV2lXYXZpT045YjhkK3VmSCszOU9Z'
    b'aHd2RVo2WTdzZExuOWxadXBQR3crZC9sVGhUanBERTNxclYrVDErVEdDcgp4Vk5OZlBrRCt5'
    b'a09rMGtSSThIck1SQlJVZVhpZUV0bXFrYkZESjBkVzJsYlp0QnJlUkFmL3VSa2pQWFBhNkdj'
    b'NkhFNm94NmY2M2hGCjQ1YTVmUXFPVDVpOUl4RC9vSFhYTmVudjMzNzhEd0ZlOVZyTkhiV0d0'
    b'a1RhWkRrNVdKUzVwKzdlV25mYjNZWDJHM1NUSTkxb0pHOHoKcnpKZEZKbkp6V3hmcnNFUjNI'
    b'bDFQU09uQnVmRHVYcTVLTUVMeHgyOS9tTGtuMXMyc1cvakVxRXdSL3Y3RS9RN3kyNHA4STNV'
    b'ZFE2cQpJckg0MVdnQUVLVUxyRjZSZXVDT25OZnV6bjh4c1pTakJONVhreWVWbVF0REo2VVlO'
    b'K3FuVkJpM2NlQi9MaGxjd0kwdlV3dEgvL2hjCjJUODlNeHVNbVJucTNYN1gzajduNDBjbUJG'
    b'RUNnQlZuam1TQ2E5WW5PZ1h0VW0rbklrTnhhbjFKbUNMaWw5RUM0QnMvKy9CVjI1WU0KeGRR'
    b'WDZBRzdpTDZQMTJ6dmVpcklNL0diQUMxRzNUWFdVSmhiTmZBeHNsZy9HRTlmTmRWc21YQmQw'
    b'bVNuVWZ5SjQ4ZXpzaTFIMmxzcwp2Nm9DVXNZSkYxUzUzUEg1bWVQcTk3TTIxT2xtSzJZNnVI'
    b'UzF0VUE3UE9HcDZCcU5VMFlyc0VpZDRWaGQwN0gzcHE3L1l1Q0F4RVVwCi81bnplN2IvYmFl'
    b'SnNKcjB4dzMwVEpvbUtKRGhDTCtzek5oZ0NiS0VjZ0pMb1NUeHk1RlYvTm1IYjcrMnFMajR3'
    b'WWQrMXBpT00rMXYKWGtRWkFHU2M0QVdaVTJtcE12bXF5L1dTSkUyNnhHQytTWXBiNlNBdy9o'
    b'Y2wvN1ovOWRXN0JoNzhoNDVYZkx4bXdWMHNHQXhXa0Q5MAo2b210SGJ0Zld2NlB6MWZkUzJK'
    b'eHNuY2Nqam0wdXZ2ZGZ6dkRLakxUbFl5U3FLR0dWMVFoakJlUWNFRUhBL0hSNytFVGhWWXJB'
    b'SmpOCnFkVzJHcU9qZzNKZklrOXp5N1EzVUsxcEtZb1VvendpNEQvMy9mQzBZQXpUVkx4OE5K'
    b'SUFvRXh6K3NqYWVnczlWbjJ3WTcvamFoTGoKS0N4MnlyZXMvdENSaUtCb3Y5TFdhRDRFQUJp'
    b'SThRSHRWeW5zcXJ3UXBSc0phRWdDNDNpcEpqM0N6Z1FVTFAvaU10OTFqcmNvLy9SQwpaRU9r'
    b'YTYydDdOYWJObk1jdCsyK2Uwd3BLUTAxRmJxMjEvNzhkSEJQVGRwek4xWVFnc2phWGF0eVlr'
    b'NDNDd0FCVEJNZ3RlTTZxNGRSCnhLbEdmOUhXUU55TzRzZHV5SGozcm82WHd3S3R3Q1BQbmJu'
    b'ditlWDNOcVEweDM4bURNbXBOWG1COW5CL2pwb1ZSY3p0WVJtRzhJNTcKY1ZFVVJmSEcxWlZs'
    b'OXNGbjVvSitRd0dPWVNSSkhqdmF1bTc5aHRhV3o0cExTcFhLY3kwd3RRemYwWkNWbzVNTE1k'
    b'WVBvSm53QU9RRwpRM3lLRVpuVlFycC81TnFzY2IrV2hqbGZQREpha3REaWQwczBmWWNiMTVT'
    b'bysxSmtjKzNyYlFtaERBQzhrbVRrMG9iNS84N1RSVEFjCk9WdzhoakREOEN3QTJHcXVLTFFX'
    b'YVduWk15dVZWT0RTM1M2U0pGWXYwVHg5ZGU2eVZLVmFSakFVQVFDbWtYbUtRUFpwRG1Fb1hT'
    b'TnQKZEwrdGszTkE0aUpDOFFETlNlUkVPT3VpMUM3WDlkUVlUcHhmcHl6SUhkTkhSVmw4UU1j'
    b'azVQTEdiRlphcGNBUVFuTWhVdkN4eGxrLwpBQXlOVHM0RW9xa2wxYjZBLzQ5cmFSQXZzZTRv'
    b'ekYyeW95R0xvZkNXTWYrZXJwbUhQK3dIQUYwZ0hCNzM4NFJDRkNTMUVxOHJWcmpjCjBaZ2dj'
    b'amdXajlJUkV5bGJVL3Z2S3U2L05mdk54Yzc2SW52WFBOZXdwZjNWQUtlS0QyaWhNYi9abmJI'
    b'UkZEUVpDUzRtYnQxa2FuMisKMDhER0FHRS9PaUx3S2d4QUJsQUVreUpHbGpVZmpNQ056OS9W'
    b'QzFDLzg3NUJBR1NXWmNtdWU2TS93cDJiVVlpZ0R3QklYdlFkdG0vLwo3YnErZmhlR0lUa3Rh'
    b'N0tuYmJ3eUtodWNqZ2RvSGVYWnUyTHoxdmJkSDgrc2U2cHkrM2tESjhHNVAxUlVsRDNTKytp'
    b'ZnhtNTVxbXI3ClQ3cC9NODJteHdHMEdJejJwdG8rOG1ULzNjemV4aXd2TFlsRmIzY2hTUUlL'
    b'KzJYenZVYnlMNno0SWdBQUprbGxMY085VFV1akJtVlQKSDNxZHVvblhZQnY5L2ZIcmRkUWEy'
    b'dHJXMWU3czNXbHJhbit4NnU1Rzh5RVM0eFpBZDNtci92N0U3OHUxUGQwYkt2V1UrNEdUL3g2'
    b'bgpSdEtvbHpGNElrelp5OFFkUFk3TzlaKzl1eEVoUXBJQXdNWWd5MTlveWJ3OGRKekxIdWo4'
    b'YU9MVEZUZCtwRm90SWp6YlArQWI4OFVMCk5KSUFnTWJEdThvZjNKVDV6bDN0TDY5S2FjbWlK'
    b'M0FRbmh6NjZXNzcxdDlWM0g5MTJ2NXpkUjNGeWQ3UklmWlh5M3VmN1BUR2VIVE0KY0dWeC9y'
    b'QTliNmpnek96aW1BODU3QVBaMXlGZkUrVnVJaTlvTjg3b0dQY1ZKUWZ3K25ybit4eWxmS0Jr'
    b'Y1BvMEZ5ZlFpMVZyYUd0YgpYL3RvN3lPLzdQOFpoc1Nic3Q0NmNXV05sb3hmUi9HOFZLNXdO'
    b'TXB2TnZaSkl0eXBzYWNZS0xzN1B6anBnVVZMdnYra3FGTkdXc0lSClNBQUFTSlFBUU1JQUFD'
    b'MjhuSEt6bTdndy9tZFBJV0RZY0czdVZlVllsZTlsRCs0TmgzaWx6Q0NmRFNRQTlNS0svSWxs'
    b'RHlHUWdqenoKVE5XUEU5VlJza3k3RDU1dzYzTzFDaXptZHdYVEROcjBpdFRSWmoyNXFOZWh4'
    b'MUZNUndHR1JCd0JBQllUOEpqSXFVaVFBQk1rRUNXTgpONG92Y203VFpxMnVMb3ZqQk0rTVg2'
    b'VWlvd0xXMFJ0cUdKcU9FMmdmcDlrN3VYbHo1dDRML3JsRStNdXI3VS9uVjd1aWh2aUFSZ0No'
    b'Cm5zakRHWStrUlNlcmZDMzVvbGVsSWlkempDZ1lQVDhYUDhkSER2VkZmNk5sN0VZNTRpVWtp'
    b'a2lRRUM5SkpKYnRaTy96aEs0aHZxZ2IKRVlxWXlrK3hacXNCNExERDFCNXBHSlhsM3RUNzBq'
    b'cmhXeStHMkhsN2QxdmJHN2UxdmVIbHRJdWJTdWRkQndEd0V2RlkvNDZyamh5SQo1N21EVE02'
    b'aFpEM1RzdXd1VlYzTENJNFFTdDJRNTFOZFlPUWJDWEYvME45bG4zdGkyRW14SWliQ2ptRlgr'
    b'OW5aZ3dIL1lzb0E0TkV6CjZwWFpIQy8yT1ZBM1UvTzVQSjhVSXNXQjRXL2JSRjljT3ZaT2J1'
    b'N3lWTzJwdWJQT2NPd2llemZnTDdxemZVKzNwekxPMVlQaFlvOXoKTHd3SUdWRkM0WnlheDRv'
    b'TldoTXRreEhTbHhwNFFRbjZsSlFrd3lRY25WRlNQaUhHd0FWZE9SR0E1b1dVUEsyQ0pzOE96'
    b'ZFliVDYvdwpkVmJRYzRxWW0vejJNL3JpR3YxNUtPZkt3MDNiQ3A1K3BPVFJoYm9oQVA3MDhM'
    b'WkgreDVoQlhuOHkzVFIwUFJRa2VrSEc3UzhFSWlsCkt5ZW1ndW1wdEtFOGJYeG9Zb25zZ2pT'
    b'OEMrUU9IRmZNc3dEd0VVNGM1ZEZCWUJjSGpNVWtSYVpXVHBOVFU4RzZNb1pXdUNTUTJQNkEK'
    b'cFhzc0xtWHdLNjYvRmFrSHlyVTlCT0pIZ3ZsdHJ0cEx4c1RoK2x1VXdNK1VaWHB6TS84cmRl'
    b'M1NGTEZuRWpkcWNFZVlxVDM1OHMxUwpvT0FiLy9TalVYZ3JRcmJVM21OaU9LZUhLMGtYSmp6'
    b'WTk3M0hNd2VIczNxbk5OLytidFpYN3VJTStJdVVlQ2pJTTRNQkt5Uk9NbDdJCk9Udm4vb0hW'
    b'ejJlL3poV0NHU3A5clROMFJ1MHRLejl0NjI4Nk1hcGlvNUlFSWtnRWhnU2FYR3ZFU1lRK2R2'
    b'SlltT2NGQ1NSQVNBckwKS1NqUFdsbGY4TVpFbnB3ZDZqV3ZPU1hpZXFWem03bGJlOWlqaWN1'
    b'ZTRkZHRsK2xsYmd3VElkRlMraVBVRXgvLzhIcTJPV05sTkNaVgpxV1l0Y0tqRWJMYXN0VGdM'
    b'OUk2bTBaTEJDWlB6bkJFK09xbUlZdWlxUUhoaGJnbkt5Rk9WT2VZVjJkYmxab1RRcjUxN2hn'
    b'U3R3ZWNUCktMSnl0c3U4N3pBZFlPUHpGQVJjRGlKNWNmM2VUK1dOcnNLYml5TXNmNm8zdXYv'
    b'ZzJPcVY2U2tXRGIrcDdFKzlwU1hkUFFGSnYyYXcKYTBVb0FnQXNpVGNYbEZOVTVFUkIyWm95'
    b'b1NoWHpuUGlzUk96d1JCWFhVeDkzekRlKytGSTdiN3VlSjUydkR4QUwzUmpxbzhOandvOAp2'
    b'ckcwRlNybk5MbEQ3ZjEzMUFTelU5Q21hajVTV3Z6bVpQNnVEYjh3QlNjd1VYQXlHZVZpLzdh'
    b'TVk2VnF4SE5ZakVmLzBVRjM0TmVhCjVJNGxnbDE4dDYraXhSN25NNldYRFdnQVVJWmpKYzJE'
    b'bjUrZUg3ejExOVBLUXI4bzB6ZS90NlpNcHRQSmFJVjhpMkxzNEpnMHFiTUMKQUFKeHE2NVRv'
    b'NVloQUVtQ2ZaL01kVERyKzNYTE5aR1ptMTk1dTloK052NkR2NXhBQXdDUFkxRVY5c0Q4Ymo2'
    b'MVVLOE1abGRxeDhZRApERU1BZ0Z5TzZhTnowd1FEQUNRZlVaTUNUY3RkcnFqTEU5bTB6cmg4'
    b'c3NVdG51UW54MVZraENVSmVid09LRjJ1b0FsQnRJN09XMGZuCmZmdFBPWDVrTTVYbUt4VEU3'
    b'R3c0Rkk1NW80U0hOSmo5WjNHUmR6TVpQVE95Y21BRlFWcWFwOVZxcUxrQlY5RkxueGhkQVpT'
    b'b2tjTmwKcUJpT1RkMW1zMjB1Vktzb0MwM2tMbEVmZTNzZzlzN0V2cGtQZEtFSUFBUmwxTW1z'
    b'Sld5MWVzMzlWOGpsZUl3VDZjYnNMZ3dwZG4zQwpSTGtrNkc4cVNoQUxYMm50UFQzTi9NMnk4'
    b'cnAwdjRjMVBkOXFXWFJYaFluR1ZvME1DM1pzN0tyODNCTERRSS9UK1hadlp0TmdRaTVWClhN'
    b'YWdBUUFYeFp5alo2Vmo5aE1WV1ZTTVQ3blVqU0JjRlAzL2V1Q28xWngyWkNSSFRQQ0M0SElG'
    b'ZmQ3elpYYVBmMDJBenVIVE9YemYKaGFFbTd4a21RU2RCSjVVRW5RU2RCSjFFa0FTZEJKM1Uv'
    b'eTlvU1VJWG5adE82cS9XL3dHTDUvSjljT2JtWkFBQUFDVjBSVmgwWkdGMApaVHBqY21WaGRH'
    b'VUFNakF5TXkwd05DMHlPRlF3TlRvek5qbzFOaXN3TURvd01ObEFWOU1BQUFBbGRFVllkR1Jo'
    b'ZEdVNmJXOWthV1o1CkFESXdNak10TURRdE1qaFVNRFU2TXpZNk5UWXJNREE2TURDb0hlOXZB'
    b'QUFBQUVsRlRrU3VRbUNDCiIgaWQ9ImltYWdlNTM1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'RU_ALT')

RU_ALT = b64_RU_ALT
index.append("RU_ALT")
index.append("Russia Altayskiy kray")
catalog["RU_ALT"] = RU_ALT
catalog["Russia Altayskiy kray"] = RU_ALT
country["Russia Altayskiy kray"] = ('RU_ALT', '', 1)
lookup["RU_ALT"] = ('RU_ALT', '', 'Russia Altayskiy kray', 1)
lookup["Altai Krai"] = ('RU_ALT', '', 'Russia Altayskiy kray', 1)
lookup["Russia Altayskiy kray"] = ('RU_ALT', '', 'Russia Altayskiy kray', 1)
details["RU_ALT"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+07:00","altname":"Altai Krai"}
regional["RU_ALT"] = ('RU_ALT', 'Russia Altayskiy kray', 1)
regional["Russia Altayskiy kray"] = ('RU_ALT', 'Russia Altayskiy kray', 1)
#----------------------------------------------------------------------
b64_RU_AMU = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyBlbmFibGUtYmFj'
    b'a2dyb3VuZD0ibmV3IDAgMCAxMjAwIDgwMCIgdmVyc2lvbj0iMS4xIiB2aWV3Qm94PSIwIDAg'
    b'MTIwMCA4MDAiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiA8c3R5bGUg'
    b'dHlwZT0idGV4dC9jc3MiPi5zdDB7ZmlsbDojMDA2NEM4O30KCS5zdDF7ZmlsbDojRTAwMDAw'
    b'O30KCS5zdDJ7ZmlsbDojRkZGRkZGO308L3N0eWxlPgogPHJlY3QgY2xhc3M9InN0MCIgd2lk'
    b'dGg9IjEyMDAiIGhlaWdodD0iODAwIi8+CiA8cmVjdCBjbGFzcz0ic3QxIiB3aWR0aD0iMTIw'
    b'MCIgaGVpZ2h0PSI1NzEuNCIvPgogPHBhdGggY2xhc3M9InN0MiIgZD0ibTEwMjguNiA1MzMu'
    b'M2MtNTcuMSAyNy45LTExNC4zIDI3LjktMTcxLjQgMHMtMTE0LjMtMjcuOS0xNzEuNCAwLTEx'
    b'NC4zIDI3LjktMTcxLjQgMC0xMTQuMy0yNy45LTE3MS40IDAtMTE0LjMgMjcuOS0xNzEuNCAw'
    b'LTExNC4zLTI3LjktMTcxLjQgMHY2Ni43YzU3LjEtMjcuOSAxMTQuMy0yNy45IDE3MS40IDBz'
    b'MTE0LjMgMjcuOSAxNzEuNCAwIDExNC4zLTI3LjkgMTcxLjQgMCAxMTQuMyAyNy45IDE3MS40'
    b'IDAgMTE0LjMtMjcuOSAxNzEuNCAwIDExNC4zIDI3LjkgMTcxLjQgMCAxMTQuMy0yNy45IDE3'
    b'MS40IDB2LTY2LjdjLTU3LjEtMjcuOS0xMTQuMy0yNy45LTE3MS40IDB6Ii8+Cjwvc3ZnPgo=', 'RU_AMU')

RU_AMU = b64_RU_AMU
index.append("RU_AMU")
index.append("Russia Amurskaya oblast")
catalog["RU_AMU"] = RU_AMU
catalog["Russia Amurskaya oblast"] = RU_AMU
country["Russia Amurskaya oblast"] = ('RU_AMU', '', 1)
lookup["RU_AMU"] = ('RU_AMU', '', 'Russia Amurskaya oblast', 1)
lookup["Amur"] = ('RU_AMU', '', 'Russia Amurskaya oblast', 1)
lookup["Russia Amurskaya oblast"] = ('RU_AMU', '', 'Russia Amurskaya oblast', 1)
details["RU_AMU"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":"Amur"}
regional["RU_AMU"] = ('RU_AMU', 'Russia Amurskaya oblast', 1)
regional["Russia Amurskaya oblast"] = ('RU_AMU', 'Russia Amurskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_ARK = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc2MDIiIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODAiIHZpZXdCb3g9IjAgMCAxMjAgODAiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'QXJraGFuZ2Vsc2tfT2JsYXN0LnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3'
    b'Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0'
    b'cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5z'
    b'OnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3'
    b'dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9z'
    b'dmciPgogIDxkZWZzIGlkPSJkZWZzNjA2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9'
    b'Im5hbWVkdmlldzYwNCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2'
    b'NiIgYm9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2Fw'
    b'ZTpwYWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgog'
    b'IDxnIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIg'
    b'aWQ9Imc2MDgiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFs'
    b'aXR5IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFB'
    b'TlNVaEVVZ0FBQUhnQUFBQlFDQVlBQUFEU203R0pBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFB'
    b'Q0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3Vs'
    b'RThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFUCkdFbEVRVlI0MnUyZGVYU2MxWG5HZjk4'
    b'eSs0eWswVGJTeUpJdFdjTDdpbmZMUUFLQlVOT0V4V25hQkU3VEJ0b1luS1FwQ1NRNWtOUk4K'
    b'NGpScEtBbmdKUUdTbkJOT1R0TUFLUTFMQUJ1enlEWmVNTGJsUmRqYVpXa2t6U0pwUnJOL1Mv'
    b'K1FCWGJpUmJhK3NVZTJuajkxWnU1YwozZWY3N3J2YzkzbXZZUC9sUVMyaGFBSm53SEtQUGIx'
    b'cGhUYzZMYytxTW82c3dTNS9UUDd5TnAraktaS1N6dlFaaXlocWd2M3BlajJoCjZtY2R6Q2FM'
    b'ZkgxV0FkK2FWNHhaRk1aWDl4SWlybWg4NzMwL2p4d0lvT3JuNWsyd1BWMnZKODlCOERCbTUx'
    b'dlp0TUxMb2lMNytFcGYKQXZ5cEk4S2E3VDVhSTZrUmZkNHFDWWk2UHZJZk9CQktVUHQvemF5'
    b'dTZ5S1Mxc1pYL0NJaGxGUlpYZGZGTGErMmpaaGNBQjBRTEUvVgo2MmxOUCs4ZkxYT1krTm5T'
    b'VW02ZGxEUE9RQWJ4YlBNQWE3YjdDQ1NVOC82dVJSSVF6RS9WNjhvRkVEeU1sUlV1Tml6M1V1'
    b'WXdqYk5oCklKckNLZTdiMXNYbXpzRUxIc01zbnVjV2ZUcTgxQjVoem5PTlBIWXdnS2FQRXpO'
    b'YUtKck9Zd2NEekgrK2NWVGtmcmhGeTA4ZTBJMGkKWmtXSmd3MjFYcWJsV2NhWnVnRHNEY1Ja'
    b'WGRmRmU0RzRJZVBKb29CbzVBVGY2WTZ5OEErTnJIMnZoNUY2NXVPQW1LTHg3ZDA5TEgyaAoy'
    b'VEJ5QVhRZGhGODJCTFVIZG5ZTG9hU3hlWXlaYmlzYmE3MHM5WXlIVkdmRHkrMFIxbXp2b24w'
    b'd2JlaTRsUzR6ank4dFRRdWFwcW05CmNVVjhZRmMzenh6ck4vUkhCT0R1cWZuOGFGRUpPV1p4'
    b'bk0yVDBCMVQrT1p1NDlkY0ZnVldUOC9uZTFkN2NKckVwS0JwbWdwRFcvWDUKQnRJalJhbGQ1'
    b'cWRMUzdtak12ZUtKMVlIbmpuV3g5ZDNkaE5NR0x0cnppbXdzcW0yaklWRnR1RS9uVXJ3c0Qz'
    b'NC9naFRZUmNTVWoyeAozRXY1RlJwU05ZWlRySzdyWW12WG9LSGoybVNSaCtjVjhhK3pDcEZQ'
    b'VFNYL0pjSEQyQmRNc0xxdWs5Myt1S0dUeVRWTGZIZCtFV3RtCkZIS2xwTFhUbXM2ajlRSFc3'
    b'dTAxM1BtOHR0VEJ4bG92VitXZU5uSTVNOEhETWRtR3cwRys4MTR2Z3dhbkpwZDU3R3lzOVRM'
    b'RGJiMnMKeWQzV0UyTjFYU2VIKzVLR2pwdHZrZmpCUWcvM1RNMC8yOGZPVHZBd1dpSXA3dHZt'
    b'NDdYakVVTW5hUklGdmphcmtPL01MOFlxWFY2dgo4MEJLNWQvMjlyTCtVTkR3Qk5DcXFseWVX'
    b'RlpLb1ZVKzEwZEhSdkF3bm0wZTRDczdmUFRHRlVNblhKMWpac055THg4dmMxNFc1TDdZCkZt'
    b'Yk5kaC9IbzhhR1BsVXVNeHRxdmR3dzhuVTZQNElCK3BJcTM5N2R3MU1OSVl4OE1BWGc4elY1'
    b'UExLNGxBS3JOQ2FKOWNVVXZyckQKeC9NdEF4a0pmYjYvd0lORFBxOXc4L3dKSHNiYnZpaXI2'
    b'N3I0WU1CWTIrS3h5ZnpISWc5MzFiakhWT2p6VkVPSUIzZDFFMDRaNjZ2TQpLN0N4YVlXWHF3'
    b'dHRGL0wxQ3ljWWhxb0xmcnpmejQvMkIwZ1piR2orcXNMRjQ4dThUSFJtZDBoVkgwcXd1cTZM'
    b'ZDN0amhvNXJsMFVlCm1sZkUvYk1Ma1lRTDlrOUdSL0RKLytTWDZyclltWjMvNUlkUVZSVWRr'
    b'S1hSbTRDRXF2T2pmYjBaZTdpZldPYWxZdlFQdHpFRUEyZzYKUFAxQmlBZDJkaHRlN1RIS2Jl'
    b'cERIRzVxQlYxZ2V2WEVVWTN6dGkvS3ZkdTZhT2czMWp5VjJHVit1TkJRODJRY3djUG9pcVg1'
    b'Nm5ZZgpmMmdOWjR1ajhTRSthTzVBVlJTbVgxVjVRZC92VDZsOGE5ZVljakNOSnpqYlFvVmc1'
    b'L3YwaFhwSjlQcUpKYUpvaWtpT1ZVUXVMU2MvCkw0L0Npa1VqR2llVEllTEdXaThmODJZa1JN'
    b'd2N3Y05QL05vTUJ2dVBMeXVsNkN6QmZyQjlGOTNKQWhJRFhlZzc5MEY1RXQzcVJOZ2IKUkx6'
    b'eE9xdzVYZ3FFTGp5VGw1OXhqTlpJaXZ1MiszaTFJek5KbnUvT0w4YVN1U1JQTXFObmVIbG1p'
    b'VWVYbFBMR3lrckRxenllYlI1Zwp4dStQOGVSWnRzdFFRaVFTUytDMHl1ZzVUcFRlT0dJNGll'
    b'NTBZakVKREViajlDbU9NL29VVHphRW1QdDhvK0hrTHZmWTJYUGJaTll0CjlHU1MzS0h0UDVO'
    b'djhNbTQyQW4zVkN4SVovc1JUQ1lMWXZndzRmNSs3QllacTdPUVVFODd1WjR5RkZzbGFVV25y'
    b'S3djUzA3NWg5L2QKSHh3S2ZYYjVqWTBLTHNGQlMvS2luY0tiUklFSDVoU3g3L1pxcnZNNkRC'
    b'MjdJK1RIMy9naWE5L3JacmdFMkdSell4MW9ST2piamRXVQpUMTVCSGpaM0VaSnN4dVcyWVpI'
    b'Y0NPSDlPR0p0bUowbEg4YjFhOS9ySnRMeUVvRnd3TkE1cnF4d3NmK09hcjR5OCtLZW9sMjBO'
    b'L2pQCk16L1BIT3ZqL25lN01hSlU2UGtaalh5czNNMWJMY2Q1dkc4V1A1eGxwVWdHVzZxRlFk'
    b'OCtkRkZBRkNTRUU3K3VDeEs2T2xUVVlIVmYKUmRvMWc4Nmt6b01Ia255anFKNXJxOHJZMnQ3'
    b'UDdZZXFSejIzUzF6c2tMd2tkVFFDY0ZlTm13TjMxSEJuVGQ2b3gvUFlaT0xSQUhQZApFcmRK'
    b'K3ppeTh4MEdCUk5hN2l4MFhVVkFCRjFEVmROb3FvcXVwdEVBVlUyakY4NWhFSm5HUGUvd09l'
    b'djd6SFZMeEFlREZOdWtVZitQCjkwek41OUNxcXk1cEpjc2xlWVAvSEMrMVIxaXpyWXVPOHd5'
    b'cGZqZWpoWlFHYnIyUGhHWm1wdHZDSzIwRFZDUjlWRlROQU5uQ1lLQ1gKSEZNRWx4WWhHRkd3'
    b'bWNGdWxvbUtMc0txQTN0K0NicWFvS1A1TUYzV0VqNVJrY2ZCVUFxN21DSWc1bUVSNGJPSHpp'
    b'OXV6cUtDdzZSTQpGbUJsaFl2cnZEWDg0RHhLaFFSMGFwd2ExY1VldGphbG1KNmo0Y25Qb3pM'
    b'WVR4VmQwTmsxWkl0MUFXZkZKMmcvdW9NZmJCRXhDeW9QCjNSREhYZUxHUGJBSFRsVFAxRmpB'
    b'NHZUZ0tYQ2o2UUdPUm0xOGFwS2JKbjhBRVIyTmN4dE9xeVR3amRtRldhWEN6SnBTUjRjc3Nt'
    b'NmgKaHpkdnFSeFJsY2VxZ2lBVDh4d2tJdDNNelZWeFNUcUh1b05zOXAvNnpGckxycWRreWlj'
    b'SXhDM01ycTVpK1l4S2N2SktLSnY3ZWJDZgorbVp1N3BVNDBoM0VKYW5NeTlGSVJRTk1janU1'
    b'dmZEY0R0ZUtFZ2Q3YnF2bXUxZDdza3BpbTNXMXJFdFBpaEhQVnVYeCsyQWh5N2JhCmVhMWJw'
    b'ek1Vb3lGU1JFZW5qa2svNlR2MmNzcW4zNFROWnFOZzBoSVdUUzNCWnJNakZNeEQwUVhzNWRl'
    b'ZTZ1a0Q3Y2RWR2lJZTJvSXgKWHZVSnJIakx6ck9Cb3JQRytodHJ2Ynh4U3lWVHMxRFJrUlUy'
    b'K0V4b0NxZTRkMXNYVzg2ZzBYbHUyakZ1bUZ4SUt0cFBhM2MvU3RuSAo4YlhVVXgxOUNVMFhj'
    b'TSsrRjN1T2gwUEhROXoveTdmUk5FanJJbVU1WnVLcW1kb0tqYitwT29LWTlnUFE0cnlaNGtt'
    b'em9XTUxrNzJGCldCdzViR2tPY1B2aG1qT2FsaXdYM2lXenVocDljbzZaUDkwOGlWOWRXM2Jh'
    b'K3FOTm5ibG9xb0t1cXpqTU9yMHhrY0FKKzIwcFhvS2kKeWZpYjNpRGVYVStaUXlPSkdiTWtV'
    b'ZWhVdVh2bU1WU3JDMGZKdkk5U3E3cEdiMHdpMXlZZ29LQ3BDdXM3L3RJRExuT1llUGFHQ2w2'
    b'NApjV0xXcXlxelhtNHdIRkx0djZQNmxKQktSdU9uMHdkNHRTWEVsbzQ0bEM1amlzZkVYbjhB'
    b'RlRPMjBvVjBiVjJQR29sUmJtcGg5WUlvCmdxN2lzRmlaVVRSSWZTaVB2MXN5QVRsbk1zTSsz'
    b'UjUvZ0NrZUU1UXM0L1gyT0s4MTkvSFlqREF5UThlZm9qQVUraHhjVlRObWRORloKdlVXZkRx'
    b'OTBESVZVN3l4b3hpWW94S0lEQkhPV0lkc0xTYmE5VEh0VW8xcEtRQ3BFdU9Fd29ib0dLajkv'
    b'TmQwUm5mL2NYVWwrVGc2RApLWTN2TFQ2SUtGdXhULzViWW0wdjBSOW9wNy9zT3NvY0pzd1ZO'
    b'NkhHUStTSHQrTnc1SkhRUlZZZXVHb3N0cTlJampuQjBNM2xMdXBYCjFiQ3QzNFV1bTdIWlhL'
    b'U2lBM1EwYkthcTJJMGtxYVFIbWhEaWJlUk9kR0F2Y1JIdDZDTVFsbWdKNkx6WEdLTGQxNGVp'
    b'YVloNmdzSEcKMzdHOXZwZGdmd0pSMUpoYzdLYjlnemRKUmlQWWJDNDBVV1puMk1XN3QwNGVr'
    b'NzFKeHFRaXpDNkxmR1pCTGFHMGcwQThUY3pmVEkzTgpUeVRReHQ2QWpwbVBpZzBLVjFRUk91'
    b'Z2pvVXVJYWdMU1NSSXBuU1BkRXJvTzYzKzduZC84ejJacUpyclpIMUtKQkZ1Wlp2Y1Q4emNT'
    b'ClRDaUVkUmUzemw4eFpyc0xqV25KbjVzUWhUYUp5dncwc2pVZlYwRUZlYVloZytyekQzbmVr'
    b'bGttYjI0WlU5MEM2KzlaeEYxWEozamsKSDVjd3IxeG42KzRPWG5pamtZbGxRNDZVeXlUZ3pL'
    b'OUFzdVpSbForaTBDcVNxNGZHOGhLTlRZSUhVaXBmZTlmSE14MHlpbXpEWnJmaApjdHFKUjNv'
    b'd2lUcXFxdkh6NStwNVkxYzdCNDc2NlU3cklNV1k2TFp3Mi9RSWxhWWczUzFwbnQ5eURFbVc4'
    b'ZmZGK1ZOZEMyWlJJeEhwCnhXbTNZN2M3VUNVYnYybVgrZmJ1c1N0b0gzTk8xb3R0WWI2ODNj'
    b'ZkhIY2R4U0hCem5wK3dabUZGUVpMai9RcS9ia216Sm5jdmlxYngKMUhQMVJLSXAraUpKK2dZ'
    b'U3JDMXlVUERGUlVRUDlURFk1T2Z2WDJ0bThVd1BuN3Q1Q2kyZEE3VFArR3Z1ckhFeElkZkV6'
    b'ajRKcDVEawp4ZjVpb29yQXRtUjVKa3RyeHAwc1gwemhzMXM2dVBYMWRqcWlhZTRxN3VYaEtq'
    b'K0NJRElyRnphM0svaVRoYVNFb2JpMGJ5Q0JKSXJrCnVhd3NtMU5LWHpqQllEeEJXdFZwdFp2'
    b'WVcrOURWVlZNc2tBaXJiTHltaW9Vc3cxL0lwOHRIV21tNVVwb29wbUhLZ1BjV2V5bk1aemkK'
    b'eHBkYitjSmJ4dzNYOVY3UmIvRHBWQU5tTkxwdUNxQXJnOFQ2dW1tSm14QkVGMEd0a3RhZXc5'
    b'eGczalVVMXg3cVp0M1R1d2dOSkRDSgpBdE5NQWtkVVNDdERSd2ZEbTI1SmdaMy8vdkV0YkUw'
    b'dm9MeDRKZ1ZpQzZvV29kcVd3cHJuUlRRNUtYdXRnS1ErdEV3WktHKzlNdC9nCmczMEpydm5q'
    b'VUdlOWt5VWhOYllZMFVBVFNpeUNZTTNGYnJaZ3NyaVpPS0dFbzNHZFdDTE5DMjgyOGVUekI3'
    b'bDUrYVFoWjhza2NVU1QKTUZ0c1dNeG1UR1l6VHFjVFVSU1o0SEhSRlloeU5BNFRKM2d3V2Qw'
    b'NHpSWjBXeDVLUEV3MDBFaTE5YVB5bmU2WXdqKzgxY21uWG1zegp2TGVHMFpDemNWTG5VZzJV'
    b'VzFLMGl5WFVkWXFzTEVsZ2NucUpNNEhtbzl2NFFDZ21hUzlsMFVJTEg3dG1Pb3Ftc2ZqcXlj'
    b'eWNhQ2ZRCkY4Y2tpN3orN25HYU93ZXdtQ0E4bU1aVFlNZWFYOHIrU0JtSFA5aEdSZmtpckpn'
    b'WlVQejhzZHZCTmNVNVRMUWxPUlEvMWY2KzNCNWgKWnRjeFE5VVhsLzBXL1U3M2tLanRkS29C'
    b'cTZDd2JsSW5GYllFZlFtRkZXNlF6QmI4bWhlTHJGT2t0L0tMVmpQM3o4bWxNK2luYVZEawow'
    b'NGVuOGNpa01KcVU0dnJFSzhSTWhiUXFKV3dJVmJBOVZzQWZwamRRNDFRcEt5amlKL3NIK09k'
    b'SktYcXBKS1ZvRkVvKzlGU1N0L3NFCjhxMG0yaE1XdnRrOGdTUi9XZTFobFByQzZDMDZhd2dl'
    b'aVdwZ3BUdklrM1BDeUxKTWNzREhZRnFnTlNwaHNuaHhXM1VLdEhaNlZET0YKZGdjV0V2UW13'
    b'Ujgzb1Z1cktQSjRLVWswY0R5WXBuTkF4VldVVCtPZ3dDSkhFeDZMVGdJTGdWZ1NqeFFqSkUy'
    b'aVB3NnBaQmNWZHBVYwpNMWh5UENpcXd0Mzc4M2k1Ny9TcWVpUFVGNWNsd1MrMmhibHZ1NC9P'
    b'RVpUcy9OdkU0M3docnduZDdPS2ZHaXBZTjdXZnlmbE9kRjBqCk1kaUhQektJZ0l6ZHBHSFNF'
    b'blFuYzBtbTBsZ2R1ZlJhcDVCU1JEeFNoR1FpaklwSWpYU0l0R2dqcHNqb2VwcmlIQ2RXdXh0'
    b'QkZHanEKai9LdEk3azhPYVVEVW1GKzNWL04ycllKNTV6akJRaTFNMGJ3SmJYQm5kRTBYOTNo'
    b'NDMvUFE4ZjBac2pPWUxxSzMvaUw2VWxiOExhcQpQQ2owNGphTGhPSWl5YlFOeFZWS3NTMk14'
    b'V3lodnljSXBsemk4U2dPaDRZN0o1K3dYeVdQSGt4NVhuSXRrMG1ta2dUaU9VaURYWVNpCkVv'
    b'VkNIMzFKalNkYWk5Z2NMbUxwUGhkM0Z2blpIUjVaTHJvNWt1S1RyN1NlVDZ1Rnk4c0dHNjFF'
    b'L1BsVmJlVHFNWlNrRXdTSjZ5dVQKbUdXWmVNU1Bidkh3Zm1jYXpWV0tVeHRFRkRUa1ZCaUxX'
    b'VUFYTEpSYmU3RzZDa21sVlRhM21ORjFEY2tjSVN6WVdIMXMwcWpuTnNKbQpLWmZQRm4wZ2xP'
    b'Qkw3MlJPTlhEZmpId0dPM2VpSm5zQkt3Z0tDQmFjbmptWWJZVUFSUHViaVBtUElzbUFMZ054'
    b'SkdzeDl0TEZQRm9mCnpKajZZbE90bDVwY3krVkpjQ2E3QVp5dXdacXVhOFJEeHhCbEI5YmMw'
    b'OXZOeE1CeE5EV0d6VjJOSUh5MEJFY0hrcXl1NitJdFg5VFEKZVo2bFlkbllKdml0RS8wOGpo'
    b'cmN6NlBVTHZQb2tsSldWUmxmV0o3SnZodW5hVGs0TmduT1pFZWVpOVhrMUJkVCtKY2RQcDdM'
    b'VU9lYwpFMDFEeHg3Qnp6WVA4T1h0UHZ3Sll3WFROYmtXTnRaNnVhN1V3Y1hFOENsV1I5VDR0'
    b'cjlQTEN2bHBuTFgyQ0M0T1RKMDE4RHJ4NDF0CnVIbVJCTk5uUmFhNzF6MjJ0SlJpbTV5ZEJB'
    b'LzN0WHg0VHk5UnhWaWJWVnN5cFAvTmxxc0N0dmZFV0YzWHhhRytoS0hqdWkwUzZ4WjYKdUh0'
    b'cVBrSTJFZngrY09pdWdUMEdkNmJOTTB0OEowczcwdzRMMnY5OWJ5OEpnME9xYTBvZGJGanVO'
    b'VUlwTVRxQ005MWJlaXhjMTlONApRbjN4UnFmeFBhQU51RTd3d2drZXJrOXVNL2c4MUdzMzhi'
    b'TmxwZHcyaGk3Y3ltUVg5MW41UTFMVUpjWDJpME53VDF6aHdRemM3eUFLCjhNVXArZng0Y1Fr'
    b'dTA5Z3M5c3pDdFJrNXdabDhTbWVmZUVvWEYxOGVON1JrY25mNzZkSVNiaDk1eDRDUkVaemxk'
    b'aVlya1duL1pQMXkKTHhQTzdaK2NuZUJNZW9yWGxnN2RrallsOS9LK0pTMVRFY1lJV3pLZG1l'
    b'QXhGT3RsUFRLWkkxanVzYk94dG96cDdoRmV5cEhwYk0yNQoyZzllenJnRVdiNVRDYzVrdm5Y'
    b'OThsSnVuT0JpSEJuTzB5LzNudHhvYm9oZ1gwd1J4L0NKeVpoRXB1KysrSzhscGVSYnBLVHd4'
    b'RUcvCjl0Q2VIc0hvTTg4RlJUWTIxWll4dDhBNnp1Wlo4S1l2eXIwWk9Dc3ZzY3VzVytCUkJQ'
    b'RVhCd3kxdEVhMzRiOFNrS2xxRjVzc1lpakIKbnl3ZmlzK3kvU0tOYklYUjlXcFd5YUFMb2ow'
    b'Mm1WOWRXOGFMTjAwY0ozY1VtSjF2cGU1VFZXeXM5UnFTcnRWaGRHL3dzRUgveWVLUwpTMXI3'
    b'ZXptaU01cm1LenQ4dkRDS3V5L01vbkRoQkU4K2NSM2Q5WmZKZFhUWkhGSmQ2RjBSSnZFQ3R1'
    b'amh4dDc3NzZnWkovY2lZRlZWCkxvYy9VOE05RjVENU8rOHRlbjZoalUyMVh1Wm5sNEx1aXNI'
    b'WmxKZW5neVNNOEEwZTdnUzc0OU5WNCtSZVFneDN0SDE0WHRHSVR0OTAKZElUSzN6YWNkWE9m'
    b'WFdCVkhsdGFFaWwzbXJYeEpjNGU3QXZHNVRYYmZLNGovUWw1SUtVSlozS0MveDh6dHNpZEtU'
    b'dnZkZ0FBQUNWMApSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TXkweE5GUXhNem94TlRv'
    b'eU5Tc3dNRG93TU5KYWV6a0FBQUFsZEVWWWRHUmhkR1U2CmJXOWthV1o1QURJd01qTXRNRE10'
    b'TVRSVU1UTTZNVFU2TWpVck1EQTZNRENqQjhPRkFBQUFBRWxGVGtTdVFtQ0MKIiBpZD0iaW1h'
    b'Z2U2MTAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'RU_ARK')

RU_ARK = b64_RU_ARK
index.append("RU_ARK")
index.append("Russia Arkhangel'skaya oblast")
catalog["RU_ARK"] = RU_ARK
catalog["Russia Arkhangel'skaya oblast"] = RU_ARK
country["Russia Arkhangel'skaya oblast"] = ('RU_ARK', '', 1)
lookup["RU_ARK"] = ('RU_ARK', '', "Russia Arkhangel'skaya oblast", 1)
lookup["Arkhangelsk"] = ('RU_ARK', '', "Russia Arkhangel'skaya oblast", 1)
lookup["Russia Arkhangel'skaya oblast"] = ('RU_ARK', '', "Russia Arkhangel'skaya oblast", 1)
details["RU_ARK"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Arkhangelsk"}
regional["RU_ARK"] = ('RU_ARK', "Russia Arkhangel'skaya oblast", 1)
regional["Russia Arkhangel'skaya oblast"] = ('RU_ARK', "Russia Arkhangel'skaya oblast", 1)
#----------------------------------------------------------------------
b64_RU_AST = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc2MTciIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODIiIHZpZXdCb3g9IjAgMCAxMjAgODIiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'QXN0cmFraGFuX09ibGFzdC5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5p'
    b'bmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6'
    b'Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4'
    b'bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cu'
    b'dzMub3JnLzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3Zn'
    b'Ij4KICA8ZGVmcyBpZD0iZGVmczYyMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJu'
    b'YW1lZHZpZXc2MTkiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2NhcGU6'
    b'cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8'
    b'ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiIGlk'
    b'PSJnNjIzIj4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjgyIiBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0'
    b'eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5T'
    b'VWhFVWdBQUFIZ0FBQUJTQ0FZQUFBQ2ZVeENDQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNC'
    b'alNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4'
    b'QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBVQo0VWxFUVZSNDJ1MmRlWFJWMWIzSFArZWNP'
    b'OStiZTVPYm00bk1DU0FCQWtnUUJBUkJCY1VKb1dndENnNnZyNlZxVyszVHAyMXRuWjVhClcv'
    b'SHAwK2R6dGRWYW4xUkF4VG9ob0l3QkFqUUdBaUZNSVhQSXpYQ1RtM3R6NXpPOFA2NnIxbmE5'
    b'OWoxRkpQRjgxc3BLMWxrNWUrMnoKditlMzkrLzMyOE1SOGg5K1YwTm4yQ0xxVGFBTHJLTUxy'
    b'S01McktNTHJLTUwvTG5KajJ4bit6Y1djcHR6aFM3d2NPTTIxKzNNY24xQQpSb1pHamp2S3p3'
    b'cittZnpBcHErRndJYXZ3MFBPbk5DRDJlREZaTlFZV3hJZzA2UHcrckdRTHZCdzRmWnR2OFNl'
    b'Nk9KbDB5LzRZRmNlCnZ3bitDbEZNNkYzMHNIbUx3MTd1bi9va0tac3pHV1B1WXBuemZqU2pU'
    b'UmQ0T0tBcE1uZU1mb1pzVHh3QVJZRnZYM0djb3I0MzlDNTYKeUlzYkN5TjRHNWhuY21MdGQ0'
    b'RUI1aWxwOEQ3TTdEdElxM0UycWl0YkYzZ29JZlIxWUVxRXVHdEtObDJkbmZ6ck0zZFN0ZVVS'
    b'Um8ySwpmK2IvUmpsbmNQQmIxM0hmcjU1RHN0aDROK0JHa1l3STFwUmgxUjZTYSs3U0I0ZjhV'
    b'NFFEekRWMG9yWWVaUGNUZDJCb3J1Ylc1Y3RvCjJmY09UYTN0ZERaME1IM1dLVEl5TkZKZEdy'
    b'WDdqZmphTDZHdCtTU1R4b3lpdktTQTc4d2N3MFNqSDE5N0M5YjRBUDNHMU9IeHdnL2wKNlVJ'
    b'dEdtS2k1aVUxNXVQVmxRL3ovcnR2SThvaCttdFdjYkQrTU82Y2NaU1V6NkM0NGhLNjExNUp4'
    b'QlBERUpFSWhzZXk2SUVQK2YwagpOOUhjMUVoNXFoZmpsTHZ3ZG5yNS9rOS9TWHRIQjB0WHZr'
    b'YmM0c1JyejlNRlB2UEthaGdIT3BrcWVIbnR5Wit6N3ZYVk9DMGEvb052ClVkZDZrSHEvbThV'
    b'ajdjejYzdS9Zcy82M3ZMSDVWVzRlNlNkaFNEN3EvbFlSVEM2K2RmZjdITm16bmgyVkg5RVk3'
    b'dWVXckJiVVNUL0cKNisxaytmZC9SbDlmUHpNZWZ3UE5tWUZtY2VoZDlKbGlncitXSFkvZlJw'
    b'cEJvYXVqbVhEZG04aEgvb3NuT3dxSnh4emNOS3VDeGZmKwpOK3NlVzhnclRUNktIQUhXV3pR'
    b'ZXl5bGdqY1BORFZvMzZ3MFgwbC8xQXJrakpyRGl2cWZSZGo3RGcvN0xvR1VkaTYxVjFBYnpP'
    b'SEwwCkdFL2ZzWlI1T1FaZU85aUpZRERwWWRLWGlxcVE1VzhpMzVUQWJEYVRrNVZKYWRWTjFE'
    b'VnQ1Mzd0Tm15eWtWdXZ2Umx6OFlXc2ZXb0YKRzhJSnZLblRtSnZSU1VnVmtSMUdaSWVSZEl2'
    b'SUdPTWhYcmN2NTJqZGY3UDYyUjh6ODg3M1dGRVlaNTN6RHU3elRjUjk0RzVTVzliZwpjRGpJ'
    b'RzVGRHZ2ODQ1ckJQOTZLL1RNYjJIK0w5bFQrbW82T0QxUTljUmFuWXhQUDlFcSttUDRpem81'
    b'YWZqbXFoZDhDSElNQ2h3RVoyCnUxZHlyZTF4eHNhc2YxUFdWRmM3NzRmZHZDZk01dnJlZCtu'
    b'dFhvekxMUEl2OGlwV3B0ekdQYjF1SGs3ZnhBY1B6NmRST0lkZHp6MUwKellGYXJubnJKSUxS'
    b'ckZ2d2wrSXdvQ0VJQXBJa01zVlFTMVcwbTdYMmUxRDYrM2k0dUk0TDc5OUJlcm9IWC9POXJJ'
    b'M2ZDNktSVW1NagphUmFSTzh3QmZ0TjJoTiswSFNGSE01RVpNVEREc281RzYzeHFUV240M3Jt'
    b'UkpYYzl3NlhmZTU3RjNiK2hLZnQ2ZmgwZFN6YUhHR0VPCklnZ0NvaURBRVBOWWhvYkFtc1pp'
    b'NFJqL3R1d0tubjdvVHJwZm5NZEpPY3hPNHd4Q3BnSitxTDVLeEpUUHJzcHR0Qi85aUYzS05D'
    b'TFcKUEp6aG8rUVlZZ0JFL0NxV1ZoVnJwNG9Sa2RFbUsrV3VXZ0EycUhkUmJ3NVN0ZVU5YXF1'
    b'cldGeXM0bWplVGFYMSsxUmFaV2F3bVhkLwpPb3Y2dzNXc3VqU2JuRkNITHZEcFJQRjNjZGV5'
    b'YTZtb21Nek0rZDhnM3hxa1dqQ3hSN29GYTNzMXBlUG1jdDE5THhFUDloQkxyR2FICmNnc0FK'
    b'ZVpER0FMRzVQQzl4OFMwclU2S050a1pVQlRzSnJBcWc4bnlEVFlPQzJPSjdieWJhNjVieHZs'
    b'M2IyQzVjVHNZekd3SVhNbkIKY0FTN1VlV0dHMjVnOWdVeldaQnYwZ1UrclpXMHUzaitwWmM1'
    b'VW4rWVV6dGZwSEV3UVpPaERFU0pHWEkxdG9FNmpoMDlndS80THBxRgpiQlJqTWh0VjRqaUpQ'
    b'U0g5citWbVdNSm9jakxEdFdOd0NmMnAvVlR2M3NhKzNkdTRQcjhkemRkR25iU1FKcXRLcWJt'
    b'ZGpXK3ZadCsrCmZXeXFiOWNGUG0yOWN5ek00K01Gbm5qbzV6Ujh2SmxaNGhaYXpCRjJocTRC'
    b'VmVFU2w1ZmliejdIWUtBZllXQVZ4ME5seE1OTkRQaGYKSjk5OUFydVFGRmpObERscFR0RGps'
    b'djljZHFwREkrNy9OYUdCN1lRc21RVHRFTm56TEdYbEZkUVYzY3VJdmxvRWc1RVRjaDVHWkxM'
    b'cQpIaVU3SzVNUGYva3ZWTVNiZElGUEIzSlBPNHV1dkJ5QVNYTVdvV3JRcWxnSTI0clJBcjNr'
    b'ZWh5VWxJNWszSVRKS0I2SnZaWVRkSld0CkpqQ3hBYmN6aEVWTENseFdic0o4dVVyNlhDaXlK'
    b'THRZT1NaZ0syaWxiOEp1T3ZLZkp1RlU4VmxHNC9GNHlCODdsZkhHcEtVMnkyTTUKR28zVEtv'
    b'Mm5vTEFJdTkzR1JhVWVQVXc2TFJYTUtlR2hYejNGemRjdG92NkQ1NWtqZ0Y5d2dBYUdVQzhG'
    b'NlcyODhzSkt6TDAxT0lzRwphRmNLUDdWUWk0THl5Yngrb1VQaXpXTlJpdXdteXR6SmE3R29R'
    b'Qm95elFCR2dlNllnZksrdGZ6dXVTek1nYVBrUzhtNHR5bHlEa0hYClJzcmt2V3paOEVkc2FU'
    b'bThWbnNLM09mb0Z2eEZ1U1J4aEFmdStSR1NBQ1doYmNncWlCWUpWUWtqUmpkek9PZTczUFM5'
    b'dXltLzVqN2kKTXFpMlQ4ZmNpQ3lpaWNtNFp0dEptZG5mSGFETEZTS1NTRjR6R0NEMkYwMFFV'
    b'aVZPQ3FYY2ZQdTlYSC9mU3hpTUVxRkFKVUU4cURZWgp0emxPNE1oR0pwU1g4OEt0bCtJSWRl'
    b'a1cvSVhHWDBYbTV2a3pzTnR0bkZNMmpuWDJXVGhENzVLU0ZhUlRlSXFjekNCcWZ5T3FxdUp0'
    b'ClBZN3dWL2R2MldWbnNFK216aDVFSzlXWU9GRWhFbzd3MFY2RmlOZUExR2pGVy9wcDBpS2hD'
    b'cVFJUHZyNitvakhZNlFiKytnYnZ4T2gKMW9Cb1VpRUJlVE9YWTdQWm1GQStudWtwMi9sUTFT'
    b'MzQ4NU9JOGQ2bXpXaWFSazkzTjFuQmZjZ3FlTklDcUJrU0NWR2dKTHlUZFg5NAppZjRqbXpF'
    b'YVFZd3FmNzdkWHFJUjB6U2t1TWpOUHd3RGNQNTBtWXFMWWppQ1pqd1R3L2hUUHMxeU9TVVpp'
    b'eEptKy9vMWJGdnpGQVl4CkNBSTQ4bngvTm9YbVA3MkhwbWw0dlY1cW1uUUwva0s0ZkhWTUx2'
    b'bDNIdjNXS3ppTU1leUN3c3dpQThWWk1yUkF5R0tnS2VkYWx0ejQKYlZUMVZ0Yis5azJjY2h3'
    b'L1J0RGdSTlRHek13UTRTWXJYZDBSOXRYZWc5djVJVDMxOWVRN0RQUTZOZFMvQ0tQU0xBbyt6'
    b'eEp1V25ZYgpBTGZmc1QwNWZrdGhCRUhqUks5Q3NPdTNQTFowRmU2TVFTNTFwUElIcHVvVy9I'
    b'a0o1RTdEVUdMa0I4KzBrcFlWWldxK0VWa0R0eVBaCkw0WTlac1RPUFFRQ0FmYnUyb1lVakpD'
    b'aEplUGE1Wlh0bUk5RFFFd2dwc2pzcS8wT1Z5MThqSUtSYnlDbXFCenRVbWp6bW5pNHNobWIK'
    b'TC9aSlNLYVNHZGlQeitkamYvVmVqaE1Bb05nVVFZNkk1S1JJYU1EMGI1N2lsZ2Q5N0xKY3Jq'
    b'dFpYNVNYUDE3QXdBQ1krczFZakhDOApSMFVTTkl4UkdjMXBRQTdzNTkwWEgwR1JFd1RVQ3Nx'
    b'RUlBRFpzc3ozNW5rWk1UN09ncnY3TVZ2T0JTQS92NUNSNDUxTXVxV1AwZWx4ClNvb0R1SUpK'
    b'Vjl1RmdwdzdpMFA3OStGYmZ5OU41bVR6RkZwaWREVWIySEV5emdYRkJucU9tYW1xc2RKaW02'
    b'ZDMwVitVT3ZFcVRLYlYKeUpsUmR2WktXRWRIcWZ5OWt5VVJMK3NtWmZOcXdNbmFYenlCS0lv'
    b'WUxFWWFEeTJoNGJpZmNlWDl6Ri93NmRyblJMd3o2U21IUXFTbgoreGs3Umdaa09rN0Z1ZVV4'
    b'TDcvSUxNYmx5dUtxYnowQXdOWkVsTGFhUjVod3VCOURTTVFnaTVnbUQ3THprSjJSQzJOc09q'
    b'd2VCRUVYCitBdDcwcFlVcXZZN1dQYXpBUUE2dlFMeGVCVFhCM0YyOUtaeXdLYXh2M29QRlZO'
    b'blVMUDFIUnc5QW0yRkZvNGRUbVBkR3BXVUZBM0oKb0hIT3FCZW9xWmxIZThzYUtzWW5XTC9P'
    b'VEc2cHpPNVZxV3hQY3pHMnFaK3UwQ0IxNC9ZemR2eEVqaHpjUVR6WHdsV05YcGJmMDA4ZwpJ'
    b'RkErWGdFaUFEeFllUjdZOVVUSGFXRkQ3UlRPSzY4aGQ4UUFPZGtha1lpRzJtcWxaN1NWQmUw'
    b'RDdQalBxOW4rckkwUmszd0lzcFdnCjI4S3FIRGN6RHlkWW1YQ3lJQjRodjhUTDVESFRtVHdH'
    b'M3ZpUEZKNzFabk4xNVNBRG1zYXVxUmxjVSswbHRUak12aGZtOC9hZ0NUTUsKcVlZODJvMG1E'
    b'dXd4c3ZDNlQ4WnBEWGJzTHFGQm5LMm5LazhYR1dsTGlZblZOTFVtMDRPUnFBQ2VHRGNlOUZK'
    b'ZG1Jck5MYkRvdmc2dQorMjRZZDA0Y1QyZVlsdUlVL2xYMHNMRWlpNk9xUkdxcXhvNXRSZ1pE'
    b'QXJKUllXOXBLZytOeWVHVnZJeGtLak1TWThwRk1lYmQyVWZGCkZiMDBXRXdNMkEwc3RrVEp5'
    b'djgwOUhwbjB3K1pmUDRCbFBqUTJQb3lKTlprZFhUMzh1MkxwM0RnUURlalM2cFo4eXNYajZq'
    b'NVZJOXcKMGpQQ1JtbHptUE9uQmRtejAwakYzQmo1VzJXYWdpTGRkaVB6ai9keGFaNFB4YWlT'
    b'VTVQQm5yMGlwYk1qak53aWN3d2pBYVBFdFlkNwptRFdobCt4Q2hYQklvRzIvaFo4VWw2S1pC'
    b'TFluek5pckpDek9FTm5aR3FsWjYzaGwzWHIyeWVsNkx2cDAwZXNxWXU0VGIzQ2hvNDdMCjVv'
    b'SWxNMEU4S0RHUWFVR01xUWp4T0QzZElwTWFQZFNjRERQdWluNmVPQlVnRVJHeGpWV0k5SXFr'
    b'N2ZXZ0lWQXUybW5ZTERGK25vK1YKQTM3aVlZSFVpUWtHZXlVUzcyVFNRQVJEYm95U3BrRk9q'
    b'bmJSbVc5SDYraWhzRWlsN3FpUkg2NStpU1pIR2NJUW1SSWVXc3RtTlkwWgowV2Q0NHFhdFZH'
    b'MHkwM0hDaXRzbFV6QWxnckxmU1pwc3hDdkdpVmdUUkYweFBEa3E3alNOOUhRTmgxM0Raa3VP'
    b'b2YzOUFvTWg2T2tWCjhQa0VvbDBtN0dFanpvaVJBck9KSTRVKzRnR1J6aVlMa2xuamdvVkJq'
    b'clhadVgvL1kwUnRoUXdsaHVTNmFNdGdJOU1OYTZsSXI4YVYKb3BLYUFpTkhLb3dlcFdJMFFp'
    b'd0dUUzBpWGQwQ3dVRUJWVWtLS3dqSjN4b2dpbUF4YTdqVElDOVhKVHNyMlF5OVBvR2pSeVNh'
    b'V2dWawpCUnE2MHRrVnZKS1Q5aXNRcEtHMzAyZEk3azJLT2txWW5sblBpbVV4QmtNQ2RmVWlq'
    b'UzBpaCtvbG9tR0IvRnlWT1hOa3hveUdSQUplCi9Fa3EwWk1HNUppQXdRaEtxc3FrUlNFdXZq'
    b'd0tRRnU3d0pyWFRJU1Y1TllXaDBQai9Ha3FvMHBWUXFFdTVqeHFIWkxpRGxtQkFWNnQKdXdy'
    b'SDZ0ZVlNMXNtMUdGazFSWTNOUllIaXQzQWtxTWhwTGlYT1F0aTFOZEptS3ZNWER6NDZhQ3Bh'
    b'TERWclhMeHdxVEF1NTVMNTJGRApPakZSSkNVUTQzcVRuK2tQOUZPNVcyTEQ3aXg2N0JWRHRa'
    b'bUdyc0NPZzkwTWRxV1NkMzBQbGJWV1BzaDBFN2Nac01VVTFEaG9uNnh2CnpScWhFaXVUMlJC'
    b'V0NLTmlGZ1cwQktSbnk1OFJQSXhJbjkxSWM1NkRTeG9VdXJ2OStJNlpzYXpYMEdacFlORUZQ'
    b'cU1zYVRuSW9KUVUKMFZFWTU3bUdEbXllQk81ekVoaXNLcG41Q24rcWtaQmxqWE9XKzFFU0Fn'
    b'Z2FpaUpnTW10SUF1eXRsakNiWU93MysxblZGMlNnVjZTLwp5WWhtTUpLUm9hRWxCTWI3b0to'
    b'MkUwMnpsdW9DbjBrK2RyZ29INVhNTHhkVVJCR3pZeGhOWUhkcDVJMVF5Y3pRNlBRS2hBTVNV'
    b'UkVpCnNvU1dBRlVBcTZnaFdWU2NhUnFwYmhXTFdhTzVWVU94Q3BBV3gyd0dXWUdpOGdSYjBt'
    b'WDZja2JwWGZTWjV0M0w3MlA1Z2x1cDNDMHgKZmFxQ09taml4QzRMZzM0VGZpU3liQkpaS1FM'
    b'cC95Qlg1NDlwZEF5bzlDc0tFVW5CTVNyR3hNc2lKT0xRN2xmeExzcGxJSDZlTHZBWgpqKzlz'
    b'VGpidXlXVEZ0VjFzZVNpTHlka0c4cTJBOWY5WFRvcFpZRXltQkh3eThUOWdKZmlLaXhwcGtE'
    b'bkxnanhZZVJHa0QxbDloKzRoCkxJSms0SGVEVDNMWFUyVTA5NmlFNDZldjdPNmd4cmI5Rmk1'
    b'ZnVZS2U5TGtNWllUaGNDQzQwdDJDZXFLS0NxV09DUTRmQmJZNGVXa0MKZVM2SkZBdFlqV0NT'
    b'UGp0M094aUR1S0xSSFZScDdkZG9EMEJqSklXcWNDRmRXVk13amp3UHdXUWU2azB6UEFUK2F6'
    b'UkZSb3VGMGVKUgpRRU9MSmsrMWM0cFJZcHFCbUdaSWJ1WTJtQkJFRWRIaUFKT0Y0Y2l3UEVa'
    b'SmtBd0lOaWZZbkorNUhoN09EejNjeG1BZFhXQWRYV0JkCllCMmdxT05EMGsvdC9Yd09uNXln'
    b'NHVRcmpHNTdUM2V5VUZYbW03M2tPVTI4MUowS1o4RVVuWFNxbmw4VXYwVitWb1JiOS9aeWJN'
    b'UVYKLzdmN2d0MjhrUDV6dWhRVHBsU1ZlcitINDF6NTlSVTRQZVRsb1l1S3VYcitkd0NZdG1V'
    b'SFA5cmFSc2prK21xdFYydmhJMjhPbmUzWgpQRkgyUjY3eFgvNTMxME5yY29Mek90ZFFMTFR4'
    b'UVA4L1VUVGpjcjVodUk2WDNROThEUzFZMDhpTmRQRFA1MmF6OU9vYnNWZytqVVVYClhEU2JN'
    b'Y1hOL0dUVlJuYXBJNzZ5UmVZbmN4ZHdrZ1ZJc1VIdWQxVmhQbEpQbHRwTnEyc0NwSHcyaDVu'
    b'Wi9TZm1odC9qb1ZzTzRUMlIKaXZoeGtLb3FCVnVSQU5wWFUvOHptK2hRRmV5RFhzWTdZWEsy'
    b'bmN1bVRlVGNDZVgvOExhdHUvYnc2TVpESERka2Z5VkNxMEVmZ3MzRgptNTdiZWJtNmtKOWQw'
    b'c0RNQTQ4aXUzS1Nqa3pZejZPV2gzR3BFZVl0UE1XZk5tUXpjWElmM2xZbmorODdseTJlcGFo'
    b'Mjk5ZkFna1dKCkRDbk9EeTQrajFrenp2OC8zelozNXZsY09IMHFIMnpleHBxYVpuYUdYY2lH'
    b'TTVkR25OYTNpU2ZLTnRIWVllUG1jVzJrRnZzeGZSeEIKQm03dGY0enBHUzFjTUxzWFZSR28y'
    b'WkxCbERuZHZQN0hmSGFGeXZpb1lNVlh1c1hscTBsVnlqRVdtTDM4ZE5uVkZPVG4vNzl2Nyty'
    b'dQpadTJHYlh6WTVLZE9kaUdidnVROUpKckdPczhLeGszdG91cURMQzVZN0dYeG8xZnh6Slhi'
    b'NlBYYU9QY1NMKzBmWjVCWkdpQVJsRmkyClpnRnRhWlBwOTVUelZmT1Y1cUtsVUI4M2pJaHo1'
    b'OUpyOEhnKzM2RW00WENFdmZzUHNMdStrWnBUQVZyalpycEVCNWhPN3pjWjh0cTIKc3UyT3A2'
    b'bmZua0haekI0cTN5cm12RG1uTUZsbEtqZGxVakhGejVOdmw3Rlptb3MzOSt6WjFuSldURGFZ'
    b'd2o2V1pNYTRiY21DejJYUgpmMDAwR3FXcHVZWEc5bE4wK3Z3RVl6TEJtRXdnRW1jd2xpQVlr'
    b'eEVrQXhaVGNxTzRsb2ppY3RoQWptTXpHWERicmFRN3JhUTdIYmhUCkhLU251VWh4T0lodkg0'
    b'ODdONEttQ2d5Mk8wQlY2ZkJMU0NKYzAvSHZ5ZFBpejdJZGgyZlZiSklZQ1REWDFzK05zeVl3'
    b'ZDlaTVJQSHMKeXNPODllZ2NybGkwZzRadFdaUk03K1g5ZFFYY1AzZ0hJZmZadTZUbnJFcDBx'
    b'RllubXpVbm03Zjd5WDcvZWE0b2NyQm8xaFFtbEk4LwpLK29YTkkxRE1PMGdHZ1hpVUpnVElk'
    b'UmRkRlpuNGM3NitXQk5qcE1iT2NXRkk4eGNQR0VVTTZhZGg4Tis1amJtSGo5K2d1M1ZCNmhz'
    b'CjZLSzd1WmEzYnYwOWI3MlZnMktRc05rRjNqbFd3TmJSZHlXM1N1Z0NuNFlLQjMyTUV2MU16'
    b'ckl6b1NDRHNTV0ZuRE42TkhiN0YzT3EKWkZtbXVhV0ZZdzFOSEc3MWNxQ2puOXFnU01DZWcy'
    b'Qk1McHF2Nkh5YkZYa2IrVVB6Skw0L3NackZmYjhHVlFFRVhlQXZNNFRSZ2o0OApoTWcxYStU'
    b'WURYanNKcHhtQXlsV013NnI1Uk1Sa25INFlDaE1WRllaaU1ib0RjWHBHb3pURlJmcFNCaFJV'
    b'akwrN3JIOTJVMmI2UGFjCmkybXdoNjNUbnVTQ0UvK0JZajY3ditVdzlCYzNDQUtDMDRNUER6'
    b'N2dvQXdNL0UxQTloZC8vOVYza1V5Zi9DVHQ4Ty9pTFo2ZjlOSWQKSHJvQ0VwY052SVpIN0dW'
    b'WFloSU5PUXZPeXViUnB3cy81MHQxYi8xQ2ZsS3htOHV5VzJsVmNuVUxIbTRjRzNFbGkvZWxZ'
    b'Wk1EeFBQSwpkWUdISTEwNU04LzZPdXBkOURCSEYxZ1hXRWNYV0VjWFdFY1hXRWNYV0VjWFdP'
    b'Y3pHQVFJNnMwd2ZQa2ZGV0d2YmpYMnRjd0FBQUFsCmRFVllkR1JoZEdVNlkzSmxZWFJsQURJ'
    b'd01qTXRNRFF0TWpoVU1EVTZOREE2TkRnck1EQTZNREJoOEVuVUFBQUFKWFJGV0hSa1lYUmwK'
    b'T20xdlpHbG1lUUF5TURJekxUQTBMVEk0VkRBMU9qUXdPalE0S3pBd09qQXdFSzN4YUFBQUFB'
    b'QkpSVTVFcmtKZ2dnPT0KIiBpZD0iaW1hZ2U2MjUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'RU_AST')

RU_AST = b64_RU_AST
index.append("RU_AST")
index.append("Russia Astrakhanskaya oblast")
catalog["RU_AST"] = RU_AST
catalog["Russia Astrakhanskaya oblast"] = RU_AST
country["Russia Astrakhanskaya oblast"] = ('RU_AST', '', 1)
lookup["RU_AST"] = ('RU_AST', '', 'Russia Astrakhanskaya oblast', 1)
lookup["Astrakhan"] = ('RU_AST', '', 'Russia Astrakhanskaya oblast', 1)
lookup["Russia Astrakhanskaya oblast"] = ('RU_AST', '', 'Russia Astrakhanskaya oblast', 1)
details["RU_AST"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+04:00","altname":"Astrakhan"}
regional["RU_AST"] = ('RU_AST', 'Russia Astrakhanskaya oblast', 1)
regional["Russia Astrakhanskaya oblast"] = ('RU_AST', 'Russia Astrakhanskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_BA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iOTAw'
    b'IiBoZWlnaHQ9IjYwMCIgdmVyc2lvbj0iMS4xIiB2aWV3Qm94PSIwIDAgOTAwIDYwMCIgeG1s'
    b'bnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KIDxwYXRoIGQ9Im0wIDMwMGg5MDB2'
    b'MzAwaC05MDB6IiBmaWxsPSIjMDA3MDAwIiBzdHJva2Utd2lkdGg9IjIuNDQ5NSIvPgogPHBh'
    b'dGggZD0ibTAgMGg5MDB2MzAwaC05MDB6IiBmaWxsPSIjMDA3MGZmIiBzdHJva2Utd2lkdGg9'
    b'IjIuNDQ5NSIvPgogPHBhdGggZD0ibTAgMjAwaDkwMHYyMDBoLTkwMHoiIGZpbGw9IiNmZmYi'
    b'IHN0cm9rZS13aWR0aD0iMiIvPgogPGNpcmNsZSBjeD0iNDUwIiBjeT0iMzAwIiByPSI3NSIg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjZmZkNzAwIiBzdHJva2Utd2lkdGg9IjEwIi8+CiA8Y2ly'
    b'Y2xlIGN4PSI0NTAiIGN5PSIzMDAiIHI9IjE2IiBmaWxsPSIjZmZkNzAwIiBzdHJva2Utd2lk'
    b'dGg9IjIiLz4KIDxnIHRyYW5zZm9ybT0ibWF0cml4KDIsMCwwLDIsNDUwLDMwMCkiPgogIDxw'
    b'YXRoIGQ9Im0wIDBoMjUiIHN0cm9rZT0iI2ZmZDcwMCIgc3Ryb2tlLXdpZHRoPSIyIi8+CiAg'
    b'PGNpcmNsZSBjeD0iMjUiIHI9IjUiIGZpbGw9IiNmZmQ3MDAiLz4KIDwvZz4KIDxnIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDEuNzMyMSAtMSAxIDEuNzMyMSA0NTAgMzAwKSI+CiAgPHBhdGggZD0i'
    b'bTAgMGgyNSIgc3Ryb2tlPSIjZmZkNzAwIiBzdHJva2Utd2lkdGg9IjIiLz4KICA8Y2lyY2xl'
    b'IGN4PSIyNSIgcj0iNSIgZmlsbD0iI2ZmZDcwMCIvPgogPC9nPgogPGcgdHJhbnNmb3JtPSJt'
    b'YXRyaXgoMSAtMS43MzIxIDEuNzMyMSAxIDQ1MCAzMDApIj4KICA8cGF0aCBkPSJtMCAwaDI1'
    b'IiBzdHJva2U9IiNmZmQ3MDAiIHN0cm9rZS13aWR0aD0iMiIvPgogIDxjaXJjbGUgY3g9IjI1'
    b'IiByPSI1IiBmaWxsPSIjZmZkNzAwIi8+CiA8L2c+CiA8ZyB0cmFuc2Zvcm09Im1hdHJpeCgw'
    b'LC0yLDIsMCw0NTAsMzAwKSI+CiAgPHBhdGggZD0ibTAgMGgyNSIgc3Ryb2tlPSIjZmZkNzAw'
    b'IiBzdHJva2Utd2lkdGg9IjIiLz4KICA8Y2lyY2xlIGN4PSIyNSIgcj0iNSIgZmlsbD0iI2Zm'
    b'ZDcwMCIvPgogPC9nPgogPGcgdHJhbnNmb3JtPSJtYXRyaXgoLTEgLTEuNzMyMSAxLjczMjEg'
    b'LTEgNDUwIDMwMCkiPgogIDxwYXRoIGQ9Im0wIDBoMjUiIHN0cm9rZT0iI2ZmZDcwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIyIi8+CiAgPGNpcmNsZSBjeD0iMjUiIHI9IjUiIGZpbGw9IiNmZmQ3MDAi'
    b'Lz4KIDwvZz4KIDxnIHRyYW5zZm9ybT0ibWF0cml4KC0xLjczMjEgLTEgMSAtMS43MzIxIDQ1'
    b'MCAzMDApIj4KICA8cGF0aCBkPSJtMCAwaDI1IiBzdHJva2U9IiNmZmQ3MDAiIHN0cm9rZS13'
    b'aWR0aD0iMiIvPgogIDxjaXJjbGUgY3g9IjI1IiByPSI1IiBmaWxsPSIjZmZkNzAwIi8+CiA8'
    b'L2c+CiA8ZyB0cmFuc2Zvcm09Im1hdHJpeCgtMiwwLDAsLTIsNDUwLDMwMCkiPgogIDxwYXRo'
    b'IGQ9Im0wIDBoMjUiIHN0cm9rZT0iI2ZmZDcwMCIgc3Ryb2tlLXdpZHRoPSIyIi8+CiAgPGNp'
    b'cmNsZSBjeD0iMjUiIHI9IjUiIGZpbGw9IiNmZmQ3MDAiLz4KIDwvZz4KIDxwYXRoIGQ9Im00'
    b'NTAgMzAwdjUwIiBzdHJva2U9IiNmZmQ3MDAiIHN0cm9rZS13aWR0aD0iNCIvPgo8L3N2Zz4K', 'RU_BA')

RU_BA = b64_RU_BA
index.append("RU_BA")
index.append("Russia Bashkortostan Respublika")
catalog["RU_BA"] = RU_BA
catalog["Russia Bashkortostan Respublika"] = RU_BA
country["Russia Bashkortostan Respublika"] = ('RU_BA', '', 1)
lookup["RU_BA"] = ('RU_BA', '', 'Russia Bashkortostan Respublika', 1)
lookup["Bashkortostan"] = ('RU_BA', '', 'Russia Bashkortostan Respublika', 1)
lookup["Russia Bashkortostan Respublika"] = ('RU_BA', '', 'Russia Bashkortostan Respublika', 1)
details["RU_BA"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Bashkortostan"}
regional["RU_BA"] = ('RU_BA', 'Russia Bashkortostan Respublika', 1)
regional["Russia Bashkortostan Respublika"] = ('RU_BA', 'Russia Bashkortostan Respublika', 1)
#----------------------------------------------------------------------
b64_RU_BEL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc0OTY3IgogICB3aWR0aD0i'
    b'MTQ5IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE0OSAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQmVsZ29yb2RfT2JsYXN0LnN2Zy5wbmciCiAgIHhtbG5z'
    b'Omlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBl'
    b'IgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9E'
    b'VEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8x'
    b'OTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHht'
    b'bG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9'
    b'ImRlZnM0OTcxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3'
    b'NDk2OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9'
    b'IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'Y2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXll'
    b'ciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc0OTczIj4KICAgIDxp'
    b'bWFnZQogICAgICAgd2lkdGg9IjE0OSIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJl'
    b'c2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6'
    b'b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFz'
    b'ZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKVUFBQUJrQ0FZQUFBQ1BiSEx6QUFBQUJH'
    b'ZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRB'
    b'QUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBSQpqVWxF'
    b'UVZSNDJ1MmRlV3lUOXhuSFA2LzkrbmJzK01JSmNVZ0laOFRWVzFBRUk1U0ZIcUswcFR2YUxw'
    b'TTJZRjJQVFZxclRtdlZTWjI2CnFkcllhTHQxYmNjWTEzcEF6eFcxRXlDT0FVMDRDalJEUUJQ'
    b'SVZSSVR4NEhZT1p6WWZtMi8rOE5zYkJPcUdrYXJpVHdmeWY5WStjblcKOC8zbzl6eS9OKzhy'
    b'SzdxdTZ3Z0FyUG53dEw1MGZmM3c2ekdwVm1IMEo0cFVNSThxSmJpQURncjUxL0JYQ3YvQ0lD'
    b'VVFSQ3BoWkxXLwpneC9YczJ6ejN6SGFDNzZVTDErV09NTmZubnBZVXJ6U1p5cGo1U3hVbC9m'
    b'Q3RKSE5vQmkvbU5ITjJYRkFFaHlKN1MvWmZvcWUzZS8rCmp4TjBqdGplemVpWnRDUW1wei9R'
    b'ZXJxSTdkMU1Zc3M2Q201Y2hIbktUTXlCRW5McEpHWmZjVjY4eGtNWTJ6OGg2U3FpNElhdmtv'
    b'bWYKUll0M2srbzZqUm8rU2VUZ1RoeFhmZVhTRG1iQ2xTZVZZK0pWUk45ZlMvTHNHZHpiMTVM'
    b'YXVocXJ4MFBTWUdXdzZqNzhwazZtblBnbApXM2ZhY0gzalVkTHZucUovKyt2NHpSRHdlRkFV'
    b'aGM2aFFTekJVaFRWSklsSit3T2pzeER2bk52Um5WNDhYaDlsWldVVU9CejR6ZEQzCndaL3cy'
    b'Sk1rTEtVRUFnRzBsbVBFM3Y0ZEZYNFhQcCtQMHRKU29yRmVGTjlvSEpPdmxiUkVxZ3ZZSjh6'
    b'QU5uWXFBK2tNaXFLUVRDYUoKeCtPNDdueUlOc2NDNnZkbE1SZ01XTnFQWXl5ZlJsOWZIME5E'
    b'UXpTM3R0R2pGbEE0NnhZc3hlV1Nsa2gxQVd0b1BJRzdIcUF0UGtnawpFa0ZWVlhSZFJ6MjZt'
    b'OGlHWi9DNVhiamRiclNCWGt3OUhkaHNObEtwRksyZFhWaW56OEUzN3k1SlNxUzZ1Rmpqbjk1'
    b'RWQzQXlHWGNRCnU5Mk8zckFQWjdTSlZDcEZLcFVpbzZVeFpaSVlqVVp5Z1RMc3MrL0FmMHNO'
    b'aXNrc1NjbWdmbkZNM2lCakhudVpySjRqc2ZzdEJuZSsKU2M2WlJZdWZJWmZMa1hZWFlhdW81'
    b'TnpZNmJqbkxjSHhiOWU3QkpIcXMxRU1PT1o5SGNYbHg3M3RaUm83QnNsb0dxTUNQclNTQ2Zo'
    b'dgpYeTdKU1B1N0JHci9nQlp0SVZqVVJpNVVTZHJpeEJFMEVIS0VVWGI4V3BJUnFZYUhuczFR'
    b'V1A4U29jaGJIRmVyS2MvRzhKRENNR1VCCjV2QitCbG9hSkJscGY4UHNma2FWeUhWUG92YWN3'
    b'bkN5blZDb0JMdmR4cWY3UGtKZFhJUEZXeW5KaUZURHgzTDluWkRMb1pqZTRHalQKVVpSZ0Vk'
    b'WlJwZWd6bDhtZGd5TFZwYzdxUmpBWWNTNjREK2ROOTVEVDBoak1Wa2xFWnFyTGR4b1VvV1Nu'
    b'dXJRQlhVc3pkR3dQaFEwYgpDRHA2Mk44WVpOTGNxY1RHM28xcFZLbWtJVklOMXlpZDFGOVg4'
    b'R0RvT2I3OUJMeS9BNWJOQW5mQlpsNThkUVcxNmpJS0Z6MkV5UnU4CjZISXQxbzNKRTVERXBQ'
    b'MWRJSDMyRFBPdHIzUGRERml6Q1hRZFNrZkQ1UEd3WUphRzZjaDZER1lMQU02Vzk3aDYyeHlz'
    b'cTZ0SjcxbEwKdWp0TTVKVm4wR0pSU1V5a3lwT0pkVEZ4VHcxMWYwc1RLb2FLTWREWkJYWWJk'
    b'RWFob3hPV0xCaWtmOE1qb09lWTFmRUVoMlovUVBmTQpuN0hjL21OK25yMktpZkdOS0lvOHB5'
    b'SHREOUNpN2Z3MGV5TVZkeWNwZWhDS1I0RzdBSHJpb0dtd2VSdU1LNGRNQmpiVmh3R0Z4RUFH'
    b'CjY0bE5HSzc5THJ1M3pLYitjQkdHMjc2SnE5QXZpWTMwblNvWmJrYnJpYkJ0dDRIblZrUDNP'
    b'WWoxd29jZlFhRUxISGFvbmd2WkxKdzQKQ2VNTVIramZzWjd0b1ZVRVQ2N0Y4K0kxWlB0anpL'
    b'eG9aMDV1TlphanI2RnJjcC82aU42cGdtLy9ubEEwVEZOdkJkR1dZN1RkQ2sxdAo0SFNBeFFM'
    b'OUNYQzc0SU1kNFBmbUJkdTQ1M21NVHh5bVkzb2RBSEVnT3hBbkcyMWxjdGNxdkZ1ZVlXL0pD'
    b'bXpYM0N6cGpVU3BZc3VmCnB1dGNKOHU3cTJnSUYvR1QycnY1emJ3WE9OYVFiNE50cDZHM0gr'
    b'NjlBL1lmZ1d1bXdmR1RIWFMrZVJlOWxna2tvbEZtZWc0eXRieVgKOXlKMzByendlWnJqWWE3'
    b'ZXRaajZRSVU4QnpFU3BUTFlIRmhENDZtcnI2U3g1RUdjK2hDeGVINlhtbFlKei80UlBHNElK'
    b'U0NYZzcwSApvVDBNRmtzdGo5ZlUwajhBOXl3R1ZZVWxaOTdnbmw4ME1QU2Q5K21hZUQvYS9v'
    b'MHdhNkVrT0ZKUGZ3MnpYMFdaV0lXeWN5WGhDQ1FTCnNQNU5tRkFPaTZ0aDMyR0lub1A5aDBF'
    b'eHdQM2Znc0ZCcUZtU0Y2citlUDd5dzVwSGo5S3o3akhDUThYNFRGMlMza2lXeXVRSmtJbWYK'
    b'UlZVVnR1MkJobVpZY2lzVUZNRDZ0OERuZ2I1K21GQUJWblArWk9qelF1cjhUSzVsNExkcllG'
    b'Y2RQSEx0RzlTWUhxZXZiSkdrTjZMYQpuNVpDUGJTT20wMHZVK0hxb0tzYkhEWVl2QUhLUW5E'
    b'Z0NHemZDOGxVZnA1NjZjLzVYYW5sVTdqaDZ2emZybHdGcTE2QmtpSVlPd2ErClg1UGZzWGJW'
    b'd1VGOUx0YXFtMEVlZXg4NVVybHFYNkRhK0NzK2JpemduTk5DVWJGS0xwZmxrN0NaOXQ0Y05u'
    b'V0Eya1BnZGhreHFWa3EKeDhIYlcxVW1qZFh4WkxONDNQRGtEL096MTZuV3ZFd3JWaG1aVko1'
    b'bGRkdlg4TjYzVW1iMGtTS1ZydXQwTjc1THR5UEN5ZGhOZEZRWgp3S2hBRG5DYW9DeUh0YTZk'
    b'RW4yQXJ2RldUQzRUbXlZVlEwc2NadHBSbzBrTURTblNXZ0dvQm13bkloUWxla21mVFJPckdN'
    b'VmdkalRjCmt1QjA2d000NHNVWTRtN2dOa254U3BZcXErY0llM2VBeHdwYzVGWVdvNEhrbkRL'
    b'YS8vdjlhZmwvRkdlQ2p2OTRlNmhvSEswWCt4dy8KOVBrNzZXeEtTb0pYK3FBK2FXdzVhdnpM'
    b'Ky9JQmkwc1N2TkozS3AvWHg3UFgvWUIzR2c2VHpHbWZhMDFmY29BVHZpYk1jWlVaeGtxTQpC'
    b'dVBuRTBxMThlTFM3MG1DSTJGUWYzamhJaDVlT0x6amZ0VlRQK0xlRytlenZGb3VFNGhVbDRr'
    b'TlN4K2h0RlR1L0pTWjZqSWlRb2xVCmd2RFo3ZSsxQXgxU2hmUHNiNGxkMnNLK1VXRFVwSURu'
    b'VVZqMm52eGNnU0R0VHhDcEJKRktFRVFxUWFRU1JDcEJFS2tFa1VvUXFRUkIKcEJKRUtrR2tF'
    b'Z1NSU3ZqaVViWk1tUzkzS1p4blMzQXF6MVhjTlB5RlI5K0JObm13OVorbzE4ZGJwUXJuYVN3'
    b'SVh0ckN2Z2hFNVZjcQpwUDBKSXBVZ1Vna2lsU0NJVklKSUpZaFVnaUJTQ1NLVklGSUpna2ds'
    b'aUZTQ1NDVUlJcFVnVWdraWxTQ0lWSUpJSlloVWdrZ2xKUkJFCktrR2tFa1FxUVJDcEJKRktF'
    b'S2tFUWFRU1JDcEJwQklFa1VvUXFRU1JTaEJFS2tHa0VrUXFRUkNwQkpGS0VLa0VrVW9RUkNy'
    b'aC94VzEKdytiUnBBeDVCb3lXQk5BejdJVW1xeGVuM3lFVnpQTVBOam5UWExqbFlBQUFBQUFs'
    b'ZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpNdApNRFV0TURGVU1UTTZNVGs2TkRjck1EQTZN'
    b'REQ1dFo1ZkFBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl6TFRBMUxUQXhWREV6Ck9q'
    b'RTVPalEzS3pBd09qQXdpT2dtNHdBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9Imlt'
    b'YWdlNDk3NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_BEL')

RU_BEL = b64_RU_BEL
index.append("RU_BEL")
index.append("Russia Belgorodskaya oblast")
catalog["RU_BEL"] = RU_BEL
catalog["Russia Belgorodskaya oblast"] = RU_BEL
country["Russia Belgorodskaya oblast"] = ('RU_BEL', '', 1)
lookup["RU_BEL"] = ('RU_BEL', '', 'Russia Belgorodskaya oblast', 1)
lookup["Belgorod"] = ('RU_BEL', '', 'Russia Belgorodskaya oblast', 1)
lookup["Russia Belgorodskaya oblast"] = ('RU_BEL', '', 'Russia Belgorodskaya oblast', 1)
details["RU_BEL"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Belgorod"}
regional["RU_BEL"] = ('RU_BEL', 'Russia Belgorodskaya oblast', 1)
regional["Russia Belgorodskaya oblast"] = ('RU_BEL', 'Russia Belgorodskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_BRY = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc2NDciIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODAiIHZpZXdCb3g9IjAgMCAxMjAgODAiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'QnJ5YW5za19PYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5r'
    b'c2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8v'
    b'c29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxp'
    b'bms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnMgaWQ9ImRlZnM2NTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFt'
    b'ZWR2aWV3NjQ5IiBwYWdlY29sb3I9IiNmZmZmZmYiIGJvcmRlcmNvbG9yPSIjNjY2NjY2IiBi'
    b'b3JkZXJvcGFjaXR5PSIxLjAiIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiIGlua3NjYXBlOnBh'
    b'Z2VvcGFjaXR5PSIwLjAiIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcg'
    b'aW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIgaW5rc2NhcGU6bGFiZWw9IkltYWdlIiBpZD0i'
    b'ZzY1MyI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2VydmVBc3Bl'
    b'Y3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHki'
    b'IHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1Vo'
    b'RVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpT'
    b'RkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFB'
    b'QUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVUKUVVsRVFWUjQydTJjZVhRY3haM0hxN3E2ZTdw'
    b'bnV1ZldYTHB2MmJJbDJiSXR5NWFOTVJnVFFpQUo3Qm9DSVpDWGtDd2g1MjRDbStXUgpsK1B0'
    b'c3RtWFpQZHRRcTYzWVNFSmhHVkRTSmFFSTR0dGhHd3dQbVRkNTBpYWtUU0haalQzMFdmVi9v'
    b'SEJKaGliUDVMeEl1YjM1ZzkxCnE2cW02ek8vL3ZYdjk1MmFnajl2MlE3SzlwYzNxb3lnRExv'
    b'TXVteGwwR1hRWmRCbEs0TXVneTViR1hRWmRCbDAyY3FnMTVEUjc3THIKWldpOTJvdWE2cWk2'
    b'S24xb0FoNGZBcGk4S3k0Y3ZrdlZPeWp3OUoyM0VBT3JQdmdJVE9mS29lTXZaU1JYVlA3MVp4'
    b'U0IzSmYvQmpEdgpndnNTZmRoUjllNXhZNGgzZFlQTkcwQmpMZVpZS2hyWEptZkY2L2RMbWdx'
    b'bTU4c3grczkwNnprMThlNmRWUFZmVXdnVlU2bjh0MzhJCkFJRHhwTFFjNW5ac2taNCtXQTRk'
    b'Zng3VGQ3M3ZET1YwS3YvdEg4SlE5TXo1MVJSanRSQUl5NkF2aUs5ZTBoc2t4ODNoaTBUay9Y'
    b'MzIKYTYrbUVKSXlxMjNNWnpuejNObi9zUXdBRUZKdk94SEh6V0c5UWRMcnBmY3FhQWlVblJu'
    b'U25mUGRHR3JvaVJPR1lJQjFLSisvOFN1bgpDOUdWUWlLWi9jNlBsVVJzMTFjbnVlNDBBQURR'
    b'eUZEdFV6TVpvT3R2K21BZ1dEUnBCVVFBaXh0NzRyNGJRMlJMVHQyWmZpOCtESWxUCkJWdXk3'
    b'c3BDVTFNbXUyS0lIN2EyT0JmWGIweklTalpiTkVQd3BsQUFaVVU3T2F5K09rZ3R4VmFPMlMz'
    b'YlV1djNSYUlKWHEyL1F0aTIKT2ZmaXkyQjg1bzNHUlJyL3d4WEpJMXR5SVh1K1BtVHlkbWQ4'
    b'TlhsSm8vSU1CQ0VPRnFuM0NtaGhmNXppc1ZTaE9acHpvcWk2WE1XeAp4eXVOeWtwZG5hb05z'
    b'ZTVtTlpWVkZVVjhuVEVCQUFJQW9LVEFYQUVBQUZRWU9XWjM5S2JhZHE4a0JGZFJhVlYrOUF1'
    b'TmFJaWMrV3grCjBKM0oxTXJkRVh5b2dSbzBLWjFUWW5OUElwdGpLQXJrODdUSnJuSmRHY1Z2'
    b'WE9PZ3NhQkw3WVg5bjVvSjV3Mll3S2JHREFSZzVoZTIKY0w0WVQ4TDZObDBlWml2V0Y1ZWlK'
    b'Z0tBMGJhMG9YcVZNdVhvUFpKUzEwaTg2OEJTQkFCQUJFZk0vU0dIN1VSTDFkankwV1AzaTlK'
    b'Lwo3czZPY0dwSG5Ga1d5Qk9YWmZZdTRxZWJrREJONHh4azQ0WTlPMWVOdkI0T0d6bW5zdWRq'
    b'ODhOekZyaklRWVZhMHg3TkVucFREa0t3CnNTT1pUSEtWMWJsalgvTnRObVp5R1NxR29aR0dW'
    b'b0ZRQ1lyMVpPZHkyUXFUNWpNQTNBYmFidzRYTXFsc3FnUHM2ME1mdUpLOW9nL3kKRmNGWGFI'
    b'ZjFSR3RIM0lOUk5JU1NHdWdYMVlITzRyYU0ybDlOaVJHYVRpQmd4Y2hiL04xaDEwMjc0c2tV'
    b'dDNWN2JDRWdwUE1zR1JPZwpBdGN5YUNMb3NsZXpPMlc3UTBJVUNRMWJaMS9DTlhXNk5VMGxG'
    b'VmMyYmZNMkpFbUl0bnAxem9Ubnc2eTJtK3I4YUhUK1JadnpKY0ttCnhzand5Y0x2VHl3Y2Vm'
    b'R3B4Zjk5ekJCWWpQSjlOZm1OalpuaWt2bmtBaCtwVlYyOGhpRUlzK2krWjJ6cjBveGFtWCsx'
    b'QXVJUWZSbWkKWExWNXMxbUpyUmdqUVlGYVpHRVJyV1hRVUVLZ3JRQVk0dkVVc2xsR1Y1R1d0'
    b'TXhQNjVwZzBmTm1DRkF5aTZ2V0Y3UWduWU9va0hOagpaRWdXbWRYZkdVUk9yVERydnZxaXR6'
    b'TDk5VmFjY3NzV3BCK2pZVzdLMGlqbzhxR0toa2toNUpJY1JEL3BwdllkRTNZdGMyNEpKVEhL'
    b'ClpNRWRHRFcwNXBCUjUzbmRQMmVXMHd3YUZOZStxSVFkbXZtbWNGVmxmbW5aVkZlYjVSbjls'
    b'WCt1SmRhek5hb0JGQVJlWFMxYTNuUXIKQUFLZ1NsTTZMOHJQV2psM0dna0s1U2hTTEliblpu'
    b'WERMdG1vb0tZay9jYlpVUWw4OGd2K29vSUNRYkd5TXIrMFpNbzg1cUVTek5vdgp3YUVDVXdO'
    b'Mnl6V0twbEZMSWRQbVRYRkhsK3pjRWZGNENxcDJidHhjZWJzUk90OSs4TDV6L21ab0Vvbnlq'
    b'aU1PMGFyTURqbzFGV1l5ClRHckFqbFJVK2xsZkF0RGRYNXZNUlEwenMyYXpSOUkxbUV3YXhJ'
    b'WThoZkJ2ZnIzNTRITmJMOXJkSkJRWVJrc2x6UmR0dWZlcTQzMlgKalF0MWhXVEtvT21RTmVE'
    b'd3JIbjlWV0hCTFovNnUvWTFDNXB0endFSUVJdURBdzdIMWxUaGo2elNSWnVhcEZUU2dBa0VB'
    b'R2dxbmN1WQpManJPL211UENvTDg4RSt1dldoTFJhVUJBSVNBVk5JZ1MzUnFqaDllTUxSMHJR'
    b'YjduZnltcks1Qm9rTjEzRlNhNlpjdWx5eEN1UDdqCmdjdS9NaWsyRlJZR0toaUZ6eDNOWm84'
    b'Z1NVSTJiL0VkRG1LMXA2NitadlR5SzZaYzN0Zzc3R0p4UzVLRVhwd3dQaENIOVVrbWNNUXAK'
    b'TnVjdnYyZGkzZTBCcVlSU1ZPbEFZNHQyL0VSRkpzTTJkeVcyZlNqWTlzVWdwMXZaNWJ4Mm1J'
    b'NU5tZC9KQ0FqcHQzL3FHYmU3YUxmTApkOXo1RE1PcTc2VFg2b3o0M1VIekkxQy9mSVhiZWRm'
    b'QzFnOHVObTlLcE5Qc2laTVYyS0t0UWRCb2xrYzBIaDZ4cnlZTUhLKzNkaVI5Ckh5aTZuYkEy'
    b'b2tXZnNWejhFVXFSRzI5OS9yTGRnZGNPZTNjczMvcUozMU1Vdm1qSFUvMzJnRkhuT1BqQjdl'
    b'bldqaVRINjZzSnc4aW8KSFNHQy9Od2FqTkV3aDlTWUlRWEF3b0tJS0dJMnE2N0toQ09IMUVP'
    b'Y3V6Sng0YjRHZy9LeE81KysrbjNUaUQ1RGxxTElkZGRObU1YaQpUMzl3ZlNGM0llSGlpZWFp'
    b'UThFVDFXcldtNVpsbE1rd0N3dGlLczJxY1liTm9UWG8wVENQMEJTdnlDaTZ3bytNMkNOQkRy'
    b'eks0SEVHCjJiSFJlSkVnNEt1T2J1a0p4dUo4OGZWeVRwYlJ5b3B4WTBla3B1NGlXbmJLcUhN'
    b'YWdReTVhOXdlV09aSFJ1elJGVjZSRVQzSncveGEKQkEwQVFITWMyMjhoR0JJQ0F6OFZYUVRv'
    b'RWNRMnFiSElSYlMwK2RucXV6OSsxejFmL0Znb2ZDWkppSzd3OTMzNTFydnUrTXprYU9PRgor'
    b'OWF2c1AzVmFQODhTYnYwVHovcklRUVNESmwrQzVyblN6bjNVb3V6VkppbG43SG5Ebk9kVFVW'
    b'cGlLVnI5SlFDTXdYbnhUdFM1RE5mCitHMWpRK2ExdzVycTNOMS8reFJpTGg2amI1d3drVHlj'
    b'c3NHT0dCNXFVbzhNbWRBemRoUm1TejN4UzFBWkp1bG1OcVZQTThpRVlhTTYKUEZnSkwzWVpG'
    b'bHY2Sy9jL1d1R1c1K2FkYjd3c1Z2M2VyLzNTV1hHUitDNm84SzRYclBOR2FKZUpVeUdQMlRD'
    b'VnZBUmxXcW5mMHZsWApZUzNHVmtCTm0rTFlyZktKb3k3ZGgyeTlGMHFLdTN2R1B2WFpQNlpU'
    b'M3N3M0ZGWTk2OElxQlEzM2lOLzV3VU9QUExUejRMTTloSncvCktSYXZpM1c5WWpuUWIvN1ZG'
    b'WmxyNXZHekhrM2N1OG81bE5nVDNyVU0ybFpkcVAxQWFPSWVSLzE2WlNMQUZId2M3a25iM2Zu'
    b'ek52YjYKVm03LzlIUGJ0aTRqR3FkVHdGalFoSE5DaFFTSkRJRE5KdC85K1VOOXV5Y2Yrc2xW'
    b'd1huZmVXb2NYejZ4Ryt3N0xqNi9RSy95Y24wTQpiYjk5Zm1IUUhsdkxvUU9TNllkckR6NVdH'
    b'eUIyN05CblkxRHZ5RHFka3RHcW5MZnh0VGYyKzN5cFRKYkJyMHQwT2dVWDY5LzBFTU1FClpq'
    b'SnNoU3R6N1lkZm9xanpyTU16V1RXblU1STZjM1NDT20ybmIvRWJYbmlzZnViaEdnREptdlZv'
    b'WXNhdFgvU2JCV1ZZOGMwdGM2ekkKUVI3WWJMS2NaNURsTFJrZWdmL3gvUnNNbk5TeWJxNjFm'
    b'WEhUNW93T3NjelI2bFcreWRsMDQ4RzRUQUdNNFdPUGRzMU8ra2FIV2xXWgp4Zmc4MFVQS0la'
    b'dE5qc2U1YmczNTU4RDZPcm5qcW5CbVozenFYNXBnZW8ybWR3Q1Q4WEVieSt2N1B1bFgxeG1R'
    b'anhFRlZkZGhkdkg4Cm1SYkdzRmpnRithcTNPNFVwRUNrenJMVWJDN21TTUhDVGJUYVFuVTJB'
    b'RWhqVXpRNDc1T0xITWJubjB0dTJhaXFsQ2lvbTNqeWdFZmUKOXdrL2E5VEd4MjBsWG9aYVVv'
    b'K0dlUVN5Nk5TZ2MzZGZ1T2ZBNHVuVGp2Z3E1M1JJeTlPbXR4TTNldnFHYnY3b2tkcmE3TlJV'
    b'dzAyOQpCR2c2Z1NGaWduQVRBRFFZUUlidFBhSHFxa2NmLzJYUHdLR3RtblkrRDhXZ29xSVlq'
    b'M043OThTN3VsWlZEWjRhZElJc0ttVzFVdkxRClFhQk9BVVZDUTBQTzdkdWpIbTh4dXNJVEFL'
    b'SUhuZGJPTjYxdWdaQTB0YzNkZVBOQWQzZVlaVEVBUUJUalh6SnVHSmVWRE1ZcXdBNlcKYmpZ'
    b'd29qZ0JBS2lzekgvdVM0ZDM3eDEvNGxlN3BrYWEvaVNBeEE4NXFuYkVOUTE2UEVXR3dTZFB1'
    b'UlFKNlJEUXBWMVhYVnFQSm9BZQpOVXBiOVVCUWNEaWtob2JNbk4rY1hXTEF1Wm9ESkkzTndS'
    b'c085Ry9lR2pieVo5VTFueTl6bis4b0FDQ1RaWFVkMmF4dlVsWnBHbS9aCkV0bTQ4Y254Y2Nl'
    b'di82dDNiTEJOMTE4Zk00ZkNNWU1nYUQ1ZmZuYldFZ2lJRkNUMG1CR1FrbjRMWHVxQ0JTM3cx'
    b'QnhudDh0K3YxblgKWVhWMUx2SjdocHdUTGkvYjk4cTk5eis1WlZ1SXBjOWY5WmxGNVU4b254'
    b'MmNJbTF0cTUvNzB2TlhYUFBTR3ljVkFQOTl4RnhUazlOMQpPRHRydHR0bGFwNUhDM3lKSjE1'
    b'U2p6WjlLT3ByeUMyOTdFajdUWmJHdkgvT3JNN2dEVzcxWlg4ZUFNQ2JDZ3lyRHJ5d2JTWGs4'
    b'RmJGCmQrOGRhMjFONmhvbENPcDU4ellBQUNBQXdOY3lQSVpoc045dmVlSFp6a2pZTmozUlNE'
    b'T2F5VlFBQUV4WjVUOVk0TTFwSk10bWlpWnAKdjhsQzY3N1ArME56WXVFcFYrbnU1bEorQzY1'
    b'dXlXMDZFUFM0aTFNVDFwazVzNVVwdHZnbG81OFpLM0xlZTlQTnplbVZxSEZxMHQxLwpxSDE4'
    b'dU1rb0ZPdnFsekdCdDk3eG9xWWdtMTJ5MnVUVk9GZmhsQkFpb1FqdnNNdUZBcjIwYkJZRitk'
    b'R0hkNmthV2c1NjBpbWh1UzNZCjJ6ZStzWE94dWlvMzZ6ZC82MGwzb0ZZS0FQcEhiam1iTURR'
    b'M1pGclhwU0pSZnZCWE5jeEpZWTNHYUFaUFRWcE5ScTE5WTRKQVFqME4KellCU1VwUnJReEVB'
    b'UUNQaTgrVjl2cms5bDgrdHJuS1RreFZIKzl1R1Q3Vis1ZTVQRXdJZHpxVEx1OHF3VXUvdUlV'
    b'RGc4WmZiTXhreApGYlBHNHc1STZaeEJhVjYzY09OSERuZDJMWGs4aFhQdmdORUszSmtrbzAz'
    b'NEFiL3hlMXNUN2UzSlZOSXdOV21GTEY2em9RUEdHVjJICnAwODdlbmRFd2FCZWE0TFNNUVBY'
    b'clVUODVrcWdISHloem15V0c1c1ROcXZzZEVwOWZZdDlPeGNUeWY3WkdlZlJnWlpUeDllTkRU'
    b'ZjMKOUoxSUpvd0FFZ09uekJ4ck5KdXp1Njg4c2FOdm9ya2w3ckJMYnl4QlRhWU1jMzU3T3NY'
    b'NUtwTXRFZmFQbTlTcjUvVS8xTUtUQmRnawpvY0hURGwySE1NYXNXZEFvd01rMVBOMlFIejVs'
    b'cTVGa2RaeEZGcnlxZ1V6T1hnbVNVeFBWei94MmwyakpidHcwMDlNNzJkb1c4M2dLCmRydThy'
    b'V2Q1Vzg5eVBqOFFXTEM4ZkxUNXBZTzl1a1oxYlBMZi8wOFBOZFFuYlRiNTlkd1JyTWE1MmVt'
    b'S0l3TnRwNCszcGxQbXE2OGYKOEZVbXI1OHh2dGdzVGRsSlN3Wi9NMlZlUnlFQ2dMekkwMEhE'
    b'MmhXVkZFak5jMW1icG84QlVWQ2xQTVhzbHNaZjlGSG9iSHFYVFl0SApEMjgrZW5pemdaTmIy'
    b'Z0s3OWc1djZGajJlQW9tazdxK1BiNitQZjZSVzQ4VEFvekdNNW1mcnNObzFEZ3g0WDdwY1B2'
    b'a1NGTWh6NzlGCkpxVSswVy81L3Z0VFY0VDBnQTgvZnNxeTI2RXpmcjdFcTBsTHJkN1JjWm9h'
    b'Tk5WVnBKUXgxdENwK05QVStxOHZqMzJqR1FDQTBKdUMKcGl3WlJrNjNqSnh1WVJpdHBuSHhz'
    b'ajBqSFpzV3E2cXlQSzhCQUZTVldsNFdoazlYOXgvZU1EOVRveXJNK1FwTERBQWdFTnp4dWJu'
    b'UgpVZk9oYW5UNUlqNXNJRmNPbXFna0t2SHZRRXNOdXZrejh6VnRtWlAvNkxiVGFwb0JsUWNL'
    b'RnJzV3VTNm1xVlJOL2ZtVlMxV2wvWlAxCi9zbDZpc0xiZGc1KzlmN25BQUFQZm4vM29XZTN2'
    b'NTIrOFpyVjFrYzFqYksvUCtxdHp2K2JxRzd2OStoQWI4M0NmZmVQQnljczB3ODAKcmVXQ0pm'
    b'QTc3L1M0TmU0VjVzMzBwTXJQTDFvWUJwdmJzNUVsWWR2V1FGVk42RUtTRktaeTJUTUpXVDdM'
    b'WDVoeVZVMW8yOVpnUE1wYgpOMlFaR2k4dmlMY1VZREpodW9XQjArUFd3UDk0MW5MQkl0d1dh'
    b'dTVNV3UyeXR6SWZEeGhGRTVsZkVFZEc3UnMzSk9ZRzdiazhjOSszCm52ajE0MXVHQjV0VWhY'
    b'MXJhZklueXdvTXZHUTBGZDlhUjdNR1pXUFg3QTBIVHVUeXpHckEyTnNYR1JtMXgrUGNiVnVT'
    b'dHhRcFgzWGUKS0dvT2x6UXpaTXM5NGx1TEJRdEZ0R1pKNjhwWkxVcGJXOHBta3dWUmxTWFVQ'
    b'K0NwcjgwaUNndzlVVlc3ZjZYS2x6ZndHbm1Mc293eAoxREVNaDRUT3poZ0FZSExTYm5jVUVV'
    b'WGVXalJDaWtoRmVqbGtXbmpPMVhYRE1vWmtmbDdjdFN0aTRQUmNqazRtdU1sSmF5ck4wcWNG'
    b'CmVvWURHSzRwajBaZTJYdERwRzFiZkhEUVVTalFwd2FkRlJWRnQ2dlkwSkRac1QwYUNBcDJx'
    b'MHlQNEV6WU9Bak1CVTZvZmwrVXFHangKQlNkOFEvcWhDT1ZXNnZhczZCZ1NESE5aTlA2SE9o'
    b'QmpnWDZtQWFHSWRWc0tJcEk4WWh1eHFUTUF1R0wwVmtISnBneTlPNklzcS90bgp6U3NyL0Vx'
    b'TU54blZ5c3I4cHZjSEo0NDVvMDk2dEhBcDhyd1NyZmczZFdkNkR3UWpZYU1zSXdDaEpLRkNn'
    b'WllrZWlsa3Nsdms0akVLCkRCaWFYWGxuVWZjb2lsRXVLQ0xWZGxVc01HZ1RsNVdPZGVGS2xD'
    b'WUxlakZvU3B4eVpwdzRHQlRDUDZ1ZWlETy9xY2s5WDF0OHZGb3oKTGpLTkZxM3ZJd3N2VDRz'
    b'UGNscklKa2Z0MnZNYmxZY256WGFEMm03UkJrODVVMmxETW1tQUVJaG1sVFBvRUlLMnJzU3lY'
    b'MVFDL05vSgpIZFlQUnZNMnJHSm9ZUFZjam5GVkZQVThIWjlpUFptaWo1VXRDdFJtYVVBVHBs'
    b'N0w1YW00RGxiU2pGSXBXQ1JsWTAxNjVhaEJFaUR5CjZsT0x0SlNqaFJvYnBzbURRRXNLR0hn'
    b'MWJ3R3Y4bmpDUTEwNXpGMEZ5WTlaUFd6RFJUdDI2Ymd0Z1pjRU9HdWx4Q1MxcHdpNk5kVGwK'
    b'SzlLQ3RoTGpCVUdWRmNRZ1lscWxVcjkxcjZrWWpTdFV3QkxDNmRRS1kyb3R3Q3BKR0MzV0FZ'
    b'MEVhUUFKMDZSbGRCS1FPR3FkMm5GRAptcUpJN0lRZ2pKS2xBTmZ5OVRqTFlBaEJKc1VFQnNT'
    b'RnA3d0xJaVgzSm0vWkcvTTZaVUtBSktIOVQ5Wk1WK0I3a1hUbnpqalE0YzhQClZid1U0dzY2'
    b'Y0sycU42VEluSTN5bStHNlNjTzNIQXBlNUFyVFJ1eFNRUkZCRlZLbEtzUXZ6Y1lvWFErTVI4'
    b'Y3M0WjlYUXBUdVhoK0QKTEptWjR5MEg1Tm90R1FCQktHU2NIN1YyQmRQUkpRTjNwNlNxVkNw'
    b'bFVGU0taYkROSmhlQ25BcUFwVVpLcFZoRlFReU5yVGFaUnZpMgpWNTBCbS80OUZYUnZTUHE4'
    b'QlVEQTBLamxxNmRzNDQycUo0K3ZlMFhjdVdqeTNMcmticzhNL2YzNjBrLzUwdTlBb3dPVmJa'
    b'Q2FiNHBVCnIwdFBUVnRsbWNwa1dOY3hyU3F2aC8zMGFqVzlXaVZTSm8xb0VHUVIwQkJGQ0VB'
    b'RUV3Z1JKaFlOMEVETG9aOGdyTFBLVUMzeExqUGYKclNsYUxRckw0dGFXVkhEQ2N2eS9mVktB'
    b'ZDhtWGVIdUJTNzh4Q3VSZ3pXMGh6Sk9UcHlwb0drZW5SZlF5cVROSitoaGoycWdrVWtabAp3'
    b'Zzc5UERYUEMxNkpOZWphY1RNTUdVeU5CVTRCMm9DTm11WHBJTGRreEVkYWxkNHdtWGFBeUpD'
    b'cFJxSU5nalkrYmhjZGNrVjlVVDF1Cmhkb2wzbWZpMG5zMFlUQnhxMXBiQVdRUmlyTFVLZzJ6'
    b'TkFBQUF3MEM2dHhsZWRDcGtQalpRZ2E2RkxKeTlsQ21pRVFUaTBJQkFMQloKSXpaZDk4aEEx'
    b'TkdVa1lveUpaYVEvaitDZm85WWVkKzdNdWd5NkxLVlFaZEJsMEdYRVpSQmwwR1hyUXk2RExv'
    b'TXVteGwwR3ZKL2c4MApyYzk0djdGTDdBQUFBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUFNakF5'
    b'TXkwd05DMHlPRlF4TWpveU1Eb3dPQ3N3TURvd01PMXpha01BCkFBQWxkRVZZZEdSaGRHVTZi'
    b'VzlrYVdaNUFESXdNak10TURRdE1qaFVNVEk2TWpBNk1EZ3JNREE2TURDY0x0TC9BQUFBQUVs'
    b'RlRrU3UKUW1DQwoiIGlkPSJpbWFnZTY1NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_BRY')

RU_BRY = b64_RU_BRY
index.append("RU_BRY")
index.append("Russia Bryanskaya oblast")
catalog["RU_BRY"] = RU_BRY
catalog["Russia Bryanskaya oblast"] = RU_BRY
country["Russia Bryanskaya oblast"] = ('RU_BRY', '', 1)
lookup["RU_BRY"] = ('RU_BRY', '', 'Russia Bryanskaya oblast', 1)
lookup["Bryansk"] = ('RU_BRY', '', 'Russia Bryanskaya oblast', 1)
lookup["Russia Bryanskaya oblast"] = ('RU_BRY', '', 'Russia Bryanskaya oblast', 1)
details["RU_BRY"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Bryansk"}
regional["RU_BRY"] = ('RU_BRY', 'Russia Bryanskaya oblast', 1)
regional["Russia Bryanskaya oblast"] = ('RU_BRY', 'Russia Bryanskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_BU = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iNjAwIiBoZWlnaHQ9IjMwMCI+DQo8'
    b'cmVjdCB3aWR0aD0iNjAwIiBoZWlnaHQ9IjMwMCIgZmlsbD0iI2ZmZDkwMCIvPg0KPHJlY3Qg'
    b'd2lkdGg9IjYwMCIgaGVpZ2h0PSIyMjUiIGZpbGw9IiNmZmYiLz4NCjxyZWN0IHdpZHRoPSI2'
    b'MDAiIGhlaWdodD0iMTUwIiBmaWxsPSIjMDAzOWE2Ii8+DQo8ZyBmaWxsPSIjZmZkOTAwIj4N'
    b'CjxwYXRoIGQ9Ik0xMTAuNyw4Mi41YTQwLDQwIDAgMSwwIDc4LjYsMGE0MCw0MCAwIDAsMSAt'
    b'NzguNiwwIi8+DQo8Y2lyY2xlIGN4PSIxNTAiIGN5PSI4MCIgcj0iMzAiLz4NCjxwYXRoIGQ9'
    b'Im0xNDkuNywxMGMwLjIyOTMyLDEuNjk3MDksMS4yMzY2MiwzLjA3OTQ0LDIuMjAyNTQsNC40'
    b'MjU3OCwwLjc0MTY1LDEuMzc3NzksMC43NzYwNCwzLjAwMzQ2LDAuMjk3NDYsNC40NzQyMi0w'
    b'LjIzMDQzLDEuNTIyMzUtMC40OTY4NiwzLjI1MzQ0LDAuNTExMTMsNC41NzQ4LDEuMDcwOTIs'
    b'MS40MzkyNCwyLjA3NzA1LDMuMTMxNDgsMS43OTI3OCw1LjAwNTA4LTAuMDM2NCwxLjk0NTI0'
    b'LTEuMzMzNzksMy43NTEwOS0xLjA5MzE3LDUuNjc3MzUsMC41MDQ4MSwxLjI3Nzc5LDEuOTc0'
    b'MzgsMi45MTQwMywyLjc5Njg4LDAuODgzOTgsMS4wMzk4OC0xLjY0ODM0LTAuNTA1NzUtMy40'
    b'Nzg2MS0wLjA0MDYtNS4yMjkzLDAuMzIzNTYtMS43MzA4MSwxLjc0NjY4LTMuMTk5ODEsMS4z'
    b'Nzg5MS01LjA3MTQ4LTAuMDM0OC0xLjY0NTE3LTIuMzI0NzQtMy4yMDA0Ni0wLjU0NTktNC43'
    b'NDA0MywwLjYyNTM1LTAuNzE3OTIsMS42NTkzOC0yLjE2NDQ0LDEuNTY4NzUtMC4zMzEyNSwx'
    b'LjA2MDkxLDEuMjU5ODksMi4yOTgyMywyLjY3OTY1LDIuMTI2NTYsNC40NTc2Mi0wLjE1NjY2'
    b'LDEuNzU1NzktMC44NDIxMSwzLjc3ODU3LDAuODA0NjksNS4wNzM2MywxLjY3NjQ1LDEuNzY4'
    b'MiwzLjE0MTg0LDMuOTg0MTksMy4xNjMwOSw2LjUwODc5LDAuMTg3ODgsMi4xOTQ3LTAuMjc4'
    b'MjUsNC41MzQ4NS0xLjcyNzc0LDYuMjQyNTgtMS45MDQxOCwxLjU3OTUxLTMuOTYxNjEsMy4y'
    b'MjE1MS02LjQ3MTE3LDMuNjE5MjgtMS43OTMxMiwwLjI2MjAyLTMuNTUxMSwwLjc0MzE4LTQu'
    b'NzE2OTEsMi4yNDQxOS0xLjY1MDY4LDEuMzY3OTEtMy4yODQwNywwLjA0NTEtNC4zMDAyLTEu'
    b'Mjg0NTctMS43NjA4My0wLjY5Njc0LTMuNzMzMTgtMC41MDc4OC01LjUyOTg4LTEuMDk3NDYt'
    b'Mi4zODMyMi0wLjY3OTI4LTQuNjQ1MDQtMi4xNjcyOC01Ljc0MDgtNC40NTA5Ny0xLjEzMDgt'
    b'Mi4yNzczNy0xLjI3NTY3LTQuOTE4ODYtMS4xMDk0LTcuNDE1NDMsMC4wNDg2LTIuMDA3LDEu'
    b'MTg2MTItMy43NzU1MSwyLjU4MzAxLTUuMTQxNDEsMS4zNzgwMS0xLjIxODUsMC44MTYwNi0z'
    b'LjE5OTM3LDAuODc2MzctNC43OTYyOSwwLjY5NC0xLjgwMjIzLDIuNTY1NzUtMi43MjYxMSwz'
    b'LjU4MzAxLTQuMzA4NCwxLjE5MzExLTEuNDczMjgsMC44NTYxNCwyLjA5MjI2LDAuODg3MSwy'
    b'LjgzMjAzLDAuMDUzNywxLjI5ODMtMS4zNzkzLDIuMTAyNTUtMS4wOTY0OCwzLjQyMzk5LTAu'
    b'MTU1NjksMS43MTI1MiwxLjg2MjU1LDIuNTQ2NDYsMi4wMzc1LDQuMTczNjcsMC43MzgzNywx'
    b'LjYzMDM2LTAuOTU2ODEsMy4zODA5NSwwLjEsNC44ODk4NCwwLjU1MDI2LDAuNzQxNzQsMS45'
    b'OTcxNCwyLjQ5NDk1LDIuMTY2OCwwLjU2Nzk3LDAuODU5NTMtMS40OTk5NSwwLjc1MDA0LTMu'
    b'MjQ0NSwwLjA0NTctNC43ODI4MS0wLjI2NDU4LTEuNzI0MTEtMS43MzI3OC0zLjMzMzQ3LTAu'
    b'OTM3NS01LjEwNjI1LDAuNTk5NjItMS42MDcwNCwyLjUyODE4LTIuNDMzNjUsMi42NS00LjI4'
    b'MTI1LDAuMjQ0OTMtMS42OTEwMy0wLjkwNjc5LTMuMTQ0MzItMS4xMjk2OS00Ljc3ODEyLTAu'
    b'NDg2MzMtMS44NDA1LDAuMzUwNzItNC4wMjI4MiwxLjc0MjE5LTUuMjg5MDcsMC4zNjI3Ni0w'
    b'LjMzNjEsMC42OTk0My0wLjcxMDQzLDEuMTI1LTAuOTcwMzF6Ii8+DQo8L2c+DQo8L3N2Zz4=', 'RU_BU')

RU_BU = b64_RU_BU
index.append("RU_BU")
index.append("Russia Buryatiya Respublika")
catalog["RU_BU"] = RU_BU
catalog["Russia Buryatiya Respublika"] = RU_BU
country["Russia Buryatiya Respublika"] = ('RU_BU', '', 1)
lookup["RU_BU"] = ('RU_BU', '', 'Russia Buryatiya Respublika', 1)
lookup["Buryatia"] = ('RU_BU', '', 'Russia Buryatiya Respublika', 1)
lookup["Russia Buryatiya Respublika"] = ('RU_BU', '', 'Russia Buryatiya Respublika', 1)
details["RU_BU"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+08:00","altname":"Buryatia"}
regional["RU_BU"] = ('RU_BU', 'Russia Buryatiya Respublika', 1)
regional["Russia Buryatiya Respublika"] = ('RU_BU', 'Russia Buryatiya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_CE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iNDUw'
    b'IiBoZWlnaHQ9IjMwMCIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4K'
    b'IDxwYXRoIGQ9Im0wLDBoNDUwdjMwMEgwIiBmaWxsPSIjZmZmIi8+CiA8cGF0aCBkPSJtNDIs'
    b'MjA0LjJoNDA5djk2SDQyIiBmaWxsPSIjREEyNTFEIi8+CiA8cGF0aCBkPSJtNDIsMGg0MDl2'
    b'MTc3LjJINDIiIGZpbGw9IiMyQjczMzgiLz4KIDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKC0u'
    b'NTg0NDMpIiBzdHJva2U9IiNmYzAiIHN0cm9rZS13aWR0aD0iMiI+CiAgPGcgaWQ9ImIiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KDEgMCAwIDEuMDAzNCAtOTcuNDc2IC00LjQ4NzcpIj4KICAgPHBh'
    b'dGggZD0ibTExOS43NCA5MC4wMjVjLTMuNiAwLjktNS42IDUuNC0zIDkuMyAyLjkgNC41IDku'
    b'NiA0LjIgMTMtMC41IDMuNC00LjcgMS43LTExLjItMi42LTE1LjItNS4zLTQuOS0xNC4yLTQt'
    b'MTguNCAyLjktNS4yIDguNy0xIDE4LjIgNC44IDI0LjlsMTAuNyAxMC41YzUuOCA2LjcgMTAu'
    b'MSAxNi4yIDQuOCAyNC45LTQuMSA2LjktMTMgNy45LTE4LjIgMy4xLTQuNC00LjEtNi4xLTEw'
    b'LjUtMi43LTE1LjJzMTAuMS01IDEzLTAuNWMyLjUgMy45IDAuNiA4LjQtMyA5LjMiIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iI2ZjMCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lk'
    b'dGg9IjMuOTg2NiIvPgogIDwvZz4KICA8ZyBmaWxsPSJub25lIj4KICAgPHVzZSB0cmFuc2Zv'
    b'cm09Im1hdHJpeCgxIDAgMCAxLjAwODcgMi44NzM4ZS03IC03Ny42MzQpIiB5PSIxNTAiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHN0cm9rZT0iI2ZmY2MwMCIgc3Ryb2tlLXdpZHRo'
    b'PSIzLjk2NTQiIHhsaW5rOmhyZWY9IiNiIi8+CiAgIDxwYXRoIGQ9Im0yMi4wODMgMTEuNmMt'
    b'My42IDAuOTAzMDItNS42IDUuNDE4MS0zIDkuMzMxMiAyLjkgNC41MTUxIDkuNiA0LjIxNDEg'
    b'MTMtMC41MDE2OCAzLjQtNC43MTU4IDEuNy0xMS4yMzgtMi42LTE1LjI1MS01LjMtNC45MTY1'
    b'LTE0LjItNC4wMTM0LTE4LjQgMi45MDk3LTUuMiA4LjcyOTItMSAxOC4yNjEgNC44IDI0Ljk4'
    b'NGwxMC43IDEwLjUzNWM1LjggNi43MjI1IDEwLjEgMTYuMjU0IDQuOCAyNC45ODQtNC4xIDYu'
    b'OTIzMi0xMyA3LjkyNjYtMTguMiAzLjExMDQtNC40LTQuMTEzOC02LjEtMTAuNTM1LTIuNy0x'
    b'NS4yNTEgMy40LTQuNzE1OCAxMC4xLTUuMDE2OCAxMy0wLjUwMTY4IDIuNSAzLjkxMzEgMC42'
    b'IDguNDI4Mi0zIDkuMzMxMiIgc3Ryb2tlPSIjZmMwIiBzdHJva2UtbGluZWNhcD0icm91bmQi'
    b'IHN0cm9rZS13aWR0aD0iNC4wMDY3Ii8+CiAgIDxwYXRoIGQ9Im0yMi42NDMgMjM0Ljg5Yy0z'
    b'LjYgMC45MDMwMi01LjYgNS40MTgxLTMgOS4zMzEyIDIuOSA0LjUxNTEgOS42IDQuMjE0MSAx'
    b'My0wLjUwMTY4czEuNy0xMS4yMzgtMi42LTE1LjI1MWMtNS4zLTQuOTE2NS0xNC4yLTQuMDEz'
    b'NC0xOC40IDIuOTA5OC01LjIgOC43MjkyLTEgMTguMjYxIDQuOCAyNC45ODRsMTAuNyAxMC41'
    b'MzVjNS44IDYuNzIyNSAxMC4xIDE2LjI1NCA0LjggMjQuOTg0LTQuMSA2LjkyMzItMTMgNy45'
    b'MjY1LTE4LjIgMy4xMTA0LTQuNC00LjExMzgtNi4xLTEwLjUzNS0yLjctMTUuMjUxczEwLjEt'
    b'NS4wMTY4IDEzLTAuNTAxNjhjMi41IDMuOTEzMSAwLjYgOC40MjgyLTMgOS4zMzEyIiBzdHJv'
    b'a2U9IiNmYzAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSI0LjAwNjci'
    b'Lz4KICA8L2c+CiA8L2c+Cjwvc3ZnPgo=', 'RU_CE')

RU_CE = b64_RU_CE
index.append("RU_CE")
index.append("Russia Chechenskaya Respublika")
catalog["RU_CE"] = RU_CE
catalog["Russia Chechenskaya Respublika"] = RU_CE
country["Russia Chechenskaya Respublika"] = ('RU_CE', '', 1)
lookup["RU_CE"] = ('RU_CE', '', 'Russia Chechenskaya Respublika', 1)
lookup["Chechnya "] = ('RU_CE', '', 'Russia Chechenskaya Respublika', 1)
lookup["Russia Chechenskaya Respublika"] = ('RU_CE', '', 'Russia Chechenskaya Respublika', 1)
details["RU_CE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Chechnya "}
regional["RU_CE"] = ('RU_CE', 'Russia Chechenskaya Respublika', 1)
regional["Russia Chechenskaya Respublika"] = ('RU_CE', 'Russia Chechenskaya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_CHE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc2NzciIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODAiIHZpZXdCb3g9IjAgMCAxMjAgODAiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'Q2hlbHlhYmluc2tfT2JsYXN0LnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3'
    b'Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0'
    b'cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5z'
    b'OnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3'
    b'dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9z'
    b'dmciPgogIDxkZWZzIGlkPSJkZWZzNjgxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9'
    b'Im5hbWVkdmlldzY3OSIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2'
    b'NiIgYm9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2Fw'
    b'ZTpwYWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgog'
    b'IDxnIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIg'
    b'aWQ9Imc2ODMiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFs'
    b'aXR5IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFB'
    b'TlNVaEVVZ0FBQUhnQUFBQlFDQUlBQUFCZCtTYmVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFB'
    b'Q0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3Vs'
    b'RThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFRCmxVbEVRVlI0MnUyY2UzUVVWWjdIZi9X'
    b'dTZtZlMzZW51SkUwU0pJR0VJSVJOZ2hESTRvc2hQSHd0b2pDdWlBNnVpcUtqUjBlUDYzaG0K'
    b'OUtnN3pxNnpzNk1MNnd4bjNWVldtQm5lZzZMNEFIa1RDUW1TRUFKSk9wMUhQOVB2N3FxdTE5'
    b'MC9Ha0lTWUdGbno4Wk02TzkvWGJmcQpkdFduZi9XOTkvZXIyNFcxNU9rZ28vOS80UmtFR2RB'
    b'WjBCbGxRR2RBWjBCbmxBR2RBWjFSQm5RR2RBWjBSaU1oOGkvcmRQdFZ0SitWCjFEeVowb0dV'
    b'QUN4SUdNTkVpbEw1ZkpsZ1FVa0JGaUlxZzFRQmdXZEEvL2xxQUlXNG0zOXFBWEFXSUJnQUFK'
    b'bFhHNW9rTVFwVjFVQnAKQUFCa1FUM1hJaDEvaTYwY1paZjJsMlFkL2lwaHlRT2d5ejlQR1FB'
    b'SUNqQUNSQm9vRGVBVUVBd3dSaWlmQmZGWllpYWkvM3hsVzVBaQpROWNaNkhURDZYWUlSWUVr'
    b'b1YrQVNBSWEyeURKQTRhQkl4ZkcyOEhseVhqMC8wRkhUeENkU1dWT09aUVZRVzBGVUZyQUtY'
    b'Q2RnMU5uClllRUNBQUJWQWlFTTdlMmdHbEFHTkFCQUNzRlJDVGx3Wk1ReEU0NWgxM1pVVVo3'
    b'NjlDcGdzb1o2SHdiTUJTZkJLZERrd0kwNThCaUgKMm82ckJlUW9Nc2J2NTFTKzVneXBsMS8v'
    b'WTgzdDZ3cEszK2RNUjVXcm80NnFxS1FBRGFNTUFCZ09sMFp2amhVMkdTeG5aSFM5UjNROApm'
    b'OXk4bVRPblRKc215M0piVzlzNVorZVpmVit1Nkd1LzB2NEk0RDhjSmN1MWphb0VPRFdrU1ZV'
    b'Z0pRemZYeGFoNWlkL1ArV1dXLy9sCjRRY2Y3emlGWFo4Ui9RMmovY0hiLzZ6VDZWS3BsQ1JK'
    b'MFdqVWFMTlBXUFdFUjdsaUFIN0dHZWUvOHJPa0NFcnFNa3pEb2VFYjI5dWgKNWNBbXE5WDZ3'
    b'bi85L2s5RzYzVm5IYjBxMmxCWkczbjh1UzFidDVyTTVyeThQQXpES2lzcmk0dUw4OGFOYTFT'
    b'dWVHRGc5b1ZWVlZYbgovQ0JHaHplSklxU0VJVDlBS2dSbnprQmU2b2pYNjgzSnlmSGVWSHNk'
    b'Z1hhcnNISEd6ZGlIMjVhOStYWWdFS0FvS2pjM056OC9YeFRGCjV1Wm11OTBlaThYMGIvN3FB'
    b'R2U0aktFenVyb0hIdlE1RzNVTVJKMmd5a05hWTFIQUVjUjdRWlZBVGtMVUNWLzlDU2JtUTJs'
    b'TzB1ZnoKTVF4enk1Sjd6OG5xZGVIUmNZVFdUYS85NFVNL0tpMHJzOXZ0YjcvOTlnWHJWU3Vt'
    b'M1ZoZFhiVjM3NzZxcWlwVlZiZjJycExlZjRlNgo0S2s4UWh1bno1bTdlazFwYWVuZWYxK3pZ'
    b'QjVzL1FRV2lLQzFBc0VBa2lFUmhxK1BnSUpnMTI0d2NpQklFQlZnU2pGTXZSa1NPOERqCjhR'
    b'QkFRVUhCbHZ3YmlyM09zUTk2bDdYdzVUZmZLaXNyTzMzNnROVnFKUWdDQUJLSmhNOGZJQWpp'
    b'OEpGajFkVlZSVVZGWHErdmV2YWMKbysvL1pnNUlBQkJDc0hQeHNtV1ByNTQ4ZVRMTHNzbmVJ'
    b'em0zd25JakhOZ1BzVFpRRmFCb01CaGd4VzFBc2FBcUlFaWcxUUJqQXM0SwpBTUNRd1BPOG9p'
    b'aloyZGtKVG5OZFJMUmFPWU5sMlQxNzl0VFUxS1JTS1o3bms4bWt4K09KeCtNZmZQREJTeSsr'
    b'eUxFMFRUTUlJWVpoCjJuUHNjd0xkQW9KdDg1Y3NmZlN4S1ZPbTBEUXR5ektMK2dBRHZSMFdM'
    b'QVVBVUdYQXIzenVVZ0tjQWJCYXJTUkpXcTNXbkxwRjZyb1cKZk14NzlLMmZibDczbzVWYWp2'
    b'dkpYWXUzYk5uUzN0NGVDb1VhR3h0Mzc5Nzk2azkvcXNxaW9pZ0lJWTFHQXdCU25nTUFOcFJN'
    b'dSsvSgpwNHFMaTJtYUJnQ2U1M0VZTWxiaS8yT0VwTUxRbDlEWmJEWUFZQmltN3E2N1B5NHNH'
    b'L3VEb1ExRGp6bWJzeDY4T3lmY3I5UHB3dUZ3CmQzYzNSVkhQUHZ1c3hXTFJHNHg1K2VNQVFK'
    b'WmxETU1JZytFRVJzMTkva1d6Mlp5ZG5YMCtRaVVwRU9QUU5lY2Y4VzZJNktvc0ZrdjYKWTFs'
    b'WjJTMnZ2N1U5MjM1ZFRPOVlESkF4dTcrLzMrMTI3OW16Wis3Y3VXYXpXZUNUR3EwV3d6RU13'
    b'OUp4VFZtc0orYk9MeTB0SFh3cwpSVkUrMlNGR3J1RnJFSVJhb2FFVnExejBURHFpQVVDUjVj'
    b'ckt5b0tYZjk2SVVkZkZQSnFsU0wvZmYralFvZG16WitmbjV3TUF6eWVECkFiOGtTUUNRSGlU'
    b'YjZvOVczbkdYMld3V3hZdWxUcDFPTjZudXBiTW5oL1FtaEtEL0ZIaVBRZkFVUkowUTY0SElP'
    b'WEFmaHVaR2FOQSsKT3F0bU5rbWU5eGVXNDFKOHNxYW1wblg1SThMM2xKYVBhQXF1c0Z4VFU1'
    b'UEQ0YWl1cnNZd0RDRkVFQ1JGSXh6RDAvTVFBRkJ5ODJmTQptSUVRR29oSEFNQXdiTkdkU3ph'
    b'czcrN2I5ZnBORlJJbVEwOEgxTGVRUHNuSzAzazR5WURRejZnUlZaR1NaSzdxcUh2dStaZE1K'
    b'dFBnCnI5WVpEQ1NmWEhqdjBpM2ZmUFhEbnJOakdiUUMwTnR3M0NxTEpXLzhvOVZxVGVQak5C'
    b'b3hsYUlaQmdBRVFRQ0E4Y1VsWnJPNXY3OC8KTHk5djhPRjZ2ZjZSMVM5MmRDemRXWCtzUCtD'
    b'ek94d2xzOFpONVRpOVhxL1ZhaG1Hd1hFOEpmQTlQZDNCVUdRWVpZU1FWcXZ6ZTl3VQpSVTE0'
    b'ZkUzeks4K1ZnenhtUVJNQUw1RFNFUVJUcTZzcDZyeFhSc0loalZZcmlTSkYwOGxrTWhBSVZG'
    b'Uk1RNnFpS0VvNEhMYmJod3hmCk5FMlhscGFXbHBiS3Nnd0FKRWtpcExwN2UvUTZiU3dhWlRs'
    b'T1RBbUFFUU9PTWZpRzhIczlQTS9iYmJaRGlVVFBJMDhhMS8vYWdZMWQKandhQW9NNm8wK2t1'
    b'Rk42VWxDQklLWkdpNlhUTUhqbHlwS0ppT3A5SXNDeHJNRndtSFhlNzNRQWd5MUl5RWZkNTNC'
    b'NTNYMG9RRUVKVwplNjVPcnk4b3VrR1NKSTdqaGcrUUNPbU5SZ0NrMCtzaWtVaE1sQTcrN2VO'
    b'eGhNYXNSd05BU3FmSDhmTy9MazRRV1NaVHR1bjhKR3o4CitQRXJWNjZjTUdGQ3dPc1JKWmta'
    b'cU9jUHJpNEZBaXpMWm1kbmt5UmxNR1pkZWkwSW9mNysva3NqT2htUEs0cWkxeHZzZG5zMEdD'
    b'eWUKTm5WemVmVkRMZCtPMllnV05OcGdNSmkyWXdCQUtocTQweG1HbVR4NU1zTXdxcW9BZ05O'
    b'NW1lb0VUZE5uejU1Tis4WmxoZ0ZGa1dVNQptVXhlMnFRM0dKR3E5Z2NDSE1kTm5qcTE5Y0Qr'
    b'UmErKzFnYkVtQVV0ZGJUdi92UlRSVG1mNW1sMU9qR1ZHZ1pMUmNoc05nOEVmamdjCkJnQ2Z6'
    b'OWZUMDBQVGRDQVF1T0t2S0FnVVJmRThINHZGaGpVbEUzRUVJS1JTUjQ4ZUxTd3NiRDNaVkY1'
    b'ZWZuamFqREVMZWdrcGR6cWQKZ2lDb3Fnb0FXcDErV0d5R2cvMUlWVm1XMWV2MWZyOC9GQXI1'
    b'L2Y3bTVtWlJGQlZGWVZrMmxVcGRjUUFJQmdFZ21Vd21rOG5CMDNBQQpFQ1VKcVNxR1lSTW5U'
    b'b3hFSWt3eUdZbEVhbGMvSFZQUjJBUjlRbFFWdjdlcnEydXdVMTkwY0VGUVZaVm0yUHI2ZW92'
    b'RklnaUMzKzhmClAzNThlWG01MVdwbEdLYXJxMHV2MXcrL1N5UXBIQTUzZEhTNDNXNVpsclZh'
    b'cmQvdmowYWpnKzhTUlpaeGdoQUVvYjI5SGNPd1hFLzMKNzM3NzI1bXpadTB6NTQ1TjBMTVpJ'
    b'bGRJSGpod0FDRjA2UTNPODBtS3ByVjZRM2QzTndCWUxCYUh3NUVPK1dBd2lHR1kwK21VWlJr'
    b'aApKRW1TS0lyaGNOamxjclcxdGJsY3JrZ2s0bkE0cXFxcXFxcXE2dXZyT3pzN0J3eUtJSWhJ'
    b'T0dReVdXS3htTVBoa0NRcGo2R1RINjBQCkJBTFNiWFZqRXpRR1lHeHVjclkwZTczZXdTYWdL'
    b'b29raXFxcVptV2J1cnU3ZTN0NzQvRTRRUkRwS1RNQW1Fd21qOGNUaVVRVVJYRzUKWENkUG51'
    b'enE2Z29FQWlSSjV1VGtsSmVYRnhVVlNaTFUydHBhWDE5L2VOc1dwOVBaMDlNejBEL0Rzamsy'
    b'Ky83OSswdEtTaHdPQjQzago5MHVKUS92MkZsVE5TSXpJUE85N2VBcStFRmMyMWgvZXZuMTdY'
    b'VjNkUUlFdEhBNEtQRTlSZERBWTdPenNESzM3ZGZmaXhmbjUrWXFpCkJJTkJnOEhBODd3a1Ni'
    b'SXNOelkyR28xR3ZWNVAwM1JmWDErNml2M1JSeC9GdmQ3NG5sMjJlTFFpR255V3dOWXJzcUlv'
    b'aFlXRjZmNWwKU1VJQVhxKzN0cmJXWkRKRmN1eEdkK2ZwdGIrNTRlK2ViS0kxTlJJL0JrR3pH'
    b'Q3pzN1ZqN2gwMXlTbmppcVRWcHM1WWxHYW1JcE9tTwpqczVERy81ekdSL1p1SEhqQ3krOFFG'
    b'R1VJQWhlcjFjVVJRekR3dUZ3UlVYRjhlUEhWVlU5czJOcnZzaHJXcHN0R0pRUldOSEFjaGtD'
    b'CkE0RGxEZnZYRXVTQ0JRdU1SbU13NE9jMG1rZ2tVbGhZbUpXVmxaV1ZCUVFCQUN0OFhUdmJX'
    b'cFdDQ2RCK2FxeFpSMXBXQXB0NzRuRGsKdlYrMXRMUUFnS3FxRkUxVExLZXE2R1JUMDYzZjdI'
    b'WXBxcXVqdytmellSZVdNU0dFRW9rRVNaSmxaV1dyVnEyNjg4NDc3VGgycjdOMQpJVXZNWUlp'
    b'aVN4WWxhVEJzMHZIREErNWh6ckYyZEhTWXpXYU5ScVBYNjlrN2xpZ0FCQUQrK2E2VU1Yc01l'
    b'dlNBYm1iSmUrTDlHeDVkCjJkYldCZ0NoY01UcjliYTJ0cDcrK0VNSEJqazRwbW44ZHNPR0RR'
    b'REFjUnpETUtJb2RuWjI1dVhsR1F3R2p1TUlnb2hhcnJKZ28xWVIKdnZyaUMxRVVzODBXUHBs'
    b'c2Ftanc5dldsSHk4c1hycjBHMFlIQUF0RDNyNm1FMk1aZEZvclhHYytmT1JCcDlONTdPalIz'
    b'YnQzLzlOcgpyMDF0YmdBQUk0NDkwdC9kZWVpQUtJb3N5MnExV28xRzAvVEpycURmcDZxcUxN'
    b'dWlLSWF2TmdVMjRwajdzMTBlandmRE1JcWlORnBOCnpqKzhXbi9zR0FEWWJMYWVtMm9CZ01U'
    b'Z0dUbXVqSG5RQUxDOHMrWGRwNS9hOXY1YWFmMi8xaDNmWDRLVWdYdS9xTmM1a0hjY09uancK'
    b'cHYyZkJ6N1pFWXZGYUpvV0JLRjQ4dVNyZGw1ejRuQkRRNE9pS0lxaXFDb3FSOUt4WDd6aDgv'
    b'a01Ca1BKdkxxZ2lnQ0F3a1lpRS8vKwpRV01BOXgzL1psNXp3ejJ4UUMxREdQQ0w1VXVhcE5J'
    b'UFg0TEI0TW1kMjZkaVNubnpDWmZMQlFENStmbDliV2V1MnZrRUhPcDM3a2lsClVqNlBHNmtx'
    b'QU56ZWVmcmdnUU1Jb1ltVEptMnRyZk9pRWFxV2pvcUZyVVljcTZFdWM4R3lUcGQrbGhnTUJ2'
    b'VW5qd1BBalRnNitQVlgKb1ZDSXBtbkcxWFZOdmZkMXB3UUJDQkp3WEVCZ0o3QWovL1plUzBz'
    b'TGp1TlAvdUtYMzJWWnJpUFFWOUtNOXBhT2pvNUlKUExaemgzegpnKzcwNlZKYk5ycGNMcElr'
    b'T2RzMXJWN2t3c0ZZUEY1WVdEUnoxcXh6Q2dLQStTZVBuV2hvTUpsTUpFbFNseTVGdlE1Qmp3'
    b'UFUwdEFRCkNvV0V6UnU1Qy9POFJTSFA3cDA3RUVJb3kzUk5tUUxQdTF5dS92NytuWnMybFJJ'
    b'WUFPVGljSGIzTHB2TkZvMUdLVkhNZ0FZQW9Ga0cKSVRTdXIzdGdDd0VRYjJ5SXhXTFU4TUwv'
    b'NWNWYmJTUkorbncrYXNONjhvSS9hYzYwU0pMVTI5dWJKV1lpR2dBQWRGbFpzVmdzUzVFRwpi'
    b'OVNlYlkzRllwckxQZXNhSmhGQjlnOFdGaFlXL243ZDJubUppK3VvMlVTY3BtbTMyejF1cEFD'
    b'UWVTOEpvNWF5SUlFNXh4cVB4MHVmCkZ1M0dpOXVuZHpwNW5tY04zRlZQL3FOVDQrNjQ1Mjlh'
    b'V2xybWFEOTJETm81cXcwQUlCNlBUbm81TlVLZ0RUWHlxQVVkNklYYzNOejIKOXZicTIyU0d2'
    b'cmg5U29sODJ1c2RQM0VLa1MxcnVTc2VIb3dDUVQ2SEVOcjMyZTkrdm56SUVuWXhvZ1VBRElr'
    b'amR2bWoxenBVRlQ0KwpkSXZkYnBmbDRYLzZrV1FBZ09uVHB4ODVkY1VsWG9vSzcreTg0N2Ji'
    b'NTdlM3Q4KzVZZHV3Vmc4L2srTTRUak55cjZJYnZhQi91WDMrCm84OStiREFZS0lxU0JvWGRH'
    b'UmYxWWYyUGJUWWJ5N0tCMk9WSklRUnZiS3BkOXZBYldxMjIvc2lYODZxSE9Nd0huK1hQditO'
    b'Um1xWnAKUm50ZGcxWlYrUHdZZC9QaW42VnJTVDZmYnlCYkRFVmhTL1B6RHp5MFpzS0VDWUZB'
    b'd0tTTFhiYUg5Wi9ZNXk1K3JiaTRHQUJJWWYrUQo5TVVQa3VXVmtwSVNSVkdTeWNTSUxlNFlk'
    b'ZitjWGJmcnhtUG5KcTE0ZUxYWmJPN3A2ZG43MWE2cHVqZTFISFQ3aUhkM3pKaFE4ZUI5Cnkr'
    b'WXBpckoxNjJaMzh6c1B6eHZpc0FlLzAzMzRSV25sbklkbTN2M1hPSTd2M2J1My92RG5pNmVl'
    b'TDg1MTlPSHZiaTZ5bFN5LzkvN2IKL1g3L2xzMS80SHZmdy81cXBDb042cmVqaVBLK1J0MCsx'
    b'NC92dlc5WmVuSGUzcS8zek5DdEtMQXBxZ3B2N1h6S2FDbTVmOWt5RE1NKwoyYld6bkhxaXNu'
    b'UklydUhzZzNlL1hGMjM2TzZLaWdwVlZiZHYrNk05OWZMaW1tZzYwWWtsWWMzYWhRK3NmR2I2'
    b'OU9rQWNPclVkMW5lCmhSVWxxUkc3dE5FRjJ0bEhuT3RqTU94OE5hM1FKaFE3SkFEZ1UzRG9G'
    b'SWVBd0FBRGdFSWJYK3dZUGx0d0I3Q1dMZ2JnL1BBNDNwNjgKSWY5aStiTS9BazFuTmVoQ3p6'
    b'cE91bW55aU01clJ4Zm9NYXpNcTM0eW9ET2dNOHFBSHIwaW93ZkpESVdSbUhWa1hqMmZzWTRN'
    b'Nkl3eQpvRE9nTTZBenlvRE9nTTRvQXpvRE9nTTZvd3pvRE9pTS9yZjZid0JscFkrR0hUUHVB'
    b'QUFBSlhSRldIUmtZWFJsT21OeVpXRjBaUUF5Ck1ESXpMVEEwTFRJNVZERXpPak0xT2pReEt6'
    b'QXdPakF3cVBoOStnQUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0FNakF5TXkwd05DMHkKT1ZR'
    b'eE16b3pOVG8wTVNzd01Eb3dNTm1seFVZQUFBQUFTVVZPUks1Q1lJST0KIiBpZD0iaW1hZ2U2'
    b'ODUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'RU_CHE')

RU_CHE = b64_RU_CHE
index.append("RU_CHE")
index.append("Russia Chelyabinskaya oblast")
catalog["RU_CHE"] = RU_CHE
catalog["Russia Chelyabinskaya oblast"] = RU_CHE
country["Russia Chelyabinskaya oblast"] = ('RU_CHE', '', 1)
lookup["RU_CHE"] = ('RU_CHE', '', 'Russia Chelyabinskaya oblast', 1)
lookup["Chelybinsk"] = ('RU_CHE', '', 'Russia Chelyabinskaya oblast', 1)
lookup["Russia Chelyabinskaya oblast"] = ('RU_CHE', '', 'Russia Chelyabinskaya oblast', 1)
details["RU_CHE"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Chelybinsk"}
regional["RU_CHE"] = ('RU_CHE', 'Russia Chelyabinskaya oblast', 1)
regional["Russia Chelyabinskaya oblast"] = ('RU_CHE', 'Russia Chelyabinskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_CHU = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iOTAwIiBoZWlnaHQ9IjYwMCIgIGZp'
    b'bGw9IiNmZmYiPg0KPHBhdGggZD0iTTAgMEg5MDBWNjAwSDB6IiBmaWxsPSIjMDAzOWE2Ii8+'
    b'DQo8cGF0aCBkPSJNMCAwVjYwMEwyMDAgMzAweiIvPg0KPHBhdGggZD0iTTAgMFY2MDBMLTIw'
    b'MCAzMDB6IiB0cmFuc2Zvcm09InJvdGF0ZSgtNjApIi8+DQo8cGF0aCBkPSJNMCAwVjYwMEwt'
    b'MjAwIDMwMHoiIHRyYW5zZm9ybT0icm90YXRlKDYwIDAgNjAwKSIvPg0KPHBhdGggZD0iTTkw'
    b'IDMwMGgxNzB2ODBoLTE3MHoiIGZpbGw9IiNkNTJiMWUiLz4NCjxwYXRoIGQ9Ik05MCAyNzUu'
    b'MjU2NDE3aDE3MHY0OS40ODcxNjZoLTE3MHoiIGZpbGw9IiMwMDM5YTYiLz4NCjxjaXJjbGUg'
    b'Y3g9IjE3My4yMDUwODEiIGN5PSIzMDAiIHI9Ijk4Ljk3NDMzMiIgZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjZmZkNzAwIiBzdHJva2Utd2lkdGg9IjQ5LjQ4NzE2NiIvPjwhLS13PTYwMCriiJoz'
    b'LzIxLS0+DQo8L3N2Zz4=', 'RU_CHU')

RU_CHU = b64_RU_CHU
index.append("RU_CHU")
index.append("Russia Chukotskiy avtonomnyy okrug")
catalog["RU_CHU"] = RU_CHU
catalog["Russia Chukotskiy avtonomnyy okrug"] = RU_CHU
country["Russia Chukotskiy avtonomnyy okrug"] = ('RU_CHU', '', 1)
lookup["RU_CHU"] = ('RU_CHU', '', 'Russia Chukotskiy avtonomnyy okrug', 1)
lookup["Chukotka"] = ('RU_CHU', '', 'Russia Chukotskiy avtonomnyy okrug', 1)
lookup["Russia Chukotskiy avtonomnyy okrug"] = ('RU_CHU', '', 'Russia Chukotskiy avtonomnyy okrug', 1)
details["RU_CHU"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+12:00","altname":"Chukotka"}
regional["RU_CHU"] = ('RU_CHU', 'Russia Chukotskiy avtonomnyy okrug', 1)
regional["Russia Chukotskiy avtonomnyy okrug"] = ('RU_CHU', 'Russia Chukotskiy avtonomnyy okrug', 1)
#----------------------------------------------------------------------
b64_RU_CU = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iMmUz'
    b'cHgiIGhlaWdodD0iMTI1MHB4IiBjbGlwLXJ1bGU9ImV2ZW5vZGQiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgaW1hZ2UtcmVuZGVyaW5nPSJvcHRpbWl6ZVF1YWxpdHkiIHNoYXBlLXJlbmRlcmlu'
    b'Zz0iZ2VvbWV0cmljUHJlY2lzaW9uIiB0ZXh0LXJlbmRlcmluZz0iZ2VvbWV0cmljUHJlY2lz'
    b'aW9uIiB2ZXJzaW9uPSIxLjEiIHZpZXdCb3g9IjAgMCAyZTggMS4yNWU4IiB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogPGRlZnM+CiAgPHN0eWxlIHR5cGU9InRleHQv'
    b'Y3NzIj48IVtDREFUQVsKICAgIC5maWwxIHtmaWxsOiNBMjI2MEJ9CiAgICAuZmlsMCB7Zmls'
    b'bDojRkZERjAwfQogICBdXT48L3N0eWxlPgogPC9kZWZzPgogPHJlY3QgY2xhc3M9ImZpbDAi'
    b'IHdpZHRoPSIyZTgiIGhlaWdodD0iMS4yNWU4Ii8+CiA8cGF0aCBjbGFzcz0iZmlsMSIgZD0i'
    b'bTEuMjg5OWU4IDIzNTgzMDAwIDU2NTcwMDAtNTY1NzAwMHY1NjU3MDAwaDU2NTcwMDBsLTU2'
    b'NTcwMDAgNTY1NzAwMCA1NjU3MDAwIDU2NTcwMDBoLTU2NTcwMDB2NTY1NjAwMGwtNTY1NzAw'
    b'MC01NjU3MDAwLTU2NTYwMDAgNTY1NzAwMHYtNTY1NzAwMGgtNTY1NzAwMGw1NjU3MDAwLTU2'
    b'NTYwMDAtNTY1NzAwMC01NjU3MDAwaDU2NTYwMDB2LTU2NTcwMDBsNTY1NzAwMCA1NjU3MDAw'
    b'em0tMzY1NzAwMCAyZTZ2LTI4MjkwMDBsMzY1NzAwMCAzNjU3MDAwIDM2NTcwMDAtMzY1NjAw'
    b'MHYyODI4MDAwaDI4MjkwMDBsLTM2NTcwMDAgMzY1NzAwMCAzNjU2MDAwIDM2NTYwMDBoLTI4'
    b'MjgwMDB2MjgyOTAwMGwtMzY1NzAwMC0zNjU3MDAwLTM2NTcwMDAgMzY1NzAwMHYtMjgyOTAw'
    b'MGgtMjgyODAwMGwzNjU3MDAwLTM2NTYwMDAtMzY1NzAwMC0zNjU3MDAwaDI4MjgwMDB6Ii8+'
    b'CiA8cGF0aCBjbGFzcz0iZmlsMSIgZD0ibTcxMDA2MDAwIDIzNTgzMDAwIDU2NTcwMDAtNTY1'
    b'NzAwMHY1NjU3MDAwaDU2NTcwMDBsLTU2NTcwMDAgNTY1NzAwMCA1NjU3MDAwIDU2NTcwMDAt'
    b'NTY1NzAwMC0xZTMgMWUzIDU2NTcwMDAtNTY1NzAwMC01NjU3MDAwLTU2NTcwMDAgNTY1NzAw'
    b'MHYtNTY1NzAwMGgtNTY1NzAwMGw1NjU3MDAwLTU2NTcwMDAtNTY1NzAwMC01NjU3MDAwaDU2'
    b'NTcwMDB2LTU2NTYwMDBsNTY1NjAwMCA1NjU3MDAwem0tMzY1NzAwMCAxOTk5MDAwdi0yODI4'
    b'MDAwbDM2NTcwMDAgMzY1NzAwMCAzNjU3MDAwLTM2NTcwMDB2MjgyODAwMGgyODI5MDAwbC0z'
    b'NjU3MDAwIDM2NTcwMDAgMzY1NjAwMCAzNjU3MDAwaC0yODI4MDAwdjI4MjgwMDBsLTM2NTYw'
    b'MDAtMzY1NjAwMC0zNjU4MDAwIDM2NTcwMDB2LTI4MjkwMDBoLTI4MjcwMDBsMzY1NjAwMC0z'
    b'NjU3MDAwLTM2NTcwMDAtMzY1NzAwMGgyODI4MDAweiIvPgogPHBhdGggY2xhc3M9ImZpbDEi'
    b'IGQ9Im0xZTggMS4xNTVlNyA1NjU2MDAwLTU2NTcwMDAgMWUzIDU2NTcwMDBoNTY1NjAwMGwt'
    b'NTY1NjAwMCA1NjU3MDAwIDU2NTcwMDAgNTY1NzAwMC01NjU3MDAwLTFlM3Y1NjU3MDAwbC01'
    b'NjU3MDAwLTU2NTcwMDAtNTY1NzAwMCA1NjU3MDAwdi01NjU3MDAwaC01NjU2MDAwbDU2NTYw'
    b'MDAtNTY1NzAwMC01NjU3MDAwLTU2NTcwMDAgNTY1NzAwMCAxZTN2LTU2NTcwMDBsNTY1NzAw'
    b'MCA1NjU3MDAwem0tMzY1NzAwMCAxOTk5MDAwdi0yODI4MDAwbDM2NTcwMDAgMzY1NzAwMCAz'
    b'NjU2MDAwLTM2NTcwMDB2MjgyODAwMGgyODI5MDAwbC0zNjU3MDAwIDM2NTcwMDAgMzY1NzAw'
    b'MCAzNjU3MDAwaC0yODI5MDAwdjI4MjgwMDBsLTM2NTYwMDAtMzY1NjAwMC0zNjU3MDAwIDM2'
    b'NTcwMDB2LTI4MjkwMDBoLTI4MjgwMDBsMzY1NjAwMC0zNjU3MDAwLTM2NTcwMDAtMzY1NzAw'
    b'MGgyODI5MDAweiIvPgogPHBvbHlnb24gY2xhc3M9ImZpbDEiIHBvaW50cz0iMS4wMzVlOCA2'
    b'MzIxOTAwMCAxLjAzNWU4IDkuN2U3IDJlOCA5LjdlNyAyZTggOS40ZTcgMS4wNjVlOCA5LjRl'
    b'NyAxLjA2NWU4IDY0NDYxMDAwIDEuMTQxNGU4IDU2ODE5MDAwIDEuMTkwOWU4IDYxNzY5MDAw'
    b'IDEuMTYyNmU4IDY0NTk3MDAwIDEuMTQ4NWU4IDYzMTgzMDAwIDEuMTYyNmU4IDYxNzY5MDAw'
    b'IDEuMTQxNGU4IDU5NjQ4MDAwIDEuMTA2MWU4IDYzMTgzMDAwIDEuMTY5N2U4IDY5NTQ3MDAw'
    b'IDEuMjEyMWU4IDY1MzA1MDAwIDEuMjEyMWU4IDU5NjQ4MDAwIDEuMTQxNGU4IDUyNTc3MDAw'
    b'Ii8+CiA8cG9seWdvbiBjbGFzcz0iZmlsMSIgcG9pbnRzPSI5LjY1ZTcgNjMyMTkwMDAgOS42'
    b'NWU3IDkuN2U3IDAgOS43ZTcgMCA5LjRlNyA5LjM1ZTcgOS40ZTcgOS4zNWU3IDY0NDYxMDAw'
    b'IDg1ODU4MDAwIDU2ODE5MDAwIDgwOTA4MDAwIDYxNzY5MDAwIDgzNzM3MDAwIDY0NTk3MDAw'
    b'IDg1MTUxMDAwIDYzMTgzMDAwIDgzNzM3MDAwIDYxNzY5MDAwIDg1ODU4MDAwIDU5NjQ4MDAw'
    b'IDg5MzkzMDAwIDYzMTgzMDAwIDgzMDI5MDAwIDY5NTQ3MDAwIDc4Nzg3MDAwIDY1MzA1MDAw'
    b'IDc4Nzg3MDAwIDU5NjQ3MDAwIDg1ODU4MDAwIDUyNTc2MDAwIi8+CiA8cG9seWdvbiBjbGFz'
    b'cz0iZmlsMSIgcG9pbnRzPSI5LjY1ZTcgNTYxNDcwMDAgOS42NWU3IDYuMDM5ZTcgNzg3ODcw'
    b'MDAgNDI2NzcwMDAgNzI0MjMwMDAgNDkwNDEwMDAgNzczNzMwMDAgNTM5OTEwMDAgODAyMDEw'
    b'MDAgNTExNjIwMDAgNzg3ODcwMDAgNDk3NDgwMDAgNzczNzMwMDAgNTExNjIwMDAgNzUyNTIw'
    b'MDAgNDkwNDEwMDAgNzg3ODcwMDAgNDU1MDUwMDAgODQ0NDQwMDAgNTExNjIwMDAgNzk0OTQw'
    b'MDAgNTYxMTIwMDAgNzM4MzgwMDAgNTYxMTIwMDAgNjY3NjYwMDAgNDkwNDEwMDAgNzUyNTIw'
    b'MDAgNDA1NTYwMDAgODA5MDkwMDAgNDA1NTYwMDAiLz4KIDxwb2x5Z29uIGNsYXNzPSJmaWwx'
    b'IiBwb2ludHM9IjEuMDM1ZTggNTYxNDcwMDAgMS4wMzVlOCA2LjAzOWU3IDEuMjEyMWU4IDQy'
    b'Njc3MDAwIDEuMjc1OGU4IDQ5MDQxMDAwIDEuMjI2M2U4IDUzOTkxMDAwIDEuMTk4ZTggNTEx'
    b'NjIwMDAgMS4yMTIxZTggNDk3NDgwMDAgMS4yMjYzZTggNTExNjIwMDAgMS4yNDc1ZTggNDkw'
    b'NDEwMDAgMS4yMTIxZTggNDU1MDUwMDAgMS4xNTU2ZTggNTExNjIwMDAgMS4yMDUxZTggNTYx'
    b'MTIwMDAgMS4yNjE2ZTggNTYxMTIwMDAgMS4zMzIzZTggNDkwNDEwMDAgMS4yNDc1ZTggNDA1'
    b'NTYwMDAgMS4xOTA5ZTggNDA1NTYwMDAiLz4KIDxwb2x5Z29uIGNsYXNzPSJmaWwxIiBwb2lu'
    b'dHM9IjAgMWU4IDkuODVlNyAxZTggOS44NWU3IDU1MzE5MDAwIDgyMzIzMDAwIDM5MTQyMDAw'
    b'IDgyMzIzMDAwIDMzNDg1MDAwIDkwODA4MDAwIDIuNWU3IDk3ODc5MDAwIDMyMDcxMDAwIDk3'
    b'ODc5MDAwIDM3NzI3MDAwIDkyOTI5MDAwIDQyNjc3MDAwIDg3MjcyMDAwIDMuNzAyZTcgOTA4'
    b'MDgwMDAgMzM0ODUwMDAgOTI5MjkwMDAgMzU2MDYwMDAgOTE1MTUwMDAgMy43MDJlNyA5Mjky'
    b'OTAwMCAzODQzNDAwMCA5NTc1NzAwMCAzNTYwNjAwMCA5MDgwODAwMCAzMDY1NjAwMCA4NDQ0'
    b'NDAwMCAzLjcwMmU3IDFlOCA1MjU3NjAwMCAxLjE1NTZlOCAzLjcwMmU3IDEuMDkxOWU4IDMw'
    b'NjU2MDAwIDEuMDQyNGU4IDM1NjA2MDAwIDEuMDcwN2U4IDM4NDM0MDAwIDEuMDg0OGU4IDMu'
    b'NzAyZTcgMS4wNzA3ZTggMzU2MDYwMDAgMS4wOTE5ZTggMzM0ODUwMDAgMS4xMjczZTggMy43'
    b'MDJlNyAxLjA3MDdlOCA0MjY3NzAwMCAxLjAyMTJlOCAzNzcyNzAwMCAxLjAyMTJlOCAzMjA3'
    b'MTAwMCAxLjA5MTllOCAyLjVlNyAxLjE3NjhlOCAzMzQ4NTAwMCAxLjE3NjhlOCAzOTE0MjAw'
    b'MCAxLjAxNWU4IDU1MzE5MDAwIDEuMDE1ZTggMWU4IDJlOCAxZTggMmU4IDEuMjVlOCAwIDEu'
    b'MjVlOCIvPgo8L3N2Zz4K', 'RU_CU')

RU_CU = b64_RU_CU
index.append("RU_CU")
index.append("Russia Chuvashskaya Respublika")
catalog["RU_CU"] = RU_CU
catalog["Russia Chuvashskaya Respublika"] = RU_CU
country["Russia Chuvashskaya Respublika"] = ('RU_CU', '', 1)
lookup["RU_CU"] = ('RU_CU', '', 'Russia Chuvashskaya Respublika', 1)
lookup["Chuvashia"] = ('RU_CU', '', 'Russia Chuvashskaya Respublika', 1)
lookup["Russia Chuvashskaya Respublika"] = ('RU_CU', '', 'Russia Chuvashskaya Respublika', 1)
details["RU_CU"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Chuvashia"}
regional["RU_CU"] = ('RU_CU', 'Russia Chuvashskaya Respublika', 1)
regional["Russia Chuvashskaya Respublika"] = ('RU_CU', 'Russia Chuvashskaya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_DA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iOTAwIiBoZWlnaHQ9IjYwMCIgdmll'
    b'd0JveD0iMCAwIDkgNiI+DQo8cmVjdCBmaWxsPSIjRDgxRTA1IiB3aWR0aD0iOSIgaGVpZ2h0'
    b'PSI2Ii8+DQo8cmVjdCBmaWxsPSIjMDAzOWE2IiB3aWR0aD0iOSIgaGVpZ2h0PSI0Ii8+DQo8'
    b'cmVjdCBmaWxsPSIjMDA5MjNGIiB3aWR0aD0iOSIgaGVpZ2h0PSIyIi8+DQo8L3N2Zz4=', 'RU_DA')

RU_DA = b64_RU_DA
index.append("RU_DA")
index.append("Russia Dagestan Respublika")
catalog["RU_DA"] = RU_DA
catalog["Russia Dagestan Respublika"] = RU_DA
country["Russia Dagestan Respublika"] = ('RU_DA', '', 1)
lookup["RU_DA"] = ('RU_DA', '', 'Russia Dagestan Respublika', 1)
lookup["Dagestan"] = ('RU_DA', '', 'Russia Dagestan Respublika', 1)
lookup["Russia Dagestan Respublika"] = ('RU_DA', '', 'Russia Dagestan Respublika', 1)
details["RU_DA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Dagestan"}
regional["RU_DA"] = ('RU_DA', 'Russia Dagestan Respublika', 1)
regional["Russia Dagestan Respublika"] = ('RU_DA', 'Russia Dagestan Respublika', 1)
#----------------------------------------------------------------------
b64_RU_IN = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iNjAwIiBoZWlnaHQ9IjQwMCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzIwMDAvc3ZnIj4KPHJlY3Qgd2lkdGg9IjYwMCIgaGVpZ2h0PSI0MDAiIGZpbGw9IiMwMDky'
    b'M0YiLz4KPHJlY3QgeT0iNjciIHdpZHRoPSI2MDAiIGhlaWdodD0iMjY3IiBmaWxsPSIjRkZG'
    b'Ii8+CjxnIGZpbGw9Im5vbmUiIHN0cm9rZT0iI0Q4MUUwNSI+CjxjaXJjbGUgY3g9IjMwMCIg'
    b'Y3k9IjIyMCIgcj0iNTUiIHN0cm9rZS13aWR0aD0iMzAiLz4KPHBhdGggZD0iTTMwMCAxNjZh'
    b'MjYgMjYgMCAxIDAtMjAuNS00Mk0yNTIuMjEgMjQ3LjFhMjYgMjYgMCAxIDAtMjYuMTUgMzgu'
    b'ODZtMTIyLjMxLTQxLjk0YTI2IDI2IDAgMSAwIDQ2LjUxIDMuMTgiIHN0cm9rZS13aWR0aD0i'
    b'MjAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIvPgo8L2c+Cjwvc3ZnPg==', 'RU_IN')

RU_IN = b64_RU_IN
index.append("RU_IN")
index.append("Russia Ingushetiya Respublika")
catalog["RU_IN"] = RU_IN
catalog["Russia Ingushetiya Respublika"] = RU_IN
country["Russia Ingushetiya Respublika"] = ('RU_IN', '', 1)
lookup["RU_IN"] = ('RU_IN', '', 'Russia Ingushetiya Respublika', 1)
lookup["Ingushetia"] = ('RU_IN', '', 'Russia Ingushetiya Respublika', 1)
lookup["Russia Ingushetiya Respublika"] = ('RU_IN', '', 'Russia Ingushetiya Respublika', 1)
details["RU_IN"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Ingushetia"}
regional["RU_IN"] = ('RU_IN', 'Russia Ingushetiya Respublika', 1)
regional["Russia Ingushetiya Respublika"] = ('RU_IN', 'Russia Ingushetiya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_IRK = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc4MTIiIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iNzkiIHZpZXdCb3g9IjAgMCAxMjAgNzkiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'SXJrdXRza19PYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5r'
    b'c2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8v'
    b'c29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxp'
    b'bms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnMgaWQ9ImRlZnM4MTYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFt'
    b'ZWR2aWV3ODE0IiBwYWdlY29sb3I9IiNmZmZmZmYiIGJvcmRlcmNvbG9yPSIjNjY2NjY2IiBi'
    b'b3JkZXJvcGFjaXR5PSIxLjAiIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiIGlua3NjYXBlOnBh'
    b'Z2VvcGFjaXR5PSIwLjAiIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcg'
    b'aW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIgaW5rc2NhcGU6bGFiZWw9IkltYWdlIiBpZD0i'
    b'ZzgxOCI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI3OSIgcHJlc2VydmVBc3Bl'
    b'Y3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHki'
    b'IHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1Vo'
    b'RVVnQUFBSGdBQUFCUENBWUFBQUFnR3dISEFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpT'
    b'RkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFB'
    b'QUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVQKMlVsRVFWUjQydTJkZVhRYjFiM0hmek1qYWJS'
    b'TGx1VmRrdGM0am1YSGliZkVjUllnQ1lRQUlZRTZDWUZDWDZGTmVaeTJlWVcreDZHdgo5Qng2'
    b'S0lUUVVpaTBvYVduRkdoQ2xoZXlRQWdCc2lmZUV1KzJiTm1XYmNsYXJIMGZqV1o3ZjVSQW5M'
    b'V0JrRG93My85MDVvN3U3L3crCmMrLzkzZC85elJrRVh1YzR1TTZpZndBVEdBSVo4QzBTOHVk'
    b'L1Q3OG84UHBHaXdmTUErYkZBK2JGQStiRkErYkZBK2JGQStiRkErWUIKOCtJQjgrSUI4K0lC'
    b'OCtJQjgvcjJBbmJIM0JNVVF5Vy83bjVJbWlSR0E2TldsbU5aSHZCMTBtaGcxUHJvN2tjdHAr'
    b'Mm5COHdlOC9EWAoxVStjSW1KZHpxN2hQelp0dHZ5eGNmTkpIdkIxMG9aOUd4eWw2YVhrVzIx'
    b'ditZVUNvYURUMmRsL3JmdVlpRTY0V20wdGd4M09ycUFDCmx5SC8xN016eFIxMVQvQ0F2MGF4'
    b'SE1zT2VnY3RycGdyTjV3SUkvbWFmTmhyMmp1V3A4Njc1aFVpR29sR0UwdkdLR3RnbEU1U1NR'
    b'NUYKVU83Wnc4LzFKNWtrZWFQNFMzQURnV1cyZFc1cm9UaUszZEcxUThTeTdPd21heE11Rm9v'
    b'bkhxcDh5TWZCdFM4OUVtQUNvVndzRjlnagpkcXh2b3IrYzVSaG9IRHRWdUw5L2YwZS9weit4'
    b'cEdpSnRscFhiZVJIOERYUTl1N3RMVnM2dDJCbTN5QlJrRFVkRmFKQ3AwcXNzdVdxCmMzMGtR'
    b'M0pxaVZwenJmdEVBRUZFUWl4V21HV0kzRHk5dmtrdFZkbGt1Snd5UjRhajdxaWIyM2owaFRB'
    b'L2dxK1IvdEgrRDBHNklvTW8KMUJuUkVYdGZTQ2FTWVkvTWVueENLbVZWeTZZdnJmcTYrcDJi'
    b'VXorZlpkRHVMbWRuY0JpM1JaYVczZG5PQXMwd0dwcHRIR3NxOXNhOApIcTFNbXpaVi9ZWk01'
    b'YXBLYjlnN0VXV2lwRTZseTZyL1V6MnBWYWFIU0pMd3o4Nlo3YnVqK0E3VndvS0ZNMm1HVFln'
    b'RUF0bjFzTHZECjBXSGExclY5NHBTMWNib1FFK0JSTXFaOHVQcmhwaFdsZDAxTDBtUlNyOWJy'
    b'TCtsb3ZxcnlRdTFwMmp1d3RYUHJ5QWY5SDdSendNbjkKRWIrMFJGUHUwZ2l6U0RHaVlGRUV4'
    b'YTRYWEFDQUxFbTJxaTVqSHJhbXZNR2NwSk5lbG1YWUhkM2I1UlJEMFQvNzRIRmJnazdFK1Nu'
    b'NgpLbVFPbXlQempmVnBuNDRmakM4clczcmNFL0N6QldsNnZEQ2xVRHpMWUp4eHZlMUpUMG5M'
    b'eW9wbStGME9aN0ErdDk2aGtpb21WTm9VCjlyVDlOSm1nRTRJZVY4L0lWQXU2cHZRSVB1azZV'
    b'V3IybWVOWnFWcTBMS09hVm9nVWJJbTJSRktlV1o0dUZvaWwxMzg5UTVEWk9iT24Kejg2ZXBi'
    b'NXp4bDBhSXBsSU1qR0thcDVvallrRllub3NNQmJoUi9EVnJOVW9yV3kwbjlRNmd4T0ZPa1Zm'
    b'MjhLaStzaXk0bVdMVUFTOQpyZzhtRVkvSHQ3MzdidmVaMXRiRVU3LzhaVW1OdnFhc3lkclVI'
    b'WWdIQkVlSGp1WkpwRktSUCtJWEVqUmg1Z0gvaTNKRlhFNldZN05zClhydG1lY1V0UndWeEta'
    b'RW5MeElpQ0lKY1R6dHNWcXZ6aFdlZjY5MjkrNzJLZUN5R3YvajczK01BQUNLQkNBTUFRRkEw'
    b'Nmd2N2pBQUEKdHFDdDF4RnhPTElWMmRuOEZIMFplV0llOXduYnNjN1NMR08vQXBkYkhXNC9L'
    b'cE1yY0VPS1BnZUJ5d01tNHZGNFBCYUxYU3RidHI2egpwV1BWZCs3aDFDbnFjRzZ1b1EvSGNS'
    b'd0F3S0F5cEMzS3IrUld6Rmp1MWF0elc0MzZXZDIya0EzMjlPNFo5TWY5UGg3d1piVFh0TmRN'
    b'Ck1hUmtybUdPZTAzNWl2NEZCUXNFYy9WejAwclNTd292MXY3Z2dZKzY2aXFyVHVYbjVIVHIw'
    b'dE81a3NLaXNaZGZldWtySHd6RUlyRlkKWmRWc29jVXlTdGx0NDRXVk5UV0pzOWUwTW0zYVhh'
    b'WHI2bElWT2JIdjFqNGNuRmRRNzh6VTZCSWUycHN3ZTgwT0h2RGxSaUZGY0dOKwpLejdnSHBE'
    b'dTdIMC9aMXZuTm9GQ3FNQ0ZtRkIwYnJzUDNuKy9vNktrdEdYdHZmY2FoVGllRVFxR3lqa09a'
    b'TkZJcFBTNVo1N1JmMVU3ClhudjFsVGExU2lQYytzN2JXZ0FBWTFtWjhOenJMTWN5ZmM1TzZR'
    b'SFRQdVgybHEyVlVvbUM3YkoxNmlxeUtncDR3SmZSblNWMzVoNngKSE05dnRaNHVENUdSVklJ'
    b'bWNHZlVHWjBVWVI4LzN2ZlV6LytiZERqc1ZXdldyV3NiN08rZkJEU1pwUFM3ZHV3NDgxWHNH'
    b'TGVPUmkwVwpNOVhWMlZrRkFKQ2kwVXlLV1VpS0pBM3FYS3gvb2xjWkl2eUtmUjI3cWxORUtU'
    b'NkpVQ0xqQVY5QzBXUTAwdS9wZHl2Rnl1RWtRK0lhCnNjYmVVTllRVm9sVitLUTlhWHFtZk9Y'
    b'eU94SkxXYVQ3dC9ldGcwMHZiRHh4L3E1bS9jT1BaTVVpWDI0OWRqbWQ3b0F2a05MWjFpWmkK'
    b'R0FZREFNak15QlNmMjBZa0VJazBzaFJCZFU3VkJBQndCQmxQVzF1eFZ0N3VhRGU1SWk3blZQ'
    b'RG5sRXBWTmxvYnUxdkhXd090NDYzbwpQUDA4V2lhUm9ONllIMzQ4OThkeno1K2VZWFRNd1pU'
    b'UFlZQ205SlFZOTI2YXJ1dDZxYnZ2bHZQLzg5YmJsaDE1ZDlmT202N1d4aGMzCmJqeng0blBQ'
    b'MXlZcDZteS9yR2w0eUplUm1YbEIzamxJQlAzcjMvdVJlVjNOZlFtbjM0bHBKS25DbzVaajVQ'
    b'UExmek5iSVZJb0FmaFUKSlFBQVdQeVd5SWgvaEVNUWhBc25RM1FvRVV3Q0FEZ2p6Z3NPMlpt'
    b'R0J5eEFVM3A0K3NualFvTSsvbGdrSWRVckZiWUxBckNQRHN5NwplZjZDNDZkT25EQmRqUzI3'
    b'ZHV4RXpvRUxodHpjMW92QlpUbVcrVnZIWDFxS1U2Y2xuRUVuWm5LYjJCWmJTd0lBUUM2U0sv'
    b'aDk4RGxxCktHK28ydHk4ZVN4SGxlTXh1d2RFdzRHUlBLbEk2bG1rdjlsblVCdStXR01waW9K'
    b'ZTB5d0FBRmh5Q3lEdjdhVlY1cUc1UDYrY3R2OG4KSFQzbkIxZWl6dmIyQlhmZXRnd1VTbVh2'
    b'RTAvK1QyanAwbHV6MjlyT2VQYnZmVC9XMjlzajhiamRhcHFtcFFBY0o1RktRMEtoaVBKNgpQ'
    b'SFdmVDNNSTR0KzFiMi9PcFphVVhGVyt5RSsyQ3o0YStOaUFjR0RIVUF6dUxMbUR2ZEtXN2xz'
    b'SFdJU0o4QWRuUCtoK28vV05VaFJCCjQyblN0UEdiYzVhR1VRU2JkTmJMSFQzZUR4eFhEZ0RB'
    b'TlRkenNIeVpBN3I3Q2hZU2xCaEZFSmJsT0JRQTRONkcxYWRiVzVxenJXTmoKMlFBQWtYRFkr'
    b'S3VuZmdHL2V1b1hBQUI1RjdNaG1ReE5kcEJRT1A3ZXZyM2hnc0xDMG91MUY2SkNJWENvckdl'
    b'OFQwRFFCQjZLaFFxRQpHQjU4WVBZRGhYeVFkUkY5citwN3RSeHdLTU14T3JGUVRLVnFWRktC'
    b'RUprMDFiRXYvOGtQQUFBWVNzSFJVMHA0OG1jNkFJQXNpM1BXCmJRYjk2YzlHSGVmMk9JWDI4'
    b'Zkd2Vk1yejYyZWZ0ZFV2V0ZCNnFlc1NvVVFtRVVnd1k1b3g0bzhHVkF6SFp0VG4xVGt4Rkpz'
    b'U2cyZEsKamVDSjZJUXJTU2VwTlRQWDlLWEp0QktLcGRHN1MrODJxaVNxbEVsUHBUYVZZd0dB'
    b'KzY4Tm55S2xSV0lRQ2d4VWp0YjBpZE1WK0dsSwpmdkRETVN0Z0tNYTJ0YlRwejBiQS80cHdr'
    b'U2lKaTNFeUhJNTgva0M5OGVmWFlmMWovM25aKzI0cnZxM1NtR0cwMjBManAzODg3MGNNCnpV'
    b'THFucjU5TFhlWDNsWExqK0J6SWxHTzQ3akhQM3pjVnBCYW9KeVpYUUVzeThKdlQveTI4L3ph'
    b'NTMxM0xKRmI4bk9PNzI0OFFmejAKdFQrRVp4anlSMmtSbmtpeUhPUkY0bW9NUldpYW9iRllQ'
    b'SFpWWlR4Wk9wMTdScWx4VXFCbXM5b3VPd1BRTEUwZE1IOTA1azlObTRjWApGU3lJaHNoSXdo'
    b'djNKbXhCRzNsbytGQTdEL2d6dFRuYXhwNDcrcHg1eFl3Vk1PZ2RUTzQzN2NjT0RCN0FVQVNG'
    b'WXlQSGVzNjJlMm5UCnBwUC84ZEQzcXA5MnU0akRyYzJpazVZaHJTOFlyR3hER0w4RVJSQ0Z4'
    b'NTlUbktJZStUSTI1T2JtQnBOSmNsSzJpcVpwMWVYdVNkQ0oKaEQza0lQdGN2UktMenlJY0RZ'
    b'eHgyenUya3doR0p3NmFENFpDUkNqQUF3YUF1WWE1MHdBQXRuUnN3VTF1RTlwb2JSUkZFaEZw'
    b'MTBRWApuaXBMbFpBMFNRQUE3TjI5aHdVQU9BNWMzcXkxYStIcDV6ZXkyM2J1T0sxL1lHMWdv'
    b'VDRQRjRaak9ma3E1WmR5NnRIRGg4czYyanVLCkpxMzNMS3NtRTRuRXBlNDVNMzVtV0tmS0Zt'
    b'dGxhZVRCd1UvcUpwSWpzcVdsTmRFOUhaL2tMTXhmS0R0L2VmbFdKem9vaGtvK3V2dlIKSnBQ'
    b'YmxFdHp0SnJqT0h6OW5QV25GYmhDc0xwODlWd0FnSUgrZ2JHdDc3dzltSjJ0a3dFQWVMMXUy'
    b'bXExTXE2aElYVGJtZjU4QVUzcAppeEF5RkVKQWRRVXpTQXpEQWd6RFpGN0ozamZlL051WmV4'
    b'b2FMbHJZUnpGVWN1UFJqWTNkcmg3QmlIK2tMbFdtOWhFVUdYaHR4V3RnCnpEUVdmKzdvUC9P'
    b'QXY0aGNELzM2NDBHZk9iZmZQVkNnVSt0YXQ2M2RWblUyay9YMjMvL2VzdUd4eDR3Y0J4Zmtl'
    b'KzBzYmhNQjZBc0UKbEQzS2Npb1VRMk5WTmRVRHNVZ01peWZpYUdabUpwV2owN0dMbHl5UnJW'
    b'aTUwcmlvdnI1enlEeFlkOFh0R3k0YWJXbHZGeGx5Y3k5Ngp6anNTR0IzN3dhNGZvZ1FWejNo'
    b'd3pvTk5wWm9aNklMY0JmTW5PWm9IL0UrRnlYQnd3RE5nRjRnRVByTm5pQXJTOW9SQlBBMVpV'
    b'blRyCllpRW14Qm1HWVhLMFdsc3lTZVZoR0RieHdFTVA5dC9UMEtCUXE5VmN5VTIzaTFFaVlj'
    b'Ujg0M0dRU3E1WTB2UEQ3My8veU01dDI4OVAKWTVLL2YvVVBIYWRiV3hONzN0dXRqWVREeFFB'
    b'Z1JCQWsvTGUzM3hwYXNXcFY1ZWY3Y2VBNFc5QTJmbnowcEUyV2twb1FNU3hyc3ZjeQpEMWMv'
    b'WElOaG1PQnNtcElIZk5hek5FbDB1Ym9zdTNwM2VRcFNDcml4OEtoUUljZUk2WXB5Y3BhMnRq'
    b'UXZJN2VBSkVuUzUvVUdqeDA1CllsMTkzMzFWS1BwRitRNDlaOUV4cEt0bkhoWjFJNEJoVjl3'
    b'ZUpaUEpaSlltTmM1eG5Cb0F1Ti85NFpXV2V4c2FqQXFGUWc0QTBHL3EKSDEyK2RFa2tHQWlX'
    b'QXdEY2R2dnRSN2J1M1BINUErR1ArMzBkemc3cjFvNnRFUTdEWkJKVVNOMWFkQ3Q2YVBndzhm'
    b'T2JucGgyYm1VSApuNHYrWjg3WnM2VmppOWVnTm1CZHJpNjB3OTRwNnJRUDZNem1FWHpZT2VR'
    b'RkFNQnhITS9PeWNsWWUvLzlOZWZDQlFEQW5uOUdnNmpWCnBzdkJiVzVxNmpka1p2V215aFRS'
    b'M014c0c4ZHg4ck1NZnZXTC81VXJGQXA1T0J5T0xGdTgrTmk4NnVxY3MzQUJBTzVldFhMU3Nx'
    b'Q1IKYWxMalZKd2U4QXhtOURtNk1wTTBsVHhnUGtCZ0tNcTlldXFQNXFud0R0T1VTblJrS2JM'
    b'UzlDcjk2STZ1SFJwQWdFdFFDWTAzNXMxawpVTERlUFhlbEtrN0ZZMUtoOUpKbnJjak5pOHFR'
    b'NFo3TDFpYlgxTllXc3d3enhBRW5KOG1FL0xPc1YvQ1d4VXM2MTZ4YksyTlpsazBtCms5UnJy'
    b'NytlWDFNeGk4SlFOTVN3YklwTUpoOWNlLy85TmVmKzE1aDN6RExrR3laSUpwSFBjWnlpMDlr'
    b'cFFCR0Vyc2lxR0ZwVHNWWXIKd2tUNHY5dW5VekxJb2xtYWVyLy8vYlptYXpOeFl1eEUwV3o5'
    b'ckxFQ1ZTRlRtS29qNStnWHpreVhwWC9wOUtQZjd3KzgrZGUvOWdsRgpJdVNaWHo2ZG41bVZa'
    b'ZnZ3azQ4Tk9yMStValROTUF6ejVNK2VPUEdiRjErWTkrckxMN2QwdG5WUWIyNTU1NmF6YTIr'
    b'ZnA2LzdrUFdZCmJkQnVrbk1vcmRiSmRVU3RvVFkyUnpkdmpsUWtsVi9nYUg0Ti9rSm5nNWRu'
    b'RHo5cldXVmNKVHZqT1Ixdkdtb1dMeTZ1amM1S1g1Q3kKc0dEaFRCUkJzYTlpUTRJZ0NCR080'
    b'K2RQODVjU3k3THMyYmFqZ1ZIclNVZlRvQ283UmJKcDIyLzBQMW53bzc1OHpUUnh0OU9FTHN5'
    b'YgpyOC9YNU9kTkZjQlRzbXlXb0lqWUVmdEhwaUp0Z2VCRDg0Y3hGRkRPSFhNWGZEcllPRkdz'
    b'cVlwL1ZiZ0FBR0tKUkhKVndjcG5jRm1PClpaUzRVbW9hNzhFZ2lyRlNYSWFIaUxob1grOEgz'
    b'RVRRRjQyRzQ0T1AzYlErYjZyNGNrb0NsZ3FsY3AyNE1OVUdEays3dlgxNmtrbEsKT0k1TGNV'
    b'ZDhrbjV2LzVtZWlPbkRUQ3hOK1oyeTcxUkloUmRPaDErSGtrd3lNZW9mdFRkWm0xd2lvUWh0'
    b'dERhbFJBWWpGUmlLMFg5cAovbXRaaGFheW8xWmZLMjJvV2xVNmxYeUpUUFZ2Tm9USmNPalE4'
    b'S0grWXlQSENGdkVxbGxxWE9vS0pFSk0xMGluWWtQZEJuV052cWJzCmV0amNaRzNxdG9Yc3NX'
    b'WnJZMklzT0liZlg3dWFmS3Y1WGZIdHhjdnBtd3NYWlJhbEZoVmQxdEg4TnVuaVV1SktWWFZP'
    b'dFE0QTRJR1oKMzAxWUprYlFnOTBIcXlpVWx0c2o5dGoxc2dORE1HVEFNMENlc2JkcHcyU293'
    b'Tzd6Y01hMDBzU2diNUF1VEMwc25Lcit1eUZlQUhlRwpuWUhjbEZ6MDZNalJPRUVSd25naWxr'
    b'd2tpUms3dW5kMFpjZ3p1Z21PaU1nd21hZ3dwVEQzV3IyTXpRSEh1YVB1aWNheFJvdFNySlFj'
    b'CkdqcnNhN0kxRjhhU3NUd1VVZlNjc0J3WEZhWVdVa3BjanRpRGRydE9yZFB4Z0wrazRuU2Nq'
    b'cEFScnQzZXJpVVlJcFVEVHF6RWxkSHkKVENNNUhyYjUyeWM2MERSMVJ0RGl0VkQxZWZXSlNm'
    b'VmJYMUlEbm9IaFpzZEp5K0hCd3dxdE9ETzBzbnc1QWtMTzhxbnAwN1FFblZDTgpoK3k0REpl'
    b'N3FuVlZDSXFoVTNZbVJHN0U3eWFGRTE1WHE3MXpSS05JaWJkYVcyRkwyOWF5V2RObW16S1JE'
    b'S1E0dlpqSmttZWxBUUFvClJVcjgzQk9kSzhuaXQ0d08rWVo4dG9DTmlORXgxaFYzSm84TUhx'
    b'dEtWYWhjYXlxL081NHVTNlZFdENoclljSENpcXQ5dzVIZkpsMkYKRk9MVWpHWnI4MEFnRWNE'
    b'cTh1YkVzcFJac1ZaelN5MURNNGxOMDMvWDgvTFJWeUlxWEVrWHBSWng2WXAwTlVFUkpJcWdx'
    b'RTZsdTZBeQowdXd4RDhlcGVKS2dDYnJaMWhJd0J3WVlWOVN0VW1LS2FOOUVYeldDSUlyVkZl'
    b'dWFjVTRJN3pSdFVkeFR2aXA1dlY5Zi9kWUJSZ0JCCjV1am5LRGEzYkNiYkhlMHBDVHJCQ1ZB'
    b'Qk03dWdjdFRzRzJRQlJkUUQzZ0dreDlPakdJMVpUT21pVEc1RzJneDhwWEhscFBUaG9IZlEK'
    b'MG1SdGN2VjZlcE5SSkNqdEhPMDFWRStyY1VZbWdtbjN6VnNld0FUc2VLL0RYUEwzcGplelJR'
    b'S2NtcGxaSHBsbnFNdTdrWHgxUXdJRwpBRmhjdExoeWNkSGl6MysvMi9YdVNUOGJETGtpRGpH'
    b'TDBDSWlTUlJnQWpTbVVrclJCQk9HTjFyZmtBSkEyK3FacXo4Ly8zMjcvVzNyCkljdVJ2RVhH'
    b'T2VPMjBmRjBobU8xemYxTnVwTHM2YVlnbVVpV1paUTdOdFE5SVN6UExKOTVvL3JwaGdVOEtZ'
    b'M0lzYXhZSUJhRXZVSFoKdU44Sy9yQS96Z0hIQUlzRVBQNGcyajNlTzVOak9ma3JwMTRaYm5P'
    b'MEhYbWsraEhEcG1PYnhqdWNuZFVJSU5KRzB4azBMOTFnOTRRQwpPTU94cUQ4Y2pMZVA5RWh6'
    b'VTNSc2dQQVRON0p2dmhHQVVRUkY1K3JuR29BRGE1MitEcGNJSkdpanJiRXhFQSt3WW9FWThj'
    b'aDh2WTZJClkrNzh2UG5qZ1hnQTVSQ09VK0JLTmo4bHY5UGl0OVJOUzUwMm1xdk00NHFOSllQ'
    b'bFdlV1NRbm1SYXNReHd1bTBXcnhZVjVKM0kvc0cKK2FaK2ZaUmlxQ1RETWZUbTVzMm5QeDc2'
    b'V0xxaVpBV3hmczc2QlpQc1lHbnF5ZjFQbmxSSTlVUjE5Z3p4OHBLbGl4QkF2cFlBaWo5Tgor'
    b'b2FMVDFYeTRnSHo0Z0h6NGdIemdIbnhnSG54Z0hueGdIbnhnSG54Z0hueGdIbkF2SGpBdkhq'
    b'QXZLYWVCQUJ3M2IvZXhYSVF4aEFRCmZjdDhqZjA3T3YxL1c0ZWVRVmtVMzlRQUFBQWxkRVZZ'
    b'ZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURVdE1ERlVNVEk2TlRRNk1EUXIKTURBNk1ERFVw'
    b'cXVQQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEExTFRBeFZERXlPalUwT2pB'
    b'MEt6QXdPakF3cGZzVApNd0FBQUFCSlJVNUVya0pnZ2c9PQoiIGlkPSJpbWFnZTgyMCIgLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'RU_IRK')

RU_IRK = b64_RU_IRK
index.append("RU_IRK")
index.append("Russia Irkutskaya oblast")
catalog["RU_IRK"] = RU_IRK
catalog["Russia Irkutskaya oblast"] = RU_IRK
country["Russia Irkutskaya oblast"] = ('RU_IRK', '', 1)
lookup["RU_IRK"] = ('RU_IRK', '', 'Russia Irkutskaya oblast', 1)
lookup["Irkutsk"] = ('RU_IRK', '', 'Russia Irkutskaya oblast', 1)
lookup["Russia Irkutskaya oblast"] = ('RU_IRK', '', 'Russia Irkutskaya oblast', 1)
details["RU_IRK"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+08:00","altname":"Irkutsk"}
regional["RU_IRK"] = ('RU_IRK', 'Russia Irkutskaya oblast', 1)
regional["Russia Irkutskaya oblast"] = ('RU_IRK', 'Russia Irkutskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_IVA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc4MjciIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODAiIHZpZXdCb3g9IjAgMCAxMjAgODAiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'SXZhbm92b19PYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5r'
    b'c2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8v'
    b'c29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxp'
    b'bms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnMgaWQ9ImRlZnM4MzEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFt'
    b'ZWR2aWV3ODI5IiBwYWdlY29sb3I9IiNmZmZmZmYiIGJvcmRlcmNvbG9yPSIjNjY2NjY2IiBi'
    b'b3JkZXJvcGFjaXR5PSIxLjAiIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiIGlua3NjYXBlOnBh'
    b'Z2VvcGFjaXR5PSIwLjAiIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcg'
    b'aW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIgaW5rc2NhcGU6bGFiZWw9IkltYWdlIiBpZD0i'
    b'ZzgzMyI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2VydmVBc3Bl'
    b'Y3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHki'
    b'IHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1Vo'
    b'RVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpT'
    b'RkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFB'
    b'QUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQWUKN2tsRVFWUjQydTE5WjNoYzFiWDIycWVmTTcx'
    b'b1pqVHF4Wkl0OXlKY2NNY0ZIR3dnY0drSk5kL05sNFNRR0M0RVNISnZiaURKaFMvSgpoUVFJ'
    b'Qkc2QVFHaUpxUWFEVFhHaHVGZlpsbVJabHF3WlNkUDdtZFBQdmo5c2JFdDJ3RHpJanYzRis1'
    b'bGZvNk4zNy8zdWRkWjYxOXI3Cm5FRTk1VTF3dHJYSysxYWNkV01tNEZ3N1IvUTVvcysxZndL'
    b'aU1ZQlFqSjExdzZiTzhQSEZXT1JUOFBxeFJHT2IyWGJEY0RPckdjNlMKWlpVYlg5clpOdDF2'
    b'ZVRwYlJhdmlIdWUwQWdpWVlsWGFjbzdvTDllMjFVQk5Mem93bW5WOTc3YVd6Y3ZHTDdycndN'
    b'NlhKNTcvbldqawo0TGdhaXN1M2t1VHNCUmRkWVhuNng4TkdMbWh2ZTR2bkErRjA5MjNtOTZl'
    b'R1hseGZjUTBtcUhORW4xU2pFYm45dGdzSnhqcDN5dUtpClZIZzkrck01WXk0d2ROMDB3WHpy'
    b'aWV6V052YmErM1ZkTDYrZCt2REJPNWVPV0VwU05aWGF4SWMzL2VFZ1ZmaVVPQk1uZFliNjZO'
    b'RUgKRExZZ040NlpIUTUxaTdKNTg0UWZtNW1xYkNZUkxLdEdtbzRWWTl5RWFaczNyQ2tXeEh1'
    b'YTcwNGxXVUIwTGh1YlBHSHNzODZyendYRApMOWY0VjdjWWovM1I0ZlJNbjNYWnJnMWhrblFw'
    b'bWx4WDM4aC83V3JiVFFzY0RvYy9XS1VvQ29mSDY3cGVWbDVkWGRob2UrUlhVVXZ0ClA3dVBs'
    b'aWpNNitqa3I3ZUlhbGJKbDVXVnYvL3VLMlBHVGV2dldoM3ZmbTlGOXhNa1phcVN4RWV1VHFi'
    b'RjhycloySkFzTnB0cFlpUGIKdTlWZmM4YmFEVG9OS2JoSm9QeW9nalMrcUJLWUtoTE9sVTRo'
    b'YzFJTHZQcksrcEtKYnJuUXhiRkNXVm1qSTVFUXp2L2VudDVsVDdXdAordFgwL3lhaW0zcDc5'
    b'K2ZOYkRRVzRhMCtqYXE5U3JzRmswZVJLVU8rblB4clRQZHNONXAvZ243ZnBwUUtiSElqbXJH'
    b'Sm1nWG9kTi9LCjVHMzJrbE9IcnBJNEhkVFliMGNhYjRqYUtoWGtNaHJQeSsrclZrVzNqa2xN'
    b'Sm1rU0F3QVlDRXdBaFRlMWhXbTVWSU4raGpJUUFCREoKQkQzdlBIMWtzTDUrbmtNSE14MXE3'
    b'V3ZIdVloZkxpalpsSjdwRDVxS2UvTFNiZXllQlJPWHJ0eTZhN1ZseG9DN0ZTc1IwVEZYK09n'
    b'QwpZOFZCcmVwdTMydjlIUWV1c2I2NmlGNnhYUnlSWmtyLy83SG9yRisxM2ROYlZpRWZqREIy'
    b'aTFIaTFETUY4cStyM1YrZmthWW8zTG5aCjV2bGRzSEJKT3RJaStLeEc0TWFvcjFiS2lXUzBn'
    b'OE1QVlBBU0lSR281WjRtaXFLcFpNN2NtV1oyWnlzejJJcHg1WDByQUp1T2ZFOWoKY2VkMHJy'
    b'MkJ6UVE0OWNuQ3dyZHQ4NDkwUFUzLzhIckh5MkV0K04vRjI2NG1uM1dKb2E1aTFYUnkrNjB6'
    b'M2lNSldOWTE2ZXJDU3lhaQpTRk10ay9mMThFMm4yc1pQb1kvV0tLQnZqQmNSUmdpc2dxbG9o'
    b'S0lSVHF2eDdjWHhReGU0TU9UR2k0eFBLUjJKRFovVzhYaHBCNFV4CmtPRFVTWTZnRkFEQTVo'
    b'L2IvQ21EL0F5emdLQ0FnTTMwWTRRazRIYndrM2ZBWkZEQm1rMllKTVdZa1VPWDJZMVVsYU5y'
    b'YmFqKzF5T2YKTENVanR4WWY5cENoRzRSSHV2b1JSUUlBTkxJSEppVldiK0xuUDhqZjl2MHhi'
    b'ei9UTmZjSDJkOFVLUGRaYWRHaDRWTE5yWDM5SWlsdwoyRzNYMG5tNktLT1IxVkozdTBWOXlR'
    b'dDJvN2RBQlVhSzFMdXU0SDBIRDN6bzlMMTZzdk9zdnZjdDh5UU1zQ3k5ZlczZDFRakJJN0hy'
    b'CkhpUi9TdW5TMy9DQ1JrKzhJSkV4eFhVeDhYR05zdnRWMTFXTjVSTFBtaTkyVHIwcDl6OEtk'
    b'YXB5eTFONHY3Z09jQmFiVVZPcTBoUW0KRUhDMDRiRWJKQW1CZ01xZm56TnI1S1pkdlB0RnJ6'
    b'bGFkSlhMYXU0RUk5RUlVQmo4aFIzVjRtd0RUZ1BHQ0p1a29SNDFJZ1IxWlVwVwpKUDFraE5Y'
    b'RnVkS3JpOGIwS2hvU1dET211UVExZFQ2M1VXQU1ualVCNE5MS3pUUE5WV2VaampZSUNQbDFE'
    b'UVBEbXBLQ2VNWUl4WmhNCmdhSklNNXFpRWhFNjlyb0h2ZXNFZ0Z5WlduMWpCQUNLM2R6eE9N'
    b'VkZLZTJDekJmY2txWVJOWmduenkrNXV5eC9FOTF0SGpjamw4MG8Kd3lFVHd3MzhYemJ0RlJT'
    b'VktDdFJOL0lMaTR4N0xOZHE1WTNQaWxYNDM3eFBMTWcvZnpiNTZPSWxTVzY3MWFsUnFSaURl'
    b'Uk5qNEJpegoxS1BsUkZMVGlicFJJciswdDdETEd2S3J2a3JGNXRZektScUgyRUVnT2E5ZWMz'
    b'VmNsOG4raisyV1BQbjMrcHBHcGFvdGhJVzIvL3ZNCnhrU3ViTnM3UFR1dzY5Z0xmRTV0dExq'
    b'L3g2SHZUUi9SU1pPWXBuRmJEOWZhelVJbE5MRWRtb0VBSUpHbE5CMDlucmwrbGUyYXM4YWkK'
    b'ODFVS096TkgwUmdqcEtrSUFDZ1NteVlpQ1ZCMXBPb0FBSlpLcGY3SzJMVFpHZFpxZEVmWThG'
    b'NkJPeTZYb2FabFphcEc0MzB3UGZkNQozV0g2N2drbEUydUNBc2RVK3R3WFZ3aURMaEE0VTJJ'
    b'Y0YxZnN5QlJJVVNIeVJhSzYzT3h6ajNOcC9aUGNuYkpDRkdWQzB4SEc4TlBBCkgwcjAzck9H'
    b'YUhwU3dlN1M0SnI0d1pIRnhCOUtXWVZnS0N4d1ppak9DS3haNGRONm9veXFvLzRrRFFBVlB0'
    b'WEtHNUo2Z21IdzQwVEYKOWczVmNnazN1dmg1RWM5Q2pxcXBPRm9rY2RHRDY5Y1lOblI2N1l3'
    b'UzlHbzJ3VXhrNlYxUi93RnV6STNzTXo1THdTcVlXWkhFR0FEQQpRaFF2elR4V29vWFBEdGVo'
    b'ZldyWHB1ZkdUTWlySXd2dGZ5cE5yWEkwM0JRMVRGQlV4REk0WHlSWUJtTUFSVHRNcnBYRGVM'
    b'MTFFRWlHCnhZMmp4S1Q5QWxCN0tOOVRueE1RRHlheXYzL3hOWVlrRUdEWndHc0tGcUFiajcw'
    b'Z25MYlZlckt5aWt3VDdUMG85REYxbGRiTVd1dkYKNXdjNmVxSk1VU0hzZ3VHeUdic084Q3JE'
    b'RVY1dlJhWWx6MXRsMW5sR1cvVEJLc1U4cnhDc2tRQUFFRlIrSTViS1VzbGVwc1NwRDYrUwpQ'
    b'WFk5SzVJQ2F4WWxncVhOUS8vQ3NZWnRtRHc0YTBjNHAxamRwWk9BRy81RnBrSUhhb1o1cXVx'
    b'RmtqTEI3dUtzZy9YWnF2MDFqWTZvCmxUZDdrL1QyYk8wRVc5dDUvcTV4enM1UWpFbGthYWZW'
    b'OERpTWZKSDBPWFVDNjdkVnZMalAwanprTEE4OTBXNGFXNnFsUGE5NU8xZTUKTno5UUVYNDZZ'
    b'SmZJN0I0TEFQUW5hZE1FRzIrczMyTzE4R1lpZS9obVVsU2s3eG5NRG9HUnBESXN5d09pUDcv'
    b'SFZzSTdvY0o3eFhsTgpGelNXTlpjNXQ4dURmVFRMUVNSdnphcmNwMzIxdW1LeXBORnlRTmdY'
    b'NG5RRGxYcFV2MHRMWnNsRWxsUTBOSzR5SmViMGI3RlBuUVd1Cnc3YWZnOThGYlFCOTFXcEZO'
    b'MU5vTGlnVWhqUjlZTFhUTnI2d1k3L2dkK3VUaG9zY2FYcnRKZ0FvQ3FGcVNFOE1IZ2JDQUJp'
    b'ZlRJK0MKcVR6NjN0NXhRWGN1bll3WEZUQ3FCczNKTkl6MnRNdURpVkszRmsrcUJrYlZBVVZX'
    b'Q1FKaGoxMVBaQ2xKSWNwS05OTUVDMk1zNzU4eQoxYjNwcmVUV1RzdkVzMERlSVlDeWJnWUE5'
    b'R0VTdTlKdFcyK0xORW1tWUpZM0ZHMkNXU2lRcXplNFNqZ2NSa0l4ekZaVlNVeFFGU1BNClFL'
    b'SVJJTUFud2JWSUNmdXMxUTh1R0xWejU4Nlh1OFQyakc5d3VkVkNsZ2o0L1BMOTRUZzl3b28r'
    b'Q0kxWVVyOGJNSEFjTGtoa01rZVgKZWRWUWpLbndxUURBUStFRzhWbkZJcHhObVdGMlZCRkxo'
    b'QzFKQWdDdVVDdkdGaGdTVWlrNjNNTk9tNXB6QnBXSnN6T09EeHpVZzJYMgp6WU9ESVdDTThV'
    b'a1JEUUFKNWJDN2owckc4WDh0U0tRTHh6TUYwaWFZQklIbjFuVzl2bSswaWJFb0VlRTREWUNU'
    b'T2NyS213eU5SWm53CjJaVXJ6V2ZPcGhROFY2bVlVL0tXdHcrWEw1d2YybmU4V0pMTWsvMDVx'
    b'aWlUTHJmV01FSWtDY3hmbmpEUkNYWURDSXd3Tms2UzZMaHMKQUlDdTYzSDlCTk5aUEd5dlFi'
    b'Q2xIczNLbXlWT25jZkZLMGJzK3FCM0ZNWXd1bFp5V2cyV05pblNaR2t6bGFWRzJFSmh5ZXNU'
    b'Tzg1bwpIMjBTS01YcjVHV3A3QmFyWTJiTzhveVBVUStUeUd1STlHdDFaUXFBMHRQRGJkbmdj'
    b'RnQxVDdrNmZFbHlqMGdLZi9NT0p0cEVnUEhKCkVxMFJxcXJtOC9rb25FQXR1QVZsYXpUb0Uz'
    b'S2FqandPWGRFUVRTRVRzTmVoNTRxa2FRSUFsRGoxV0pvaVNlekJhYzVDeG9pNk05cWkKVTR0'
    b'U29WTE5PeTNubUptVjFqcU9zQXdBT2dLaDhYRGVVVmtwdTRPcVRPSmRuOWdCWU9RMU1lVzYy'
    b'UEd1Z3laMFJTNWlVLzVpTjgzYQp3NG1VYVpxOThvQ0ZNZkhoQVZ3ellaOUNDaHhqVWlTMkNT'
    b'WUFMR3JvM0JMMml4SUJBRGJCVkRTaUlKR2FnYUlwNXZhU1A1RllQNk9KCmRqWVZ4OTBRNWF5'
    b'R1pheG9MMUVIT01wR3FiVHVLR1cxbFpLMVFEcVdlZGYvdktwN283MzhnclFhMEFacy9DRGdL'
    b'RFViMndMRkhhYngKQmYxaVJFUkZMWlBMUjVGd1FxS3R0UEppKzBRTGI2b2E0bWlUb1hFdXBX'
    b'VU0renY3Ry9aRmJiS0tPbnRaakNFblV2Mks1K0hRdjlCWQpPNk9KbGxhNERRU3hLSlBmYWNI'
    b'SEFHTUFZV0g2YU9xb29qMVBsdXIvcjhLVkpzdTNXN0NFTERZaitJMEJSczFpeUxVSklINEM0'
    b'cWRxCit4ZHJnSVJpeGtSWnB3YVVBSTlVOGo2Tk56ekozOU9ic3dKQVZpUVZGWkVFcmlaRHRa'
    b'YSs3YWtha2tKZWg0NHhsRGkxMmJVOUkxR0wKVEZyT2FLSnR1M21wZ3hkM1d1UnRGbTZEL2Fo'
    b'TG1WaW9uWDI0MmluTFJOc0RsZmEzWGZSblJpTys1NG9ubU14eFJTVjVod1duWHVmbApGZkx4'
    b'bXVUNHRDVWNEeGUwUWRMYndDUUFaQ1ZtUlg1T1hLaDlOSFZqWDhIaHRCcTZnVXlNTWlwdldG'
    b'eTN6ZGk2T3RTQUVMWmJUSzlECjEzUWdTRHhjM1hhbXE0N0lib3ZRVHp1OU92Mlo1OGhWSzNX'
    b'MzlCMVJGdnYrV09yY09zQmVISzNXK0tQVnlkY0diNVdhbSt3dXRGUHAKSy9DdFgyelJ2VHFO'
    b'cTBhVFlCNzdwUTVrT085NHBHWE9zOFZyQWVCcDh0WS85eTFDQ0t5OHlkSjRhNnh5bUNYYzFj'
    b'K0NybUVnSEZZagpscVpNakVaNFUzUW1jcExwMGorTTZPcnRGbWl4Q2pPejZaRlN4cWRuSitl'
    b'RGQ0VnQ3c094NVdBUEJ6NDExMXdvVHNsbG00cEZGZ01BCm1LWjlCK1hvR1d6UnRoUVpldHVU'
    b'Zk0zTG5NUnBFSjRpN0RReTBJQ3l0WWFwM3gyODhoRjhSNEl1UCtUS0Z3YTIvYTExVkNoR2F3'
    b'YVUKdTR1SkRNMno1a1hEOW4vUTF4UkxVNGFKYkx5eHlQdUo2U3dCaElhV21TSE9ER2tUNkJp'
    b'VmZUaklUYzNUY3hXaFJuR1ZLa2RUbUNnego1cHI0VWEyZG9udGY4K1QyODZXdC9JbmgzbkR4'
    b'RW5reS9iNGFKemtDSDFlWkloOVR2eWNLaC9jQlNGMXA0THFtTm1vZmhodXZxR3Y1CnBJL3cr'
    b'SFNlTlFzU01hTzAvZjN3eUtuQmJsSXFZRURmZGo3M3cyTHpXWkN3T1BvWi9sVVBmaUtZM0dF'
    b'WktBOEdjR0YzYXlPK0ZlRm0KWmFQT284SkNBeWgrWmsyQ1NOTG1RSUVCVUVCQTZPcWdIanNN'
    b'UzR0bUJRREFKaktPYWdhUlBycmJ3cHBpbCtnLzBFdlBDTzUvYnZkNAoyYURzZ2hIUFVMMEpK'
    b'cDVBTTMxN1d4TytUL3NxR1FaZDZWMDFXdHQ0RnRRNkFDQkxvV3lWcEdXcGlnSnBzeDdtRVI5'
    b'WDRGY1Vna2xRCjdneTV2YW5XZWRrU2NsaWRiclVxaG03bWk4YStEajBTVS9KNWx1ZVJ5MEdX'
    b'bEpDbGZ0UGxsREgrU05CNk5iMGpaM1lXOUxTa1p4WGQKeWxCQkN6WEtTVFhaS1JhcmVZTm9G'
    b'L0hhWEdRWlZCK05ycVRWUTZacS9YSi9rcm0wZHRlem00ZlRGRGdzUm9sVEw4cWt3NklUUlBl'
    b'YgovWlB2M1RmN3Jxcm5IdkQvY25IaWJ3YkJudWxFZzFmbHk5WGd0TndSbGdGQTJtMDU0Tllx'
    b'aDBrVWlRL3RmV3g1dzBOK2FyY0NxRFFWClc3OVJXZjJSZytNUUlycGswY2J4Tm4rQUt5bkJz'
    b'cXoxUldQYld6UnNDQ3pMay9RRE02OHNGa1dydzE3bmRkWllHQWNqU0pyZUp4bHYKdGZhdlFC'
    b'Z3h2S2xLQkNMdHhnQTVIRlQzMTNyemlTd3RjR1kwVFYwenZ2MlZyZ2szanR5MHE1TVhPRk5T'
    b'YUpiQlRENTZmcFgrczRQZgp2Y3o3NFozVUEvY2IvejVVem5yb2ljWUFKZ0xOUkpsT3RpNXc5'
    b'QjdQWkNoeHMxWDgyTGE5U21tK3I5c3cwSmIvcVBhMjhvSUpBSUE5CmJ2OHQzMGJoUHJVdnlw'
    b'R0VzenlvbDNoWlRTZmtvazVRMkNMd0NKUEpqTnJiVHl2S25GcFByYTNVamRRVVpwS0tXVFNR'
    b'aDZlYkhQVGwKRldVZElrNnBVTUlSOVR6K1lITmtRS0NXOS9iRTJJQkxpMldvaGdybGpzMVh2'
    b'NE91R0JhNXM5YlpreStTTldWS0lrTUZuUHI4NEJZZgptN216N3g0R0t6eVpreWpIbVVpMHhP'
    b'TlVoV0p6YWVQdkNSMFdzeVlpQ1F3QVRxZk9qeE9kN3prS05USUF0RDN2Qys0NUdnUE4xdmIw'
    b'Ci9ROWFhcXZCN2RZRlh2dHdYYTZqTXlNV0tBd0dnWGlTc2pzY2RLbWZLUEZxZGx0S2hRMEh4'
    b'SzVVWGk0VWFJdk5KdkNTcWluNWpNZnQKR3VFV0hEVHF6dUZuVThWRWR4SHFqNUV4RHFJMnFI'
    b'U0UyQUxsdm1mYnpFZXR2OENJK09QK0MrOXNmTlZuVFVSVFZGRWg2bTE5Ny9jMApYbHJmc3M1'
    b'ejg4cm8rRzNTK3Q2MDhHZCtLVWJrbVVXMHlCclZOMFlJQWdQQXdYWE8ySWZPcUZPZjlhLzlC'
    b'SWJPSndMK0RYWUZnZi9yCkNRQkFDR1FHYzUvVlEvQzQwYzQ1Yy9SOSs2RXZJa29TVjFmdG56'
    b'NHQ0SEVXQUt3MHBXZHlFRXZva1NnUmp4ZTdRd2NxcGd4M1VGOHIKOTFYeFB0SlVDNG9oMExS'
    b'T3Vkdnp4dTZNMWxrd3ZReGNWZTlNcWZTT1k1MVpxdjNsWFUydUV2TEI4SFhiTFhNd0lnRGdS'
    b'ZXYzcjA2dgpyS21JMDVTWjZ5YzVDOVhlWDdZdkUyMXd4a1lMKzkvSXpIdUhYdlRWV1I1Nm9r'
    b'Mm5TYnQxVDBERkdESXZld085akkwelA4bFVWSVZZCmxDWVZncEtSbm42d3pQS1RVTk4xMGZE'
    b'SVl1b1ZMeEVuSFRHbWROVTZ4enZyamtGYWUxaDRIRjlSQVhoK3hwMW0vbkJjSlJYUnBvdEYK'
    b'Z2xRNWZzQkJ4UlJ3dVRya01ZN1FoRHd1bFhUL0t2TE5GdXZNMjFmKzBWWE0vM1g4d282cXl0'
    b'dVR2L3daK2RBd3ZtZGlSZS9yZThyZgpUVXhKY2xWWGFPK3hvR1JOUjV3dUh4Sm1odmpZTHBV'
    b'bnUvcllpcG01ZUI5THZsUkNBREE2c2tkcFdhVklqN3ZyNS9jS1lsNU05SVNpCkRPM1ZndzNG'
    b'd0x5TVkzNm1yMVhBY1pvNTZXVi9hTTYxK0xNWWhTbEdaaXdHelIwZnRVZ3BiL0QyT3JYbFp2'
    b'b0pyYURjWUhzNXJBWEMKcU1iYmxibW1oaXViTzNYUjg0OWxUT3FUbXJsSXpCWlY2bzM0ekJx'
    b'bWQzMTJUQnMxN3BuOE5iOFdiNDlvWHBteW5ZayttalhBSHFjSQpoRG5lakZRcDdvTXNBSWcy'
    b'cXo1KzdQM2p2NWJ1TXVxcDB2L2J6WnBRRzI4eCtpYTFuWGR0SDBsamRXNGh1RWZvSktIT0dN'
    b'ckJJRU1qCnNINXo0U0ZiTnJ1MGJNZG1lVnlGb1AyQWZQUTMyci85VkExbWNtWFRicjd6emxY'
    b'UFRudXo4N1pMNzFvaHg0dU1leHhjbTNmWGJxT24KSHc3ZzdKQ2RvUjc2aElVcmtKa280M0Jy'
    b'b3gvc3pGNmNBZ0N4dlBRN3pkZk1lKzI1SngvK2tTTVc3bXRxNnZuSkhhUGZlK2VGV2N1Lwp1'
    b'L21XdFZzbjYrMDJBUEJpRkNhSGJoakpiczNtTVJERjlWcEZjdjdkbVh1cmFwZmVldVV6WWYv'
    b'RFFiT1lJcmxleXZtNjZyano0dThVClNyd0FzSkI4NTlmNE8ySWVGV1dTTXBRaHAyWG9UL3pU'
    b'RXBISTBHUzFZckViaVJTTE5sbEpra281aERsNzN1MXFLT3l5amFPK2RaSFUKdlh0MXI4NXUy'
    b'K2hZMlZyYUczQjlIT2NBTklyUU1VUUlLQ0RBQUFZQzliT1Bob0E0eGlpT3VBNWs2RXcrUmlx'
    b'Rkl4K3FrS1NsakNQZQpNNk8zazZTNWhOMDcvYU1XaTBLVzdkaEtDdFFIa1V4QlRkVUZxZFor'
    b'Y1pUNWRvS3R2NkJuOXdwWEk2VVY3NHIvWEV0VDFhNmVlcUkxCkMrNGVzdTVNSnhvQU1obDNk'
    b'N3o1ZmFuQjNCak1jcmJvMUduWmFTUGt5YlZxOVd2ZTBoNHozTG1PRXRNdzRmcS8vRDU2dlJQ'
    b'blZyWGEKWmowKzc2cFBMcjFoY3R0MmQ3N2dBTUFBNGpGRXF3Z0tDT0lFWUFBZTRLRTUxOUs1'
    b'S0YxSUVKcGtjSFpNTVljL0RLZlpTaXF6aVpkZgovR1dKbSt1WjBNem4rcnZzMUhqYlk3NTY1'
    b'L3hsbTM0N2FrRWc4UXNrUmVkWUg2dWoyK1kyemlGYzFLVjd0algwN2lVVVpxZHdRWGwvCmY0'
    b'cmk5M0pqUWtOTjlDbkpEQXVOOVk4MExmbXVUYW4veFhscnQ3US9xNVlzTHV3clpuS0UvNXNx'
    b'K0ZnYzdVM1h6WkN5Z0V6U2dvem0KckNPMzhwdUcva1pVdnZYVzN6N3l5cStkTzNkeW1zNDBq'
    b'MGNVWFloK25LdE5PdzVZM0oxV0FPZ25JQXZBWkNNNmExVWRBUUNZaTEvdwo0dkFlYW5HRnRU'
    b'S3BFZjBIRHo3ejBpOUQ4K2I5Zk56bFU3SnI1anYyVzhpL1dGaWpxQlJ4S3VPSFlvU29xL2Y1'
    b'Tk9VS3lreUZFMklSCnVkZE91Znc2Tmo2M2VmaUdUYjIvVDR3ZjJidHBrM2YyV2VBNmlnajZT'
    b'TXRhYTlud2p6N3N6K1JlU2dxM0xuKzZPaDYxOUNhazBTTU4KMXNVV1ZzbEs0VVgreXFzSzNk'
    b'WlA5OGkwcUhoa3c3NjdWbmo3Z0ZiMnd0aWI1K1FPRXBsMDVTdlBCVzY0ZHF1NExCTFlMK3gx'
    b'UUphVwpFZEFBWVFxVngzcnUrUGlWUlRzL21OUzFxMUhjTXNHemJFTFoyQWVYWERKUDdWOXcz'
    b'MTJKQytmZlB2cVNHZklqaTdsZjhOcE8xYUQzCjVNYU9Xa25CQlF2dmMwNjVSSC9JeGhDRWJY'
    b'U1dERzZXNjdhYUZUMEt2Q2ZaK2lQUmw1SjhmMEZ2Q1V3bUZVbGorRE9YNkR4QnhJTWwKd0xM'
    b'T1pOd3A1VjZ0Yi83dXNqK1BaSlgwekdFUjJKR2ZHb2JPajlIR0QwcEQrU2tmNWZkWW12N1Vm'
    b'SW03ZWtUalRqTDRBZU04LzZjMApickQxUGRzQmxjdkhYenMzMjZVOC8zSW00TndmL3g4bVZo'
    b'YllZU1VSclFXRGlZb3FxYm91TmF6UkRKUnhIRnZaZThDZk40dEJwVUNaCmVyTE0vT0hkQnkr'
    b'NjhMYmhsNDVLUE5Hc2JMYlYvc3hXWEdKNVNmRlJFejZaZTlVOTN2T0pZaVpPVkdqaXdmNXdx'
    b'eGZ0SFlkZm8wMXIKcGQyUkF2dHF6ZU9NZFJZZC9ndTdOdi9tL1NjYmtsMHRqdklpYnhzcWNv'
    b'YnlHWmFuTDcrMjNWZExPYTIzUFA1ZnBDeTlNUFBDcFN2ZgozTGowc3BpL2xrb2RzSW82SzdM'
    b'bi9Yblo0WElvUWF5cUdmVngwNVQxalJPWGFwME5tUjQvZ3E3OWo4cGxsYzlOZWpKbDByOVo4'
    b'NlI5CjA0YVd5M2N5dzZaTm4vWGM3cTI3cnQvRFJQeTFSNlNiSzkvLzZreG5RNmwzMWR2VG9F'
    b'TWN2bko0Nkp2WDMrYWZ1Y2doc1owL2FhRW0KWGRSMHVlT2pEM2I3NjE4Z3ltUURWQ0Iwd1hs'
    b'a3REOHEyYlV2WGh4blMwdEVYYXZHdkowcHVhcHQ1VFpudy96RTN0MWpKNE9zbHFmNwpuaXVm'
    b'ZFNZU2ZmOUZWMTY0OWVQbkw3M3VqdVhQeEdycS9sVGQvTkFMdnpNUjZoczJUQmVFaWwwN0ZZ'
    b'NFhpb01QT3lkWXl6T1RGMDZPCmRzeG9iOUVKSUc3NVYvL1M3My96TCt0Yk9kLzkrMWMwUFBO'
    b'MHBFYm5QS1BWWkhHL2pHcFRDVTVYcDkvK05CajZ5RlRuN2Z2V3NZTGkKYmR2a1RuSmI3L2pK'
    b'VDRsaFMxektFMHZHL011YnJjdFNBZ0FFOHVFVUlXaWNEWk9ERDB0eWhpeVQzRVFtMzZOU2Nl'
    b'QUJtOE96bmI5ZAovWXlNNGFjWGZUY3I2eGFrZERnYnowU2lpejRQbTB6LzU4VTNGUnVHNStQ'
    b'eC8xajJlSGtoOTJWQkZLK0x2Zk1IYlp2Ky9FTGp4RGZKCnIzK2JpTXp1MlpVemliZGMxZmMr'
    b'OUxOREN1L1F5NnVzYXZaaUpuZlpnYzJJNS85U2RkNmFJblV0UE1hNDVnV0NFKzl0TitRdkgr'
    b'ZHAKS1Z0dTVoeFdTNCtvRjNtM0JXbEo0TTlFb28vNGhBTjJkME1tOFZYcXVKcEZiMS9Tdnk4'
    b'NzRTM2grcTFWVFU2MStLTjNuL3BheDNZNApobWdBb01RMFJaQUdtQmpEWmNTamRpYi9IUEdm'
    b'S25CZm9jaHJVbEplRnh3dzFBMmR5YTlqd3dRZzh3VGZuL0IxYkFRWUpwQm43RnorCjd2MUZC'
    b'Z1BzNUVuTWlBYkM2d0dNalVSS2E5dW5iTmhzOUVlL25LejVDampIc253c3psUGpQREhaYkVt'
    b'cmE2TnlXRHhjSHpsSmxpc3MKMUV3L084Yk4rRGdDWXpnZTV5VGJsOFVaU0RSQ3pLZ1IvUHc1'
    b'M0x6WnpPZ1RXVHJHNnU1VytmMDEwbnVyMWQydGYvZnd3eW5HdWVtWQozWnp0U1hWNVNIb3pW'
    b'TnllVlAvZVVRd0VNTjdETEtrUUZsZndFenpNQ1hlRlRqVU9Dbzg1bi9TNDZSR043SlJKL0x6'
    b'WlpLbi9lRklPCnpYblExMFovVkhwL3RiSmhxOWJhYmlSVEFIRGFjREE2d1VaZVdEU1doNHJy'
    b'b3NxdXRCcVREUUR3Y2VRWUZ6TXJ3RjVjTHBSYnlPTkoKT2NUZDZjRkJKendhcSsxcGs5NWZv'
    b'NnpmcExaM21Ja1VBQkJlTnpPOGdaM1N6TStiVFk4Y2ZwTDMxeW5DcWJ4dmhZOGpSN3ZvV1FG'
    b'dQpjUVUvenMyY0pNNk9sTG84SksySnlMdlQyaEVTVHcvT1VhS3hxaW9idGtpclBwVGVYMlAw'
    b'OW4rZTJ5MHI1ZWZONWhmTVphYzJJL3E0CjUvcE9QYzZnWUZocG9SWlg4RXNxK2RrQmppRUcy'
    b'NVppNExWUitjMGVhWGxJNmhFLzd6enVLY1ZCdWNlZk1xSnhyYTFEMmI0VEY4UUIKL3JzOFNJ'
    b'OW9JTnh1QURCVEthMTFueDd1RzdCS1ZnczdZU3pkT0l6MGx3REFhY081ODdLbGNkbllsZFlP'
    b'RmdaTTJFWVRVMHZZVVM2NgpsQ2NCb0Y4eVd0THFocmlhMXdab2x5b3JOY1pGbDNBa0FKdzJu'
    b'TUh5RGxFVU83V1pueitIbXorYktpOGJ0Rlo2dUZkYXRWcCtmNDJ5CmZqUFdQMjlWVHc5T2Qw'
    b'Ri9NeVF0RHhYWFJoVE4vTHhqaVRTQlpnWFlRM0dzMmtxZGZwekRSSk9sZm5aS016OS9OamQ3'
    b'T21INzRrcUsKbWMvTGF6NldWcTFXTm00NVZxajlvM0N5cXZsdXIvUm1TRm8zVUdDVlc4aFpm'
    b'bTV4Qlg5aEdlOWdpSDhnRGxJN0RwQWxIc0poSCtBZgpkVjNac0VYWnVFWGIyMjZtMHdCQXVO'
    b'MzBpQVoyU2pNN2VTS2lCcXlrbWMwWjhTUUFuRGFjci8rZjM1Unc1QmdYUFN2QXpmQ3o5RUIv'
    b'Cm1sYk5RNDluK1huU05aQVV6Y1Ryb3NxNmlMd3pyU1ZrQXdCT0c4NEExV0htOHZLYWo2UlZx'
    b'K1hWSDVtNS9JazNHZTAyYnM0TWZ1RmMKYnRaMHduNWlXenZWT01jR1F5ZERYRlRPWDFMQkx5'
    b'empuWC9IMWpLZjJkYzdZU21qbWllODVsVGpJSG56ZGpPVjB2YTJLeHUzS0J1MgpEUEtZaE1O'
    b'T2VEMEFZQ2FTWmpZMzJIdE9tY1JPbmtRM05SNE5kS2NGWjg0UG40aEpSbnJnVkdrQ3pmU3pN'
    b'd1BjMkdNQzFNNjB0aTRpCnI0c085cGd1aHZEeEpBQ2NOcHdUMURvSXE1V2JNNTFmTUplZFBP'
    b'bllmTUhvanlvYk5rdnZyWlpYZjJ3V0NsKzh3WDZLY2NLaXNUWXEKdjlsVGZMZFh6bW5tRitM'
    b'WWFlTENNdTZTU21HbW56czI3emc5T0VlSnBzcUQzTHpaL0lJNTdKUVRxTm9CSGxQVGxBMmJE'
    b'OG1HUVVMdApINEtqbW5odFJIa3pWRndla2dZSnJFTWliSEVGdjZSQ21CVmdqMWZIcHcwSEZW'
    b'NWNSbmk5OVBCaFZIbHdBQXNGVWRtMlUydnYrQ3hBCmVlbmg5ZXo0c1dqZ2V4cjBjSy9XMm1F'
    b'bWt3QncybkQrYThGTkFaNGM1V0ttbERBMm1oZ2tzRm8reTliOEhEbmFSVmNORkdGNXpWd2YK'
    b'VjNhbnRVT0I3clRoREU3QmpiNkk5TUVhYWVXSHl2ck5XQjE4c0I0eEREdTFtVjg0bDc5Z05o'
    b'a01mTTZxbmxLY0k4R1FKZEhzQUhkSgpCWDl4QlY5aCtieEtmMGpVM3dwSmI0U2tOUkZaTVFZ'
    b'cjVkT0FnL0NSMHVYR0xmTDdhOVRkclNlWjd6T2ptN2g1czluSmsrakdZYVRYCkRRQ25EZWVF'
    b'OWVnSkhtWnhCVC9UejQxeTBUNk9CSUNZYkxTa3RYVVJlWGxJMnA1U1QzSThwd2dIOVZTTkJ1'
    b'TXJIM2tqU1FBNGJUaGYKK0Rzc0pBSUFNTDd5RTJ4RGlFTU5BVHREUXZHUTRoaEQ5SkRnRU9L'
    b'YyszbVEwOVRPRVgyTzZITkVuMnZuaUQ1SDlEOTkrMTlURndGVApyeVpMU2dBQUFDVjBSVmgw'
    b'WkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TkMweU9GUXdOVG8wTkRvMU1pc3dNRG93TUFEQnRu'
    b'NEFBQUFsCmRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNRFF0TWpoVU1EVTZORFE2TlRJ'
    b'ck1EQTZNREJ4bkE3Q0FBQUFBRWxGVGtTdVFtQ0MKCiIgaWQ9ImltYWdlODM1IiAvPgogIDwv'
    b'Zz4KPC9zdmc+Cg==', 'RU_IVA')

RU_IVA = b64_RU_IVA
index.append("RU_IVA")
index.append("Russia Ivanovskaya oblast")
catalog["RU_IVA"] = RU_IVA
catalog["Russia Ivanovskaya oblast"] = RU_IVA
country["Russia Ivanovskaya oblast"] = ('RU_IVA', '', 1)
lookup["RU_IVA"] = ('RU_IVA', '', 'Russia Ivanovskaya oblast', 1)
lookup["Ivanovo"] = ('RU_IVA', '', 'Russia Ivanovskaya oblast', 1)
lookup["Russia Ivanovskaya oblast"] = ('RU_IVA', '', 'Russia Ivanovskaya oblast', 1)
details["RU_IVA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Ivanovo"}
regional["RU_IVA"] = ('RU_IVA', 'Russia Ivanovskaya oblast', 1)
regional["Russia Ivanovskaya oblast"] = ('RU_IVA', 'Russia Ivanovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_KAM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMjAwcHgi'
    b'IGhlaWdodD0iODAwcHgiIHZpZXdCb3g9IjAgMCAxODAwIDEyMDAiPg0KIDxkZWZzPg0KICA8'
    b'c3R5bGUgdHlwZT0idGV4dC9jc3MiPg0KICAgPCFbQ0RBVEFbDQogICAgLnN0cjIge3N0cm9r'
    b'ZTojY2NjO3N0cm9rZS13aWR0aDoxfQ0KICAgIC5zdHIxIHtzdHJva2U6I2ZmZjtzdHJva2Ut'
    b'd2lkdGg6NX0NCiAgICAuc3RyMCB7c3Ryb2tlOiNmZmY7c3Ryb2tlLXdpZHRoOjg7c3Ryb2tl'
    b'LWxpbmVqb2luOmJldmVsfQ0KICAgIC5maWwwIHtmaWxsOiMwMDUxQkF9DQogICAgLmZpbDQg'
    b'e2ZpbGw6IzAwMH0NCiAgICAuZmlsMyB7ZmlsbDojRDgxRTA1fQ0KICAgIC5maWwyIHtmaWxs'
    b'OiNmZmZ9DQogICAgLmZpbDEge2ZpbGw6d2hpdGV9DQogICBdXT4NCiAgPC9zdHlsZT4NCiA8'
    b'L2RlZnM+DQogIDxyZWN0IGNsYXNzPSJmaWwwIiB3aWR0aD0iMTgwMCIgaGVpZ2h0PSIxMjAw'
    b'Ii8+DQogIDxyZWN0IGNsYXNzPSJmaWwxIiB3aWR0aD0iMTgwMCIgaGVpZ2h0PSI4MDAiLz4N'
    b'CiAgPHBhdGggY2xhc3M9ImZpbDIgc3RyMiIgZD0iTTM4My4xODQgNDczLjAwM2MtMzguODM1'
    b'OCwwLjA2ODUwMzkgLTY3LjAyMTcsLTI5LjYzMjcgLTEwNS4xOTMsLTI5Ljg5MDIgLTMzLjY4'
    b'MDMsLTAuMjI2NzcyIC02MC4wOTkyLDI4LjcwMiAtMTA2LjkzMywyOC40NzI4IDAuODg3MDA4'
    b'LC0zMC43MjE3IDAuMjQyMTI2LC02MS40NDMzIC0xLjkzMzQ2LC05Mi4xNjM4IC04LjQ4Mzg2'
    b'LC0xMTkuODAyIDk3LjM5ODQsLTIxNy41IDIxNy41LC0yMTcuNSAxMjAuMTAyLDAgMjIxLjU0'
    b'Niw5Ny40NjgxIDIxNy41LDIxNy41IC0xLjk5NzI0LDIxLjA0MjUgLTQuODIwMDgsMzcuNzA3'
    b'OSAtMy4wNzc5NSw5MS4yODAzIC00Ni43NjQ2LDAuMDY2MTQxNyAtNzEuNDI5NSwtMjguNjU0'
    b'NyAtMTA2LjYwNywtMjguMjcwOSAtMzYuMjkyOSwwLjM5Njg1IC03Mi40MTkzLDMwLjUwMzEg'
    b'LTExMS4yNTUsMzAuNTcxN3oiLz4NCiAgPHBhdGggY2xhc3M9ImZpbDAiIGQ9Ik0zODYuNjI0'
    b'IDM3OS40MjJsLTIwNy4wNTQgNTYuMDIzMiAtMS45NDUyOCAtNTYuMDIzMmMtNC4wMDM5NCwt'
    b'MTE1LjMzNyA5My41OTE3LC0yMDkgMjA5LC0yMDkgMTE1LjQwOCwwIDIxNi41NDIsOTMuODQ1'
    b'NyAyMDksMjA5bC0zLjQzMjI4IDUyLjM5MjUgLTIwNS41NjcgLTUyLjM5MjV6Ii8+DQogIDxw'
    b'b2x5Z29uIGNsYXNzPSJmaWwzIHN0cjAiIHBvaW50cz0iMzg1LjUzMywxNjQuNTQ1IDQxNC41'
    b'ODcsMTk5LjI5OCA0NTEuOTg3LDE3NC43MjQgNDY4Ljg4MSwyMTYuNzU1IDUxMi4wNDIsMjA0'
    b'Ljk0MSA1MTUuMTIyLDI1MC4xMzUgNTU5LjgyMiwyNTIuMjM3IDU0OC43ODUsMjk2LjE3MSA1'
    b'OTAuNjQ4LDMxMS45ODMgNTY2LjU3NCwzNTAuMzU1IDYwMC42NTEsMzc4LjMzMSA1NjAuMTMz'
    b'LDQyMS43OTQgNTkyLjUwMSw0MzYuOTgzIDM4NS4yODUsMzk3LjgwNSAxNzkuNzE3LDQzOS42'
    b'NzIgMjExLjgyNSw0MTUuODgxIDE3MS43NDgsMzgwLjUxMyAyMDYuNSwzNTEuNDU5IDE4MS45'
    b'MjYsMzE0LjA2IDIyMy45NTcsMjk3LjE2NSAyMTIuMTQ0LDI1NC4wMDQgMjU3LjMzNywyNTAu'
    b'OTI0IDI1OS40NCwyMDYuMjI0IDMwMy4zNzMsMjE3LjI2MSAzMTkuMTg2LDE3NS4zOTggMzU3'
    b'LjU1NywxOTkuNDczICIvPg0KICA8cGF0aCBjbGFzcz0iZmlsMiIgZD0iTTM4Ni42MjQgMzc5'
    b'LjQyMmwtMTY4LjI0MyA2My45OTIxYy03Ljc1NzQ4LC0yMC40MzY2IC0xMS43NTY3LC00Mi4x'
    b'Mjc2IC0xMS43NTY3LC02My45OTIxIDAsLTk5LjM5NDUgODAuNjA1NSwtMTgwIDE4MCwtMTgw'
    b'IDk5LjM5NDUsMCAxODAsODAuNjA1NSAxODAsMTgwIDAsMjAuMzI2OCAtMy40NSw0MC41MjI0'
    b'IC0xMC4xNzQsNTkuNjg0NmwtMTY5LjgyNiAtNTkuNjg0NnoiLz4NCiAgPHBhdGggY2xhc3M9'
    b'ImZpbDMiIGQ9Ik0zODYuNjI0IDM3OS40MjJsLTE1OC44OTYgNjAuNDM3Yy03LjMyNzU2LC0x'
    b'OS4zMDE2IC0xMS4xMDQ3LC0zOS43ODU0IC0xMS4xMDQ3LC02MC40MzcgMCwtOTMuODcyOCA3'
    b'Ni4xMjgsLTE3MC4wMDEgMTcwLjAwMSwtMTcwLjAwMSA5My44NzI4LDAgMTcwLjAwMSw3Ni4x'
    b'MjggMTcwLjAwMSwxNzAuMDAxIDAsMjAuMDI4IC0zLjU3MDQ3LDM5Ljk3MzIgLTEwLjQ4MTEs'
    b'NTguNzU2M2wtMTU5LjUyIC01OC43NTYzeiIvPg0KICA8cGF0aCBjbGFzcz0iZmlsMiIgZD0i'
    b'TTE3OS41NyA0MzUuNDQ1YzQ0LjIyOTksLTMyLjQ3OTEgOTcuNDY4MSwtNzAuOTQ3NiAxMzEu'
    b'MzUyLC0xMTQuNzM2bDE3LjAzODYgMCAzMy4yNTUxIDUwLjgyODcgMzEuNjI0IC0yOS40Mjcy'
    b'IDE3Ljc5OTIgMCAzNy43ODgyIDQwLjY2MyAyMy4yMjY0IC0yMy41MDc1IDE4LjM4NSAwLjY3'
    b'MjA0N2MyNS45NTEyLDM0LjQzMjcgNjYuMDM3OCw1NC41MzAzIDEwMi4xNTQsNzEuODc2bDEu'
    b'NzY1NzUgMjkuNTI5OSAtOTAuOTU2NyAtNDcuNTM4MiAtMjU2LjI4NCA1Ljg4NTQzIC02Ny4z'
    b'MDk4IDM5LjU1MDQgMC4xNjI5OTIgLTIzLjc5Njl6Ii8+DQogIDxwYXRoIGNsYXNzPSJmaWw0'
    b'IiBkPSJNMTc5LjMyIDQ2NC42NzRsMC4zOTY4NSAtMjUuMDAxNmMzNS43NzMyLC0yMi42OTYx'
    b'IDY4LjAwMzEsLTQ3LjI4MTkgOTguODE1NywtNzYuNTkyMWwtOC43MzA3MSAyMy44MTEgMTku'
    b'ODQyNSAtMjMuNDE0MiAtOC4zMzM4NiAzMC41NTc1IDIzLjQxNDIgLTI0LjYwNDcgMy4xNzQ4'
    b'IDM1LjcxNjUgMTUuNDc3MiAtMzYuMTEzNCAxOC42NTIgMjUuMDAxNiAtMC4zOTY4NSAtMjIu'
    b'MjIzNiA1Ny4xNDY1IDQzLjI1NjcgLTI2Ljk4NTggLTM0LjUyNiAyNS4wMDE2IDE2LjY2Nzcg'
    b'Ni43NDY0NiAtMjEuODI2OCAzMi41NDE3IDI5Ljc2MzggLTMuOTY4NSAtMjEuMDMzMSA1OC4z'
    b'MzcgMzIuMTQ0OSAtMzIuOTM4NiAtMjYuOTg1OCAyMi4yMjM2IDcuNTQwMTYgMy4xNzQ4IC0x'
    b'MS4xMTE4IDIzLjQxNDIgMTQuNjgzNSAtNy41NDAxNiAtMTkuODQyNWMyNy40ODQzLDIyLjI1'
    b'NjcgNTkuMjUyNCw0MS44NzcyIDkzLjY1NjcsNTcuNTQzM2wxLjk4NDI1IDI2Ljk4NThjLTM2'
    b'LjA5NDUsLTQuNzM5NzYgLTY2LjM2MDIsLTMwLjY1NDMgLTEwMy43OTQsLTI5LjY0MzMgLTM0'
    b'LjUzMDcsMC45MzMwNzEgLTcwLjMzNywyOS40NDg0IC0xMDYuOTMzLDMwLjQzNyAtMzYuMTkx'
    b'MywtMC4yMTAyMzYgLTY5LjY1NTUsLTMwLjQzNTggLTEwNS44NDgsLTMwLjY0NDkgLTMxLjkz'
    b'MTEsLTAuMTg1NDMzIC02Ni41OTY1LDI5LjYzOTggLTk4LjUyOTksMjkuNDU0M3oiLz4NCiAg'
    b'PHBhdGggY2xhc3M9ImZpbDMgc3RyMSIgZD0iTTMxMi42OCAzMjAuNjhsMTIuNTA0MyAwYzYu'
    b'MjI0NDEsLTE0LjcgMTEuODEzNCwtMjkuODU1OSAxMS4zNTM5LC00NC45MTg1IC0zLjY0OTYx'
    b'LDEuNTA4MjcgLTYuNTc2MzgsNC4xOTc2NCAtOS4wNDk2MSw4LjA2MjIgLTAuOTM0MjUyLC02'
    b'Ljk3Njc3IC0zLjEzMTEsLTEzLjA0ODggLTcuNDA0MzMsLTE4Ljc1NzEgLTQuNjc4MzUsNC43'
    b'MjY3NyAtNy42MzkzNywxMC41NDAyIC04Ljg4NTQzLDE3LjQ0MTMgLTEuODkwOTQsLTIuNzkw'
    b'OTQgLTMuOTYxNDIsLTQuNDAxOTcgLTcuNTY4NSwtNS45MjMyMyAtMC42MDM1NDMsMTQuNjk3'
    b'NiAyLjkwNjY5LDI5LjM5NjUgOS4wNDk2MSw0NC4wOTUzeiIvPg0KICA8cGF0aCBjbGFzcz0i'
    b'ZmlsMyBzdHIxIiBkPSJNMzk1LjUyOCAzNDIuMzUxbDEyLjUwNDMgMGM2LjIyNDQxLC0xNC43'
    b'IDExLjgxMzQsLTI5Ljg1NTkgMTEuMzUzOSwtNDQuOTE4NSAtMy42NDk2MSwxLjUwODI3IC02'
    b'LjU3NjM4LDQuMTk3NjQgLTkuMDQ5NjEsOC4wNjIyIC0wLjkzNDI1MiwtNi45NzY3NyAtMy4x'
    b'MzExLC0xMy4wNDg4IC03LjQwNDMzLC0xOC43NTcxIC00LjY3ODM1LDQuNzI2NzcgLTcuNjM5'
    b'MzcsMTAuNTQwMiAtOC44ODU0MywxNy40NDEzIC0xLjg5MDk0LC0yLjc5MDk0IC0zLjk2MTQy'
    b'LC00LjQwMTk3IC03LjU2ODUsLTUuOTIzMjMgLTAuNjAzNTQzLDE0LjY5NzYgMi45MDY2OSwy'
    b'OS4zOTY1IDkuMDQ5NjEsNDQuMDk1M3oiLz4NCiAgPHBhdGggY2xhc3M9ImZpbDMgc3RyMSIg'
    b'ZD0iTTQ3NC40MDIgMzU5LjkzOWwxMi41MDQzIDBjNi4yMjQ0MSwtMTQuNyAxMS44MTM0LC0y'
    b'OS44NTU5IDExLjM1MzksLTQ0LjkxODUgLTMuNjQ5NjEsMS41MDgyNyAtNi41NzYzOCw0LjE5'
    b'NzY0IC05LjA0OTYxLDguMDYyMiAtMC45MzQyNTIsLTYuOTc2NzcgLTMuMTMxMSwtMTMuMDQ4'
    b'OCAtNy40MDQzMywtMTguNzU3MSAtNC42NzgzNSw0LjcyNjc3IC03LjYzOTM3LDEwLjU0MDIg'
    b'LTguODg1NDMsMTcuNDQxMyAtMS44OTA5NCwtMi43OTA5NCAtMy45NjE0MiwtNC40MDE5NyAt'
    b'Ny41Njg1LC01LjkyMzIzIC0wLjYwMzU0MywxNC42OTc2IDIuOTA2NjksMjkuMzk2NSA5LjA0'
    b'OTYxLDQ0LjA5NTN6Ii8+DQo8L3N2Zz4NCg==', 'RU_KAM')

RU_KAM = b64_RU_KAM
index.append("RU_KAM")
index.append("Russia Kamchatskiy kray")
catalog["RU_KAM"] = RU_KAM
catalog["Russia Kamchatskiy kray"] = RU_KAM
country["Russia Kamchatskiy kray"] = ('RU_KAM', '', 1)
lookup["RU_KAM"] = ('RU_KAM', '', 'Russia Kamchatskiy kray', 1)
lookup["Kamchatka"] = ('RU_KAM', '', 'Russia Kamchatskiy kray', 1)
lookup["Russia Kamchatskiy kray"] = ('RU_KAM', '', 'Russia Kamchatskiy kray', 1)
details["RU_KAM"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+12:00","altname":"Kamchatka"}
regional["RU_KAM"] = ('RU_KAM', 'Russia Kamchatskiy kray', 1)
regional["Russia Kamchatskiy kray"] = ('RU_KAM', 'Russia Kamchatskiy kray', 1)
#----------------------------------------------------------------------
b64_RU_KB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSIgc3RhbmRhbG9uZT0i'
    b'bm8iPz4KPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWw6c3BhY2U9InByZXNlcnZl'
    b'IiB3aWR0aD0iMTIwMHB4IiBoZWlnaHQ9IjgwMHB4IiB2aWV3Qm94PSIwIDAgNDUwIDMwMCI+'
    b'CjxjbGlwUGF0aCBpZD0ibWlkIj48Y2lyY2xlIGN4PSIyMjUiIGN5PSIxNTAiIHI9IjUwIi8+'
    b'PC9jbGlwUGF0aD4KPHJlY3QgZmlsbD0iIzMzOTlGRiIgd2lkdGg9IjQ1MCIgaGVpZ2h0PSIx'
    b'MDAiLz4KPHJlY3QgZmlsbD0id2hpdGUiIHdpZHRoPSI0NTAiIGhlaWdodD0iMTAwIiB5PSIx'
    b'MDAiLz4KPHJlY3QgZmlsbD0iIzAwOTIzRiIgd2lkdGg9IjQ1MCIgaGVpZ2h0PSIxMDAiIHk9'
    b'IjIwMCIvPgo8Y2lyY2xlIGN4PSIyMjUiIGN5PSIxNTAiIHI9IjUwIiBmaWxsPSIjMzM5OUZG'
    b'Ii8+CjxwYXRoIGNsaXAtcGF0aD0idXJsKCNtaWQpIiBmaWxsPSJ3aGl0ZSIgc3Ryb2tlPSIj'
    b'MzM5OUZGIiBzdHJva2Utd2lkdGg9IjEiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIGQ9Ik0g'
    b'Mjc2LDE1MSBDIDI3NiwxNTEgMjUxLDEyMiAyNDAsMTIyIEMgMjMxLDEyMiAyMjYsMTMyIDIy'
    b'NiwxMzIgTCAyMjksMTM1IEMgMjI0LDEzMSAyMTksMTI0IDIxMSwxMjQgQyAxOTksMTI0IDE3'
    b'NCwxNTEgMTc0LDE1MSBaIi8+CjxyZWN0IGNsaXAtcGF0aD0idXJsKCNtaWQpIiBmaWxsPSIj'
    b'MDA5MjNGIiB4PSIxNzUiIHk9IjE1MCIgd2lkdGg9IjEwMCIgaGVpZ2h0PSI1MCIvPgo8L3N2'
    b'Zz4=', 'RU_KB')

RU_KB = b64_RU_KB
index.append("RU_KB")
index.append("Russia Kabardino-Balkarskaya Respublika")
catalog["RU_KB"] = RU_KB
catalog["Russia Kabardino-Balkarskaya Respublika"] = RU_KB
country["Russia Kabardino-Balkarskaya Respublika"] = ('RU_KB', '', 1)
lookup["RU_KB"] = ('RU_KB', '', 'Russia Kabardino-Balkarskaya Respublika', 1)
lookup["Kabardino-Balkaria"] = ('RU_KB', '', 'Russia Kabardino-Balkarskaya Respublika', 1)
lookup["Russia Kabardino-Balkarskaya Respublika"] = ('RU_KB', '', 'Russia Kabardino-Balkarskaya Respublika', 1)
details["RU_KB"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Kabardino-Balkaria"}
regional["RU_KB"] = ('RU_KB', 'Russia Kabardino-Balkarskaya Respublika', 1)
regional["Russia Kabardino-Balkarskaya Respublika"] = ('RU_KB', 'Russia Kabardino-Balkarskaya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_KC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9y'
    b'Zy8xOTk5L3hsaW5rIiB4bWw6c3BhY2U9InByZXNlcnZlIiB3aWR0aD0iMTIwMCIgaGVpZ2h0'
    b'PSI2MDAiIHZpZXdCb3g9IjAgMCA2MDAgMzAwIj4KPGRlZnM+CjxwYXRoIGlkPSJiaWciIGZp'
    b'bGw9IiNGRkIwMDAiIGQ9Ik0gMCwtMjMgQyAyLC0zNyAzLC00NCAwLC00NCBDIC0zLC00NCAt'
    b'MiwtMzcgMCwtMjMgWiIgLz4KPHBhdGggaWQ9InNtYWxsIiBmaWxsPSIjRkZCMDAwIiBkPSJN'
    b'IDAsLTIzIEMgMSwtMzMgMS41LC0zNyAwLC0zNyBDIC0xLjUsLTM3IC0xLC0zMyAwLC0yMyBa'
    b'IiAvPgo8L2RlZnM+CjxjbGlwUGF0aCBpZD0ibWlkIj48Y2lyY2xlIGN4PSIzMDAiIGN5PSIx'
    b'NTAiIHI9IjQ5IiAvPjwvY2xpcFBhdGg+CjxyZWN0IGZpbGw9IiNFMDIwMTAiIHdpZHRoPSI2'
    b'MDAiIGhlaWdodD0iMzAwIi8+CjxyZWN0IGZpbGw9IiMwMDcwMzAiIHdpZHRoPSI2MDAiIGhl'
    b'aWdodD0iMjAwIi8+CjxyZWN0IGZpbGw9IiMwMDkwRDAiIHdpZHRoPSI2MDAiIGhlaWdodD0i'
    b'MTAwIi8+CjxjaXJjbGUgZmlsbD0iI0ZGQjAwMCIgY3g9IjMwMCIgY3k9IjE1MCIgcj0iMjAi'
    b'IC8+CjxwYXRoIGZpbGw9IndoaXRlIiBjbGlwLXBhdGg9InVybCgjbWlkKSIgZD0iTSAzMDAs'
    b'MTQ1IEMgMjg1LDEzMCAyMjIsMTg1IDIyMiwxODUgTCAzOTEsMTg5IEMgMzkxLDE4OSAzMjMs'
    b'MTI3IDMwMSwxNDUgWiIgLz4KPHBhdGggZmlsbD0iIzAwNzAzMCIgY2xpcC1wYXRoPSJ1cmwo'
    b'I21pZCkiIGQ9Ik0gMzAxLDE2MiBDIDI4MSwxNDQgMjYzLDE3OCAyNDEsMTY2IEMgMjUyLDIx'
    b'NiAzNjYsMjIxIDM1NiwxNjQgQyAzMzgsMTY2IDMyMSwxMzkgMzAxLDE2MiBaIiAvPgo8Y2ly'
    b'Y2xlIGN4PSIzMDAiIGN5PSIxNTAiIHI9IjQ4IiBzdHJva2U9IiNGRkIwMDAiIHN0cm9rZS13'
    b'aWR0aD0iNCIgZmlsbD0ibm9uZSIgLz4KPGcgaWQ9IkwiPgo8dXNlIHRyYW5zZm9ybT0idHJh'
    b'bnNsYXRlKDMwMCwxNTApIHJvdGF0ZSgtNzUpIiB4bGluazpocmVmPSIjc21hbGwiIC8+Cjx1'
    b'c2UgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMzAwLDE1MCkgcm90YXRlKC02NCkiIHhsaW5rOmhy'
    b'ZWY9IiNiaWciIC8+Cjx1c2UgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMzAwLDE1MCkgcm90YXRl'
    b'KC01NikiIHhsaW5rOmhyZWY9IiNiaWciIC8+CjwvZz4KPHVzZSB0cmFuc2Zvcm09InJvdGF0'
    b'ZSgzMCAzMDAsMTUwKSIgeGxpbms6aHJlZj0iI0wiIC8+Cjx1c2UgdHJhbnNmb3JtPSJyb3Rh'
    b'dGUoNjAgMzAwLDE1MCkiIHhsaW5rOmhyZWY9IiNMIiAvPgo8dXNlIHRyYW5zZm9ybT0icm90'
    b'YXRlKDkwIDMwMCwxNTApIiB4bGluazpocmVmPSIjTCIgLz4KPHVzZSB0cmFuc2Zvcm09InJv'
    b'dGF0ZSgxMjAgMzAwLDE1MCkiIHhsaW5rOmhyZWY9IiNMIiAvPgo8dXNlIHRyYW5zZm9ybT0i'
    b'dHJhbnNsYXRlKDMwMCwxNTApIHJvdGF0ZSg3NSkiIHhsaW5rOmhyZWY9IiNzbWFsbCIgLz4K'
    b'PC9zdmc+', 'RU_KC')

RU_KC = b64_RU_KC
index.append("RU_KC")
index.append("Russia Karachayevo-Cherkesskaya Respublika")
catalog["RU_KC"] = RU_KC
catalog["Russia Karachayevo-Cherkesskaya Respublika"] = RU_KC
country["Russia Karachayevo-Cherkesskaya Respublika"] = ('RU_KC', '', 1)
lookup["RU_KC"] = ('RU_KC', '', 'Russia Karachayevo-Cherkesskaya Respublika', 1)
lookup["Karachay-Cherkessia "] = ('RU_KC', '', 'Russia Karachayevo-Cherkesskaya Respublika', 1)
lookup["Russia Karachayevo-Cherkesskaya Respublika"] = ('RU_KC', '', 'Russia Karachayevo-Cherkesskaya Respublika', 1)
details["RU_KC"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Karachay-Cherkessia "}
regional["RU_KC"] = ('RU_KC', 'Russia Karachayevo-Cherkesskaya Respublika', 1)
regional["Russia Karachayevo-Cherkesskaya Respublika"] = ('RU_KC', 'Russia Karachayevo-Cherkesskaya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_KDA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxMTU3IiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X0tyYXNub2Rhcl9LcmFpLnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlu'
    b'a3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0cDov'
    b'L3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzIGlkPSJkZWZzMTE2MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJu'
    b'YW1lZHZpZXcxMTU5IiBwYWdlY29sb3I9IiNmZmZmZmYiIGJvcmRlcmNvbG9yPSIjNjY2NjY2'
    b'IiBib3JkZXJvcGFjaXR5PSIxLjAiIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiIGlua3NjYXBl'
    b'OnBhZ2VvcGFjaXR5PSIwLjAiIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAg'
    b'PGcgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIgaW5rc2NhcGU6bGFiZWw9IkltYWdlIiBp'
    b'ZD0iZzExNjMiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFs'
    b'aXR5IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFB'
    b'TlNVaEVVZ0FBQUhnQUFBQlFDQUlBQUFCZCtTYmVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFB'
    b'Q0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3Vs'
    b'RThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFVClRFbEVRVlI0MnUxY2VaUmxSMW4vdnFx'
    b'N3YvdnVXL3IxNis3WGU4OU1Nc2tzbWNrTUpDR0pRUU1SQWtFTnVBRkNPSWk0b1hKWXp4RWoK'
    b'Z29vQ2lpZ3FCdkhJSWlGSENDRXhTa1Mya0F4SnlDUWttYlY3bHQ1ZWQ3OTl2MHZWclNyL21E'
    b'Ykx6QVRQOFppWnllVDl6anYzbkZmMwozbHArOWRWWHYvcnEzb3NYWC9OWjZPTzVCK2xUMENl'
    b'NlQzUWZmYUw3UlBlSjd1T01RSHQrVmZlUzBTTTNiTGwzb1RsNnh4TlhkWUpFCm4ram5wcTRr'
    b'ZnM5MS8ySWE0UTZZMjFLWWYvOGRiKzhUL1J5Wjg3SGhYTVBRSVphdzB6blNkeDNQRmZhdlRS'
    b'WFgwdGxVTjR6SXZ1V0wKK3BQaGM0V1FHeCs2KzIyTW13ZUxtLy9rbmpmM0xmbzV4Tkg2NkNN'
    b'TFcwS3V4NUwwTGZxNVJjYnFQRkdjN3V2bzV4eVhiWjU5N2FYMwo5WFgwL3pQZXVPM3VldGRy'
    b'eDU0Q0lDaWxJcFdLMldwckx4bDdRaWVNQ2NPZ2JOUEF3djBMT3c3V1ovcEUvOStSdFZxWGp6'
    b'dzZOSXBlCnNpMFVvVlFLZ1Z1bml6czJmREZXcUtFcTExTDFLdDFmbVlGNjMzVThPeWJUSlVU'
    b'MVl5NjQrOGpWNlN5ekU1Z2Y3ZzRQZHdZSHV5U0sKRFJHbDBzRm9vWjNMOXpTcWVVbitnK1Vk'
    b'UHlhVHNWVGxoVTcwMVJzZmU4YzFkL3lZQzY0YzNhdnJVQzd5OHBxek1wL3dlM3A2a0xzNQpz'
    b'YktRbUQvcWRScEdiWTFUS25jT0gzeTJIRWE4MmdkditOd0xuZWpiSC91Slg3cnkzbXN2Mkh2'
    b'YXM2L2NlTzhGMlFVazBHanIzWTRlCngxUUpaSnpLR0ZOcGhnaWxrcTBBMnR4OS9jVmZUeHE5'
    b'VTNNd2FQeVptLzV5My9MWlZ5bmF2ZDlybk9WbHlFK1AzbnpGdjkzODJTazgKUlJxdjVDcnRM'
    b'T3FnQ3NQU05HTERWSVJLS1lnUzRHV2pWdHMwVFpId3JIUWdscW00L2ZFMXM1UTlLUWQrd3dP'
    b'TzQ3L21NOXR2WEdtOApvQzBhQU9EVHIxenJRbS9IM0tsbkNsLzlxYzBmK3hXa1FEVUZDcDFF'
    b'cENRaUtpQ29GRkpkQWlpTklrcTQ1QU8vZVNyTGlzamk3bjNkCnUzWnFLN20ram9iMlNKa3pX'
    b'bi9EUS9Bc3N5SUM2RHFSZ00yR2d3UUVwd0NLUjRRelZKSUFBaWc4N1kzUjd6NFkyYXlNcks4'
    b'NlFCcDgKK2VwSDNkSDB4UFl1ZS9lRHA3MUdBUkNkOHBnZ0toR2pra0NJNnJSTjF4RkVVK3Rk'
    b'Y2VwZGRwVDloVU5ETTRPTmtWSjd5N0VYTk5HTgpLNTdZOS81L05uTzlrVEcvT0ErcDE4NHBn'
    b'NSt1aWtwSmxiQTVLdFZ1R1QyZjFxcVdpSW1RUUFDUW5PaUxVNGorMUwwOGtybGNaM2pLClcv'
    b'ejVieDUvKzFkZkVFUXI4elRqdDNUTlhtS3hvY2s4QzFtcHBBaWJGWDk1NzJsOUJ4TE01RUxk'
    b'bElRQUlCSlVDcFZoaXNKa0Z3bW8KVTB4YWpMYVNGOC82b1ZVcGF4TWJVRXV5Mm5pSjUxcW41'
    b'S3hBRStjVjBmSE5YK2JYUDNSUzRvWmJiclFzTVR3YTFaWjdVeE85eFFVdgp0WHRPNWpzbkN5'
    b'TmRkanZtN0xGTnErV0phbXVzN1k5VW11TzE5dWhxWlhMLzRVMkd6azUxN3ZyZjM5c3NOVnBy'
    b'cXhDdTFvdkxxYXc5CjlmQTJ2WnA2UnQvbld2RW5ieEdGNm5sRk5QMzR6OW52K0FhLytkYW5K'
    b'L2F1MkpjdFpDay9LaFZSVXBtYVdKNXQ0OTkvLzJTSjlxMHQKenFHa3U5OUp6VHJlRVN0cmx0'
    b'S0xtbmZJU1I1eTNIMEorbGpPdU9mU1ozVHFaUXZLUE5UcmFqcVJVaERMWW1NemJuRGx2bWZr'
    b'dWUyNAo4YVZQcUwwemRISG9EREh3WHJqdURCU0RvY25tUmhJM2ZhK1NhdGdQclcrT2xIL3Jq'
    b'dEdOZG0zSnp3Mzc2UXhydGcwTklGVm9CbzlNCjBsSVNBSlRGK1kxN3pKbVMxa2phajJ4eTdy'
    b'ck1tQjh5Ym54STI3dkovYnNiOUpwbmpOY01pMmtKanRVVXR0YjNhczEvK1ZacHVha2sKREF5'
    b'SFhwcjVEUjFrcXljc1l5NnZWZE1BRUcxZW9CLzVZclJuay9HcDE1eCtKbjMrRWcwQXBEamc3'
    b'NTJxdlBSaCtlS2FjOS9Hems4KwpLaSt2NWRJcm5DdENGT2QwcE5DcjE2MU9RemszZE1pWHRn'
    b'QkFmUE90NUtKbC9NNTJqSWw4MFJIMnN3L29OendNbXRDbUs4R1YrOVhtClpWd1pvQXREY01F'
    b'eXZPNEg4T2dNTmwzMmhzZlZSUTlKSVpNZU4wMFJkWFhMaXcwOWRnWW1TL2tudlAvYXphK2ZL'
    b'LzdjUGRFREcxTi8KY3lPZXdkMkRNeHE5cSt3NHJDZXM0Y3VxYk9lL054YVBUVTBYRm80MUNv'
    b'V2VGQmhMQUFDQ1NqZEV1M0hjZWUxKzgvYUwxZlFhZmRkYgpTVG56bEdQOXZUdmgyc2VnbkxK'
    b'Lzc5ZWV5dmNidTRMUGZrS2JMT0hpb1BzYisycExTaW93clZqWEphTUtCRlFhTmtBUnM4VC85'
    b'UjhNCnZ1WHh4djVFUFN5TmlET3F1TTVvWWQxTXkwb2k1OUlaWHN6UDJMWitQR0Z6b1ZCSm9F'
    b'UzFHNlpoQzZVd2xXTDRob09nVUM0UFNDOTQKU2lFQXFFTmpTcUZjekQyWkFnQkFKY1NFemhV'
    b'NnI3M1BORXBTb2dJVW5QaGRIWWpVYlNGaVVKSVZOazNtM3J4M2JTVXhQRVVFRlR6ZApPYU94'
    b'ampOVzB1S2I3NWJEZGNlMWxZaXJGVzh3ZXpqR2Jad2ZxMWZOYkRZa0JHS09xSlJHWlhKbzVO'
    b'RDlxNE5iam10M1hCSC8ybi9nCjBWRzBRL3VWajdOYVF0ZEZJaGYycnB4Vm4vK0VVV2oxOW15'
    b'QzQvbDQ4eUx1dVppc0R2amJEemRySTVwMmpITUtBRW9wS1JFVjZMb3kKbkVUU1h1TGNXRGph'
    b'MjdtYmVFbCs0TGR2Mi9ieFh5R2hlYjc1NlBtZi9aNmVZRVBqam10WFRNUFh0QUI0cFJmbVVR'
    b'YUVnSnZpc1NBcwowb2lPNVZyVytLOXAvK3JIdlMrOW5INXZHMzNmMTlKWEhJOEZra1NVeUFW'
    b'K3h6QWM1Z3oxR0tQMmhvcStkVW04ODYzR25pM05YL2cyClNMS21TaHUySllKV3lHTndrekhS'
    b'MU9xeUt3UVpubEFpYU1RUkd4NDFkWU0xeTNFN3hsUXhiMVN5NTV2cnVQQUwxNXV4WnRscVpW'
    b'NVcKUzJ4bDNsbGFUT1FHaXFCbGdwNit2SkFvcnprc290N3dWR21oTlhEYnRTUXdnMTJIa09u'
    b'eDdQQUozNEdJUVZkVFNzVXhpVUpOU2RRTgpHWlpkV2sxSk4vQjNIeHI0M0N1aG1GMVpjaENC'
    b'UjlwS01WRXJXMGh3YkNPcEZNUFZsVVN6aHVYbERzV1dsZEEyZnVQS3hLSHA4OUIxCldNZEdx'
    b'U2wwZzd0cDNxd1pBSXBTS0s4a0NoUExwY29ZaGczWDVWSnF4dzVHcVgyVDBnMVNyb3plOUMz'
    b'dDJpY2c2ZGZMdHFaSnhQV0YKb3VBZ09BQkFzMndKUnRSNy81Vm5XMG1keER1T2ozL2grcm1o'
    b'TDE1NitVaTNVZ3dDd29VMnNURmVXMVFZRXhFckFSUUJsT1MyYTVCaQpIc1Y1cWpxVUZvZXRE'
    b'bXVUc2NrdVNCUVNTaXVKNVFYWE5CdWFrK0dzNHcxTkxzNlhObi81alNMVEdyenVJQUlBckR3'
    b'OUJ4YlJkdDAwCkxPRmxvdldrZkFnWHJHOFgxbGYzNi9kZjdDN2s1d2Y5aVFMNm9URThGcTNP'
    b'VTRKQ0VkeHdZYnRldHBGZ3JXaFMxd3d1blRPUGo1eUgKcWtNbVFxU28wWjdsaVNqUXdwQnlS'
    b'azJIVzVaaURKMnNaN21GSS91ckEzdTJJanU1KzNsSTZ5VzdYVGY4amc0S1pFd2JWYnZWTk52'
    b'VgowMHhsNDU5N2RhdlM1V1NUakZQdENpQW93V2wySU9DTUlpakxacm9qZGN0bUc1YlBUM2tY'
    b'ekN4VFErdTJwVzdIaENncENFRndiTVVaCjBYVlpLYmI5UUdJUEJ1LzZpWk5aWnFSWnQ1SnB4'
    b'b1RScnB0QlQyODM5VjViUjVDeElINzM1RjZoSGNlWkcxMDZVQVRnUnNMU05XRzcKc1ZMWTYr'
    b'aUVRTXhKR0dpYVFXQ3djMzRTSFYwNlp6bEc0T3ZsWXNKeE9SSWxKU0pLQlFvUkdyVzR1bGJW'
    b'VWEyOS9wdkNEcDhSVFMzYgp6YXE1ZE1RekRhWVVhanJJR0ExVGRGdG1yMjFVaW00VVBJUHIr'
    b'aldQMG13dmxzQ2pIaGVXQWt5bElpbVJvQ0lVT2gyZE1XTG9BaFBCCmVVcjBhTlZKV1BtQ3Iy'
    b'dXl1T3dxQllTcVJES21pS2hiTVZlSzBja2RsY20zM3IvNDU3ZjRrMnNuN2dwOUxmUTFBSkFT'
    b'V2FDQlJCVWoKQVBDSXNFQlRDbGhFL0k2K1BnY1FOZnYrejN2dnVXdnpEWWRrUkxrQTEwc2pR'
    b'TGVqQTREZ3hISVlZMVFCRU1xSUZaK2ZDeGJ1K3QyMgpOVHppS1l3MXBXbzFNK1h4V3Qwa29B'
    b'elhVOHJYNnluUFd5dXZPWjRYVlgvbS9sVGRCQUtnd0UwekZ3RVVLQUEzR3lGUmhrU0NZSU5R'
    b'Cm9GeEFwS3JkTkFHZ21XbU9iNm8wSzdidHhLa2NheFdUd1dqSUdHbTM5WFFtWXB5MGx4SlM0'
    b'TlFGdlZDa2taYVVIaVBYemplaUV6L2EKV0hQMlAvR291M2xuZW5WdTN0SWxZOVRVcEthSk9L'
    b'SjZZT2pWTkFCUVhVUWRUWUJNWmlKOFptU3QxekVTeWZVTmhGNWJkengrVXVTdAo3Z2ExWXNJ'
    b'YlhQY0ozcDZ0dmNtSE5RTThqOGNDVVNLTDZlZ2tOanM3dTZ1emZpV1pQb05CcFROWFV1YnVs'
    b'K1MrYzJuUVpvL3RLVG01Cm1meWtSQ0lqUm9KQWJ6ZERhMm1JbHRjRDg1S1FoQ2xPblJLamdQ'
    b'b2RQUXIwc0tleGtJYTlrNjNFc0dNVjB4TnRFcUdXZlhDcjRIeG8KS2gwcllJeTY2V2g2NjND'
    b'OW5HNnZ6SFhuczBNZis2VXpxYVBQWUVrOU8vdjFxNmIvK2hleFl4MC91TEp3dERBOFBhRHJj'
    b'bUJFaGIwdwpkV0RHV2hpSkltTGJ3cnJ6OHNSOTJ3R0FoWlN6OVI5SU5EUVpjd0lTcFNDYUJq'
    b'R2pJa2JPYUJSb25GR2xrUGpXMkx0L1Mwa3dkTVVyCm50Wk1Ba29CYVNGd2JKclQ1Q1VyQjB2'
    b'ZGVodStkbm5odzIvUm5oWVVQTitpZHdCZ0xPVTNmUEJYMHc5ZjJPczBIbjh3VG85dk50d1IK'
    b'RVlON1lNbzdPTlZzV2dEQWR4NU4vT0JpQUdBaEVSemppSVMreGhoRkNvN0hBQldnQXBRS0lQ'
    b'QzFPQ0pVa3pISG1LR3htSThLNWFUSApLWlg2dmlsUXlGc084OVg0eGxTMXVxRzlkTGl6N0Ex'
    b'KzZLYk1uVmVqT05NTlB3dFBrNklnK1MrK2d0MjN2ZmlPMjQ4K05rOXBXa21rCnpTUW9iTTRO'
    b'cEY2MG9tMWNseHhLSWlFU3FJcGpJaVZFSVUya0ZFaEpOQlhIT2tHbEpCSlRTb0ZLZ201SUFH'
    b'aTk3SkV4S3k2dE9ibDcKTGdNQU5aL3JqbGJiSlNINGt2akdyckV2WC90c0Q0R2NieGI5bEdu'
    b'UEY2YmU4NXZtdmttaEdySnJuV2kvK3crdmprTE56ZmtzMndFQQoxQlJxQ3FrQ0JDbUlZUW9B'
    b'RURHZTRCUUp4REVoVkJLcWRGTkdvUVlBOUxKWlVGaS9kNVBXc1FIQU9yQ0JZc3V2Z2ZQN2J4'
    b'bTQ5V1ZuCmkrVXpHaVk5aldrcmRIOTRrWDVzR0EzbVByNEpBSXk2dDNiaDBmeW1XcW1wcGJl'
    b'dUlnSW9WQklWUU1MakxLS21MUVFubWk2alVFdW0KR1E4SnBRQUtsQ1FzcEdKNVFFNVhXS1Ns'
    b'Zi84bUVtc0FRRkhWWlR6OHAyK2k3YlA4OXVmWkpIcmR0Q3NaWjNZU1k3cis5NG1aOExwSApB'
    b'aENKYkE4UkJTY25mSWdRS0JVQ29HQlVTQlF4NFJGRklnRXc1Z2dLUVVHdmF5YkhtNDI3TGtr'
    b'K3VHVjl3TFpjZDk4R2pNLys4L2JuCnhEc3NKRFNlNHIyYXF1NGQxL09kaEJkVFhUa2VwN3B5'
    b'a3B4UWNEMEdBRll5UWdKdW1wbFduRWpHbEtwRWtsTk5KVHpXY1R1TnVqWDQKdVZjOE5XZ2t3'
    b'Y2c0SjlvSTV4NjhyNytFeCtnSFdpd3crSitqa0JnRWVpeWVQR3BNVUQvUVk0bFBIaFdWbmYw'
    b'amhPbm5ZS1BPbFhkWQpGSldOM2Z2WmxZZWdVSFBHR3ZHUlFUTFpvVlFKQVpTQ0VFQUlnTUtn'
    b'U3pWVGlwaVl0aUJFaVJpcHBvUUFTa0FxTURwMlludHg5Vy8vCm1wUlMrUGgwOXJzN3RXYnlI'
    b'R2tnVnVIalo3MFMzWXVPQisvNzZzaG9sMm9TRUJhUGU5NUhYeWMvY0ZzcUY3UnE5c0N3WDF0'
    b'MXNzTisKME5XcExwd2s5M3M2eEdnNm9yYm1wSE5CcTI0YXBrUlU3Skdwc2hRYmYvSVlJVW9w'
    b'cU5lczdqZTNEdC95bXI3cldFZnpwbnNHOHI1aApDaEdUK2NPWjVJZC9XUzluQVlCRkZCU0V2'
    b'Z1lJVWFncEFNc1dtcVpRWWN6cGlhZ2VpeWdvakRrcWhYRWpNZkdSTng3N3pvWnVWMGVFCjNH'
    b'QkFyenJFQmxyblFodlB2dXFvdi95aHd1c2V0YXk0MHpFVzl1V0hQdmdtYTJXUUJLWjQ5VVBK'
    b'd2NCeE9kV2w0M0pDRlNpd0V6RWkKU0lGU291WEV0c3MxWFRxSjJIUUVFb1YvK3lwYVNYdjNi'
    b'VnV6dWpCUlJZUkN3VDgyWEV4OWUxZmZSd01iYkFLQWFVcE5qK3hkcTUxLworbFJqemNWdlhw'
    b'Sjk5OXZxNzd0Tkc2OVJYWWtZQ0FFaE1PRnhTaFFBUkFFVm9iN3V3V05Rdm9XZmZUbW52UGFS'
    b'ejlnejFjbUJVTmVWCllZZ2dvSHJHNzFzMEFFRGl3TlR5NXFONkt0QjFhWm5TVFhBbkZacVhM'
    b'SzJtYXdNZmVqUCs1ODYxbVlYUTRwM1pvWWhEZU44RnhtU3QKOWUyTEdvcDNEeFo4aTNWYkZ2'
    b'MzA5ZTZuWDgyU3Z2cWpXNGMyTmpLWnlEUWxJdmlCdHJMa3VSLzllYU9lZXFFVDdlK2NyYi85'
    b'YnZCOApueE5OVjc1UE9kTVlwMUpDWUljUmpXdHYrcytwM2F1RjhXNW1wdGxoUk82NXNFb0Q5'
    b'YU1aVm1oTVhEVS9OdGxKNWZ6TzFtTmhNZDErCnl6Mld4d2lCTUtBUjAzbzlyZDB5b3E0WmJa'
    b'MW51YVo5WUFyUDN2cjdMS3VPNWxXUG1lKytLNW5rbENwQ1FFbEZLV2lhakNJeSs4UEMKMkpZ'
    b'S0lhcFN0c1ludW8yR05UZ1loQ0gxTzBZcUV5bUpxMnZPMUhTNzI5V0Z3Q2lrUXFKbGllcGF3'
    b'azFGSTRXZVVzZ1lJa0VwQVJRdwpScGZ1bnh6NzBFMW4wMGUvNU00SHoxYlpIMXQ5OUtVZVV3'
    b'cEJnWWdCQ1lZQmlZWGVxQnNqRjFadE94WUNNOW5JTkdYU1k2Mm1vZWxLCkFwd0lMU2tGemFi'
    b'cEpPS1lveFRFU3pBaGNIU3l2YmlZdEN4QmlES3RXQW9ncUFDQlVtVmZXTHI2emdjRW5EV2pQ'
    b'cHZ5YnR6b0lRSUMKU0FVS2dCQkFvbHlYajAvMFhJOUxpVWVQZUNjZUZFY0FRcUhYMC95QUFv'
    b'QUNFREd5aUNBb0FMQnNQamVYamlLTkVEVTkzVXBuUXMwUQppSXFnaWdVUmdsQXFQWTl0OExz'
    b'dlVOWHhRWHY3VHgwdHBTVlRDSndTQWVncVVRQi8wdTBNNXNKU3lUa3MwaHZ0TnVla1ZMTHor'
    b'YkRaCk5JNTF2UGd3N1VpZE1SeWI3QmFMVGlyRk0rbElDTnkzTUhEWlJhdnR0ckZjVGk2QlV5'
    b'V21BakNrSkJJWXdYMGtNNWRMdmtDSlB1UjQKaHh6djZTa0RjZlFIcFlQMXN2dVA3UXVUT3I5'
    b'T2xFcHJUbjdZTjAxcFdYRTMxSDVuWk5jdFMzdS9raGw3a2FodGx6WGJFWVl1RzAyegpHbGtE'
    b'SlA3RG83czJpYzZMby9vQkwvMkZ6T1E1RmVzZzUwdzkxRHVqdzMreDhLTzZwdi9xeEs2RnBI'
    b'TjllL1dUK1FzK3oyZm01NU9KCkJCZVMxRVA3eWV0blNUSUt0V3dtV2xsMUhsakt2M05xNTRK'
    b'aHZ5cGMrYXZoVFgrVzMveXlkdm1UeFlkM2ljYTVRelFkK09VdFo3MFMKRzJYbnkrWjl1NUsx'
    b'ajVFdG44OU01WG4wUjZYOXQ2VW52cFhNNzdkVElpQ05sbTIxNUVjVEY1VU42NGIyNmdITHV5'
    b'dFRlTmxLNllmVgp3U09oOTRlajJ4VGlkOTM4cXpwckwrN1ZiODFNM0owcXZOUXN2M053Lzdn'
    b'ZmZCdUgrOUc3ZFd4UnJWbm12VC9hMFhIMHZBei9Lbmo0Cis5YncxOUtqSjg3ZW5oc0hnT213'
    b'cTBuMTlCRndpN25wdTVuOGt5a1M4YjJGN1greDhNZ2ZzOGMrWUZ6eUhuUG5OYlhSdDlFalJD'
    b'bUoKMkxkb0FJRER4UHQzR0dWSURhWCsxZncrT1BndWUrZEo3OE0yTmFPdW13QndkV1Z0em5L'
    b'UDJjbDUrK1RkcVFqSlN0SitWKzRBK3ZndwpHVmdnaWR0aFhKMERMTU81RnZoL1JWeEVnTmV6'
    b'SytXekM5N2RXMnJUcVdjTlgrelZzbjlhMy9ZNmN3SE9NWnhiSDYrNlV4KzdrNC85Cjc2dUtI'
    b'L2NWSnZnS25maEtQSEd1RWYzOCsrN2QvakF6QzhublhiVzE1MTJOMzRHN2dUN3ZhdDMvSW5x'
    b'ZjZEN1JmZlNKN2hQZFI1L28KUHRGOW92djRQK0MvQVRTalB1b1ZiQ0pXQUFBQUpYUkZXSFJr'
    b'WVhSbE9tTnlaV0YwWlFBeU1ESXpMVEEwTFRJM1ZERTBPalE0T2pRMQpLekF3T2pBdzNZTTNL'
    b'UUFBQUNWMFJWaDBaR0YwWlRwdGIyUnBabmtBTWpBeU15MHdOQzB5TjFReE5EbzBPRG8wTlNz'
    b'd01Eb3dNS3plCmo1VUFBQUFBU1VWT1JLNUNZSUk9CiIgaWQ9ImltYWdlMTE2NSIgLz4KICA8'
    b'L2c+Cjwvc3ZnPgo=', 'RU_KDA')

RU_KDA = b64_RU_KDA
index.append("RU_KDA")
index.append("Russia Krasnodarskiy kray")
catalog["RU_KDA"] = RU_KDA
catalog["Russia Krasnodarskiy kray"] = RU_KDA
country["Russia Krasnodarskiy kray"] = ('RU_KDA', '', 1)
lookup["RU_KDA"] = ('RU_KDA', '', 'Russia Krasnodarskiy kray', 1)
lookup["Krasnodar"] = ('RU_KDA', '', 'Russia Krasnodarskiy kray', 1)
lookup["Russia Krasnodarskiy kray"] = ('RU_KDA', '', 'Russia Krasnodarskiy kray', 1)
details["RU_KDA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Krasnodar"}
regional["RU_KDA"] = ('RU_KDA', 'Russia Krasnodarskiy kray', 1)
regional["Russia Krasnodarskiy kray"] = ('RU_KDA', 'Russia Krasnodarskiy kray', 1)
#----------------------------------------------------------------------
b64_RU_KEM = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc5OTIiIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODAiIHZpZXdCb3g9IjAgMCAxMjAgODAiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'S2VtZXJvdm9fT2JsYXN0LnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlu'
    b'a3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0cDov'
    b'L3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzIGlkPSJkZWZzOTk2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9Im5h'
    b'bWVkdmlldzk5NCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpw'
    b'YWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxn'
    b'IGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9'
    b'Imc5OTgiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZlQXNw'
    b'ZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5'
    b'IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNV'
    b'aEVVZ0FBQUhnQUFBQlFDQUlBQUFCZCtTYmVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0Jq'
    b'U0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThB'
    b'QUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFJCkMwbEVRVlI0MnUzYmUyeFQxeDBIOE4rOXZ0'
    b'Zlh6dlg3N1NUT3d3bExRZ0poRUI0SllUREJLSU9wMEc0TVZkdjYwcXB1dEtWcTFXaXQKcXJi'
    b'YXBrN3JDdEkyQ2Y0b3E5WldnNktWb1kxUjJKakdDSlR3U0VKNEpIRVNZanN2eDNZUzI3RWR2'
    b'KzV6ZnlScm9TRkpwM1dySm43Zgp2Nnh6emoxL2ZIVHZ6K2RjblV2QTdwUHdSYVQzd0ZhNGww'
    b'SUNCcUVSR3ZPL2dtYUp4QThkeDllenJRUklpUGhmaEY2cjhXelUrRjh2Ck9LV1ZFNGo0K1VP'
    b'VElnY0Flb2phVlVtVk1jMERaYUpTT2pIeWNSZm04NEYrcVBnMHlQSmpwdWJENFhWQlFYMHNW'
    b'NkVncFMyR0xqc3oKdHNWK0JUWC9VK2dDR01pbnh3REFLUEtQRnA5MDUwMXUwN1lhZENtZEx2'
    b'T0VvNWtBK2NXYTMwZHpCZ0JZcnI2aEVEUElPanZVWnhrVQpnT0tYclllT1JOY0hlTXREdGl2'
    b'Sk5MTkwzKzdRSldwaG9FeWJOdW1qK2VaWVo3TG9RWE16S1FwWE0wdVI5ZCtEVnZMcE5mek4r'
    b'L3M4CkdUdlZ4cmhlTGZ6VGgvRktqU1pER25tWmsydnNRN3prOWtXMTFhVUJiOFQyb08zU3Rq'
    b'elBPN2VXL2VyV3dTSEdmTXBWMFUxWEFZSEwKeDVrb1lPVjM1dXA3Z1QvNjNQbHo0NlhzaHM1'
    b'K2F5WXRGaEQxcnNHTVF1RXdSQ01wUXpocGlvVDBraEswZWVuWXFMNUJPZElmMGo5dwpydHZF'
    b'NTFSczdydWU5bGlab2xjdW5tdnlaMW9QWVkwR0FGRExVOWtJMWJyVXRjZzdjZm5MaFNYaEtQ'
    b'dVhYRGpPcW5oNVlNU3BVVTZCClFJQkdVT1dFMElDRnBtVmZVTC8yK0VERXdJWU5lWVlwcnM5'
    b'bGxTY0JaQm52NWZsS2g0Wk12TkgzUGl0elNWcDVvcXFzSTFWNm8yYTQKYm14OHFwM2dMRm9h'
    b'WkVrMnlySkl5c1Nrck1vcFNBNUl3Z090aTF4bmRHNFloMHBIdUZDVmV2cmErZElsNFY4YmRx'
    b'THluTkN5d0drbwpmbFgzd0crM3Jyb3dXbm5zMnNHWmpsdWZqR21wZHBmNkk4NTAvUFlMdDhQ'
    b'TnJJS3UzdlR5bStrL1ZrWkRWdzB1Sko2dmRLUkl5MFYzClNVekZydTRNVkJEKzJRTXV1b3Ni'
    b'WDdraHY1cjE2eXl6ZXgrbW0rczdCaStWdTQvQk1pUmVvRWEvTFgzdFVwMXJoYysvV2d6Tzdt'
    b'VW8KcVMxb0ZUWHk3QWtrSU92OVFVYmdQNm9wYlFWYzZpMEV6UU56bVhXSFdUMlQrUFJySTQv'
    b'ZG1YdHNjcytQd3Q5N0tjbzNaU0lxOXM0WgpwZUxSV0UrUjg0UUNsUmVDSmdocGZhYURIY3Q0'
    b'bkRhQ3Z3TTZ5Qm9tbnNnKy9sUnZRNlBiYXRmdDNqYzIrS1E2UjlKM1ZCNmxNcUtsCnEzeUJH'
    b'cUVIaWVlRHZvKzgvTXJWRHpjbnZHbVRNcTFYZkNKSU16MlAwL3ZlaWVyMHJNQ1JsSUpVS3Bp'
    b'OXAyT1h0anRrSUdiK1NJRVkKTHRjQ1NiemsvM3ZUOE4vMFpCU1Y1NFEyY0dsTkxpZXF5S3Rh'
    b'ZTQvQ050MG9FbVR6L1pabjkzWHFqZXB0MnhhcjhraU5odDZ4dGRKLwpLN3F2M1hlbXJtVG1h'
    b'UUM1aFNvY3N1cXlTcHJKU25ZMVFzOE43YVd0SWJQZU9KWWFWbHZiRkl1bUcwL1VGeDhiR2Z2'
    b'V3pzb3JGL3hXCnM1TFBpVHF0ZW1JeXgycnBMZmVaRHFZR0w1WE03QVBmVjI4a1dLSmtZaUxK'
    b'S3IycElsU2VFN3BEckFpNU5JdURnYTlRdnVtV2srWHUKRHhJalAvMEIvOTV2cnFlU21jR1Jq'
    b'SnBWVUFwbHB5ZmMxeGtxc0pFL2ZrNnhseGp1Tmpwa0lIUk11bUl3QmdEOXBTWVJsS2c4SjdS'
    b'QQpNTDEyc3dTRWZTUkp5T0pGYytGcnZXME5kYmEzanhicy8rWEs1UTNGaDk5cmlTVXluVjJC'
    b'ai83UnMvV2JpK1ZjbmtzL1ZiYzZyMGtLCmgxVGFwVlMvZVRUZGEzZTBjS1ZJUE4vT0VBREdP'
    b'T3NFcTJQU2NrSWQzejE0SXhLZmpNWnpiNzExNWFoWi8reFRTeC80aHUxNmwyUzAKc1BzUHJP'
    b'cnprazB2dHI1YjUxVFM2WnZkM2llZDBpS0paM1BjdUY0VDBPWkRHcEhuaGM0S2hFUVFNZ1Ar'
    b'RE1mRkp3SGd5Tys2QUNBYQppYi8yay9OcjExVSsvWWcxS2JNLy8wV2Y3MVlJQU5vdkRFNWYy'
    b'QlAwbDRneVR4RXlBYUtNcjBrWDJyRG9OU2xkTnBOV0tqaGlaaitTCm1FeE4vMWp6MWJMdlA2'
    b'eHI5VkI5dmNUemUwcEtLMnlmZmhvb2JaWmttSnlna3lhUmVBRm9rNURXOE5sSmJSNzhhNEU4'
    b'bldlZVg3V3gKMGJibmhhNmhZT0pzUytDTk4vMjdINjNZdnF2MjlqRURXWE5LUTJzem1meDBE'
    b'SWtYS0IybVJCWUFZaG8xT0hYUXRBdHl3blQ3ZnBHVQo0aEk4a2g5anNuRm55VEFQVFVHZ25B'
    b'N1lVLzd4NWozS21hWlllb2svNFNDVFNMd0F0QzZYbG9IZ3RCU1FESHdwZnRzN281bkV4dzBS'
    b'Ck5RbWFLQUFJdDE4cDB0Qks4bFpTejJWTTZoUmtFWG5lMGtFTEVnQ1FJSUo0OXpGakZKV2do'
    b'THUrS1FFRkpXZUJBSm1XUlNSZUFEcWoKcGdpUW5lTUpnbmRBM0Q1N3dKQXhLcWp1ZGt4cHRO'
    b'eEJSM1Z4SWFGVXgwazFFaTlRT2dZTjVxaEtVOXNlZXIzaEQrOE9Ob3dJNHVhOApHN0pJWE13'
    b'VmhRV0wzaGhMNVh1WUZNTUZxL21zc2xyaHExQk5SSFBNV1hITk50UHcxeWYvdk13ejFPZDA5'
    b'QWhPSkY0QStoQ3NLMjZNCkxHc2IvZmJ4RHRQYWRBdWJ2eVlRTFJ5Tzc3U01kbGRhVlNHeEx5'
    b'QXR6c2JDNXE1OEtWWFdHNHVUVE01SUZoWjA3TGpjWDlmdnUxWlUKY25sNWZqTzM0czQxeTcy'
    b'Yk9ZOGJwT1M4TThxcVZKbWtsZm42NjM3S1J2RVNDQlJkMXorMHdqT2lqM01pcDY4TmhwY05o'
    b'QnE3dkNRUApYcXRPb1NlV0RFZnIrbngvM1ZCem9LanhDR3dDWWs3bWUrMjR3WHdIYURoUUh4'
    b'RTNpN1ZLSU1rTkYzcmJMQ1UvMjdDcHNiS3dPaFEwCmhyaHdQbXZRR25WVFhIdHRZWnZGZFRO'
    b'cFBIejJBNW1BMDJ1cTltbzNlUWszM3NWM3JoQSt3emNzeTRudVZZVDNDcFJmbGFvQVFBRmMK'
    b'c1hwa0tPWFVLRE1tSnVtYmNrMmZTTnBCbjdPUXlWUHl5Z0JuVzNET2UrMGJGZ0kvRnZxQ2wz'
    b'Y1loRVpvREVJak5FSmpFQnFoTVFpTgowQWlOUVdpRXhpQTBRaU0wQnFFUkdvUFFDSTNRR0lS'
    b'R2FBeENJelJDWXhBYW9URUlqZEFJalVGb2hNWWdORUlqTkFhaEVScUQwQWlOCjBCaUUvci9L'
    b'UHdGcHQwWXdxekJJdUFBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3TkMweU9W'
    b'UXhNRG8xTkRveE1Dc3cKTURvd01QelN0WmtBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJ'
    b'd01qTXRNRFF0TWpsVU1UQTZOVFE2TVRBck1EQTZNRENOancwbApBQUFBQUVsRlRrU3VRbUND'
    b'CiIgaWQ9ImltYWdlMTAwMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_KEM')

RU_KEM = b64_RU_KEM
index.append("RU_KEM")
index.append("Russia Kemerovskaya oblast")
catalog["RU_KEM"] = RU_KEM
catalog["Russia Kemerovskaya oblast"] = RU_KEM
country["Russia Kemerovskaya oblast"] = ('RU_KEM', '', 1)
lookup["RU_KEM"] = ('RU_KEM', '', 'Russia Kemerovskaya oblast', 1)
lookup["Kemerovo"] = ('RU_KEM', '', 'Russia Kemerovskaya oblast', 1)
lookup["Russia Kemerovskaya oblast"] = ('RU_KEM', '', 'Russia Kemerovskaya oblast', 1)
details["RU_KEM"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+07:00","altname":"Kemerovo"}
regional["RU_KEM"] = ('RU_KEM', 'Russia Kemerovskaya oblast', 1)
regional["Russia Kemerovskaya oblast"] = ('RU_KEM', 'Russia Kemerovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_KGD = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iNjMwIiBoZWlnaHQ9IjQyMCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzIwMDAvc3ZnIj4KICA8cGF0aCBmaWxsPSIjMjgzNTk1IiBkPSJNMCAwaDYzMHY0MjBIMHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZmRmMTAwIiBkPSJNMCAwaDYzMHYyNDBIMHoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZWMxYTIzIiBkPSJNMCAwaDYzMHYxODBIMHoiLz4KICA8ZyBzdHJva2U9IiMw'
    b'MDAiPgogICAgPHBhdGggZD0ibTM4LjgzMyAxNTYuNjg4LjA4MS00Ny45MDJoLTEuOTM4bC4w'
    b'OC0zLjc5N2gxLjc3N2wuMDgxLTE3LjkzMyAyLjE4MS0uMDguMTYyLTE5LjQ2OC02LjM4Mi04'
    b'LjQ4Mi0uMDgtMTguMTc2aDguNzI0bC0uMDgxIDkuMTI5IDQuNDQzLjA4LjA4LTkuMjkgOC4x'
    b'Ni4wODF2OC45NjdoMy42MzRsLS4xNjEtOS4xMjggOS4zNy4wOHYxNy44NTNsLTYuNjI0IDku'
    b'NDUxLjE2MiAxOC45MDMgMTUuMzY4LjAyLjA2IDExLjcxMyA0Ljk2OS4wMi0uMTYyLTExLjU5'
    b'MmgxNS44OTRsLjAyIDExLjYzMiA1LjQ3My4wNjEtLjA4MS0xMS43NzQgMTYuNDE4LjA0Vjk4'
    b'LjgxaDUuMjkxVjg3LjA3N2wxNS4zMjgtLjA2MS0uMTIxLTE5LjEyNS02LjYyNC05LjM3LjA0'
    b'LTE3LjU3aDguNzA0bC4wODEgOS4wMDcgNC40NDMuMDItLjAyLTkuMDY3IDguMDc4LjAyLjA2'
    b'IDguOTg3IDMuNzM3LjA0LS4wMi05LjAyNyA4Ljg0NS4wNC4wMiAxNy45OTQtNi4yNCA5LjAy'
    b'Ny4xMiAxOC45NjMgMi41NjYuMDIuMDggMTguMTc2IDEuMjUyLjAyLjA2MSAzLjQ3NC0xLjQx'
    b'NC4wNC4wODEuMDItLjAyIDQ4LjcxLTQ4LjgxLS4yODEuMDE3LTM0LjE1OS0uMjMzLTMuMjcz'
    b'LTEuMjE3LTMuNy0zLjE1LTIuODY4LTMuNTY0LTIuNjYtNC42Ni0xLjAxLTQuMzEuMDU0LTQu'
    b'NDY0IDEuMDc1LTMuMiAyLjc5Mi0yLjc1NCAzLjM1LTEuMzg2IDMuNTYxLS4wNzkgMi4yOTR2'
    b'MzQuMzc2bC00OC4xNDYtLjI3OHoiIGZpbGw9IiNmZmYiIHN0cm9rZS13aWR0aD0iLjkwNSIv'
    b'PgogICAgPHBhdGggZD0ibTYyLjQgODYuODczLS45NzIuMDU3LjA1NyAxMi4wNTMtNS40ODMt'
    b'LjA1N3YtMTIuMTFsLTE0LjkwOC4xMTRtOTkuODg4LjA5My45NTctLjAyMS0uMDI5IDExLjgx'
    b'aDUuMDg0bC0uMDU3LTExLjcxIDE1LjI1LS4wNThtLTM5LjUyMSA2OS45NjctLjA4LTMuMDdo'
    b'LTYuNzA1bDcuNDMyLS4wOHYtNC4yODFsLTcuNTEzLjA4IDYuNTQzLS4wOHYtNC40NDNsLTYu'
    b'My0uMDgxIDcuMTA4LS4xMjEtLjAyLTMuNjk2aC03LjI3IDYuNDQydi00LjQ0M2wtNi40MDIt'
    b'LjA0IDcuMzkxLjA0LjAyLTQuNTIzLTcuNTEyLjAyIDYuNDgzLS4wMi0uMDItNC41ODVoLTYu'
    b'NDgzbDcuNDUyLS4wMi0uMDYtNC4zNjItNy4zNTItLjAyIDUuNDkzLS4wMi4wNjEtNS40OTMt'
    b'NS42MzQgMi4xNCA2LjgyNS0yLjYwNS0yLjgyNy01LjAwOC01LjY1NCA0LjAxOSA0LjQwMi0z'
    b'LjE5MS0zLjMzMi00LjA2LTQuMTYgMy44NTggNS40NTItNS4wOS01LjEzLTMuNjM0LTMuMTkg'
    b'Ni4zMiAyLjY4Ni01LjMzLTYuMDk5LTEuMzk0LTEuNDU0IDUuNjc1IDEuODk4LTcuMjMtMy44'
    b'OTcuMDJtLTIxLjA2NyA1NC40MjUuMDgtMi43NDZoNi43MDVsLTcuNDMyLS4wODF2LTQuMjgx'
    b'bDcuNTEzLjA4LTYuNTQzLS4wOHYtNC40NDNsNi4zLS4wODEtNy4xMDgtLjEyMS4wMi0zLjY5'
    b'Nmg3LjI3LTYuNDQydi00LjQ0M2w2LjQwMi0uMDQtNy4zOTEuMDQtLjAyLTQuNTIzIDcuNTEy'
    b'LjAyLTYuNDgzLS4wMi4wMi00LjU4NWg2LjQ4M2wtNy40NTItLjAyLjA2LTQuMzYyIDcuMzUy'
    b'LS4wMi01LjQ5My0uMDItLjA2MS01LjQ5MyA1LjYzNCAyLjE0LTYuODI1LTIuNjA1IDIuODI3'
    b'LTUuMDA4IDUuNjU0IDQuMDE5LTQuNDAyLTMuMTkxIDMuMzMyLTQuMDYgNC4xNiAzLjg1OC01'
    b'LjQ1Mi01LjA5IDUuMTMtMy42MzQgMy4xOSA2LjMyLTIuNjg2LTUuMzMgNi4wOTktMS4zOTQg'
    b'MS40NTQgNS42NzUtMS44OTgtNy4yMyAzLjg5Ny4wMm02My4zODYgNi40NDItNDkuMjc1LjEy'
    b'MW00OS4wMzMtMy42NzUtNTEuNzQuMTYybS03NC4xNyAzLjQ3M2g0OC41OW0tNDguNDI4LTMu'
    b'Nzk3IDUwLjg5MS4yNDMiIGZpbGw9Im5vbmUiIHN0cm9rZS13aWR0aD0iLjkwNSIvPgogICAg'
    b'PHBhdGggZD0ibTk1LjI5OCA5OS4wOTIuMDgxIDUuMjUxTTgzLjAyIDk5LjI1NHY1LjczNW0t'
    b'MTIuMjc5LTUuODE2LjA4MSA2LjM4Mm0tMTIuNjAxLTYuMy0uMDgxIDUuOTc3bS0xMS43MTMt'
    b'NS45Nzh2NS42NTVtNjEuMTUtNS44MTctLjA4MSA1LjI1MW0xMi4zNi01LjA4OXY1LjczNW0x'
    b'Mi4yNzgtNS44MTYtLjA4MSA2LjM4Mm0xMi42MDItNi4zLjA4IDUuOTc3bTExLjcxMy01Ljk3'
    b'OHY1LjY1NW0tNzkuMTAyIDQ4Ljc5LjA4IDMuNTU1bS0xMy4yNDctMy41NTV2My4zOTNtNi43'
    b'ODUtOS42MTMuMTYyIDYuMjJtNS45NzctMTIuMTk3djYuMTM5bS0xMi42ODItNS45NzgtLjA4'
    b'IDUuODk3bS02LjE0LjI0My4wOCA1Ljk3N20tNi4wNTgtLjA4LjA4MSAzLjM5Mm0tNS45Nzgt'
    b'OS40NTEtLjA4IDUuODk3bTUuOTc3LTEyLjAzNi0uMDggNi4yMm0tNS44OTctMTEuNzEzLS4x'
    b'NjIgNS42NTRtMTIuMDM2LTUuODE2djUuODE2bTEyLjYwMi01LjgxNi4xNjEgNS44OTdtNi4z'
    b'MDEtMTIuMzZ2Ni4zMDJtLTYuNDYyLTEyLjAzN3Y1LjY1NW02LjMtMTEuNzEzLjA4MSA2LjE0'
    b'bS0xMi43NjMtNi4xNC4wOCA2LjIybS0xMi4yNzgtNi4wNTh2NS43MzVtLTUuODk2LTEyLjAz'
    b'Ni0uMDgxIDYuM20xMS45NTUtNi4yMi0uMDggNi4wNTltMTIuNzYzLTYuMTR2Ni4yMm02LjMt'
    b'OC44ODUuMDgxIDIuNTA0bS0xMi42ODItMi40MjMuMDggMi40MjNtLTEyLjQ0LTIuNDIzLjA4'
    b'MSAyLjU4NW0xMi4xMTcgMTguMDE0djYuMjJtLTEyLjI3OC02LjMwMXY2LjQ2Mm0tNS41NzQt'
    b'MTIuMzZ2NS44MTdtMTEuNjMyLTUuNjU1LjA4IDUuODk3bTY3LjMxIDI0LjE1My0uMDggMy41'
    b'NTVtMTMuMjQ3LTMuNTU1djMuMzkzbS02Ljc4Ni05LjYxMy0uMTYxIDYuMjJtLTUuOTc4LTEy'
    b'LjE5N3Y2LjEzOW0xMi42ODMtNS45NzguMDggNS44OTdtNi4xNC4yNDMtLjA4MSA1Ljk3N202'
    b'LjA1OC0uMDgtLjA4IDMuMzkybTUuOTc3LTkuNDUxLjA4MSA1Ljg5N20tNS45NzgtMTIuMDM2'
    b'LjA4MSA2LjIybTUuODk3LTExLjcxMy4xNjIgNS42NTRtLTEyLjAzNy01LjgxNnY1LjgxNm0t'
    b'MTIuNjAxLTUuODE2LS4xNjIgNS44OTdtLTYuMy0xMi4zNnY2LjMwMm02LjQ2Mi0xMi4wMzd2'
    b'NS42NTVtLTYuMzAxLTExLjcxMy0uMDggNi4xNG0xMi43NjItNi4xNC0uMDggNi4yMm0xMi4y'
    b'NzgtNi4wNTh2NS43MzVtNS44OTctMTIuMDM2LjA4IDYuM20tMTEuOTU1LTYuMjIuMDgxIDYu'
    b'MDU5bS0xMi43NjMtNi4xNHY2LjIybS02LjMtOC44ODUtLjA4MiAyLjUwNG0xMi42ODMtMi40'
    b'MjMtLjA4MSAyLjQyM20xMi40NC0yLjQyMy0uMDggMi41ODVtLTEyLjExOCAxOC4wMTR2Ni4y'
    b'Mm0xMi4yNzktNi4zMDF2Ni40NjJtNS41NzQtMTIuMzZ2NS44MTdtLTExLjYzMy01LjY1NS0u'
    b'MDggNS44OTdNODkuMiA5My4yNzZsLjA0IDUuOTk4bS0yNC4yNzQtNS45OTh2NS45MzhtLTEy'
    b'LjM1OS02LjAxOC0uMDYgNi4wOThtNjEuNTcyLTYuMDE4LS4wNCA1Ljk1OG0yNC4yNzQtNS45'
    b'NTh2Ni4wMThtMTIuMzYtNi4wOTh2Ni4xOG0xMy43MzggNTQuMjQxLTQwLjk0Ny4yNDJtNDEu'
    b'MTEtNi4yMmgtNDIuMDkzbTQyLjAxMi01Ljg5NmgtNDEuNDM5bTQxLjM1Ny01LjgxNWgtNDAu'
    b'ODY1bTQwLjg2NS02LjM4MS00Mi4wOTQtLjA4MW00Mi4wOTQtNS44OTctNDEuMTkzLjE2Mm00'
    b'MS4xMS01Ljg5Ny00Mi42NjYtLjE2MW00Mi45MDgtNi4xMzktNDcuMjQ4LS4xNjFtLTc4LjQ0'
    b'OSA0Mi4yNDYgNDAuMzkuMjQybS00MC41NTEtNi4yMmg0MS41Mm0tNDEuNDQtNS44OTdoNDAu'
    b'ODc1bS00MC43OTQtNS44MTZoNDAuMzFtLTQwLjMxLTYuMzgyIDQxLjUyLS4wOG0tNDEuNTIt'
    b'NS44OTcgNDAuNjMyLjE2MW0tNDAuNTUxLTUuODk3IDQyLjA4Ni0uMTYxbS00Mi4wMDUtNi4x'
    b'NCA0Ni4yODYtLjE2MW0yMi40MjUtMjQuNDc2LS4wOCA2LjQ2Mm0yNC42ODktNi40NjItLjA4'
    b'MSA2LjQ2Mm0yNC41OTktNi40NjItLjA4MSA2LjQ2Mk05NS4zMSA4Ni44OTVsLjA4MSA2LjQ2'
    b'Mm0tMjQuNjktNi40NjIuMDgxIDYuNDYybS0yNC41OTktNi40NjIuMDgxIDYuNDYybS03LjM5'
    b'MSA1Ljg5NyAxMjUuOTY1LjAxbS0xNy42NDMtNS45MyAxNy40NzctLjAxM20tMzguNzQuMDE0'
    b'IDE1LjcwMy0uMDE0bS0zNy4xNS4xIDE1LjcwMS0uMDE1bS0zNy4wNjUtLjA0MiAxNS43MDIt'
    b'LjAxNW0tMzcuNDA0LjA0NCAxNi43NTItLjI0NG0tMzkuMzE0LjM1OCAxNi43NTItLjI0NG0u'
    b'Mzg0IDQuNDE0IDUuNjEzLS4wNzNtLTUuNzg0LTQuODQgNS42MTMtLjA3Mm0tNS42MTMtNC40'
    b'NCA1LjYxMy0uMDczbS00LjMyMi0uMDk0LjEyMSA0Ljc4NU01MS42IDgzLjU4N2wuMTQzIDMu'
    b'MjEzbS0uMTctMTIuNjkyLjExNiA0LjY4Mm0tLjA3OC0xNC4wMTQuMTIgNC4zNjNtNS4zMjUg'
    b'OS41NzkuMTIgNC43ODVtLTExLjA5MS00LjY5Ny4xMiA0Ljc4NW0xMC43Ny0xNC40MDUuMTIx'
    b'IDQuNzg1bS0xMS4wOTItNC42OTcuMTIgNC43ODVtMTAuOTMyLTE0LjE2My4xMiA0Ljc4NW0t'
    b'MTEuMDkxLTQuNjk2LjEyIDQuNzg1bTE2LjE1LTkuMDgyLjEyIDQuMzYzbS0xMC44NjQtNC42'
    b'MDUuMTIgNC4zNjNtLTExLjEwNi00LjIwMi4xMiA0LjM2NG0xNi4zMTktOS4wNDkuMTIgNC4z'
    b'NjNtLTExLjEwNy00LjI4Mi4xMjEgNC4zNjNtMTYuNDgtOS4wNDguMTIgNC4zNjNtLTExLjE0'
    b'Ny00LjM2My4xMjEgNC4zNjNtLTExLjA2Ni00LjM2My4xMiA0LjM2M20uNDQyIDMzLjA0NyAy'
    b'MS4xMjYtLjIybS0yMS4wNjktNC40NjQgMjEuMTI2LS4yMm0tMjEuMDY5LTQuNzUgMjEuMTI2'
    b'LS4yMm0tMjEuMzU0LTQuNDA2IDIxLjEyNi0uMjJtLTIyLjgwMi00LjI0NSAyNS4zMzQtLjIw'
    b'MW0tMjkuMjYzLTQuNzggMzEuOTM2LS4xNzhNMzQuODY3IDU1LjZsMzQuMDQ0LS4xNzFtLTM0'
    b'LjEtNC41NDEgMzQuMDQzLS4xNzFtLTguOTEtNC4zOTkgNS44MjQtLjA3NiAyLjg1Ny0uMDM4'
    b'bS0yMS4wNDQgMCA4LjY4Mi0uMTE0bS0yMS40NTMuMjg1IDguNjgzLS4xMTRNMTQ3LjIgOTcu'
    b'NjY4bC01LjYxMy0uMDcybTUuNzg1LTQuODQtNS42MTQtLjA3Mm01LjYxNC00LjQ0LTUuNjE0'
    b'LS4wNzNtNC4zMjItLjA5NC0uMTIgNC43ODVtNS42MzMtOS4yODQtLjE0MiAzLjIxNG0uMTct'
    b'MTIuNjkyLS4xMTcgNC42ODJtLjA3OC0xNC4wMTQtLjEyIDQuMzYzbS01LjMyNSA5LjU3OC0u'
    b'MTIgNC43ODVtMTEuMDkxLTQuNjk2LS4xMiA0Ljc4NW0tMTAuNzctMTQuNDA2LS4xMiA0Ljc4'
    b'NW0xMS4wOTEtNC42OTYtLjEyIDQuNzg1bS0xMC45MzItMTQuMTYzLS4xMiA0Ljc4NW0xMS4w'
    b'OTEtNC42OTctLjEyIDQuNzg1bS0xNi4xNS05LjA4MS0uMTIgNC4zNjNtMTAuODY0LTQuNjA2'
    b'LS4xMiA0LjM2NG0xMS4xMDctNC4yMDItLjEyMSA0LjM2M20tMTYuMzE4LTkuMDQ4LS4xMjEg'
    b'NC4zNjNtMTEuMTA3LTQuMjgyLS4xMiA0LjM2M20tMTYuNDgtOS4wNDktLjEyMSA0LjM2NG0x'
    b'MS4xNDctNC4zNjQtLjEyIDQuMzY0bTExLjA2Ni00LjM2NC0uMTIxIDQuMzY0bS0uNDQyIDMz'
    b'LjA0Ni0yMC44NDMtLjIybTIwLjc4Ni00LjQ2NC0yMC43ODItLjI0bTIwLjcyNS00LjczLTIw'
    b'Ljc0Mi0uMTU4bTIwLjk3LTQuNDY4LTIxLjEyNS0uMjJtMjIuODAxLTQuMjQ1LTI0Ljg3LS4x'
    b'OG0yOC44LTQuOC0zMi4yOC0uMTc4bTMyLjk2Mi00LjIyNC0zNC4wNDMtLjE3MW0zNC4xLTQu'
    b'NTQxLTM0LjA0My0uMTcybTguOTEtNC4zOTgtNS44MjUtLjA3Ny0yLjg1Ny0uMDM3bTIxLjA0'
    b'NCAwLTguMjE3LS4wMzRtMjAuOTg4LjIwNS04LjY4Mi0uMTE0IiBmaWxsPSJub25lIiBzdHJv'
    b'a2Utd2lkdGg9Ii40NTIiLz4KICAgIDxwYXRoIGQ9Ik0xMDIuMzA3IDMyLjIzMmM5LjU2Ni4w'
    b'MjMgOS45MDggOS41NzIgMy42ODUgMTEuMDE2IDIuNTAxLTMuMzU3IDIuNjMtNS41NjQgMS44'
    b'OS03LjM1LjE1MyAyLjA4My0uMzA4IDMuNjExLTIuMjM0IDMuODE4IDEuNDgyLTUuNTEzLTMu'
    b'NDE4LTQuODk2LTMuODU2LTUuNDQxeiIgZmlsbD0iI2ZmZDIxMSIgc3Ryb2tlLXdpZHRoPSIu'
    b'MTczIi8+CiAgICA8ZyBmaWxsPSIjZmZkMjExIj4KICAgICAgPHBhdGggZD0iTTEwMC42MTIg'
    b'MjJoLjUyOXYtMS4yNWwuNzI4LS4wMDctLjAwNC0uNjg5LS43MzktLjAwNy0uMDAzLS44MDct'
    b'LjUzMi0uMDA0LjAwNy44MTQtLjgtLjAwNy4wMTUuNjg1Ljc5Mi4wMDcuMDA3IDEuMjY0em0z'
    b'LjQxMSAxMC4xNjcgMi4yMjEtMy4zNTNjNC4zMi00LjcyNS0zLjE2My04LjQ3Mi01LjMzMS00'
    b'LjI4MS0yLjU5MS00LjA5NS05LjU2Mi0uNzQyLTUuMTcgNC4zNjJsMi4xNCAzLjI0MSA2LjE0'
    b'LjAzeiIgc3Ryb2tlLXdpZHRoPSIuMTgxIi8+CiAgICAgIDxwYXRoIGQ9Ik0xMDEuODc2IDIy'
    b'LjkyYTEuMDA4IDEuMDA4IDAgMSAxLTIuMDE1IDAgMS4wMDggMS4wMDggMCAwIDEgMi4wMTUg'
    b'MHoiIHN0cm9rZS13aWR0aD0iLjIwNCIvPgogICAgICA8cGF0aCBkPSJtOTUuODIzIDI4Ljk3'
    b'NiAxMC4yNi0uMDgxbS02Ljg2NiAzLjI3NWgzLjUwNmwuMDkyIDM0LjgzOWMtMS4wMzQuMTM0'
    b'LTIuNjg2LjExLTMuNDk5LS4wODUgMC0xMi42MjktLjA1NC0xOS43OTQtLjA5OS0zNC43NTV6'
    b'IiBzdHJva2Utd2lkdGg9Ii4xODEiLz4KICAgIDwvZz4KICAgIDxwYXRoIGQ9Ik0xMDcuOTk2'
    b'IDU0LjcwMmMtMy40ODkuMzc1LTIuNjctNC44MTQgMS42MDQtMy45NyAzLjI0NSAxLjExMiA1'
    b'LjI4IDUuMjIxIDQuNzYyIDguMDUzLTUuMzMzIDI5LjEzLTQ2LjY0Mi01LjcwNi0xNS4xMS0x'
    b'My4wOTRsLjAzOSAxLjQ1MWMtMTEuNTQgMi41NzItMTAuNDU4IDIxLjg3IDUuOTU2IDE3LjMz'
    b'NGwtLjE1MyAyLjI5MWMyLjcyMi0uMDY4IDExLjU3LTkuNjkyIDIuMzY4LTE0LjIwMy0uMzM0'
    b'LjU4NS4wNjcgMS4zNTMuNTM0IDIuMTM4eiIgZmlsbD0iI2ZmZDIxMSIgc3Ryb2tlLXdpZHRo'
    b'PSIuMTczIi8+CiAgICA8cGF0aCBkPSJNOTkuMzEgNTcuMTkzYy0xLjk3MSAzLjA2Ny03LjI2'
    b'NiAxMS41OC0xMS4wMTUgNS42MDMtLjc1NCAyLjU0NSAyLjU0NiA5Ljg2NSAxMS4wMTUtNC4y'
    b'MDktLjAzOC0uMDMyLjAxNC0xLjM5MyAwLTEuMzk0em0zLjQ3NC0xMC41MDljMy4wMzktLjI1'
    b'OSAxLjk3OCAyLjE3Mi4wMiAyLjI1My0xMC4yMyAxLjc1Mi04LjY5NS04LjczMS01LjM4NC0x'
    b'MC44NDRsLTIuMDYyLS44NzhjMS4yODctLjkzMiAyLjY2My0yLjk3NiAzLjg1Ni0yLjc4N2wu'
    b'MDEtMi4yMDVjLTEuMjcuMTU2LTIuNDkgMS4yNDgtMy41NiAyLjUxbC4xMTQtMi44MjVjLTIu'
    b'OTU0IDQuMTkxLTQuMTg4IDcuMjU0LTMuOTI2IDkuNDM3IDIuMyAxOS4xNTcgMjQuNzQ4IDQu'
    b'MTY2IDEwLjkwNCA0LjExN2wuMDI5IDEuMjIyeiIgZmlsbD0iI2ZmZDIxMSIgc3Ryb2tlLXdp'
    b'ZHRoPSIuMTczIi8+CiAgPC9nPgo8L3N2Zz4K', 'RU_KGD')

RU_KGD = b64_RU_KGD
index.append("RU_KGD")
index.append("Russia Kaliningradskaya oblast")
catalog["RU_KGD"] = RU_KGD
catalog["Russia Kaliningradskaya oblast"] = RU_KGD
country["Russia Kaliningradskaya oblast"] = ('RU_KGD', '', 1)
lookup["RU_KGD"] = ('RU_KGD', '', 'Russia Kaliningradskaya oblast', 1)
lookup["Kalingrad"] = ('RU_KGD', '', 'Russia Kaliningradskaya oblast', 1)
lookup["Russia Kaliningradskaya oblast"] = ('RU_KGD', '', 'Russia Kaliningradskaya oblast', 1)
details["RU_KGD"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+02:00","altname":"Kalingrad"}
regional["RU_KGD"] = ('RU_KGD', 'Russia Kaliningradskaya oblast', 1)
regional["Russia Kaliningradskaya oblast"] = ('RU_KGD', 'Russia Kaliningradskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_KGN = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSIgc3RhbmRhbG9uZT0i'
    b'bm8iPz4KPCFET0NUWVBFIHN2ZyBQVUJMSUMgIi0vL1czQy8vRFREIFNWRyAyMDAxMDkwNC8v'
    b'RU4iCiAgICAiaHR0cDovL3d3dy53My5vcmcvVFIvMjAwMS9SRUMtU1ZHLTIwMDEwOTA0L0RU'
    b'RC9zdmcxMC5kdGQiPgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sOnNw'
    b'YWNlPSJwcmVzZXJ2ZSIKCSB3aWR0aD0iNjAwcHgiIGhlaWdodD0iMzAwcHgiCgkgdmlld0Jv'
    b'eD0iMCAwIDYwMCAzMDAiPgo8cmVjdCBmaWxsPSJ3aGl0ZSIgd2lkdGg9IjYwMCIgaGVpZ2h0'
    b'PSIzMDAiIHg9IjAiIHk9IjAiIC8+CjxyZWN0IGZpbGw9IiMwMDgwNDAiIHdpZHRoPSI2MDAi'
    b'IGhlaWdodD0iMTAwIiB4PSIwIiB5PSIxMDAiIC8+CjxwYXRoIGZpbGw9IndoaXRlIiBkPSJN'
    b'IDMzMSwxMTkgQyAzNDcsMTIwIDM1MCwxNDAgMzU4LDE1NCBDIDM2NiwxNjkgMzcwLDE3MCAz'
    b'NzAsMTczIEMgMzcwLDE3NiAzNjAsMTc4IDM0OSwxNzggQyAzMzEsMTc4IDI5NSwxNjYgMjk1'
    b'LDE2NiBDIDI5NSwxNjYgMzE1LDExOCAzMzEsMTE5IHogIiAvPgo8cGF0aCBmaWxsPSJ3aGl0'
    b'ZSIgc3Ryb2tlPSIjMDA4MDQwIiBzdHJva2Utd2lkdGg9IjIiIGQ9Ik0gMjM5LDE3OSBDIDI2'
    b'MiwxNzggMjc4LDE5MSAzMDMsMTkyIEMgMzI5LDE5MiAzMzIsMTgwIDMzMiwxNzcgQyAzMjUs'
    b'MTc0IDMyMywxNjUgMzIwLDE1OSBDIDMxMywxNDQgMzA3LDExMCAyODYsMTA5IEMgMjYyLDEw'
    b'OCAyNTUsMTYwIDIzOSwxNzkgeiAiIC8+Cjwvc3ZnPg==', 'RU_KGN')

RU_KGN = b64_RU_KGN
index.append("RU_KGN")
index.append("Russia Kurganskaya oblast")
catalog["RU_KGN"] = RU_KGN
catalog["Russia Kurganskaya oblast"] = RU_KGN
country["Russia Kurganskaya oblast"] = ('RU_KGN', '', 1)
lookup["RU_KGN"] = ('RU_KGN', '', 'Russia Kurganskaya oblast', 1)
lookup["Kurgan"] = ('RU_KGN', '', 'Russia Kurganskaya oblast', 1)
lookup["Russia Kurganskaya oblast"] = ('RU_KGN', '', 'Russia Kurganskaya oblast', 1)
details["RU_KGN"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Kurgan"}
regional["RU_KGN"] = ('RU_KGN', 'Russia Kurganskaya oblast', 1)
regional["Russia Kurganskaya oblast"] = ('RU_KGN', 'Russia Kurganskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_KHA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZlcnNpb249IjEuMSIg'
    b'd2lkdGg9IjMyNCIgaGVpZ2h0PSIyMTYiPjxyZWN0IHdpZHRoPSIzMjQiIGhlaWdodD0iMTA4'
    b'IiBmaWxsPSJ3aGl0ZSIvPjxyZWN0IHdpZHRoPSIzMjQiIGhlaWdodD0iMTA4IiB5PSIxMDgi'
    b'IGZpbGw9IiMwMDk5ZmYiLz48cG9seWdvbiBwb2ludHM9IjAsMCAwLDIxNiAxMDgsMTA4IiBm'
    b'aWxsPSJncmVlbiIvPjwvc3ZnPgo=', 'RU_KHA')

RU_KHA = b64_RU_KHA
index.append("RU_KHA")
index.append("Russia Khabarovskiy kray")
catalog["RU_KHA"] = RU_KHA
catalog["Russia Khabarovskiy kray"] = RU_KHA
country["Russia Khabarovskiy kray"] = ('RU_KHA', '', 1)
lookup["RU_KHA"] = ('RU_KHA', '', 'Russia Khabarovskiy kray', 1)
lookup["Khabarovsk Krai"] = ('RU_KHA', '', 'Russia Khabarovskiy kray', 1)
lookup["Russia Khabarovskiy kray"] = ('RU_KHA', '', 'Russia Khabarovskiy kray', 1)
details["RU_KHA"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":"Khabarovsk Krai"}
regional["RU_KHA"] = ('RU_KHA', 'Russia Khabarovskiy kray', 1)
regional["Russia Khabarovskiy kray"] = ('RU_KHA', 'Russia Khabarovskiy kray', 1)
#----------------------------------------------------------------------
b64_RU_KHM = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMTIwMCIgaGVpZ2h0PSI2MDAiIHZp'
    b'ZXdCb3g9IjAgMCA0MCAyMCI+DQo8cmVjdCB3aWR0aD0iNDAiIGhlaWdodD0iMjAiIGZpbGw9'
    b'IiNmZmYiLz4NCjxyZWN0IHdpZHRoPSIzOCIgaGVpZ2h0PSIyMCIgZmlsbD0iIzAwOTcxQyIv'
    b'Pg0KPHJlY3Qgd2lkdGg9IjM4IiBoZWlnaHQ9IjEwIiBmaWxsPSIjMkU5NkZGIi8+DQo8cGF0'
    b'aCBmaWxsPSJub25lIiBzdHJva2U9IiNmZmYiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgZD0i'
    b'TTE1LDIgMTIsNiA4LDYgNSwyIE0xMi41LDIuMjUgMTAsNS42NSA3LjUsMi4yNSBNOC41LDMu'
    b'NiA5LjUsMi4yNSBNMTEuNSwzLjYgMTAuNSwyLjI1Ii8+DQo8L3N2Zz4=', 'RU_KHM')

RU_KHM = b64_RU_KHM
index.append("RU_KHM")
index.append("Russia Khanty-Mansiyskiy avtonomnyy okrug")
catalog["RU_KHM"] = RU_KHM
catalog["Russia Khanty-Mansiyskiy avtonomnyy okrug"] = RU_KHM
country["Russia Khanty-Mansiyskiy avtonomnyy okrug"] = ('RU_KHM', '', 1)
lookup["RU_KHM"] = ('RU_KHM', '', 'Russia Khanty-Mansiyskiy avtonomnyy okrug', 1)
lookup["Khanty-Mansi"] = ('RU_KHM', '', 'Russia Khanty-Mansiyskiy avtonomnyy okrug', 1)
lookup["Russia Khanty-Mansiyskiy avtonomnyy okrug"] = ('RU_KHM', '', 'Russia Khanty-Mansiyskiy avtonomnyy okrug', 1)
details["RU_KHM"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Khanty-Mansi"}
regional["RU_KHM"] = ('RU_KHM', 'Russia Khanty-Mansiyskiy avtonomnyy okrug', 1)
regional["Russia Khanty-Mansiyskiy avtonomnyy okrug"] = ('RU_KHM', 'Russia Khanty-Mansiyskiy avtonomnyy okrug', 1)
#----------------------------------------------------------------------
b64_RU_KIR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iNjAwIiBoZWlnaHQ9IjQwMCIg'
    b'aW1hZ2UtcmVuZGVyaW5nPSJvcHRpbWl6ZVF1YWxpdHkiIHNoYXBlLXJlbmRlcmluZz0iZ2Vv'
    b'bWV0cmljUHJlY2lzaW9uIiB4bWxuczp2PSJodHRwczovL3ZlY3RhLmlvL25hbm8iPjxzdHls'
    b'ZT48IVtDREFUQVsuT3tzdHJva2UtbGluZWpvaW46cm91bmR9LlB7c3Ryb2tlOiNmZmZ9LlF7'
    b'ZmlsbDojZGEyNTFkfS5Se3N0cm9rZTojZjhjMzAwfS5Te3N0cm9rZS1saW5lY2FwOnJvdW5k'
    b'fS5Ue3N0cm9rZS13aWR0aDoxLjgxOH0uVXtzdHJva2Utd2lkdGg6MS40NTV9LlZ7c3Ryb2tl'
    b'LXdpZHRoOjEuMDkxfV1dPjwvc3R5bGU+PHBhdGggZD0iTTAgMGg2MDB2NDAwSDB6IiBmaWxs'
    b'PSIjZmZmIi8+PHBhdGggZD0iTTAgMzAwaDYwMHYxMDBIMHoiIGZpbGw9IiMwMDkyM2YiLz48'
    b'cGF0aCBkPSJNMCAzNTBoNjAwdjUwSDB6IiBmaWxsPSIjMDA3Y2MzIi8+PHVzZSB4bGluazpo'
    b'cmVmPSIjQiIgc3Ryb2tlPSIjZGEyNTFkIiBzdHJva2Utd2lkdGg9IjcuMjczIiBmaWxsPSIj'
    b'MDA5M2RkIi8+PGcgY2xhc3M9IlQiPjx1c2UgeGxpbms6aHJlZj0iI0IiIGZpbGw9IiNmOGMz'
    b'MDAiIGNsYXNzPSJSIi8+PGcgY2xhc3M9Ik8iPjxwYXRoIGQ9Ik0zODcuMzY0IDU5LjgxOGMt'
    b'NiAuNTQ1LTEwLjU0NSAxLjYzNi0xNS4wOTEgNi45MDlDMzYxLjM2NCA2OCAzNTUuOTA5IDc0'
    b'LjE4MiAzNTUuMzY0IDg0Yy04LjE4MiA1LjgxOC0xMC45MDkgMTQuOTA5LTggMjcuMDkxLTku'
    b'NjM2IDYtMTMuNDU1IDEzLjYzNi04LjkwOSAyMy4wOTFsLjE4MiAyMi4zNjRjLjcyNyAzLjA5'
    b'MSAyLjM2NCA2IDQuNTQ1IDguOTA5LTYuOTA5IDEwLjkwOS0zLjgxOCAyMC43MjcgOS4yNzMg'
    b'MjYuNzI3IDAgMTguNzI3IDEwLjM2NCAyNCAyNS42MzYgMjMuMDkxIDIgMi43MjcgNS4wOTEg'
    b'NC43MjcgOS4yNzMgNi4xODJsLjE4Mi0xNjEuODE4eiIgc3Ryb2tlPSIjMDA3Y2MzIiBmaWxs'
    b'PSIjMDA3Y2MzIi8+PHBhdGggZD0iTTM4Ny4zNjQgNTkuODE4Yy02IC41NDUtMTAuNTQ1IDEu'
    b'NjM2LTE1LjA5MSA2LjkwOUMzNjEuMzY0IDY4IDM1NS45MDkgNzQuMTgyIDM1NS4zNjQgODRj'
    b'LTguMTgyIDUuODE4LTEwLjkwOSAxNC45MDktOCAyNy4wOTEtOS42MzYgNi0xMy40NTUgMTMu'
    b'NjM2LTguOTA5IDIzLjA5MWwuMTgyIDIyLjM2NGMuNzI3IDMuMDkxIDIuMzY0IDYgNC41NDUg'
    b'OC45MDktNi45MDkgMTAuOTA5LTMuODE4IDIwLjcyNyA5LjI3MyAyNi43MjcgMCAxOC43Mjcg'
    b'MTAuMzY0IDI0IDI1LjYzNiAyMy4wOTEgMiAyLjcyNyA1LjA5MSA0LjcyNyA5LjI3MyA2LjE4'
    b'MiIgZmlsbD0ibm9uZSIgY2xhc3M9IlAgUyIvPjwvZz48L2c+PGcgY2xhc3M9IlEgVSBPIFAi'
    b'PjxwYXRoIGQ9Ik0yNDEuMTgyIDcyLjM2NGMtNy4wOTEgMS44MTgtMTIuMzY0IDQuMTgyLTE2'
    b'LjM2NCA3LjQ1NVY1OC43MjdjNCAzLjI3MyA5LjI3MyA1LjYzNiAxNi4zNjQgNy40NTUtMS44'
    b'MTgtNy4wOTEtNC4xODItMTIuMzY0LTcuNDU1LTE2LjM2NGgyMS4wOTFjLTMuMjczIDQtNS42'
    b'MzYgOS4yNzMtNy40NTUgMTYuMzY0IDcuMDkxLTEuODE4IDEyLjM2NC00LjE4MiAxNi4zNjQt'
    b'Ny40NTV2MjEuMDkxYy00LTMuMjczLTkuMjczLTUuNjM2LTE2LjM2NC03LjQ1NSAxLjgxOCA3'
    b'LjA5MSA0LjE4MiAxMi4zNjQgNy40NTUgMTYuMzY0aC0yMS4wOTFjMy4yNzMtNCA1LjYzNi05'
    b'LjI3MyA3LjQ1NS0xNi4zNjR6Ii8+PGNpcmNsZSBjeD0iMjQ0LjI3MyIgY3k9IjQ0LjcyNyIg'
    b'cj0iNC41NDUiLz48L2c+PGcgc3Ryb2tlLXdpZHRoPSIxLjM5NSIgY2xhc3M9Ik8gUCBRIj48'
    b'Y2lyY2xlIGN5PSIyMTkuNzQyIiBjeD0iLTY5LjIwOCIgdHJhbnNmb3JtPSJyb3RhdGUoMjcw'
    b'KSIgcj0iNC41MzMiLz48Y2lyY2xlIGN5PSItMjY4LjY4OSIgY3g9IjY5LjIwOCIgdHJhbnNm'
    b'b3JtPSJtYXRyaXgoMCAxIC0xIDAgMCAwKSIgcj0iNC41MzMiLz48L2c+PGNpcmNsZSBjeD0i'
    b'MjQ0LjI3MyIgY3k9IjkzLjYzNiIgcj0iNC41NDUiIGNsYXNzPSJPIFAgUSBVIi8+PGcgZmls'
    b'bD0ibm9uZSIgY2xhc3M9IlMgVCBPIFAiPjxwYXRoIGQ9Ik0zODcuMzY0IDkyYy0xNC4xODIg'
    b'MS44MTgtMjAuNzI3IDEwLjE4Mi0xNiAyNy44MThtLTEuNjM3LTEyLjE4MmMtMTMuNDU1IDIt'
    b'MjEuMjczIDgtMjIgMjAiLz48cGF0aCBkPSJNMzgyLjI3MyA5My4wOTFjLTEuNjM2LTIuNzI3'
    b'LS45MDktNi4xODIgMi0xMG0tMS42MzctNC43MjdjLTUuNjM2IDQuNzI3LTcuODE4IDEwLTUu'
    b'MjczIDE2LjcyN20tMTEuOTk5IDQuMzY0Yy0yLjE4MiAzLjA5MS0yLjE4MiA2LjE4Mi0uMzY0'
    b'IDkuMjczbS0xLjgxOC0xNi4zNjRjLTUuNDU1IDQuNTQ1LTcuNjM2IDEwLjE4Mi00LjE4MiAx'
    b'OC4zNjRtNC41NDUtMjMuNjM3Yy0xMC4zNjQgNC41NDUtMTMuODE4IDEzLjI3My05LjI3MyAy'
    b'Ni43MjdtMzMuMDkyIDI2LjkwOWMtMy42MzYtMy4yNzMtNC4xODItNi41NDUtMS40NTUtOS40'
    b'NTVtMS40NTUgMTYuOTFjLTkuNDU1LTUuODE4LTEyLjU0NS0xMi41NDUtNi0yMC43MjdtNiAy'
    b'Ny4yNzJjLTE1LjYzNi04LjcyNy0yMS4yNzMtMTkuODE4LTYuNzI3LTMxLjQ1NW02LjcyNyA3'
    b'Ny4yNzNjLTI2LjkwOS0xMC0yOC0yNy44MTgtNC00MC4zNjRtLTE2LTM5LjI3MmMtMTYuOTA5'
    b'IDE0LjkwOS0yMS42MzYgMzEuMDkxIDIuMzY0IDQ5LjgxOCIvPjxwYXRoIGQ9Ik0zNzQuMDkx'
    b'IDE2Ni4zNjRjLTEwLjE4Mi02LjM2NC0xNC45MDktMTQuNTQ1LTE0LjE4Mi0yNG0xNy40NTUg'
    b'MjEuNDU0Yy02LjM2NC0zLjYzNi05LjYzNi05LjgxOC0xMi45MDktMTUuNDU1bTguNzI3IDQu'
    b'MTgyYzEuNDU1IDMuMDkxIDQgNS4yNzMgOCA4LjcyN00zNzIuMDkxIDE3NmMtMS40NTUgOC4z'
    b'NjQgNS4wOTEgMTMuODE4IDE1LjA5MSAxNy44MTgiLz48cGF0aCBkPSJNMzc3IDE3OC4zNjRj'
    b'LS4xODIgNC4zNjQgMy40NTUgNy40NTUgMTAuMTgyIDkuNjM2bS0yNi0xNi4zNjRjLTYuNTQ1'
    b'LS4zNjQtMTMuNjM2LTEuNjM2LTE4LTYuMTgybTE2LjM2MyAxNS40NTVjLTMuNDU1LTIuOTA5'
    b'LTQuNTQ1LTYtMi43MjctOS42MzZtLTQuNTQ1LS45MDljLTIuNTQ1IDUuNjM2LS45MDkgMTAu'
    b'NTQ1IDQuNzI3IDE0LjcyN20tMi4xODIgMi43MjdjLTgtNS4wOTEtMTAuNzI3LTEwLjE4Mi02'
    b'LjM2NC0xOC43MjdtNC4wMDEgMjMuMjczYzcuMDkxIDEuODE4IDEzLjA5MS45MDkgMTkuNDU1'
    b'LS41NDVNMzc1LjU0NSAyMDRjLS41NDUgNS4wOTEuMTgyIDguNTQ1IDIuMzY0IDExLjQ1NSIv'
    b'PjxwYXRoIGQ9Ik0zNjQuNjM2IDIwMi4xODJjMy4wOTEgMy4yNzMgNiA1LjYzNiAxMC45MDkg'
    b'NS40NTUiLz48cGF0aCBkPSJNMzU5IDIwMC45MDljNCA3LjYzNiA5LjYzNiAxMS4yNzMgMTYu'
    b'OTA5IDEwLjU0NSIvPjwvZz48cGF0aCBkPSJNMzA5LjM2NCAxMzIuOTA5aC0yNS4wOTFsLTMu'
    b'NjM2IDQuMzY0SDI3M3YtMTUuODE4Yy0yMC43MjctMTguMTgyIDgtMzEuMDkxIDE2LjkwOS01'
    b'My4yNzNsMTkuNDU1IDY0LjcyN3ptLTMuMDkxIDE0LjcyN2wyLjE4MiAzLjQ1NS0xOC4zNjQg'
    b'NjEuMDkxYy04LjkwOS0yMi4xODItMzcuNjM2LTM1LjA5MS0xNi45MDktNTMuMjczdi0xNS44'
    b'MThoNy42MzZsMy42MzYgNC4zNjRoMjJ6bTUuMjczIDUuODE4YzQuMTgyIDIuMTgyLS4zNjQg'
    b'NS44MTggMTYgMi43MjdsMi4zNjQgMi41NDVjNy44MTgtNS4yNzMgMTYuMzY0LjU0NSAyOS44'
    b'MTggMi45MDktOC05LjYzNi04LjkwOS0yMC0xLjQ1NS0zMC45MDktOC41NDUtLjE4Mi0xNi4x'
    b'ODIgMS4wOTEtMjEuNjM2IDQuOTA5aC0xMS40NTVjLTMuMjczLTItNy4wOTEtMy4wOTEtMTIt'
    b'My4wOTFsLTIxLjQ1NS03MC4xODJjLjE4Mi0uNzI3LjM2NC0xLjYzNi4zNjQtMi4zNjQgMi43'
    b'MjcgMS40NTUgNS4yNzMgMS42MzYgNy40NTUgMCAzLjA5MS0yLjE4MiA2LjE4Mi41NDUgMTMu'
    b'NjM2LS43MjctNi45MDkuMzY0LTEwLjM2NC0yLjcyNy0xMy44MTgtMS4yNzMtMy4wOTEgMS4y'
    b'NzMtNS4yNzMuNTQ1LTcuMDkxLTEuNjM2IDAtMS44MTggMC0zLjQ1NS0uMzY0LTUuNDU1LTEu'
    b'NjM2LTEwLjcyNy0xNS42MzYtLjcyNy00LjkwOSAyLjcyNyA0LjkwOSAyOC41NDUtNDkuNjM2'
    b'IDQ2LjE4Mi0yNS42MzYgNzAuNzI3djEyLjcyN2gtMjQuNzI3Yy41NDUtMiAxLjgxOC0zLjgx'
    b'OCAzLjI3My01LjQ1NS02LjkwOSAyLjkwOS0xNS4wOTEgNS42MzYtMjQuMzY0IDguNTQ1IDku'
    b'MjczIDIuOTA5IDE3LjQ1NSA1LjYzNiAyNC4zNjQgOC41NDUtMS40NTUtMS44MTgtMi41NDUt'
    b'My42MzYtMy4yNzMtNS40NTVoMjQuNzI3VjE1NmMtMjQuMTgyIDI0LjU0NSAzMC4zNjQgNDIu'
    b'MTgyIDI1LjYzNiA3MC43MjctMTAuNzI3IDMuNDU1IDMuMjczIDEzLjI3MyA0LjkwOSAyLjcy'
    b'Ny4zNjQtMS44MTguMzY0LTMuNjM2LjM2NC01LjQ1NSAxLjgxOC0yLjE4MiA0LjE4Mi0yLjkw'
    b'OSA3LjA5MS0xLjYzNiAzLjQ1NSAxLjQ1NSA3LjA5MS0xLjYzNiAxMy44MTgtMS4yNzMtNy40'
    b'NTUtMS4wOTEtMTAuNzI3IDEuNDU1LTEzLjYzNi0uNzI3LTIuMTgyLTEuNjM2LTQuNzI3LTEu'
    b'MjczLTcuNDU1IDAtLjE4Mi0uOTA5LS4xODItMS42MzYtLjM2NC0yLjM2NGwxOS44MTgtNjQu'
    b'NzI3eiIgc3Ryb2tlLXdpZHRoPSIxLjI3MyIgY2xhc3M9Ik8gUCBRIi8+PGcgZmlsbD0iI2Y4'
    b'YzMwMCI+PHBhdGggZD0iTTMxMC4wOTEgMTM3LjQ1NWMtLjM2NCAxLjQ1NSAzLjA5MSAxLjYz'
    b'NiA0LjU0NSAxLjYzNiAyLjkwOSAwIDIuNzI3IDEuMDkxIDQuMzY0IDMuMjczIDQuMTgyIDUu'
    b'MjczIDUuMjczIDMuMDkxIDYuNTQ1IDQuNzI3LTEuMjczIDEuMDkxLTQuMTgyLTIuMTgyLTQu'
    b'MTgyIDEuODE4IDAgNiA3LjA5MSA3LjI3MyA3LjYzNi41NDUuNTQ1LTYuMzY0LS43MjctNy42'
    b'MzYtNC4zNjQtMTEuNDU1LTEuNjM2LTEuNjM2LTEzLjI3My00LjM2NC0xNC4zNjQtLjU0NXpt'
    b'LjM2NCA0LjU0NWMtMi45MDkuMzY0LTEuMjczIDMuMDkxIDEuMDkxIDIuNTQ1IDMuNjM2LS45'
    b'MDkgNi43MjctMy40NTUtMS4wOTEtMi41NDV6bS45MDkgNC41NDVjLTIgLjkwOS0uNTQ1IDMu'
    b'MjczIDIgMiA0LjE4Mi0yIDUuMjczLTUuMjczLTItMnptMi43MjcgMy40NTVjLTEuNjM2Ljkw'
    b'OS0uMzY0IDMuMjczIDIgMS42MzYgMy42MzYtMi4zNjQgMy4wOTEtNC45MDktMi0xLjYzNnpt'
    b'My4wOTEgMi43MjdjLTEuNjM2IDEuMjczLjM2NCAzLjA5MSAyIDEuMDkxIDItMi41NDUtLjM2'
    b'NC0yLjU0NS0yLTEuMDkxem0zMS4wOTEtOS44MThjLS45MDktNS40NTUgMS42MzYtNCAxLjgx'
    b'OC02LjcyNy0xMC41NDUuOTA5LTEyIDMuMjczLTcuMjczIDEwLjM2NC45MDktMy44MTgtMi4x'
    b'ODItNC43MjcgMS40NTUtNi41NDUgMCAxLjYzNi41NDUgMy40NTUgMS42MzYgNS4wOTEuNTQ1'
    b'LTItLjU0NS00LjkwOS45MDktNS44MTguMzY0IDEuMjczLjU0NSAyLjcyNyAxLjQ1NSAzLjYz'
    b'NnptLTEzLjYzNyA2LjM2NGMtLjE4Mi0yLjkwOS4xODItNS44MTggMS4yNzMtNi45MDkuMTgy'
    b'IDIuMTgyLjU0NSA0LjE4MiAyIDUuMjczLS4xODItMy42MzYtLjE4Mi01LjYzNi43MjctNi4z'
    b'NjQtMi4xODItMS40NTUtMy4yNzMtMi00LjcyNy0yLjE4Mi0uOTA5IDQuNzI3LS41NDUgOC4z'
    b'NjQuOTA5IDEwLjE4MnoiLz48cGF0aCBkPSJNMjg0LjA5MSAxMzguNzI3bC0xLjI3MyAxLjQ1'
    b'NWgyMy4yNzNsMS4yNzMtMS40NTV6IiBjbGFzcz0iTyBSIFYiLz48L2c+PHBhdGggZD0iTTMw'
    b'OSAxMzcuMDkxbC0xLjQ1NSAxLjgxOG0tMjEuODE4LTEuODE4bC0xLjQ1NSAxLjgxOG00Ljkw'
    b'OS0xLjgxOGwtMS40NTUgMS44MThtNC45MDktMS44MThsLTEuNDU1IDEuODE4bTQuOTA5LTEu'
    b'ODE4bC0xLjQ1NSAxLjgxOG00LjkwOS0xLjgxOGwtMS40NTUgMS44MThtNC45MDktMS44MThs'
    b'LTEuNDU1IDEuODE4bTQuOTA5LTEuODE4TDMwNSAxMzguOTA5IiBmaWxsPSJub25lIiBjbGFz'
    b'cz0iTyBSIFMgViIvPjxkZWZzID48cGF0aCBpZD0iQiIgZD0iTTMwMC4yNzMgMjYyLjcyN0Mz'
    b'MDEuNTQ1IDI1Mi4xODIgMzEwLjQ1NSAyNDQgMzIxLjM2NCAyNDRsNDQuNTQ1LTEuMDkxYzEx'
    b'LjgxOCAwIDIxLjI3My05LjQ1NSAyMS4yNzMtMjEuMjczVjM3LjI3M0gyMTIuODE4djE4NC4z'
    b'NjRjMCAxMS44MTggOS44MTggMjEuMjczIDIxLjQ1NSAyMS4yNzNMMjc4LjgxOCAyNDRjMTAu'
    b'OTA5IDAgMjAgOC4xODIgMjEuMjczIDE4LjcyN2guMTgyeiIvPjwvZGVmcz48L3N2Zz4=', 'RU_KIR')

RU_KIR = b64_RU_KIR
index.append("RU_KIR")
index.append("Russia Kirovskaya oblast")
catalog["RU_KIR"] = RU_KIR
catalog["Russia Kirovskaya oblast"] = RU_KIR
country["Russia Kirovskaya oblast"] = ('RU_KIR', '', 1)
lookup["RU_KIR"] = ('RU_KIR', '', 'Russia Kirovskaya oblast', 1)
lookup["Kirov"] = ('RU_KIR', '', 'Russia Kirovskaya oblast', 1)
lookup["Russia Kirovskaya oblast"] = ('RU_KIR', '', 'Russia Kirovskaya oblast', 1)
details["RU_KIR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Kirov"}
regional["RU_KIR"] = ('RU_KIR', 'Russia Kirovskaya oblast', 1)
regional["Russia Kirovskaya oblast"] = ('RU_KIR', 'Russia Kirovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_KK = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMTIwMHB4IiBoZWlnaHQ9IjYwMHB4'
    b'IiB2aWV3Qm94PSIwIDAgMzYwIDE4MCI+DQo8cmVjdCBmaWxsPSIjZDgxZTA1IiB3aWR0aD0i'
    b'MzYwIiBoZWlnaHQ9IjE4MCIvPg0KPHJlY3QgZmlsbD0iI2ZmZiIgd2lkdGg9IjM2MCIgaGVp'
    b'Z2h0PSIxMjAiLz4NCjxyZWN0IGZpbGw9IiMwMDUxYmEiIHdpZHRoPSIzNjAiIGhlaWdodD0i'
    b'NjAiLz4NCjxyZWN0IGZpbGw9IiMwMDk4NDciIHdpZHRoPSI2MCIgaGVpZ2h0PSIxODAiLz4N'
    b'CiA8ZyBmaWxsPSJnb2xkIiB0cmFuc2Zvcm09InJvdGF0ZSg0NSwgMzAsIDkwKSI+DQo8cGF0'
    b'aCBkPSJNMzAsMTIwIDUxLDkwIDMwLDYwIDksOTB6Ii8+DQo8cGF0aCBkPSJNNjAsOTAgMzAs'
    b'MTExIDAsOTAgMzAsNjl6Ii8+DQo8Y2lyY2xlIGN4PSIzMCIgY3k9IjkwIiByPSIyNCIvPg0K'
    b'PGNpcmNsZSBmaWxsPSIjMDA5ODQ3IiBjeD0iMzAiIGN5PSI5MCIgcj0iMjEiLz4NCjxjaXJj'
    b'bGUgY3g9IjMwIiBjeT0iOTAiIHI9IjE4Ii8+DQo8Y2lyY2xlIGZpbGw9IiMwMDk4NDciIGN4'
    b'PSIzMCIgY3k9IjkwIiByPSIxMiIvPg0KPGNpcmNsZSBjeD0iMzAiIGN5PSI5MCIgcj0iMTAi'
    b'Lz4NCiA8L2c+DQo8L3N2Zz4=', 'RU_KK')

RU_KK = b64_RU_KK
index.append("RU_KK")
index.append("Russia Khakasiya Respublika")
catalog["RU_KK"] = RU_KK
catalog["Russia Khakasiya Respublika"] = RU_KK
country["Russia Khakasiya Respublika"] = ('RU_KK', '', 1)
lookup["RU_KK"] = ('RU_KK', '', 'Russia Khakasiya Respublika', 1)
lookup["Khakassia"] = ('RU_KK', '', 'Russia Khakasiya Respublika', 1)
lookup["Russia Khakasiya Respublika"] = ('RU_KK', '', 'Russia Khakasiya Respublika', 1)
details["RU_KK"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+07:00","altname":"Khakassia"}
regional["RU_KK"] = ('RU_KK', 'Russia Khakasiya Respublika', 1)
regional["Russia Khakasiya Respublika"] = ('RU_KK', 'Russia Khakasiya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_KL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA2'
    b'NDAgMzIwIiBoZWlnaHQ9IjMyMCIgd2lkdGg9IjY0MCI+CjxwYXRoIGZpbGw9IiNmZmM3MmMi'
    b'IGQ9Ik0wLDBINjQwVjMyMEgweiIvPgo8Y2lyY2xlIGZpbGw9IiMwMDljZGQiIHI9IjkyLjgi'
    b'IGN5PSIxNjAiIGN4PSIzMjAiLz4KPGcgZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDA5Y2RkIiBz'
    b'dHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13'
    b'aWR0aD0iMS45MiI+CjxwYXRoIGQ9Ik0yOTEuMywxNTQuN2MtNSwtMTcuMyAtMTEuOSwtMjUu'
    b'NiAtMjcuMywtMzMgLTExLjgsMjkuOSAxMCw0OC4yIDI5LjcsNDkuMSAtMjMuNiwtMS4xIC0y'
    b'NS43LC0xOS4yIC01OC40LC0zLjIgMjguMywyOS44IDQxLDE1LjkgNjYsNy45IC0xNy42LDUu'
    b'NiAtMjksMTMuOCAtMzIuNSwyOS40IDIwLjcsMi4yIDM5LjksMS42IDUxLjIsLTI2IDExLjMs'
    b'MjcuNyAzMC41LDI4LjIgNTEuMiwyNiAtMy40LC0xNS41IC0xNC45LC0yMy44IC0zMi41LC0y'
    b'OS40IDI1LDggMzcuOCwyMS45IDY2LC03LjkgLTMyLjcsLTE2IC0zNC44LDIgLTU4LjQsMy4y'
    b'IDE5LjYsLTAuOSA0MS41LC0xOS4yIDI5LjcsLTQ5LjEgLTE1LjQsNy40IC0yMi4zLDE1Ljcg'
    b'LTI3LjMsMzMiLz4KPHBhdGggZD0iTTMwMC44LDE2OWMtMTcuNSwtMTQuNyAtMjMuOCwtMzcg'
    b'LTEwLC01NS44IDExLjIsOCAxNi42LDE4LjEgMjEuMiwzNy4zTTMzOS40LDE2OWMxNy41LC0x'
    b'NC43IDIzLjgsLTM3IDEwLC01NS44IC0xMS4yLDggLTE2LjYsMTguMSAtMjEuMiwzNy4zIi8+'
    b'CjxwYXRoIGQ9Ik0zMjguNCwxNjkuNGM5LjEsLTE5LjIgOC42LC00NS4zIC04LjMsLTU4Ljgg'
    b'LTE2LjksMTMuNiAtMTcuNSwzOS42IC04LjMsNTguOCIvPgo8L2c+Cjwvc3ZnPgo=', 'RU_KL')

RU_KL = b64_RU_KL
index.append("RU_KL")
index.append("Russia Kalmykiya Respublika")
catalog["RU_KL"] = RU_KL
catalog["Russia Kalmykiya Respublika"] = RU_KL
country["Russia Kalmykiya Respublika"] = ('RU_KL', '', 1)
lookup["RU_KL"] = ('RU_KL', '', 'Russia Kalmykiya Respublika', 1)
lookup["Kalmykia"] = ('RU_KL', '', 'Russia Kalmykiya Respublika', 1)
lookup["Russia Kalmykiya Respublika"] = ('RU_KL', '', 'Russia Kalmykiya Respublika', 1)
details["RU_KL"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Kalmykia"}
regional["RU_KL"] = ('RU_KL', 'Russia Kalmykiya Respublika', 1)
regional["Russia Kalmykiya Respublika"] = ('RU_KL', 'Russia Kalmykiya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_KLU = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc5MTciIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODAiIHZpZXdCb3g9IjAgMCAxMjAgODAiIHNvZGlwb2RpOmRvY25hbWU9IkZsYWdfb2Zf'
    b'S2FsdWdhX09ibGFzdC5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtz'
    b'Y2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9z'
    b'b2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4bGlu'
    b'az0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4K'
    b'ICA8ZGVmcyBpZD0iZGVmczkyMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJuYW1l'
    b'ZHZpZXc5MTkiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2NjYiIGJv'
    b'cmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2NhcGU6cGFn'
    b'ZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZyBp'
    b'bmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiIGlkPSJn'
    b'OTIzIj4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjgwIiBwcmVzZXJ2ZUFzcGVj'
    b'dFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0eSIg'
    b'eGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhF'
    b'VWdBQUFIZ0FBQUJRQ0FJQUFBQmQrU2JlQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNG'
    b'Sk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFB'
    b'QUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBSApUa2xFUVZSNDJ1M2ErM09VVnhuQThYUE9lOTlM'
    b'TnB0TnNza21hUzZicE5BMEtaU0dLUWhDd09tQWphV0FuUXBTcTViUlRxMWpiM1pVClJzZldq'
    b'anAyclA1UUdhZHFwMUxVR2JSRTBCSkxnZEFTRXBDRWtFUUpLV2tnbDgxbDJjM3VKcnY3WHM4'
    b'NS91b3dqUFlYT2h2NmZQK0MKczU5OTlubmZlZC9GazVnZzZPWUh5aDlUNHVJNjdod2hYYzB5'
    b'RVZEalArMEtod0wwVFlsaWRQUU90YkNGcVc1K2RsNVdoOHdpeWhiTAo0ZkVpMnRFT3hyRjl4'
    b'SzF5aEJBaEtQa3dMbHM4UTczSVZrZjdyOVdTZTZuaTVqUHZDaHU0Q2F2ajVweVY4MVhuckFO'
    b'QlZSVFFwL3ZOCkVycVlkdlFpdSt1NDlEa3g2T2VoUWpiNWdBQjNIVGN4ZHhYZnZUNkRFSHEv'
    b'VjNFd0ZqbGZMQ2NYbnNFNEI0L0ZFQm91bFBxcnBmUTIKY2tUV1BESVBKTmdWU2J3Y0VZdFhz'
    b'ZW1ZMEwxWERxYVpuN0dKQXZGdk8xWDFJZDdKbFdzNktjNHdDU2I2STk1YXRGY3FyaStnWFZ1'
    b'egozOXViOS9CYWZYeFdpS3gxWmUzOE1icmd4L3FlbDN5VThLODhtTzFEK1JsdlhpU1RtSW80'
    b'YVpYOHEwQjg5VkRtNEx2YTVDdGsrNXhPCllLTC9SeWxDdXA2UWQzemYrT0hyZVpldVNPRUs1'
    b'OUFwZFh1TE1SSWxyYTBsYVZ2VTBVSzR6cW1vcFA1aVhscFl0SHlaT2p3ejE3cEcKUDNSU1c3'
    b'ZkMvT003V3NkNTVmbGZaQTRudGJvUG5KejZxZWJRRjg4UmVxWFdvNVdqbi83ZTg4d1gwL2sr'
    b'OXRnRDJZMzNXUGxlUGp3bQpYQncxRzhPcVplUEJFWEUySml4azhlMVZTdWVBTVRxQnV3Zmxy'
    b'UnYwN1MyR1MrR1AzcC85Ylp0cjFRN3JRTDRHcStQR25jK1RIbnBTCmY2M052ZjlIQ1UzaFp3'
    b'YmxYLzNabmRYeHdST3FJdk5vSXIzODlzQkNWcTBPbVpyQ003cXIyQytrMHFsQ1ArdTVLQTJO'
    b'aXY4NHJaWUgKNlpaMXh1b21xL1hwZ3VlZXpaZy93RXJPWEMxemFIVjBMMVZ3RFhwOFcvYjF3'
    b'NjRMdzFJd1FHZmk1THRmVGpzVTJ3NW1qQzJyejdzeQo1VndldHpsR3dRSlhXWkhXTlJDTEo0'
    b'WHZQSnIrL0VhOTdUMDFsY1laSGJlZlZsOThmS0ZyVUJaR2VURExZSFZjMzlDMHRLckpVaFhl'
    b'Ck55dy91TjdZdFZrWEJOUTNMTVZTNUVpbkdwMmpoc1hkcWtJd2p5V0kzNk5jdUd6R2srVEtG'
    b'RGwxUWQ3Zjd0cHhuLzd6cCtiSFo4UmsKR2xlSGFIT0RQV0hrME84MWh5WTZzd20zRFdoanMr'
    b'S0xYNS8vUzRkYWtNZFA5aXJ2OThsUGJNOWFEcjZXd0xjRlBiMlh6TmExeVZBaApHNXZ4RW1J'
    b'ZDdPQy8yWk84cTg3K3lSdmU2akpuU2FWem9rZmV1Tkk2Zms0NWRsWXB1MFpyRnloTTlQV3BC'
    b'ZzlYMEhDNTQ5YjRoeFBpCnlmUHl6NzZaOHJwNGFTRzk3MTVqTkNLZStiZFI0SXVIaW1oRDJF'
    b'NmxVNzFEaGlqeTJUbHlva2Y1OXBmU24ycXluM3padDdYRmFGbGgKZGcvS1g5dVd6VXR4bU9n'
    b'Yk5KRVZ3bHZvdVNGcE1pcXV1OXVrRkpjVXNxTm4xS05uRlVWQ3g4NHBUKytJRGwwVkIwZWtp'
    b'NlBTWGZYbQovV3N5YlIxYXFJZ2RPSzVWbGRBVlM2MUxWNlVQeGtUR1VHMEZiVCtscmo5dnVu'
    b'TG1ZcGhERTkwOFpjOUd5ZElxR3JsR0dtcWNReWZWClozK1p0NnplYnFoeHFrTE9teThrUkpG'
    b'UHg4bXFKdXN6SzgydWZzbWo4VmVmVHpYVzJrc3JuY3BTWjlPM0FwdFhtODBOOXQ2MzNFVisK'
    b'aXFlNGo4RkUzNmlqdTdUaUdqWjBWZlJxdk8reXhEaXVDTktHc0ZOYjduVDFLL3ZiWFk5dHlY'
    b'SkdPdnZWc1dseHpUSzdPdVRzZmltZgpjYlM2eVdvSU84ZlBxcnFOcTBwb1dpZWhBRzI2eCtt'
    b'ZWxHcW5LRUJmM3dtcVJrUkNPVllrYWYwSzYwcUU5QTFMZjNwSDgrZnhqSTdYCjNXMjk4SnEz'
    b'S0Q5WUVsaTRvNW9lN0FpODhYZnhxUjJaU0V4TTYvamxOejAvL3NiODFEV0JJeFNKaWc1RFZh'
    b'VnNZcDlRWnpnNTh1bHkKNnczTGxDQmNmRTdLQ3lDRVdFZXZUNVUwanBPUGJNNmswcml6WDQ2'
    b'bmhPWDFEbVdxYmdobHhmT2QvWEl3d082c3R2MCtkTHBQS2k5MQp6Z3pJV1pNMDFWbVJUakV3'
    b'd1Q1N1ZjK2RIWjF6cjdLdWl1THZ3dTVscmNqbk5YMXVGa3VSd1JGL0ttMHVxVFFDUGpZZEZ5'
    b'UkJZb2hRCmFwWUVhTmJFNHpOYWZiblhjbUkxWlhaOG50aTJkT3FzZTgveFdYZU9QVUhOeFhl'
    b'R2s2THc5aU5seVV4YWtpeFY1cHJLTVVjZUYxSVYKUGhvUkZySkVrVEhpYkVtVlkxT1V5UkxM'
    b'UnBhRHN6cTJIRkpYNFUvOU5mSFZEMVB3bVBUL042S0pHVE9CQmJSems5NTdLWEJiMENzSgpS'
    b'RlhHSjZPb3NoUTNONFQ4SHVIWXVYR0VlTDVIYVF3SGRaTm1qWGhqZUw2alIra2JqcXM1K1RJ'
    b'akZ3OVZUWkM4cENCaFJHZGlBblVFCmhIZ3liVmE2V1dNdDNYZEVpczdOYWdxZWlaT2RtNHl4'
    b'YVRJYk03MGUwYUhZc1BETUhLa0l1amU4SGMvQkQ1V0xxOFBFK0E4YjgvVnkKKzg2d25URnhM'
    b'RUZzQjNPT1pZazVEa1lJaVFKbkdDT09DT2FXZzZtREtrcVlXMlB2OWNoMUlVL3RXOG5tV1Iy'
    b'Z1AxS0gvZXJjU29HTgpvK0lJRFpxMGdIRWZZd3BITHM2RS83ckljWVNTaENRSm1aQkl0RVEw'
    b'eWxEK0FHdWROMkNpUDdtQk1rRGZXb21rb0FEbDVEOE9ickV3Clh6ei9RWUhWQVFFMFFBTTBC'
    b'TkFBRFFFMFFBTTBCTkFBRFFFMFFIK3l3cUcyM2ZDUTlHTkluTkxuUUFGV0IwQkRBQTNRQUEw'
    b'Qk5FQkQKQUEzUUFBMEJORUJEQUEzUUFBMEJORUJEQUEzUUFBMEJORUJEQUEzUUFBMEJORUJE'
    b'QUEzUUFBMEI5SzNRZndCV2VFUGpockY5WkFBQQpBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUFN'
    b'akF5TXkwd05DMHlPRlF3TlRvME56b3dNQ3N3TURvd01EU0pFakFBQUFBbGRFVllkR1JoCmRH'
    b'VTZiVzlrYVdaNUFESXdNak10TURRdE1qaFVNRFU2TkRjNk1EQXJNREE2TURCRjFLcU1BQUFB'
    b'QUVsRlRrU3VRbUNDCiIgaWQ9ImltYWdlOTI1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'RU_KLU')

RU_KLU = b64_RU_KLU
index.append("RU_KLU")
index.append("Russia Kaluzhskaya oblast'")
catalog["RU_KLU"] = RU_KLU
catalog["Russia Kaluzhskaya oblast'"] = RU_KLU
country["Russia Kaluzhskaya oblast'"] = ('RU_KLU', '', 1)
lookup["RU_KLU"] = ('RU_KLU', '', "Russia Kaluzhskaya oblast'", 1)
lookup["Kaluga"] = ('RU_KLU', '', "Russia Kaluzhskaya oblast'", 1)
lookup["Russia Kaluzhskaya oblast'"] = ('RU_KLU', '', "Russia Kaluzhskaya oblast'", 1)
details["RU_KLU"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Kaluga"}
regional["RU_KLU"] = ('RU_KLU', "Russia Kaluzhskaya oblast'", 1)
regional["Russia Kaluzhskaya oblast'"] = ('RU_KLU', "Russia Kaluzhskaya oblast'", 1)
#----------------------------------------------------------------------
b64_RU_KO = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMjAwIiBoZWlnaHQ9IjgwMCIgdmll'
    b'd0JveD0iMCAwIDkgNiI+CjxyZWN0IGZpbGw9IiNGRkYiIHdpZHRoPSI5IiBoZWlnaHQ9IjYi'
    b'Lz4KPHJlY3QgZmlsbD0iIzAwOUIzQSIgd2lkdGg9IjkiIGhlaWdodD0iNCIvPgo8cmVjdCBm'
    b'aWxsPSIjMDAzOUE2IiB3aWR0aD0iOSIgaGVpZ2h0PSIyIi8+Cjwvc3ZnPg==', 'RU_KO')

RU_KO = b64_RU_KO
index.append("RU_KO")
index.append("Russia Komi Respublika")
catalog["RU_KO"] = RU_KO
catalog["Russia Komi Respublika"] = RU_KO
country["Russia Komi Respublika"] = ('RU_KO', '', 1)
lookup["RU_KO"] = ('RU_KO', '', 'Russia Komi Respublika', 1)
lookup["Komi"] = ('RU_KO', '', 'Russia Komi Respublika', 1)
lookup["Russia Komi Respublika"] = ('RU_KO', '', 'Russia Komi Respublika', 1)
details["RU_KO"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Komi"}
regional["RU_KO"] = ('RU_KO', 'Russia Komi Respublika', 1)
regional["Russia Komi Respublika"] = ('RU_KO', 'Russia Komi Respublika', 1)
#----------------------------------------------------------------------
b64_RU_KOS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmc5MiIgd2lkdGg9IjEyMCIgaGVpZ2h0'
    b'PSI4MCIgdmlld0JveD0iMCAwIDEyMCA4MCIgc29kaXBvZGk6ZG9jbmFtZT0iMTIwcHgtRmxh'
    b'Z19vZl9Lb3N0cm9tYV9PYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93'
    b'd3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJo'
    b'dHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1s'
    b'bnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8v'
    b'd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAw'
    b'L3N2ZyI+CiAgPGRlZnMgaWQ9ImRlZnM5NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlk'
    b'PSJuYW1lZHZpZXc5NCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2'
    b'NiIgYm9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2Fw'
    b'ZTpwYWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgog'
    b'IDxnIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIg'
    b'aWQ9Imc5OCI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxp'
    b'dHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFO'
    b'U1VoRVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFD'
    b'QmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxF'
    b'OEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQUEKQjNSSlRVVUg0UWdLQWdBeWhWSk16QUFB'
    b'Q3VSSlJFRlVlTnJ0M0d0d0ZlVWR4L0hmLzNuMjdKNTdjbkpQU0VpSXVTQ0VBRUliTUZHdwpn'
    b'RldoaWhlcWVMZnRNQ3JhV212djFVNDdhanZUNm5TWThWTFIwZHBLTDliU0NtMFZ0Q3FJSUFJ'
    b'eEpKUVFFaURtZW1KSWNrN09mZmQ1Cm5yNFE3ZGdYZGpvVEJKcm4rL3FjWnphZjJmbnZQbWN6'
    b'Uy90eHNxcGZ1QUZuV3Z0M1hudVNWbWJRZlNwcGFBMnRvWFVhV2tOcmFFMmcKb1RXMFRrTnJh'
    b'QTJ0MDlBYVdxZWhOYlNHMW1sb0RhMzcvNGZlc09hUitXVkh6N2pETnM2SW83eStZY2VOUzdk'
    b'MTloWDJET2VWKzBjNgp3MFVhZW9LNzlweWQ4NmQzcmJuaVphbkU0b1pXQUR1Mnp6d1RSOGZw'
    b'RG4zRHNqY2k0dmlUejFFMHhjMUE4ZUpadlk1Z0ducmk2eHNPClByVytyWDY2N084QlhMM0pN'
    b'QnJuRVdOU1h3d251SlRqaWNkbCt5YWpLWEJGNXpFMExZREpoYjdyT0FuUXRybmhDU3k0eW1s'
    b'cGZYSFYKQ2xnR1hDNkhrWWFlNktSZ2xkTXcvMXk0ejNXV0xjV0NCcmk0UEJQUDZOTjlSanVT'
    b'R1FZdVc0NUxMeVlwNlJlL1hsRVlHTlBRRTUrUQpiT1BXQmUrOW43ZjdZSlhKbkpod3I3djYy'
    b'Uy9PZWZ2Um5aL1QwQlBacGozejlyNVhJVUhQM2ZMbzdKcnVEVnZQSTBOZU5MTmwyN0hxCnRv'
    b'RXlQYU1uck4zZGxaYmh2UHkxbjF4eDlnNWZPbm5kZVc4bUhmTTdmN3JtemtWYjgzM2pHbnJD'
    b'c2d6bnBYc2VQSDlLR3hUeUVTMDMKd2dYdTZQcWJuOXpSVmZQRFN6WVNLUTA5TWExYi9VeERY'
    b'Z2NrUk14aWhpUUhKam4xK1YzZnVIQnpyaWUydHVGVkRUMEJYYi9nclpzYQpYbE1PaVpqRjNJ'
    b'NTBHRWdSRkV0UWJkWjdkYVhkeTJ0YWxsVWQrSVFWZnZQbHg5eUdyYUUvOFRKTjRyNlZ6eU1P'
    b'SjJZeXQ2MXN4a3loCkJBT0hrb0REcXJON0Z0YTF1cm1UWlNYLzQ3c0JNMVVTSFB2RG5ldUNs'
    b'RW81TG4zWDhjbW44NDV5NzVBOVpIRlBCcEtUSVlsTE9Bd1EKSU9Za1RDT1llbURMVlpzT3pm'
    b'NzNXVVBLTk1SUFZ2MTJWZU11d2RqRGYxaEJtZE5saUo4dTBFUktxWS90ckMvL3pHNTcwTTM5'
    b'YWVVdwpRREdYQUNBbE1RYTRGVG1JeC93UHZib2NRSkV2ZXMyQ3R4clA3aWoyalFiekVtMUh5'
    b'MmJlL2JQenF3OXRhcHY3K2wwUFBMMW5VU1R0CjBkQW5XakwxNE0wTHQyOXNucmU5dDNZb0h2'
    b'QVltUVovdCtGUEM1dVRBdlBhQUpURldKRmtYaWdMS3MyMjdhb0xHT21JN1I2TUI3ZDMKVEgr'
    b'cHRiNTlxR1IyY1UvYjRCU2gyS2EydVN0bjduMC9ITHB1L3M1SGQ1ejYzYzJwbjlFaFQzejFu'
    b'RjJ2ZE0vSXo0MThhOUhmLzd6bQo0WXJnOERkbmI4a3VpNGlrQ3dCWkRnaFVET1UxV0pZQUFB'
    b'a2VzcHZmbS9iNXNyWVBGdG5iVTlFK1ZBS2daYUJNcUJOLzFLeWkzbDI5CjA4NE85VCs3K3JH'
    b'T0g5eDE0THYzVE10NmZ6S2UwZmRmL01KbmF6dUtLWjVVWm10LzJXak1PN3UyeDVMT2kxZXZ1'
    b'M3ZMYXBuZ1pBb2kKUlZ5eEVpQUFKQWhRSUxBY1d3eFl5WlNyTnhZNnQvRElXK0hLajlhc0NB'
    b'NS9aY0hycGJuRForV0djNExSb3NDWTEwakttRW1BY3FtLwpydjNwakFjZm1selF2N24rOGZQ'
    b'bkhRZ2xvMktLTWZ6UDNHZXVlakpGM09valZZcTBsODNLNytQWmprZ1FtWUx5Z1FBQVFFSFpu'
    b'QXdKCmdJV2N1SFJQRFl3d3FIZEhTaE8yQ1dCNVRjdUdMejlzeEFtSzhNRmVKZ2tKVS9rbDBx'
    b'UlN2Q1E0TXVsR3gyaXIxWG1rMktxenZhR2sKa1oyQlY2V2tTeVU1R3pJcUt3WWp0dHRKR3N4'
    b'eXlBUEtQZkVWNVRCSXdGQUFlTFk5TjcrN2JhU2tKNTV6ZGVXZUR6N3c0T1hQR1RFbQowd2Iz'
    b'Mk55ZllWNmJlV3ptZGxvSEtuWVBWTXVnK1AzZXhrazNPbHIyRm4ybW9pczI3UFhuSlVwbURy'
    b'RTlGTzRPRFZlNWNnY3dZcm92Cm1ISm9HSUZDU2xQaGg4b0pEZ1VZOHFOdHQ1TW5aNFFHREpK'
    b'N2hpc1dGWGU4TVZBVFQzbFlUb2JTaHBUa2hBUE1kR0JJT094d3VPakcKRGJkUDBvdmhzOWFG'
    b'ZTR5YTVsM1ZrYzRzQUc1SHZORmZzN2V6a21jNy9sQXlHYURtbytXVUE3Z1JpM2lPaDRPeEhq'
    b'K1pramp3NFZSbwptbnRRU05ZOFBMVTJPRkRvSGkvd1JKYzg4djAzTytxSlMyWUtLSUJBQkhD'
    b'MWN1N2JiOTM1dzBsNmU1Y1IvSTRYYm54dXhSTTFoWU5CCko1cHhYQ3RtTk0vSzZaZFJQdExu'
    b'LzhHbVZUY3QybmJod25mdmUrU2F4MTliR3N0WXF5dmZ5UXJHeWd1T1g3bDBwOStYeUN1TDFG'
    b'YjMKV2dYSnkwUE5yL1hWakdSODExYnZEaFdQUitJKzhnclljT1hINmFObk1RUy9MM1Zxb2Zs'
    b'dEoyM3B4OHF1L0srZitjdmh1Y3ZQZWJlcwpjTmhVVGlHTHlVRkxUQkdiT3VZd0xqODM4OERB'
    b'VU40VFc1ZjBSN01WcUM2bnYzc3M3K0RnbElMOHlLMlByMmxybnhweTBrMzE3ZmR1CnZxcXhz'
    b'S3ZJTTE1Vk1YRDN6WCt1bnRuSDh4V0Z3TElWc3NCQ29CeFFBWHdCZTZRM3VMZC8yaWNmejIy'
    b'OUwveC8za2YvYU5uR3hrVnQKNUpZQWpPSzBXVDl1ZUoyNnNwNm4xejcrYXR1c2ZhMlY2Mjlk'
    b'WHhLTXJMMWc2OUo1TFFhWHkrYzBBMmc2cTUwYmN0M0dpOS9aVzFPUQpGUzNNaTg2dlB4eU4r'
    b'cnAybDU4WUt3eXdRQjdBQWdncUJrOHcrY0F0R3hxbkhwNk1HNWE3ejN2NXE3ZHNKcWJJVU9a'
    b'WkNWalN5TS80CnBrZk9YZHdtNHNiYXBxMFh6VzJwemczbmVHUGZ2R3p6UUNSVVg5cDk2WGw3'
    b'd05TTlRXK3VXcmhMRUMxWjJNSklJamR6WmNQdWkyYzEKNTAwL3psMVNKUUVGMklDQ2tsQnhJ'
    b'QWt3QkwzeFc1cTJUYm9aZlVsTnkvZSs5RWUzTHcwRktBQXdDakt3SVNOTXBneDNSV0ptNVpI'
    b'MAppRGw2SlB1aHkzN3JUVGsxeFlQVEYvY0VaSXFSbkZON0pEYnFuVjE5YkdyV3lGT3JuN0w4'
    b'bVd4UE1uZnhJYktsU29COFFBcXdnQXlJClFhVUJRQW5BUm5ZZ051bWcxeXo1UnpBM0RnQU80'
    b'QUxTZ0F2SzVqSnBjRjlhUmFGc3htMHFtajlVaENHbjMxbzA2K0JZM01OSnpnLzEKUkk3N1Bj'
    b'cTU3Zk5iV1paVE5iMlBlVElpYkZGYVVoWkF3RGlVRnlTaEJCQUQzTUE0SUtFRVdvK1dUenJv'
    b'b3REWWlSdGtCcklCQy9LNApJVzFtRktUQm9KSk1wZ3h1cGRVQVZNWkZoZ2dWaklRWXhLaVZY'
    b'eldzTWt6RkRLODdJd1pOY3Rzd0FMK2lFRlFDU0lHeUFBQUprQnR5CkVLd01jZ1FVeGRGd3li'
    b'cHR5eWJkak43WGNlSUhDdUtBVGZLNEFRTkdRVVpGSVllWUhPZEduazI1UUpDckFIaXVBMENN'
    b'bXN4bEl3WVoKTlpqZmhwY1FBQzlWVUp3cG9jSUFRRGxRS1dBY2NFTU9nWlZBRFFOQlJFZThk'
    b'eno3cGRHVWI5SkIvK2h2bDdmdkx3ZWdNa3hLQnE1SQpPbkFBa3l1RGs5dFJ4NVhzNVhLWU0y'
    b'V3JOR0J6OGtnS1NzVTU4MHBBeVFpbnRGQzlVQm1DVjFFQlNFQU5BUXpraFVxQTVVSWxvVHdZ'
    b'CkdjMjY0Ykc3WHUyYU1SbDNodUZFOE90UDMzQnNmNG5LRUNTeGJFSFprRkdta2tSU01JOUNO'
    b'bE1leHFiWTVJTVNKREtja2FOaUpGT2MKeUFHREVweVhDaXFDbEl5U1VnNEFBQldBUElBSnln'
    b'TGNVQUgyeGp0ekx2M1p0MS9xckp1a08wTUEzSkFEeWF5V1Z5cXFTZ2RtekRtRwpESU5Kc0NT'
    b'RGxLTk1nck8wZ0tNVUI1VEJMVUVtVklvelU0QkJ4amd4b1hvZ3dNa3ZLQWo2K0tQQlROeTE2'
    b'KzJ6TjJ4dmZHWmZrMVNuCi9yOGlUeVgwbGtOMVd4Nm9BMkNRK1BuSzM5MzBoZGY2ZS9MS3F3'
    b'ZGRiaHNXNDRha0Fna2JJbUlRS1VESUJKTkVuRHZnZ01tWVQ1QVgKUEE2bGdBK1ZaWnEzSHlq'
    b'ZDNqYmpML3ZtdlhKa0JrNmJUb3RIV1Q0ejB6V2F2L2krZTF0Nnk1dktPbjk1Ky9yUlVkOVl3'
    b'bHRaSEM0dgpHZWFtSUs4Z0EycWNjU2JKQjVYZ1JJcThFZ3BLa3BQbVJ6dW5kUFNXdEhXWGJl'
    b'K29mZjFZcmFNNFRyUG9kSHVUWTBsd3JMSHEwUFA3CkdnQXdVdmN2Zjk3SjhGakdYVlVRYnFw'
    b'djM5TlJxWURQVHU4NjFsZXd2MmRxamp0MndjTFdTMzc4bmNOamhXb2k1c1BKZTVNam5ZbXYK'
    b'ekh4azlhL3VlZjdhcE9QNjlrV2JYUzduL2swckoycGxEZjBwcGQ5TmVzYW5vVFcwaHRacGFB'
    b'MnRvVFdCaHRiUU9nMnRvVFcwVGtOcgphSjJHMXRBYVdxZWhOYlR1ZisxZmFPNjBIcW9EeXJj'
    b'QUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNVGN0TURndE1UQlVNREk2Ck1EQTZOVEFy'
    b'TURBNk1EQzVHd3htQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ERTNMVEE0TFRFd1ZE'
    b'QXlPakF3T2pVd0t6QXcKT2pBd3lFYTAyZ0FBQUFCSlJVNUVya0pnZ2c9PQoiIGlkPSJpbWFn'
    b'ZTEwMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_KOS')

RU_KOS = b64_RU_KOS
index.append("RU_KOS")
index.append("Russia Kostromskaya oblast")
catalog["RU_KOS"] = RU_KOS
catalog["Russia Kostromskaya oblast"] = RU_KOS
country["Russia Kostromskaya oblast"] = ('RU_KOS', '', 1)
lookup["RU_KOS"] = ('RU_KOS', '', 'Russia Kostromskaya oblast', 1)
lookup["Kostroma"] = ('RU_KOS', '', 'Russia Kostromskaya oblast', 1)
lookup["Russia Kostromskaya oblast"] = ('RU_KOS', '', 'Russia Kostromskaya oblast', 1)
details["RU_KOS"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Kostroma"}
regional["RU_KOS"] = ('RU_KOS', 'Russia Kostromskaya oblast', 1)
regional["Russia Kostromskaya oblast"] = ('RU_KOS', 'Russia Kostromskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_KR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI5MDAiIGhl'
    b'aWdodD0iNjAwIj4NCjxwYXRoIGZpbGw9IiMwMDgwMDAiIGQ9Ik0wIDBoOTAwdjYwMEgweiIv'
    b'Pg0KPHBhdGggZmlsbD0iIzAwYWFmZiIgZD0iTTAgMGg5MDB2NDAwSDB6Ii8+DQo8cGF0aCBm'
    b'aWxsPSIjZDUwMDAwIiBkPSJNMCAwaDkwMHYyMDBIMHoiLz4NCjwvc3ZnPg0K', 'RU_KR')

RU_KR = b64_RU_KR
index.append("RU_KR")
index.append("Russia Kareliya Respublika")
catalog["RU_KR"] = RU_KR
catalog["Russia Kareliya Respublika"] = RU_KR
country["Russia Kareliya Respublika"] = ('RU_KR', '', 1)
lookup["RU_KR"] = ('RU_KR', '', 'Russia Kareliya Respublika', 1)
lookup["Karelia"] = ('RU_KR', '', 'Russia Kareliya Respublika', 1)
lookup["Russia Kareliya Respublika"] = ('RU_KR', '', 'Russia Kareliya Respublika', 1)
details["RU_KR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Karelia"}
regional["RU_KR"] = ('RU_KR', 'Russia Kareliya Respublika', 1)
regional["Russia Kareliya Respublika"] = ('RU_KR', 'Russia Kareliya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_KRS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxMTg3IiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X0t1cnNrX09ibGFzdC5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtz'
    b'Y2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9z'
    b'b2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4bGlu'
    b'az0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4K'
    b'ICA8ZGVmcyBpZD0iZGVmczExOTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFt'
    b'ZWR2aWV3MTE4OSIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpw'
    b'YWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxn'
    b'IGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9'
    b'ImcxMTkzIj4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjgwIiBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0'
    b'eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5T'
    b'VWhFVWdBQUFIZ0FBQUJRQ0FJQUFBQmQrU2JlQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNC'
    b'alNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4'
    b'QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBSQo3a2xFUVZSNDJ1MmFlMnhUMXgzSDc5Tysx'
    b'OC9Zc1IzbkFjUkp5SU1RQnlpdkJDSm8wZ3E2d2hDamF3R1ZxWlFXOXBDRzFBMVZLM1RUCjJO'
    b'WlNxVjFacDY2anJMUjBZMEVzcklHbUlRa0pKQVFUQ0ZtSUV4NjJTWWhqSjdIaloveTR2cjYr'
    b'ci8yQlJCZUt0R21DeXQzTzV5OWIKUGtjNjUzT092dmZubncxUFpHZERnRWNQQWhRQTBVQTBB'
    b'SWdHb29Gb0FCQU5SQU9BYUNBYWlBWUEwVUEwQUlnR29vRm9BQkFOUkFPQQphQ0FhaUFZOGVq'
    b'RE1aQUlXdmdaZ1VSU0JCUkFkRDZDNy9lalp6dzhDMFkrY08vYXVNVWZYTnkranZ5a0w1WG5P'
    b'TnRoQ0tuSzVGTTF5CjBJaWpMK3kzVlN6ZUpKV1NJS01mR21OTys5a1R1NVJ5d3RaaVQ2U0Nn'
    b'Z1JUOEJuRmF3dW9KUFRVMXNPNWVTWVFIUThwbDV2ZmtHSkoKWG1BREpFY0VsSktBSkprdHNB'
    b'SWtRV0pkelFkQWREdzBCQWlDK1NoRlJ3dEx0R0Z4UXE1V29qb1pUN3NoU0lRNEZEd00vMHQ4'
    b'VTFOLwplTFhhWWJkOUdkQ0NaR1RFM1dXNVRVVkNjWVRtWVg5b2FzTG1jSTFQQmpDRXZqdEdG'
    b'TVdiTjY0ZjJydk03L01CMGY4UnJjZmZXci9DCmV2UzFMYUZRaUUybGp1N2F0V0xGRDZYNjVh'
    b'Uk00NDh3U1pGMUJWaWFnU0l4TVM0V2xjM2Y4Y25Pbld3cTVmUDVHbjYxN2VtcTYyZFAKdmcr'
    b'aTQ5L0FjWnpYNnhWUllteGNxZFhUSC81c2kzaUxYaFNKZEE4T0duWnVaVDBYQkcrV1R5bEJK'
    b'SEtGWDZJcFNEQlp5L3YzN01sTApKTjZ1cTBQS0pWbzlkY2VwZ2lUU3lja0pvekViUWRMb0dx'
    b'VlgxZEhSMmtTTzdoaTZyUnllSUYvYTZEN1IrVmh3VkFZUmlxVzNoMWhJCnRLcmsrVnVlSjBr'
    b'U2htR1daZTk4K2tuSmRGU09vcmZNWmlZV3k4aVBibHhoUGZ6M1dlVW1xdFJFTVVXZlB2N0Vt'
    b'alFTbmJ6NWRQcXMKWnU4dnZYV1ZmbzJHYWJVWWRRVGtvbkNQNWtYM25YNFNUU213MUhpeThP'
    b'UDNkNWNVNnUrTmR3d01HUEx5TW5TNit2cGoxMDY5TzF2Qgp4VG0rcnRybjljb3UyalAzN3pP'
    b'bWtXaktBcWZQYWhyUDY1MjNkVVBocGRrNjJoOGtYMyt4ZnYrWnQ0TWVhL1dTd3JhMkZoSENw'
    b'ZHBWCnh6N2NiZFFyNzV0WVgvOFhNNzd6d0xIbkRKbEpYd0F0MWZRWGxRYlcxd1RBdy9BQnhH'
    b'alU0NWZXVmdXMnIrcWtHYW1UTFcxb254c04KVGE2dFhTQ1ZTamR2M2hwbHNpTVV1dnYxeGhq'
    b'RmZIVjZmWXZaelJZSEtmVUx0WmJxeXNpNGwwalFDQkQ5QU01MDYxWlYwSjFYZEE0bgpIb2ly'
    b'RVZqSVZGSVoydXkydHJNTlg5ai9kTFRObE0wSVhHTFVGWHJ0aldhT0UvNTFyaWlLQ2dYRmlu'
    b'aUlVdDUwWUwyRG1zZk5pY1lMCmVpRDZmbzU4bGpkcHk4RlJjWDdKZEo5em5pdFZzQ0t6bldP'
    b'NDZvV3FHR3ZnQlF6WDFrelFTeEJNaFhJVGZmMy9lUFAzSFRNU0VJTFUKa3VrcXZTVXBtM3ZO'
    b'WGJLd1BNUnhhTUNSZTZReEY0aWV3YVludlFtY2FqaVRlNjVYN3hRV0Z5dnRtNThZNERoTXBV'
    b'QStlRzgvb1RMZAp2YmRMNW5yTWhja2N1YjNwc3lNZjFmZk9LQTFUK0xiYWJwTDNqUEpWclQz'
    b'NnBuWWpKWWx0WHVzQm9tZWdWbkRiTmprcEJrblFNSVlJCkM1VjlWNjdxVTd3QWlXSjVpZkhB'
    b'dm8wSUFxT0NYNlBSckY1ZGcySmtTc0ErK0xpbHVlUFd2ZWhJc0tMbHNtR3hvZ3VCaFVRQ2lU'
    b'UEkKQzg4NFpZUUFSTThneVNCdEY3SldtcU9MVEd5VnJtZVlOaGx6bzRTRXYvdHB6YktDSCs5'
    b'WXliTGM1SVR6cjhlYmNyTDFHV1JFNEpGZgovNjY5OTVycjNsSGxGMDY3R1dPMS90TGlvbFIx'
    b'NVhTSFJjOXlNQkE5ZzFBTW02M2pLeW9DSmNWaEZUbTljODE1blVxSXhQQjdBN1p1ClhMVGx1'
    b'WFdlcWJBbmJyb3dxSWd5V1poVXdYSENxNy81WXRnWmdDQW9FSmJvbFB6THRlZTBaSERldk9E'
    b'OHNyQktpa3hUNmRKeVF2ZnUKU0lzelY4cDRwU3A1K1liaTg0dGFOUm1mOW1vdTJVcFNmREty'
    b'cU1wc1huQjNUTlhpL0E2TDErdFA0RVNtQUpFNllqVGZFRXZHUmxxNwpBNFd6Sks1Yk4yMmpw'
    b'YWtZRzZhcGN3TUtxWXhkWGVYTFZQSGdSbitsMFNFZ2JnOVpyQ0p3R0xXRzhpOUdhLzFVL295'
    b'MXd2QWYzLzJSCnVXSWVCRUV3RE04MXFWVksyT3NhaWt5MGR2VkZnc2s1bDJJMXpyZ080N0J5'
    b'RGVHWkloSjBHblZRc2ZZcjZiS1VZWmZzMnlzak1CUzUKZkNWYm0ybjEzY3hqQk95K1JneEo0'
    b'QWYzYjNqcEp5ZW93TEJCbDUxbHpDWklSY3VGb0FnaHJJRE14bTF6alNPSnNMSnUxUWpMSWFl'
    b'Nwo1RVd6VXVraWVzTXI2ZE5VQ3AxZGx2OXNGZUdmeG1BMno4MFdaZkVoanJ0L2VSbzErYzR2'
    b'MW0vN3ZxT3Y3K3BZdUVDSk9EUGxBZ1NWCjB5bHNDaTI3NDNId3NaaWxKK2VZaFRyZjd3SmZX'
    b'QjRNZ1VwOVUzS0hUM1pxYkFPQjBEZHMzUTlzTHViUDBoNTg4d2YrTUlRUkJvYXMKb2RDVkNB'
    b'emI3SjFTaU9rS2ZNdERTUUlCbVJ3bjBtcHJhU1FheDNGUEpIWFNHZ3pEWlNsQnFtVTZoMTJU'
    b'bHk5ZkZvUUgxTUtQbWZOKwp1bWNmZ2tvZ0NFWlJuS0VtN002SlRMNDNLWkJSdE96MGpYQ1E0'
    b'akFzamJydDZWSm1mbS90bk9lZlRBazhmT3BDN3FEdzNSeUZaOHY4CmhvK2E4UnV1aUZxdHhH'
    b'V1pNSUtvRlhJcXlWUldWZ3FDTUdpMUNvTEF3MG9VazdBeDkzVFF0N0JJK2ZKVHFjTjl6MDRs'
    b'c3hZaUp6ZlcKamlNWWY3eGRldWhVV2dSSStwdzVqQ0l3eENNUUltVjV2RUo3UzVmQmJWK0Qy'
    b'Q2ZWNjJ1bUxWZklmbGZPQUxjK2h4ZzRkT2dRaXFMcgo2cDVCcEZrcTFscFRjbWRCUmFpbFIx'
    b'MDJtNVVyK0FyOXpmR3hXUUtNSjJrTXg2RUVreTdiUzVjQ0tCaEY1RUp1ODFXNHNjZjJ5aHJY'
    b'CmQxWVBFZ1RmYXpWMWV0Y3Ruek5rTk5CamszbCtPSStCTTVmT3pTb3JYc2JpQnBQYU5WdWJX'
    b'Rm94VGlXa1I2M2I4OURSK1dXQnlnSzMKSkQ3MjI1UFg0M0VETmEwNTFldUxValM0MFY4eTdn'
    b'dTkxUmk2KzlydEM1L3V5T0tpNnR2eHpGelppRkxKUUNJc2s5QVpmRUN0Wmp5QgpnaWliVWFm'
    b'N00wWm85YVJQb1VnUkpKY25kUXg3ZFhRVGpxc2pMbitZVGlaUFdtN0JjQnI5VUplT2Y0cTRO'
    b'QlM5UHNiN0tiSHAwaldkCkxJQUljcWZkYUhHRXBpYjcxNVdPZVYzRFpXcGJsQXE5MXpBRXd4'
    b'bytxbk9IK1I3cmNLUEZGdWV4NXF2aHRxdFRhYmdwR0VwN0NLbWsKcmpJZlJ0RHRhNUxITzlH'
    b'L2RRMUxKZmpQdHhRVXpFa2NiSUIwQ3JKallEU1pZaUhBdzZsREVTVFhvTDMzVm9ManE4eW1Y'
    b'RU1HTUFPWQpHUjNkZWoydzhIVlVIUVVZQml6ODMvVTZnR2dBRUExRUE0Qm9JQnFJQmdEUlFE'
    b'UUFpQWFpZ1dnQUVBMUVBNEJvSUJxSUJnRFJRRFFBCmlBYWkvMGY1SjROckRMSGhtRklvQUFB'
    b'QUpYUkZXSFJrWVhSbE9tTnlaV0YwWlFBeU1ESXpMVEE0TFRBelZESXhPakkzT2pFd0t6QXcK'
    b'T2pBd1gyL2R5d0FBQUNWMFJWaDBaR0YwWlRwdGIyUnBabmtBTWpBeU15MHdPQzB3TTFReU1U'
    b'b3lOem94TUNzd01Eb3dNQzR5WlhjQQpBQUFBU1VWT1JLNUNZSUk9CiIgaWQ9ImltYWdlMTE5'
    b'NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_KRS')

RU_KRS = b64_RU_KRS
index.append("RU_KRS")
index.append("Russia Kurskaya oblast")
catalog["RU_KRS"] = RU_KRS
catalog["Russia Kurskaya oblast"] = RU_KRS
country["Russia Kurskaya oblast"] = ('RU_KRS', '', 1)
lookup["RU_KRS"] = ('RU_KRS', '', 'Russia Kurskaya oblast', 1)
lookup["Kursk"] = ('RU_KRS', '', 'Russia Kurskaya oblast', 1)
lookup["Russia Kurskaya oblast"] = ('RU_KRS', '', 'Russia Kurskaya oblast', 1)
details["RU_KRS"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Kursk"}
regional["RU_KRS"] = ('RU_KRS', 'Russia Kurskaya oblast', 1)
regional["Russia Kurskaya oblast"] = ('RU_KRS', 'Russia Kurskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_KYA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxMTcyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X0tyYXNub3lhcnNrX0tyYWkuc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cu'
    b'aW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRw'
    b'Oi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6'
    b'eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3'
    b'LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2'
    b'ZyI+CiAgPGRlZnMgaWQ9ImRlZnMxMTc2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9'
    b'Im5hbWVkdmlldzExNzQiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiIGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2Nh'
    b'cGU6cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4K'
    b'ICA8ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2Ui'
    b'IGlkPSJnMTE3OCI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1'
    b'YWxpdHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FB'
    b'QUFOU1VoRVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFB'
    b'QUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0Nj'
    b'dWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQUoKRUVsRVFWUjQydTNjZTNCVTFSM0E4'
    b'ZCs1cjkxNzkvM0labmZ6SU5rUU00RThDQlZGQktsQVFTMktyOXFxZzZob2E0ZEJoMnExbFFF'
    b'YwpPM1k2VHJHK21EcVdRaW9pb2gyUWprRUxTS0d5MUJEUUdCTElBL0xZWk1QdUpwdDk3OTY5'
    b'cjlNL3dpaWRNVm83N2N3eVBkOS85OTZaCnU1ODljKzZlczNjVzVSMElTUC83S0VKQW9BazBp'
    b'VUFUYUFKTkl0QUVta1NnQ1RTQkpoRm9BazBpMEFTYVFKTUlOSUVtRVdnQ1RhQkoKQkpwQWs3'
    b'NWR6T1Z5b1NFTTcxYWJoY0VzdnFQRWJtTkhtb2ZTMDAzZjY0ek5BVXhHOUgrdHNBWnYzMVoy'
    b'bEtLZGE2cmUrbHYwcFhkQwozdFdWSnpQNDRDMmxyY3JsTVZEb0RjSmw4S1RTS3pSdDZqRVdJ'
    b'YVpERnV2SGRNc3o1bDFwN1BOZS85ckFIUVpQZXQ3WUNFdEc5SCtXCjM4TDVLWHB5VWxBQWl1'
    b'NHFUZHJWOGdUYlZHWGdHSVFBRmpad3A0SzhWd2tzV0xzMnlla256eHJUQ1BTM1NRRm9uVmNr'
    b'L2FKbVA4dE0KM2taUVoxS3NwcVpuMllseEJXTUFESm1FMklkcVo5bkRodTZ1WWlrM2VWYkxB'
    b'NzVtQjArZy82MG1BTlpYbVoxdVBRS1UxVk1SRFFJYQpYSGM2SGs5SUVnMlJzS1F3T0k5eEpD'
    b'S25XYnRkSFJmZWVIMXlMR3NBNXdMWjBBTG5YaU5INXVodjdqaEZGYStjbHN5cTdYMFpwVVJZ'
    b'CjhmMm5ENHBhUXN5L1czWmx5TkFIQmlRNTBXaUptbEtVR3ZhSVA2ZUVjbWk3cWVpbkwrejZZ'
    b'TGp6a2NVNmhPQ01sVk9IY3o2MXNPYVIKZ3Z0NmQ3TEpOdGZJQk1MNThtTGR6RXFoL1BDeElh'
    b'dnp4YnNmQm9xYTI5NWxFdWd2anN5STZoN3ZnejBhelJ6KzBOemJkWE5WNG53UQplWjNjZVVv'
    b'OFVheGZIRWlUcWVOclAza1pueG5NTWpTU0ZNM2ZGbnYvYU10VDNTZU53YUU1MjlaZnFnd0FC'
    b'ajA5LzlBcmhsajAyYk1uCitqZXZZK081YkY1TlpCUTlSeVdGZ2h0QXFOQWVSRzllWHJMb0J2'
    b'ZGYvTkhCdm5SRlRwRlBVTmVvVmdEWXVYQlZDN2ZpanZ5ZW10UGIKWnNZNE05Q1hqcFJSa0pL'
    b'bXdJNXFzOWVscnlubko4Yno2dzlkWU1qVU1WVWRDdVJ0M0tHVGNZK0RZNUZKVkRWRGoxSWY0'
    b'd0ZBNDYxQgpmVms0MVhYblJwdnc4MXlGK2k5M1BCSGp3QU8raFRrbFBDRUR3Tkw1anJiRDRX'
    b'czBqVXdkVTB6UU41Y1VXZG1Sc1h3eW8zSTZTaHJKCkNUSHB5MnROZHVxRTNyZmVETGN1Vlhi'
    b'ZGxINnZQUDNsNmh0Qi9YUkJWbkJHVkMxR09wMVQ5V3BoTGMwTEM3cnBRQ2dheURrclBjTmoK'
    b'VWs4Z1p5MFRwQ0xkNUV1SjlEK2VkdDhMK1VXMlVzYmN3QnBtY0dmcVplbVNqWTRYM2g3MWVm'
    b'VldJM00rS0I3ZEhaeUZDUFRVMVNqcQowS0g4dXFibjMwdjdTbDJjbzRpVFpBd0FJYVFtc3ll'
    b'TlBHMjJIYXY1a0ZGVmpCQUljZlNicFJOUHpvaE1uaHRQSzdzL0dxLzNHYlpyCmN4MWp1a0xi'
    b'V0NnczZIZHFMTFB2dDVwUEhlbDY3TlU5Zlh4bmY5Ykkwd0RReDRrMHZlU0Q0S0tIYmxIaFVW'
    b'MXdYT0oxbEp4UitWNjgKT0NwY1hCSFFvT2VveldlTHd5dWY4QmNiaGpVQ1BYV3BsRHdReXIr'
    b'czJ3TUEvcWQyaGxqSGVGZ0VBSkhERGxNdlZuS2JkMDJjQytZawpHVnVOVE1vQTgwYjRaV0Vq'
    b'QUdBTUxpdDNvUFNHVHpmdUJsbWFjeVg5NFJ3SGdaNzZhaEJLNTlRai92RHlIV3ZCVWJUdHVr'
    b'MW1EUUJnClljcWc0K0lzeTJETlZPblJwM1Bxc1k2azZUek8ycjQ4dDZYNkJ4UHJYNEsrczB1'
    b'MnJCWW9WUjNPRXVncGsyeWNqa01WSHQweVErREcKN1d0cVR1MExzbm9BQ0dBcGtSNEdUZHk0'
    b'V3RmYW1aNVhaOTc0UUprM3ozUlBrNzg0TjR2MDdwZC9XYi9wUjdQczJmNVJVVWlwQkhySwo3'
    b'dXFPR3pHTVJLVGdlUDQrYS9lNzMra29nandBTUlCY05tYk50VDBiZm05ZmY4RFc4WDVTbERU'
    b'K3V6cE5CeW00T0JsdjF1MWJuZHovCjFLMDJqNE96Y0ZTRFJLQ25UbER3aThscmQ5UTlFcytv'
    b'L3ROSi8rY0pvNklCUUFYaU11TFBiaisrMjJ5VTJ6ZmdPYmRiWWlsbDNuSkwKOVZWQ0JNdVRi'
    b'd09QaTI0N2w4Z29lNlVabi9RNFo2a0Vlb29VZ05lV2VlOTFkelhRbzF2bmI4em5xR2wvN0Rk'
    b'K3NZU2x1VnJ0dmMyUAo1V3Q4UWlLdEtpcnU3TXlpblZJVnV2aEZlMWJMaFdnT3JUTTlkR3pW'
    b'YjgwMHRSL1JCUHFyb3dIY1BGV2h6OTZkUE9oSkRtKzdiMnUvCjAzUHBBUzU5K0ZoSDh0Q1Q0'
    b'Y0htVkNhblJVYnpzVWI0bU05TXZ0ckcyNSs1L2xXamlXdHVXYUhYRFgyMnlFV2dwOWpmQXBE'
    b'L1BzN3IKcUxHNFhCYzdyYzYrZXMyV3ZTTTBDd0REV0U1bHRpd3Y5L2NNc2ZlTVdlOFBXVnVP'
    b'Ukhrdlk2eGxnOVVZQUZUQWp6LzNCNWg5VmRQQQowYW9TdmE5S1NPVTBBajFsK3ZuT3ZLeEpN'
    b'bmIydEpZK3Z4WmM3amFYQ3dCWVFOVmxPU3VmTzlVeEh3QjRvTzU2VStqc3l5Z1VOa1l3CkFJ'
    b'U1JobGx1K3ArZWxZZUhEN1RGdkE0ZElqZkRyMm1vTDgweWlLWlFoTEZzc0xWV1A3TXlqd085'
    b'V0hRanBuLzB4dzkzN3JHYnlpYVAKdEFDOXBFVmYvenUwUEdRQ2dEWThZWHQ1MDA5aSsxYVV4'
    b'MDBDUGFPU3AzaTZvSVowWWUxSGIyMjBsUzl6RDRUa3JyeXRRUi9OeTFwVAp0Zkg0cjdxVHhZ'
    b'NFlYYXRFZFQ1Mm9pbzRXSXV0bjFQajQwanlVRWpCY0x5Q243UEMwaldRVlRYTU1zaHBZVk5a'
    b'dGFjdnZiVW56aU1DCi9WVjFVdFQrMmZhS3Eyd1pHWTFsa0VkUXp3Vnppb0lOUEgxd1VIZjgw'
    b'ZGNCZ09zOW80dEcwOU92d0VaVDlmcEg2a3F6dHkxMGhDYWsKZXA5QjFmRGVjNGFicmxDR0F3'
    b'bGwvNFcxTWJGdzNscGhiZnhmb1dudGRXYVhsWHVwMi9XeDkvcGZKNW9qTWJuWDFYaXNiREZr'
    b'dWlBdwpDSXR1a0dZMlh0eWk3bXp2VzN6clFDYTVyM1NwSmQxMlQrdWY5eG11SGJubkNmekdx'
    b'anNiZVU5VUxLaDVzYkNnT1lBTDdmSCtNY2xDCjg1TEREUWx3VjNtYUZ6d09aN3ZBWklhQnZp'
    b'V1BQeGNYbkFhSHFSYkNKektPVCtldFVvYjY0WnFGc1VVM2J2OW9GcFdZZ0pHQW04MUYKWW14'
    b'amdlMlRGdHh2aGtNYUhGbFoyVGtxaW1iSHgxR3JaQ3VlTnQ0em5Za2U1aGZmcHZ2RXdrcGxM'
    b'bDJ2UDJxdk0yT2Vid203UmtXdQpnUTUxcVM1c3NldEJtalp3WXQydGpyL3VIdGwwSms2Z3Y2'
    b'NXVpdnJrOXRKNFZuV1c4S3FHOHhMbVdCVHB6NVIrRmpNL1dDa3BXanFsCnpOemF2MytacDlK'
    b'bkdJdkpmTXNGOW9lbEZFSjVXYk1ZbU5QOW1RYWZVTHZsWENORFJ2UTNGY1JRakdCcnRka1ps'
    b'VGhSOWFibGVnUlIKQ3JVTGJKeWxtcUppTFEwbjlZeC9tbUZ1ZC9KcWhEYzZlYUhPb3FnWW1S'
    b'angwL2pTVUc0QkZOeFRlSWo4NzkzLzQ0S0ZRSk1JTklFbQpFV2dDVGFCSkJKcEFrd2cwZ1Ni'
    b'UUpBSk5vRWtFbWtBVGFCS0JKdEFrQWsyZ0NUU0pRRjhHL1JPQzBmZURIQnprWndBQUFDVjBS'
    b'VmgwClpHRjBaVHBqY21WaGRHVUFNakF5TXkwd09DMHlNVlF5TVRveE16b3dNU3N3TURvd01Q'
    b'WW5wVDRBQUFBbGRFVllkR1JoZEdVNmJXOWsKYVdaNUFESXdNak10TURndE1qRlVNakU2TVRN'
    b'Nk1ERXJNREE2TURDSGVoMkNBQUFBQUVsRlRrU3VRbUNDCiIgaWQ9ImltYWdlMTE4MCIgLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'RU_KYA')

RU_KYA = b64_RU_KYA
index.append("RU_KYA")
index.append("Russia Krasnoyarskiy kray")
catalog["RU_KYA"] = RU_KYA
catalog["Russia Krasnoyarskiy kray"] = RU_KYA
country["Russia Krasnoyarskiy kray"] = ('RU_KYA', '', 1)
lookup["RU_KYA"] = ('RU_KYA', '', 'Russia Krasnoyarskiy kray', 1)
lookup["Krasnoyarsk"] = ('RU_KYA', '', 'Russia Krasnoyarskiy kray', 1)
lookup["Russia Krasnoyarskiy kray"] = ('RU_KYA', '', 'Russia Krasnoyarskiy kray', 1)
details["RU_KYA"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+07:00","altname":"Krasnoyarsk"}
regional["RU_KYA"] = ('RU_KYA', 'Russia Krasnoyarskiy kray', 1)
regional["Russia Krasnoyarskiy kray"] = ('RU_KYA', 'Russia Krasnoyarskiy kray', 1)
#----------------------------------------------------------------------
b64_RU_LEN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI5MDAiIGhl'
    b'aWdodD0iNjAwIiB2aWV3Qm94PSIwIDAgOTAwIDYwMCI+PHN0eWxlIHR5cGU9InRleHQvY3Nz'
    b'Ij4gIC5zdDB7ZmlsbDojRkZGRkZGO30gLnN0MXtmaWxsOiMxNTdkYzE7fSAuc3Qye2ZpbGw6'
    b'I2U0MjkxMzt9IC5zdDN7ZmlsbDojMTU3ZGMxO30gLnN0NHtmaWxsOiNGRkZGRkY7c3Ryb2tl'
    b'OiMwMDAwMDA7c3Ryb2tlLXdpZHRoOjEuMTQ7fSAuc3Q1e2ZpbGw6bm9uZTtzdHJva2U6IzAw'
    b'MDAwMDtzdHJva2Utd2lkdGg6Mjt9IC5zdDZ7ZmlsbDpub25lO3N0cm9rZTojMDAwMDAwO3N0'
    b'cm9rZS13aWR0aDoxLjE0O30gLnN0N3tmaWxsOiNlYTliMDA7c3Ryb2tlOiMwMDAwMDA7c3Ry'
    b'b2tlLXdpZHRoOjEuMTQ7fTwvc3R5bGU+PHRpdGxlPiAgRmxhZ19vZl9MZW5pbmdyYWRfT2Js'
    b'YXN0PC90aXRsZT48cmVjdCBjbGFzcz0ic3QwIiB5PSIwLjMiIHdpZHRoPSI5MDAiIGhlaWdo'
    b'dD0iNjAwIi8+PHBhdGggY2xhc3M9InN0MSIgZD0ibTkwIDUxNy41YzMzIDAgNjQuNS0xMy4x'
    b'IDg2LjQtMzZsMy42LTMuOCAzLjYgMy44YzIxLjkgMjIuOSA1My4zIDM2IDg2LjQgMzYgMzMg'
    b'MCA2NC41LTEzLjEgODYuNC0zNmwzLjYtMy44IDMuNiAzLjhjMjEuOSAyMi45IDUzLjMgMzYg'
    b'ODYuNCAzNnM2NC41LTEzLjEgODYuNC0zNmwzLjYtMy44IDMuNiAzLjhjMjEuOSAyMi45IDUz'
    b'LjMgMzYgODYuNCAzNiAzMyAwIDY0LjUtMTMuMSA4Ni40LTM2bDMuNi0zLjggMy42IDMuOGMy'
    b'MS45IDIyLjkgNTMuMyAzNiA4Ni40IDM2czY0LjUtMTMuMSA4Ni40LTM2bDMuNi0zLjh2LTc3'
    b'LjhjLTIyIDIzLjEtNTQuMiAzNy42LTkwIDM3LjZzLTY4LTE0LjUtOTAtMzcuNmMtMjIgMjMu'
    b'MS01NC4yIDM3LjYtOTAgMzcuNnMtNjgtMTQuNS05MC0zNy42Yy0yMiAyMy4xLTU0LjIgMzcu'
    b'Ni05MCAzNy42cy02OC0xNC41LTkwLTM3LjZjLTIyIDIzLjEtNTQuMiAzNy42LTkwIDM3LjZz'
    b'LTY4LTE0LjUtOTAtMzcuNmMtMjIgMjMuMS01NC4yIDM3LjYtOTAgMzcuNnMtNjgtMTQuNS05'
    b'MC0zNy42djc3LjhsMy42IDMuOGMyMS44IDIyLjkgNTMuMyAzNiA4Ni40IDM2eiIvPjxwYXRo'
    b'IGNsYXNzPSJzdDIiIGQ9Im05MDAgNDkyYy0yMy41IDIyLjYtNTYgMzUuNS05MCAzNS41cy02'
    b'Ni41LTEyLjktOTAtMzUuNWMtMjMuNSAyMi42LTU2IDM1LjUtOTAgMzUuNXMtNjYuNS0xMi45'
    b'LTkwLTM1LjVjLTIzLjUgMjIuNi01NiAzNS41LTkwIDM1LjVzLTY2LjUtMTIuOS05MC0zNS41'
    b'Yy0yMy41IDIyLjYtNTYgMzUuNS05MCAzNS41cy02Ni41LTEyLjktOTAtMzUuNWMtMjMuNSAy'
    b'Mi42LTU2IDM1LjUtOTAgMzUuNXMtNjYuNS0xMi45LTkwLTM1LjV2MTA4aDkwMHYtMTA4eiIv'
    b'PjxwYXRoIGNsYXNzPSJzdDMiIGQ9Ik01NTAgOTguNVYyNzFjMCAyMS0xNC4xIDM2LjQtMzMu'
    b'NSAzNi40aC00My43Yy0xNC4zIDAtMjEuNSAxMS0yMi45IDE5LjggLTEuMy04LjgtOC42LTE5'
    b'LjgtMjIuOS0xOS44aC00My42Yy0xOS40IDAtMzMuNS0xNS4zLTMzLjUtMzYuNFY5OC41SDU1'
    b'MHoiLz48cG9seWdvbiBjbGFzcz0ic3QyIiBwb2ludHM9IjU1MCAxNDAgMzUwIDE0MCAzNTAg'
    b'OTguNSA1NTAgOTguNSIvPjxwb2x5Z29uIGNsYXNzPSJzdDQiIHBvaW50cz0iNDE2LjcgMTUy'
    b'LjUgMzgzLjQgMTUyLjUgMzgzLjQgMTQwIDQxNi43IDE0MCIvPjxwb2x5Z29uIGNsYXNzPSJz'
    b'dDQiIHBvaW50cz0iNDUwIDE1Mi41IDQxNi43IDE1Mi41IDQxNi43IDE0MCA0NTAgMTQwIi8+'
    b'PHBvbHlnb24gY2xhc3M9InN0NCIgcG9pbnRzPSI0ODMuNCAxNTIuNSA0NTAgMTUyLjUgNDUw'
    b'IDE0MCA0ODMuNCAxNDAiLz48cG9seWdvbiBjbGFzcz0ic3Q0IiBwb2ludHM9IjUxNi43IDE1'
    b'Mi41IDQ4My40IDE1Mi41IDQ4My40IDE0MCA1MTYuNyAxNDAiLz48cG9seWdvbiBjbGFzcz0i'
    b'c3Q0IiBwb2ludHM9IjU1MCAxNTIuNSA1MTYuNyAxNTIuNSA1MTYuNyAxNDAgNTUwIDE0MCIv'
    b'Pjxwb2x5Z29uIGNsYXNzPSJzdDQiIHBvaW50cz0iMzgzLjQgMTUyLjUgMzUwIDE1Mi41IDM1'
    b'MCAxNDAgMzgzLjQgMTQwIi8+PHBvbHlnb24gY2xhc3M9InN0NCIgcG9pbnRzPSI0MzMuNCAx'
    b'NDAgNDAwIDE0MCA0MDAgMTI3LjQgNDMzLjQgMTI3LjQiLz48cG9seWdvbiBjbGFzcz0ic3Q0'
    b'IiBwb2ludHM9IjQ2Ni43IDE0MCA0MzMuNCAxNDAgNDMzLjQgMTI3LjQgNDY2LjcgMTI3LjQi'
    b'Lz48cG9seWdvbiBjbGFzcz0ic3Q0IiBwb2ludHM9IjUwMCAxNDAgNDY2LjcgMTQwIDQ2Ni43'
    b'IDEyNy40IDUwMCAxMjcuNCIvPjxwb2x5Z29uIGNsYXNzPSJzdDQiIHBvaW50cz0iNTMzLjMg'
    b'MTQwIDUwMCAxNDAgNTAwIDEyNy40IDUzMy4zIDEyNy40Ii8+PHBvbHlnb24gY2xhc3M9InN0'
    b'NCIgcG9pbnRzPSI1NTAgMTQwIDUzMy4zIDE0MCA1MzMuMyAxMjcuNCA1NTAgMTI3LjQiLz48'
    b'cG9seWdvbiBjbGFzcz0ic3Q0IiBwb2ludHM9IjM2Ni43IDE0MCAzNTAgMTQwIDM1MCAxMjcu'
    b'NCAzNjYuNyAxMjcuNCIvPjxwb2x5Z29uIGNsYXNzPSJzdDQiIHBvaW50cz0iMzc1IDEyNy40'
    b'IDM1OC40IDEyNy40IDM1OC40IDExNC45IDM3NSAxMTQuOSIvPjxwb2x5Z29uIGNsYXNzPSJz'
    b'dDQiIHBvaW50cz0iNDAwIDE0MCAzNjYuNyAxNDAgMzY2LjcgMTI3LjQgNDAwIDEyNy40Ii8+'
    b'PHBvbHlnb24gY2xhc3M9InN0NCIgcG9pbnRzPSI0MDguNCAxMjcuNCAzOTEuNyAxMjcuNCAz'
    b'OTEuNyAxMTQuOSA0MDguNCAxMTQuOSIvPjxwb2x5Z29uIGNsYXNzPSJzdDQiIHBvaW50cz0i'
    b'NDQxLjcgMTI3LjQgNDI1IDEyNy40IDQyNSAxMTQuOSA0NDEuNyAxMTQuOSIvPjxwb2x5Z29u'
    b'IGNsYXNzPSJzdDQiIHBvaW50cz0iNDc1IDEyNy40IDQ1OC40IDEyNy40IDQ1OC40IDExNC45'
    b'IDQ3NSAxMTQuOSIvPjxwb2x5Z29uIGNsYXNzPSJzdDQiIHBvaW50cz0iNTA4LjQgMTI3LjQg'
    b'NDkxLjcgMTI3LjQgNDkxLjcgMTE0LjkgNTA4LjQgMTE0LjkiLz48cG9seWdvbiBjbGFzcz0i'
    b'c3Q0IiBwb2ludHM9IjU0MS43IDEyNy40IDUyNSAxMjcuNCA1MjUgMTE0LjkgNTQxLjcgMTE0'
    b'LjkiLz48cGF0aCBjbGFzcz0ic3Q1IiBkPSJNNTUwIDk4LjVWMjcxYzAgMjEtMTQuMSAzNi40'
    b'LTMzLjUgMzYuNGgtNDMuN2MtMTQuMyAwLTIxLjUgMTEtMjIuOSAxOS44IC0xLjMtOC44LTgu'
    b'Ni0xOS44LTIyLjktMTkuOGgtNDMuNmMtMTkuNCAwLTMzLjUtMTUuMy0zMy41LTM2LjRWOTgu'
    b'NUg1NTB6Ii8+PHBhdGggY2xhc3M9InN0NCIgZD0ibTM3NS4zIDE3MC42YzMuNy00LjcgMTAu'
    b'NS01LjYgMTUuMi0xLjlzNS42IDEwLjUgMS45IDE1LjItMTAuNSA1LjYtMTUuMiAxLjktNS42'
    b'LTEwLjUtMS45LTE1LjJ6bS0yLjQgMjAuNmM3LjcgNiAxOC44IDQuNyAyNC44LTNzNC43LTE4'
    b'LjgtMy0yNC44LTE4LjgtNC43LTI0LjggMy00LjcgMTguOCAzIDI0Ljh6Ii8+PHBhdGggY2xh'
    b'c3M9InN0NCIgZD0ibTQ3NS4zIDI5Ny4yYy0xLjUtMS4xLTIuNS0yLjctMi44LTQuNiA0LjEg'
    b'MC4zIDkgMi4zIDE3LjMgMS43IDExLTAuOSAxMy4yLTQuNCAxOC44LTguNSA0LTIuOSA4LjIt'
    b'Mi44IDEyLTEuNy0yLjQtMy41LTIuOS04LTEuMy0xMiAyLjYtNi41IDUuNS05LjQgMy42LTIw'
    b'LjMtMS40LTguMi00LjYtMTIuNS01LjgtMTYuNCAxLjgtMC4yIDMuNyAwLjQgNS4xIDEuNi0w'
    b'LjctMi4xLTYuNi0xMC43LTExLjUtMTMuOSAxLjQgMy41LTAuOCAxNC4zIDAuNCAxNy41IDEu'
    b'NS0yIDIuNS0zLjggMy44LTQuMyAwLjcgMS43IDQuNiAxNC40IDAuOCAyMC40LTMuOSA2LjIt'
    b'MTEuMSA3LTE5LjMgMS42LTYuMy00LjItNzcuMi01Ni42LTkxLjEtNjcuMyAyLjUtNC45IDEu'
    b'MS0xMS0zLjMtMTQuMy01LjEtMy45LTEyLjQtMi44LTE2LjMgMi4zLTMuOCA1LTIuOSAxMi4x'
    b'IDIgMTYgNC4zIDMuNSAxMC41IDMuNCAxNC43LTAuMiAxMy44IDEwLjkgODEuNyA2NyA4Ny4z'
    b'IDcyLjIgNy4zIDYuNyA4LjIgMTMuOCAzLjEgMTkuMXMtMTguMiA0LjUtMjAgNC4xYzAuMS0x'
    b'LjQgMS42LTIuOCAzLjItNC43LTMuNC0wLjQtMTMuNCA0LjMtMTcgMy44IDQuMiA0IDE0IDcu'
    b'NiAxNi4zIDcuOXptLTc0LjctMTA2LjljLTIuMyAzLjItNi44IDQtMTAgMS43cy00LTYuOC0x'
    b'LjctMTAgNi44LTQgMTAtMS43bDAuNCAwLjRjMi45IDIuNCAzLjQgNi42IDEuMyA5LjZ6Ii8+'
    b'PHBhdGggY2xhc3M9InN0NCIgZD0ibTM4My41IDE4OGMtNi0wLjItMTAuNi01LjItMTAuNC0x'
    b'MS4xIDAuMi02IDUuMi0xMC42IDExLjEtMTAuNCA2IDAuMiAxMC42IDUuMiAxMC40IDExLjEt'
    b'MC4xIDIuMy0wLjkgNC41LTIuMyA2LjMtMS4yIDEuNS0yLjggMi43LTQuNiAzLjQgMC4zIDEu'
    b'NyAxLjMgMy4yIDIuNyA0LjMgMC42IDAuNSAxLjMgMC45IDIgMS4xIDIuMS0xLjEgMy45LTIu'
    b'NiA1LjMtNC41IDYtNy43IDQuNy0xOC44LTMtMjQuOHMtMTguOC00LjctMjQuOCAzLTQuNyAx'
    b'OC44IDMgMjQuOGM0IDMuMiA5LjMgNC40IDE0LjMgMy40LTEuOS0xLjctMy4yLTQtMy43LTYu'
    b'NnoiLz48cGF0aCBjbGFzcz0ic3Q0IiBkPSJtNDIyLjQgMjA4Yy04LjkgMTAtMjYuMiAyMi4x'
    b'LTI2LjIgMjIuMWwtMy44LTUuNCA0My40LTQ4LjQgNS43IDMuMWMwLjEgMC4xLTEwLjEgMTgu'
    b'Ni0xOS4xIDI4LjZ6Ii8+PGxpbmUgY2xhc3M9InN0NiIgeDE9IjQzMS4yIiB4Mj0iNDM4LjMi'
    b'IHkxPSIxODEuNSIgeTI9IjE4NS4zIi8+PGxpbmUgY2xhc3M9InN0NiIgeDE9IjQyOS41IiB4'
    b'Mj0iNDM2LjkiIHkxPSIxODMuNCIgeTI9IjE4Ny40Ii8+PGxpbmUgY2xhc3M9InN0NiIgeDE9'
    b'IjQyNy44IiB4Mj0iNDM1LjYiIHkxPSIxODUuMyIgeTI9IjE4OS42Ii8+PGxpbmUgY2xhc3M9'
    b'InN0NiIgeDE9IjM5NyIgeDI9IjQwMS41IiB5MT0iMjE5LjciIHkyPSIyMjYuMyIvPjxsaW5l'
    b'IGNsYXNzPSJzdDYiIHgxPSIzOTguNyIgeDI9IjQwMy41IiB5MT0iMjE3LjgiIHkyPSIyMjQu'
    b'NyIvPjxsaW5lIGNsYXNzPSJzdDYiIHgxPSI0MDAuNSIgeDI9IjQwNS42IiB5MT0iMjE1Ljki'
    b'IHkyPSIyMjMuMiIvPjxwYXRoIGNsYXNzPSJzdDciIGQ9Im0zODMuNCAyODQuNSAyLjgtMi4z'
    b'LTItMi41LTIuOCAyLjJjLTIuMy0xLjQtNS4yLTAuNy02LjYgMS42cy0wLjcgNS4yIDEuNiA2'
    b'LjYgNS4yIDAuNyA2LjYtMS42YzAuNi0xLjIgMC44LTIuNyAwLjQtNHoiLz48cGF0aCBjbGFz'
    b'cz0ic3Q3IiBkPSJtNTI2LjQgMTk2LjZjLTAuNy0yLjEtMS45LTQuMS0zLjQtNS43IDEuNy0w'
    b'LjUgMy4yLTEuNCA0LjYtMi41IDYuNi01LjIgNy43LTE0LjcgMi41LTIxLjNzLTE0LjctNy43'
    b'LTIxLjMtMi41Yy0xLjMgMS4xLTIuNSAyLjQtMy40IDMuOS0xLjItMS45LTIuOC0zLjQtNC43'
    b'LTQuNi03LjEtNC41LTE2LjQtMi40LTIwLjkgNC43cy0yLjQgMTYuNCA0LjcgMjAuOWMyLjYg'
    b'MS43IDUuNyAyLjUgOC44IDIuNGwtMi44IDIuMi00IDAuNy0wLjEgMi41LTEuNSAxLjJjLTEt'
    b'MC42LTIuMi0wLjYtMy4yLTAuMS0wLjggMC44LTEgMi0wLjYgM2wtOTkgNzcuNyA0LjIgNS40'
    b'IDk5LjEtNzcuN2MxLjIgMC42IDIuNCAwLjcgMy4xIDAuMSAwLjgtMC44IDEuMS0yIDAuNi0z'
    b'bDEuNi0xLjIgMi41IDAuNSAxLjctMy44IDIuNy0yLjFjLTIuMiA4LjEgMi41IDE2LjQgMTAu'
    b'NSAxOC43IDguMSAyLjIgMTYuNC0yLjUgMTguNi0xMC41IDAuNy0zIDAuNy02LjEtMC4zLTgu'
    b'OXptLTExLjEgMTQuNmMtNS41IDEuOC0xMS4zLTEuMi0xMy4xLTYuNi0wLjktMi42LTAuNy01'
    b'LjUgMC42LTcuOWwwLjYtMS4yLTIuNC0zLjIgMy40LTIuN2MyLjMgMS42IDUuNCAxIDYuOS0x'
    b'LjMgMS4zLTEuOSAxLjEtNC40LTAuMy02LjEtMS43LTIuMi00LjktMi42LTcuMS0wLjktMS42'
    b'IDEuMy0yLjMgMy41LTEuNyA1LjVsLTMuNCAyLjctMi41LTMuMWMtMC40IDAuMS0wLjkgMC4z'
    b'LTEuNCAwLjQtMi43IDAuNi01LjUgMC4xLTcuOC0xLjRzLTQtMy44LTQuNi02LjVjLTEuNS01'
    b'LjYgMS44LTExLjMgNy4zLTEyLjggNS42LTEuNSAxMS4zIDEuOCAxMi44IDcuMyAwIDAuMSAw'
    b'LjEgMC4zIDAuMSAwLjRzMC4xIDAuMyAwLjEgMC40YzAuMiAwLjcgMC4zIDEuNCAwLjMgMi4x'
    b'bDQuNy0wLjFjMC4xLTUuOCA0LjktMTAuMyAxMC42LTEwLjJzMTAuMyA0LjkgMTAuMiAxMC42'
    b'Yy0wLjEgNS44LTQuOSAxMC4zLTEwLjYgMTAuMi0wLjcgMC0xLjQtMC4xLTIuMS0wLjNsLTEu'
    b'MiA0LjZjMC43IDAuMiAxLjMgMC40IDIgMC43IDUuMiAyLjYgNy4zIDguOCA0LjcgMTQtMS4y'
    b'IDIuOC0zLjQgNC43LTYuMSA1LjR6Ii8+PHBvbHlnb24gY2xhc3M9InN0NyIgcG9pbnRzPSIz'
    b'ODQuNiAyNzAuOCAzODcuNiAyNzQuNyAzOTUgMjY4LjkgMzkyIDI2NSIvPjxwb2x5Z29uIGNs'
    b'YXNzPSJzdDciIHBvaW50cz0iMzk3LjggMjU5LjEgMzk1IDI1OC44IDM5NC43IDI1NS4xIDM4'
    b'OS4xIDI0OCAzODUgMjUxLjIgMzkwLjIgMjU4IDM4Ni4zIDI2MS4xIDM4MSAyNTQuMyAzNzYu'
    b'OCAyNTcuNSAzODIuMSAyNjQuNCAzNzguMSAyNjcuNCAzNzIuOCAyNjAuNyAzNjguNyAyNjMu'
    b'OSAzNzQuNCAyNzEuMSAzNzcuOCAyNzIuMyAzNzcuNSAyNzUgMzc4LjUgMjc1LjYgMzk4LjEg'
    b'MjYwLjIiLz48L3N2Zz4=', 'RU_LEN')

RU_LEN = b64_RU_LEN
index.append("RU_LEN")
index.append("Russia Leningradskaya oblast")
catalog["RU_LEN"] = RU_LEN
catalog["Russia Leningradskaya oblast"] = RU_LEN
country["Russia Leningradskaya oblast"] = ('RU_LEN', '', 1)
lookup["RU_LEN"] = ('RU_LEN', '', 'Russia Leningradskaya oblast', 1)
lookup["Leningrad"] = ('RU_LEN', '', 'Russia Leningradskaya oblast', 1)
lookup["Russia Leningradskaya oblast"] = ('RU_LEN', '', 'Russia Leningradskaya oblast', 1)
details["RU_LEN"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Leningrad"}
regional["RU_LEN"] = ('RU_LEN', 'Russia Leningradskaya oblast', 1)
regional["Russia Leningradskaya oblast"] = ('RU_LEN', 'Russia Leningradskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_LIP = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZlcnNpb249IjEuMSIg'
    b'eD0iMCIgeT0iMCIgd2lkdGg9IjYwMCIgaGVpZ2h0PSI0MDAiIHZpZXdCb3g9IjAgMCA2MDAg'
    b'NDAwIiB4bWw6c3BhY2U9InByZXNlcnZlIj48dGl0bGU+RmxhZyBvZiBMaXBldHNrIE9ibGFz'
    b'dDwvdGl0bGU+PHBhdGggZmlsbD0iI0QyMDAwMCIgZD0iTTAgMGg2MDEuNXY0MDAuNzVIMFYw'
    b'eiIvPjxwYXRoIGZpbGw9IiMwMDhFMUYiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjUiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0i'
    b'TTYwMS41IDQwMC43NWMtMjcuNTY4LTU0LjYwMi05OS4zNDctOTMuNDc1LTE4My40NTgtOTMu'
    b'NDc1LTg0LjEwOCAwLTE1NS43ODggMzguODczLTE4My4zNTUgOTMuNDc1Ii8+PHBhdGggZmls'
    b'bD0iIzAwOEUxRiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgc3Ryb2tlLWxp'
    b'bmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNMzY2LjgxNCA0MDAu'
    b'NzVjLTI3LjU2Ni01NC42MDItOTkuMjQ2LTkzLjQ3NS0xODMuMzU3LTkzLjQ3NS04NC4xMDkg'
    b'MC0xNTUuODg4IDM4Ljg3My0xODMuNDU3IDkzLjQ3NSIvPjxwYXRoIGQ9Ik00ODcuMjIgMzk0'
    b'Ljc1Yy0xMS42MDYtMzAuOTEyLTM1LjAwNC01MS42MjktNjkuMDM1LTcwLjM5LTMyLjctMTgu'
    b'MDI3LTczLjM3LTI4LjcwOC0xMTcuNDM1LTI4LjcwOC04OS45MjUgMC0xNjUuNzEzIDQ0LjQ4'
    b'My0xODguNDcgMTA1LjA5OCIgZmlsbD0iIzAwOGUxZiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'd2lkdGg9IjEuNSIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJv'
    b'dW5kIi8+PHBhdGggZmlsbD0iIzAwOEUxRiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'IjEuNSIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBk'
    b'PSJNMzY5LjYyMyA0MDAuNzVjLTM1LjU5LTM1LjQ2Ny05Mi44MzItNTguNDA5LTE1Ny41OTQt'
    b'NTguNDA5LTY0Ljc2MSAwLTEyMS45MDMgMjIuOTQyLTE1Ny40OTIgNTguNDA5Ii8+PHBhdGgg'
    b'ZmlsbD0iIzAwOEUxRiIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgc3Ryb2tl'
    b'LWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNNTE2Ljc4OSA0'
    b'MDAuNzVjLTM1Ljg4OS0zMi4xNTktOTAuMzI0LTUyLjY5Ny0xNTEuNDc3LTUyLjY5Ny02MS4x'
    b'NTQgMC0xMTUuNjkgMjAuNTM4LTE1MS40NzkgNTIuNjk3Ii8+PHBhdGggZmlsbD0iI0ZGRDcw'
    b'MCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTMwMy43NTggMTg1LjM0'
    b'N2MtLjE5OS0xNS4wMjcgOS4xMjQtMTUuOTMgMTMuODM1LTI2LjU1IDQuNzEyLTEwLjYyIDQu'
    b'NTEyLTIwLjQzOC0xMC44MjctMjMuMjQzLTMwLjc3OC0xLjMwMy0xNS45NCAzOS4xNzMtMy4w'
    b'MDggNDkuNzkzek0yMDEuNTAyIDE3Ni4wM2MxMC42MjgtMTAuNjIgMTcuODQ1LTQuNjA5IDI4'
    b'LjY3My04LjYxNiAxMC44MjctNC4wMDggMTcuNzQ0LTExLjAyMSA5LjEyMi0yMy45NDUtMjAu'
    b'NTUxLTIyLjk0My0zOS4xOTcgMTYuMDMtMzcuNzk1IDMyLjY2MXYtLjF6Ii8+PHBhdGggZmls'
    b'bD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTIwNi42'
    b'MTYgOTIuNTczYzguMDIgMTIuNzI0IDE2LjQ0IDguMzE2IDI2LjA2NCAxNC43MjggOS42MjQg'
    b'Ni40MTIgMTQuOTM3IDE0LjYyOCAzLjcwOCAyNS40NDctMjUuMDYyIDE3LjczNC0zNC43ODUt'
    b'MjQuMjQ1LTI5Ljc3Mi00MC4xNzV6TTI0MS44MDMgMjUwLjg3YzQuMTEtMTQuNDI4LTQuNzEy'
    b'LTE3LjczMy02LjUxNi0yOS4yNTUtMS44MDUtMTEuNTIyLjkwMi0yMC44MzkgMTYuNDQxLTE5'
    b'LjczOCAzMC4wNzUgNi43MTMgNS4yMTIgNDEuOTgtMTAuMDI1IDQ4Ljg5MmguMXYuMTAxeiIv'
    b'PjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUi'
    b'IGQ9Ik0yNDguNDIgMjQwLjE0OWMzLjQwOC01LjUxMSAyLjQwNi0xMC44MTggMy4yMDgtMTYu'
    b'MDI5LjUwMS0zLjAwNyAzLjgwOS0xMS41MjItMS41MDQtOS45Mi04LjkyMiAyLjYwNi0uODAy'
    b'IDE4LjIzNi0xLjcwNCAyNS45NDl6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTIyNC4wNTggMjM2LjM0NGM0LjUxMi0xNC4z'
    b'MjktNC4yMS0xNy45MzYtNS42MTQtMjkuMzU3LTEuNDAzLTExLjQyMSAxLjUwNC0yMC44Mzgg'
    b'MTcuMDQzLTE5LjIzNSAyOS44NzUgNy42MTQgNC4wMTEgNDIuMTc4LTExLjQyOSA0OC41OTJ6'
    b'Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEu'
    b'NSIgZD0iTTI0Ni44MTYgMjAxLjc3OWMtLjIwMS0xNS4wMyA5LjEyMi0xNS45MzEgMTMuODMz'
    b'LTI2LjU1MSA0LjcxMi0xMC42MiA0LjUxMi0yMC40MzgtMTAuODI3LTIzLjI0My0zMC43NzYt'
    b'MS4zMDMtMTUuOTM5IDM5LjE3My0zLjAwNiA0OS43OTR6TTIwMS43MDMgMjM1Ljc0MWM1Ljcx'
    b'NS0xMy45MjUtMi43MDgtMTguMjM0LTMuMTA3LTI5Ljc1Ni0uNDAxLTExLjUyMSAzLjMwOC0y'
    b'MC42MzkgMTguNjQ2LTE3LjczMyAyOS4wNzMgMTAuMTE5LjQwMiA0Mi4yNzktMTUuNDM4IDQ3'
    b'LjQ5bC0uMTAxLS4wMDF6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9IjEuNSIgZD0iTTIwOS41MjIgMjI1LjgyMmM0LjExMS01LjEwOSAzLjYx'
    b'LTEwLjUyIDUuMDEzLTE1LjUyOC44MDMtMi45MDYgNS4xMTQtMTEuMDIxLS40LTEwLjAyLTku'
    b'MTI0IDEuNjAzLTIuOTA4IDE4LjAzNS00LjYxMyAyNS41NDh6TTE4NS4yNjEgMjA1LjE4NGM5'
    b'LjAyMi0xMi4wMjIgMS45MDUtMTguMjM0IDQuNDEyLTI5LjY1NSAyLjUwNi0xMS40MjIgOC4z'
    b'Mi0xOS4xMzUgMjIuNDU3LTEyLjUyMyAyNS42NjMgMTcuMDMxLTEwLjEyNiA0MS4wNzYtMjYu'
    b'NzY4IDQyLjA3OGwtLjEwMS4xeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0xOTUuMjg2IDE5Ny40N2M1LjIxNC0zLjkwOCA2'
    b'LjExNi05LjIxOCA4LjcyMy0xMy44MjcgMS41MDMtMi42MDUgNy43MTktOS40MTcgMi4xMDUt'
    b'OS44MTgtOS4yMjMtLjcwMi03LjIxOCAxNi43MzEtMTAuOTI3IDIzLjY0NWguMDk5eiIvPjxw'
    b'YXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9'
    b'Ik0xNjcuMjE3IDE3My4yMjVjMTQuOTM4LTEuODA0IDE0LjUzNi0xMS4yMjEgMjQuNDYxLTE3'
    b'LjIzMiA5LjkyNS02LjAxMiAxOS42NDgtNy4yMTQgMjQuNTYxIDcuNTE0IDUuNDE1IDMwLjI1'
    b'Ni0zNi42OTEgMjEuMDM4LTQ5LjAyMiA5LjcxOHoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMTc5Ljc0OCAxNzUuMjI4YzYu'
    b'NDE2IDEuMTAyIDEwLjkyNy0yLjAwMyAxNi4wNC0zLjIwNiAyLjkwNy0uNzAyIDEyLjEzLS45'
    b'MDIgOC42MjItNS4yMS01LjkxNS03LjIxNC0xNy4xNDQgNi4zMTItMjQuNjYyIDguNDE2ek00'
    b'MTguNzQ1IDIwNS4xODRjLTkuMDIyLTEyLjAyMi0xLjkwNC0xOC4yMzQtNC40MS0yOS42NTUt'
    b'Mi41MDctMTEuNDIyLTguMzItMTkuMTM1LTIyLjQ1Ny0xMi41MjMtMjUuNjYzIDE3LjAzMSAx'
    b'MC4xMjYgNDEuMDc2IDI2Ljc2OCA0Mi4wNzhsLjA5OS4xeiIvPjxwYXRoIGZpbGw9IiNGRkQ3'
    b'MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik00MDguNzE5IDE5Ny40'
    b'N2MtNS4yMTQtMy45MDgtNi4xMTUtOS4yMTgtOC43MjItMTMuODI3LTEuNTA0LTIuNjA1LTcu'
    b'NzE5LTkuNDE3LTIuMTA0LTkuODE4IDkuMzIyLS43MDIgNy4zMTYgMTYuNzMxIDEwLjkyNyAy'
    b'My42NDVoLS4xMDF6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9IjEuNSIgZD0iTTQzNy42OTIgMTc0LjMyNmMtMTQuOTM4LTEuNTAzLTE0Ljcz'
    b'Ni0xMC45Mi0yNC43NjMtMTYuODMxLTEwLjAyNC01LjkxMS0xOS43NDktNi45MTQtMjQuMzYg'
    b'OC4wMTUtNC45MTEgMzAuNDU3IDM2Ljk5MyAyMC4zMzggNDkuMTIzIDguODE2ek00MDEuMzAy'
    b'IDIzNS43NDFjLTUuNzE2LTEzLjkyNSAyLjcwNS0xOC4yMzQgMy4xMDYtMjkuNzU2cy0zLjIw'
    b'OC0yMC42MzktMTguNjQ2LTE3LjczM2MtMjkuMDczIDEwLjExOS0uNCA0Mi4yNzkgMTUuNTQg'
    b'NDcuNDg5eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjUiIGQ9Ik0zOTMuNDgxIDIyNS44MjJjLTQuMTA5LTUuMTA5LTMuNjA4LTEwLjUy'
    b'LTUuMDEzLTE1LjUyOC0uODAyLTIuOTA2LTUuMTEyLTExLjAyMS40MDEtMTAuMDIgOS4xMjMg'
    b'MS42MDMgMi45MSAxOC4wMzUgNC42MTIgMjUuNTQ4ek0zNjUuNzEzIDI0NC44NThjLTQuODEz'
    b'LTE0LjIyOCAzLjkxLTE3LjkzNCA1LjExMy0yOS40NTYgMS4yMDMtMTEuNTIxLTEuOTA1LTIw'
    b'LjgzOC0xNy4zNDQtMTguOTM1LTI5LjY3NiA4LjExNi0zLjIwOCA0Mi4xNzkgMTIuMjMxIDQ4'
    b'LjM5MXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iMS41IiBkPSJNMzU4LjU5NCAyMzQuNDM4Yy0zLjcwOS01LjMxLTIuOTA1LTEwLjcxOS0z'
    b'LjkxLTE1LjgyOC0uNjAyLTMuMDA3LTQuNDEtMTEuMzIyIDEuMDA1LTEwLjAyMSA5LjAyMSAy'
    b'LjIwNiAxLjYwMyAxOC4xMzUgMi45MDUgMjUuODQ5ek0zNDIuMDUzIDI0My4zNTVjLTUuOTE0'
    b'LTEzLjgyNiAyLjUwNS0xOC4yMzQgMi44MDctMjkuNzU2cy0zLjUxLTIwLjYzOC0xOC44NDgt'
    b'MTcuNDMzYy0yOC45NzIgMTAuNDIuMTAzIDQyLjI3OSAxNi4wNDEgNDcuMjg5di0uMXoiLz48'
    b'cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBk'
    b'PSJNMzM0LjEzNCAyMzMuNTM3Yy00LjExLTUuMDEtMy43MS0xMC40Mi01LjIxMy0xNS41My0u'
    b'OTAyLTIuOTAzLTUuMjEzLTEwLjkyLjIwMS0xMC4wMTkgOS4yMjIgMS41MDMgMy4xMDcgMTgu'
    b'MDM0IDQuOTExIDI1LjU0OWguMTAxek0zNTIuMTc5IDIyMS41MTRjLTMuNTA5LTE0LjYyNyA1'
    b'LjQxMy0xNy41MzMgNy42MTgtMjguOTUzIDIuMjA2LTExLjQyMSAwLTIwLjk0LTE1LjYzOS0y'
    b'MC4zMzktMzAuMjc0IDUuNTEtNi45MTcgNDEuNzc4IDguMDIxIDQ5LjI5MnoiLz48cGF0aCBm'
    b'aWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzQ2'
    b'LjA2MyAyMTAuNTk1Yy0zLjIwOC01LjYxMS0xLjkwNC0xMC45MjEtMi41MDctMTYuMTMxLS40'
    b'LTMuMDA2LTMuNDA3LTExLjYyMiAxLjkwNS05LjkxOSA4LjgyMiAzLjAwNi4xMDEgMTguMjM0'
    b'LjcwMyAyNi4wNWgtLjEwMXpNMzI4LjExOSAyNDIuNDU0Yy0xLjkwNS0xNC45MjkgNy4zMTct'
    b'MTYuODMyIDEwLjcyNy0yNy45NTMgMy40MDgtMTEuMTIxIDIuMjA2LTIwLjczOC0xMy4zMzMt'
    b'MjEuOTQtMzAuNjc3IDIuMzAzLTExLjQyOSA0MC44NzYgMi42MDYgNDkuODkzek0zNzguNzQ1'
    b'IDIzNi45NDNjLTMuNDA5LTE0LjYyNyA1LjYxNC0xNy41MzIgOC4wMjEtMjguODU0IDIuNDA1'
    b'LTExLjMyMi4yLTIwLjk0LTE1LjQzOC0yMC41MzktMzAuNDc5IDUuMjExLTcuNDIgNDEuNzgx'
    b'IDcuNDE3IDQ5LjM5M3oiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iMS41IiBkPSJNNDAxLjMwMiAyMzUuNzQxYy01LjcxNi0xMy45MjUgMi43'
    b'MDUtMTguMjM0IDMuMTA2LTI5Ljc1NnMtMy4yMDgtMjAuNjM5LTE4LjY0Ni0xNy43MzNjLTI5'
    b'LjA3MyAxMC4xMTktLjQgNDIuMjc5IDE1LjU0IDQ3LjQ4OXoiLz48cGF0aCBmaWxsPSIjRkZE'
    b'NzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzkzLjQ4MSAyMjUu'
    b'ODIyYy00LjEwOS01LjEwOS0zLjYwOC0xMC41Mi01LjAxMy0xNS41MjgtLjgwMi0yLjkwNi01'
    b'LjExMi0xMS4wMjEuNDAxLTEwLjAyIDkuMTIzIDEuNjAzIDIuOTEgMTguMDM1IDQuNjEyIDI1'
    b'LjU0OHpNMzg0LjQ1OSAyMDIuMjc4Yy04LjkyMi0xMi4wMjItMS44MDQtMTguMzM0LTQuMjEt'
    b'MjkuNjU1LTIuNDA2LTExLjMyMS04LjIyLTE5LjIzNS0yMi4zNTYtMTIuNjI1LTI1Ljc2NCAx'
    b'Ni44MzQgOS45MjQgNDEuMTc4IDI2LjU2NiA0Mi4yOHoiLz48cGF0aCBmaWxsPSIjRkZENzAw'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzc0LjUzNCAxOTQuNTY0'
    b'Yy01LjIxMi0zLjkwOC02LjAxNS05LjMxOC04LjYyMi0xMy44MjYtMS41MDQtMi42MDUtNy42'
    b'MTgtOS40MTgtMi4xMDQtOS44MTggOS4zMjQtLjcwMiA3LjIxNyAxNi44MzEgMTAuNzI2IDIz'
    b'LjY0NHoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iMS41IiBkPSJNMzk0Ljg4NSAxOTQuMzYzYy04LjkyMy0xMi4wMjItMS44MDUtMTguMzMz'
    b'LTQuMjEtMjkuNjU1LTIuNDA3LTExLjMyLTguMjIyLTE5LjIzNi0yMi4zNTctMTIuNjI0LTI1'
    b'Ljc2NCAxNi44MzIgOS45MjYgNDEuMTc4IDI2LjU2NyA0Mi4yNzl6Ii8+PHBhdGggZmlsbD0i'
    b'I0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTM4NC45NjEg'
    b'MTg2LjY1Yy01LjIxNC0zLjkwOC02LjAxNi05LjMxOC04LjYyMS0xMy44MjctMS41MDQtMi42'
    b'MDUtNy42MTgtOS40MTctMi4xMDUtOS44MTcgOS4zMjItLjcwMyA3LjIxNyAxNi44MyAxMC43'
    b'MjYgMjMuNjQ0ek00MzguMTkzIDEzNy41NTdjLTEzLjYzNCA2LjIxMS0xOC4yNDYtMi4wMDMt'
    b'MjkuODc1LTIuMDAzcy0yMC41NSA0LjEwNy0xNi45NDEgMTkuMjM2YzExLjIyOCAyOC42NTMg'
    b'NDIuMzA1LTEuMjAzIDQ2LjgxNi0xNy4zMzN2LjF6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTQyOC42NyAxNDUuNzczYy00'
    b'LjkxMyA0LjMwOC0xMC4zMjUgNC4wMDctMTUuMzM4IDUuNjEtMi45MDguOTAxLTEwLjgyNiA1'
    b'LjUxLTEwLjAyNSAwIDEuMjAzLTkuMjE2IDE3Ljk0My0zLjYwNyAyNS4zNjMtNS42MXpNNDE1'
    b'LjAzNiAxNjQuMjA4Yy0xNC44MzgtMi4xMDQtMTQuMzM3LTExLjUyMi0yNC4wNjItMTcuNzMz'
    b'LTkuNzIzLTYuMjEyLTE5LjQ0Ny03LjYxNC0yNC42NTkgNy4wMTMtNi4wMTcgMzAuMTU2IDM2'
    b'LjI4OSAyMS44NCA0OC44MiAxMC43MmgtLjA5OXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNNDAyLjUwNCAxNjUuODExYy02'
    b'LjQxNS45MDEtMTAuODI2LTIuMjA0LTE1LjkzOS0zLjYwNy0yLjkwNi0uODAxLTEyLjAzLTEu'
    b'MjAzLTguNTIxLTUuNDEgNi4wMTYtNy4xMTMgMTcuMDQxIDYuNjEzIDI0LjQ2IDguOTE3di4x'
    b'ek00NDAuNTk5IDExOC43MjJjLTE0LjgzOCAyLjAwNC0xNC40MzYgMTEuNDIyLTI0LjE2IDE3'
    b'LjYzMy05LjcyNSA2LjIxMi0xOS41NDkgNy42MTQtMjQuNjYtNy4yMTQtNS45MTUtMzAuMTU2'
    b'IDM2LjM4OS0yMS41MzkgNDguODItMTAuNDE5eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik00MTIuMzMgMTI2LjIzNmMtMTIu'
    b'MTMyIDguOTE3LTE4LjM0NiAxLjgwNC0yOS42NzUgNC4xMDgtMTEuMzI4IDIuMzA0LTE5LjI0'
    b'OSA4LjExNi0xMi43MzMgMjIuMjQyIDE2Ljc0MyAyNS44NDkgNDEuMjA0LTkuNzE4IDQyLjQw'
    b'OC0yNi4zNXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iMS41IiBkPSJNNDA0LjUxIDEzNi4yNTVjLTQuMDEgNS4xMS05LjMyNCA2LjAxLTEz'
    b'LjkzNSA4LjYxNi0yLjYwNyAxLjUwMy05LjQyNSA3LjYxNC05LjgyMyAyLjEwNC0uNjA0LTku'
    b'MzE3IDE2Ljg0LTcuMTEzIDIzLjc1OS0xMC42MmwtLjAwMS0uMXpNNDA3LjIxNiA3MS4xMzNj'
    b'LTYuMzE1IDEzLjYyNS0xNS4yMzggMTAuMzE5LTI0LjA2IDE3LjgzMy04LjgyMiA3LjUxNC0x'
    b'My4wMzMgMTYuMzMxLS40IDI1LjY0OCAyNy4xNjcgMTQuNjI4IDMxLjM3OC0yOC4yNTIgMjQu'
    b'NDYtNDMuNDgxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjUiIGQ9Ik00MDUuMjEgODMuNjU3Yy0xLjAwMiA2LjQxMi01LjMxMyA5Ljcx'
    b'OS04LjAxOCAxNC4yMjctMS42MDUgMi42MDQtNC42MTIgMTEuMjIxLTcuNjE5IDYuNTEzLTUu'
    b'MDE0LTcuODE2IDExLjMyNy0xNC4zMjkgMTUuNjM3LTIwLjc0ek00MDQuMzA4IDEwMy41OTRj'
    b'LTkuODI0IDExLjMyMS0xNy40NDMgNS44MTEtMjguMDY5IDEwLjUyLTEwLjYyOCA0LjcwOC0x'
    b'Ny4wNDMgMTIuMTIzLTcuNTE4IDI0LjU0NSAyMi4wNTQgMjEuNDQgMzcuOTkzLTE4LjYzNSAz'
    b'NS40ODYtMzUuMDY1aC4xMDF6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTM5OC44OTQgMTE1LjAxNWMtMi43MDYgNS45MTIt'
    b'Ny44MTggNy45MTYtMTEuNjI3IDExLjQyMi0yLjIwNiAyLjAwMy03LjUyMSA5LjUxOC05LjEy'
    b'NCA0LjIwNy0yLjcwNy04LjkxNyAxNC44MzYtMTAuNjIgMjAuODUzLTE1LjYyOWgtLjEwMnpN'
    b'MzgxLjI1MiA0OC41OTFjLTMuMDA4IDE0LjcyOC0xMi4zMzEgMTMuNjI1LTE5LjE0NyAyMi45'
    b'NDMtNi44MTcgOS4zMTctOC44MjIgMTguOTM1IDUuNjE0IDI1LjA0NiAyOS43NzIgNy45MTYg'
    b'MjMuOTU4LTM0Ljg2NCAxMy41MzMtNDcuOTg5eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0zOTQuMDgzIDg2LjM2MmMtMTAu'
    b'MDIzIDExLjIyMS0xNy41NDQgNS41MS0yOC4xNzEgMTAuMTE4LTEwLjYyNSA0LjYwOS0xNy4y'
    b'NDEgMTEuOTIzLTcuOTE5IDI0LjQ0NyAyMS43NTQgMjEuODQxIDM4LjI5Ni0xOC4wMzQgMzYu'
    b'MDktMzQuNTY1eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjUiIGQ9Ik0zODguNTY5IDk3LjY4M2MtMi44MDcgNS44MTEtNy45MiA3Ljgx'
    b'NC0xMS44MjkgMTEuMjIxLTIuMzA2IDIuMDA0LTcuNzIgOS4zMTctOS4yMjMgNC4wMDctMi41'
    b'MDctOC45MTcgMTUuMDM3LTEwLjQyIDIxLjA1Mi0xNS4zMjl2LjEwMXpNMzYwLjA5NyAzNy40'
    b'N2MtMS4yMDMgMTQuOTI4LTEwLjYyNiAxNS4wMjgtMTYuMzQgMjUuMDQ3LTUuNzE1IDEwLjAy'
    b'LTYuNTE3IDE5LjgzOCA4LjUyMSAyNC4yNDYgMzAuNDc4IDQuMzA3IDE5LjY1LTM3LjQ3MSA3'
    b'LjgxOS00OS4yOTN6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9IjEuNSIgZD0iTTM2Mi41MDUgNDkuODk0YzEuMzAzIDYuMzEyLTEuNjA0IDEw'
    b'LjkyLTIuNjA2IDE2LjEzLS42MDEgMy4wMDYtLjUwMiAxMi4xMjMtNC45MTMgOC44MTctNy40'
    b'MTktNS42MTIgNS42MTMtMTcuMzM0IDcuNTE5LTI0Ljk0N3pNMzY2LjMxNSA2OC4wMjdjLTQu'
    b'MTEyIDE0LjQyNi0xMy40MzUgMTIuNjI0LTIwLjk1NCAyMS4zNC03LjUxOCA4LjcxNi0xMC4z'
    b'MjUgMTguMjM0IDMuNTEgMjUuNDQ4IDI5LjA3MSAxMC4yMTkgMjYuNjY2LTMyLjg2MSAxNy40'
    b'NDQtNDYuNzg4ek0zNTQuMjg0IDMxLjY1OWMtOC42MiAxMi4yMjMtMS40MDMgMTguMzM0LTMu'
    b'NjA4IDI5LjY1Ni0yLjIwNiAxMS4zMjEtNy44MiAxOS40MzYtMjIuMDU2IDEzLjEyNC0yNi4x'
    b'NjUtMTYuMzMxIDkuMDIyLTQxLjM3NyAyNS42NjQtNDIuNzh6Ii8+PHBhdGggZmlsbD0iI0ZG'
    b'RDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTM0NC40NiAzOS42'
    b'NzVjLTUuMTEzIDQuMDA3LTUuODE0IDkuNDE3LTguMzIgMTQuMDI1LTEuNTAzIDIuNzA1LTcu'
    b'NDE5IDkuNjE4LTEuOTA1IDkuOTE5IDkuMzIxLjUwMSA2LjgxNy0xNi45MzEgMTAuMjI1LTIz'
    b'Ljk0NHoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iMS41IiBkPSJNMzQ3LjM2NyA1Ni4xMDVjLTUuMzEzIDE0LjAyNi0xNC40MzcgMTEuNDIx'
    b'LTIyLjY1NiAxOS41MzctOC4yMjIgOC4xMTUtMTEuNzMgMTcuMjMyIDEuNDA0IDI1LjY0OCAy'
    b'OC4wNjkgMTIuNjIzIDI5LjI3MS0zMC40NTcgMjEuMjUyLTQ1LjE4NXoiLz48cGF0aCBmaWxs'
    b'PSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzY2LjIx'
    b'NSA4NS44NjFjLTEyLjEzMiA4LjgxNi03LjIxOSAxNi45MzItMTIuODMyIDI3LjA1LTUuNjE1'
    b'IDEwLjExOS0xMy41MzUgMTUuOTMtMjUuMDY0IDUuNDEtMTkuNzQ5LTIzLjg0NCAyMS41NTMt'
    b'MzYuMzY3IDM3Ljg5Ni0zMi40NnoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzU0LjI4NCA5MC4xNjhjLTYuMTE1IDIuMjA1'
    b'LTguNTIxIDcuMTE0LTEyLjQzMiAxMC42Mi0yLjIwNCAyLjEwNC0xMC4xMjUgNi43MTItNC45'
    b'MSA4LjcxNyA4LjYyIDMuNTA2IDExLjgyOC0xMy44MjYgMTcuMzQyLTE5LjQzN3YuMXoiLz48'
    b'cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBk'
    b'PSJNMzg2Ljk2NiAxMDMuODk1Yy0xMy40MzMgNi43MTItMTAuMDI2IDE1LjQyOS0xNy4yNDMg'
    b'MjQuNDQ1LTcuMjE4IDkuMDE3LTE2LjA0IDEzLjMyNS0yNS42NjQgMS4wMDItMTUuMjM4LTI2'
    b'Ljc1IDI3LjU2OC0zMi4wNiA0My4wMDgtMjUuNDQ3aC0uMTAxeiIvPjxwYXRoIGZpbGw9IiNG'
    b'RkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0zNzQuNjM1IDEw'
    b'Ni4yOTljLTYuNDE1IDEuMTAzLTkuNjI0IDUuNTEtMTQuMDM1IDguNDE2LTIuNTA3IDEuNzA0'
    b'LTExLjEyOCA0LjkwOS02LjMxNSA3LjgxNCA3LjkxOSA0LjgxIDE0LjAzNC0xMS42MjEgMjAu'
    b'MzUxLTE2LjEzdi0uMXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iMS41IiBkPSJNMzg2LjM2MyAxMjQuODM0Yy0xMi41MyA4LjMxNS04LjAx'
    b'OSAxNi41MzEtMTQuMTM0IDI2LjM0OXMtMTQuMzM3IDE1LjIyOC0yNS4zNjUgNC4yMDhjLTE4'
    b'LjM0Ni0yNC42NDYgMjMuNDYtMzUuMTY2IDM5LjQ5OS0zMC41NTd6Ii8+PHBhdGggZmlsbD0i'
    b'I0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTM4Ny40NjYg'
    b'MTYxLjcwMmMtMTMuNjMzLTYuNDEyLTE4LjM0NSAxLjgwNC0yOS44NzMgMS43MDQtMTEuNTI5'
    b'LS4xMDEtMjAuNDUxLTQuMjA4LTE2Ljg0My0xOS40MzcgMTEuNDI5LTI4LjU1MiA0Mi4zMDUg'
    b'MS42MDMgNDYuNzE2IDE3LjczM3oiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzc3Ljk0MiAxNTMuNDg4Yy00LjkxLTQuMzA5'
    b'LTEwLjMyNC00LjEwOC0xNS4zMzgtNS43MTEtMi45MDYtMS4wMDEtMTAuNzI4LTUuNjEtMTAu'
    b'MDI1LS4xIDEuMTA0IDkuMjE3IDE3Ljg0NSAzLjcwNyAyNS4zNjMgNS45MTF2LS4xeiIvPjxw'
    b'YXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9'
    b'Ik0zNjMuMDA3IDE4Ny4xNWMtNy4wMTktMTMuMjI1LTE1Ljc0MS05LjUxNy0yNC45NjQtMTYu'
    b'NTMxLTkuMjIyLTcuMDEyLTEzLjgzNC0xNS42MjgtMS44MDQtMjUuNjQ3IDI2LjM2NS0xNS45'
    b'MzEgMzIuODgyIDI2LjY0OSAyNi43NjggNDIuMTc4eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAi'
    b'IHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0zNDIuNzU1IDE5OS45NzVj'
    b'LTQuMTA5LTE0LjQyNy0xMy4zMzMtMTIuNjI0LTIwLjg1Mi0yMS40NHMtMTAuMjI2LTE4LjIz'
    b'NCAzLjcxLTI1LjQ0OGMyOS4wNzEtMTAuMDIgMjYuNDY1IDMyLjk2MSAxNy4xNDIgNDYuODg4'
    b'eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjUiIGQ9Ik0zNDIuNzU1IDE4Ny4zNTFjLjEwMS02LjUxMy0zLjcwOS0xMC40MTktNS43MTQt'
    b'MTUuMzI4LTEuMTA0LTIuODA2LTIuODA3LTExLjgyMy02LjUxNy03LjcxNS02LjIxNiA2Ljkx'
    b'MyA4LjkyMyAxNS45MjkgMTIuMTMxIDIyLjk0M2wuMS4xek0yODQuOTExIDE5Ny44NzFsNi44'
    b'MTcgOC44MTYtLjkwMiAyOC42NTRjLTIuNjA3IDE5LjgzOC00LjYxMiAzOS4xNzMtMTEuMzMg'
    b'NjMuMjE5IDYuOTE3IDYuODExIDE0LjQzNyA1LjcxIDIxLjk1NSA1LjcxczE0LjkzOCAxLjEw'
    b'MSAyMS45NTUtNS43MWMtNi43MTctMjQuMDQ2LTguNzIyLTQzLjM4MS0xMS4zMjgtNjMuMjE5'
    b'bC0uOTAzLTI4LjY1NCA2LjgxNy04LjgxNmgtMzMuMDgxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3'
    b'MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0zMTAuOTc1IDIxNy44'
    b'MDljLTQuMTA5LTE0LjQyOS0xMy4zMzMtMTIuNjI1LTIwLjg1MS0yMS40NDEtNy41MTktOC44'
    b'MTYtMTAuMjI3LTE4LjIzNCAzLjcwOC0yNS40NDcgMjkuMDczLTEwLjAyIDI2LjQ2OCAzMi45'
    b'NjEgMTcuMTQzIDQ2Ljg4OHoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzEwLjk3NSAyMDUuMTg0Yy4xMDEtNi41MTItMy43'
    b'MDgtMTAuNDE5LTUuNzE1LTE1LjMyOS0xLjEwMy0yLjgwNS0yLjgwNi0xMS44MjItNi41MTUt'
    b'Ny43MTQtNi4yMTYgNi45MTMgOC45MjIgMTUuOTMgMTIuMTMgMjIuOTQzbC4xLjF6Ii8+PHBh'
    b'dGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0i'
    b'TTMyNy42MTggMjEyLjc5OWMtNC4xMTEtMTQuNDI4LTEzLjMzNS0xMi42MjUtMjAuODUzLTIx'
    b'LjQ0LTcuNTItOC44MTYtMTAuMjI2LTE4LjIzNSAzLjcxLTI1LjQ0OCAyOS4wNzItMTAuMDE5'
    b'IDI2LjQ2NyAzMi45NjIgMTcuMTQzIDQ2Ljg4OHoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzI3LjYxOCAyMDAuMTc0Yy4x'
    b'LTYuNTEyLTMuNzEtMTAuNDE5LTUuNzE1LTE1LjMyOC0xLjEwNC0yLjgwNi0yLjgwNi0xMS44'
    b'MjItNi41MTctNy43MTUtNi4yMTUgNi45MTQgOC45MjIgMTUuOTMxIDEyLjEzMSAyMi45NDNs'
    b'LjEwMS4xeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjUiIGQ9Ik0zMTkuOTk5IDE4NC4yNDVjLTEuODA1LTE0LjkyOCA3LjUxOS0xNi44'
    b'MzEgMTEuMDI3LTI3Ljg1MnMyLjQwNi0yMC43NC0xMy4xMzMtMjIuMDQyYy0zMC44NzggMS45'
    b'MDQtMTEuODI5IDQwLjY3NyAyLjEwNiA0OS44OTR6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTM0My4wNTUgMTY4LjUxNmMt'
    b'My44MDgtMTQuNTI3LTEzLjEzMi0xMi45MjQtMjAuNDUtMjEuODQxLTcuMzE4LTguOTE3LTku'
    b'OTI1LTE4LjQzNCA0LjExLTI1LjM0NyAyOS4xNzItOS41MTkgMjUuODY0IDMzLjQ2MiAxNi4z'
    b'NCA0Ny4xODh6TTM0MS40NTIgMjUuMDQ3Yy05LjUyMyAxMS41MjEtMi44MDcgMTguMTM0LTUu'
    b'ODEzIDI5LjM1NC0zLjAwOSAxMS4yMjItOS4xMjQgMTguNzM1LTIyLjk1OCAxMS40MjItMjQu'
    b'ODYyLTE4LjIzNCAxMi4xMjktNDAuNTc1IDI4Ljc3MS00MC43NzZ6TTE2NS43MTQgMTM1LjY1'
    b'NGMxMy44MzQgNS43MTEgMTguMjQ1LTIuNjA1IDI5Ljc3My0zLjEwNSAxMS41MjktLjUwMiAy'
    b'MC42NTIgMy4zMDYgMTcuNjQ1IDE4LjYzNS0xMC4xMjUgMjkuMDU0LTQyLjMwNS4zLTQ3LjUx'
    b'OS0xNS41MjloLjEwMXYtLjAwMXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMTYyLjMwNSAxMTguMDIxYzE0LjkzNyAxLjMw'
    b'MyAxNC45MzcgMTAuNzIgMjUuMDYzIDE2LjQzMSAxMC4xMjUgNS43MSAxOS44NDkgNi42MTIg'
    b'MjQuMjYxLTguNDE2IDQuNDEtMzAuNDU3LTM3LjM5NS0xOS43MzctNDkuMzI0LTguMDE1eiIv'
    b'PjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUi'
    b'IGQ9Ik0xNzQuNzM1IDExNS42MTdjNi40MTctMS4zMDMgMTAuOTI4IDEuNjAzIDE2LjE0MiAy'
    b'LjcwNSAzLjAwNy42MDIgMTIuMTI5LjUwMSA4LjcyMiA0LjkwOS01LjYxNSA3LjQxMy0xNy4z'
    b'NDUtNS43MTEtMjQuODY0LTcuNjE0ek0xOTcuNzkzIDY5LjYzYzYuMzE3IDEzLjYyNiAxNS4y'
    b'MzkgMTAuMzE5IDI0LjA2IDE3LjgzMyA4LjgyMyA3LjUxMyAxMy4wMzMgMTYuMzMxLjQwMSAy'
    b'NS42NDctMjcuMTY3IDE0LjYyOS0zMS4zNzctMjguMzUyLTI0LjQ2MS00My40OHoiLz48cGF0'
    b'aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJN'
    b'MTk5Ljc5OCA4Mi4xNTRjMS4wMDIgNi40MTIgNS4zMTQgOS43MTggOC4wMjEgMTQuMjI3IDEu'
    b'NjA0IDIuNjA0IDQuNjEyIDExLjIyMSA3LjYxOSA2LjUxMiA1LjAxMi03LjgxNS0xMS4zMjgt'
    b'MTQuMzI4LTE1LjY0LTIwLjczOXpNMjIzLjA1NiA0OC4zOTFjMy4wMDcgMTQuNzI4IDEyLjMz'
    b'MSAxMy42MjUgMTkuMTQ4IDIyLjk0MyA2LjgxNyA5LjMxNyA4LjgyMiAxOC45MzUtNS42MTQg'
    b'MjUuMDQ3LTI5Ljc3NSA3LjgxNC0yMy44NTktMzQuODY1LTEzLjUzNC00Ny45OXoiLz48cGF0'
    b'aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJN'
    b'MjQ1LjAxMSAzNi4wNjdjLjkwMSAxNS4wMjggMTAuMzI1IDE1LjIyOSAxNS43NCAyNS40NDgg'
    b'NS40MTMgMTAuMjE5IDYuMDE1IDIwLjAzNy05LjEyNCAyNC4wNDQtMzAuNTc2IDMuNTA4LTE4'
    b'Ljc0Ni0zNy45Ny02LjYxNi00OS40OTJ6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTI0Mi4zMDQgNDguMzkxYy0xLjUwNCA2'
    b'LjMxMiAxLjMwMyAxMS4wMjEgMi4yMDYgMTYuMjMuNTAxIDMuMDA2LjA5OSAxMi4xMjMgNC42'
    b'MTEgOC45MTYgNy42MTktNS40MS01LjIxMy0xNy41MzMtNi45MTctMjUuMDQ3bC4xLS4wOTl6'
    b'TTI2My45NTggMjQuNTQ2YzEwLjEyNSAxMS4wMjEgMy44MTEgMTguMDM0IDcuMzE4IDI5LjA1'
    b'NSAzLjUxIDExLjAyMSAxMC4yMjUgMTguMjM0IDIzLjU1OSAxMC4yMTkgMjMuODU5LTE5LjUz'
    b'Ny0xNC4yMzUtMzkuODc1LTMwLjk3OC0zOS4yNzRoLjEwMXoiLz48cGF0aCBmaWxsPSIjRkZE'
    b'NzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMjc0Ljc4NiAzMS4x'
    b'NTljNS42MTMgMy4zMDYgNy4wMTcgOC42MTYgMTAuMDI0IDEyLjgyNCAxLjgwNSAyLjUwNCA4'
    b'LjYyMSA4LjUxNSAzLjEwNyA5LjUxNy05LjEyMyAxLjcwMy04LjkyMi0xNS45My0xMy4yMzMt'
    b'MjIuNDQybC4xMDIuMTAxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0zMDQuODYxIDEyLjEyM2MtLjIwMSAxNS4wMjggOS4x'
    b'MjEgMTUuOTI5IDEzLjgzNCAyNi41NSA0LjcxMiAxMC42MTkgNC41MTIgMjAuNDM4LTEwLjgy'
    b'NyAyMy4yNDMtMzAuNzc2IDEuMzAzLTE1Ljk0LTM5LjE3NC0zLjAwNy00OS43OTN6Ii8+PHBh'
    b'dGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0i'
    b'TTMwMS4yNTIgMjQuMjQ2Yy0xLjkwNCA2LjIxMS41MDEgMTEuMDIxIDEuMDAyIDE2LjMzLjMw'
    b'MiAzLjAwNS0uNzAxIDEyLjEyMyA0LjAxIDkuMjE4IDcuOTE5LTQuODEtMy45MDktMTcuODM0'
    b'LTUuMDEyLTI1LjU0OHpNMjgyLjAwMiA1MC4zOTRjOS4yMjQgMTEuODIyIDIuMzA3IDE4LjIz'
    b'NCA1LjAxMyAyOS41NTUgMi43MDcgMTEuMzIyIDguNjIyIDE5LjAzNiAyMi42NTcgMTIuMTIz'
    b'IDI1LjM2NC0xNy42MzMtMTAuOTI3LTQwLjk3Ni0yNy42Ny00MS42Nzh6Ii8+PHBhdGggZmls'
    b'bD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTI5Mi4y'
    b'MjkgNTcuODA4YzUuMzEzIDMuODA3IDYuMjE1IDkuMTE3IDkuMDIzIDEzLjYyNSAxLjYwNCAy'
    b'LjYwNSA3LjgyIDkuMjE4IDIuMzA3IDkuODE5LTkuMjI1LjkwMi03LjYyMS0xNi42MzEtMTEu'
    b'MzMtMjMuNDQ0eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjUiIGQ9Ik0zMzMuNDMyIDU1LjkwNGMtOS4xMjQgMTEuOTIyLTIuMTA2IDE4'
    b'LjIzNC00LjYxMiAyOS41NTUtMi41MDcgMTEuMzIyLTguNTIxIDE5LjEzNy0yMi41NTcgMTIu'
    b'MzI0LTI1LjU2My0xNy4yMzMgMTAuNTI4LTQwLjk3NyAyNy4xNjktNDEuODc5eiIvPjxwYXRo'
    b'IGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0z'
    b'MjMuMzA2IDYzLjUxOWMtNS4yMTMgMy44MDgtNi4xMTQgOS4yMTgtOC44MjEgMTMuNzI2LTEu'
    b'NTA1IDIuNjA1LTcuNzIgOS4zMTgtMi4yMDYgOS44MTkgOS4yMjQuODAyIDcuNDE5LTE2Ljcz'
    b'MSAxMS4xMjgtMjMuNTQ0aC0uMTAxek0yNDguNjIgMzEuMDU4YzkuNTI0IDExLjUyMiAyLjgw'
    b'NyAxOC4xMzQgNS44MTQgMjkuMzU0IDMuMDA3IDExLjIyMSA5LjIyMyAxOC43MzUgMjMuMDU3'
    b'IDExLjQyMiAyNC44NjQtMTguMjMzLTEyLjEyOS00MC41NzUtMjguODcxLTQwLjc3NnoiLz48'
    b'cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBk'
    b'PSJNMjY5LjE3MSA0Ni42ODhjNi40MTcgMTMuNTI1IDE1LjIzOCAxMC4zMTkgMjQuMTYxIDE3'
    b'LjczMyA4LjkyMSA3LjQxNCAxMy4wMzIgMTYuMzMxLjYwMSAyNS42NDgtMjcuMDY4IDE0Ljcy'
    b'OC0zMS41NzktMjguMTUzLTI0LjY2MS00My4zODFoLS4xMDF6Ii8+PHBhdGggZmlsbD0iI0ZG'
    b'RDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTI3MS4xNzYgNTku'
    b'MTFjMS4wMDMgNi40MTIgNS4zMTMgOS43MTkgOC4xMjEgMTQuMTI3IDEuNjA0IDIuNjA1IDQu'
    b'NzEyIDExLjIyMSA3LjYxOSA2LjUxMiA1LjAxMi03LjgxNC0xMS40MjktMTQuMjI3LTE1Ljgz'
    b'OS0yMC42MzloLjA5OXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iMS41IiBkPSJNMjUwLjMyNCA1Ni43MDZjNy42MTkgMTIuOTI0IDE2LjE0'
    b'IDguODE2IDI1LjU2NCAxNS41MjkgOS40MjMgNi43MTIgMTQuNTM2IDE1LjAyOCAyLjkwNiAy'
    b'NS41NDgtMjUuNjY0IDE3LjAzMi0zMy45ODQtMjUuMjQ3LTI4LjQ3MS00MC45Nzd2LS4xeiIv'
    b'PjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUi'
    b'IGQ9Ik0yNTMuNTMyIDY4LjkyOWMxLjYwNCA2LjMxMiA2LjIxNiA5LjIxNyA5LjMyNCAxMy40'
    b'MjYgMS44MDQgMi40MDQgNS42MTQgMTAuNzE5IDguMjIxIDUuODExIDQuMzEtOC4yMTYtMTIu'
    b'NjMyLTEzLjIyNi0xNy41NDQtMTkuMTM2di0uMTAxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAi'
    b'IHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0yNzguODk2IDcwLjMzMmMx'
    b'LjkwNiAxNC45MjggMTEuMzI4IDE0LjUyNyAxNy40NDMgMjQuMzQ2czcuMzE5IDE5LjUzNy03'
    b'LjQxOCAyNC41NDZjLTMwLjI3NiA1LjYxMS0yMS4xNTItMzYuNTY5LTkuOTI2LTQ4Ljg5Mmgt'
    b'LjA5OXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iMS41IiBkPSJNMjc2Ljk5IDgyLjg1NWMtMS4wMDIgNi40MTMgMi4xMDcgMTAuOTIxIDMu'
    b'MzEgMTYuMDMxLjcgMi45MDUgMS4wMDIgMTIuMTIyIDUuMzEzIDguNTE2IDcuMjE4LTUuOTEy'
    b'LTYuNDE3LTE3LjEzMy04LjYyMy0yNC41NDd6TTIzMi44ODEgNzAuNjMyYzguODIyIDEyLjEy'
    b'NCAxNi45NDIgNy4zMTMgMjYuOTY4IDEzLjAyNSAxMC4wMjUgNS43MSAxNS44MzkgMTMuNjI1'
    b'IDUuMzEzIDI1LjE0Ny0yMy44NTkgMTkuNDM3LTM2LjE5LTIxLjg0MS0zMi4yODEtMzguMDcx'
    b'di0uMTAxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjUiIGQ9Ik0yMzcuMjkyIDgyLjQ1NGMyLjIwNiA2LjExMiA3LjAxOCA4LjUxNyAx'
    b'MC42MjcgMTIuNDI0IDIuMDA0IDIuMjA0IDYuNjE2IDEwLjExOCA4LjcyMiA1LjAxIDMuNTA3'
    b'LTguNjE3LTEzLjgzNi0xMS45MjQtMTkuMzQ5LTE3LjQzNHoiLz48cGF0aCBmaWxsPSIjRkZE'
    b'NzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMjExLjgyOCA5My41'
    b'NzVjMTQuMDM2IDUuMzExIDE4LjE0Ni0zLjIwNiAyOS42NzQtMy45MDcgMTEuNTI5LS43MDIg'
    b'MjAuNzUyIDIuNzA2IDE4LjI0NiAxOC4xMzQtOS4zMjMgMjkuMzU0LTQyLjMwNiAxLjUwMy00'
    b'Ny45Mi0xNC4yMjd6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJv'
    b'a2Utd2lkdGg9IjEuNSIgZD0iTTE5MC4xNzUgMTQ3LjU3NmMxMy43MzQtNi4wMTEgMTAuNzI3'
    b'LTE0LjkyNyAxOC40NDYtMjMuNTQzIDcuNzE4LTguNjE2IDE2Ljc0MS0xMi41MjQgMjUuNjY0'
    b'LjIgMTMuOTM0IDI3LjQ1MS0yOS4xNzMgMzAuNjU3LTQ0LjExIDIzLjM0M3oiLz48cGF0aCBm'
    b'aWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMjAy'
    b'LjYwNSAxNDUuODczYzYuNDE2LS44MDIgOS44MjUtNS4wMSAxNC40MzYtNy43MTUgMi42MDct'
    b'MS41MDIgMTEuMzI4LTQuMzA4IDYuNzE3LTcuNDEzLTcuNzE5LTUuMjEtMTQuNjM2IDEwLjky'
    b'LTIxLjE1MyAxNS4xMjh6TTIwNy41MTggMjExLjY5NWM4LjIyMS0xMi42MjIuNzAyLTE4LjMz'
    b'MyAyLjQwNi0yOS44NTUgMS43MDUtMTEuNTIxIDcuMDE4LTE5LjYzNyAyMS41NTQtMTMuOTI2'
    b'IDI2Ljc2NiAxNS4zMjktNy40MiA0MS42NzgtMjMuOTYgNDMuNzgxeiIvPjxwYXRoIGZpbGw9'
    b'IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0yMTcuMDQx'
    b'IDIwMy4zOGM0LjkxMy00LjIwOCA1LjQxNC05LjYxNyA3LjgyLTE0LjMyNiAxLjQwMy0yLjcw'
    b'NSA3LjAxNy05LjgxOCAxLjUwMy05LjkxOC05LjMyMy0uMTAxLTYuMTE1IDE3LjEzMS05LjMy'
    b'MyAyNC4zNDV2LS4xMDF6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9IjEuNSIgZD0iTTIwOS4zMjIgMTczLjkyNWMxMy45MzUtNS40MSAxMS4z'
    b'MjktMTQuNTI3IDE5LjM0OS0yMi44NDMgOC4wMi04LjMxNSAxNy4xNDItMTEuOTIyIDI1LjY2'
    b'NCAxLjIwMiAxMi44MzEgMjcuOTUzLTMwLjI3NyAyOS41NTYtNDUuMDEzIDIxLjY0MXoiLz48'
    b'cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBk'
    b'PSJNMjIxLjg1MyAxNzIuNzIzYzYuNTE3LS42MDEgMTAuMDI1LTQuNzA4IDE0LjczNy03LjEx'
    b'MiAyLjcwNy0xLjQwMyAxMS40MjktMy45MDggNy4wMTgtNy4yMTQtNy41MTktNS41MTEtMTUu'
    b'MDM4IDEwLjQxOS0yMS43NTUgMTQuMzI2ek0yNjcuOTY4IDI0NC42NTljMy44MS0xNC41Mjgt'
    b'NS4xMTItMTcuNjM1LTcuMTE3LTI5LjA1Ni0yLjAwNi0xMS40MjIuNDAxLTIwLjkzOSAxNi4w'
    b'NC0yMC4wMzcgMzAuMTc1IDYuMDExIDYuMTE0IDQxLjg3OC04LjkyMyA0OS4wOTN6Ii8+PHBh'
    b'dGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0i'
    b'TTIzMC43NzYgMjE2LjQwNWMxMS42MjgtOS40MTkgNi4zMTUtMTcuMjMzIDExLjQyOS0yNy42'
    b'NTIgNS4xMTMtMTAuNDE5IDEyLjczMS0xNi42MzEgMjQuNzYyLTYuNzEyIDIwLjc1MSAyMi43'
    b'NDMtMTkuODUgMzcuMzcxLTM2LjI5IDM0LjM2NWguMDk5di0uMDAxeiIvPjxwYXRoIGZpbGw9'
    b'IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0yNDIuMzA0'
    b'IDIxMS40OTVjNi4wMTUtMi41MDUgOC4xMi03LjUxNSAxMS44MjktMTEuMzIxIDIuMTA2LTIu'
    b'MjA0IDkuNzI0LTcuMjEzIDQuNTEyLTkuMDE3LTguODIyLTMuMDA2LTExLjEyOCAxNC40Mjct'
    b'MTYuMzQxIDIwLjIzOHYuMXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMjYzLjY1NyAyMTcuODA5YzMuMjA4LTE0LjYyOS01'
    b'LjgxNC0xNy40MzQtOC4yMjEtMjguNzU1LTIuNDA1LTExLjMyMS0uNC0yMC44MzkgMTUuMjM4'
    b'LTIwLjYzOSAzMC4zNzggNC45MDkgNy43MiA0MS41NzctNy4wMTcgNDkuMzk0eiIvPjxwYXRo'
    b'IGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0y'
    b'NjkuNjczIDIwNi42ODdjMy4xMDgtNS43MSAxLjcwNS0xMC45MiAyLjIwNS0xNi4xMjkuMzAx'
    b'LTMuMDA2IDMuMTA3LTExLjcyMy0yLjEwNC05LjgxOC04LjcyMiAzLjEwNS4zIDE4LjIzMy0u'
    b'MTAxIDI2LjA0OHYtLjEwMXpNMjQyLjYwNSAxODguNzUzYzcuNjIxLTEyLjkyNC0uMDk5LTE4'
    b'LjQzNCAxLjEwNC0yOS45NTYgMS4yMDItMTEuNTIxIDYuMTE1LTIwLjAzOCAyMC44NTItMTQu'
    b'OTI4IDI3LjQ2NyAxNC4wMjctNS41MTUgNDEuOTc5LTIxLjk1NiA0NC44ODR6Ii8+PHBhdGgg'
    b'ZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTI1'
    b'MS43MjggMTgwLjAzN2M0LjcxMS00LjQwOSA1LjAxMi05LjkxOCA3LjExNy0xNC43MjggMS4y'
    b'MDQtMi44MDUgNi42MTYtMTAuMTE5IDEuMDAzLTEwLjAxOS05LjMyMy4zMDEtNS4zMTMgMTcu'
    b'NDMyLTguMTIgMjQuNjQ3di4xek0yNzUuNjg4IDIwMy4xOGM4LjMyMS0xMi40MjIgMS4wMDIt'
    b'MTguMzMzIDIuODA2LTI5Ljc1NSAxLjgwNy0xMS40MjEgNy4zMi0xOS42MzcgMjEuNzU1LTEz'
    b'LjYyNiAyNi41NjYgMTUuNjMtOC4wMiA0MS41NzgtMjQuNTYxIDQzLjQ4MXYtLjF6Ii8+PHBh'
    b'dGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0i'
    b'TTI4NS4yMTEgMTk0Ljk2NWM1LjAxMi00LjIwOCA1LjYxNS05LjYxOCA4LjAyMS0xNC4yMjYg'
    b'MS40MDQtMi43MDYgNy4yMTgtOS43MTkgMS42MDQtOS45MTktOS4zMjQtLjIwMS02LjQxNiAx'
    b'Ny4xMzItOS42MjUgMjQuMTQ1ek0yNzMuMjgxIDE4OC4zNTJjMy41MS0xNC42MjcgMTIuODMz'
    b'LTEzLjIyNSAxOS45NS0yMi4zNDEgNy4xMTktOS4xMTcgOS40MjQtMTguNjM1LTQuODEyLTI1'
    b'LjI0Ny0yOS40NzQtOC44MTYtMjUuMDYyIDM0LjA2NC0xNS4xMzggNDcuNTg4eiIvPjxwYXRo'
    b'IGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0y'
    b'NzIuNzgxIDE3NS43MjljLS4zMDEtNi41MTIgMy4yMDctMTAuNjIgNS4wMTItMTUuNTI5IDEu'
    b'MDAyLTIuODA1IDIuMzA2LTExLjkyMSA2LjExNi03LjkxNSA2LjUxNiA2LjYxMy04LjIyMSAx'
    b'Ni4zMy0xMS4xMjggMjMuNDQ0eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0yNTMuMjMyIDE2OC4xMTRjOS4yMjItMTEuODIy'
    b'IDE3LjE0Mi02LjcxMiAyNy40NjgtMTIuMDIyIDEwLjMyNi01LjMxIDE2LjM0MS0xMy4wMjQg'
    b'Ni4yMTYtMjQuOTQ2LTIzLjE1Ny0yMC4zMzktMzYuOTkzIDIwLjUzOC0zMy41ODQgMzYuOTY5'
    b'bC0uMS0uMDAxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjUiIGQ9Ik0yNTguMDQ0IDE1Ni4zOTRjMi40MDYtNi4wMTIgNy4zMTgtOC4z'
    b'MTYgMTEuMDI4LTEyLjAyMyAyLjEwNC0yLjEwNCA3LjAxNy05LjkxOCA4LjkyMi00LjYwOSAz'
    b'LjEwNyA4LjcxNy0xNC4yMzUgMTEuNDIyLTE5Ljk1IDE2LjczMXYtLjA5OXoiLz48cGF0aCBm'
    b'aWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMjc5'
    b'LjY5NyAxNzAuNTJjNy45MjEtMTIuNzI1IDE2LjM0MS04LjQxNyAyNi4wNjYtMTQuODI5IDku'
    b'NzI1LTYuNDExIDE0LjgzNy0xNC43MjcgMy41MDktMjUuNDQ3LTI1LjE2My0xNy43MzQtMzQu'
    b'NTg4IDI0LjM0NS0yOS41NzUgNDAuMjc2eiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0yODMuMjA2IDE1OC4zOTZjMS44MDQt'
    b'Ni4yMTEgNi40MTYtOS4wMTcgOS43MjUtMTMuMTI1IDEuOTA1LTIuNDA0IDUuOTE1LTEwLjUy'
    b'IDguNDIxLTUuNjEgNC4wMSA4LjQxNy0xMy4wMzIgMTIuODI0LTE4LjA0NSAxOC43MzVoLS4x'
    b'MDF6TTIxNC43MzYgMTIyLjIyOWMxMy43MzQgNi4xMTEgMTguMjQ2LTIuMjA1IDI5Ljg3NC0y'
    b'LjMwNCAxMS42My0uMTAxIDIwLjU1MiAzLjgwNyAxNy4yNDQgMTkuMDM1LTEwLjkyOCAyOC44'
    b'NTQtNDIuMzA2LS43MDEtNDcuMDE4LTE2LjczMWgtLjF6Ii8+PHBhdGggZmlsbD0iI0ZGRDcw'
    b'MCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTIyNC40NiAxMzAuMjQ0'
    b'YzQuOTEyIDQuMjA4IDEwLjQyNiAzLjkwNyAxNS40MzggNS40MSAyLjkwNy45MDEgMTAuODI4'
    b'IDUuNDEgMTAuMDI1LS4xLTEuMzAzLTkuMTE3LTE3Ljk0NC0zLjMwNi0yNS40NjMtNS4zMXoi'
    b'Lz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41'
    b'IiBkPSJNMjM1Ljg4NyA5OC4zODRjOS4xMjQgMTEuOTIzIDE3LjA0MyA2LjgxMyAyNy4yNjkg'
    b'MTIuMzIzIDEwLjIyNiA1LjUxIDE2LjI0MSAxMy4yMjQgNS45MTUgMjQuOTQ2LTIzLjM1OCAy'
    b'MC4wMzctMzYuNzkyLTIwLjkzOS0zMy4yODQtMzcuMjdoLjF6Ii8+PHBhdGggZmlsbD0iI0ZG'
    b'RDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTI0MC42IDExMC4x'
    b'MDZjMi4zMDYgNi4xMTEgNy4zMTkgOC4zMTUgMTAuOTI4IDEyLjEyMyAyLjEwNSAyLjIwNCA2'
    b'LjkxNyA5LjkxOCA4LjgyMiA0LjcwOCAzLjIwOC04LjcxNi0xNC4xMzUtMTEuNTIxLTE5Ljc1'
    b'LTE2LjkzMnYuMTAxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjUiIGQ9Ik0yNDQuMjA5IDEzMC4yNDRjMTQuNjM2LTMuMzA2IDE3LjU0'
    b'NCA1LjYxMSAyOC44NzEgOC4wMTYgMTEuMzI5IDIuNDA0IDIwLjk1My4yMDEgMjAuNTUyLTE1'
    b'LjQyOS01LjExMy0zMC4zNTgtNDEuNzA0LTcuNDE0LTQ5LjQyMyA3LjQxM3oiLz48cGF0aCBm'
    b'aWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMjU1'
    b'LjIzNyAxMjQuMjMyYzUuNzE0LTMuMjA3IDEwLjkyNy0xLjgwNCAxNi4xNC0yLjQwNSAzLjAw'
    b'OC0uMyAxMS43MjktMy4yMDYgOS44MjQgMi4wMDQtMy4xMDggOC44MTYtMTguMjQ2LS4xMDEt'
    b'MjYuMDY1LjRoLjEwMXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iMS41IiBkPSJNMjM2LjY5MSAxMDcuNjAyYzE1LjAzOCAwIDE1Ljg0IDku'
    b'MzE3IDI2LjM2NiAxNC4xMjYgMTAuNTI2IDQuODA5IDIwLjM1MSA0LjgwOSAyMy40NTgtMTAu'
    b'NTIgMS43MDYtMzAuNzU4LTM4Ljk5Ny0xNi40MzEtNDkuODIzLTMuNzA3di4xMDFoLS4wMDF6'
    b'Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEu'
    b'NSIgZD0iTTI0OC44MjEgMTA0LjA5NWM2LjIxNi0xLjgwMyAxMS4wMjguNzAyIDE2LjM0MSAx'
    b'LjMwMyAzLjAwOC4zIDEyLjEzMS0uNjAyIDkuMTIyIDQuMTA3LTQuOTEyIDcuOTE1LTE3Ljc0'
    b'NC00LjIwOC0yNS40NjMtNS40MXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMjYzLjY1NyA4OS4xNjdjOS43MjUgMTEuNDIx'
    b'IDMuMTA4IDE4LjEzNCA2LjMxNSAyOS4yNTUgMy4yMDkgMTEuMTIgOS41MjQgMTguNjM0IDIz'
    b'LjE1OCAxMS4wMjEgMjQuNTYzLTE4LjYzNi0xMi44My00MC4zNzYtMjkuNDczLTQwLjI3Nnoi'
    b'Lz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41'
    b'IiBkPSJNMzAzLjM1NyA2MS43MTZjLjQgMTUuMDI4IDkuODI0IDE1LjYyOSAxNC44MzcgMjUu'
    b'OTQ4czUuMzEzIDIwLjIzOC05LjkyNSAyMy42NDVjLTMwLjY3NyAyLjUwNC0xNy40NDMtMzgu'
    b'NTczLTQuOTEyLTQ5LjY5NHYuMTAxeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0zMDAuMjQ5IDczLjkzOGMtMS43MDQgNi4z'
    b'MTIgMS4wMDMgMTEuMDIxIDEuNzA0IDE2LjIzLjQwMiAzLjAwNi0uMiAxMi4xMjMgNC40MTEg'
    b'OS4wMTcgNy43Mi01LjEwOS00LjYxMS0xNy42MzMtNi4wMTQtMjUuMjQ4aC0uMTAxeiIvPjxw'
    b'YXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9'
    b'Ik0zMzUuMTM2IDY3LjYyN2MtNi42MTggMTMuNDI0IDEuNDAzIDE4LjMzNCAxLjEwMyAyOS44'
    b'NTUtLjMwMiAxMS41MjEtNC43MTEgMjAuMzM4LTE5Ljc1IDE2LjMzMS0yOC4zNy0xMi4wMjIg'
    b'Mi41MDYtNDIuMjc5IDE4Ljc0Ny00Ni4yODdsLS4xLjEwMXoiLz48cGF0aCBmaWxsPSIjRkZE'
    b'NzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJNMzI2LjcxNiA3Ny4w'
    b'NDRjLTQuNDExIDQuODA5LTQuMzExIDEwLjIxOS02LjAxNiAxNS4xMjktMS4wMDIgMi44MDQt'
    b'NS44MTMgMTAuNjItLjMwMSAxMC4wMTkgOS4yMjQtMS4wMDIgNC4xMS0xNy44MzMgNi40MTYt'
    b'MjUuMjQ4aC0uMXYuMXoiLz48cGF0aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0'
    b'cm9rZS13aWR0aD0iMS41IiBkPSJNMzM3LjI0MSAxNDcuNTc2Yy00LjExLTE0LjQyNi0xMy4z'
    b'MzMtMTIuNjI0LTIwLjg1Mi0yMS40NC03LjUyLTguODE2LTEwLjIyNi0xOC4yMzQgMy43MS0y'
    b'NS40NDcgMjkuMDczLTEwLjAyIDI2LjQ2NiAzMi45NjEgMTcuMTQyIDQ2Ljg4N3oiLz48cGF0'
    b'aCBmaWxsPSIjRkZENzAwIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJN'
    b'MzM3LjI0MSAxMzQuOTUyYy4xMDEtNi41MTItMy43MDktMTAuNDE5LTUuNzEzLTE1LjMyOS0x'
    b'LjEwNC0yLjgwNS0yLjgwOC0xMS44MjItNi41MTgtNy43MTMtNi4yMTYgNi45MTIgOC45MjMg'
    b'MTUuOTMgMTIuMTMxIDIyLjk0MmwuMS4xek0yNzEuODc4IDE0OS41OGM5LjYyNC0xMS41MjEg'
    b'MTcuMzQzLTYuMDExIDI3Ljg3LTExLjAyMSAxMC41MjctNS4wMDkgMTYuODQyLTEyLjQyMyA3'
    b'LjExOS0yNC42NDYtMjIuNDU4LTIxLjEzOS0zNy42OTYgMTkuMjM2LTM0Ljk4OSAzNS42Njd6'
    b'Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEu'
    b'NSIgZD0iTTI3Ni45OSAxMzguMTU4YzIuNjA3LTUuOTExIDcuNjIxLTguMDE0IDExLjUyOS0x'
    b'MS42MjIgMi4yMDYtMi4xMDQgNy40MTktOS42MTggOS4wMjMtNC4zMDggMi44MDggOC44MTct'
    b'MTQuNjM2IDEwLjkyMS0yMC41NTIgMTUuOTN6Ii8+PHBhdGggZmlsbD0iI0ZGRDcwMCIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTMwMi43NTYgMTU5LjA5OGM0LjEx'
    b'LTE0LjQyOCAxMy4zMzQtMTIuNjI0IDIwLjg1Mi0yMS40NCA3LjUyLTguODE3IDEwLjIyNS0x'
    b'OC4yMzQtMy42MDgtMjUuMzQ4LTI5LjA3My0xMC4wMTktMjYuNDY3IDMyLjk2MS0xNy4xNDMg'
    b'NDYuODg4bC0uMTAxLS4xeiIvPjxwYXRoIGZpbGw9IiNGRkQ3MDAiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0zMDIuNzU2IDE0Ni40NzVjLS4xLTYuNTEzIDMuNzA4'
    b'LTEwLjQyIDUuNzEzLTE1LjMyOSAxLjEwNS0yLjgwNiAyLjgwOS0xMS44MjMgNi41MTktNy43'
    b'MTUgNi4yMTQgNi45MTMtOC45MjMgMTUuOTI5LTEyLjEzMSAyMi45NDNsLS4xMDEuMTAxeiIv'
    b'Pjwvc3ZnPg==', 'RU_LIP')

RU_LIP = b64_RU_LIP
index.append("RU_LIP")
index.append("Russia Lipetskaya oblast")
catalog["RU_LIP"] = RU_LIP
catalog["Russia Lipetskaya oblast"] = RU_LIP
country["Russia Lipetskaya oblast"] = ('RU_LIP', '', 1)
lookup["RU_LIP"] = ('RU_LIP', '', 'Russia Lipetskaya oblast', 1)
lookup["Lipetsk"] = ('RU_LIP', '', 'Russia Lipetskaya oblast', 1)
lookup["Russia Lipetskaya oblast"] = ('RU_LIP', '', 'Russia Lipetskaya oblast', 1)
details["RU_LIP"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Lipetsk"}
regional["RU_LIP"] = ('RU_LIP', 'Russia Lipetskaya oblast', 1)
regional["Russia Lipetskaya oblast"] = ('RU_LIP', 'Russia Lipetskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_MAG = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iOTAw'
    b'IiBoZWlnaHQ9IjYwMCIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4K'
    b'IDxkZWZzPgogIDxsaW5lYXJHcmFkaWVudCBpZD0iYiI+CiAgIDxzdG9wIHN0b3AtY29sb3I9'
    b'IiNjMGMwYzAiIG9mZnNldD0iMCIvPgogICA8c3RvcCBzdG9wLWNvbG9yPSIjZjdmN2Y3IiBv'
    b'ZmZzZXQ9Ii41Ii8+CiAgIDxzdG9wIHN0b3AtY29sb3I9IiNjMGMwYzAiIG9mZnNldD0iMSIv'
    b'PgogIDwvbGluZWFyR3JhZGllbnQ+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJhIj4KICAgPHN0'
    b'b3Agc3RvcC1jb2xvcj0iI2Q0YWYzOCIgb2Zmc2V0PSIwIi8+CiAgIDxzdG9wIHN0b3AtY29s'
    b'b3I9IiNmZmQ5MGQiIG9mZnNldD0iLjUiLz4KICAgPHN0b3Agc3RvcC1jb2xvcj0iI2Q0YWYz'
    b'OCIgb2Zmc2V0PSIxIi8+CiAgPC9saW5lYXJHcmFkaWVudD4KICA8bGluZWFyR3JhZGllbnQg'
    b'aWQ9Im4iIHgxPSIyNS43MTkiIHgyPSIxMDQuODQiIHkxPSIyNTEuNjkiIHkyPSIzNzMuNjYi'
    b'IGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoMS4zMjY4IDAgMCAxLjMyNjggLTc0NS42NiAt'
    b'MzAyLjM4KSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiIHhsaW5rOmhyZWY9IiNi'
    b'Ii8+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJtIiB4MT0iMzkuMzQ2IiB4Mj0iMTMyLjE1IiB5'
    b'MT0iMjIxLjg2IiB5Mj0iMTc0IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KDEuMzI2OCAw'
    b'IDAgMS4zMjY4IC03NDUuNjYgLTMwMi4zOCkiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9u'
    b'VXNlIiB4bGluazpocmVmPSIjYiIvPgogIDxsaW5lYXJHcmFkaWVudCBpZD0ibCIgeDE9IjIy'
    b'OC44OCIgeDI9IjMxNC42OCIgeTE9IjE2OS4xNiIgeTI9IjIyNy41IiBncmFkaWVudFRyYW5z'
    b'Zm9ybT0ibWF0cml4KDEuMzI2OCAwIDAgMS4zMjY4IC03NDUuNjYgLTMwMi4zOCkiIGdyYWRp'
    b'ZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIiB4bGluazpocmVmPSIjYSIvPgogIDxsaW5lYXJH'
    b'cmFkaWVudCBpZD0iayIgeDE9Ii03NTkuMTkiIHgyPSItNzUxLjgiIHkxPSIxMDguNzgiIHky'
    b'PSIxMDguNzgiIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoMS4zMjY4IDAgMCAxLjMyNjgg'
    b'MTQ5My42IDk0Ljc0NSkiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIiB4bGluazpo'
    b'cmVmPSIjYiIvPgogIDxsaW5lYXJHcmFkaWVudCBpZD0iaiIgeDE9Ii0xMjQuMTgiIHgyPSIt'
    b'MTE2Ljc4IiB5MT0iNzYxLjk1IiB5Mj0iNzYxLjk1IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0'
    b'cml4KDEuMzI2OCAwIDAgMS4zMjY4IC01OS42MTEgLTE0OTUuNCkiIGdyYWRpZW50VW5pdHM9'
    b'InVzZXJTcGFjZU9uVXNlIiB4bGluazpocmVmPSIjYiIvPgogIDxsaW5lYXJHcmFkaWVudCBp'
    b'ZD0iaSIgeDE9IjQ3OS4xMiIgeDI9IjUwOS4wMyIgeTE9IjU1Ny41NCIgeTI9IjU5MC45OCIg'
    b'Z3JhZGllbnRUcmFuc2Zvcm09Im1hdHJpeCgxLjMyNjggMCAwIDEuMzI2OCAtMTExMS40IC0x'
    b'MDAyLjMpIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeGxpbms6aHJlZj0iI2Ei'
    b'Lz4KICA8bGluZWFyR3JhZGllbnQgaWQ9ImgiIHgxPSI0MzIuNTUiIHgyPSI0NzYuMTEiIHkx'
    b'PSI2MDAuNSIgeTI9IjYwMC41IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KDEuMzI2OCAw'
    b'IDAgMS4zMjY4IC0xMTExLjQgLTEwMDIuMykiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9u'
    b'VXNlIiB4bGluazpocmVmPSIjYiIvPgogIDxsaW5lYXJHcmFkaWVudCBpZD0iZyIgeDE9IjM5'
    b'MC4xMyIgeDI9IjQ1MC44NiIgeTE9IjYwOC41MSIgeTI9IjU1Mi41MyIgZ3JhZGllbnRUcmFu'
    b'c2Zvcm09Im1hdHJpeCgxLjMyNjggMCAwIDEuMzI2OCAtMTExMS40IC0xMDAyLjMpIiBncmFk'
    b'aWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgeGxpbms6aHJlZj0iI2EiLz4KICA8bGluZWFy'
    b'R3JhZGllbnQgaWQ9ImYiIHgxPSI0NTYuNjQiIHgyPSI1MDYuMTgiIHkxPSI2MTYuNjkiIHky'
    b'PSI2MTYuNjkiIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoMS4zMjY4IDAgMCAxLjMyNjgg'
    b'LTExMTMuMSAtMTAwMi4zKSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiIHhsaW5r'
    b'OmhyZWY9IiNhIi8+CiAgPGxpbmVhckdyYWRpZW50IGlkPSJlIiB4MT0iNDA1LjA0IiB4Mj0i'
    b'NDU0LjU4IiB5MT0iNjE2LjU3IiB5Mj0iNjE2LjU3IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0'
    b'cml4KDEuMzI2OCAwIDAgMS4zMjY4IC0xMTEzLjEgLTEwMDIuMykiIGdyYWRpZW50VW5pdHM9'
    b'InVzZXJTcGFjZU9uVXNlIiB4bGluazpocmVmPSIjYSIvPgogIDxsaW5lYXJHcmFkaWVudCBp'
    b'ZD0iZCIgeDE9IjIyOC44OCIgeDI9IjMxNC42OCIgeTE9IjE2OS4xNiIgeTI9IjIyNy41IiBn'
    b'cmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KDEuMzI2OCAwIDAgMS4zMjY4IC03NDUuNjYgLTIw'
    b'NC4yOCkiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIiB4bGluazpocmVmPSIjYSIv'
    b'PgogIDxsaW5lYXJHcmFkaWVudCBpZD0iYyIgeDE9IjIyOC44OCIgeDI9IjMxNC42OCIgeTE9'
    b'IjE2OS4xNiIgeTI9IjIyNy41IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KDEuMzI2OCAw'
    b'IDAgMS4zMjY4IC03NDUuNjYgLTEwNi4xNykiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9u'
    b'VXNlIiB4bGluazpocmVmPSIjYSIvPgogPC9kZWZzPgogPGcgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoMTk5LjQ1IDM4OS40NykiPgogIDxyZWN0IHRyYW5zZm9ybT0idHJhbnNsYXRlKC0xOTku'
    b'NDUgLTM4OS40NykiIHdpZHRoPSI5MDAiIGhlaWdodD0iNjAwIiBmaWxsPSIjYzQyNzMwIi8+'
    b'CiAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTE5OS40NSAtMzg5LjQ3KSIgZD0ibTky'
    b'LjY4OCA0NTBjLTI4LjM2OSAxMS42NDEtNjUuODc4IDI0LjQwNC05Mi42ODggMTYuNDA2djEz'
    b'My41OWg5MDB2LTE0My4wNmMtMzEuMzEyIDkuNzU2NS02My4wMTkgMTguMDg1LTEwMy44MS02'
    b'LjkzNzUtNDQuNDM5IDE3LjkwNC04Ni4zOTQgMjkuNDgtMTEyLjQxIDAtMzguNDAxIDE0LjQy'
    b'Mi03Ny4wNjcgMjQuOTYxLTExOC4wOSAwLTM4LjA4OCAxNS42MjktNzYuMjg4IDI3LjY0LTEx'
    b'NS42OSAwLTM5LjM2NCAxMC42NC03MC4wMjQgMzEuMTM0LTEyMC43OCAwLTM0LjU0IDE2Ljg0'
    b'NC04OS45NTYgMjkuNDgtMTE1Ljk3IDAtMzguNDAxIDE0LjQyMi03Ny40MTUgMzQuODYtMTIw'
    b'LjU2IDB6IiBmaWxsPSIjMmU0MThhIi8+CiAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUo'
    b'LTE5OS40NSAtMzg5LjQ3KSIgZD0ibTk0LjgxMiA1MzQuMTljLTI5LjExOCAxMS45NDgtNjcu'
    b'ODkxIDI1LjA2OS05NC44MTIgMTUuNzE5djIwLjg0NGMyNC4yOTEgMC41MTU0MiA1Mi45NTMt'
    b'OS41NjQ5IDc1LjcxOS0xOC45MDYgNDMuMTQ4IDM0Ljg2IDgyLjE2MiAxNC40MjIgMTIwLjU2'
    b'IDAgMjYuMDEyIDI5LjQ4IDgxLjQyOSAxNi44NDQgMTE1Ljk3IDAgNTAuNzU3IDMxLjEzNCA4'
    b'MS40MTcgMTAuNjQgMTIwLjc4IDAgMzkuMzk5IDI3LjY0IDc3LjU5OSAxNS42MjkgMTE1LjY5'
    b'IDAgNDEuMDI2IDI0Ljk2MSA3OS42OTMgMTQuNDIyIDExOC4wOSAwIDI2LjAxMiAyOS40OCA2'
    b'Ny45NjcgMTcuOTA0IDExMi40MSAwIDQ4LjE1MyAyOS41MzcgODMuNjU1IDEyLjYxOCAxMjAu'
    b'NzggMS43MTg4di0xMS43ODFjLTMwLjYyNiA5LjQ1NjgtNjEuODE2IDE2Ljg2My0xMDEuNjkt'
    b'Ny41OTM4LTQ0LjQzOSAxNy45MDQtODYuMzk0IDI5LjQ4LTExMi40MSAwLTM4LjQwMSAxNC40'
    b'MjItNzcuMDY3IDI0Ljk2MS0xMTguMDkgMC0zOC4wODggMTUuNjI5LTc2LjI4OCAyNy42NC0x'
    b'MTUuNjkgMC0zOS4zNjQgMTAuNjQtNzAuMDI0IDMxLjEzNC0xMjAuNzggMC0zNC41NCAxNi44'
    b'NDQtODkuOTU2IDI5LjQ4LTExNS45NyAwLTM4LjQwMSAxNC40MjItNzcuNDE1IDM0Ljg2LTEy'
    b'MC41NiAwem0tMi4xMjUtNTUuMTg4Yy0yOC4zNjkgMTEuNjQxLTY1Ljg3OCAyNC40MDQtOTIu'
    b'Njg4IDE2LjQwNnYyMC4xODhjMjMuODI0LTAuMDg3NyA1MS40ODktOS44Njc0IDczLjU5NC0x'
    b'OC45MzggNDMuMTQ4IDM0Ljg2IDgyLjE2MiAxNC40MjIgMTIwLjU2IDAgMjYuMDEyIDI5LjQ4'
    b'IDgxLjQyOSAxNi44NDQgMTE1Ljk3IDAgNTAuNzU3IDMxLjEzNCA4MS40MTcgMTAuNjQgMTIw'
    b'Ljc4IDAgMzkuMzk5IDI3LjY0IDc3LjU5OSAxNS42MjkgMTE1LjY5IDAgNDEuMDI2IDI0Ljk2'
    b'MSA3OS42OTMgMTQuNDIyIDExOC4wOSAwIDI2LjAxMiAyOS40OCA2Ny45NjcgMTcuOTA0IDEx'
    b'Mi40MSAwIDQ5LjA3NiAzMC4xMDMgODQuOTk5IDExLjk0NyAxMjIuOTEgMS4wOTM4di0xMS44'
    b'MTJjLTMxLjMxMiA5Ljc1NjUtNjMuMDE5IDE4LjA4NS0xMDMuODEtNi45Mzc1LTQ0LjQzOSAx'
    b'Ny45MDQtODYuMzk0IDI5LjQ4LTExMi40MSAwLTM4LjQwMSAxNC40MjItNzcuMDY3IDI0Ljk2'
    b'MS0xMTguMDkgMC0zOC4wODggMTUuNjI5LTc2LjI4OCAyNy42NC0xMTUuNjkgMC0zOS4zNjQg'
    b'MTAuNjQtNzAuMDI0IDMxLjEzNC0xMjAuNzggMC0zNC41NCAxNi44NDQtODkuOTU2IDI5LjQ4'
    b'LTExNS45NyAwLTM4LjQwMSAxNC40MjItNzcuNDE1IDM0Ljg2LTEyMC41NiAweiIgZmlsbD0i'
    b'I2ZmZiIvPgogIDxnIHRyYW5zZm9ybT0ibWF0cml4KC40MTc0IDAgMCAuNDE3NCAxNTguMzUg'
    b'LTIxNC44NykiPgogICA8cGF0aCB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtNzQ5LjM5IC0zMDUu'
    b'NzgpIiBkPSJtNDY5LjIyIDYuODEyNWgtNDU2Ljg4bDIyOC40NCAyNjMuNzggMjI4LjQ0LTI2'
    b'My43OHoiIGZpbGw9IiNjNDI3MzAiLz4KICAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUo'
    b'LTc0OS4zOSAtMzA1Ljc4KSIgZD0ibTI0NS4yNSA1NzMuMDNjMi42NjA1LTQuNjEzNiA1Ljg1'
    b'MTEtOC44NDc2IDEwLTEyLjM3NSA5LjQyMDUtOC4wMDkzIDIzLjAwNy0xMi41MzEgNDIuNTYy'
    b'LTEyLjUzMWgxNTAuMjJjMTAuNjMyIDAgMTcuMjA1LTEuMzEyMyAyMC45MzgtNC43MTg4IDMu'
    b'NzMyOS0zLjQwNjUgNS43NS05Ljc3NDMgNS43NS0yMS45Njl2LTUwNy4xOWwtMjI5LjQ3IDI2'
    b'NC45MXYyOTMuODh6IiBmaWxsPSIjMTgzODgzIi8+CiAgIDxwYXRoIHRyYW5zZm9ybT0idHJh'
    b'bnNsYXRlKC03NDkuMzkgLTMwNS43OCkiIGQ9Im02LjgxMjUgMTQuMjE5djUwNy4yMmMwIDEy'
    b'LjE5NiAyLjA1ODkgMTguNTY1IDUuNzgxMiAyMS45NjkgMy43MjIzIDMuNDA0MiAxMC4yNDMg'
    b'NC43MTg4IDIwLjg3NSA0LjcxODhoMTUwLjIyYzE5LjU1NSAwIDMzLjE0MiA0LjUyMiA0Mi41'
    b'NjIgMTIuNTMxIDQuMTMwOCAzLjUxMiA3LjMxNDUgNy43MjMgOS45Njg4IDEyLjMxMmwwLjAz'
    b'MTI1LTI5My44NC0yMjkuNDQtMjY0LjkxeiIgZmlsbD0iIzAwOTNkZCIvPgogICA8cGF0aCB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSgtNzQ5LjM5IC0zMDUuNzgpIiBkPSJtNi44MTI1IDE0LjIx'
    b'OSAyMjkuNDQgMjY0LjkxLTAuMDMxMiAyOTMuODRjMS43MjEyIDIuOTc2MyAzLjI1NTMgNi4w'
    b'NzU2IDQuNTMxMiA5LjM3NSAxLjI2NzQtMy4yNzcgMi43OTM4LTYuMzUzOCA0LjUtOS4zMTI1'
    b'di0yOTMuODhsMjI5LjQ3LTI2NC45MXYtNy40Mzc1aC01LjVsLTIyOC40NCAyNjMuNzgtMjI4'
    b'LjQ0LTI2My43OGgtNS41MzEydjcuNDA2MnoiIGZpbGw9IiNkNGFmMzgiLz4KICAgPHBhdGgg'
    b'ZD0ibS03NDIuNTUtMzA1LjMzLTYuODQxNCA1Ljg4NzcgMjM2LjI2IDI3Mi43OC0wLjA0MTQg'
    b'MzE0LjA4aDkuMDM4OXYtMzE0LjA0bDIzNi4zLTI3Mi44My02Ljg0MTQtNS44ODc3LTIzMy45'
    b'MyAyNzAuMTMtMjMzLjkzLTI3MC4xM3oiIGZpbGw9IiNmZmYiLz4KICAgPHBhdGggZD0ibS03'
    b'NDkuMzgtMzA1Ljc4djUyMS40NGMwIDEyLjk0MyAyLjA5NzggMjEuNjMgNy45NjA5IDI2Ljk5'
    b'MiA1Ljg2MzEgNS4zNjIgMTQuMzUyIDYuNTA5NyAyNS41IDYuNTA5N2gxNTAuMjJjMTguNTIg'
    b'MCAzMC4xOTkgNC4xNDg0IDM4LjE0NiAxMC45MDVzMTIuNDM4IDE2LjQyMSAxNS42MzIgMjgu'
    b'MjM2bDMuMjc1NiAxMi4xNDkgMy4yNzU2LTEyLjE0OWMzLjE5MzYtMTEuODE1IDcuNjg0OC0y'
    b'MS40OCAxNS42MzItMjguMjM2czE5LjYyNi0xMC45MDUgMzguMTQ2LTEwLjkwNWgxNTAuMjJj'
    b'MTEuMTQ4IDAgMTkuNjI2LTEuMTQ5OSAyNS41LTYuNTA5N3M4LjAwMjQtMTQuMDQ4IDguMDAy'
    b'NC0yNi45OTJ2LTUyMS40NHptNi43OTk5IDYuNzk5OWg0NjcuOTF2NTE0LjY0YzAgMTIuMTk0'
    b'LTIuMDMwNSAxOC41NjktNS43NjM0IDIxLjk3NS0zLjczMjkgMy40MDY1LTEwLjMwNyA0Ljcy'
    b'NjgtMjAuOTM5IDQuNzI2OGgtMTUwLjIyYy0xOS41NTUgMC0zMy4xMiA0LjUxMjUtNDIuNTQx'
    b'IDEyLjUyMi02LjgwOTUgNS43ODk1LTExLjI2OCAxMy4yOTgtMTQuNTEyIDIxLjY4NS0zLjI0'
    b'MzYtOC4zODcxLTcuNzAyNS0xNS44OTYtMTQuNTEyLTIxLjY4NS05LjQyMDUtOC4wMDkzLTIy'
    b'Ljk4Ni0xMi41MjItNDIuNTQxLTEyLjUyMmgtMTUwLjIyYy0xMC42MzIgMC0xNy4xNzUtMS4z'
    b'MjI2LTIwLjg5Ny00LjcyNjgtMy43MjIzLTMuNDA0Mi01Ljc2MzMtOS43NzkxLTUuNzYzMy0y'
    b'MS45NzV6IiBmaWxsPSIjZDRhZjM4Ii8+CiAgIDxwYXRoIGQ9Im0tNTY4LjA4IDUwLjA5NC0w'
    b'Ljk5NTExIDEuMDc4LTIuNTcwNyAyNC41ODgtMjEuMzUzIDkuMTYzM2gyMC40bC0xLjI4NTQg'
    b'MTIuNTYzLTIyLjIyNCA4LjQ1ODUgMjEuMzEyLTZlLTUgLTEuMzY4MyAxMi45NzgtMjQuOTE5'
    b'IDguMDAyMyAyNC4wOSA3ZS01IC0zLjg5NzUgMzcuNDYyLTUuNjM5IDIyLjE2MmgzLjI3NTZs'
    b'MTUuMTc1LTExLjQwMiAxNS4xMzQgMTEuNDAyaDMuMzE3bC01LjUxNDYtMjIuMTYyLTQuMDIx'
    b'OS0zNy40NjIgMjQuMDktNmUtNSAtMjQuOTE5LTguMDAyMy0xLjM2ODMtMTIuOTc4IDIxLjM1'
    b'MyA3ZS01IC0yMi4yNjYtOC40NTg1LTEuMjg1NC0xMi41NjNoMjAuNDQxbC0yMS4zOTUtOS4x'
    b'NjMyLTIuNTcwNy0yNC41ODh6bTAgMTAuNjE1IDAuNzA0ODcgNi45MjQzaC0xLjQwOTd6bS0w'
    b'LjkxMjE4IDguOTE0NWgxLjgyNDRsMC41ODA0OCA1LjM0ODdoLTIuOTg1M3ptMC45MTIxOCA2'
    b'LjYzNDEgMS42NTg1IDAuNjYzNDEgMC43MDQ4NyA2LjU1MTFoLTQuNzI2OGwwLjcwNDg3LTYu'
    b'NTUxMXptLTMuNzczMSAxLjQ5MjctMC42MjE5NSA2LjIxOTRoLTE1LjEzNHptNy41NDYyIDAg'
    b'MTUuNzk3IDYuMjE5NGgtMTUuMTc1em0tNS40NzMxIDcuNzEyMWgzLjRsLTEuNyAyLjczNjZ6'
    b'bS0xLjA3OCAxLjk5MDIgMS42MTcgMi42NTM2LTIuMjgwNSAzLjY5MDJ6bTUuNTU2IDAgMC42'
    b'NjM0MSA2LjM0MzgtMi4yODA1LTMuNjkwMnptLTIuNzc4IDQuNTE5NSAyLjczNjYgNC40MzY1'
    b'LTIuNzM2Ni0wLjUzOTAyLTIuNzM2NiAwLjUzOTAyem0wIDUuNzIxOSAzLjk4MDQgMC45MTIx'
    b'OCAwLjY2MzQgNi40MjY4aC05LjI4NzdsMC42NjM0LTYuNDI2OHptLTYuMDEyMSAxLjY1ODUt'
    b'MC42MjE5NCA1LjY4MDRoLTE1LjY3M3ptMTIuMDI0IDAgMTYuMjk1IDUuNjgwNGgtMTUuNjcz'
    b'em0tOS45NTExIDYuNTkyNmg3Ljg3OGwtMy45MzkgNC4yNzA3em0tMC45OTUxMSAxLjg2NTgg'
    b'My42MDczIDMuODU2LTQuNDc4IDQuODkyNnptOS44NjgyIDAgMC40MTQ2MyA0LjEwNDggMC40'
    b'NTYwOSA0LjY0MzgtNC40NzgtNC44OTI2em0tNC45MzQxIDUuMzQ4NyA0LjMxMjIgNC42NDM4'
    b'LTQuMzEyMi0wLjkxMjE5LTQuMzEyMSAwLjkxMjE5em0wIDUuMDE3IDYuMTc4IDEuODI0NCAw'
    b'LjY2MzQxIDYuMDk1aC0xMy42ODNsMC42NjM0MS02LjA5NXptLTguMjUxMSAyLjQ0NjMtMC41'
    b'ODA0OCA1LjQ3MzFoLTE3LjkxMnptMTYuNTAyIDAgMTguNDkyIDUuNDczMWgtMTcuOTEyem0t'
    b'MTUuMTc1IDYuMzAyNGgxMy44NDlsMC42NjM0MSA2LjUwOTctNy41ODc3IDguNDU4NC03LjU4'
    b'NzctOC40OTk5em0tMC45NTM2NSA5LjA4MDQgNi41OTI2IDcuMzM4OS04LjMzNCA5LjI4Nzd6'
    b'bTE1Ljc1NiAwLjEyNDMyIDEuNyAxNi40NjEtOC4yMDk3LTkuMjA0OHptLTcuODM2NSA4Ljcw'
    b'NzIgOS45MDk2IDExLjA3MSAwLjg3MDcyIDguMTY4MmgtMjEuNjAybDAuODI5MjYtOC4wNDM4'
    b'em0tOC44NzMxIDIxLjIyOWgxNy42NjNsLTguODMxNiA2LjYzNDF6bS0yLjQ4NzggMC41ODA0'
    b'OCA5LjUzNjUgNy4xNzMxLTE0LjEzOSAxMC43OHptMjIuNjM5IDAgNC42MDI0IDE3Ljk1My0x'
    b'NC4xMzktMTAuNzh6IiBmaWxsPSIjZmZmIi8+CiAgIDxwYXRoIGQ9Im0tNzExLjU0IDMxLjU2'
    b'djM2LjY5NWw4NC40NiAxMjUuMTRoMjAuNTI0di04Ljg3MzFoLTkuNTc3OWwtNjYuNTg5LTk4'
    b'LjY0IDE1LjY3MyA1LjgwNDggNjAuNDk0IDkyLjgzNiA1LjgwNDggOC44NzMxaDEyLjE5di03'
    b'LjkxOTRoLTYuMzg1M2wtNTguMjU1LTg4LjY0OCAxOC42NTggNi45MjQzIDU0LjA2OCA4OS42'
    b'NDNoMTAuNDl2LTYuOTY1OGgtNS4wOTk5bC01MC43NTEtNzkuNDQzIDExLjU2OCA0LjI3MDcg'
    b'NDkuOTYzIDgyLjEzOGg2Ljc1ODV2LTYuMTM2NWgtNi4zODUzbC00NS42OTItNzkuMTUzdi0y'
    b'MS4xMDVsLTEwMS45Mi01NS40MzZ6IiBmaWxsPSJ1cmwoI24pIi8+CiAgIDxwYXRoIGQ9Im0t'
    b'NjE0LjI2IDExMS4yNXYtMjMuMTVsLTEyLjk0MS02LjgzMDZ2MjUuMTgyem0tNDAuNDMxLTQ0'
    b'LjQ5djI5LjVsMjAuMTY4IDcuNDc3N3YtMjYuMzMyem0tMzcuMTUxLTE5LjYwOXYzNS4zMzRs'
    b'MjQuNzk3IDkuMTkzN3YtMzEuNDR6IiBmaWxsPSIjY2ZjZmNkIi8+CiAgIDxwYXRoIGQ9Im0t'
    b'Njk2LjkgMzkuNTIxdjQuOTc1NmwtMS42MTcxLTAuODcwNzJoLTMuNjQ4N3YyNC40MjJsODAu'
    b'NzcgMTE2LjQ3aDUuMjY1OGwtNzUuNzExLTExMi4xMnYtMTkuNjEybDUuNzYzNCAzLjAyNjh2'
    b'LTUuNTk3NWwyMy41MDkgMTIuMzk3djIyLjQ3M2w2NS4zMDQgMTAwLjY3IDIuMzIxOS0wLjI5'
    b'MDI0LTU4LjI1NS04OC42NDggNi42MzQxIDIuNDQ2My04LjEyNjctMTAuODIydi0xNi4wNDZs'
    b'MS40OTI3IDAuODI5MjZ2LTUuNjM5bDIxLjUwMSAxMS4zMDZ2MjUuODg4bDUzLjU0NiA4MS42'
    b'MzhoMy4wNjgzbC01MC43NTEtNzkuNDQzIDUuNDczMSAyLjAzMTctNi44NDE0LTkuNjE5NHYt'
    b'MTIuNjA1aDEuMzY4M3YtNC43NjgybDEzLjIyNyA2Ljk1NDF2MTcuNDc3bDQ3LjQzMyA4MC44'
    b'MDJoMS4yNDM5bC00NS42OTItNzkuMTUzdi0yMS4xMDV6IiBmaWxsPSIjNjY2Ii8+CiAgIDxw'
    b'YXRoIGQ9Im0tNzExLjU0IDY4LjI1NXYxMjUuMTRoODQuNDZ6IiBmaWxsPSIjYzFjMWMxIi8+'
    b'CiAgIDxwYXRoIGQ9Im0tNjUyLjUxLTQwLjg5NiAxMC4xNzMtNS4xOTY0aDEzLjc4NGw0MS4w'
    b'MzYtMjMuNjkyczE1LjkxNC01LjQzNTcgMTkuNDQ1IDBjMi40MTc3IDMuNzIyNC01LjQxNDIg'
    b'MTIuMTY1LTUuNDE0MiAxMi4xNjVsLTQ0LjA3OCAyNS40NDktMjAuMjU2IDM1LjA4NS0xNy4y'
    b'ODEgOS45NzcyIDEwLjI5OS0yOC42NTgtMjQuOTMxIDEzLjcxNnMtNi41NjU4IDMuNTQwNy0x'
    b'MC41ODcgMi44NzA1Yy05Ljg5MTgtMS42NDg2LTE0LjcxOS0xMy4xNTQtMjYuMjE5LTIxLjAy'
    b'NiAwIDAtNC45NzIzIDUuMzU5MS05LjI5ODIgNy45NTc5IDAgMCAwLjI1MDE3LTcuNTg5NCA0'
    b'LjM1NTktMTAuODlsLTcuMzcxNi0yLjQ5NDlzNS42MTI0LTUuNzcyMiAxNC41NzYtNC41MjM1'
    b'YzkuMTIzNCAxLjI3MSAyMS40NTUgMTUuMzYyIDMzLjgxNiA4LjE5MTJsMjUuOTk0LTE1LjA3'
    b'OGMtMy42NTMxIDAuMzM2NTEtNS42NDYzLTIuMDkzNi04LjA0MTctMy44NTMzeiIgZmlsbD0i'
    b'dXJsKCNtKSIvPgogICA8cGF0aCBkPSJtLTQzMi4wMy03OS41ODhjMjUuNjUxIDMuMzM2IDMw'
    b'Ljc3OSA5Ljc1MjQgNDYuMjM2IDE3LjA4IDcuMDkyMy0wLjg2MzU3IDE2LjA4LTAuMzE1MDgg'
    b'MjEuMjc3IDIuODQ4MS0wLjcwMDIgMy44NTU4LTAuOTg0MzYgOC4wMDg3LTQuNjkxIDkuNzE3'
    b'MSA3LjcwNjYgNy41MzkxIDE1LjY3NSAxNC43NTEgMjMuMTIgMjIuNjE3IDEuMzc1MSAxLjQ1'
    b'MjktMS43MDMzIDIuMzYyOS0zLjM1MDcgMi44NDgxIDQuMTE4MSAyLjg3NjQgOC44MzY2IDUu'
    b'MzUyNSAxMS43MjcgOS4wNDY5IDE4LjkzMiAxLjQyNDEgMjQuNDYgNy4wMzY1IDI0LjQ2IDcu'
    b'MDM2NS05LjAwOTkgMS42ODQtMjAuMDYxIDguNDMzNi0yMC43NzQgMjEuNzgtMi44MjI1LTEu'
    b'NTI3NS04LjIzNS05LjUzMDItMTYuNDE4LTI0LjQ2LTIuOTU4NCAwLjg4NTI0LTUuMjY1IDEu'
    b'Nzg2Ny03LjQ1NTMgMC4wODM3Mi03LjM0MjEtNS43MDg0LTE1LjQ2My0xMC45NjItMjQuMDQx'
    b'LTE1LjMzIDAgMC0yLjQ1MDMgNC4xNzEzLTMuMTAxOSA4LjM3NjgtMC43MDk3OSA0LjU4MTQt'
    b'NS42NDcyLTQuNDMxNy02Ljk1MDMtMTEuODk1LTM5LjkzLTE5LjE4Mi00OS4wNzEtMzUuOTE1'
    b'LTUwLjc2My00My44MTEtMS40MjE2LTYuNjM0MSA2LjAzODctNi41NDg3IDEwLjcyNi01Ljkz'
    b'OTF6IiBmaWxsPSJ1cmwoI2wpIi8+CiAgIDxwYXRoIGQ9Im0tNDQyLjUzLTc4LjAyNmEwLjU5'
    b'NzEzIDAuNTk3MTMgMCAwIDAtMC4xMjQzMiAxLjExOTVjMi44NTIxIDEuNTMzOCA1LjEwOTEg'
    b'NC4zMjU4IDUuODg3NyA4LjI5MjZhMC41OTcxMyAwLjU5NzEzIDAgMSAwIDEuMTYxLTAuMjA3'
    b'MzJjLTAuODQyMTUtNC4yOTAzLTMuMzA1Mi03LjQ2MjItNi40NjgyLTkuMTYzM2EwLjU5NzEz'
    b'IDAuNTk3MTMgMCAwIDAtMC40NTYwOS0wLjA0MTR6Ii8+CiAgIDxwYXRoIGQ9Im0tNDI5LjY3'
    b'LTc2Ljc4M2MtMC44OTUxNiAwLTEuNjU4NSAwLjc2MzM2LTEuNjU4NSAxLjY1ODUgMCAwLjg5'
    b'NTE2IDAuNzYzMzYgMS42MTcxIDEuNjU4NSAxLjYxNzFzMS42MTctMC43MjE4OSAxLjYxNy0x'
    b'LjYxNzFjMC0wLjg5NTE2LTAuNzIxODktMS42NTg1LTEuNjE3LTEuNjU4NXoiLz4KICAgPHJl'
    b'Y3QgdHJhbnNmb3JtPSJtYXRyaXgoLS42OTg3NSwtLjcxNTM3LC0uNzE1MzcsLjY5ODc1LDAs'
    b'MCkiIHg9IjQ4Ni42MyIgeT0iMTY1LjA0IiB3aWR0aD0iOS4xNTM4IiBoZWlnaHQ9IjE0OC4w'
    b'NyIgZmlsbD0idXJsKCNrKSIvPgogICA8cmVjdCB0cmFuc2Zvcm09Im1hdHJpeCguNjk4NzUs'
    b'LS43MTUzNywuNzE1MzcsLjY5ODc1LDAsMCkiIHg9Ii0yMjQuMDQiIHk9Ii01NTUuMjkiIHdp'
    b'ZHRoPSI5LjE1MzkiIGhlaWdodD0iMTQxLjY3IiBmaWxsPSJ1cmwoI2opIi8+CiAgIDxwYXRo'
    b'IGQ9Im0tNDgxLjU2LTI1Ni44MyAzOS41MzUgNDAuNDc2YzEuODA3OCAwLjQ4NDM5IDQuNzc1'
    b'NSAwLjc2MTI2IDUuOTg4OS0xLjc5NGwtMy43OTQ2LTIzLjMzMy0yOC4wMjctMjguNjkzeiIg'
    b'ZmlsbD0idXJsKCNpKSIvPgogICA8cGF0aCBkPSJtLTUzMy44OS0yMTUuMjloNTAuNTQxbDcu'
    b'MjY2MiAxOS41MzhoLTY1LjA3M3oiIGZpbGw9InVybCgjaCkiLz4KICAgPHBhdGggZD0ibS01'
    b'NTAuNjktMjQyLjM3YzAuNTE2MTMgMy44Njc4IDMuMzAwMyA4LjA4ODcgMy4zMDAzIDguMDg4'
    b'N2wtNi4zOTYyIDYuNTQ4NGMwLjAyOTkgMC4wMjk5LTIuNzY2NS0xLjc1My0xMS4yNzUtNC43'
    b'ODczLTkuNzg4Mi0zLjQ5MDYtMjUuMDI4IDM2LjY1NC0yOC43NDIgMzcuNjIzLTEuOTM3Ny02'
    b'LjYyMDMgMTEuNzM4LTM4LjU1MyAyNS44MzUtNTEuNjcxIDE0LjQ1Mi0xMy40NDggMzguOTE1'
    b'LTI2LjQ4MSA1NC43MzktMjIuNjA2LTEyLjgxNCA4LjU2MTQtMzguMTkzIDIxLjMxOS0zNy40'
    b'NjEgMjYuODA0eiIgZmlsbD0idXJsKCNnKSIvPgogICA8cGF0aCBkPSJtLTQ5OS42Ni0xOTMu'
    b'ODFoNTAuNTQxbDcuMjY2MiAxOS41MzhoLTY1LjA3M3oiIGZpbGw9InVybCgjZikiLz4KICAg'
    b'PHBhdGggZD0ibS01NjguMTMtMTkzLjk3aDUwLjU0MWw3LjI2NjIgMTkuNTM4aC02NS4wNzN6'
    b'IiBmaWxsPSJ1cmwoI2UpIi8+CiAgIDxwYXRoIGQ9Im0tNTMyLjM4LTYzLjk3MSAxNy4wNDEg'
    b'MjMuNzE3aDYuNzE3bC0yMy41OTItMjMuNTkyLTAuMTY1ODUtMC4xMjQzMnptMjMuNzU4IDIz'
    b'LjcxNyAyMy41NTEtMjMuNTkyLTIzLjU1MSAxNi44NzV2Ni43MTd6bTAgMCAyMy43MTcgMjMu'
    b'NzE3LTE3LTIzLjcxN2gtNi43MTd6bTAgMC0yMy41OTIgMjMuNTkyIDIzLjU5Mi0xNi44NzV2'
    b'LTYuNzE3eiIgZmlsbD0iI2Q0YWYzOCIvPgogICA8cGF0aCBkPSJtLTUzMi4zNi0xNi41MTQg'
    b'MjMuNzM3LTIzLjczNy02LjcxNi0wLjAwMjd6bTQ3LjQ3NS0wLjAwNTMtMjMuNzM3LTIzLjcz'
    b'Ny0zZS0zIDYuNzE2em0tNWUtMyAtNDcuNDc1LTIzLjczNyAyMy43MzcgNi43MTYgMC4wMDI3'
    b'em0tNDcuNDcyIDAuMDAyNyAyMy43MzcgMjMuNzM3IDNlLTMgLTYuNzE2eiIgZmlsbD0iI2Zm'
    b'ZDcwMCIvPgogICA8cGF0aCBkPSJtLTUwOC42Mi04Ny4zOTctNi42NzU1IDQwLjQ2OCA2LjY3'
    b'NTUgNi42NzU1di00Ny4xNDN6bTAgNDcuMTQzaDQ3LjE0M2wtNDAuNDY4LTYuNjc1NS02LjY3'
    b'NTUgNi42NzU1em0wIDB2NDcuMTQzbDYuNjc1NS00MC40NjgtNi42NzU1LTYuNjc1NXptMCAw'
    b'aC00Ny4xNDNsNDAuNDY4IDYuNjc1NSA2LjY3NTUtNi42NzU1eiIgZmlsbD0iI2Q0YWYzOCIv'
    b'PgogICA8cGF0aCBkPSJtLTU1NS43NS00MC4yNTRoNDcuMTMzbC02LjY2NTYtNi42NjU2em00'
    b'Ny4xMzMgNDcuMTMzdi00Ny4xMzNsLTYuNjY1NiA2LjY2NTZ6bTQ3LjEzMy00Ny4xMzNoLTQ3'
    b'LjEzM2w2LjY2NTYgNi42NjU2em0tNDcuMTMzLTQ3LjEzM3Y0Ny4xMzNsNi42NjU2LTYuNjY1'
    b'NnoiIGZpbGw9IiNmZmQ3MDAiLz4KICAgPHBhdGggZD0ibS00MzIuMDMgMTguNTE4YzI1LjY1'
    b'MSAzLjMzNiAzMC43NzkgOS43NTI0IDQ2LjIzNiAxNy4wOCA3LjA5MjMtMC44NjM1NyAxNi4w'
    b'OC0wLjMxNTA4IDIxLjI3NyAyLjg0ODEtMC43MDAyIDMuODU1OC0wLjk4NDM2IDguMDA4Ny00'
    b'LjY5MSA5LjcxNzEgNy43MDY2IDcuNTM5MSAxNS42NzUgMTQuNzUxIDIzLjEyIDIyLjYxNyAx'
    b'LjM3NTEgMS40NTI5LTEuNzAzMyAyLjM2MjktMy4zNTA3IDIuODQ4MSA0LjExODEgMi44NzY0'
    b'IDguODM2NiA1LjM1MjUgMTEuNzI3IDkuMDQ2OSAxOC45MzIgMS40MjQxIDI0LjQ2IDcuMDM2'
    b'NSAyNC40NiA3LjAzNjUtOS4wMDk5IDEuNjg0LTIwLjA2MSA4LjQzMzYtMjAuNzc0IDIxLjc4'
    b'LTIuODIyNS0xLjUyNzUtOC4yMzUtOS41MzAyLTE2LjQxOC0yNC40Ni0yLjk1ODQgMC44ODUy'
    b'NC01LjI2NSAxLjc4NjctNy40NTUzIDAuMDgzNzItNy4zNDIxLTUuNzA4NC0xNS40NjMtMTAu'
    b'OTYyLTI0LjA0MS0xNS4zMyAwIDAtMi40NTAzIDQuMTcxMy0zLjEwMTkgOC4zNzY4LTAuNzA5'
    b'NzkgNC41ODE0LTUuNjQ3Mi00LjQzMTctNi45NTAzLTExLjg5NS0zOS45My0xOS4xODItNDku'
    b'MDcxLTM1LjkxNS01MC43NjMtNDMuODExLTEuNDIxNi02LjYzNDEgNi4wMzg3LTYuNTQ4NyAx'
    b'MC43MjYtNS45MzkxeiIgZmlsbD0idXJsKCNkKSIvPgogICA8cGF0aCBkPSJtLTQ0Mi41MyAy'
    b'MC4wOGEwLjU5NzEzIDAuNTk3MTMgMCAwIDAtMC4xMjQzMiAxLjExOTVjMi44NTIxIDEuNTMz'
    b'OCA1LjEwOTEgNC4zMjU4IDUuODg3NyA4LjI5MjZhMC41OTcxMyAwLjU5NzEzIDAgMSAwIDEu'
    b'MTYxLTAuMjA3MzJjLTAuODQyMTUtNC4yOTAzLTMuMzA1Mi03LjQ2MjItNi40NjgyLTkuMTYz'
    b'M2EwLjU5NzEzIDAuNTk3MTMgMCAwIDAtMC40NTYwOS0wLjA0MTR6Ii8+CiAgIDxwYXRoIGQ9'
    b'Im0tNDI5LjY3IDIxLjMyNGMtMC44OTUxNiAwLTEuNjU4NSAwLjc2MzM2LTEuNjU4NSAxLjY1'
    b'ODUgMCAwLjg5NTE2IDAuNzYzMzYgMS42MTcxIDEuNjU4NSAxLjYxNzFzMS42MTctMC43MjE4'
    b'OSAxLjYxNy0xLjYxNzFjMC0wLjg5NTE2LTAuNzIxODktMS42NTg1LTEuNjE3LTEuNjU4NXoi'
    b'Lz4KICAgPHBhdGggZD0ibS00MzIuMDMgMTE2LjYyYzI1LjY1MSAzLjMzNiAzMC43NzkgOS43'
    b'NTI0IDQ2LjIzNiAxNy4wOCA3LjA5MjMtMC44NjM1NyAxNi4wOC0wLjMxNTA4IDIxLjI3NyAy'
    b'Ljg0ODEtMC43MDAyIDMuODU1OC0wLjk4NDM2IDguMDA4Ny00LjY5MSA5LjcxNyA3LjcwNjYg'
    b'Ny41MzkxIDE1LjY3NSAxNC43NTEgMjMuMTIgMjIuNjE3IDEuMzc1MSAxLjQ1MjktMS43MDMz'
    b'IDIuMzYyOS0zLjM1MDcgMi44NDgxIDQuMTE4MSAyLjg3NjQgOC44MzY2IDUuMzUyNSAxMS43'
    b'MjcgOS4wNDY5IDE4LjkzMiAxLjQyNCAyNC40NiA3LjAzNjUgMjQuNDYgNy4wMzY1LTkuMDA5'
    b'OSAxLjY4NC0yMC4wNjEgOC40MzM2LTIwLjc3NCAyMS43OC0yLjgyMjUtMS41Mjc1LTguMjM1'
    b'LTkuNTMwMi0xNi40MTgtMjQuNDYtMi45NTg0IDAuODg1MjMtNS4yNjUgMS43ODY3LTcuNDU1'
    b'MyAwLjA4MzctNy4zNDIxLTUuNzA4NC0xNS40NjMtMTAuOTYyLTI0LjA0MS0xNS4zMyAwIDAt'
    b'Mi40NTAzIDQuMTcxMy0zLjEwMTkgOC4zNzY4LTAuNzA5NzkgNC41ODE0LTUuNjQ3Mi00LjQz'
    b'MTctNi45NTAzLTExLjg5NS0zOS45My0xOS4xODItNDkuMDcxLTM1LjkxNS01MC43NjMtNDMu'
    b'ODExLTEuNDIxNi02LjYzNDEgNi4wMzg3LTYuNTQ4NyAxMC43MjYtNS45MzkxeiIgZmlsbD0i'
    b'dXJsKCNjKSIvPgogICA8cGF0aCBkPSJtLTQ0Mi41MyAxMTguMTlhMC41OTcxMyAwLjU5NzEz'
    b'IDAgMCAwLTAuMTI0MzIgMS4xMTk1YzIuODUyMSAxLjUzMzggNS4xMDkxIDQuMzI1OCA1Ljg4'
    b'NzcgOC4yOTI2YTAuNTk3MTMgMC41OTcxMyAwIDEgMCAxLjE2MS0wLjIwNzMyYy0wLjg0MjE1'
    b'LTQuMjkwMi0zLjMwNTItNy40NjIyLTYuNDY4Mi05LjE2MzNhMC41OTcxMyAwLjU5NzEzIDAg'
    b'MCAwLTAuNDU2MDktMC4wNDE0eiIvPgogICA8cGF0aCBkPSJtLTQyOS42NyAxMTkuNDNjLTAu'
    b'ODk1MTYgMC0xLjY1ODUgMC43NjMzNS0xLjY1ODUgMS42NTg1IDAgMC44OTUxNiAwLjc2MzM2'
    b'IDEuNjE3IDEuNjU4NSAxLjYxN3MxLjYxNy0wLjcyMTg5IDEuNjE3LTEuNjE3YzAtMC44OTUx'
    b'Ny0wLjcyMTg5LTEuNjU4NS0xLjYxNy0xLjY1ODV6Ii8+CiAgPC9nPgogPC9nPgo8L3N2Zz4K', 'RU_MAG')

RU_MAG = b64_RU_MAG
index.append("RU_MAG")
index.append("Russia Magadanskaya oblast")
catalog["RU_MAG"] = RU_MAG
catalog["Russia Magadanskaya oblast"] = RU_MAG
country["Russia Magadanskaya oblast"] = ('RU_MAG', '', 1)
lookup["RU_MAG"] = ('RU_MAG', '', 'Russia Magadanskaya oblast', 1)
lookup["Magadan"] = ('RU_MAG', '', 'Russia Magadanskaya oblast', 1)
lookup["Russia Magadanskaya oblast"] = ('RU_MAG', '', 'Russia Magadanskaya oblast', 1)
details["RU_MAG"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+11:00","altname":"Magadan"}
regional["RU_MAG"] = ('RU_MAG', 'Russia Magadanskaya oblast', 1)
regional["Russia Magadanskaya oblast"] = ('RU_MAG', 'Russia Magadanskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_ME = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDI5MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01hcmlfRWwuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczEw'
    b'Mjk2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTAyOTQi'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTAyOTgiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFEck9WNm5BQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFXCjhVbEVRVlI0'
    b'MnUyZGQzd1UxZHJIbnluYld6WTltMndLcWRTRVlBb2hwSUVnTlNwd1JYcFJRUVVGUmJtS1hW'
    b'RVFVVUZRTVFvcUVDNEkKU0tnWEJSSkNJQVFDZ1JRU0NLbWJ2a2wyTjlrMnV6dHozajhDaUY2'
    b'VTlmMjg3NGVaM0R4L3pTZDdaaksvODUzbm5PZDBiSGMvSlRodAppckQrS1R1ekJLN3UwR2Vz'
    b'TWR6SmRMTGcwTkg3VHpnc2xsUFRKMWkxYlgwWnh6R0U4dENJMU16RExnTUhwKzdNWWlqcTlK'
    b'ekhxTTcyCnZyempERUtwZjFEcXppeExXL1BSdEljb2d5NTAzaUxEamZMcTNkdjc4bzRsUnQ0'
    b'M2hibXBvZjN5QmE4UnFWSy9nSnlaNlE2VEtXVFcKd3Y2TGwvWGxIV2U4a0hIWTg1Y3NhTTA3'
    b'TmZLNzNjcUJrVUhUWmtTLzh6RmdHTmVWRzF0djNEejFLV0lZcmd2Qm5JeEljWkkzZk5OVwo3'
    b'NlRSQkovZkMvaFpEQzAxSjFjNVRCcXhhbXhJMmt1Y1Z1UnNSTW80N0czbnp4SUNRUy9nQndD'
    b'NjZyTU9Vd05nWU8yNGFqRzBjRm9MCk1VMHBjaVpkeUp5bm85LzhxSFREV3B0ZUp3OEpaN2tx'
    b'YzJlRHZxNFE1NGw1UW1uUFg2eGQ3VlduMWdnVmFyN0V0UzcvTzVuM1FMNDgKaE9yV0JhVzkx'
    b'VlorRkNmNEFwbG5VM0ZXKzgxc3BYOU16eTBJb2E2bWNsMzlaWmxuQ09jUkJqODViOWk3NjBv'
    b'L1gzTnQwN3FHNDRkawpRU0dLc1A1c1ZzVVR5aG92NzJncCt0TFlXb1VMRkVLNWQxUGhENmFt'
    b'RTRiR01yN1V0L1hxbDEwTjV6MGlKdnZGem0rOHZLdTdacitwClE4TWdnYmJvTTZycnBzUTdq'
    b'aWVVdFJRZnFNL2YwRm41azhKdnBNUTlpTnNJWmNHaEk3L2QzWEg1d29XVlM0YTl2MTdvN2xI'
    b'MitWcEYKeEFCNWNCaUxxM2hNcm9veTFCVlErbUo5N1NtTFhpZjJDTGQwM0hRSkd0TlplWXlo'
    b'V29DaHVwdUt6VHB0ViswQkRBUEcxaTV5SFdnego2d1h5TUo3SW8vN3NaOGFHNDhpdVZ3WlBW'
    b'UTJkeXZtQzFLYnJORGMxaHN4K3ltL3NKTytScWJYN2Q1c2I2L3RObXkzeDgyZTFNSjZRCkVI'
    b'bnJhL09GYmtNdGJYbldyamJmbUtXMHc5NWRkeEF3d0FTQnlOWm9NNVJqdUJBWGVDTzZ5OXJW'
    b'R3BDOENpZUVMWmMzQVlaamZEOVMKNkJvODZuVU13MW1PMEtuM3E5MlhXYkQ4R1htL2tBc3ZQ'
    b'OXR5NW1SaXhpNlB1QkhzcitkZEEyUGt2aVA0SWhmM2lJV083b3F1aGdLcApaeGdwajhBRnF0'
    b'Q0gzMGU0REFBa3FpVFB3VE1Sd2hTQmFRUXBiQ3ZkQllROE1QbE54dDd1RlRrSHc0bmUwNmdB'
    b'QUxHUHI4MmdIN2wxCmowZk1jTTQwSHZRdE40NHM4Unl5c0wxOGoydjRGRjNWWWYrNEY2eGRq'
    b'WlN4VlhmOVJ3QUFRaGJ5eUlhT3FueWgxTFg5eGxHeGV3akQKTUxTNUEzQWlaUFNxWHRXb0FB'
    b'QnpjNk5uZktMN3NEZ09CZHdpRjIrNU9rbFhtZVdmc01KaDFERG02dWFTVEdWUXZPN21ZUVFr'
    b'WHhrSApkSGRiNlg2bE9yTDUwbWE3NFpwUTJWL3NGbTVzT2UvUmYzSnZhMVNRWXZHQXBhL1U3'
    b'TjFsMHRTcFJqMkNjYWQxeUJON3RsZnNJU1UrClhacHp5S0YzbUJ0MTlkY1JWU3Z4alBlTGY2'
    b'Yno1bkdxcTlHb0xXZW9Kc0NRUUI1b3FEa3BrQWY0UnMvZ2lrRFNLYzRpVVdMR0xzLzQKa2E2'
    b'RGg1NWRQSXVockhHZmJzRUlnaE1LcFI1QllzOWhIUlg3a0VPUFlZQUIwTWFyQUNCVEo0aVZm'
    b'a0szU0d0N2diM0wwSk80by9JSQpSbmU2aGIvU3E1cjJwRmlTdE8wblJWakVsUTllNy9mRUhL'
    b'R2JSMFhHRnppUDV4R2J3QldSRHF2VjJKaHRwNUROQW5ZYjJHMWdzK0oyCnE3MnQvSlJWMzJi'
    b'dDF2WDhrWFlBQmxaQzRCNDRjaGtuQWhsbnZaQW5WNGk5Zld3NlhkT0pZNGFLTW5OTHMzSlFW'
    b'TWlzcHpqMG5mSmwKdmgzTndCTWdnc0FBQVU0Q2hqTUdUUUh0QUo0QXd3bEFEREFJR0Jxc0pv'
    b'U2JHWnprYzBqZC9jTVpTMHRUOXBPVE1KSkkzWFhFM053bwpkSFZQL21FdlgrSENJWkZLOVNB'
    b'M3RadmNGYmRad1dwR0dBNDRBUWhoREEwWWhnZ1NFQUt6QVJFRXVIaGk2cWhrNEpRNVZSZWFt'
    b'eHR6ClpxYW5aaDVNMlhGUTRPYk9MWDRBUU5zcFk3dkpUdUVNQXdTSlVSWWNNQnpEZ1Nja0hE'
    b'UnROeUZBaUM5Z1ROME1SZUUycUFnWXdTVjEKZjZOZDZQdndoQkZmUC9qQitzTEN3c1dMRi8r'
    b'OWV4Q3lHRnB4Z28vaCtGK21Ba1RiTVpJVVNKUi82L0VCQVFINzl1MWp0UmNDZ0hKUQpWTXph'
    b'TDdRRlo4VXFYNGs2OEFFaTdPN3Vsc3ZsNjlhdFk0a1RkSFoyTGwyNmxPMEZxWExBa09RZjlo'
    b'cHVsSjk1YWpwZjRaS1NlVkRxCi95QTc3MTFjWElZTkc4WVNoSzJ0cld3UFo2U0J3Y2s3RGhn'
    b'MWRibnpwM29ucGZHVnJqa3owMDJhV3VnenJrU2tKazF0eStrVGlyQUIKQTVlOE1uempkK3BI'
    b'SnB1YkdwcE9IZS9MTzg0Z1JEUmRzT0paemRHZkl4WXZxL2twcytTekR3Y3RmeTEwN2lKMjZx'
    b'RnM5Q2ViRDlUVwphL3NRL3BIaXhaVkxDMVk4Vy9qRzhrSExYeHV3aEwzOVQwVWxkUTd0K1gy'
    b'SDgvc1Ezb05pM2MrNzFlUFRCenkvZ3MxNjRvZjF1OUF5CmFOeVkrRDZFOXpDM29RODEvUHRR'
    b'L2FGOWJOYkRNTWhnb25VR2F4L0NQOXJBRjFlTzJ2dEwrTUxuQzE1ZVhIZGdEMnYxZEJvc0RJ'
    b'UGEKZGViL0hvUk90UXNITFg5dHdQTXJHbzRmR3ZMcTJ3NkwrY0tyeitNOG5uckNZeXpVMHdP'
    b'dlUyL3A4OExmVEJZY0dySG94ZmJMRi9LWAp6TC95NFJ2R3VocFNKQmFyMUN3UjBORnA2akpT'
    b'UGRmRkpVVWxKWVVLZ2JaQlUxWmFka2x2TUFBQVFsQmQzM25QZSsxMiszK0ZGM1pYClZaNWRO'
    b'R3ZFMTl2alB2dW00S1ZGcEVpYzlQMCt0NkVQc2VIdGpXYmJOOS91MUJ1UndEWE1Tam5pUkZ2'
    b'Q1hidmVTd01BWUlyZ283MlAKQ3hUaFhSMk52dUs2dFBFemgwVUczcm54V01hWE43TlBsSjQ3'
    b'TzJETUl5SU1GbjY1bFNDSVhvc1FBSnBQbnppM2RFSENwbTFvN1NacApZREJMK0FHQVZNejM4'
    b'UXYwWkxEd2lPQm1iVGRSOWJ2cElBRytpdkFCQVJhTGU5RmxJaXhFWmJmYnp4L0pxczQ5cFQy'
    b'VFV5ZDFqYXkvCk5vcUE4OGVQZU9KUWZDWjNhRXBxYjBZSUFFMG5qbDFjdVRUdTB5MXNFekJ2'
    b'eHBnNzF4V1ZIeDNKdWU3S001Ni9ibG0rWU1RY2xVb3EKa1FEQXhGR0RHelNhS2VQSExEUzNp'
    b'Z0Q4QVdSNnJRTmh0WUFOSmhrSndMSEZzNVZIc2dPRFEzdHpSTXFUeVVObVAwMTFhQmtieFZv'
    b'eApFYUVocnE0cUx6ZFBnZEF0SWpTMGgxK1ArYW5WQ1pGUmxRSlJBeUpOQ0ZNeXRCRmhHS0Nl'
    b'RkNGMjg4ZFRKMnNmZElmMS95TkNua3llCjlQMCtpVG9nZThia3ZFV3phSXJpbGtnN1pTMC90'
    b'RDhwTkVpZCtrai9sRlJyUWxvbnd2eHhKZ0JEUFFscUdEeEFyOTN4K29yZWlaQW4KVnlUL3NG'
    b'K2k4c3VlTVpHbXJPMlhDdktYekdQc05uYnFzZG1zUFZIbzcyb0x2c0FsWXVDUVoxK3NyZGVj'
    b'S2luVFhMbDA5KzgzR0t3TApJQkJudXZOUG44MDUxUXNSRWdJQlR5cHpXTTBpZDYrMGZ4MkpY'
    b'UGxPMDZuajVWOTl4azQ5Rjc1Y1hsOS8wMWExN2NQMHNUYmJyZThNCnd6Q2YwSEIzVDYrM0Qv'
    b'MnlkTzhSMHR6dGR0di9HQUJYREEzQkdRYUIwbUo2WmNIY2xwYm0zb2JRcW0zTG5qR1JwcWlV'
    b'eklOVVowZkoKcHg5NnhDYUVQN1dFaFdJc0ZvdXdRM090S0x0RE5GWmFVcmcrTFo3Nmp6SmY0'
    b'ZUp5bVNFdjBiZUVteEZHSWZ5MGd6aEtremNZZkRxWQpONDlKL0NYcjU5NVdGMXJidGFmblBL'
    b'WTVjaUJuOW1QS2dZT1R0dTBseFJJV2loRUlCQXhQWUtlNkFaaHVCTUhOdFIrUFNiUmFmOWRm'
    b'CjJ0blI3aVVSK2VDM3ZKQ1BJWGVNU1NUcEJnWVNTZG9iUTROTXVuKzlzQ2h6eC9aZWhSQUFy'
    b'RzJ0K1M4c2NBa2ZrUGpOTGtJb1pLa1kKSE9lTm5DQ1Z5UUdoVUJ3QlFIaEQxVWVKMFpVVjVU'
    b'MEpHalNhWmRPbnBsajBxdHNGcVlDSGk4VmtvMVE0MFpNVWVZdUZLb25BVlpqaQpRUjdjdFky'
    b'Mm0zcFZ1eEFBQ0tHd3E2YlMzS2lSc2JqOUZKVXlEMmtMOVhYS2h1Z0UrYVY4T1lZRzZscU9q'
    b'Ui81MDZCaEFXa1BYL3JxCmM2SEZsbzhSZ3doR1BtNUltempBZ2dtdERnR0ZTRHZpMXpFOG1z'
    b'RUZwQjBRTmNoRitOWEd6OFE4cHArbk9YbmEreGpCNHp4Q2o5aUUKK00rL1BmZmM3T3daRTVO'
    b'M1pDbENJOWlwQjhOd2I3OHdVWnZ4cFo4T3J4d1pHOWxVUlFMeXhoZ291MmdvSzJUc21BTERQ'
    b'REZFSWF3WgpseHh0U3ZuVEI5M2UzV3AyWEgwS1RyTFpDNTBxU0wxR0pDZHQyNHZ6ZVVuZjd4'
    b'UDdxay9QZWF5N3FwSzFrdmJrdEZwdENBQ21yL21rCmtvWTc3UWNGb0NDU2lTSG9NQUtwY0Fa'
    b'emJzY1pna0FzMytURHFaR0t4RzkyNmN0TGppUkZkUlJkOUVsKzJOclcybGFReDFwSmRTMVcK'
    b'bWtFQU1IUkUwcWdmOWxVQTBZcXdIbHpWTkpIaklMSWRPQTBZRHVqMzdvdnVlVTNnM0YrbzNW'
    b'MVZXWlc1elhWSXRPL1lpWGxQenlqNwo0dU9vVmF1RFo4em5SRldmbUp3aWVIU0dIV0VOQ0t0'
    b'bWNCb0RBUVlQa3pRSkNFZS9lV0dNcW1icWdFSVNad0FnU0ttZEUzbE95cmZlCjlrSzJyNlIw'
    b'cXBTL3Nub1ZZNk5pUDk2TVliZzhPRFJzd2JNY2FqWXRmWGYxRTJkeVIydnJBVU1SZ0NyUnJh'
    b'K1dRUFN0Q01oYkl4TlkKdFdiWnBQQXJwVzIrb2NvMkl5V005cW0vM094dnRBbDd5WFlKQUZD'
    b'ODdyM0s3N2ZFcnRzY3dlNE45S3phL1BTdzNFREJHWFM3azAwaQpsVzdhcy8vcWtIajdsRG5Z'
    b'c2xYWFNiRURNQURvS1VqRlBOdFE3M3FseUF3SW1yc1ZrOE91Tkpua2VxdElRTnJUK2xVQUFO'
    b'azd2SkJMClJrcmJMSEpFU3U5ZVNoNFlHTFF0NjBqUDljaVVVVCttajRvaGJoV2taanYvWkcz'
    b'RVlJOUdpNFB2SmpUbGFVTDd1YlRYNkR3Q1hkb1AKWG8vcWFXdjJFaThjOHNwYm9YT2Z1YkRp'
    b'dVlxdlAyZXpIcUZ5Y0w0bXFvMGUrcWRDSWlPSHJGcGRnM0RpZGwxWXIzY3oyRVREVkxVNApR'
    b'VThiZUxGYTd6NDVvdWpvelNFMHdnR0F3TEhlZ0RCcTFlcndwNWRlV0xtay90Qys0ay9ldjdI'
    b'MUswNDc2cHluRjdYNEJRTmlldUFFCktiVnludlZTWXlDRHNEMmxzVUdLam9NVlE4ZUhGdmRF'
    b'TnpqQmZZU3k0TkRnR2ZNN2l5ODNIaitjbUpFNWNPbXJWMWF2cXNyY3hsMkUKTkUzclRkMEdx'
    b'NTFQMnNWOFczTGdkUkhQSnVMYk9zeXlwSURydFFaM3BjaGt0dlBIaDE0RmdDNjlyamMwS3ZL'
    b'ZWVkS2wvK0FKdVZmYwpoc1kwbi81VjZPbmxHWmZJWFlRSDkrK04wN1VTSmtyTXM1bHQvTUxH'
    b'UUwxVmhDRk1KZFh2S3grbWt1cVZJck9SRXB5c0hnQUFwb3FyCnV6NTRtL01GYWV2WjA3bnpw'
    b'ekkyZSs2OEtlWkdUY3IyQXpKdVRqTUJnSmJtcHB5M1gzWERVSWlwVzhhM0FFQnBtMStuVmVv'
    b'cTdqNTQKUGFwRzUxR2k5Wlh3cUNzdC9pYTdBQUJFREtVcHZkb2JJbEx0aFhOSDA2SjVja1Zx'
    b'NW1IdThpczdkM2Jia3FjU3FHNEFZRHBOSGhFZAo5ZUFPQUVYTi9rWE4vbmVpbXgvMXQvWmo0'
    b'ZUcwd1VyNWo1cktlUys4VllWWXJmS2dVTEd2bW92d0hBN0hsaGNXRjg2ZUhHdG83WWxQCjdI'
    b'cTdEKzgrYTlqY3hFWjFlNGUrc0tBM0lCUjZlZzNmdUZWLy9WcmVNMC9TVnU0dE9sbnozRE95'
    b'SXorSjd1b1hSVFFqcCs4VHFvUksKNnVpNmpvWnJKWnhIS0hUM1NObCtRRDNoMFpUdFArdktT'
    b'bkxuVDNXWVRSemkxOXpVeFB2MUVQbjdmbTBMWUVxcmpzRCthcnpDRzI5eQpkTnVKNWthSHc4'
    b'RmhoRUlQejlUTXd6aWZuek5qc3NEVmJmQkxyMnN2bkx2KzdTWjI2ckcwRjQ0THlWZnp6cU83'
    b'WnJIbEhUc1NoTk4zCkordGtNQndoUjFsTmhHdmRuejJLaDlQSzdtWUFVQ05xN1p1dmNSZ2hU'
    b'VkYyWXpjcEZGdmFXMDlObjNCMTdUdXF0TEg5bjEzT1VqMFkKYnJXVER2UTdYUzFseFhjN0VZ'
    b'VUF4NERBc0szTmtEcUkvck5IUlh1VUNhOVdBWUFJb09MWFgyaWE1aXBDZTVmaDlOekhUWTJh'
    b'MU16RApoRkRrUGl4dStLYnZjUjVMZHlrVHVFVm4xOFUwTzJMdjdpTTFFbVFWL1p0U0syQThE'
    b'QjNEeFhOV3ZaV1E4dkJBNzg1N3VtQVVYV0xYCm1nR0FCeERmMlpEMTNUY2NyZ3Z0M1YyNTg2'
    b'ZWFOSFdwTzdNU3Qrd2dCQUp1eFRKbW5xQWUvVGFNU3dOWUVEYnZxNjJQVDN2Q0p5eDUKVmlv'
    b'akl2ODRzM21hYnc2V1UwemR2c2NEUXcyZnZOdGwwSE00SXJWM2Q5M2NuaUZ3ODhENUhPTUhB'
    b'T21QUGxhQmNPTnRIaGlHYkFCdQpibTVpc1JnQVlzWSs5OUs0RmpIL3pyeGhOQzJ5c3J1bS9r'
    b'ZGFzVnZpY1llaUYyM2IvdUlpRGlOVWpSNFhzL2FMdXA5M2R4UVZjZzZoCnI5ci94WFVicm1L'
    b'Q0hoelhIVVFkamN0azhwNWZDWjQ0YmVxcmJ6eHVqUEZ2OTVDYVhoNmptYjFnd2JKZDJkdE9u'
    b'ZG1lZTc1UWR1dTgKVFFPQ2x0d2NGcTRxZGFwM3hpZDVkTUlYVytzUDdyMzR6eGRJc1lROVMw'
    b'U2ROQjhmbi9USHA0UUU5enY1ajNIdUdBSU1DUWRGQlFRRwovUFloazhMaGsxNEtIbHlvYjZz'
    b'S2ZXZ1JocE1BNE9ucEJRQUJDU01kdnh3Z0FUVXhPSWlFRFB1TzZYSnFwR0xFbGgyZEpWY3Uv'
    b'dk9GCjBIbUwzS0pqYytkTlliTXZrdGc5MnF3OEhpOXlXSXdaWWUwSWl5U1FDMElrK2NlcG9a'
    b'NkJENFhGUG9IOWZzcWhnK1FSZ095QTJRaGkKOGRFY0FmdmlBS2RHS2lxMmJIQ1BqaDIrYVZ2'
    b'VTZ4OUlBNEljRnJPNVNjTmFoT05DTHpMMmV3U1pPWWNPK09PTUdrTWRDTnBibXB4NQpsSTJp'
    b'bUY4UFlRQTRRTkNqLy9BTll1UEpQMDRWcEtXZmZlUXdtNGU4K25ieDJuZXFNcmZGZnJ5Wm5k'
    b'dGRBSUN4K1V5UXNzdUNpZ0RtCkEwQjVhVkhod1VPT3VtcFRrOFo2clZnTm9FWEF4NURFdVo3'
    b'ZURZc1hlTm1zZ0lFVndZVGxLMWxhNmppWnJtTExCdTJGczUzRlJYSHIKdi9hZk5JVzFMdWdt'
    b'c1FiempCVHFBb0NqKzdhZVA3YTU2bGZOY0lKMndSQWZnRUtBQWU3Kzh0dlBQL3RYSzdNUVFq'
    b'dS8rYkJnKzgrZQpEYlVTQWdHQVJ1R204dlBqTmtJQTZDZ3FWRTk0bE0zOEFDQWhlVUoxb2E1'
    b'ZmRDd0FlUHBGZVBzRmR3dzBWNWUzdTVFOEJZNnNVa1hVClA5OGRQZldKdjM3SStieGZyNWVj'
    b'NHdkaEhWTFZGUWNsd1R3ZVhmMEplK3QrSjlOaEJPRS9lV3JkZ1QySzhFOGU3RFpzZkQ3L3p0'
    b'clAKLzdUQWZnTUQrMzNVYy8xUVhJSzNTaDAwTEQ4cGRieEVLblgrWHd3Zk9XWlFaSnpOYWpi'
    b'b3RRcFhUemQzNzcrcUwyMDJQcC9QZG9RWQpRY1NzL1NMd3Nla2VEdzB2ZkdNNU1NeUFwYTgr'
    b'cURmMjgvT3JxYWx4TnJGYTdhZiszd3h3eXVRS2tDdmNQSDN1bTdLNnVscXRWck1hCklVWVFj'
    b'Wjk4NVR0MlVzWFhuNGMvdllUcTBKWjh1cG9uVnp5b0xVa0RBZ0lZaHFtb3FJaUlZTVhxcXYz'
    b'Nzk0OFpNNGJWQ0NYcVFPL2sKMFlZYjE4bzJyZXNzS1RMVzE0cFZmcXEwc1Evd3BWZXVYTGxz'
    b'MmJLalI0OCs4SG02SlNVbEJ3NGNLQzB0WlhXNzBGaGJsVE1yWGFvTwpTTnEydHlYM2xFM1ht'
    b'Ykl6NjhGdWtqOTM3bHgzZC9lWk0yZnE5Zm9IK0JwbnpweEpUMC8vN3J2dlpETFpBM3dOWjgr'
    b'cFVBNktTdjV4CnY2R2k3SUVmY3RCak5FMS84TUVIR1JrWlk4YU1DUTRPSnNuN0Z5ZGlzVmls'
    b'VWlVbEpYbDRlUHhuSzZLb3FLaWtwRVNyMVRvekxtZzAKR3ZQeTh0cmIyN2RzMlpLUThJRFBy'
    b'dUxlVVNOM20wNm5PM0hpUkgxOXZUTVRJOHhtczBhak9YbnlaR0ppNHZyMTY3MjliOFdaeDQ0'
    b'ZApXN0ZpaFZLcGpJbUo4ZkR3Y0dZL1BZbEVFaDBkSFI4Zno0WVZGODRpRkt2OFVqTVBNbllI'
    b'RncvOHVkc2NEc2ZtelpzM2J0eVlrNU9qClZxc3pNakkyYnR5NGZmdjJxS2dvamlweTZnaEtz'
    b'WTl2U3VaQjVLQ3paMDVxK1BjaDlmaDBRaWppcUdBY3grUGo0L2w4L252dnZSY2QKSGIxbzBh'
    b'Szh2THlRa0JEdWZwVDNMd2RFM3FyVVhZZVFnODUrY29KRTVVZDFkcHllTzlYR3l2RnI1MjN4'
    b'NHNVRVFVeVpNbVg5K3ZWZQpYbDZjMXVLRUZ6S01hdFE0c2ErZnBhVXAvdE52ZUdKSnpVODdT'
    b'SW1FUTBkUTNxUCt3REN4V0p5VmxaV1JrY0grRllUL0IzVWhJUktOCnpOamxPVHlwSmZmazJj'
    b'V3oxQk9ueEt6WmlIRmNPVVZSNWVYbDNLMEMvMTVkaUJ5T2huOGZSSWk1OU5Zci9wTjZBejhB'
    b'SUVueVRsRGEKKzczd2pxblN4bzdZc3JNWDhPdE45amRnaUgxODI4N250VjhxNk1zMVRpSU1u'
    b'REpqZk01bFZkclkzUGxUMjg2ZjZjczRqaUVNbkRJagpaczNHcnBzM1l0ZC81VDF5Vk43VFQy'
    b'b0x6dmJsSFdjUXlvSkRZejdhMEhINXdpOFRrMnIyN0JBb2xZek5idXZTOStVZFp5SlNtNjdU'
    b'CnFtMExtYlVRSVZTODVtMTlSVm5jcDErcng2WDM1UjFiUW10bkVsWC82d2VjejQ5K2F3MEF1'
    b'RVFNOUh0a1VsL0djUXdoQU56OE1RUEQKaWFGdmZ0aVhaVnlOU0hHUzV4ay9ncWFvUHg0ZzBH'
    b'ZWNRSWlUdk9HYnRub25wcDFaK0VUaEc4c1IrOVlWOUlVejkrZm5OU0kxNzZucAp1bXZGblZj'
    b'dVV4MWFuNVNIV2I1WGJsOWQrSnVKVlg3dTBiSGR0VGVORFhVcE83TzBCV2V2ZkxCSzVLMWk3'
    b'VnJ0L3paenFvOVVIaHFSCnNpT0w3K0ppYlczSm5qR0pGRXRTZG1ZSlhOMzdzbzh6ZFdGWFpV'
    b'WDJreE4wcGNYWk05TnhnU0Q1eDUvNytISE1DKytZSXF4L24vK3gKemY0SGlqN0NPeXhEZlhj'
    b'QUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURndE1ETlVNREE2TWprNk16Y3JN'
    b'REE2TURENgozTW1qQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEE0TFRBelZE'
    b'QXdPakk1T2pNM0t6QXdPakF3aTRGeEh3QUFBQUJKClJVNUVya0pnZ2c9PQoiCiAgICAgICBp'
    b'ZD0iaW1hZ2UxMDMwMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_ME')

RU_ME = b64_RU_ME
index.append("RU_ME")
index.append("Russia Mariy El Respublika")
catalog["RU_ME"] = RU_ME
catalog["Russia Mariy El Respublika"] = RU_ME
country["Russia Mariy El Respublika"] = ('RU_ME', '', 1)
lookup["RU_ME"] = ('RU_ME', '', 'Russia Mariy El Respublika', 1)
lookup["Mari El"] = ('RU_ME', '', 'Russia Mariy El Respublika', 1)
lookup["Russia Mariy El Respublika"] = ('RU_ME', '', 'Russia Mariy El Respublika', 1)
details["RU_ME"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Mari El"}
regional["RU_ME"] = ('RU_ME', 'Russia Mariy El Respublika', 1)
regional["Russia Mariy El Respublika"] = ('RU_ME', 'Russia Mariy El Respublika', 1)
#----------------------------------------------------------------------
b64_RU_MO = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMTIwMCIgaGVpZ2h0PSI4MDAiIHZp'
    b'ZXdCb3g9IjAgMCAxMjAgODAiPg0KPHJlY3Qgd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgZmls'
    b'bD0iYmx1ZSIvPg0KPHJlY3Qgd2lkdGg9IjEyMCIgaGVpZ2h0PSI2MCIgZmlsbD0iI2ZmZiIv'
    b'Pg0KPHJlY3Qgd2lkdGg9IjEyMCIgaGVpZ2h0PSIyMCIgZmlsbD0iI2QyMDAwMCIvPg0KPHBv'
    b'bHlnb24gZmlsbD0iI2QyMDAwMCIgcG9pbnRzPSI1NSwyNSA3NSw0NSA0NSw0NSA2NSwyNSA2'
    b'NSw1NSA0NSwzNSA3NSwzNSA1NSw1NSIvPg0KPHBhdGggZD0iTTU0LDM0bDEyLDEybS0xMiww'
    b'bDEyLC0xMiIgc3Ryb2tlPSIjZmZmIiBzdHJva2Utd2lkdGg9IjEiLz4NCjwvc3ZnPg==', 'RU_MO')

RU_MO = b64_RU_MO
index.append("RU_MO")
index.append("Russia Mordoviya Respublika")
catalog["RU_MO"] = RU_MO
catalog["Russia Mordoviya Respublika"] = RU_MO
country["Russia Mordoviya Respublika"] = ('RU_MO', '', 1)
lookup["RU_MO"] = ('RU_MO', '', 'Russia Mordoviya Respublika', 1)
lookup["Mordovia"] = ('RU_MO', '', 'Russia Mordoviya Respublika', 1)
lookup["Russia Mordoviya Respublika"] = ('RU_MO', '', 'Russia Mordoviya Respublika', 1)
details["RU_MO"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Mordovia"}
regional["RU_MO"] = ('RU_MO', 'Russia Mordoviya Respublika', 1)
regional["Russia Mordoviya Respublika"] = ('RU_MO', 'Russia Mordoviya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_MOS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxMjQ3IiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X01vc2Nvd19vYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5r'
    b'c2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8v'
    b'c29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxp'
    b'bms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnMgaWQ9ImRlZnMxMjUxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9Im5h'
    b'bWVkdmlldzEyNDkiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2NhcGU6'
    b'cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8'
    b'ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiIGlk'
    b'PSJnMTI1MyI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxp'
    b'dHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFO'
    b'U1VoRVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFD'
    b'QmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxF'
    b'OEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQUYKNEVsRVFWUjQydTNhZTJ4VFZSekE4WFB1'
    b'dlcxdmUvdGM2ZHB1WFRjMlNBWjBNc0h5R09PTkFmNFkrQWNoQWhHQ3lDTUVIeWkraUVRSgp5'
    b'QjhtUkRHQ1lnUXlKVUZqaUtESXc0aFJSRURETnRqWTJOZ1kzUVBhOWQzYmRuM2NlKzd4SCtO'
    b'L2FKbndsNy92WDAzdWY1K2NuTjg1CnR4ZjN1OFlqNk5ISEFBRkFBelQwaUtDYngrVC8vazNC'
    b'N0JGQkU0d1N6cnlFRVVKSTFLcGJQdHB6dldFK3dEMThhSmFpRXI5S1JSRkMKcUcvOU13c1hM'
    b'cVNUYTBXblBhdlhBMS9oc1Z1TnRuL2ZPbGF1VmlWU3BrZzhYRHNoeW10TU5sdTZlbXpDYXJT'
    b'MDNnVEJBc1AzTzBlSAp0YW83VHorbE1wcEdsWlVOdHAyZTBMQ1JYN0h4bE12UnRuemwrVERK'
    b'cXZRWnJZSE5wamdpbjJwOHo1N0xBZVVJVjNUY1lnNHRuaytzCjVoeXZsbzFaWTFGVmZsbERx'
    b'dEkxYmJSVG5ZejhJbFJLYW0zV2FFdmIzSWRtTFcxbHlOTGVUdEQ4aDdqN1BkRElwSDd1WEYr'
    b'ZnoxWHEKdXRQVjN6czRhQ0lLMSt2RERpZkJURzZVQzBreW9oUkpoQjNPam8zRmdIS0V3ekJl'
    b'NFNLRUNCb2VZMnl4VnJqTDNZRjRmRXhkM1dpWAppeU1JRVFXeExNcEpLQ2R0UHZ2cG0wMC9B'
    b'K1VJb1ZPMW51Ym01dEQybmF5aUtOaktJaXhZTFJFcDE5M244NURFOUYrL1JyazhvMEpICkRy'
    b'KzJyZVUzY0J6NU1Fd2FoSWpWRW5BNXpHdFhpYkZyRWkxRGlqTHg4VW0rdmo1QnAxTzk4dGF4'
    b'NGlwUExMeDRvRGVyMDZWMnZKengKKyswSEd0V3lES1lQQnYzWEJuSm8zN2g1YzlwYmptZXlK'
    b'ZDRwVTg2YytIYmlZNU9MSzBzRGc5MFhqNTB3MTlTb0dRWmxjK085VHpqZAo3cXRuenprM2Jn'
    b'UFRRb2NoUVNpalVldHorWlRGVkZFM2pWS3FVakdSV0RvV0dBb2Zhcm5DZG1Tb2xKN3dmY1dD'
    b'ZDdWYUhjSkk1M0Q0CjFtd1NUbjVaVXVPQkMvb0RRTjladDZKbTg0YjJ3NDJSV3oxZDUzL2tX'
    b'QzZaQ01UdWZSYUtyazZySlFQUkVqNW1jSWNsU1E1SEJxaEMKTWNQWU5XcFJGR04rZnhHSUZn'
    b'aE5FVEpObnhwZXNtTFNEOS9jR3dvRUEwTXpaODcwK2JyYldyaEVySlh6K0dQNG5IUHNQV3Zs'
    b'ZGxadwpHZ3lHNGN3d3gzS3FZTVJXWE56WmVCU2dDNFVPemFtajZUUVRqbDNldnRQMjdDcEJF'
    b'QlJGNmJ4NUF6RkZHajJ2OHJBR2JZbkdXSi9ECnB0bGVMMEpJRk1VTG54OHRTeVFKSWJwck53'
    b'QzAwSnRoUksrTnluSjh5a1JTV1o3czZJejIrVzQzWDljY09PaVAzMUdDc3FFanp2OGUKRkMz'
    b'V2FVOHVDQVdESnBPcDZlcFZ5NjY5bG5TbWRYQkFpVVN0Z1RDWUZyU2lIUjA5K2NxS2xGNm8z'
    b'ZjJCZ25HL0JsZGtsUlNIb3RwdwpRT3kxaThxWXRKSnN2VGt3MWV0MHUyKzF0eU5LaTJKaVZv'
    b'VkdYVGhURk1VQVd2QXdwSlJkdHNTNForOHVEMzlzcWk1dFpydmVEMzljCnBUNVdid3hiZVhX'
    b'Q1lFSjVHZjIwWnJQMnl2bU9qVnRMait6djhveXVmTTZQUks3elRLcjZFcHc3Q29CV01MNXEx'
    b'K083QXk5NG9rbEIKUnluMVpraTJHSGRhT1MxVnVJeWlFWWs5VHQ3NFkxaGF1NjdweFZmVlJr'
    b'UFh5ZS9zL202U3N3UXZEUkN6QmY2QktRaGFaUEU3czRSNgpmNXVvWjdpTXNzZkxiNm9aeXM0'
    b'YnUrNzEyeStWNjBxa1RFTmJmdlV0eXU5N215K3R5alYrcFRyNmliQjZreW5LWVF0MlhiVG9r'
    b'Z3FBCkZub3pUS3J3RjE2cEVpazkvYm9kSDFvUnNhbFk1a1pIeDJsZmVFbGR3b0RMUmhsTHRi'
    b'cUVJcE83RVVmUFpXMzF3VTZNME1Eek9aUEoKYmR3OUJLQ0ZRb2Q1R2x5VWNFdzMySXAxQnYx'
    b'b3l2aGlvdEVzOUlweWlHT3BvNGhEbEVXVVFSUWpyR1JrMU45dENGNWtpdXNsbnB2SQpidWtE'
    b'MEFkKzF4SGRZakZOTU52czVvemN4UE1pd3loeW51aDVRWmF0dDNxaTFkVkpsbEVDSVowR3or'
    b'RFVVaW8xSE5vZktHcktBMmloCjBCU2g5cTNCR2JQWmVLaWNrSXpaekJ2MCtVemF5ekJVVWxL'
    b'VURpdE1LckkrZUU4djVSZWxhK2N4b1ExNll4cE9kU05hMGFLRzV0MXEKcEViSXEwZFpRa1Ra'
    b'Zm5vWUllU2JqSVZ4V2ptSGJDZUhvenBGWHM0eEViWGplQllRLzlQV0FUM2M0Sk13Z0Fab0NL'
    b'QUJHcUNCQUtBQgpHZ0pvZ0Fab0NLQUJHZ0pvZ0Fab0NLQUJHZ0pvZ0Fab0NLQUJHZ0pvZ0Fa'
    b'b0NLQUJHZ0pvZ0Fab0NLQUJHZ0pvZ0Fab0NLQUJHZ0pvCmdBWm9DS0FCR2dKb2dBWm9DS0FC'
    b'R2dKb2dQNi85aWMyK29BZVRJVjBBQUFBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VBTWpBeU15'
    b'MHcKTnkwd00xUXdOVG95T1Rvd09Dc3dNRG93TU55cm0zUUFBQUFsZEVWWWRHUmhkR1U2Ylc5'
    b'a2FXWjVBREl3TWpNdE1EY3RNRE5VTURVNgpNams2TURnck1EQTZNREN0OWlQSUFBQUFBRWxG'
    b'VGtTdVFtQ0MKIiBpZD0iaW1hZ2UxMjU1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'RU_MOS')

RU_MOS = b64_RU_MOS
index.append("RU_MOS")
index.append("Russia Moskovskaya oblast")
catalog["RU_MOS"] = RU_MOS
catalog["Russia Moskovskaya oblast"] = RU_MOS
country["Russia Moskovskaya oblast"] = ('RU_MOS', '', 1)
lookup["RU_MOS"] = ('RU_MOS', '', 'Russia Moskovskaya oblast', 1)
lookup["Moscow oblast / Podmoskovye"] = ('RU_MOS', '', 'Russia Moskovskaya oblast', 1)
lookup["Russia Moskovskaya oblast"] = ('RU_MOS', '', 'Russia Moskovskaya oblast', 1)
details["RU_MOS"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Moscow oblast / Podmoskovye"}
regional["RU_MOS"] = ('RU_MOS', 'Russia Moskovskaya oblast', 1)
regional["Russia Moskovskaya oblast"] = ('RU_MOS', 'Russia Moskovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_MOW = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDkzNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01vc2NvdyxfUnVzc2lhLnN2Zy5wbmciCiAgIHhtbG5z'
    b'Omlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBl'
    b'IgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9E'
    b'VEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8x'
    b'OTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHht'
    b'bG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9'
    b'ImRlZnMxMDk0MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzEwOTM5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2'
    b'NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRv'
    b'dz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBh'
    b'Z2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9Imxh'
    b'eWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwOTQzIj4KICAg'
    b'IDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAg'
    b'cHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJp'
    b'bmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7'
    b'YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FZQUFBQmtXOG53QUFB'
    b'QUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFB'
    b'ZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBdwpC'
    b'a2xFUVZSNDJ1MmRkM3hVWmRyK3YrZE16MHlTU2U4aGpaWVFldTlJRVZBQlFRRzdXRjlCVjkw'
    b'VjI2cnY2dXE2ZHQyMXJ3cUtIUkFRCnBIY0VFaW1CRkVKSkwwTjZaaWJUejh3NXZ6L0NCaEhj'
    b'WFgzZjkvT0RtT3N2UHVTY00yZk9YT2QrN3Z1Nnl5TjhTUitGTG5UaGZ4ZWwKWXRjejZNTC9C'
    b'YnFJMVlVdVluV2hpMWhkNkNKV0Y3clFSYXovTHdpZzRCTzZndWRmQW5YWEkvaDVXTVVBT2Qx'
    b'MDVHdmN1Snd1SnFxagpDSzYzRXllcGlRbDBQYnJmQkxFMkJ6bVk2REtpUXZoVjV4ZHB2WVNq'
    b'SnM2bklvRENBYjJieENkdjUvTFVic1FlelNjdU5wYUdoZ1o4ClBpOEZoNHVKMlZIVHhaN2ZB'
    b'ckcwY1pIa3hvWXpjcS9sVjUxdlJvTnQ0VFFTUnd5aDRPaFJSdmJ0UzBscENhdFhyMmJZMEtG'
    b'RVJVVVIKSEJ4TWVXVTVyaVpyRjNQK0RZVE9vcndIVU5nNnFSczlIU0lwT1JXLytIeEpVTENv'
    b'L0d5TGc2dzVVMGhMU3ljdExZMUFJRUI0V0Rncgp2MW5KM3IzN0VEdytwaDkzMDFQU2RiSG41'
    b'MUhhYVN5V0NvSEJPOG81Y3NNUXFMZVNVdjdMcklwR0VUaXA4Wkk1WVFKdFZYVzgvTVZ5Ci9J'
    b'ck11TGdNOG4wdFBQRGdBeVFsSldGWnZaMmVVblVYZFg1THpudEVRSVYrK1Y2YTdyb0NZY2xP'
    b'dXRubFgzVCtaTGNKUGprQXdEZ2gKQW9CajFnYTJoclJTYTdIZzgvbG9UUXJISlZRU3BIUUYx'
    b'TDhwdVdHVTIwRDF1dDJVWGpPSW1nZW5jeXBhKzZ1dW8xRUVKQlMrTXRubwoyYXNYdDk5K085'
    b'bloyYnp3eHF2azY3MWR6UG10RVF0Z2Nya1BwOTFPai9FanFadVNqZi9YQllyazZ6em9vOE5C'
    b'VVZpeFlqa25UcHprCnVlZWVvMTZVdXBqeld5U1dxTURNT1hNQWhTR1hqYVZBNi81VjF5bFhT'
    b'MXc5ZXpZUFAvSXdwU1ZsakI0OW1tblRwb01wcUlzNXYwVmkKQ2NEaFRkc1pQV29VWmVYbDJP'
    b'ZVBwYnAzOUMrK2prTURoL1B5eUVqUElENGhnVysvWGNQcTFhdFFuSjUvSHhacGZOU3AvSnpR'
    b'ZVBuVwphTWNseUYzRXV0UmhVRVF5UDk3UEM3OTdtTlNVYmx4OTNWeWtHeVpnVWYreUpheEJr'
    b'Qmc0b0Q5eDhYRmNlKzAxeE1iRzh2cnJyeE9xCjAvL2JjeXZWRWxrYlhxZi84aGZJK1AzTnZK'
    b'WG1wMDJVOFFnS05Xby9BVHAzaXFqVDVpVzBpb0N5OG51Ni85Y0M5bnkvaDUyN2RwS2wKbG9q'
    b'M2F6cU84UWtLTzJMTkhJK09Jcm1saVpHV0puU0tnRmxXVWFXV3FCY2wxR28xUCtUK1FHeGNE'
    b'UDBIOUdmbnpsMFluRDVBalU5UQoyQlJyb2lyWVNGWkRBMGt1aVVCYUxFcUVpU2hCNGFuSG42'
    b'Q2h1WWx4NDhjemJzWTBTaFdSOE5ob2V2VHNRY0d1ZlNTOHNhSFRScGVxCmE0aitVMmNsVjZT'
    b'c1lrbHpNU2twS2R5emNCRWZyRm5PSUxzS0VZRlRHaCt2OUlnZ2QvQWthcm9Qb1hEUU5MYjE2'
    b'TUYyazhUV3pHeU8KQkFVSUVweG9kVnFpb3FQcDNyMDdXcTJPRC83eEQvUkZWUWlpbWlkbXpp'
    b'RS9PWlZXVHgxOXB3OWc4SU1MR0xMZ1dpS0g5YVVsV0VOWgplUmtMRml4Z3gvYnQ1T2JtRXBl'
    b'VWdDQ0twS1Nrb3VqVUhDODVTWHhUcDR3d1d6dDFKbFdsZ05ydVFxUFJzblhMVnQ3ZnVKcG5S'
    b'cy9FClprNWcrNmlyOEp2alVUbWEwTlFkeDdqL0UyUmpPSjZzYVNpMVIvQzc2bERiN096Wjh6'
    b'MUpTVW1zWDc4ZXYrVERhclZSRnFPbmZ2SjkKcUMxRktLRXgvR25oelFRTEhrcEtTNmlvckdE'
    b'djNuME1HemFNZGQrdDQralJmTUxEdzhuSnplR1BmL3dqUzVZczRjMDMzMlQ4K0hGVQpWdGVR'
    b'S1pnNnBkVVNPbnN6UmJQS1QrNjhBU3grOUZGS1MwcVFaWmw3L3ZBWVBsTWtRc0NQUDZJYm5z'
    b'd3ArTU1TRVh3dWdncStnNEFmCmIvY3hxQnRMQ0Qzd0Jla3B5Wnc4Y2FMam1wNWVFeEJkclFS'
    b'QzRybDVSQVpwRVFiME9qMjlldlZpei9kN01CaU0zSGZmSXJadDNVNVEKa0o2RXhBVDBlZ1BS'
    b'MGRGb3RWcmVmdXR0OXU3YmkyWFRQaGJad2p2all5L3QxRXNoUUpBaVVoS2hwcytvNGNoeUFM'
    b'UFpUS2hSejVGZApteEZkVnRUTkZlaE83VVpmdWcvUmJjVTVlRDZCaUNRTXg3YWdxVCtCTEln'
    b'MHRia1F2WTZ6bHRCcVFXMDdqZHBheXgvK2F3SGxaZVVrCkppZlIzTlRJanAwNytldGZuMmZy'
    b'bHEwWURIcDZaL1ltTlRVTnM5bU1ScU5CRkVXR0RSdkd3SUVEMlhCd0wvMHJYQWkvc2lMalls'
    b'NEsKTzMxZXdpL0FpY0pqYk4yNmhSNDllckJoNHdZV0xWckkrQW5qMi8yd3lFam16cGxGa2tu'
    b'RVVMaVJ5RTl1SStqSVdxU29ESnlENStQcQpOd3RGZGE1NkwvaDk5TXZ1ZzBweVk3ZmJTY3RJ'
    b'cDZhbW11cWFhaDU4NEVHYW1wcFFxVlhFSnlTUWtKRFFjZDZ5VDVaUldWR0IxK3ZsCi9mZmZK'
    b'Nytna0VPZFZNWHYxQmFyVlF6d0Q3T05FcE9CbXRLVEpDWW1JcXBFdnY3NmExNS8vVFZXTEYr'
    b'QjFXcmxtV2Vlb2JBZ240YUcKUm1iTm1rR3c4elJ5OFM0NHNoNWR4UStJYmh0R294RkphcGNy'
    b'UWtOREdUbHFGSklrRVJrWmljbGtJaUlzZ2phSGt6blh6S0dnb0JBNQpFQ0FsTllYZzRHQUNn'
    b'UUJ0YlcxWXJWWk9uejZOMld4bXlwUXB4TWJHVXFSMUUzTDhOS2JPNVdlMWRscGl1UVdaUDA0'
    b'Y1MyWDJaYmdHCnpjSFpYRWRaN2phdXV2SktDZ29La0FNSzExOS9QYnQzNzBadjBQUE5ONnU0'
    b'N3ZycjZOMnJONmxwcWJTMnR1TDJlQWdFQWlRbEpUTjEKMnVVME56WHo3SFBQTW16WVVFcEtT'
    b'a2xOUzJQeDRzVnMyN2FOSGoxNjB0TGNSRXgwTk5VMTFZaWltcXlzVE5ScU5jM056WncrZlpx'
    b'VQpidDN3Qi94VVYxVmpOcHNaTzNZc0tXbHBmSHg0TjcxT2V6dVRxTmg1bzhLdjQ0Tm9UUnVD'
    b'b2Y0RVdFL2o3VEdlc2gxdmN1andZWktUCnUvSGtrMCt5WmVzV3hrK1l3SnQvZnhNQWE2c1Z0'
    b'VnFGV20zZ25YZmZwcWp3R0c2M0c2L1BTM3A2T2xxdGh2bno1L1BacDUreWUvZHUKMXExYng4'
    b'TVBQOHhycjczR2xDbVhzMnpaSjFSV1Z1THpTbWpVR3ZUNmRpRzF1YW1adXJvNjhnN25jZFdN'
    b'cXpoNThnUk5qWTFvTkJyNgo5dXZMN0VWM3NQYmVQM0cxSTdocktiellrZUwwTWpGdkgvT0x5'
    b'd2lyT3NMUnRPNm8yaHJJMjdHUnc0Y09JVWtTdVRrNXZQNzY2MnpjCnVCR3IxWW9nQ0FTSEJL'
    b'TWdFQmNieDRnUncrbVQzWWZzN0d3U0VoS29xYWxGRHNnODhzZ2ozSHpMTGVUbTVyUVQ2OVhY'
    b'Q0FveU1IZnUKWEhidDNrTjZhaW91dDR1ZVBYc0NZRFFadVhmUklucjI2a1ZJU0NoSlNVbWtw'
    b'cVlTQ0FUUTYvWDA3ZHVYdzIxMUZCNCtRcHBmMnlrcwpWcWNsbGw0Uk1Ta2lBbEFsZURqcExF'
    b'WGRVSHJPTVkyTmpmZ2tIODg4OHpRclZxekVhclZ5OE9CQnBrMmJScHVqalhYcjE5TzdWeTlL'
    b'ClM4dFl1V0lseXo3NWxQZmVldytyMWNxNGNlTVlPWElFUzVZczVmTExwMUJSVVU1MmRqYk5U'
    b'WTFvZGUza3lNaklBRUNqMFhEeVZBa3YKdmZnaVpXV2xGQmNYZ3dKcDZXbW8xV29FUVdEU3BF'
    b'a0VqOHdtdC9JazBaWFdMbUpkekxDTE1nZDBidFliN2ZnOXRnc2VrM2M0ait6cwpiSzY3L2px'
    b'V2Y3MGNXWlp4dVZ6MDZONERuOWVMNUpNb0tTbmhtV2Vlb2FHaEhyL2Z6NENCQTNqNDRZZXBy'
    b'S2lrYjc5K2JOdTJsWWpJCktMSXlNL0Y2UEFpQ2l1Q1FFQklUejBhRW1abTl5YzNOcFc1dkhz'
    b'VjVSL2x5elNyV2ZQc3RSNDRjd2RyYXlsdHZ2ODExMTEzSHhnUDcKNkhiVWNza1RxOVA1V0pL'
    b'ZzhFVmFORVhob2JTRWhJTVNRRGFFb3JLZFJ0RUdFUWlPUVhRMWcwcUR0dndBaWtiSG80OCt4'
    b'dHAxNjNqaQppU2Q0K3Vtbk9YTGtDTG01dVFERXg4ZGpzWno5b1FWQjRNMDMzK1RGRjE5aTFz'
    b'eVpIRHo0QThuSjNWQ0pBazZuQzQxV2l5aUlCQUtCCmMrNHJOamFXeU1oSUpqcENTZlpyOEFn'
    b'S3grek5IRHkyaHMyYk5pTTdQVXlmTmcyUDJQNGROTXFsclcxMU9tTDl2VjkzZnBpNUdBU2gK'
    b'UTNOQ0RxQ290UWl5SDhIbkJrVUdVWTI3OXhUVVRXVW94VnU0NC9ZNzJMcHRDN3QyNzJMbmpw'
    b'MGQxL3N4cVFBTUJnTTdkK3hrNnRUTAorZUxMTDdqampqdnhTeEtIRHgrbXBxWWFqVnBESU9E'
    b'SGFEcmZFWjk5OVd5K1c1VkRzbCtEWGhFWTZOVXowS3RuUjVTZW1PdkhzK1cyCng0a2FNK0NT'
    b'SnhWMHdyS1pZeW05RVFJK1JGY3JvcU1KMGRtQ0VKQVFBaEtLV29jY1pFWTJoaU1iUWdpRXho'
    b'SUlqa2FLVEtlcXFwTEYKRHkzbTFWZGVJU0lpNG1ldjcvUDVLQzB0SVMwdGpVbVRKbkhvMENF'
    b'Y0RnZkhpb3NKQ3d0SG85VWdvMkN6bmU4blRaMDJsZnFNODY4OQpvZFJEOG12ckdXeFYwLy9i'
    b'd3E2bzhHSkVVMk1CTlZFeENBcW9XNnNSWGUwL3NMYitPTnJ5SDlEVW5VRFdoNEJLalhualg5'
    b'RldIVUpiClY0d3ZlU0NsK3pZUkV4UExnNy8vUFY5KzhRV3hzYkdJb29qWGUxWWRsMldacHFZ'
    b'V0JnMGNpQ0lybkRoNUFxdlZSa1JFQkRxZEJsRlEKb2RmcmlZbUpJU1ltNXB4NzAyZzA3TW83'
    b'aUpoZmdWbFduZk0zclNLZzdqeXBuYzdudkdzQ0FRcnI5Nkt4SEVQZFhJbldVb2phZGhyZApx'
    b'VDNJd1pINEV2c2p1cTJFYm5rWlpCa3BxUzhCY3p6NjQ5c1I1QUI3OSs1bDN0eTVwS2FtVWxk'
    b'WFIzeDhQTlhWMVIzRWtHV1pRWU1HCjRuUzVhR2xweHVsMDBtcHRvYjYrbmtHREJxUFZxbEdw'
    b'TkRqYUhDUW5KeU9LNXk0S1dWbFp2THRtT2Yyc25TNC9lQTZ4T3QxU2VGVHIKeFIrWmhxZm5l'
    b'RHk5SnVJYWVDMnV2bGZoR2pJUFJhWEZVTFFCbGFNWjIvUW5jWXk0R1kybENQMnh6YmdHWDR1'
    b'aTB1RDMrM25nZ1FlNAo4NjQ3Q1k4SUp6OC9uenZ2dkpNOWUzYnowRU4vQUdESGpoM29kRm95'
    b'TWpJWU1uZ0l2WHRuRWZEN0VVV0J4b1ltSko4UGpWWkwzZW5UCjU5MWZRa0lDd1lONzB5b0dP'
    b'ak94T3M5U0tLUHdlcDl1N0o3OUVLNkJjNURpTXZGSHBSRUlTMnozcWZRaFNNa0RFRDBPMUMw'
    b'VjZFN3QKUWQxYWl5ZHpNcTZCczFFM2xxR3R5UWVncGFXRmlzb0tubm42YVQ3NmFBazVPVG5V'
    b'TjlSejhNQUJHaG9hU0UxTlpjcVVLUWlpd081ZAp1K25WcXljS0lBb2lpWW1KU0pLRTJSeUt5'
    b'K1VtTmk3MjNHaEpyU2JVYkdiVHl0VmtTTnBPYTdFNkRiRzJtaFcyOXhtRW9DaW83SFdvCjJo'
    b'cFEyZXNSblMySW5qYUVnQmNFRmY3WVhrZ3hQZkNsRHNFZm1ZTGc5NkJ1cVNaNDMxSlF6cGFt'
    b'SFM4K3p1REJneGc3Yml3Yk4yN2sKMUtsVE5EUTBrSjZlem44Ly9TZmE3SGIyN2QxSFZIUTA0'
    b'OGVQNTd0MWErblpxeGNORFEyb05Xb2lJaUl4R28yRWg1OWZieVdLQXQ4ZQoya3RXaFJPaGkx'
    b'Z1hMeFJnYWE5dXRIYnJCNElJU2dEUjYwTFZWbyttNFJTNjhseDBaVG1vRzhzUlhTMm9IUFZv'
    b'TFVXSUhpZkJ1OTVECjNWYUhOM1VvbXZwVDU1SjE2emJ1di84QlRDWWpCdzhjQkNBcU9vYU10'
    b'RlNLVDV3Z09UbVpzV1BHOHZubm54TnFEbVhJNENFNEhHMkkKb2dxTlJrTjhmQnhHby9HOCt3'
    b'ME5EYVg4dElYYTd3OTIxbkZJbmNQSFdwMWtwbkx3VFB4UkdjakdDRlRPRmxTdE5lQ1g4RWVr'
    b'NE02YQpTdHZFQi9DbURVZFRmeEp0NVdIVTlTZFJ0VmJqR0gwNzluRUxFU1J2aHdENlQ3amRi'
    b'bTY1NVJZV0xWckU2REdqQVJnL2ZoekJ3U0ZrClovVWhJVDZCRlN0WDhOVlhYOUhXNXVSWThU'
    b'RXl1bmRIRkVXc1Zpc3VsK3VDOSt0d09Nakt5bVJUa0FPbjJEbmJ3aTc1MG1RRmVEVFIKaXhR'
    b'YVM1cmRSVGVybFRnZmhNb3FRbVVScjZCUW81WTRHS0tpTUxVM25oNWpVRFJCeUlaUTFLMDFx'
    b'RnFyMFRTMGswMFVSUjU0OEVGZQpmZVdWY3o1ajF0V3plT3FwcHhnMmRCZ3paODJrVDNZZkJF'
    b'V2d6ZW5ndE1WQ2JHd2NzVEV4TkxjMG85UHE2TisvUHphYmpWQ3ptY0dECkI2RW9DanJkdWRO'
    b'cERoMDh4SXdaTXdqMXdsMTJNM0VCVFdmaTFhVmZtaXdBMlU2WVhlOWptRDFBVDUrRytJQ0dD'
    b'Rm1GVVJFSmxWVWsKK1RVTWM2b1pXdGRJZFhNQmpvQVQ0Nkd2RU4wMkFtRkpLS0lHVGYwSmpD'
    b'WVRzYkV4ZUQxZW5FNG5EejMwQjZaZk1aMFZ5MWNRSHg5UAphbG9xbjMvMk9YMzdablB5MUVr'
    b'R0R4ek1SeDk5eExIaVl2cjE2MHRZV0RpdDFsYnE2azdUbzJkUFFFQ3YxNlBJTW5xRG9lT2VY'
    b'UzRYClpXVmxiTnk0RVpjUWdLRTlTQ20zb2VsRU9sYW5XT0JqLzBNL0pTYWc1cDdhQUMrSDIy'
    b'bUtTRWVLeWtCVFY0eXU4aUQzL2U0K1JvNGMKU1p2ZFRuUjBOR1BIakdYMW1qVjg5c0tMQUR6'
    b'MitPT3NXdlVObGxvTE83YnY0UGp4RTZSMFM2Vyt2cDdKa3ljVEdtcEdyVllURXgyTgp3K21p'
    b'cnE2T2lSTW5ZcW10eFdneVlRNEw2N2lQb0tBZ1hFNFhnd1lONHRDaFEvUVlPb2lsQndwWjJJ'
    b'a2FLMzV6czNqTXNvby9INjNsCm9md3l4bjIvR2wzcFBvU0FSSEpTTWxxTkZyM2VnRXFsNXRa'
    b'YmIrV3pUejhGNEo2Rjl4QVZHY250dDkzT2swODlnY0Znd092MWRpeVoKTnJzTlJaR1JaUm1m'
    b'SkJFYUVzekpVeWNSUlpHV2xsYmtueVNrWlZrbUpEUUVlNXNkOVpuYzRuR05seEtOcjlNODUw'
    b'NWhzY28wUG83MQppNkh2N0tsRVJrVmhyNnlsNmF0dDlEN1Zlc0dacEFLUUlXblJLUUxWYW9s'
    b'NmxaL0ZpeGVmYzh6Z3dZTVlOV28wRFkwTm5EcFZRa3hNCk5BZ0N0OTkyTzg4Ly8xZG16cHFG'
    b'NUdzbmdsYXJRMUVVM0I0UFdvMEd0OGREZUZnNDc3MzNIaU5HaktDcXBwcUV4TVNPd01CU1c0'
    b'c2sKK2FtcnF5Y3FPaEtWMko3ZXlkVzV6OU8yYktKTStlZzB3bzlXazJ5N2RFVFZTOXJIVW9B'
    b'OXZZT1p0T3hGL3ZEODA0d2FQWm9CQXdjdwpmTUk0eHR4OVBmdU5YcXIzNXhFaFhkZ3doOG9x'
    b'c2lRZHV3em5SMjl1dDRkUm8wWlJkS3lJVHo5ZHhvMDMzVVJzVEN4bDVXVlVWVlV4Cjk5cHIy'
    b'YkZqQjRxaTBLOS9QMnBxYXFtdHJhRzIxa0pUY3pOMmV4dDJtdzJuMDRYUjJPNjdsWmFXb2xh'
    b'cGFHeHE1dFRKazZ4YXRRcVQKeVlUVDZhQ21wcFlHbFo5SmJpUGltWmRCRWhRK2pIYnc4dWFW'
    b'bk5SNE1lMDZkc240V0pkMFZMZy9NNVJIdG54SmJHd3N1M2J1b252MwpEUEtPSE1FY2FpWStJ'
    b'WjdFeEVRcUt5djU2UEZuU1ZoOW1LaUFDcjhBcFdvdng3VmVhdFIrbWtVL1RhcWZ0d1JUcDAx'
    b'bHpwdzVqQmd4Cmd2RHdjQndPQjkrc1hFbEthaW9yVnF4Z3hmSVZ6SjR6bTdsejUrS1gvT2ox'
    b'ZW94R0kzVjFkVFEwTkdDMzIybHVhVWFqMFdBd0dMRFoKYk1UR3hHSXltVml5WkFuaEVlR1lU'
    b'Q1kyYnRnSXdDSmJPRDBsSGVWcUgxOEcyem10YXU4TUVnV0J4MW9pTHhYZHEvU1NJWlpmZ0J5'
    b'ZAppOUdlOXRsVVA0VEozTExqTXh4dGJkanRkZ3dHQTZkS1RoRVJIb0VrU2NpS1RFWjZCbFZW'
    b'VlRRMU5mUHQ2bFY0OXhkUnF2SGhGR1EwCldpMlhUNWxDNzk2OThQcDg1T2Jra3B1YmkxcXR4'
    b'dS8zbi9mNWVyMmVZY09Ia1pHUndZbmpKMUJwMVB6bHVlZTRiTUpsakI0OW1ydnUKdW92bTV1'
    b'YjJJQ0VtQmxHbDZnZ0VUQ1lqM1h2MEFLQ29xSWgxNjlheFB5Y0h0OHZGMENIREdENThHTGZk'
    b'ZGhzQUNYNDFRWXFJSnkyRwphZE9uOC9IU3BSM1ZGYWwrTGIremh2L3FrZU5kY3NOUDhNK2RJ'
    b'WmFiN0F6MUduQ0xDbEV2THlJMlBvNFZLMVl3ZlBodzh2THlpSTZLCnBxcXFrdno4ZkE1czNN'
    b'N0tGOThrZjhzdWlxckxPRnhZUUt0QnhDUDdTVXhLNG05dnZJSEQ2ZURnb1VORVIwZGpiN05q'
    b'czlxWk1HRUMKd2NFaFpHU2tBd0poWVdHRWhJVGk5L3NwS3l2ajRNR0RWRlZWb2RWcTBlbjFY'
    b'SG5GRlZpdFZxWk9tNHJSWkVLU0pLeFdLNEV6SmN3cApxU2xFUlVWMWZCZVB4MDFsWlNVOWUv'
    b'YWtyYTJOdzNtSEtTZ293RkxiWGxDWU1iZ2ZTbVFvaXhjdlpzcmxVL2ppdzZYY1pBdEJqVUNS'
    b'CjFvdFhVT2g5OFU5c3Z2amxobEtOajYwR0J5NUJ3YUtXYUZBRnFNMk81K1c3NzJUcmxxMU1u'
    b'aktGV2tzdGtaR1JGQllWOHUxcjczRzEKTTRTUmtoWUl4OWttODZ4MGtoRWpoek4zM2p6Kzh0'
    b'eGZxSzJwWWV1MnJWdzI0VEttVDV1TzNtRGc3YmZmNHE2Nzd1QlVTUWxUcGt3aQpMVDBEclVh'
    b'RFZxZkZaclZSV2xaR1ZGUWtUL3p4Q1lZT0c4cnR0OTNPN2JmZnpwZGZma2xWVlNVbEphVm90'
    b'VnFDUTBJUUJJRWhRd2FmCkl6RjArSVVLNkxRNktxdXF5TXpNWXV1V3JkeTZZQUVGK1FWNFBC'
    b'N01vV1lpdTBmaGNqbFpjTTExUE5oa0pqS2dvcDlQVDB4QXpmb2cKQjlrK1BkMHY4Z1QyUlcy'
    b'eEFpaHNEbkp5UzFzWUJrUk9hSDBNOVFiUjUrVUhpSW1OcFNBL0gxTndNQ0hCSVZSWFY3SHp6'
    b'Mjl4aDgxTQpoSHoyZlZrZjFJYS9aeUx2dlBzT0ZlVVZqQmd4Z3Brelp6SnExQ2kwR2kxYXJS'
    b'WkZscW1ycjhQdjk3ZGZMeVNrM2E4UlJTUy9STUFmCndHcHQ1ZkRodzR3ZU5ab2JycitCb3FJ'
    b'aWR1L2VUVTVPTHZmZmZ6L05UVTFvTkJyOEFUOTkrbVFSK1NNcjlXTjRQQjQ4YmcrYk4yOW0K'
    b'eU9EQnFOUXFhbXRyU1V4S3BLS2lnbHFMaGN1blhNNm5ueXpqc2tJYktUK2E1NVV1YVhHSU1s'
    b'dk9rT3NpbmxKemNlY0tHMVVCZ3VYMgpHS20vVjg4TmJhR2NOZ21NdTJ3Q1IvS09rSkNRU0hO'
    b'VEV3ME5EYXg5NnlQbTJVem4rQjllUVNGSDcrYnBwNTltOTY3ZGhJV1ppWTJOClplQ2dnU1Fs'
    b'SlRGaTVBZ0dEQnhBL3dIOXljck00cW9aTTlIckRhU21waEdRQTdTMHRORFUySVRYNTBXcjAx'
    b'SmRWYzJDMnhiZzlYcFoKdW5RcEFOWFZWYnovL3Z2NEpJbVltQmdpSXlLSWpZM0ZaclBoY3Ju'
    b'd2VyM0k4dGw4WUd4c0xGWFZWYlMwTlBQeEp4OFRHaHBLU1VrcApJMGVNYUk4RWZUNWVmK1VW'
    b'UmgxcElzdDMvcEozdFNNWWxTTHc3ZkJ3YWlNdVhxdDFVUk1yUkJhcC9kRjR4MnlmSGx0U0dH'
    b'dldmSXZCCllFQVVSWktTay9uNDQ0OFpWK3c0ejZuOVFlY21xWGQzREFZRHNoekFZQWhpM1Bo'
    b'eFpHUmtFQmNYZDA3QzJXNjNveWdLOVEwTkpDUW0KNHZGNENUSUdZVEtaRUVVUm05VkdYVjA5'
    b'ZnNtUHcrSG9TRW9ETEg1NE1YVjFkV3pmdnBYTXpNd3pTNTdDbGkxYjJMMTdEems1dWVmYwox'
    b'NFFKRXlnb0tPUkkzaEUyYnRoSWMxTVQwV2ZLbUZVSTNHd1BaYURYY09FbEJnR2RJakRueHV1'
    b'Ujc3NmlpMWkvQmtHS1NLc29VNmc5ClczTmU0R21sVzNJeVJxTVJxNjI5Z2tCVFVFR2kvM3gz'
    b'c1ZqclllclVhYlMwTkpQVkp4dEZVYWl0dWZEbVNuYTduWWlJY01MRHduQTYKSFVSRVJLRFZh'
    b'QWt5QnAxWk1qVkVSa1hpOW5nNFhXZGg3YmRyaVkyTnBVZlBudFRVMUxCKy9YZWtwS1R5N2p2'
    b'dnRTdjhaak9TVDZLcApxUkdBd3NJaUdob2FBTkJwdFlTR2hyWmI1Y1pHM0c0M3I3ejhLaEVS'
    b'RVV3WU9oeno3SEVVLzlkNHRzelA1bVMvdVBQdWRVR2JtZld2Ci93TTBGNitMZk5FNzc5YzRR'
    b'M2d2cElWQlhqMVJBUTNSUFhxajFXbzVmUGd3Z3dZUDVwNy8raThHbjNZQzU0L0l0b3N5WTBh'
    b'UDVzVEoKRStqMUJ2cjM3NGRPZitIQnREcWREcGZMUlpCQmowNnJ3eTlKS0NoRVIwZlQwdHFD'
    b'd1dERTQzWno2dVFKUWtQTnVOMXVRa05EQ1E4TApvN21wbWVuVHBsTmJheUVtSnByVEZndDFk'
    b'ZlVvaW9KQmI2QzV1YjFjdWJtcGlWTW5UekZxOUNqV2IxalAvbjM3QVlpTGo2ZDM3MTRrCkpD'
    b'VGc4L2xvczlzSk5aczVmdnc0YXBXYXRmM21rUHdqWHlzbW9HWlVxWnNQM242SHA0bnNzbGkv'
    b'QmhtU2x2dHRrYlNvWk5ZWTdZd2YKUDY3OTRjYkcwRkJmVDFoNEdBbitDNzhmYnEySVNxMG1L'
    b'aXFLb0tBZ1pFWEJiRFpmOEZoQkZOdXRqQ1NoS0FvbWs1SDB0SFE4WGkrUgpFWkY4dW13WlE0'
    b'Y05ZL1NZTWV6Y3NSTkJFQmcyYkJpVEprMmlmLzkreko4M2w0RGZUMlZWSmQ5OXQ1NkRCdzhR'
    b'RVJtQnkrWEU0WEJnCk9XM0I0WEFneXpMcjFxM0RVbXNobzN0M2hnNGRTblIwTkczMk5yN2Y4'
    b'ejE1ZVhsczNicU5XMjYrbVUwYk41S2Vua1pUei9OSGlmc0UKaFd2dnVQVlhiNDd3bTdkWUFJ'
    b'bCtOUXR0NGJ3ZjBrSmlZaEloSVNFRUdZTW9LaXlpOE1CaGJnakVYakRkRTlVOUJiMU9SM2hZ'
    b'T09hdwpNQ0lqTC94Mmw1YVdJSW9DRnN0cHVuVkx3ZTN4TUdyMGFEUWFEZVhsRlJ3OWtrZFlt'
    b'SmtoZ3dkeEpPOEk2OWV2UjZWU29kYW9tVHB0CktzWEhUOUJxYmFXaXNvSk5HemZ4N0xOL1p0'
    b'ZnUzUndyUHM2NHNXTnBiVzBsS3JvOVN2UkpQaExpRTdDYzJadkg1L1ZpT1cyaHNLQ1EKWThl'
    b'S3FLOXZ3RkphVG9wUFE4V0dQV3pZc0FHMzJrR21vS0EvMDhpcUFNZkhwWFB2akJuc2VXa1ZT'
    b'WDVORjdIK0ozQUtDcUlvMG1wdAp4ZVAyME5UVVRFeEFqYWdvOEJQSDNTN0t4Q1lrNFBGNENB'
    b'a05KVFUxQlkxR2M4SHczMmExNDNLNVNFdExKU2RuUHphN2paVXJWM0RrCnlGSHV1dk5PMUdv'
    b'Tm1WbFp6SncxaXhkZWVCRy8zMDlxYWlwSlNja2NMejVPMzM1OUVRVUJqVXBOWTJNalM1WXM1'
    b'YlhYWDJQMjdEbFUKVmxaZ05KbVlNbWt5WWVGaFNENkp2THc4OXUzYng0MDMzc2hiYjcrRlhx'
    b'OW4wOFpOcEVsYUpydE45UEpGbzBJZ2dNSjdoMDlSb3ZHeQp4V0RpS2xkN2QzV1pJY0NINjFi'
    b'eTFGTlBjVnJyN1NMVy93VE5Lais5cnB4QVFtSWlwU1h0RnViekx6N0hvcGI0SUtTVk8rM2g1'
    b'eVU2Ck5Gb05iVzF0QkFVRmRjeXEraW1PSGptS3dhRG44S0U4RmkxYXhOMTMzNDNrODFGWlZV'
    b'VkJmZ0dOalEza0Z4UXc0Nm9aT0oxT2Z2Z2gKRjNOWUdJOCsraWhwNmVrVUZoYlExdWJBY3Zv'
    b'MGdrcGszOTU5Mk8xMm5uNzZhVjUvN1RYbXo1K1BMTXRzM3JqcGJHU25VaEVJQkZpNwpkaTBh'
    b'UldDSTE4RDkzZ2pTZnlKNnFoQzR5eDdPaDhFdGJBOXlNdENuSjhHdkljRWo4dGdkQ3ducmtZ'
    b'THJJaTF0dm1TcUc0NWRtY1hnCnl5ZmlseVEwR2czNStRVjh2M01YaHFBZ1ZJa3hSRFc1emhG'
    b'R0FTcjZ4ZEd2WHo4TUJnTUpQNXI4MGtIVzVtWUtDd3Z3K1NRT0hEekEKOW0xYktUNXhndHFh'
    b'R2tKQ3pRd1kwSitZMkZoMjd0aEpaR1FFbWIxN2s5MjNMOHUvWHQ2ZUNvcUtSUEw1YUcxdG9i'
    b'Q3drSnFhR25MUApTQXNscDBxWVBIa1M2Um5keWRtLy95ZnF1MEtvTERMWmJlSkdoNWxCWGdQ'
    b'aFArbU0vckVUM045bm9GanJJVWZuWm9qWFFKQWlFbEZRCnk1cERlMG53YTBpOStHWnFYUm9W'
    b'cEJhMVJOTEVFUjM1TlgvQXo5WlBsL05FYXhUdkIxcXBjbFh5dlY1UGp4L2wwTFFLNkxWNmpD'
    b'WVQKV3QzNVFxUEQ0YUNpdklLVTFEUWVmZVJoNGhNU2VQbVZWeWtwS1NVNUtaRldxeFZabHFt'
    b'c3JDUXRMUTJ0VHNmbXpWdVlPMjh1Mjdadgo0NW81MS9MZGQrdVpOV3NXbjMvK0JRY09IRGp2'
    b'TSs2NVp5RnIxNjVsN2VvMUpCYlZJUXNRR2hCSjhXdEprelQvY1RKWnJjRFZ6aEJlCkQyMG1m'
    b'MFlXdzljVW8xY0U3clNINHhVdXpocUNTNEpZaFZvdmZmeCtxbXVxQ2ZqOXJIMytUZTZ1MFJH'
    b'a2lGenVNckkwMk1weHJSY1oKcGFPV1NVUkE1NVhRYWJWWVcxczdydFhRMEVCTGN3dkhqaDNE'
    b'YXJXeTlPT2xWRmRWYys5OTkzSG5IWGVRMWFjUHZYcjJZdk9XemN5NAphZ1lmZnZRaEIzNDR3'
    b'Qk5QL0pIaTQ4VkVSRVJRYTZsbDRxVExXUGJKc281eFJ4ZEN1QStlV25BUFR6Ny9KMnBuUDQ3'
    b'Si96OUpiN1dqCkVnKzl4QUJoY2pzdDlSZnBaSnBMZ2xnTktqODJ1NTM2aGdZb3NUQ2oySTNx'
    b'akZJUzUxZlRyVnMzb3FLanNHK3FPbWZZUnFESmhrK1MKQ0FRQ1NKSkVVV0VSZ1VDQXlzcEtG'
    b'RVhoOGNjZkp6ZzRtQnR2dW9sMTY5YXhkZXMydG03ZDFuSCtxbTlXZGZ6N3lTZWZBbUQ0c0JG'
    b'TQp2T3d5cnBzL24vUzB0STcvL3pHUy9Sckd1WTBNOU9xaDFjdTNMNzlGei91dXdQamFkNys2'
    b'NEtXN3BHV3N4OGp1dmZzWUwwUmQ5TC9aCkplRmpsV2w4RlBsczFGc3NqTnBVZWs3eTFTa3Fu'
    b'T3htNHRTcFUvUnhxZ243RWJFYU0rUHBOV29vZXIyT3Fzb3FXbHBhcUttcHhtYXoKOGV4emYy'
    b'SENaUk80ZXZaczh2SU9keFRhL1R2a0Z4U1FFQitQSUFvTUhEaUlKVXVXRUFnRVVDR1E2ZE54'
    b'dmNQTWxhNWdFZ0lhUkFSRQpCS0txYmRUM1Q2Slo1U2V5MXY2cm4wTnZuNDQ4bllmSWdKcUVp'
    b'N3RkN05Md3NYcElXcUw2OXFIZ2t6V1k1WE5MVVR5Q3pMWHpydVg3ClBkL0Q2bk5uUzRVbXg1'
    b'T2QzWWZxNm1wV3IxcU55K1hDSC9DVGtaN0JlKysreThlZmZNeGZuMysrWTM3N2Y0TGFtaG9l'
    b'ZlBEM3FCQkkKMXBybzE2YWl0ODlNYjUvdVo2c05qTEpJOEFkYk9IeFZGbTFSQXBuZGU3Q2x0'
    b'WXB4Snh6bnZBai9EZ0l3YitiVjFKZFZ3dTZMZThQegpTNEpZOFg0TjczNzVGVmY1ejUrU3R6'
    b'ZGFJT0p3SG9keUR6RExIM0tPWHpac3lqaUNnNE14bTgzY2NPTU5wS1MwYTFtNU9ia3NXTEFB'
    b'CnUvMTg2NkZTdGM4UC9hZGZGaWFyR09qVkV4MVFFeFZRWTVKRk5HYzB0ZVJmb0I4bFNtb3F2'
    b'ai9CWlIvOWhjcUQrUXdPR3NMQk43OWcKY3ZVdmE1QTRVbDdDU1VzbFBWUnFvZ0txaS9ZM3V5'
    b'VGF2N1JLKzI0ejhULzVJY3MwUG80YkpIcjE2a1cyVjljUlpWV3BKZHkzVFdiNgo5T2xBZTZs'
    b'S1FrSUNiWFk3Zi8vYjM1Z3paMDRIcVlKbGtZbnVzL01WSG52c01iWnUzY3pJa1NQUW5vbTha'
    b'anBER09FSklrUFNFaHRRCkV4RlFjMHpyNFQyejdSZTFiTVcxK2xpeDdETXFTMHJJN0pQTndC'
    b'dXV4dmNMb3JvcXRjU1RiN3pFZTU4c1pWdVFzOHRpL1U4UnBJajAKbEhTWTVIUGZnMTJ4QWph'
    b'YmpWZGZlWlY3YmVFRVVQZyt4TWV3bHhmejBPMExFQVNCNnVvcW1wdGEyTGx6QnhzM2JTTHZj'
    b'QjRBa1FFVgpFOXdtaG5vTk9FU1piUVluZDkxOU55NjNpMGNlZnBSOSsvWnpqVFBrZ2xVVEFD'
    b'TTlSc0x1bXN5Ty9IeHNRZ2laMjA5aCtEZUZkK21TCkZsYmxVVHd0azZUa1pNWStNWTYvZkxl'
    b'THZnV04vOUZ6Q0paRlRoVVU4dmYzMzhPcDhuVVI2MzhEMXpwQ3o5TzIrbDgvZzRLUFB5SEMK'
    b'QzkwbEhWdTdxWGhrOHdwQ1FrSm9iR3pFWWpuTnl5Ky9STTcrSE5yYTJoQVI2T1BUTWRGdEls'
    b'WFNkRWdUT1ZvUDNYdjBZUHo0Y1N4ZQovREMxTlRVTTh4b1k2ekgrUzdJUEhqU1EwYU5HOGRG'
    b'SEg5SHI3d3NwZk8xek1zcHMyTVVBWlFsR1RLT3lzVGEzRXRoYndHaW5BUlVDCkNYNE56YzRB'
    b'cnp6N0xDKzkrU2J4c3lleHlyZVNaS3ZNb1BwL3JVZUV5U3BhYm5rZWpjbUdWUjNvSXRiL0Ju'
    b'N3FUeFFiQTlEVWhGYXIKcForOW5TTFIwMFpoTXBtNDVwcHJNUnFET0ZaMERKL1hTN3FrNVFx'
    b'dm1YNCtIY2FmV0wxNmxaL3ZndHJ3bkxSenl5MjM0dmY1dU54bApZb1RYUUFEbFowWE1QSzJi'
    b'VFg5NW51VXJWbkRublhmdy92c2ZjTTFqQ3hCVUt1VFdWbDY5LzNlMHRMUlFWSFFNdFZyRngv'
    b'ZitrY3VPCnRISkk1K1pZMlNsbVhIVVgyOVp2Wk1LMU0xRENqVXlkTnBVMXcrYVQyUHF2eVJV'
    b'aWk5eGhEN3ZvSndKZXNpMzJ6Um5STExqdGRqUWEKRFZFQk5RRVVvbEtTS0MrdjRPU0pFelQr'
    b'VU1DTVpqMS9ib25oZDdZSVJub001NUdxVlF6d21ya1p6eGsvUi9MNXVNWVJ5aFd1WUZwRQpt'
    b'ZVVtR3g4RnQ3SW5RdWFFVHFKWmRYYUw4Q0ZlQTJFV096ZmZmRE1BQ3hmZHc3SmxuN0JzMlRL'
    b'U2s1TVJCQUZGbHFtdnEwT24xNU45CjQ4eDJIY3hqd05acTVZTi9mTUJ6VC8rSlJUZmVTbHhj'
    b'SENxVmlpTlIvN2t6L2t1aXlTNWkvUUtFcGlZUUhCek13SUVEa1FRRmk5cFAKVnI5Ky9PMk5O'
    b'MGlUdFB6Qkdza1lUeEFoOHM5L1JjMlpNdDkvSXRXdlpjeVp2c1VNU2N0OGg1bE1TVWZGMENS'
    b'R3JIbWRTWVVyaU5qMApNcTQzNzZIMnNWbU12RzBlRXlkTnBMS3lpbjU5KzdMczAwL1pzblVM'
    b'WVdGaDNIdnZ2ZWgwT2hLU0VuQTVuY2hTdXlWU0lURFhFVXA5CmZUMXRmaDhUWjEvRmxNdW44'
    b'TTQ3Ny9EQXAyL1RITm81eGtkZXNyTWJQTWNxeWM4L1NwdkRTVU9NR2tlYlRDL0p4K1RKazdH'
    b'dkt2aVAKOG5BbVdlU1ByVkY4R054S3NkWkx0Y3FIUTVUUENSS0dlNElvL3I2SUd3L2NpRGtz'
    b'ak9uVHB6TjkyalN1dm03dUJkdTdBTVpQR00rcQoxYXNwcjZna05qcUdzckp5Zk0xbnQxeEo4'
    b'bXRJOW11bzgvdVpOMjhlb2lneTQ2cXJpSTZKb21SMEtoSGZuYmpraVhYSnR0anYwYnVvCnY2'
    b'SWZTNWN1NWQxMzM2T211cHFIRmovRVBXT21jMFBGZjU0NGFWUUZPSzFxTDcyQjltNmdteDFo'
    b'cUgvMFZFNW92UHdqeW9IUGR6WVMKRTBXUnlNaElFcE1TNmRHOUJ4cXRoclRVTkdiUG1VMXNi'
    b'Q3hXcTVVMzMzeUxoeDc2QXpVMU5YeTQ4Rkg2YnkzcE9MOU81ZWV2WVUzMApHOWlmalJzM0lz'
    b'c3lvaWh5OUdnK1g0NjVqdjZPUzNvUVcra2xhN0ZHZWd6c2RNdDh2Znhyamg0OXdyeTU4M2pu'
    b'N1hjZ0k0N2RHanZtCnloWWlaZFU1MnBjQ25OSjRhZE1JZU0xQlhQYmFZNHp2M1l2Z1lCUFdG'
    b'MTlreU9BaHhNVEU4TVBXSFVqTk5tTDY5Q0E1SXgxZjdnK00KcWF4Zzh1VEp2UHZ1dTR3WU1Z'
    b'S2NuQno2OXUxTGZuNCtGUlhsekp3NWk4eXN6STY1N21hem1mejhvOXgwMDAwOCtlUlRCRTZl'
    b'MjhRUgpHMURUMTZ2ajZKR2pWRlJVWUxOYTZaMlpTVU45UFd2Q1BJUjcrRVVDYkpmRitsK0VR'
    b'NVRaMU4rTUxjTEFoZzBiR0Q5K0FwOS8vaGxmCmZmMFZjMmJQWWRrbm55SzR2V2lEOU9TdDNj'
    b'TG9PVmR5N1lLYjJiQitBOTk4czVKaHc0Zmo5L3VaT1hNV2E5ZDl5NDNYMzBCQ1lpSSsKbjQr'
    b'V2xtYXFxMnFvckt4ZzM3NzlSRVJHMEx0WGI0d21JejZ2ait6c1BnUUhoeENRQThUSHg5UGMz'
    b'SXhXcSsxb2RnVVlNMllzRXlkZQpoa3Fsd3ZEbkw4K3I5Q3pVZXZrc3pzdW5uMzNHL24xN09Y'
    b'RGdJQXNYTG1UVDVYZlJROUpkdEpVTG5kcGkvZE5IbXA1blJmM2hIZXpjCnVaT1NVNmZZdUdF'
    b'RGZmdjBaZFUzMzNERmxkUHAzYnMza2lTeHNVZDM1czZiUzFWVkpVRkJRZVRrNUZKY2ZCeVh5'
    b'OFg3NzcxUGFHZ28KUHE5RVJubzZZZUZoMkt3MlJKV0kzVzZuc0xBUVVSVDQvZTkvajFhcnhX'
    b'S3hjT0NIQXhRZE8wWlpXU25KeWNuTW1qV0xBZjM3Y3lUdgpDR25wYWVoME9rcE9uZUxraVJN'
    b'WTlRYitIRENmZC85cGtvWk1tNDh2dnZpY2RXdlh0US9EYldobFJFQjlLWlBxMG80Sy80bXE2'
    b'MGR3Cnd5MDNzWFA3RHVLOUlpKzkvQXBQUHZra08zYnV3cURYczIvZlB2Nzd2LzlFOFlsaXlz'
    b'dkxXTEhpRzRxUEZ3TmdzOW1RSkFsSmttaHEKYXVLOWQ5OGxFQWp3MFljZjR2VjZzVmhxc1Zn'
    b'c1RKbzhDWXZsTkE4OXRKaXhZOFl5WXZnSTdyLy9mZ3J5ajdKZ3dRS2VlKzQ1akVZagpzMmZQ'
    b'SVQ4L241Q1FFRVJSSkRxNnZidkc1WEVqSVY5UVpBMldGTDcrNnV1T0Njc1Q5bGorNDlHWFhW'
    b'SGgvNlZ3MnJ1OVV1R0hEVnRaCmJJMmtzUzFBaTJpalhOUEl2U09uRXVpYnlxWXRtd0dZT0hF'
    b'U3AwNmUvSmZYOHdmOGpCMDdscmk0T0h5U0Q3VktRM1JNTkc2M216V3IKVndPUW1KVEVVMDgr'
    b'd2RScDB5Z3RMZVc2K2RleGE5Y3VYbnJwSldManpqYVlMbDI2bEp0dnZwbUdoZ2FPYVgwTThw'
    b'NWJkMjhYWmZicAp6eDM2cGxVNng0RGJTNTVZTFU4dllkUGdDR0pQMWdNaFJBVlVSQVZVOUR4'
    b'VHB0dzBZeVkrbjQvdDI3WWhpc0xQS3RsYUJENDMyWEMwCnRhSFJhTEdjdHVCMmU1QWtpUWNm'
    b'ZUxEaitNek1UTDc2K2lzYUdocTVkOUc5ckZ1M0RwMU94LzBQUEVCbVppYloyWDFZOWMwcUJn'
    b'MFoKeklDQkEzand3UWQ1N0xISE9LN3hNdENyN3hCQmptazlmQmxzWjhSbDQ5bXhZd2ZRbmt1'
    b'OGlBZDkvTGFJbFNGcHFTcHV4akJ2Q29HUAo5cCtuWDFXZnRqQmw4aFRLeXNvNm9yRjZsYjlE'
    b'UVhlSUNwRnllemxNaHFURjY1TTRYVmVIMVdvbElTR0Jvc0tpYzY1WFdWbko3eDk4CmtHM2J0'
    b'aVBMTWlOR0RPZUtLNjlrK3ZUcFdDd1dac3ljeVhYenJ5TTVLYW1kUU1YSE1KbE01T0tnUWUw'
    b'bnpxOUdpSXNneDI3SGFEUjIKOUJzQ1RIR2I2Q3pvRks5SEQ0ZklEWGZmVHRtQWN6dHhGR0Rr'
    b'MkRGa1pXVWhDQUlHUmVSK2E4UTVBcWlNUXZPWnZOdFFyd0dEWGtkaQpRaUtpS0dLM3Q1R2Ft'
    b'bnJPTloxT0oxdTJiRVdXWmE2ZGV5MzNQL0FBYytiTVpzbVNKY3laUFlkWk0yZHkwODAzNGZG'
    b'NGNMdmRhRFZhCmJyNmxQZTFUcnZaeFBON0FpRHZtTS8vNjYvQjRQSHo5MWRjQTlQWHA2ZTNU'
    b'ZFJIcllrSjRRT1JZMFRGbWZQZzhkYXF6U1Z3QmFLaTIKOE02Nzd6QjZ6R2pjZ3N3YldRTFB2'
    b'UEV5TDc3NDRsbHluY2tWbWdNcXZsNzJHUysrK0NKSDhvNHdkT2dRUXMyaFAvdTU4K2JPbzIv'
    b'Zgp2bHgvL1EzOC9XOS81NXBycjJYZXZIbDgrZVdYaUtMSWJRdHVZODJhTmR4OTk5Mk1HajJx'
    b'M2EreTJ6Q1pqR1QzNmNQczJiTUJ5UExwCnVMSE5UR2RDcDVuemJyZmJ1ZmUrKzNqSDNJcGJP'
    b'QnVCNVQzL1BpdFhyaVFoUHFIanVLU2taS3hXS3dCeEFRM2RKQTB1UVdiMVFETloKZ3dZaVNS'
    b'TGw1ZVY4OEk4UDJMSjV5ODkrNXZ2L2VKOXhZOGVSZHppUDBXTkdjOTExODVrNmRSb3BLYWw4'
    b'dXV4VHRtL2ZUbE5URSsrOAo4eTVQUHZGa3gwaWt1cnA2Y25OejJiRmpCNk05UWR4cEQ3dms1'
    b'WVdmb25Qcy9pWEFoRGNlSnpZdWpnT0YrWGpzYlhRLzQ3d25PaFErCjJyS09iY1ZIQUpBa2lh'
    b'Ky8vcG85ZS9hZ1F1REd0bENpWkRYSCs4Znk4QmZ2SWdvaVc3WnNvVStmTE41ODh5M2NIamNI'
    b'RHg1RVZHQ0MKMjRoWGdMWXozY2VscGFVZE1rRnpjek1ybHEvZ29ZY2VRaEFFSG5ua2tZNGh1'
    b'VnF0aHNsVHBwQ1psY242NzlaejhPQkJqaGNmSjduVgp6NjF0WVFpZGIzTzV6ckhsaVZZUitH'
    b'YlM3ZVRIYS9BMzI2aFZuMTBPVlFqYzJoYkd0MEYydnRjNzhRdWdVUVF5SkMwelhjRWRLUjlY'
    b'CmRUM0Z4NDh6ZDk1Y2R1L2V6ZHk1YzNuc3NmWktVb0FSbmlCbU9VT1FVZGhqY0hGYzQ4VW5L'
    b'RlNySlR5Q2d0UHA1SzIzM3NMdGRuZE0KUVA0bmJyMzFWdExUMC9ucXE2OFJCSUdvcUNnOGRV'
    b'My9zcER3VXNjbHYvdlhMNEVrS0FUNCtTYlBITDJMTGNscW5CNDNDeGN1NHY0SApmc2NWMDY5'
    b'ZzRjS0YvT25PZS9tOU5mSzhjMlVVaXJVKzJzUUFkVmNOSkhoM01Ta3RFaW9GWGpVM1l6UWFl'
    b'ZURCQjFpM2RoMU9weE9UCnljakVTUk1KUFBNWmFTNnhROC9TS1B6YjB1WkxDS1dkYnJQeGY3'
    b'bnU4NjkzaWc4THFOZ3Z0OUI3eUVEV3JGbERjWEV4Qnc4ZTVJVVgKL2twSmc0VmxKWWNKVmtS'
    b'T2FYMVVhaVJpQXhvMENFUUgxQ1Q2TlpoUDFORzNUVVc0ckVLckNEU3FBNXdXSlJ3T0I5T21U'
    b'ZVhaNTU3agp6OC84bVhGang3R3E1aGlCS0RPcnZEV283NWhPVGxpQS9XSWJrWGJwdkIzdUw4'
    b'V2w4RGRsc1M2RVpjRldqbW85QkNraWJhSk1BSVdwCjA2YVNzejhIcTlXS1JxdWxSL2NNTXJP'
    b'eVNFMUo0Y1VYWHlJbW9DWlYwdUlUWkc1dU0zZlV6cDhqUzRneW13MU9kaGdjQUJpTlJrd20K'
    b'RS9YMTlXUmtaREJtekJpMmJkdEdWVlVWOGZIeHBKUlpDWk5WTklrQnBydE1GMzJGNkwreldP'
    b'cmZLcUZLTlQ2K05ObW9WL25iYWFHMApqLytPaVlsaDl0VlhjL2RkZHpOMzdsd2tuNCtpb21O'
    b'WVR0ZHh6VFhYRUI0ZVFlOWFEd084ZXBJQ1dtUUJ4Sis4bXVWcUgzOHp0M0MyCmtCbGVlT0VG'
    b'TEpaYXZ2enlLeW9ySzNHNTNhU25wVkZWVllXbnVnR3ZvT0Z5Vjd0QTZ1OEV2dnh2MG1JcHdI'
    b'S1RqZW11WUU1b3ZIVHoKYTRrTXFHZ1RaYXJVRW50Nm1aaDIvVngyN2RwSlpVNGVNNXdoeUlK'
    b'Q2c4cFA5Wm5BUUswSVhPVUtKdUlDVGFOZm1Hd0VLeUk5ZlRyQwpaUlZIdFI2TzZEeUVCMFNT'
    b'L1ZwU0pRMXRaNGIyOXBDMERQWWFxRkpMbDNUOTFVL2YyOS9zVXVnWE9LZEs5THlsVEpCWmJX'
    b'eWpVZVZuCm5pUGt2SzExRmRwbGh3dlYxUCtyN3A2Zm9sRVZ1S2c3bXJ1V3dsOEk5Yjk1bll5'
    b'S3lBMW5laGtiTDdBN21BQS8yNmp4U3paUjZvU2sKQW42RE82eitHblRXSDcrTFdGM29JbFlY'
    b'dXRCRnJDNTBFYXNMWGNUcVFoZTZpTldGL3h2OFA2V0RobkVmd1I2dkFBQUFKWFJGV0hSawpZ'
    b'WFJsT21OeVpXRjBaUUF5TURJekxUQTVMVEF5VkRFMU9qRTJPalV4S3pBd09qQXd6aUNMUGdB'
    b'QUFDVjBSVmgwWkdGMFpUcHRiMlJwClpua0FNakF5TXkwd09TMHdNbFF4TlRveE5qbzFNU3N3'
    b'TURvd01MOTlNNElBQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxMDk0NSIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_MOW')

RU_MOW = b64_RU_MOW
index.append("RU_MOW")
index.append("Russia Moskva")
catalog["RU_MOW"] = RU_MOW
catalog["Russia Moskva"] = RU_MOW
country["Russia Moskva"] = ('RU_MOW', '', 1)
lookup["RU_MOW"] = ('RU_MOW', '', 'Russia Moskva', 1)
lookup["Moscow"] = ('RU_MOW', '', 'Russia Moskva', 1)
lookup["Russia Moskva"] = ('RU_MOW', '', 'Russia Moskva', 1)
details["RU_MOW"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Moscow"}
regional["RU_MOW"] = ('RU_MOW', 'Russia Moskva', 1)
regional["Russia Moskva"] = ('RU_MOW', 'Russia Moskva', 1)
#----------------------------------------------------------------------
b64_RU_MUR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSIgc3RhbmRhbG9uZT0i'
    b'bm8iPz4KPCFET0NUWVBFIHN2ZyBQVUJMSUMgIi0vL1czQy8vRFREIFNWRyAyMDAxMDkwNC8v'
    b'RU4iCiAgICAiaHR0cDovL3d3dy53My5vcmcvVFIvMjAwMS9SRUMtU1ZHLTIwMDEwOTA0L0RU'
    b'RC9zdmcxMC5kdGQiPgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sOnNw'
    b'YWNlPSJwcmVzZXJ2ZSIKCSB3aWR0aD0iNDUwcHgiIGhlaWdodD0iMzAwcHgiCgkgdmlld0Jv'
    b'eD0iMCAwIDQ1MCAzMDAiPgo8cmVjdCBmaWxsPSIjMzk1Yzk4IiB3aWR0aD0iNDUwIiBoZWln'
    b'aHQ9IjI0MCIgeD0iMCIgeT0iMCIgLz4KPHJlY3QgZmlsbD0iI2Q1MzEyYiIgd2lkdGg9IjQ1'
    b'MCIgaGVpZ2h0PSI2MCIgeD0iMCIgeT0iMjQwIiAvPgo8cGF0aCBmaWxsPSIjZWRiYjMyIiBz'
    b'dHJva2U9ImJsYWNrIiBzdHJva2Utd2lkdGg9IjAuNSIKZD0iTSAxMDgsMTgwIApDIDEyMCwx'
    b'NjAgMTQwLDE2MiAxNTgsMTYyIApDIDE4MCwxMzAgMjA2LDEyNyAyMjUsMTI3IApDIDI0NCwx'
    b'MjcgMjcwLDEzMCAyOTIsMTYyCkMgMzEwLDE2MiAzMzAsMTYwIDM0MiwxODAKCkwgMzc1LDEy'
    b'OCAKTCAzNDAsMTY5IApMIDM2MywxMTcgCkwgMzI4LDE2MyAKTCAzNTIsMTExIApMIDMxOSwx'
    b'NTggCkwgMzM4LDEwNSAKTCAzMDgsMTU2IApMIDMyMiwxMDQgCkwgMjk2LDE1NCAKTCAzMTEs'
    b'OTkgCkwgMjkxLDE0NSAKTCAzMDIsOTEgCkwgMjgzLDEzOSAKTCAyOTIsODMgCkwgMjc2LDEz'
    b'NCAKTCAyODEsNzUgCkwgMjY2LDEyNyAKTCAyNjgsNjkgCkwgMjU2LDEyMyAKTCAyNTMsNjUg'
    b'CkwgMjQ1LDEyMiAKTCAyNDEsNjIgCkwgMjMzLDEyMCAKCkwgMjI1LDYwIApMIDIxNywxMjAg'
    b'CkwgMjA5LDYyIApMIDIwNSwxMjIgCkwgMTk3LDY1IApMIDE5NCwxMjMgCkwgMTgyLDY5IApM'
    b'IDE4NCwxMjcgCkwgMTY5LDc1IApMIDE3NCwxMzQgCkwgMTU4LDgzIApMIDE2NywxMzkgCkwg'
    b'MTQ4LDkxIApMIDE1OSwxNDUgCkwgMTM5LDk5IApMIDE1NCwxNTQgCkwgMTI4LDEwNCAKTCAx'
    b'NDIsMTU2IApMIDExMiwxMDUgCkwgMTMxLDE1OCAKTCA5OCwxMTEgCkwgMTIyLDE2MyAKTCA4'
    b'NywxMTcgCkwgMTEwLDE2OSAKTCA3NSwxMjggCgpaIiAvPgo8L3N2Zz4K', 'RU_MUR')

RU_MUR = b64_RU_MUR
index.append("RU_MUR")
index.append("Russia Murmanskaya oblast Murmansk ")
catalog["RU_MUR"] = RU_MUR
catalog["Russia Murmanskaya oblast Murmansk "] = RU_MUR
country["Russia Murmanskaya oblast Murmansk "] = ('RU_MUR', '', 1)
lookup["RU_MUR"] = ('RU_MUR', '', 'Russia Murmanskaya oblast Murmansk ', 1)
lookup["Murmansk"] = ('RU_MUR', '', 'Russia Murmanskaya oblast Murmansk ', 1)
lookup["Russia Murmanskaya oblast Murmansk "] = ('RU_MUR', '', 'Russia Murmanskaya oblast Murmansk ', 1)
details["RU_MUR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Murmansk"}
regional["RU_MUR"] = ('RU_MUR', 'Russia Murmanskaya oblast Murmansk ', 1)
regional["Russia Murmanskaya oblast Murmansk "] = ('RU_MUR', 'Russia Murmanskaya oblast Murmansk ', 1)
#----------------------------------------------------------------------
b64_RU_NEN = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMTIwMHB4IiBoZWlnaHQ9IjgwMHB4'
    b'IiB2aWV3Qm94PSIwIDAgNDUwIDMwMCIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzE5OTkveGxpbmsiPg0KPHJlY3QgZmlsbD0iZ3JlZW4iIHdpZHRoPSI0NTAiIGhlaWdodD0i'
    b'MzAwIi8+DQo8cmVjdCBmaWxsPSIjMDAzOGE4IiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjI2NCIv'
    b'Pg0KPHJlY3QgZmlsbD0iI2ZmZiIgd2lkdGg9IjQ1MCIgaGVpZ2h0PSIyMDQiLz4NCjxnIHRy'
    b'YW5zZm9ybT0idHJhbnNsYXRlKC02MS44NzUsIDE5Mi43NSkgcm90YXRlKC00NSkgc2NhbGUo'
    b'Ny45NTUpIj4NCjxwYXRoIGlkPSJob3JucyIgZmlsbD0iIzAwMzhhOCIgZD0iTTAsM3YtMWgx'
    b'djFoMXYtM2gxdjFoMXYxaC0xdjFoMXYtMWgxdjFoMXYxaC0zdjFoMXYxaDF2LTFoMXYxaC0x'
    b'djJ6Ii8+DQo8dXNlIHg9IjUiIHk9IjUiIHhsaW5rOmhyZWY9IiNob3JucyIvPg0KPHVzZSB4'
    b'PSIxMCIgeT0iMTAiIHhsaW5rOmhyZWY9IiNob3JucyIvPg0KPHVzZSB4PSIxNSIgeT0iMTUi'
    b'IHhsaW5rOmhyZWY9IiNob3JucyIvPg0KPHVzZSB4PSIyMCIgeT0iMjAiIHhsaW5rOmhyZWY9'
    b'IiNob3JucyIvPg0KPHVzZSB4PSIyNSIgeT0iMjUiIHhsaW5rOmhyZWY9IiNob3JucyIvPg0K'
    b'PHVzZSB4PSIzMCIgeT0iMzAiIHhsaW5rOmhyZWY9IiNob3JucyIvPg0KPHVzZSB4PSIzNSIg'
    b'eT0iMzUiIHhsaW5rOmhyZWY9IiNob3JucyIvPg0KPHVzZSB4PSI0MCIgeT0iNDAiIHhsaW5r'
    b'OmhyZWY9IiNob3JucyIvPg0KPC9nPg0KPC9zdmc+', 'RU_NEN')

RU_NEN = b64_RU_NEN
index.append("RU_NEN")
index.append("Russia Nenetskiy avtonomnyy okrug")
catalog["RU_NEN"] = RU_NEN
catalog["Russia Nenetskiy avtonomnyy okrug"] = RU_NEN
country["Russia Nenetskiy avtonomnyy okrug"] = ('RU_NEN', '', 1)
lookup["RU_NEN"] = ('RU_NEN', '', 'Russia Nenetskiy avtonomnyy okrug', 1)
lookup["Nenets"] = ('RU_NEN', '', 'Russia Nenetskiy avtonomnyy okrug', 1)
lookup["Russia Nenetskiy avtonomnyy okrug"] = ('RU_NEN', '', 'Russia Nenetskiy avtonomnyy okrug', 1)
details["RU_NEN"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Nenets"}
regional["RU_NEN"] = ('RU_NEN', 'Russia Nenetskiy avtonomnyy okrug', 1)
regional["Russia Nenetskiy avtonomnyy okrug"] = ('RU_NEN', 'Russia Nenetskiy avtonomnyy okrug', 1)
#----------------------------------------------------------------------
b64_RU_NGR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iMTM1'
    b'MCIgaGVpZ2h0PSI5MDAiIHZlcnNpb249IjEuMSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzIwMDAvc3ZnIj4KIDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKDAgNy4yMTM2KSI+CiAgPHJl'
    b'Y3QgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMCAtNy4yMTM2KSIgeD0iMjM1LjA0IiB5PSItMTEw'
    b'LjY3IiB3aWR0aD0iODYzLjc3IiBoZWlnaHQ9IjExMzAuMSIgZmlsbD0iI2ZmZiIvPgogIDxy'
    b'ZWN0IHg9Ii00MS4xMzIiIHk9Ii02My4wNDIiIHdpZHRoPSIzNzIuMTUiIGhlaWdodD0iMTA0'
    b'NCIgZmlsbD0iIzJmNDE4YyIvPgogIDxyZWN0IHg9IjEwMDIuOCIgeT0iLTc0Ljc5NCIgd2lk'
    b'dGg9IjQzMi44NiIgaGVpZ2h0PSIxMDI0LjQiIGZpbGw9IiNkMDM1MjgiLz4KIDwvZz4KIDxn'
    b'IHRyYW5zZm9ybT0idHJhbnNsYXRlKDM2OC45NyA0OS44NDQpIj4KICA8cGF0aCBkPSJtMjk3'
    b'Ljg0IDYxNXYtNDIyLjZoLTE2OC41NHYzNTkuNzRzMC43ODExNyAxMS44MzYgMTEuMzQ1IDIw'
    b'LjQyN2MxMC41NjQgOC41OTExIDIwLjA5NCA3Ljg1NzEgMjAuMDk0IDcuODU3MWgxMDcuNTdz'
    b'MTIuODU1IDEuMTczNyAyMS4yMTIgMTIuMjQ4YzguMzU2OCAxMS4wNzQgOC4zMjE1IDIyLjMy'
    b'OSA4LjMyMTUgMjIuMzI5IiBkaXNwbGF5PSJub25lIi8+CiAgPHBhdGggZD0ibTEyOS41NiAx'
    b'OTIuMjh2MzU2Ljk3czAuMDU5MSAxNC41NTMgMTAuNDY5IDIzLjA5NGMxMC45MDEgOC45NDMy'
    b'IDIzLjc1IDguMDkzOCAyMy43NSA4LjA5MzhsMTAyLjY1IDAuMzQ2MjVzMTUuMTI0IDAuMDI0'
    b'IDIyLjYwNCAxMS4xMjJjNi4yNjA1IDkuMjg5IDguODcyNSAxOS43NDEgOS4zNDM4IDIyLjU5'
    b'NHYwLjc4MTI1czAuMDM1Ni0wLjIyNjY2IDAuMDYyNS0wLjQwNjI1YzAuMDI2OSAwLjE3OTU5'
    b'IDAuMDYyNSAwLjQwNjI1IDAuMDYyNSAwLjQwNjI1di0wLjc4MTI1YzAuNDcxMjktMi44NTMx'
    b'IDIuMjk5Ni0xMy4wNzQgOS4zNDM4LTIyLjU5NCA4Ljk2NzktMTIuMTE5IDIzLjI5Ni0xMS40'
    b'NjkgMjMuMjk2LTExLjQ2OWgxMDEuOTVzMTMuNjYyIDAuODI0MDMgMjMuNzUtOC4wOTM4YzEw'
    b'LjkwMS05LjYzNTcgMTAuNDY5LTIzLjA5NCAxMC40NjktMjMuMDk0di0zNTYuOTdoLTE2OC44'
    b'MS0wLjEyNXoiLz4KICA8cGF0aCBkPSJtMTMyLjM4IDE5NS4xOXYzMTguNTZoMjQuODAyYy0w'
    b'LjQ5ODg2LTIuNzkzNC0yLjA4ODktOS4yNjU3LTcuMTA4Ni0xOS42MjUtNi45MTA3LTE0LjI2'
    b'Mi0xMC4zODEtMTUuMDc0LTEwLjM2NS0xOC4wMzEgMC4wMTYtMi45NTc1IDEwLjExOC0xMS43'
    b'NDEgNi40NTEtMjMuNDA2LTIuNTcwMS04LjE3NTMtOS45OTA5LTUuNzY3Ni0xMS4xMTctNy4z'
    b'MTI1LTEuMDUzOS0xLjQ0Ni0yLjA0NDMtMTYuNTY1IDIuMzQ4Ni0zOS4yODEgNC4zOTMtMjIu'
    b'NzE2IDEwLjA0MS00MS42MDEgMTcuODgxLTYxLjQzOCAxMC4yNzYtMjYuMDAyIDMyLjQxMy03'
    b'MC4xOTUgMzcuOTU0LTc0LjgxMiAxLjI2NzctMS4wNTY1IDcuMzI3OCA2LjI1IDcuMzI3OCA2'
    b'LjI1czEyLjMyMSAwLjM0ODI1IDE1LjAzMSAxLjI1YzIuNzYxMiAwLjkxODU5IDcuMTM5OSA1'
    b'Ljg3NSA3LjEzOTkgNS44NzVzNS40NzUyIDEuMzMzOCA4LjA3OTMgMi4zNDM4YzMuMDY3NiAx'
    b'LjE4OTYgNC43NDU4IDEuOTU2OSA2LjI2MzEgNC44MTI1LTMuNzMyMyA5LjI5MjUtNC44MDky'
    b'IDQuNjQxLTEwLjU4NSAxMi41LTMuNTkxOSAxLjYxNzQtOC4wMDQ1IDAuMjQwMi0xMS4wODYg'
    b'Mi41LTQuOTgzNCAzLjY1NS02LjQ1MSAxOC4yMTktNi40NTEgMTguMjE5czcuODg4NiAwLjkx'
    b'MDMzIDE1LjAzMS0yLjg3NWM2LjQzOTMtMy40MTI2IDEwLjYzNS04LjM0MjYgMTkuMzUzLTE0'
    b'LjYyNSAxMC4zNDMtNy40NTQgMjAuNDE1LTguODA3MyAyMC40MTUtOC44MDczczIuNTYwMiA1'
    b'LjE0MDIgNC40NDk2IDguNjE5OGMtNS42MDM0IDAuOTA1OTMtNi4yNjY2IDAuNTA0NjktMTQu'
    b'NDk5IDkuNjU2Mi04LjIzMjQgOS4xNTE2LTcuNDUxNSAxMi41NzgtMTUuNjk4IDIxLjYyLTgu'
    b'MjQ2NCA5LjA0MTUtMTMuMjY1IDkuMzExMi0xOS4yMTQgMTMuMTY2IDYuNzMzNiAxLjAzMDQg'
    b'MjQuMDUtMi43ODc1IDI4LjM3MyAxLjQ2OTQgMy43NDcgMy42OTAyIDMuMDQxMiA3LjAyMTgg'
    b'MS45ODcxIDEwLjE0NS0wLjgxNDc0IDIuNDEzOS02LjQ5MDggMy42MDk1LTYuNDkwOCAzLjYw'
    b'OTVzLTMuNjczOC0wLjg0MzQ3LTEwLjAyNC0wLjc1NDY3Yy03LjkwNjggMC4xMTA1OS03LjM5'
    b'OTIgNS42Mjg4LTEzLjcxOSA3LjAxMDMtNS4xODg3IDEuMTM0My0xMy4wMDEtMC4yMDMyNS0x'
    b'My4wMDEtMC4yMDMyNXMwLjcxMjMxIDIuOTg0OSA5LjQ4ODUgMi42ODc1Yy00LjczODIgMTIu'
    b'MjI0LTIwLjIzIDM0LjQ2OS0yMC4yMyAzNC40NjlzMTMuMTMzIDIuNDA2NSAyMC4wNDIgMTAu'
    b'MTU2YzguMjcxNCA5LjI3ODEgMy4wNTg5IDE4LjkyOSAzLjA2ODkgMjQuMjgxIDAuMDEyMyA2'
    b'Ljc4Ni0yLjA5ODkgMTIuNTEzIDQuNjM0NyAxOS44NDQgNi43MzM1IDcuMzMwOCAxNi42NiA1'
    b'LjUzMTIgMTYuNjYgNS41MzEybC0wLjE4Nzg5IDEwLjcxOWgtMjEuNDgycy05LjU3MjQtOS42'
    b'MTgxLTE5LjY2Ni0xNi4wOTRjMC4yNzUxNS0zLjE0ODQgMi44MjM3LTEwLjk3Mi0wLjcyMDI1'
    b'LTEzLjU2Mi03LjIwNzYtNS4yNjkyLTE2LjQ3Mi00LjI4MTItMTYuNDcyLTQuMjgxMmwxLjA2'
    b'NDcgMTQuMjgxcy0zLjU4MiAzLjI1MzktNy41MTU3IDguNzVjLTMuOTMzNiA1LjQ5NjEtNS4z'
    b'NTQ5IDkuMTI1LTUuMzU0OSA5LjEyNXMtMS41MjM5IDEwLjk1NSAyLjEyOTQgMjEuNDA2YzEu'
    b'ODE3MSA1LjE5ODIgNS4zODYyIDUuMzc1IDUuMzg2MiA1LjM3NXMxMC40NDgtMS4wNDQ4IDE0'
    b'LjY1NiAyLjEyNWMyLjU4MzEgMS45NDU5IDIuOTYwMSA1LjEzODYgMi44NDk3IDcuMzEyNWgy'
    b'MDUuM2MtMC4xNzE2Mi0yLjE2NTQgMC4wNDMzLTUuNjIwNSAyLjc4NzEtNy42ODc1IDQuMjA3'
    b'OC0zLjE2OTggMTQuNjg3LTIuMTI1IDE0LjY4Ny0yLjEyNXMzLjUzNzgtMC4xNzY3NyA1LjM1'
    b'NDktNS4zNzVjMy42NTMzLTEwLjQ1MSAyLjE2MDgtMjEuNDA2IDIuMTYwOC0yMS40MDZzLTEu'
    b'NDUyNi0zLjYyODktNS4zODYyLTkuMTI1Yy0zLjkzMzctNS40OTYxLTcuNTE1Ny04Ljc1LTcu'
    b'NTE1Ny04Ljc1bDEuMDk2LTE0LjI4MXMtOS4yNjQzLTAuOTg3OS0xNi40NzIgNC4yODEyYy0z'
    b'LjU0MzkgMi41OTA4LTAuOTk1MzkgMTAuNDE0LTAuNzIwMjUgMTMuNTYyLTEwLjA5NCA2LjQ3'
    b'NTctMTkuNjk3IDE2LjA5NC0xOS42OTcgMTYuMDk0aC0yMS40NTFsLTAuMTg3ODktMTAuNzE5'
    b'czkuODk0OSAxLjc5OTYgMTYuNjI4LTUuNTMxMmM2LjczMzUtNy4zMzA4IDQuNjUzNy0xMy4w'
    b'NTggNC42NjYtMTkuODQ0IDAuMDEtNS4zNTE5LTUuMjMzOC0xNS4wMDMgMy4wMzc2LTI0LjI4'
    b'MSA2LjkwODgtNy43NDk3IDIwLjA0Mi0xMC4xNTYgMjAuMDQyLTEwLjE1NnMtMTUuNDkxLTIy'
    b'LjI0NS0yMC4yMy0zNC40NjljOC43NzYyIDAuMjk3MzggOS40ODg1LTIuNjg3NSA5LjQ4ODUt'
    b'Mi42ODc1cy0xMC43MiAwLjYwMzA1LTE1LjkwOC0wLjUzMTI1Yy02LjMxOTctMS4zODE2LTEw'
    b'LjAwNi03LjM4OTQtMTcuOTEyLTcuNS02LjM1LTAuMDg4OC02LjU3ODQtM2UtMyAtNi41Nzg0'
    b'LTNlLTNzLTMuNDc4Ny0wLjM2MDYyLTUuMTM1OS0yLjkxNjJjLTEuNDk0NS0yLjMwNDgtMS4x'
    b'MzAyLTguNjAwMSAxLjQ1NTMtMTAuNjgxIDUuMjIwOS00LjIwMjYgMjQuNzY1IDAuNjk1OTkg'
    b'MzEuNDk5LTAuMzM0MzYtNS45NDg2LTMuODU1LTkuODY5OC0yLjAxNy0xOS4xOS05LjYzLTku'
    b'MzItNy42MTMtOC42ODIzLTExLjUyNC0xNS43Mi0yMS42MjItNy43NDI3LTExLjExLTguNTgy'
    b'My05LjI5NjMtMTQuMTg2LTEwLjIwMi02LjYxMzItMi45MzA2LTMuMjcxMi0xMC4zNDktMy4y'
    b'NzEyLTEwLjM0OXM5LjY5ODQtMi40MzM4IDIwLjA0MiA1LjAyMDJjOC43MTc3IDYuMjgyNCAx'
    b'Ny4xNzcgMTMuMzYgMjYuODM3IDE3Ljg0NCA3LjMzMyAzLjQwMzcgMTUuMDMxIDIuODc1IDE1'
    b'LjAzMSAyLjg3NXMtMS40Njc1LTE0LjU2NC02LjQ1MS0xOC4yMTljLTMuMDgxMS0yLjI1OTgt'
    b'Ny40OTM3LTAuODgyNjEtMTEuMDg2LTIuNS01Ljc3NTMtNy44NTktNi44MjEtMy4yMDc1LTEw'
    b'LjU1My0xMi41IDEuNTE3My0yLjg1NTYgMy4xOTU1LTMuNjIyOCA2LjI2MzEtNC44MTI1IDIu'
    b'NjA0Mi0xLjAwOTkgOC4wNDgtMi4zNDM4IDguMDQ4LTIuMzQzOHM0LjQxLTQuOTU2NCA3LjE3'
    b'MTItNS44NzVjMi43MTA2LTAuOTAxNzUgMTUuMDMxLTEuMjUgMTUuMDMxLTEuMjVzNi4wNi03'
    b'LjMwNjUgNy4zMjc4LTYuMjVjNS41NDEzIDQuNjE4IDI3LjM3IDQ4LjkyMSAzNy45MjMgNzQu'
    b'ODEyIDguMTAzIDE5Ljg4IDE0Ljk2IDM4LjcyMSAxOS4zNTMgNjEuNDM4IDQuMzkzIDIyLjcx'
    b'NiA0LjQzNiAzOC41NTQgMy4zODIgNDAtMS4xMjYgMS41NDQ5LTExLjAyMS0xLjU4MTYtMTMu'
    b'NTkxIDYuNTkzOC0zLjY2NzQgMTEuNjY2IDYuNDM0OSAyMC40NDkgNi40NTEgMjMuNDA2IDAu'
    b'MDE2IDIuOTU3NS0zLjQ4NiAzLjc2OTQtMTAuMzk3IDE4LjAzMS01LjI2NDEgMTAuODY0LTYu'
    b'NzU0NiAxNy40NTEtNy4xNzEyIDIwaDI3Ljk2NXYtMzE4LjU2eiIgZmlsbD0iI2NjYyIvPgog'
    b'IDxwYXRoIGQ9Im0yNDIuMzIgMzcwaC0xMi43MzFzLTAuMTYxNzMtMTEuMzg1IDAuOTc5MzMt'
    b'MTIuNzY3YzEuNTk0Mi01Ljk4MjEgMTIuNzY2LTEzLjM0MiAyMC4zMjEtMjAuNTY2IDcuNTU0'
    b'OS03LjIyMzYgMTYuODkzLTE5LjM0MiAxNi44OTMtMTkuMzQybC0wLjQ4OTY2IDEzLjk1NWMt'
    b'MTMuODc5IDE0LjMyMS0yNC40ODMgMjEuNTQ1LTI0LjQ4MyAyMS41NDV6IiBmaWxsPSIjZGRi'
    b'NTIzIiBzdHJva2U9IiM4YzU3MDAiIHN0cm9rZS13aWR0aD0iMXB4Ii8+CiAgPHBhdGggZD0i'
    b'bTM0Ny40MSAzNzBoMTIuNzMxczAuMTYxNzMtMTEuMzg1LTAuOTc5MzMtMTIuNzY3Yy0xLjU5'
    b'NDItNS45ODIxLTEyLjc2Ni0xMy4zNDItMjAuMzIxLTIwLjU2Ni03LjU1NDktNy4yMjM2LTE2'
    b'Ljg5My0xOS4zNDItMTYuODkzLTE5LjM0MmwwLjQ4OTY2IDEzLjk1NWMxMy44NzkgMTQuMzIx'
    b'IDI0LjQ4MyAyMS41NDUgMjQuNDgzIDIxLjU0NXoiIGZpbGw9IiNkZGI1MjMiIHN0cm9rZT0i'
    b'IzhjNTcwMCIgc3Ryb2tlLXdpZHRoPSIxcHgiLz4KICA8Zz4KICAgPHJlY3QgeD0iMzIzLjYx'
    b'IiB5PSIyMTQuOTQiIHdpZHRoPSI1LjIzOCIgaGVpZ2h0PSIyNi43MzUiIGZpbGw9IiNmZmYi'
    b'IHN0cm9rZT0iIzc2NzQ3OSIvPgogICA8cGF0aCBkPSJtMzI1LjU1IDIwMC4wM2MtMC4wODIy'
    b'IDAtMC40MjE2OSAyLjY1NzUtMS45NDAyIDYuMDMyMi0xLjcwMjkgMy43ODQzIDEuMjMwNiA2'
    b'LjU1ODggMy4wODk2IDguNzg0NiAwLjAzMjEtMS45MjQyIDAuNTM4NS0zLjU3MTggMS4yNTM0'
    b'LTYuNDk4MSAwLjk2NTMzLTMuOTUxNy0xLjE5MDktNS44OTQ5LTIuNDAyNy04LjMxODZ6IiBm'
    b'aWxsPSIjZDIzMjI1IiBzdHJva2U9IiM0YTAwMDAiLz4KICAgPHJlY3QgeD0iMjU0LjUzIiB5'
    b'PSIyMTQuNzciIHdpZHRoPSI1LjIzOCIgaGVpZ2h0PSIyNi43MzUiIGZpbGw9IiNmZmYiIHN0'
    b'cm9rZT0iIzc2NzQ3OSIvPgogICA8cGF0aCBkPSJtMjU2LjQ3IDE5OS44NmMtMC4wODIyIDAt'
    b'MC40MjE2OSAyLjY1NzUtMS45NDAyIDYuMDMyMi0xLjcwMjkgMy43ODQzIDEuMjMwNiA2LjU1'
    b'ODggMy4wODk2IDguNzg0NiAwLjAzMjEtMS45MjQyIDAuNTM4NS0zLjU3MTggMS4yNTM0LTYu'
    b'NDk4MSAwLjk2NTMzLTMuOTUxNy0xLjE5MDktNS44OTQ5LTIuNDAyNy04LjMxODZ6IiBmaWxs'
    b'PSIjZDIzMjI1IiBzdHJva2U9IiM0YTAwMDAiLz4KICAgPHJlY3QgeD0iMjg5LjI4IiB5PSIy'
    b'MTMuMjkiIHdpZHRoPSI1LjIzOCIgaGVpZ2h0PSIyNi43MzUiIGZpbGw9IiNmZmYiIHN0cm9r'
    b'ZT0iIzc2NzQ3OSIvPgogIDwvZz4KICA8ZyBmaWxsPSIjZGRiNTIzIj4KICAgPHBhdGggZD0i'
    b'bTI4Ni42NyAyMzcuMDVjMC4zNDYyNSA2LjY2MjggMy4wMDM4IDEwLjY1OCAzLjAwMzggMTAu'
    b'NjU4cy0zLjc0NSA5LjI2OTQtMi45MDMxIDIwLjYwMWgxMC4yNjdjMC4wNDUzLTEzLjkzNS0y'
    b'LjU1NjktMjAuNzc0LTIuNTU2OS0yMC43NzRzMi40ODQ0LTQuMjg2MyAyLjY1NzUtMTAuNDg1'
    b'eiIgc3Ryb2tlPSIjOGM1NzAwIi8+CiAgIDxwYXRoIGQ9Im0yNjIuOTIgMzAwLjQ5czcuMDAx'
    b'OS01LjQ2NDUgNi40NDgyLTE5LjIxN2MxNC42MDQtMi41MTQzIDEyLjg3Mi0xNS4xMzcgMjEu'
    b'ODUyLTE1LjIzNSA5LjI3MzYtMC4xMDEyNyAxMC4xNzUgMTEuNDcxIDIyLjkyNyAxNS4yMzUg'
    b'MS4wNzcyIDEzLjcwMiA4Ljk1NTkgMTkuMjE3IDguOTU1OSAxOS4yMTd6IiBzdHJva2U9IiM4'
    b'YzU3MDAiLz4KICAgPHJlY3QgeD0iMjczLjc1IiB5PSIzMDIuOTQiIHdpZHRoPSIzOS42NDki'
    b'IGhlaWdodD0iNzAuMjc1Ii8+CiAgIDxnIHN0cm9rZT0iIzhjNTcwMCI+CiAgICA8cmVjdCB0'
    b'cmFuc2Zvcm09InJvdGF0ZSgtOTApIiB4PSItMzczLjA5IiB5PSIyNjcuNTUiIHdpZHRoPSI2'
    b'Ni41MzEiIGhlaWdodD0iNi4xMTQ1Ii8+CiAgICA8cmVjdCB0cmFuc2Zvcm09InJvdGF0ZSgt'
    b'OTApIiB4PSItMzczLjEiIHk9IjMxMi40OSIgd2lkdGg9IjY2LjU0NyIgaGVpZ2h0PSI2LjEx'
    b'NDUiLz4KICAgIDxwYXRoIGQ9Im0yOTMuODggMzIyLjQ5Yy0xMC44NjUgMC4wMTY1LTIwLjE2'
    b'NCAxLjgzOTgtMjcuMzQ2IDUuMzA3NWwwLjQwODc1IDcuMjU1YzYuMTExNC0zLjIwNzcgMTQu'
    b'NTgtNS43NDY5IDI2LjIxOS01Ljc4MTIgMTAuNjU3LTAuMDMxNSAxOS4xNzcgMi41OTA1IDI1'
    b'Ljg3NSA2LjE1NjJ2LTguMTg3NWMtNi44MDUtMi44MjIxLTE1LjExNS00Ljc2NTItMjUuMTU2'
    b'LTQuNzV6Ii8+CiAgICA8cGF0aCBkPSJtMjkzLjY1IDM0My43MWMtMTAuODY1IDAuMDE2NS0x'
    b'OS44MTggMS4xNDczLTI3IDQuNjE1bDAuMDYyNSA3Ljk0NzVjNi4xMTE0LTMuMjA3NyAxNC41'
    b'OC01Ljc0NjkgMjYuMjE5LTUuNzgxMiAxMC42NTctMC4wMzE1IDE5LjE3NyAyLjU5MDUgMjUu'
    b'ODc1IDYuMTU2MnYtOC4xODc1Yy02LjgwNS0yLjgyMjEtMTUuMTE1LTQuNzY1Mi0yNS4xNTYt'
    b'NC43NXoiLz4KICAgPC9nPgogIDwvZz4KICA8cGF0aCBkPSJtMjM2LjAyIDQwMi43N2gxMTcu'
    b'MjhzLTIwLjQyNy0zOS43NzgtNjAuNzE5LTM5LjQxOGMtNDAuMjkyIDAuMzU5NjMtNTYuNTU2'
    b'IDM5LjQxOC01Ni41NTYgMzkuNDE4eiIgZmlsbD0iI2Q5MjUxYyIgc3Ryb2tlPSIjOGM1NzAw'
    b'Ii8+CiAgPGcgZmlsbD0iI2RkYjUyMyI+CiAgIDxwYXRoIGQ9Im0yMzUuOTIgNDA1LjAzdjcx'
    b'Ljg0NGw1OC43ODEtNjcuNTYyIDU4LjgxMiA2Ny41NjJ2LTcxLjg0NGwtNTguODEyIDAuMzEy'
    b'NS01OC43ODEtMC4zMTI1eiIvPgogICA8ZyBzdHJva2U9IiM4YzU3MDAiPgogICAgPGc+CiAg'
    b'ICAgPGc+CiAgICAgIDxwYXRoIGQ9Im0yNDAuMTUgNDI5LjkzczEuNTk4IDEuMjk3MSAyLjk0'
    b'MzEgNC4zMjgxYzEuMzQ1MSAzLjAzMS0xLjMzMzUgNS41ODkyIDEuNTU4MSAxMC4wNDFzMTEu'
    b'MDEzIDIuOTkyOSAxMi42MzgtMS4yMTE5IDAuNDM4NzgtNy40MTQ4LTIuOTQzMS03Ljk2Mzct'
    b'NS40MTI1IDIuOTI2Ni01LjcxMzEgNC4zMjgxYy0wLjg4MjUtMC4wNjI5LTAuMDQ0MS00LjUw'
    b'MjgtMi40MjM3LTYuNjY1Mi0yLjM3OTYtMi4xNjI0LTYuMDU5My0yLjg1NjUtNi4wNTkzLTIu'
    b'ODU2NXoiLz4KICAgICAgPHBhdGggZD0ibTI0NS44MSA0NzguNDNoLTEwLjI4M3M1LjI2MDIt'
    b'MTUuMTE3IDkuNzkzMy0yMS41NDVjNS41MzI4LTcuODQ2MiAxNi4xNTktMTIuMjQyIDE2LjE1'
    b'OS0xMi4yNDJzLTAuNjMxMTQtNy45Mjg0IDIuNjkzMi0xMi45NzZjNC41MzQ3LTYuODg1NyAx'
    b'Mi44MzYtOC43MjA4IDE4LjM2Mi0xNS42NjkgMi4xMjIxLTIuNjY4MSAxLjk1ODctMTAuMDM4'
    b'IDEuOTU4Ny0xMC4wMzhoMTAuMjgzdjUuMzg2M3MtMC44NzE4NyA1LjIxODItMy45MTczIDgu'
    b'NTY5MmMtNC45MDI5IDUuMzk0OC0xNi4xNzMgMTMuMDMzLTE5LjA5NyAxOC42MDctMy4zODYg'
    b'Ni40NTQ1LTIuNjkzMiAxMy40NjYtMi42OTMyIDEzLjQ2NnMtNy41Mzg1LTAuNjExMzMtMTUu'
    b'NjY5IDcuODM0N2MtNC42NDU3IDQuODI1OC03LjU4OTggMTguNjA3LTcuNTg5OCAxOC42MDd6'
    b'Ii8+CiAgICAgIDxwYXRoIGQ9Im0zNDMuNzUgNDc4LjQzaDEwLjI4M3MtNS4yNjAyLTE1LjEx'
    b'Ny05Ljc5MzMtMjEuNTQ1Yy01LjUzMjgtNy44NDYyLTE2LjE1OS0xMi4yNDItMTYuMTU5LTEy'
    b'LjI0MnMwLjYzMTE0LTcuOTI4NC0yLjY5MzItMTIuOTc2Yy00LjUzNDctNi44ODU3LTEyLjgz'
    b'Ni04LjcyMDgtMTguMzYyLTE1LjY2OS0yLjEyMjEtMi42NjgxLTEuOTU4Ny0xMC4wMzgtMS45'
    b'NTg3LTEwLjAzOGgtMTAuMjgzdjUuMzg2M3MwLjg3MTg3IDUuMjE4MiAzLjkxNzMgOC41Njky'
    b'YzQuOTAyOSA1LjM5NDggMTYuMTczIDEzLjAzMyAxOS4wOTcgMTguNjA3IDMuMzg2IDYuNDU0'
    b'NSAyLjY5MzIgMTMuNDY2IDIuNjkzMiAxMy40NjZzNy41Mzg1LTAuNjExMzMgMTUuNjY5IDcu'
    b'ODM0N2M0LjY0NTcgNC44MjU4IDcuNTg5OCAxOC42MDcgNy41ODk4IDE4LjYwN3oiLz4KICAg'
    b'ICA8L2c+CiAgICAgPHJlY3QgeD0iMjM3LjQyIiB5PSI0MDIuNzUiIHdpZHRoPSIxMTUuNCIg'
    b'aGVpZ2h0PSI1LjE2MDgiLz4KICAgICA8cmVjdCB4PSIyMzIuNDkiIHk9IjM2OS45NSIgd2lk'
    b'dGg9IjYuNzk0NCIgaGVpZ2h0PSIxMDguMjMiIHN0cm9rZS13aWR0aD0iMS4wMDg0Ii8+CiAg'
    b'ICAgPGc+CiAgICAgIDxwYXRoIGQ9Im0zNTAuNyA0MjkuN3MtMS41OTggMS4yOTcxLTIuOTQz'
    b'MSA0LjMyODFjLTEuMzQ1MSAzLjAzMSAxLjMzMzUgNS41ODkyLTEuNTU4MSAxMC4wNDFzLTEx'
    b'LjAxMyAyLjk5MjktMTIuNjM4LTEuMjExOS0wLjQzODc4LTcuNDE0OCAyLjk0MzEtNy45NjM3'
    b'IDUuNDEyNSAyLjkyNjYgNS43MTMxIDQuMzI4MWMwLjg4MjUtMC4wNjI5IDAuMDQ0MS00LjUw'
    b'MjggMi40MjM3LTYuNjY1MiAyLjM3OTYtMi4xNjI0IDYuMDU5My0yLjg1NjUgNi4wNTkzLTIu'
    b'ODU2NXoiLz4KICAgICAgPHJlY3QgeD0iMzUxLjA1IiB5PSIzNzAuMDciIHdpZHRoPSI2LjYy'
    b'MTMiIGhlaWdodD0iMTA4LjExIi8+CiAgICAgIDxwYXRoIGQ9Im0yNjUuOTQgNDExLjkyczMu'
    b'Nzg5MyAwLjA0NjEgNC41MDEyIDMuODA4N2MwLjcxMTkzIDMuNzYyNi0zLjUwNjkgNS4xMTY5'
    b'LTUuODE1OSAyLjY0NjEtMi42NDMyLTIuODI4NC01LjEzNDktOS4zOTM3LTE0LjYxMy04LjM1'
    b'OTJzLTEyLjMxNyAxNy4wOS0wLjY5MjQ4IDE4LjY5N2M4LjM0MjYgMS4xNTM4IDcuOTYzNy02'
    b'LjQwNTYgNy45NjM3LTYuNDA1NnMtMy41Nzk0IDMuMjM0Ny02Ljc1MTggMS45MDQ0LTMuMDY4'
    b'Ni04LjUyODcgMy40NjI1LTguMTM2OCA3Ljc2ODMgNy42NjY0IDE0LjU0MiA3Ljc5MDVjNi43'
    b'NzQxIDAuMTI0MTcgOC4xMDItNi4xNTE0IDYuMDU5My0xMC4wNDEtMi4wNDI3LTMuODg5OC04'
    b'LjY1NjItMS45MDQ0LTguNjU2Mi0xLjkwNDR6Ii8+CiAgICAgIDxwYXRoIGQ9Im0zMjQuODkg'
    b'NDEyLjI2cy0zLjc4OTMgMC4wNDYxLTQuNTAxMiAzLjgwODdjLTAuNzExOTMgMy43NjI2IDMu'
    b'NTA2OSA1LjExNjkgNS44MTU5IDIuNjQ2MSAyLjY0MzItMi44Mjg0IDUuMTM0OS05LjM5Mzcg'
    b'MTQuNjEzLTguMzU5MnMxMi4zMTcgMTcuMDkgMC42OTI0OCAxOC42OTdjLTguMzQyNiAxLjE1'
    b'MzgtNy45NjM3LTYuNDA1Ni03Ljk2MzctNi40MDU2czMuNTc5NCAzLjIzNDcgNi43NTE4IDEu'
    b'OTA0NCAzLjA2ODYtOC41Mjg3LTMuNDYyNS04LjEzNjgtNy43NjgzIDcuNjY2NC0xNC41NDIg'
    b'Ny43OTA1Yy02Ljc3NDEgMC4xMjQxNy04LjEwMi02LjE1MTQtNi4wNTkzLTEwLjA0MSAyLjA0'
    b'MjctMy44ODk4IDguNjU2Mi0xLjkwNDQgOC42NTYyLTEuOTA0NHoiLz4KICAgICAgPHJlY3Qg'
    b'eD0iMjIxLjM5IiB5PSI0NzguMiIgd2lkdGg9IjE1NC44NSIgaGVpZ2h0PSIxNi44NjkiLz4K'
    b'ICAgICA8L2c+CiAgICA8L2c+CiAgICA8cGF0aCB0cmFuc2Zvcm09Im1hdHJpeCguODg2MjQg'
    b'MCAwIC45MzAzOCAzNC4wOCAzMy43ODQpIiBkPSJtMzA0LjA4IDQ4NS4yOGE0Ljc3NDIgNC4y'
    b'ODQ2IDAgMSAxLTkuNTQ4NSAwIDQuNzc0MiA0LjI4NDYgMCAxIDEgOS41NDg1IDB6IiBzdHJv'
    b'a2Utd2lkdGg9IjEuMTAxMyIvPgogICA8L2c+CiAgPC9nPgogIDxwYXRoIHRyYW5zZm9ybT0i'
    b'dHJhbnNsYXRlKC4xNTMwMikiIGQ9Im0zMDEuMTQgNDg1LjI4YTIuMDE5OSAxLjgzNjIgMCAx'
    b'IDEtNC4wMzk4IDAgMi4wMTk5IDEuODM2MiAwIDEgMSA0LjAzOTggMHoiIGZpbGw9IiM4YzU3'
    b'MDAiLz4KICA8ZyBmaWxsPSIjZGRiNTIzIiBzdHJva2U9IiM4YzU3MDAiPgogICA8Zz4KICAg'
    b'IDxnPgogICAgIDxwYXRoIGQ9Im0yOTkuNDMgNDkzLjYxYzMuMTgzNi01LjMwNTEgMTEuNDY1'
    b'LTEzLjM4OCAxOS45NTQtMTIuOTc2IDUuMjE1Ny0wLjA2NDQgNy4zMzc4IDMuNDY2MiA2Ljk3'
    b'NzcgNi45Nzc3LTAuMzYwMDIgMy41MTE2LTQuMjI5NSA2LjgyNzktOC4yMDE5IDUuNTA4OC0z'
    b'Ljk3MjQtMS4zMTkyLTMuOTE3My01LjE0MTUtMy45MTczLTUuMTQxNXMyLjQ2MjkgMi40MzM2'
    b'IDUuMTQxNSAxLjU5MTQgMy40OTU4LTYuMTU3My0xLjgzNjItNS45OTg0Yy01Ljc0MjYgMC4x'
    b'NzExLTEzLjA5OCA2LjU1MzgtMTguMTE4IDEwLjAzOHoiLz4KICAgICA8cGF0aCBkPSJtMzQ1'
    b'LjkzIDQ5NC4zNWMzLjE4MzYtNS4zMDUxIDExLjQ2NS0xMy4zODggMTkuOTU0LTEyLjk3NiA1'
    b'LjIxNTctMC4wNjQ0IDcuMzM3OCAzLjQ2NjIgNi45Nzc3IDYuOTc3Ny0wLjM2MDAyIDMuNTEx'
    b'Ni00LjIyOTUgNi44Mjc5LTguMjAxOSA1LjUwODgtMy45NzI0LTEuMzE5Mi0zLjkxNzMtNS4x'
    b'NDE1LTMuOTE3My01LjE0MTVzMi40NjI5IDIuNDMzNiA1LjE0MTUgMS41OTE0IDMuNDk1OC02'
    b'LjE1NzMtMS44MzYyLTUuOTk4NGMtNS43NDI2IDAuMTcxMS0xMy4wOTggNi41NTM4LTE4LjEx'
    b'OCAxMC4wMzh6Ii8+CiAgICAgPHBhdGggZD0ibTI5OS4zMyA0OTMuNjFjLTMuMTgzNi01LjMw'
    b'NTEtMTEuNDY1LTEzLjM4OC0xOS45NTQtMTIuOTc2LTUuMjE1Ny0wLjA2NDQtNy4zMzc4IDMu'
    b'NDY2Mi02Ljk3NzcgNi45Nzc3IDAuMzYwMDIgMy41MTE2IDQuMjI5NSA2LjgyNzkgOC4yMDE5'
    b'IDUuNTA4OCAzLjk3MjQtMS4zMTkyIDMuOTE3My01LjE0MTUgMy45MTczLTUuMTQxNXMtMi40'
    b'NjI5IDIuNDMzNi01LjE0MTUgMS41OTE0LTMuNDk1OC02LjE1NzMgMS44MzYyLTUuOTk4NGM1'
    b'Ljc0MjYgMC4xNzExIDEzLjA5OCA2LjU1MzggMTguMTE4IDEwLjAzOHoiLz4KICAgICA8cGF0'
    b'aCBkPSJtMzIyLjY4IDQ5NC4zNWMzLjE4MzYtNS4zMDUxIDExLjQ2NS0xMy4zODggMTkuOTU0'
    b'LTEyLjk3NiA1LjIxNTctMC4wNjQ0IDcuMzM3OCAzLjQ2NjIgNi45Nzc3IDYuOTc3Ny0wLjM2'
    b'MDAyIDMuNTExNi00LjIyOTUgNi44Mjc5LTguMjAxOSA1LjUwODgtMy45NzI0LTEuMzE5Mi0z'
    b'LjkxNzMtNS4xNDE1LTMuOTE3My01LjE0MTVzMi40NjI5IDIuNDMzNiA1LjE0MTUgMS41OTE0'
    b'IDMuNDk1OC02LjE1NzMtMS44MzYyLTUuOTk4NGMtNS43NDI2IDAuMTcxMS0xMy4wOTggNi41'
    b'NTM4LTE4LjExOCAxMC4wMzh6Ii8+CiAgICAgPHBhdGggZD0ibTI3Ni4xOSA0OTQuMzVjLTMu'
    b'MTgzNi01LjMwNTEtMTEuNDY1LTEzLjM4OC0xOS45NTQtMTIuOTc2LTUuMjE1Ny0wLjA2NDQt'
    b'Ny4zMzc4IDMuNDY2Mi02Ljk3NzcgNi45Nzc3IDAuMzYwMDIgMy41MTE2IDQuMjI5NSA2Ljgy'
    b'NzkgOC4yMDE5IDUuNTA4OCAzLjk3MjQtMS4zMTkyIDMuOTE3My01LjE0MTUgMy45MTczLTUu'
    b'MTQxNXMtMi40NjI5IDIuNDMzNi01LjE0MTUgMS41OTE0LTMuNDk1OC02LjE1NzMgMS44MzYy'
    b'LTUuOTk4NGM1Ljc0MjYgMC4xNzExIDEzLjA5OCA2LjU1MzggMTguMTE4IDEwLjAzOHoiLz4K'
    b'ICAgICA8cGF0aCBkPSJtMjUyLjU2IDQ5NC4zNWMtMy4xODM2LTUuMzA1MS0xMS40NjUtMTMu'
    b'Mzg4LTE5Ljk1NC0xMi45NzYtNS4yMTU3LTAuMDY0NC03LjMzNzggMy40NjYyLTYuOTc3NyA2'
    b'Ljk3NzcgMC4zNjAwMiAzLjUxMTYgNC4yMjk1IDYuODI3OSA4LjIwMTkgNS41MDg4IDMuOTcy'
    b'NC0xLjMxOTIgMy45MTczLTUuMTQxNSAzLjkxNzMtNS4xNDE1cy0yLjQ2MjkgMi40MzM2LTUu'
    b'MTQxNSAxLjU5MTQtMy40OTU4LTYuMTU3MyAxLjgzNjItNS45OTg0YzUuNzQyNiAwLjE3MTEg'
    b'MTMuMDk4IDYuNTUzOCAxOC4xMTggMTAuMDM4eiIvPgogICAgPC9nPgogICAgPHJlY3QgeD0i'
    b'MjAzLjE1IiB5PSI0OTUuMjEiIHdpZHRoPSIxOTEuMTIiIGhlaWdodD0iMTYuMzk4Ii8+CiAg'
    b'IDwvZz4KICAgPHBhdGggdHJhbnNmb3JtPSJtYXRyaXgoLjg4NjI0IDAgMCAuOTMwMzggMzQu'
    b'MDggNTAuMzEpIiBkPSJtMzA0LjA4IDQ4NS4yOGE0Ljc3NDIgNC4yODQ2IDAgMSAxLTkuNTQ4'
    b'NSAwIDQuNzc0MiA0LjI4NDYgMCAxIDEgOS41NDg1IDB6IiBzdHJva2Utd2lkdGg9IjEuMTAx'
    b'MyIvPgogIDwvZz4KICA8cGF0aCB0cmFuc2Zvcm09InRyYW5zbGF0ZSguMTUzMDIgMTYuNTI2'
    b'KSIgZD0ibTMwMS4xNCA0ODUuMjhhMi4wMTk5IDEuODM2MiAwIDEgMS00LjAzOTggMCAyLjAx'
    b'OTkgMS44MzYyIDAgMSAxIDQuMDM5OCAweiIgZmlsbD0iIzhjNTcwMCIvPgogIDxnIGZpbGw9'
    b'IiNkZGI1MjMiIHN0cm9rZT0iIzhjNTcwMCI+CiAgIDxnPgogICAgPHBhdGggZD0ibTI5OS4y'
    b'MyA1MDguMzFjLTMuMDM2Mi00LjU1NTQtMTAuOTM0LTExLjQ5Ni0xOS4wMzEtMTEuMTQyLTQu'
    b'OTc0NC0wLjA1NTMtNi45OTgyIDIuOTc2My02LjY1NDggNS45OTE2IDAuMzQzMzYgMy4wMTUz'
    b'IDQuMDMzOCA1Ljg2MyA3LjgyMjMgNC43MzAyIDMuNzg4Ni0xLjEzMjggMy43MzYxLTQuNDE0'
    b'OSAzLjczNjEtNC40MTQ5cy0yLjM0ODkgMi4wODk3LTQuOTAzNiAxLjM2NjUtMy4zMzQtNS4y'
    b'ODcxIDEuNzUxMy01LjE1MDdjNS40NzY5IDAuMTQ2OTIgMTIuNDkyIDUuNjI3NiAxNy4yNzkg'
    b'OC42MTk1eiIvPgogICAgPHBhdGggZD0ibTI3Ny4zNSA1MDkuMjZjLTMuMDM3NC00LjcxNzQt'
    b'MTAuOTM5LTExLjkwNS0xOS4wMzgtMTEuNTM5LTQuOTc2Mi0wLjA1NzMtNy4wMDA4IDMuMDgy'
    b'Mi02LjY1NzQgNi4yMDQ3IDAuMzQzNDkgMy4xMjI1IDQuMDM1MyA2LjA3MTUgNy44MjUzIDQu'
    b'ODk4NCAzLjc5LTEuMTczIDMuNzM3NS00LjU3MTkgMy43Mzc1LTQuNTcxOXMtMi4zNDk4IDIu'
    b'MTY0LTQuOTA1NCAxLjQxNTFjLTIuNTU1Ni0wLjc0ODg5LTMuMzM1My01LjQ3NTIgMS43NTE5'
    b'LTUuMzMzOSA1LjQ3ODkgMC4xNTIxNCAxMi40OTcgNS44Mjc3IDE3LjI4NiA4LjkyNnoiLz4K'
    b'ICAgIDxwYXRoIGQ9Im0yNTQuOTQgNTA5LjcxYy0zLjAxOTItNS4wMDM0LTEwLjg3My0xMi42'
    b'MjctMTguOTIzLTEyLjIzOC00Ljk0NjQtMC4wNjA3LTYuOTU4OCAzLjI2OS02LjYxNzQgNi41'
    b'ODA5IDAuMzQxNDIgMy4zMTE4IDQuMDExMSA2LjQzOTYgNy43NzgzIDUuMTk1NCAzLjc2NzIt'
    b'MS4yNDQyIDMuNzE1LTQuODQ5IDMuNzE1LTQuODQ5cy0yLjMzNTcgMi4yOTUyLTQuODc2IDEu'
    b'NTAwOWMtMi41NDAzLTAuNzk0MjgtMy4zMTUyLTUuODA3MSAxLjc0MTQtNS42NTcyIDUuNDQ2'
    b'IDAuMTYxMzcgMTIuNDIyIDYuMTgxIDE3LjE4MiA5LjQ2NzJ6Ii8+CiAgICA8cGF0aCBkPSJt'
    b'MjMyLjI5IDUwOS4yOWMtMi45NzI2LTQuNzQxNC0xMC43MDUtMTEuOTY2LTE4LjYzMi0xMS41'
    b'OTgtNC44NzAxLTAuMDU3Ni02Ljg1MTUgMy4wOTc5LTYuNTE1MyA2LjIzNjQgMC4zMzYxNiAz'
    b'LjEzODUgMy45NDkyIDYuMTAyNSA3LjY1ODQgNC45MjM1czMuNjU3OC00LjU5NTIgMy42NTc4'
    b'LTQuNTk1Mi0yLjI5OTcgMi4xNzUtNC44MDA4IDEuNDIyMy0zLjI2NDEtNS41MDMxIDEuNzE0'
    b'Ni01LjM2MTFjNS4zNjIxIDAuMTUyOTEgMTIuMjMgNS44NTc0IDE2LjkxNyA4Ljk3MTZ6Ii8+'
    b'CiAgICA8cGF0aCBkPSJtMjk5Ljg5IDUwOC4zMWMzLjAzNjItNC41NTU0IDEwLjkzNC0xMS40'
    b'OTYgMTkuMDMxLTExLjE0MiA0Ljk3NDQtMC4wNTUzIDYuOTk4MiAyLjk3NjMgNi42NTQ4IDUu'
    b'OTkxNi0wLjM0MzM2IDMuMDE1My00LjAzMzggNS44NjMtNy44MjIzIDQuNzMwMi0zLjc4ODYt'
    b'MS4xMzI4LTMuNzM2MS00LjQxNDktMy43MzYxLTQuNDE0OXMyLjM0ODkgMi4wODk3IDQuOTAz'
    b'NiAxLjM2NjUgMy4zMzQtNS4yODcxLTEuNzUxMy01LjE1MDdjLTUuNDc2OSAwLjE0NjkyLTEy'
    b'LjQ5MiA1LjYyNzYtMTcuMjc5IDguNjE5NXoiLz4KICAgIDxwYXRoIGQ9Im0zMjEuNzcgNTA5'
    b'LjI2YzMuMDM3NC00LjcxNzQgMTAuOTM5LTExLjkwNSAxOS4wMzgtMTEuNTM5IDQuOTc2Mi0w'
    b'LjA1NzMgNy4wMDA4IDMuMDgyMiA2LjY1NzQgNi4yMDQ3LTAuMzQzNDkgMy4xMjI1LTQuMDM1'
    b'MyA2LjA3MTUtNy44MjUzIDQuODk4NC0zLjc5LTEuMTczLTMuNzM3NS00LjU3MTktMy43Mzc1'
    b'LTQuNTcxOXMyLjM0OTggMi4xNjQgNC45MDU0IDEuNDE1MWMyLjU1NTYtMC43NDg4OSAzLjMz'
    b'NTMtNS40NzUyLTEuNzUxOS01LjMzMzktNS40Nzg5IDAuMTUyMTQtMTIuNDk3IDUuODI3Ny0x'
    b'Ny4yODYgOC45MjZ6Ii8+CiAgICA8cGF0aCBkPSJtMzQ0LjE5IDUwOS43MWMzLjAxOTItNS4w'
    b'MDM0IDEwLjg3My0xMi42MjcgMTguOTIzLTEyLjIzOCA0Ljk0NjQtMC4wNjA3IDYuOTU4OCAz'
    b'LjI2OSA2LjYxNzQgNi41ODA5LTAuMzQxNDIgMy4zMTE4LTQuMDExMSA2LjQzOTYtNy43Nzgz'
    b'IDUuMTk1NC0zLjc2NzItMS4yNDQyLTMuNzE1LTQuODQ5LTMuNzE1LTQuODQ5czIuMzM1NyAy'
    b'LjI5NTIgNC44NzYgMS41MDA5YzIuNTQwMy0wLjc5NDI4IDMuMzE1Mi01LjgwNzEtMS43NDE0'
    b'LTUuNjU3Mi01LjQ0NiAwLjE2MTM3LTEyLjQyMiA2LjE4MS0xNy4xODIgOS40NjcyeiIvPgog'
    b'ICAgPHBhdGggZD0ibTM2Ni44MyA1MDkuMjljMi45NzI2LTQuNzQxNCAxMC43MDUtMTEuOTY2'
    b'IDE4LjYzMi0xMS41OTggNC44NzAxLTAuMDU3NiA2Ljg1MTUgMy4wOTc5IDYuNTE1MyA2LjIz'
    b'NjQtMC4zMzYxNiAzLjEzODUtMy45NDkyIDYuMTAyNS03LjY1ODQgNC45MjM1cy0zLjY1Nzgt'
    b'NC41OTUyLTMuNjU3OC00LjU5NTIgMi4yOTk3IDIuMTc1IDQuODAwOCAxLjQyMjMgMy4yNjQx'
    b'LTUuNTAzMS0xLjcxNDYtNS4zNjExYy01LjM2MjEgMC4xNTI5MS0xMi4yMyA1Ljg1NzQtMTYu'
    b'OTE3IDguOTcxNnoiLz4KICAgPC9nPgogICA8cGF0aCBkPSJtMzIwLjk2IDIzOS4xM2MwLjUx'
    b'OTM3IDQuNzUyNiAwLjk0NjUgOC43OTE5IDIuODEgOS4yODA2LTAuMDExMSAyLjI3MTQtMC41'
    b'OTY0MSA2LjgxNjctNi41OTM4IDcuMDIxMy03LjM5ODYgMC4yNTIzMy0xMC41MTYtNS4xNTMt'
    b'MTUuOTI4LTUuMjAxOS01LjQxMjItMC4wNDg5LTguMDg4MiAyLjk5Ny04LjQ3ODEgNi42MDgx'
    b'czEuMzY2OSA3LjM0MyA2Ljc1IDcuMjVjNS4zODMxLTAuMDkzIDYuMzM2OC02LjcwNzUgMi4y'
    b'NTk0LTcuNzkxMi0xLjM1ODYtMC4zNjExMSAxLjE5NTQgMy40MDYxLTIuNDE1NiAzLjgwMzEt'
    b'My43ODIyIDAuNDE1ODUtNC4zMDQ0LTYuMTkzNyAxLjg5NjktNi4wNiA2LjIwMTIgMC4xMzM2'
    b'NyAxMC45MDcgNS43MTYyIDE3LjQ3MSA0LjUwNDQgNy4xMzE1LTEuMzE2NiA4LjYyMDItNi42'
    b'OTIyIDkuNDYxOS0xMC4xMzQgMS44NjQ4LTAuNDg4MzMgMi42NjgxLTQuNTI3NCAzLjAxNDQt'
    b'OS4yODA2eiIvPgogIDwvZz4KICA8cGF0aCBkPSJtMjkxLjIxIDE5OC4zOGMtMC4wODIyIDAt'
    b'MC40MjE2OSAyLjY1NzUtMS45NDAyIDYuMDMyMi0xLjcwMjkgMy43ODQzIDEuMjMwNiA2LjU1'
    b'ODggMy4wODk2IDguNzg0NiAwLjAzMjEtMS45MjQyIDAuNTM4NS0zLjU3MTggMS4yNTM0LTYu'
    b'NDk4MSAwLjk2NTMzLTMuOTUxNy0xLjE5MDktNS44OTQ5LTIuNDAyNy04LjMxODZ6IiBmaWxs'
    b'PSIjZDIzMjI1IiBzdHJva2U9IiM0YTAwMDAiLz4KICA8ZyBmaWxsPSIjZGRiNTIzIiBzdHJv'
    b'a2U9IiM4YzU3MDAiPgogICA8Zz4KICAgIDxwYXRoIGQ9Im0yNzUuODEgMjkxLjMxczkuNTkw'
    b'NyA3LjM0MzggMTYuNjU4IDcuNDQ0M2M3LjA2NzMgMC4xMDA1IDE3LjAxNi03LjA5ODEgMTcu'
    b'MDE2LTcuMDk4MXMtNC44NzcyLTcuMDIyMy03LjUyMjktMTAuMzg3Yy0zLjE4MjMtNC4wNDc0'
    b'LTQuNzczLTExLjkxMi0xMC4wMzEtMTEuNzcyLTUuMDM3NSAwLjEzMzY5LTYuMDMyNCA3Ljgw'
    b'NS04Ljk1NTkgMTEuNzcyLTIuNDQwNCAzLjMxMTctNy4xNjQ3IDEwLjA0MS03LjE2NDcgMTAu'
    b'MDQxeiIvPgogICAgPHBhdGggZD0ibTI3MC4yNiAzMDAuOTFzNS4wMTgzLTUuODMyMSA1LjAx'
    b'NTMtMTYuMWMzLjEzNTItMC4wOTUzIDQuMzE4MS0wLjIxNDkyIDYuOTg1NiAwIDAuNDk0OTQg'
    b'MTAuMjExLTMuMjI0MSAxNi4xLTMuMjI0MSAxNi4xeiIvPgogICAgPHBhdGggZD0ibTMxNC40'
    b'MyAzMDAuOTFzLTUuMDE4My01LjgzMjEtNS4wMTUzLTE2LjFjLTMuMTM1Mi0wLjA5NTMtNC4z'
    b'MTgxLTAuMjE0OTItNi45ODU2IDAtMC40OTQ5NSAxMC4yMTEgMy4yMjQxIDE2LjEgMy4yMjQx'
    b'IDE2LjF6Ii8+CiAgICA8cGF0aCBkPSJtMjg5LjcyIDI3Ni4xOXYxNS4wMjZjMC41MDY2MyAy'
    b'LjgxNTYgNC45OTM2IDIuNzU0NCA1LjMxMDIgMGwwLjEyNjY2LTE1LjAyNmMtMC43NTk5NC0y'
    b'LjI2NDctNC42MTM2LTIuMzg3MS01LjQzNjkgMHoiLz4KICAgPC9nPgogICA8cmVjdCB4PSIy'
    b'NjkuMTgiIHk9IjI4MS4xOSIgd2lkdGg9IjQ1LjI4NCIgaGVpZ2h0PSI0Ljc1OTciIHN0cm9r'
    b'ZS13aWR0aD0iLjk5Njk4Ii8+CiAgIDxyZWN0IHg9IjI2Mi4yOSIgeT0iMzAwLjQ1IiB3aWR0'
    b'aD0iNjEuNDk1IiBoZWlnaHQ9IjYuMzQxOSIgc3Ryb2tlLXdpZHRoPSIxLjA1MzUiLz4KICAg'
    b'PHJlY3QgdHJhbnNmb3JtPSJyb3RhdGUoLTkwKSIgeD0iLTM3My4wOSIgeT0iMjYyLjMyIiB3'
    b'aWR0aD0iNzEuNzk0IiBoZWlnaHQ9IjYuNzA5MSIgc3Ryb2tlLXdpZHRoPSIxLjAzODgiLz4K'
    b'ICAgPHJlY3QgdHJhbnNmb3JtPSJyb3RhdGUoLTkwKSIgeD0iLTM3My4wOSIgeT0iMzE2Ljk1'
    b'IiB3aWR0aD0iNzIuMDkzIiBoZWlnaHQ9IjYuNzA5MSIgc3Ryb2tlLXdpZHRoPSIxLjA0MSIv'
    b'PgogICA8Zz4KICAgIDxwYXRoIGQ9Im0zNjYuMSAyMjkuODFjLTMuMjA1MiAwLTUuODEyNSAy'
    b'LjYwNzMtNS44MTI1IDUuODEyNSAwIDEuMTg2MiAwLjM1NzkgMi4yOTk3IDAuOTY4NzUgMy4y'
    b'MTg4bC05LjA5MzggMTIuOTM4LTUuNjg3NS00LjA5MzhjMC4xMTg2MS0wLjQ2MjM5IDAuMTU2'
    b'MjUtMC45MzgxMiAwLjE1NjI1LTEuNDM3NSAwLTMuMjA1Mi0yLjU3Ni01LjgxMjUtNS43ODEy'
    b'LTUuODEyNXMtNS44MTI1IDIuNjA3My01LjgxMjUgNS44MTI1IDIuNjA3MyA1LjgxMjUgNS44'
    b'MTI1IDUuODEyNWMxLjEwOTYgMCAyLjExODUtMC4zMzQ3OCAzLTAuODc1bDUuODQzOCA0LjEy'
    b'NS04Ny43ODEgMTI1LjAzIDIuOTQ4MSAyLjE3MiA4OC4yMDgtMTI0LjgzIDYuNTkzOCA0LjY1'
    b'NjJjLTAuMTEzOTEgMC40NTM3Mi0wLjE1NjI1IDAuOTE3Mi0wLjE1NjI1IDEuNDA2MiAwIDMu'
    b'MjA1MiAyLjU3NiA1LjgxMjUgNS43ODEyIDUuODEyNXM1LjgxMjUtMi42MDczIDUuODEyNS01'
    b'LjgxMjUtMi42MDczLTUuODEyNS01LjgxMjUtNS44MTI1Yy0xLjE4NjIgMC0yLjI2ODUgMC4z'
    b'NTc5LTMuMTg3NSAwLjk2ODc1bC02LjU2MjUtNC42ODc1IDkuMzEyNS0xMi45MzhjMC40MDcy'
    b'NSAwLjA5MDUgMC44MTU0OCAwLjE1NjI1IDEuMjUgMC4xNTYyNSAzLjIwNTIgMCA1LjgxMjUt'
    b'Mi42MDczIDUuODEyNS01LjgxMjVzLTIuNjA3My01LjgxMjUtNS44MTI1LTUuODEyNXoiLz4K'
    b'ICAgIDxwYXRoIGQ9Im0yMTguNzkgMjI1LjUzYy0yLjIyOTUgMC00LjAzMTIgMS44MDE4LTQu'
    b'MDMxMiA0LjAzMTIgMCAyLjIyOTUgMS44MDE4IDQuMDMxMiA0LjAzMTIgNC4wMzEyIDAuMDk2'
    b'NCAwIDAuMTg2NTItMC4wMjQ3IDAuMjgxMjUtMC4wMzEybDUuMDMxMiA3LjI1LTUuNDA2MiAz'
    b'LjY4NzVjLTAuNDg5NzEtMC4yMTEwOS0xLjAyNjYtMC4zMTI1LTEuNTkzOC0wLjMxMjUtMi4y'
    b'Mjk1IDAtNC4wNjI1IDEuODAxOC00LjA2MjUgNC4wMzEyIDAgMi4yMjk1IDEuODMzIDQuMDMx'
    b'MiA0LjA2MjUgNC4wMzEyczQuMDMxMi0xLjgwMTggNC4wMzEyLTQuMDMxMmMwLTAuMTA3LTAu'
    b'MDIzMS0wLjIwNzYtMC4wMzEyLTAuMzEyNWw1LjM3NS0zLjY4NzUgNyAxMC4wOTRjLTAuNDAz'
    b'NTMgMS4xNDAyLTAuMzU1NjUgMi41MzIyIDAuMjgxMjUgMy44NDM4IDAuOTE1OTEgMS44ODYx'
    b'IDIuNzM1MSAyLjk5NjggNC40Mzc1IDIuOTA2MmwyLjAzMTIgMi45MDYyYy0wLjQyMDgxIDEu'
    b'ODkwMSAwLjA2MjIgNC41MDk4IDEuNDY4OCA3IDEuODg0MiAzLjMzNiA0Ljc5MDggNS4zNTgg'
    b'NyA1LjA2MjVsMS45Njg4IDIuODEyNXYwLjAzMTJjLTAuMjgzNTUgMS4yMTA5LTAuMDIwNSAy'
    b'LjcwOTEgMC44NDM3NSA0LjA2MjUgMC45Njk5NyAxLjUxOTEgMi40MyAyLjQyNjggMy43ODEy'
    b'IDIuNTMxMmwxNS44NzUgMjIuNjg4YzAuMzU3NzIgMi4zMzk2IDIuMDA1NyA1Ljk0ODIgNC41'
    b'OTM4IDkuNjI1IDIuNTY2NyAzLjY0NjUgNS4zNzMyIDYuNDQ5MSA3LjQ2ODggNy42MjVsMS43'
    b'ODEyIDIuNTMxMmMtMC4wNTQ1IDEuMDQ4NSAwLjA4OTMgMi44MDc4IDAuOTY4NzUgNC4wNjI1'
    b'IDEuMDg3OCAxLjU1MiAyLjU5MjcgMi43OTA5IDQuMDkzOCAzLjE1NjJsMTYuMTI1IDIzLjAz'
    b'MWMwLjAxMjggMC4wMTkyIDAuMDE4NCAwLjA0MzMgMC4wMzEyIDAuMDYyNSA1LjE4MzkgNy43'
    b'NjA1IDE1LjQ2OSAyMy4yNSAxNS40NjkgMjMuMjVsMi42NDg1LTIuMDI2MXMtMjAuNjE5LTMx'
    b'LjM3NC0zMS4xOC00Ni4yNTVjMC4xNzk1NS0xLjUxOTYtMC4wOTQ0LTMuMTc2LTEuMTU2Mi00'
    b'LjU2MjUtMS4wMDg1LTEuMzE3MS0yLjQzMTYtMi43ODc2LTQuMTU2Mi0zLjAzMTJsLTEuNS0y'
    b'LjEyNWMtMWUtMyAtOWUtMyAxZS0zIC0wLjAyMjEgMC0wLjAzMTItMC4zMjMxMi0yLjMzMjIt'
    b'Mi4wMjk4LTUuOTg3NC00LjY1NjItOS43MTg4LTIuNTU1Ni0zLjYzMDctNS4zNzA0LTYuNDA4'
    b'OS03LjQ2ODgtNy41OTM4bC0xNS45NjktMjIuNzgxYzAuMzUxNjItMS4yNDE2IDAuMDkxMy0y'
    b'LjgzNDYtMC44MTI1LTQuMjUtMS4wMTgxLTEuNTk0NS0yLjU2MTQtMi41MzUtMy45Njg4LTIu'
    b'NTYyNWwtMi4yMTg4LTMuMTU2MmMwLjQ0OTYtMS44OTItMC4wMTQxLTQuNTExLTEuNDM3NS03'
    b'LjAzMTItMS44OTUxLTMuMzU1My00LjgxNjktNS4zODQ3LTcuMDMxMi01LjA2MjVsLTEuNjI1'
    b'LTIuMzQzOGMwLjUxMDU5LTEuMTgxMiAwLjQ2NDA3LTIuNjg3Ny0wLjIxODc1LTQuMDkzOC0w'
    b'Ljg0NjMyLTEuNzQyOC0yLjQ1MDctMi44NTI3LTQuMDMxMi0yLjkzNzVsLTcuMDMxMi0xMC4w'
    b'NjIgNS4xMjUtMy41YzAuNDc1NDkgMC4xOTY5MSAwLjk4NDU4IDAuMzEyNSAxLjUzMTIgMC4z'
    b'MTI1IDIuMjI5NSAwIDQuMDYyNS0xLjgwMTggNC4wNjI1LTQuMDMxMiAwLTIuMjI5NS0xLjgz'
    b'My00LjA2MjUtNC4wNjI1LTQuMDYyNXMtNC4wMzEyIDEuODMzLTQuMDMxMiA0LjA2MjVjMCAw'
    b'LjEzODczIDAuMDE3NyAwLjI3MTExIDAuMDMxMiAwLjQwNjI1bC01IDMuNDA2Mi01LjA2MjUt'
    b'Ny4yNWMwLjIyODkyLTAuNTA2NTMgMC4zNDM3NS0xLjA2NDMgMC4zNDM3NS0xLjY1NjIgMC0y'
    b'LjIyOTUtMS44MDE4LTQuMDMxMi00LjAzMTItNC4wMzEyeiIvPgogICAgPHBhdGggZD0ibTI2'
    b'Mi40NCAyMzkuMTNjLTAuNTE5MzcgNC43NTI2LTAuOTQ2NSA4Ljc5MTktMi44MSA5LjI4MDYg'
    b'MC4wMTExIDIuMjcxNCAwLjU5NjQxIDYuODE2NyA2LjU5MzggNy4wMjEzIDcuMzk4NiAwLjI1'
    b'MjMzIDEwLjUxNi01LjE1MyAxNS45MjgtNS4yMDE5IDUuNDEyMi0wLjA0ODkgOC4wODgyIDIu'
    b'OTk3IDguNDc4MSA2LjYwODFzLTEuMzY2OSA3LjM0My02Ljc1IDcuMjVjLTUuMzgzMS0wLjA5'
    b'My02LjMzNjgtNi43MDc1LTIuMjU5NC03Ljc5MTIgMS4zNTg2LTAuMzYxMTEtMS4xOTU0IDMu'
    b'NDA2MSAyLjQxNTYgMy44MDMxIDMuNzgyMiAwLjQxNTg1IDQuMzA0NC02LjE5MzctMS44OTY5'
    b'LTYuMDYtNi4yMDEyIDAuMTMzNjctMTAuOTA3IDUuNzE2Mi0xNy40NzEgNC41MDQ0LTcuMTMx'
    b'NS0xLjMxNjYtOC42MjAyLTYuNjkyMi05LjQ2MTktMTAuMTM0LTEuODY0OC0wLjQ4ODMzLTIu'
    b'NjY4MS00LjUyNzQtMy4wMTQ0LTkuMjgwNnoiLz4KICAgPC9nPgogIDwvZz4KICA8cGF0aCBk'
    b'PSJtMTMyLjI1IDUxNS40NHYzMS44NDRzLTAuNjg4NTggMTIuOTY4IDkuMzQzOCAyMS45MDZj'
    b'MTAuMDMyIDguOTM4NiAyNS45MDYgOC4yMTg4IDI1LjkwNiA4LjIxODhoOTguNjg4czE0LjA3'
    b'Ny0wLjEwNTIgMjIuNzgxIDkuNTYyNWM2Ljg3OTQgNy42NDExIDguNjYxNSAxMy44NCA5LjEy'
    b'NSAxNi4xMjV2MXMwLjA0NDktMC4yMDIxNSAwLjA5MzctMC41YzAuMDQ4OCAwLjI5Nzg1IDAu'
    b'MDkzNyAwLjUgMC4wOTM3IDAuNXYtMWMwLjQ2MzUyLTIuMjg1NCAyLjI3NjktOC40ODM5IDku'
    b'MTU2Mi0xNi4xMjUgOC43MDQtOS42Njc3IDIyLjc4MS05LjU2MjUgMjIuNzgxLTkuNTYyNWg5'
    b'OC42ODhzMTUuODc0IDAuNzE5ODkgMjUuOTA2LTguMjE4OCA5LjM0MzgtMjEuOTA2IDkuMzQz'
    b'OC0yMS45MDZ2LTMxLjg0NGgtMTY1Ljg4LTAuMTg3NXptMTA2LjIyIDQuODQzOCA4LjAwMjUg'
    b'OS42NTEyYzYuNDYwOC0wLjA4NjYgMTEuNzE3IDAuMzgwODQgMTQuNzE2IDAuNzg2MjUgMTEu'
    b'NTc3IDEuNTY1IDEyLjUyNCA0LjMxMjkgMTcuNDM4IDUuNSA0LjM4MzMgMS4wNTkgOC41NjI1'
    b'IDEuNDY4OCA4LjU2MjUgMS40Njg4cy01LjMzNCA0LjA1OTgtOC4zMTI1IDUuMzc1LTkuMzEy'
    b'NSAyLjQzNzUtOS4zMTI1IDIuNDM3NSA2LjQyNTkgMC4xODU0NSA4LjU2MjUgMSA0LjE1NjIg'
    b'Mi45Mzc1IDQuMTU2MiAyLjkzNzUtNS4wODIzIDAuNTIxODItNy41OTM4IDAuOTY4NzVjLTgu'
    b'MzIzIDEuNDgxMS0xNi4xMDkgNS40MDU5LTI0LjcxOSA1LjYyNS0zLjYwNTEgMC4wOTE3LTgu'
    b'MDQ2NSAwLjIwMjY1LTEyLjcxOSAwLjI4MTI1LTAuOTY4NjIgMS4wNTEyLTIuMzE1NCAyLjQ5'
    b'NDItMi41IDMuOTY4OHMxLjc1IDQuNjg3NSAxLjc1IDQuNjg3NS05LjI4MyAxLjQ0MTktMTQu'
    b'MjE5IDEuMzc1LTE1LjIxOS0xLjkwNjItMTUuMjE5LTEuOTA2Mmw0LjM0MzgtOC4xMjVjLTAu'
    b'ODUxOTUtMC4wMTcyLTEuNzMxMy05ZS0zIC0yLjU2MjUtMC4wMzEyLTUuNzI2OC0wLjE1Mzc0'
    b'LTEyLjY3Ny0wLjY1NTkzLTE5LjU2Mi0xLjIxODhsLTMuOTM3NSA3LjM0MzgtMTUuMTg4LTIu'
    b'MjE4OCAyLjg3NS02LjQzNzVjLTYuMTM0Ni0wLjQ1NTc1LTEwLjQyNi0wLjgyMDQzLTEzLjQw'
    b'Ni0wLjQwNjI1cy02LjAwMTMgMi40ODk0LTguODEyNSA0LjQwNjItOC4zMTI1IDcuMDkzOC04'
    b'LjMxMjUgNy4wOTM4LTAuNTcxMTUtNi43Mzc0IDEuMjE4OC0xMC4wMzEgNi4xMjUtNS44NzUg'
    b'Ni4xMjUtNS44NzUtMy43MTI5LTMuMDM4NS01LjQwNjItNS44NzUtNC40MDYyLTExLjI1LTQu'
    b'NDA2Mi0xMS4yNSAxNC43MDggOC4yNDU5IDIyLjUzMSA4LjMxMjVjNC41MDU2IDAuMDM4NCA5'
    b'LjEwNzktMC41MDUzMyAxMy43NS0xLjM0MzhsLTUuNDA2Mi01Ljc1IDE4LjU5NC04LjgxMjUg'
    b'Ni43MjEyIDEwLjUxN2M2LjQ3NDUtMC45OTQ0OSAxMi4xMDUtMi4xMSAxOC4wMjktMi41Nzk0'
    b'bC01LjQwNjItOS45MDYzem0xMDguNDQgMCAyOC45MzggMS45Njg4LTUuMTA4MSA5LjU2YzQu'
    b'MDMwNyAwLjc1NjM0IDEzLjY5NCAyLjY1MjIgMTcuMTAzIDMuMDk4N2w2LjkxMTItMTAuNjkg'
    b'MTguMTU2IDguODEyNS01LjI4MTIgNS43NWM0LjUzNDMgMC44Mzg0MiA5LjAzNjUgMS4zODIx'
    b'IDEzLjQzOCAxLjM0MzggNy42NDEzLTAuMDY2NiAyMi04LjMxMjUgMjItOC4zMTI1cy0yLjYy'
    b'NzIgOC40MTM1LTQuMjgxMiAxMS4yNWMtMS42NTQgMi44MzY1LTUuMjgxMiA1Ljg3NS01LjI4'
    b'MTIgNS44NzVzNC4yMjA0IDIuNTgxMiA1Ljk2ODggNS44NzVjMS43NDg0IDMuMjkzOCAxLjE4'
    b'NzUgMTAuMDMxIDEuMTg3NSAxMC4wMzFzLTUuMTU0OC01LjA4MDEtOC4xMjUtNy4wOTM4Yy0y'
    b'LjY3NTEtMS44MTM2LTUuMDE2Mi0zLjg5NzItOC41OTM4LTQuNDA2Mi0yLjI0NDItMC4zMTkz'
    b'Mi03LjEwMTUtMC4wNDk1LTEzLjA5NCAwLjQwNjI1bDIuODEyNSA2LjQzNzUtMTQuODQ0IDIu'
    b'MjE4OC0zLjg0MzgtNy4zNDM4Yy02LjcyNTkgMC41NjI4Mi0xMy41MzEgMS4wNjUtMTkuMTI1'
    b'IDEuMjE4OC0wLjgxMTkxIDAuMDIyMy0xLjY2NzggMC4wMTQtMi41IDAuMDMxMmw0LjI1IDgu'
    b'MTI1cy0xMC4wNTQgMS44Mzk0LTE0Ljg3NSAxLjkwNjJjLTQuODIxMiAwLjA2NjktMTMuODc1'
    b'LTEuMzc1LTEzLjg3NS0xLjM3NXMxLjg5OS0zLjIxMjkgMS43MTg4LTQuNjg3NWMtMC4xODAy'
    b'OS0xLjQ3NDYtMS41MjI2LTIuOTE3NS0yLjQ2ODgtMy45Njg4LTQuNTYzOC0wLjA3ODYtOC44'
    b'ODQ4LTAuMTg5NTMtMTIuNDA2LTAuMjgxMjUtOC40MTA0LTAuMjE5MDktMTYuMDI2LTQuMTQz'
    b'OS0yNC4xNTYtNS42MjUtMi40NTMyLTAuNDQ2OTMtNy40MDYyLTAuOTY4NzUtNy40MDYyLTAu'
    b'OTY4NzVzMS45NzU1LTIuMTIzIDQuMDYyNS0yLjkzNzVjMi4wODctMC44MTQ1NSA4LjM0Mzgt'
    b'MSA4LjM0MzgtMXMtNi4xODQ0LTEuMTIyMy05LjA5MzgtMi40Mzc1Yy0yLjkwOTMtMS4zMTUy'
    b'LTguMDkzOC01LjM3NS04LjA5MzgtNS4zNzVzNC4wNjIyLTAuNDA5NzQgOC4zNDM4LTEuNDY4'
    b'OGM0Ljc5OTMtMS4xODcxIDUuNzU0LTMuOTM1IDE3LjA2Mi01LjUgMi45Mjk4LTAuNDA1NDYg'
    b'OC4zNzY2LTAuODcyODIgMTQuNjg4LTAuNzg2MTl6IiBmaWxsPSIjMDU2YTllIi8+CiAgPHBh'
    b'dGggZD0ibTI0Ny4yNSA1MzEuNDRjLTEwLjAxOSAwLjEyNjc5LTIyLjA1NCAxLjA3NDMtMzEu'
    b'NTMxIDIuMDMxMi0xNC4xNiAxLjQyOTgtNDIuNTYxIDcuODgyNS01MS4yNSA3LjkzNzUtNS4x'
    b'MjE4IDAuMDMyNC05Ljk2MTgtMS40NzE0LTEzLjM0NC0yLjc1LTMuMDY1OS0xLjE1OTEtOC44'
    b'MTI1LTQuMzQzOC04LjgxMjUtNC4zNDM4czEuNTg5NiA1LjM5NiAzLjYyNSA4LjUgNC43NjM1'
    b'IDQuNTUwOSA1LjkzNzUgNi4yMTg4Yy0xLjU2NjYgMS4yMzg1LTIuMTMwMyAwLjkwODc3LTUu'
    b'MjgxMiA0LjAzMTJzLTIuOTA2MiA5LjA5MzgtMi45MDYyIDkuMDkzOCAzLjI0NTItMy4zNzU3'
    b'IDYuNDA2Mi01LjU2MjUgNi40NTQ5LTQuMTgwOCA5Ljg3NS00LjU5MzggMzkuODkyIDIuODM1'
    b'MSA1Mi4yODEgMi45Mzc1IDM0Ljk2NyAwLjE5NjQ2IDQwLjE1Ni0wLjUzMTI1YzYuODcwNS0w'
    b'Ljk2MzQ2IDEzLjQxMy0zLjc1MDEgMjAuMjUtNS4wMzEyIDIuMjMwMi0wLjQxNzkxIDYuNzUt'
    b'MC44NDM3NSA2Ljc1LTAuODQzNzVzLTAuODcwNTMtMC43ODMyOC0zLjYyNS0xLjQwNjItOS4y'
    b'MDIyIDAuMjkwMTgtMTAuMjE5LTEuMjE4OGMxLjU0MzgtMi4wNjYxIDcuMTkwNy0yLjE3NzMg'
    b'MTAuOTA2LTMuNDM3NXM3LjI4MTItMy44MTI1IDcuMjgxMi0zLjgxMjUtMy45Mzk1LTAuNzAy'
    b'MzEtNS44NzUtMS4yMTg4Yy01LjM0MjUtMS40MjU1LTYuMjgyNC0zLjQzMTYtMTUuNzgxLTUu'
    b'MTg3NS0zLjU2MjEtMC42NTg0OC04LjgzMjEtMC44ODg1Ny0xNC44NDQtMC44MTI1em0xMC45'
    b'MTggMC4zNjUzMmMxLjA0NjIgMC45NDYyNS03LjQwNjMgNS41MDYtNy43NDIgMTIuNTEtMC4y'
    b'NDY4NSA1LjE1MDcgNi4xNjAyIDkuMTM2MSA1LjExMjQgOS44MjY3LTEuMDQ3OCAwLjY5MDY0'
    b'LTcuMjQxNC00LjM3NzctNi44OTIzLTkuNzI2NCAwLjQ3ODA5LTcuMzI1MSA4LjQ3NTctMTMu'
    b'NTU3IDkuNTIxOS0xMi42MXptLTcuOTgwOCAwLjc5MDkzYzAuOTQ0NTcgMS4wMjA1LTcuMjk0'
    b'NCA1LjAwNzMtOC4wNjI1IDExLjQ2OS0wLjc2MzE2IDYuNDE5NyA1LjE5OTQgOS4yMDkgNC4x'
    b'ODc1IDEwLjE1NnMtNi41OTQ0LTQuNDQ2OC02LjA5MzgtOS42NTYyYzAuNjc3Mi03LjA0NjMg'
    b'OS4wMjQyLTEyLjk4OSA5Ljk2ODgtMTEuOTY5em0xNC4wOTQgMy44MTI1YzEuNDgyIDAgMi42'
    b'ODc1IDEuMDUzIDIuNjg3NSAyLjM0MzhzLTEuMjA1NSAyLjMxMjUtMi42ODc1IDIuMzEyNS0y'
    b'LjY4NzUtMS4wMjE3LTIuNjg3NS0yLjMxMjUgMS4yMDU1LTIuMzQzOCAyLjY4NzUtMi4zNDM4'
    b'em0tMzEuMTg4IDIuNSA0LjMxMjUgNy41MzEyLTguNjI1IDAuMjV6bS04LjY1NjIgMC43NSAz'
    b'Ljc4MTIgNy03LjU2MjUgMC4yMTg3NXptLTguMTI1IDAuNTkzNzUgMy40Njg4IDYuNTkzOC02'
    b'LjkzNzUgMC4wMzEyem0tOC4xNTYyIDAuODQzNzUgMy41OTM4IDUuOTY4OC03LjE1NjIgMC4x'
    b'ODc1em0tNy45MDYyIDAuNjU2MjUgMy4yNSA1LjUzMTItNi43NSAwLjA5Mzd6bS04LjIxODgg'
    b'MC42ODc1IDIuOTA2MiA0Ljk2ODgtNiAwLjE4NzV6bS04LjA5MzggMC43NSAyLjg3NSA0LjQw'
    b'NjItNS43ODEyIDAuMTg3NXptLTguMDkzOCAwLjYyNSAyLjg0MzggMy45Njg4LTUuOTA2MiAw'
    b'LjIxODc1em0tNy43NSAwLjcxODc1IDIuMjUgMy40Njg4LTQuNjU2MiAwLjE1NjI1eiIgZmls'
    b'bD0iI2U2ZTZlNiIvPgogIDxwYXRoIGQ9Im0zMzguNTEgNTMxLjM4YzkuNzc2NiAwLjEyNjc5'
    b'IDIxLjUyIDEuMDc0MyAzMC43NjcgMi4wMzEyIDEzLjgxNyAxLjQyOTggNDEuNTMgNy44ODI1'
    b'IDUwLjAwOCA3LjkzNzUgNC45OTc2IDAuMDMyNCA5LjcyMDQtMS40NzE0IDEzLjAyLTIuNzUg'
    b'Mi45OTE2LTEuMTU5MSA4LjU5ODktNC4zNDM4IDguNTk4OS00LjM0MzhzLTEuNTUxIDUuMzk2'
    b'LTMuNTM3MSA4LjVjLTEuOTg2MSAzLjEwNC00LjY0OCA0LjU1MDktNS43OTM2IDYuMjE4OCAx'
    b'LjUyODcgMS4yMzg1IDIuMDc4NyAwLjkwODc3IDUuMTUzMyA0LjAzMTJzMi44MzU4IDkuMDkz'
    b'OCAyLjgzNTggOS4wOTM4LTMuMTY2NS0zLjM3NTctNi4yNTEtNS41NjI1Yy0zLjA4NDUtMi4x'
    b'ODY4LTYuMjk4NS00LjE4MDgtOS42MzU3LTQuNTkzOC0zLjMzNzItMC40MTI5My0zOC45MjUg'
    b'Mi44MzUxLTUxLjAxNCAyLjkzNzUtMTIuMDg5IDAuMTAyMzctMzQuMTIgMC4xOTY0Ni0zOS4x'
    b'ODMtMC41MzEyNS02LjcwNC0wLjk2MzQ2LTEzLjA4OC0zLjc1MDEtMTkuNzU5LTUuMDMxMi0y'
    b'LjE3NjItMC40MTc5MS02LjU4NjQtMC44NDM3NS02LjU4NjQtMC44NDM3NXMwLjg0OTQ0LTAu'
    b'NzgzMjggMy41MzcyLTEuNDA2MmMyLjY4NzctMC42MjI5NyA4Ljk3OTIgMC4yOTAxOCA5Ljk3'
    b'MTEtMS4yMTg4LTEuNTA2NC0yLjA2NjEtNy4wMTY0LTIuMTc3My0xMC42NDItMy40Mzc1LTMu'
    b'NjI1NS0xLjI2MDItNy4xMDQ4LTMuODEyNS03LjEwNDgtMy44MTI1czMuODQ0LTAuNzAyMzEg'
    b'NS43MzI2LTEuMjE4OGM1LjIxMy0xLjQyNTUgNi4xMzAyLTMuNDMxNiAxNS4zOTktNS4xODc1'
    b'IDMuNDc1Ny0wLjY1ODQ4IDguNjE4LTAuODg4NTcgMTQuNDg0LTAuODEyNXptLTEwLjY1NCAw'
    b'LjM2NTMyYy0xLjAyMDggMC45NDYyNSA3LjIyNjggNS41MDYgNy41NTQzIDEyLjUxIDAuMjQw'
    b'ODcgNS4xNTA3LTYuMDExIDkuMTM2MS00Ljk4ODUgOS44MjY3IDEuMDIyNCAwLjY5MDY0IDcu'
    b'MDY1OS00LjM3NzcgNi43MjUzLTkuNzI2NC0wLjQ2NjUxLTcuMzI1MS04LjI3MDMtMTMuNTU3'
    b'LTkuMjkxMS0xMi42MXptNy43ODc0IDAuNzkwOTNjLTAuOTIxNjggMS4wMjA1IDcuMTE3NiA1'
    b'LjAwNzMgNy44NjcxIDExLjQ2OSAwLjc0NDY3IDYuNDE5Ny01LjA3MzQgOS4yMDktNC4wODYg'
    b'MTAuMTU2IDAuOTg3MzIgMC45NDcyNiA2LjQzNDYtNC40NDY4IDUuOTQ2MS05LjY1NjItMC42'
    b'NjA3OS03LjA0NjMtOC44MDU1LTEyLjk4OS05LjcyNzItMTEuOTY5em0tMTMuNzUyIDMuODEy'
    b'NWMtMS40NDYxIDAtMi42MjI0IDEuMDUzLTIuNjIyNCAyLjM0MzhzMS4xNzYzIDIuMzEyNSAy'
    b'LjYyMjQgMi4zMTI1YzEuNDQ2MSAwIDIuNjIyNC0xLjAyMTcgMi42MjI0LTIuMzEyNXMtMS4x'
    b'NzYzLTIuMzQzOC0yLjYyMjQtMi4zNDM4em0zMC40MzIgMi41LTQuMjA4IDcuNTMxMiA4LjQx'
    b'NiAwLjI1em04LjQ0NjUgMC43NS0zLjY4OTYgNyA3LjM3OTIgMC4yMTg3NXptNy45MjgxIDAu'
    b'NTkzNzUtMy4zODQ3IDYuNTkzOCA2Ljc2OTQgMC4wMzEyem03Ljk1ODYgMC44NDM3NS0zLjUw'
    b'NjcgNS45Njg4IDYuOTgyOCAwLjE4NzV6bTcuNzE0NiAwLjY1NjI1LTMuMTcxMiA1LjUzMTIg'
    b'Ni41ODY0IDAuMDkzN3ptOC4wMTk2IDAuNjg3NS0yLjgzNTggNC45Njg4IDUuODU0NiAwLjE4'
    b'NzV6bTcuODk3NiAwLjc1LTIuODA1MyA0LjQwNjIgNS42NDEyIDAuMTg3NXptNy44OTc2IDAu'
    b'NjI1LTIuNzc0OCAzLjk2ODggNS43NjMxIDAuMjE4NzV6bTcuNTYyMiAwLjcxODc1LTIuMTk1'
    b'NSAzLjQ2ODggNC41NDM0IDAuMTU2MjV6IiBmaWxsPSIjZTZlNmU2Ii8+CiA8L2c+CiA8ZyB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSgwIDcuMjEzNikiPgogIDxwYXRoIGQ9Im02MDQuMzcgNDA0'
    b'LjE5Yy0yLjQ4NDYtMC4xNTU5My00LjA0MSA0Ljg1NjUtMTIuMTE5IDUuMTQyIDAgMC0wLjg3'
    b'MDc1LTkuOTY1LTAuODY1NjEtMTUuNjYyIDcuMzQ4IDAuMTkzMTggMjAuMTc3LTQuODI4IDI1'
    b'Ljc5NSAxLjcwNTQgMi42ODM4IDMuMTIwNyAyLjkwMzEgMTEuMjQ3LTEuMDM4NyAxMi4zMDQt'
    b'OC4yNTY1IDIuMjE0LTkuMjg3OC0zLjMzMzMtMTEuNzcyLTMuNDg5MnoiLz4KICA8cGF0aCBk'
    b'PSJtNzIzLjExIDQwMy4zOWMyLjQ4OTQgMC4wMjUxIDMuMzMwOSA1LjMxMDYgMTEuNzEzIDYu'
    b'MDA5NiAwIDAgMS4xMzgtMTAuNzc2IDEuNTQ3Mi0xNi40NTktNy4zNDI2LTAuMzQxNjMtMTku'
    b'NTAxLTUuNzctMjUuMzk2IDAuNzI2MjgtMi43MDM2IDIuOTc5NC0zLjcxMzIgMTEuMDA2IDAu'
    b'MTQxMyAxMi4zNDcgOC4wNzM3IDIuODA4NSA5LjUwNTYtMi42NDkxIDExLjk5NS0yLjYyNHoi'
    b'Lz4KIDwvZz4KPC9zdmc+Cg==', 'RU_NGR')

RU_NGR = b64_RU_NGR
index.append("RU_NGR")
index.append("Russia Novgorodskaya oblast")
catalog["RU_NGR"] = RU_NGR
catalog["Russia Novgorodskaya oblast"] = RU_NGR
country["Russia Novgorodskaya oblast"] = ('RU_NGR', '', 1)
lookup["RU_NGR"] = ('RU_NGR', '', 'Russia Novgorodskaya oblast', 1)
lookup["Novgorod"] = ('RU_NGR', '', 'Russia Novgorodskaya oblast', 1)
lookup["Russia Novgorodskaya oblast"] = ('RU_NGR', '', 'Russia Novgorodskaya oblast', 1)
details["RU_NGR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Novgorod"}
regional["RU_NGR"] = ('RU_NGR', 'Russia Novgorodskaya oblast', 1)
regional["Russia Novgorodskaya oblast"] = ('RU_NGR', 'Russia Novgorodskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_NIZ = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxMjc3IiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X05pemhueV9Ob3Znb3JvZF9SZWdpb24uc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6'
    b'Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2Rp'
    b'PSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIg'
    b'eG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRw'
    b'Oi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8y'
    b'MDAwL3N2ZyI+CiAgPGRlZnMgaWQ9ImRlZnMxMjgxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZp'
    b'ZXcgaWQ9Im5hbWVkdmlldzEyNzkiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiIGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIg'
    b'aW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0i'
    b'MCIgLz4KICA8ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0i'
    b'SW1hZ2UiIGlkPSJnMTI4MyI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIg'
    b'cHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncw'
    b'S0dnb0FBQUFOU1VoRVVnQUFBSGdBQUFCUUNBWUFBQURTbTdHSkFBQUFCR2RCVFVFQUFMR1BD'
    b'L3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1B'
    b'QUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVQKQlVsRVFWUjQydTJjYVlB'
    b'VTVabUFuN3E2cXUrNVo1Z1RobXRHUVFSa1JBVkJpV2pZWkYwakd0RjR4YWlKYmp3VEUwemNh'
    b'TndZbzZLNwpScE9OTWZFQ1NkUWNvdkVpb0lLQUlBTEtNY00xREQxM3o5RjNkM1YzSGZzREF4'
    b'b0ZEU2E3RTZ6bjEvUlU5ZGRWOWRUN2ZlOTNWQW0yCmJkczRITEdJemlWd0JEczRnaDBjd1E2'
    b'T1lBZEhzSU1qMk1FUjdBaDJjQVE3T0lJZEhNRU9qbUFIUjdDREl4Z2cxUHdpZTdjK3kyZHAK'
    b'aHZRekpUald0Wng0OS9MUFZBVExuNldUTlZ6anNERVJCTUVSL0U4dk01VWkrdXB5NHVISHlW'
    b'c2V2TE8rejhhMmZaVldvS0laNi9VNwprWlUwZ2FJTEtUamxWR1NmNzRpOERzS1J1R1FuK2U2'
    b'NzlOejhYZXhkTzNGOXk0MVNVNC9kOXlYc28vYUNJQ0xzR0E3ZUo3RWkzZWcvClNpQ01IRVhG'
    b'SFhmZ216RFJhWU9IT21ZNnZWOHVnTkVleFZ2bUlycnM5N2pzTGhTcmcvalM1L0JXK2pEYUJn'
    b'Q3dkKytpWi81OGpHVEMKRVR6VWlhOWV0Vjh1Z05GbEl5aEJ5RFNUVGNjdzlEajU1R1pFVjRC'
    b'Y3A3bC9QN3QxTi9GVnE1dzJlS2lUNkEwZCtIdWFoWnh5WWFNaQpCak1rZWw0RHdVYjJLdGhv'
    b'WkJNdWpPa1d2cFVpQXBEczNVdVJFOEZEbTdTbmhid3NraW9XS1puaklsN2tBZHZFcUZHUnZK'
    b'OUQ4czRtClh5ZGpZNU1vVUNuNXZFYXFUTVFTQmVMdXJVNFZQUlRJSk1KMHZuUC9SMjZUUmt3'
    b'aGNmb3doQk4xR0gwbkJkUEdrRE5jQ01WdUZFM0IKNVhFakYybmtEWVhnaWFOZ3pEMklKMmFJ'
    b'blZhR092cWtqeXl6Yy9NRHBPUGRqdUQvQy9yMkxDR3gvaVNrMkc4L3RHMWpXNVRTbWliRQph'
    b'ZE1RM3dxZ1AzazF4cHZyVWZXWHlKb0drYzVYaUxUL2liUWg0a3EvU0g3ZFpuSlBYWWI0WmdC'
    b'eDVuVEtxcWV4c1MyS1pmM1ZUUlA5ClBjbTNwOU8zKzNkT04ra2ZpV1daZEsvK0V1bmVOOUND'
    b'bzhua1pXcG4vSW5ubXhQYyt1SXVXblNCaXhzTHVHbmthMlQzL2c5ZW54L1oKVjRXaWVaRWtG'
    b'N0prWVNOZ21ESzJtU1dYVFdBa09za2tFOGhWRjNOZmFBNi8yaHBsakdaeXkybjFuRDJwakxZ'
    b'L240Nm1tdWl4RnZ4bApUWlFlLzBka1JYV1NySC9JM1NpSTJLaWtjd3FTUG9DNzVIVE8rZVZt'
    b'TnZXazZkTk5tbW9EaEdKNWlxcG5ZM2p6U0dJZTJleEJUdytTCjFlUGtFYkFSUUxDUlpCVnZ3'
    b'WENzNGlhOHRvd1FPSVgyYlhtT0wzV3hzVDNHVGMrMjhQaWFFQStkZUJ5NXZ1ZklaQlU4cUVp'
    b'eXk4bWkKLzk3WXRvMGdDQWlDZ0ZwN0hVcDRBN2JuYUFLamJ1STZyODJ2M3VxbnZUdEtjY0JO'
    b'U2pkcEhUUm9YZnNXRHcwMDBaR2N6S1hMSG1WVQpyUE1EWlhiNFMvajVxYWRSSFJ6Z3NwSjFq'
    b'RHJ1WkV4TEl1aFJhQ3FSR1ZaYXdLWEhGK092dXA1WUpvU2NmUmRYMWZYN2h6bi9ja3hPCkZm'
    b'MTNvR1BqdllqWmRSanUwOWl5WlNOQmowTGQyS25ZYmRlaDFGNVAwajBYUVJCNGFYdWNSOTZO'
    b'c0R0dUlHZXkxTG95Vk9YN21aZFkKajJYa1FkZjNGYWhwaUxMQ1U5N0poTlJTMnZOdThxcEdY'
    b'VURra3ZFRmZMR3hBTnUyOFdXV2tHLy9DVUx0WGV6ZHZabDRKRUhqaE1tNAo5T1dZcm1Pb21m'
    b'UmRKNEwvSHUydUpHWUk3M21WNGxxUnNSUE94MFpGNi93U084SkZsR3FiaVFabVVsSmN3cHdH'
    b'UDNNYS9EeTlJY3prCnVpcnFpLy9TVnM3K3lMS25tQ2FTSk5FMnFMT21OY3E4NHlyK1VtY3dF'
    b'Qm5Bam0raXI5dkZXT1VLS3VwZm9OeU1JU2Vmb1MrMGpQTEcKTVZpV2lTaEtUaFo5dUdRekVU'
    b'cFhuc0ZnejJiY0hvVkl4ekxNK0daa0VmWjBCeWdyekZEQWN1Q0RWZVU1azhyZUovY0FHelp1'
    b'Wk9PbQpUZVJ5T1V6VFpOdTJaZ0NHRjJudmszdUFvUDBhNVNVWlduc0t3Y3BocFZ1SWRyeUNW'
    b'NU1aN0c2aDgvWFR5R1lHSGNHSDNYNklNcTd5Cjh5bndtc2pGWnlJVWY1azlMUnZaOE1iOTZO'
    b'SXdMTS9KQ0dPZVFSQU9mUnFaVEFhQVJ4NTVsS3JLU2x3dUY5dTM3NkMxdGZXUUNaM2MKOEJT'
    b'MmJ3WTVxWkpOYi82VXRoM3JvWGd1WXNsWkJQMTVYTU11UU1DSjRNUEdwZnJSU21jaGxaMk50'
    b'MndxZFJPdllabHZQaXNqNWN6WQpjZyszaCtaVFVuM0N4NWJUMWRWRlYxY1hVNmRPcGF5c2pI'
    b'UTZ3NGdSdzNuNm1hY1ArYjJpeWlidTdKalA5SGZ1WmtXa2t1ZmxiMUUzCjZVYTg1Vk9SeXM1'
    b'R0s1bUZ5eDEwMnVERFJVL0hTYjg5Qlk4U0laRlNHWkNxdVhyOGJaeTdkUmFqVloxbmR0czB2'
    b'clNUMmFXSExxZSsKdnA2NzcxNUFVOU1VYk50bTQ4WU5WRlpXY3NyTVV3LzV2WHYrdkpQRk8r'
    b'S01WTEtzU3AvS1U1TTZHSHpyYTRqNUVINlBUbmF2bjlUeApPL0FHaXAwSVBodzBUd0RmY1J0'
    b'SW1FZWpLQ2FtM2t0aTg0M01QcXFjdktpaVN3by9XZDFOSXBQLzJMS09tVENlWmN1WDg4b3JT'
    b'K25yCjYyZmh3aWU1NElKNUI2L1dzeVozck93a0xjamtaWTFaamVXa3R0eUFtZWxFVVV5UzFo'
    b'alVTWnVHdE54L2lxRktmMUVWdWhYRU1FV3kKT1FsUlVhbVBQa0hvdlI2UFh4RlFYWWR1Qjl2'
    b'ZVhzL0oyUXlYcG1LMFB2MWJLZ2Y2dU9XVzc2RnAyc0diQjBVa29PNHJONVFUR1RHdwpDRmwy'
    b'a2NuSkdJYUliaFFRTEs1eHVrbWZsa2pINjdncXIwQlN2azVScm9QaU1WZXgrcTB3OWZvQTJI'
    b'RGVTRGN1S1hQb2JIenJGcklyCmxsTXgwTS81TnNoTlV6LzJkeVZSNFBLSlpUeTJJd0VJV0Vk'
    b'L2oxRW5QVUQvOXArQlVvRnFDQXlHWHFXbzloUW5nZytYWERaRk90bUwKSjN3OWlyc1V0ZndM'
    b'L1BMeGEzaHc5VzUyOW1lSXhwTE1QNzNoWTh0cHVQaFNmSGN1UUZkVUZBR1V3aytXR04wMGV6'
    b'VEpXSnFkL1JsKwpzYmFOWC96Nkd0VGl6NkY2cXRGNmJpQ1Q2aUtuSjUwSVBodzZ0eTNDTmJB'
    b'QVBkWkgydlRpMlhVenkxMi81dnRkbHhBeFFNam5HZWFYClNYWThDOVFlZkpqVHNraS90aHh6'
    b'OVVyYytTeTVZVlY0cXFvLzBUSEVRczlUNlNtZ1o4RGczYVRNTGRtdjROa2hjN3I1WGRJSkRX'
    b'SFgKZkdKOWQ1RXJ2cEdxb3k5eUl2aHZvYkIyRGdtakZzRklFazlrc2RMTmJPc0lFekgyYlMr'
    b'MWRXcmxQWmlEcngreW5PVFBmNHA0L3dLVQo5ZXYyVmIxbnpJRlBPSVpzUkZZeFhObEZxWlVC'
    b'QktKNWtlYXVmdXpNRmhLcExCZ0owdFp3QWxXem5TcjZiOFhqSzZUcWhFV28xWmRSClZON0Ez'
    b'djVhcnB4U1NJWExacXlTWk9HeHQvSGd1R3RCTzNqMEd2MTlDTXRlT2ZEWjQ4WDdoVFBmRjk0'
    b'MitZRUJQalFCdkQvVHF1YmUKeGh0WlBQay9HQ3NuS0pFc3JtZ3FaRTkvTFFWbFkvRFdmbzN5'
    b'cHNmd0YxUTRWZlRob0dwZXZOWG5ZWHVuaytyOExmR2U5WlFKbzlpZQpkUkdVSXRpNlRhTDFJ'
    b'Y3pTWTREQ0R3dU94eEJOYS85SXBweE9FZi9tbFFqcE5PS3dLcXh3TDJKL0g1bktLc1N6enNa'
    b'ejRuVEU5OVpICm03bEJFcDBQb2dCQklVYklVS2hYRExMOTc1RGlLT1RLZWJnTGg2RjVDcHdr'
    b'NjlPUTdsdUwySFkrNHhxOENHWVNuMnFSRXhUYXdoNUUKeWNUcnNVRDQ2RzZTVWxhQnFYMXdU'
    b'TnJWMVlrU2pTQTFiMEVaNkVNU1FPbnV4Rno0S0VqdkswZVE4THB0Wk1rZ0ZIYWpvK0pUUmF4'
    b'cwpsUEdOWmNpaHI1RHVXKzEwa3o0dGhpV1MxR3N3MjU2alpPb1ZmSFhYRTR4UDVWa1dPd2xY'
    b'V0dIcWxIbEkyY0NCL1FjR3lMZUhJSm5FCmJONkdLTWxBRnNNRythK2FYcHNEMHhTdWVKeDhS'
    b'd2ZxNk5INzJtb2xpRkR4VFRhdGU0U1g0MDFjS1QzSnBHS0Y4aEVYMDd2cURpUzEKQnI4dE9v'
    b'SS9WVGRKVHlGR0ZxUFlZUVJKb3J0NUVhZU10YkcxVWN3cCtRSFJtSnVjSHQxdnlVb21TZnoz'
    b'QWx4akd4SDhmdXhZbEx4dApvd0hXWDhrMUFkMEM3M3VPakpvNi9LTkdmWENmWEl4Nlg0Z2Yx'
    b'alR6aDc3Ym1WV3pnODdteFdoU0hzVU9JdzQralo2K0ZNMFRkQVFmCkRpN05pNnYrYmlUZllr'
    b'VHZCTEppTFhySHcxU2FPK2tiOEpGemVhbHZ1SWJ3OWpieW5WMGtGajVHNElxdkkxY2ZTTHow'
    b'NXEyWTg3K04KUFcwbVppSUd4VVVJRGVQSnIzd1Y3K1pOWklLRmFJbllSMmJXSlExWDA5WDZL'
    b'TGwrbVJyakZiSjZnS0thdWJocngyR2wza0VxT1FmVgpIWEFpK05QZ0RWU1JORTRuMDdlR3RD'
    b'MHdrS2ltenJPQ29KWWlxZWZadS9ZNktMaU94Sk9QRTdqc2E4Z2xINXg1MEJxUEpqSjhCUDdM'
    b'CnIwUU9Ib2cwZThNNmpER05CSzY5Z2Z6ZVBmRGtRbEpMWDhJNysvUDc5d210dlpFQ1lSQ1BQ'
    b'NCtXM1V3NE5vOFNmeGVJSWRTaVUvQUcKYTRiOHNwMGhMVGk4OHluRW5oK1R5OG9JMmIySW5u'
    b'TVF6VFFiQW90WnZXc1ozc3dnVjVSSkdMa012NG9tdUxtazlLREpsckduRmZuWQpBdytYQ1RW'
    b'MWlHZDhFYm1xR3JtcUduUENKQkwvdFlDMFllR1o4eS9rYzJsRTJjZERvZk5KdW9xWVZIOEtq'
    b'YW5Ia0xNYkVGS0x5Y2ZyCjBIdXlKTXUrUS9tWUM1d3MrckQ2d3FYSEkrUjdpVWJDOUVVVXhN'
    b'eTdaSE0yRjh3Nm1mV0owN2l2KzB5V05QY2h5UzV1dXUyMmc1WWoKVEQ0T2EzdkxCLzlaV29i'
    b'NXp2cjlIeVd2bDhDL1gwdG0rYjUrc3l5ci9LbWxsd1hkWjdJcVBvdExUcDlCTm05RCtoMzZC'
    b'aFZpa1RCMgpyaGRQeVZRbmdnOFhYMEVkbVpHTDhRYzNvYVYyRXgzc0lSWHZwYmR6RXdOeEhR'
    b'VFluaDdPVEZGQ2xnOStLdDdaWnpCdzN6MTQzamZBCmtXM1pTdkFyRjMvd2JnOEdjVTJhUXJh'
    b'OUhjSG5ZM3Q2T0FDUmVKYStubTJrWTcxRVhHVVUxVTVBOGRaaGwwekNYelRTNlFkL0dxeDgK'
    b'aEZ6b1IwVGJucUhTOVNMakpremw1bWZXc2tmUXdMWlIvRk0rdmhCQndLVzZ5Tzdjc1cvNDh2'
    b'ZFBvNDBaaTFUMDRibGNkZHAwY2l0ZQoyNWZrQlp2QXRtbVgzZHowbTFVMFREaVJhdmVMeEVO'
    b'UGt3dmRpWlh0SC9MZHBDRXQyRFJOckQwM29DbFpxaW9Ma2NjK1JYdlJWVHcrCjJMZ3ZNbVU0'
    b'NjhRVGtLUkR6d2VIUXlINlluSFUrcEcwYjlsTXRLc0w5L3VTcWZlemRja1NsSkVqRVVXSnVT'
    b'Zk5JUEJleGJCd3NJR2QKdnN0UkduOUh4YkJTTkRtUEVMb1dJNTl6QkIvMndZa2lPY3NESlYr'
    b'bDVPVDFsSTZZelp0dE1TeEVLbHdXQythTTRyVEdjanlhZ3E0ZgpmRTY0cFcwdjFybm5neVN4'
    b'cmJNTGFlNlhFY1FQbjNvaWthQzFzZ3JoMklsNE5KbHBvNHU1OXd1am1lTHBCa0ZrUTBlY2ty'
    b'cFpsRTUvCkU4b3ZSemY4aU5MUVhuUTM1QmUrcHhNRGFONEMydGJjU0cvZkJzN2IvRU5DT1pr'
    b'clJrVDU3akc3R0hIY2RYU3Z2NDU0ZUJWUlRrSlcKQzdBOFU5SDhOWWlpZ0dsYWdJVW9pbmc5'
    b'KzFyaGRDYURhWnFBaUNTSldKWk5OdG1Ca0ZxRGtZMFN0TjhrV0RxWllVMFAwcmJoQVpacwp0'
    b'N2gyMnlTcVhBWlBqTHVOMnBLakdISFMvZWlwS0I3LzBGNnlNK1NTckx5ZUlKdE5FVzEvR1gv'
    b'WnNRaVN4dXFsdDNQVTFJdDQ5SjBJCm9keStRdzU2ZkJpUlpYUnVTQ0lYbjRXNyt4RVVxNTBD'
    b'Tll1cjRRcDhoWlcwdi8yZlpQVVlvMDY2bTNnOHpwNjJQUWdJMU5YVkVRd0cKMmIzNk82aXFs'
    b'NnBKdDVCT2xKSlpmeUh4UENoeUJvcHZwM1BUbmVUNlYyS3Bsd0hRbVpONXVXTTAzNTV5RWF2'
    b'L2VBTVRabnlUV0RoRQpJcnlGZ3ByWnlMS001aTEyQkI4TTI3WnBYM01SN3R4S2VzTXFVVTBq'
    b'Yndsa014UFl0ZlZWa3VZNDZnbzF6dk04UTN2dk9Gd1R2NFhlCnZ4VEIzSVFwamFISXM0Vkkw'
    b'a2ZYOXJYY3U3V09LV2FJRTRKcmVHRlJDVmZOdTRuQ2dpSU0wOERuRC9MVHhYZHpOQy93Vm1J'
    b'aXE5L2UKeVBYak82bExRWUUzeVVDMkFUbXlEVk9Qb2cyZno4Nlh0ekMvWmkyTEUzTkoyNDIw'
    b'TnE5RVQzU3hhK2tadUdRTFBaTkZhTCtldkhvOApOVE9XZkd4TzhKbXVvcnQzTHNFSTNZNlI2'
    b'c1FRQW1UU1NWelYxeEx0YjhQWGVCVnIzN3lGNmI0VnBIUVg4YndmMDlXRVp1MW1RQjFMClBD'
    b'bXdLNjV5eitBOGtxWklvOUtEYXZXeXlaekFoS0RFcEdFZUJBRTI5bVRZR0RFWUo3VWd5QUUy'
    b'Wnl2eFluTmo2VzlvQ09oNFBRYmwKVmdzcFJpSHFiMU9neHZCb09kNkluOHlFcGgrUTMvRVFS'
    b'ZVVOWlBiZWhlYjI0aUtCNHExQ3JMcUp5b1p6bkRiNDQraFpNWTF3MTA0OAphaDR4Y0FMRFQx'
    b'bENOaDBqa3dxVDNUUUZMSkdCaklkaWQ0TGVRUjlQaHM5bFZ5cElqYitQNlVVUm51MmR5Y0xZ'
    b'ZUR4NkNzdWxvSXNmCi9jaW5ZaHRvV1oyRTV1T1M0azJjV2JLQzF3Y0xhSStYVWV0SmMySDVZ'
    b'b1lWeGVuWGd4U3JDUVRKUmg2L0NtK2dCczFiU050cloySEcKWGllVlZpbXJyS0ZpeHJvaE4z'
    b'UTU1TExvOEo2bHFNWkdOSGNBdGVwS1JwejZQS0lvNGZZVmdabkNMTGlBTG4wS21waEZ6MG1z'
    b'eXg3RApsblFwamQ0OS9Mei9BamE0cnFhaWZOL2dROWFFWE01Q01Nd1AzOW1taFprMVNMKzNx'
    b'YWg0TkJ2Y1YvT3ovZ3NaNmV0Z2R5YkE2c3drCjlKeU1td3hkK2lTTXdvc1JiUjIzcndoQkVC'
    b'Zys4dzlvMWRmZzhmcFJ6VzJFVzE5d3N1aFAwdmZOSkFmeEJRLyt1RUwzdXFzUm80dTQKYThj'
    b'M2VMaDNCajVaNUxLeE9jWkliOUdRZlpnV2N3emZhTDJWVENvUFpwNXpSeXVjWGZJSzRXd0Z0'
    b'aUJUcHU3bHVZRTVMTnFlQjFsQwpkYXY4YlBpUE9kcjFManZVaTJteFR1U1JGcFdvYWZQVmto'
    b'WE1iM2dBS3ppWHl1TWZQdWd4cGVMOWFKNGdrcXc0Z2o4dGljRzlLRm9SCjBieUxSVysxTTNO'
    b'TU1hVjd2NEVaZVFuYjNqYzkvTEs1Z0dmREV4bHVyZVRyTlgra291RmF5a2YvR3dDOXU1K25w'
    b'M2tCdjl6N3IreVUKcG5ObVJUTm5jQTJDWUdNRGNzR3BETlkveXRLV01PZFBycVJZTThsbkJ2'
    b'RVgxLzJ6WGFvajUxV0dQU3RQeFcrOVRpemxScFFFeEJFUApZQm9HUnM4VEZFejROZjdpK2cv'
    b'ZUpKRTJvcHN1UXlxZGk2SVdZTFplaVdWYUJMMFpFcHhBeFl3M2pvVExjdVM4SjB1dW0wK1Bl'
    b'aXVhCks0L3VQcE5NdnBEQkhROVNNUEhSRDhrRjhCY09wMmppNDhSMlBVd3lLNVB4ek1XdDV1'
    b'aFJia2FxKy82UmNsbU9ySmVSNXZRRW5SdSsKUjkzVSt4QkZDZk85Si9nL3JzMFgzeHUyYkZ0'
    b'elBaWEgzb282eEZkS2ZtWUZPeHpCVmJTREk5Z1I3T0FJZG5BRU96aUNIUnpCRG81ZwpCMGV3'
    b'Z3lQWUVlemdDSFp3QkR2OC95QURsbk1aamx6K0Y4UTIvSlYvUHUyd0FBQUFKWFJGV0hSa1lY'
    b'UmxPbU55WldGMFpRQXlNREl6CkxUQTFMVEF6VkRJek9qQTNPalUzS3pBd09qQXdFWmx4Q2dB'
    b'QUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3TlMwd00xUXkKTXpvd056bzFOeXN3'
    b'TURvd01HREV5YllBQUFBQVNVVk9SSzVDWUlJPQoiIGlkPSJpbWFnZTEyODUiIC8+CiAgPC9n'
    b'Pgo8L3N2Zz4K', 'RU_NIZ')

RU_NIZ = b64_RU_NIZ
index.append("RU_NIZ")
index.append("Russia Nizhegorodskaya oblast")
catalog["RU_NIZ"] = RU_NIZ
catalog["Russia Nizhegorodskaya oblast"] = RU_NIZ
country["Russia Nizhegorodskaya oblast"] = ('RU_NIZ', '', 1)
lookup["RU_NIZ"] = ('RU_NIZ', '', 'Russia Nizhegorodskaya oblast', 1)
lookup["Nizhny Novgorod"] = ('RU_NIZ', '', 'Russia Nizhegorodskaya oblast', 1)
lookup["Russia Nizhegorodskaya oblast"] = ('RU_NIZ', '', 'Russia Nizhegorodskaya oblast', 1)
details["RU_NIZ"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Nizhny Novgorod"}
regional["RU_NIZ"] = ('RU_NIZ', 'Russia Nizhegorodskaya oblast', 1)
regional["Russia Nizhegorodskaya oblast"] = ('RU_NIZ', 'Russia Nizhegorodskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_NVS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI4OTkuOTEi'
    b'IGhlaWdodD0iNjAwIiB2aWV3Qm94PSIwIDAgODk5LjkxIDYwMCI+PHRpdGxlPkZsYWcgb2Yg'
    b'Tm92b3NpYmlyc2sgb2JsYXN0PC90aXRsZT48cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAuNGg4'
    b'OTkuMTJ2NTk5LjRIMHoiLz48cGF0aCBmaWxsPSIjMDA4ZTFmIiBkPSJNNjUxLjc3IDBoMjQ4'
    b'LjE0djYwMEg2NTEuNzd6Ii8+PHBhdGggZD0iTTM5OS4yIDBoOTguOWMwIDk5Ljk5My4yNiAy'
    b'MDAuMTc3LjM3IDMwMCAuMTEgOTkuODIzLjIzIDE5OS45ODcuMzcgMzAwaC05OS42NlYtLjE4'
    b'IiBmaWxsPSIjMDAzOWE2Ii8+PHBhdGggZD0iTTI0OSA0MjdoMTUwLjE1djYuNDVIMjQ5VjQy'
    b'N000OTguMTMgNDI2LjgxaDE1Mi42OHY2LjQ1SDQ5OC4xM3YtNi40NSIvPjxwYXRoIGQ9Ik0z'
    b'OTkuMTUgNDI1LjgyaDk5LjQ5VjQzNWgtOTkuNDl2LTkuMTUiIGZpbGw9IiNmZmYiLz48cGF0'
    b'aCBkPSJNMzkyLjQyIDIzMS43MmgxMTMuOTF2LTguMzJjLTguMTUtMjAuNTYtMjIuMzgtMzEu'
    b'NTMtMzcuNjYtMzYuM2wtMi4xLS42di01Ljk0aC0zNC41MXY2LjExbC0xLjI1LjM0YTU5LjY0'
    b'IDU5LjY0IDAgMCAwLTM4LjQzIDM2LjQ0VjIzMiIgZmlsbD0iZ29sZCIvPjxwYXRoIGQ9Ik0z'
    b'MTEuNjQgNDE5Ljg1Yy0xLjUxLS40LTMtLjgyLTQuNTItMS4yOCAyLTEuNTkgMy44OS0zLjM1'
    b'IDUuODUtNWw0LjkxIDEuMTZjLTIuMTIgMS43MS00LjE2IDMuNDUtNi4yNCA1LjEyeiIgZmls'
    b'bD0iI2QyMDAwMCIvPjxwYXRoIGQ9Ik0zMTEuNjQgNDE5Ljg1Yy0xLjUxLS40LTMtLjgyLTQu'
    b'NTItMS4yOCAyLTEuNTkgMy44OS0zLjM1IDUuODUtNWw0LjkxIDEuMTZjLTIuMTIgMS43MS00'
    b'LjE2IDMuNDUtNi4yNCA1LjEyeiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMjIuOTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGggZD0iTTMwNC4x'
    b'NyA0MTcuOTJsLTQuNTItMS4zM2MyLTEuNjIgMy44OS0zLjM1IDUuODUtNSAxLjU5LjQ1IDMu'
    b'MjQuODIgNC44NiAxLjIyLTIuMDcgMS44NC00LjExIDMuNDQtNi4xOSA1LjExeiIgZmlsbD0i'
    b'I2QyMDAwMCIvPjxwYXRoIGQ9Ik0zMDQuMTcgNDE3LjkybC00LjUyLTEuMzNjMi0xLjYyIDMu'
    b'ODktMy4zNSA1Ljg1LTUgMS41OS40NSAzLjI0LjgyIDQuODYgMS4yMi0yLjA3IDEuODQtNC4x'
    b'MSAzLjQ0LTYuMTkgNS4xMXoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1p'
    b'dGVybGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik0yODAuMzcg'
    b'MjAwLjg4YTYuMTMgNi4xMyAwIDAgMSA4LjcyLTIuODRjMy42NiAzLjMyIDMuMjEgNC4xNyA2'
    b'IDguOCAxLjA4IDEuNzMgMy41NSAzLjkyIDYgNi44N2E2OS41MyA2OS41MyAwIDAgMSAxMyAy'
    b'Ny42OWMzLjMyIDE1LTEuODcgMjguNC03LjM2IDM5LjQ4LTMuODEgNi40OC04IDEyLjY0LTEx'
    b'LjM2IDE5LjQ1LTIuNDQgNS40LTUgOS44My00LjggMTYuODcuMiA0LjIzIDEuNDUgOC4zNSA2'
    b'LjkzIDcuMTlhMTEuNSAxMS41IDAgMCAwIDYuMTktNS4xNCAyNC45NCAyNC45NCAwIDAgMCAx'
    b'LjgyLTEuOTNjLS42MiA2LjQyLjQzIDEyLjg5LTEuOSAxNy44NGExMy44MyAxMy44MyAwIDAg'
    b'MS0xMC45MSA0Ljk0IDEzLjQ2IDEzLjQ2IDAgMCAxLTE0LjUxLTkuNjhjLTguODktMjQuNiAz'
    b'Ljg2LTY4IDMuODktODUuNzcgMC0yMS45LTguMDktMzQuNjgtMS42NS00My43MU0zMDMuNTgg'
    b'MTU0LjY3YTEwLjU0IDEwLjU0IDAgMCAwIC42MiA2LjQ4Yy0uNDMtNS42OC0uNTQtMTAuNzEg'
    b'My40NC0xMy44IDMuNjQtMi4xMyA4LjIxIDEgOS41MSA1LjY4IDAtMiAxLjUxLTYuMTEgMy01'
    b'LjUxIDIgMCAxLjMzIDQuMzcgMi44NCA2LjM2YTYwLjg5IDYwLjg5IDAgMCAxIDE3LjYxIDku'
    b'NTdjMi4zIDEuNzkgNC4xMiAyLjE5IDQuNDMgNC42My42MiA2LjI4LTQuOTQgNi42Mi0xMi4x'
    b'OCA1LjM0LTEuNTYgMS40MiAyLjMzIDIuNjQgNCAyLjg0YTIuMjcgMi4yNyAwIDAgMS0xLjM2'
    b'IDIuNyA0NS40NCA0NS40NCAwIDAgMS0xMSAuMzFjLTIuODQuMjYtMy42NiA1LjQgMS42NSA3'
    b'Ljg0YTEwMy4yNCAxMDMuMjQgMCAwIDEgMzkgMjcuNjZsLTMyLjg2IDIwLjE2Yy01LTE1LjA4'
    b'LTE0LjItMjguNzctMjguNC00Mi4yOWEzMy44MyAzMy44MyAwIDAgMS05LjM0LTIxLjM5IDE5'
    b'IDE5IDAgMCAxIDkuMTItMTYuNTYiLz48cGF0aCBkPSJNMzI4LjI5IDE2MC4xOGEzLjY2IDMu'
    b'NjYgMCAwIDEgMi44NCAzLjcyYzAgMS43LTMuMSAxLjM5LTUuMTQuNTFhMy4xNSAzLjE1IDAg'
    b'MCAxLTIuMzMtMy43OGMuNDgtMS4zMyAyLjUzLTEuMzEgNC42LS40NSIgZmlsbD0iI2ZmZiIv'
    b'PjxwYXRoIGQ9Ik0zMjcuODkgMTYwLjc4YTEuNTEgMS41MSAwIDEgMS0xLjUxIDEuNTMgMS41'
    b'MSAxLjUxIDAgMCAxIDEuNTEtMS41MyIvPjxwYXRoIGQ9Ik0zNDEuOTUgMTY0LjNhOC41MiA4'
    b'LjUyIDAgMCAxIDQuODYgMS45M2MxLjQ4IDMuMDctMS44MiA1LjQtMi4xMyA0LjY5YTQgNCAw'
    b'IDAgMC0uNjItMi44NGMtLjc3LS4yLTEuMTEuNzctMS4zMyAxLjMzYTcuMzggNy4zOCAwIDAg'
    b'MS0uNzgtNS4xMXoiIGZpbGw9IiNmZmYiLz48cGF0aCBkPSJNMzQxLjk1IDE2NC4zYTguNTIg'
    b'OC41MiAwIDAgMSA0Ljg2IDEuOTNjMS40OCAzLjA3LTEuODIgNS40LTIuMTMgNC42OWE0IDQg'
    b'MCAwIDAtLjYyLTIuODRjLS43Ny0uMi0xLjExLjc3LTEuMzMgMS4zM2E3LjM4IDcuMzggMCAw'
    b'IDEtLjc4LTUuMTF6IiBmaWxsPSJub25lIi8+PHBhdGggZD0iTTMzNy4wNiAxNzVjMi42NC0u'
    b'MiA1LjE0LjgyIDguMTUtLjgyYTYuNTYgNi41NiAwIDAgMSA5LjIuMmMxLjgyIDEuMDggNC44'
    b'LS4zMSA2LjgyLS41MWE1LjA4IDUuMDggMCAwIDEtNi4yMiA1LjExYy0yLjctLjI2LTMtMi4x'
    b'My02LTIuMjQtMi41IDAtMi44NCAyLjM5LTQuODMgMi41Ni00LS40LTQuMTItMi44NC03LjI3'
    b'LTQuMjMiIGZpbGw9IiNkMjAwMDAiLz48cGF0aCBkPSJNMzIyLjE1IDE4MS40NWMuNDUtMi4x'
    b'MyAxLjg3LTIuMzMgNS0yLjA3YTIuMTkgMi4xOSAwIDAgMC0uODUgMy43OGMzLjM4IDQuMDYg'
    b'MTMgOS4wOSAyMC4zOSAxNS4xNGExMDQuNDMgMTA0LjQzIDAgMCAwLTIxLjgxLTExLjcgNC43'
    b'NCA0Ljc0IDAgMCAxLTIuNzMtNS4xNXoiIGZpbGw9IiNmZmYiLz48cGF0aCBkPSJNMzIyLjE1'
    b'IDE4MS40NWMuNDUtMi4xMyAxLjg3LTIuMzMgNS0yLjA3YTIuMTkgMi4xOSAwIDAgMC0uODUg'
    b'My43OGMzLjM4IDQuMDYgMTMgOS4wOSAyMC4zOSAxNS4xNGExMDQuNDMgMTA0LjQzIDAgMCAw'
    b'LTIxLjgxLTExLjcgNC43NCA0Ljc0IDAgMCAxLTIuNzMtNS4xNXoiIGZpbGw9Im5vbmUiLz48'
    b'cGF0aCBkPSJNMzA5Ljg4IDE1Mi4yM2MxLjM5LTEgMy40Ni42NSAzLjQ2IDMuMTUtMi41LS40'
    b'NS0zLjI0Ljc3LTMuNjQgNC40My0xLjgyLTEuNzMtMi02LjMxLjE0LTcuNTgiIGZpbGw9IiNm'
    b'ZmYiLz48cGF0aCBkPSJNMzk3LjI1IDE4MC40OWMtMi40MS0zLjM1LTEzLjE1IDIuODQtNy43'
    b'IDE0IC44MiAyMi43Mi0xNC42NSAyMS40Ny0yNS4yNSAxNi4wN0E2NS41OCA2NS41OCAwIDAg'
    b'MSAzNzQuNjcgMjM1YzAgLjM0IDE2LjMtOCAyMC41MS0xOS42NSAyLjMzLTEwIDkuNjYtMzQu'
    b'NDUgMi4wNy0zNC44OCIvPjxwYXRoIGQ9Ik00MDEgMTgwLjM3YTIuODQgMi44NCAwIDAgMC00'
    b'LjIzLjgyIDEuMjggMS4yOCAwIDAgMS0uNi0yLjQxIDQuMjkgNC4yOSAwIDAgMSA0LjgzIDEu'
    b'NTl6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTQwMSAxODAuMzdhMi44NCAyLjg0IDAgMCAw'
    b'LTQuMjMuODIgMS4yOCAxLjI4IDAgMCAxLS42LTIuNDEgNC4yOSA0LjI5IDAgMCAxIDQuODMg'
    b'MS41OXoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIy'
    b'LjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik00MDIuNTMgMTgzYTIuODQgMi44'
    b'NCAwIDAgMC00LjIuNzcgMS4yMiAxLjIyIDAgMCAxLS42Mi0yLjMzIDQuMjkgNC4yOSAwIDAg'
    b'MSA0LjgyIDEuNTZ6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTQwMi41MyAxODNhMi44NCAy'
    b'Ljg0IDAgMCAwLTQuMi43NyAxLjIyIDEuMjIgMCAwIDEtLjYyLTIuMzMgNC4yOSA0LjI5IDAg'
    b'MCAxIDQuODIgMS41NnoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVy'
    b'bGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik00MDIuNjcgMTg1'
    b'LjgzYTIuNDcgMi40NyAwIDAgMC0zLjQ2LjQ5bC0uMTUuMjJhMS4xMSAxLjExIDAgMCAxLS41'
    b'NC0yLjA3IDMuNzggMy43OCAwIDAgMSA0LjE1IDEuMzZ6IiBmaWxsPSIjZmZmIi8+PHBhdGgg'
    b'ZD0iTTQwMi42NyAxODUuODNhMi40NyAyLjQ3IDAgMCAwLTMuNDYuNDlsLS4xNS4yMmExLjEx'
    b'IDEuMTEgMCAwIDEtLjU0LTIuMDcgMy43OCAzLjc4IDAgMCAxIDQuMTUgMS4zNnoiIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIyLjkzIiBzdHJva2Ut'
    b'd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik0zNDEgMzQ0LjI4Yy0yLjg0LTIyLjQxIDIuMzktMzEu'
    b'MjQgMTAtNDIuNi0xLjgyIDguODYtMi4zMyAxNC40NiA2LjExIDE2LjcgMjEuNzYgMTEuMzYg'
    b'MjQuMjUgMjIuMjcgMTcgNTUuNDEtMi4zMyA1LjE0IDMgMTMuOCA5LjIgMTguOCA3IC43NyAx'
    b'NS41NC0yIDE4IDUuNjguMTQgNi42Ny01LjM3IDExLjgxLTE1IDEwLjkxLTE1LjA4LTQuMTIt'
    b'MTUuMzktMTguOTQtMjUuNTYtMjkuMDguNDUtNi43MyAzLjgxLTEwLjM5LS45MS0xNi4xLTQu'
    b'NDMtNi41Ni0xNS44Mi02LjU2LTE4LjgtMTkuODgiLz48cGF0aCBkPSJNMzMxLjc1IDIzMy44'
    b'OGwzMi41Mi0yMC40MmM4LjE1IDEwLjU0IDExIDE5LjcxIDE1IDMwLjUgMi44NCA2LjExIDUu'
    b'MDYgNS4yNSA4LjgzLTJzNS4wNi04IDkuMTUtMTAuMjhoMTQuNTRhNy42NyA3LjY3IDAgMCAx'
    b'IDAgMi41NmMwIDQuNDMgMCAxMS41Ni0xMC43MSAxNC44My00LjA2LjMxLTUuODUtLjgyLTgg'
    b'MS40Mi0zLjgxIDQuNjktMi42MSAxNi43LTEwLjE3IDE2Ljc2LTYuOTMtLjU3LTExLjM2LTcu'
    b'MDctMTguNTUtMTYuNTYgMS42OCA0IDIuNDEgNy4zMyA2LjMxIDEwLjM0LTUuMjUgMjIuNzIt'
    b'MTEuMzYgMjUuOTMtMTguOTIgMzcuODYtNS44NSA5LjgzLTEyLjg5IDE3LjY3LTEzLjEyIDM0'
    b'LjM0LS42MiA4LjUyIDIuNDEgMTQuNzcgMS4zMyAyNC41MS0uNTEgNC44OC0xLjUxIDE1LjA4'
    b'LTkuODMgMjAuNzktNy4yMSA2LjQyLTE4Ljc3IDIuODQtMjYuNzggNy41LTIuODQgMi4zOS00'
    b'LjggMTAuMTQtMy4zMiAxNy40N2EzLjY5IDMuNjkgMCAwIDAgMy41NSAzLjcyYzcuOS0xLjA4'
    b'IDE0LjA2LjUxIDE1LjM0IDUuOTEuNDUgNS0xMy4yOSAxMC41NC0xOC40IDkuMzctNS42OC0x'
    b'LjA4LTkuMzItOS44OC0xMC4zNy0xNiAwLTYuODIgMC0xMy42LS4xNC0yMC4zNC43MS0xMi43'
    b'IDE3LjI0LTYgMTQuMi0yNy40MS0yLjQ0LTkuMjMtMS41MS0xMy43NSAxLjU2LTIyLjE1IDAt'
    b'MTEuODctMS0yMi43MiA2LjE5LTMzLjQ2IDEwLjYyLTIyLjE1IDI1LjU2LTQyLjYgMTkuODgt'
    b'NjkuMTgiLz48cGF0aCBkPSJNMzg5LjQ5IDQwNy4yN2MuNjUtMSAxLjQ4LTEgMi42MS0uMjZh'
    b'OC4xNSA4LjE1IDAgMCAxLS45NCA2LjczYy0uMzYtMi43NC0yLjA3LTQuOTQtMS42Ny02LjQ3'
    b'eiIgZmlsbD0iI2ZmZiIvPjxwYXRoIGQ9Ik0zODkuNDkgNDA3LjI3Yy42NS0xIDEuNDgtMSAy'
    b'LjYxLS4yNmE4LjE1IDguMTUgMCAwIDEtLjk0IDYuNzNjLS4zNi0yLjc0LTIuMDctNC45NC0x'
    b'LjY3LTYuNDd6IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0'
    b'PSIyMi45MyIgc3Ryb2tlLXdpZHRoPSIuNjIiLz48cGF0aCBkPSJNMzkzLjIxIDQwNy4wN2Ex'
    b'LjYyIDEuNjIgMCAwIDEgMy0uNTdjLjg1IDIuODQtLjc3IDQuNDMtMS42NSA2LjQ4LjIxLTMu'
    b'NjEtLjg5LTMuMTUtMS4zNS01LjkxeiIgZmlsbD0iI2ZmZiIvPjxwYXRoIGQ9Ik0zOTMuMjEg'
    b'NDA3LjA3YTEuNjIgMS42MiAwIDAgMSAzLS41N2MuODUgMi44NC0uNzcgNC40My0xLjY1IDYu'
    b'NDguMjEtMy42MS0uODktMy4xNS0xLjM1LTUuOTF6IiBmaWxsPSJub25lIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyMi45MyIgc3Ryb2tlLXdpZHRoPSIuNjIiLz48cGF0'
    b'aCBkPSJNMzk2Ljg1IDQwNC41N2MwLTEgMi4yNy0xLjc5IDIuODQtLjQ1LjgyIDIuODQtMSA0'
    b'LjE3LTEuODIgNi4yMi43Ny0zLjUyLS44Ny0zLjI3LTEuMDItNS43N3oiIGZpbGw9IiNmZmYi'
    b'Lz48cGF0aCBkPSJNMzk2Ljg1IDQwNC41N2MwLTEgMi4yNy0xLjc5IDIuODQtLjQ1LjgyIDIu'
    b'ODQtMSA0LjE3LTEuODIgNi4yMi43Ny0zLjUyLS44Ny0zLjI3LTEuMDItNS43N3oiIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIyLjkzIiBzdHJva2Ut'
    b'd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik0zOTkuNjYgNDAxLjYyYzAtMSAxLjI4LTIuMyAyLjE5'
    b'LS40IDEgMi41Ni0uOTQgMy45Mi0xLjcgNS42OCAxLjE4LTMuOS0xLTMuNjEtLjQ5LTUuMjh6'
    b'IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTM5OS42NiA0MDEuNjJjMC0xIDEuMjgtMi4zIDIu'
    b'MTktLjQgMSAyLjU2LS45NCAzLjkyLTEuNyA1LjY4IDEuMTgtMy45LTEtMy42MS0uNDktNS4y'
    b'OHoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIyLjkz'
    b'IiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik0zMDcuMTMgNDIwYTEuODUgMS44NSAw'
    b'IDAgMSAyLjU2LS4yIDUuMTcgNS4xNyAwIDAgMS0uOTQgNS4yNWMtLjM0LTIuMDUtMi4wMi0z'
    b'Ljg2LTEuNjItNS4wNXoiIGZpbGw9IiNmZmYiLz48cGF0aCBkPSJNMzA3LjEzIDQyMGExLjg1'
    b'IDEuODUgMCAwIDEgMi41Ni0uMiA1LjE3IDUuMTcgMCAwIDEtLjk0IDUuMjVjLS4zNC0yLjA1'
    b'LTIuMDItMy44Ni0xLjYyLTUuMDV6IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS1taXRlcmxpbWl0PSIyMi45MyIgc3Ryb2tlLXdpZHRoPSIuNjIiLz48cGF0aCBkPSJNMzEw'
    b'LjgyIDQxOS44NWExLjczIDEuNzMgMCAwIDEgMy0uNDVjLjg1IDIuMTktLjc3IDMuNDEtMS42'
    b'OCA1LjA4LjI3LTIuOS0uODktMi40OC0xLjMyLTQuNjN6IiBmaWxsPSIjZmZmIi8+PHBhdGgg'
    b'ZD0iTTMxMC44MiA0MTkuODVhMS43MyAxLjczIDAgMCAxIDMtLjQ1Yy44NSAyLjE5LS43NyAz'
    b'LjQxLTEuNjggNS4wOC4yNy0yLjktLjg5LTIuNDgtMS4zMi00LjYzeiIgZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMjIuOTMiIHN0cm9rZS13aWR0aD0i'
    b'LjYyIi8+PHBhdGggZD0iTTMxNC40NiA0MTcuODZjMC0uNzcgMi4yNy0xLjQ4IDIuNy0uNDUu'
    b'ODIgMi4yNC0xIDMuMzUtMS44MiA0Ljk0Ljg1LTIuNy0uNzctMi41LS44OC00LjQ5eiIgZmls'
    b'bD0iI2ZmZiIvPjxwYXRoIGQ9Ik0zMTQuNDYgNDE3Ljg2YzAtLjc3IDIuMjctMS40OCAyLjct'
    b'LjQ1LjgyIDIuMjQtMSAzLjM1LTEuODIgNC45NC44NS0yLjctLjc3LTIuNS0uODgtNC40OXoi'
    b'IGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIyLjkzIiBz'
    b'dHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik0zMTcuMjEgNDE1LjQ4YTEuMTQgMS4xNCAw'
    b'IDAgMSAyLjE5LS4zMWMxIDItLjk0IDMuMTUtMS43IDQuNTQgMS4xOS0zLjA3LS45NC0yLjk1'
    b'LS40OS00LjIzeiIgZmlsbD0iI2ZmZiIvPjxwYXRoIGQ9Ik0zMTcuMjEgNDE1LjQ4YTEuMTQg'
    b'MS4xNCAwIDAgMSAyLjE5LS4zMWMxIDItLjk0IDMuMTUtMS43IDQuNTQgMS4xOS0zLjA3LS45'
    b'NC0yLjk1LS40OS00LjIzeiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0'
    b'ZXJsaW1pdD0iMjIuOTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGggZD0iTTQxMi4xOCAy'
    b'MjkuOTFhNC45MSA0LjkxIDAgMCAxLTIuMjIgNS42OGMtLjMxIDIgMS4yNSAzLjI3IDIuMTkg'
    b'MS42OGE4LjUyIDguNTIgMCAwIDAgLjAzLTcuMzZ6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0i'
    b'TTQxMi4xOCAyMjkuOTFhNC45MSA0LjkxIDAgMCAxLTIuMjIgNS42OGMtLjMxIDIgMS4yNSAz'
    b'LjI3IDIuMTkgMS42OGE4LjUyIDguNTIgMCAwIDAgLjAzLTcuMzZ6IiBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyMi45MyIgc3Ryb2tlLXdpZHRoPSIu'
    b'NjIiLz48cGF0aCBkPSJNNDEwLjM3IDIzMC42N2E0IDQgMCAwIDEtMi4yMiA1LjJjLS4zMSAx'
    b'LjkzIDEuNTEgMyAyLjUzIDEuNjJhNi41MyA2LjUzIDAgMCAwLS4zMS02LjgyeiIgZmlsbD0i'
    b'I2ZmZiIvPjxwYXRoIGQ9Ik00MTAuMzcgMjMwLjY3YTQgNCAwIDAgMS0yLjIyIDUuMmMtLjMx'
    b'IDEuOTMgMS41MSAzIDIuNTMgMS42MmE2LjUzIDYuNTMgMCAwIDAtLjMxLTYuODJ6IiBmaWxs'
    b'PSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyMi45MyIgc3Ryb2tl'
    b'LXdpZHRoPSIuNjIiLz48cGF0aCBkPSJNNTg2Ljc0IDQxOS40NWMxLjUxLS40IDMtLjgyIDQu'
    b'NTQtMS4yOC0yLTEuNjItNC0zLjI3LTUuOTEtNC45NC0xLjY1LjQ1LTMuMjcuODItNC44NiAx'
    b'LjIyeiIgZmlsbD0iI2QyMDAwMCIvPjxwYXRoIGQ9Ik01ODYuNzQgNDE5LjQ1YzEuNTEtLjQg'
    b'My0uODIgNC41NC0xLjI4LTItMS42Mi00LTMuMjctNS45MS00Ljk0LTEuNjUuNDUtMy4yNy44'
    b'Mi00Ljg2IDEuMjJ6IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxp'
    b'bWl0PSIyMi45MyIgc3Ryb2tlLXdpZHRoPSIuNjIiLz48cGF0aCBkPSJNNTk0LjI2IDQxNy41'
    b'YzEuNDgtLjQgMy0uODIgNC41Mi0xLjI4bC01Ljg4LTVjLTEuNjUuNDUtMy4yNy44Mi00Ljg2'
    b'IDEuMjIgMi4wNSAxLjc2IDQuMTIgMy40NCA2LjIyIDUuMDZ6IiBmaWxsPSIjZDIwMDAwIi8+'
    b'PHBhdGggZD0iTTU5NC4yNiA0MTcuNWMxLjQ4LS40IDMtLjgyIDQuNTItMS4yOGwtNS44OC01'
    b'Yy0xLjY1LjQ1LTMuMjcuODItNC44NiAxLjIyIDIuMDUgMS43NiA0LjEyIDMuNDQgNi4yMiA1'
    b'LjA2eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMjIu'
    b'OTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGggZD0iTTYxOCAyMDAuNzdhNi4xNiA2LjE2'
    b'IDAgMCAwLTguNzItMi44NGMtMy42OSAzLjM1LTMuMjcgNC4yMy02IDguOC0xLjA4IDEuNzkt'
    b'My41OCAzLjkyLTYgNi44N2E3MCA3MCAwIDAgMC0xMyAyNy42NmMtMy4zNSAxNC44OCAxLjgy'
    b'IDI4LjQgNy4zNiAzOS4zNCAzLjg2IDYuNDggOC4wNyAxMi42NCAxMS4zNiAxOS40NSAyLjQ0'
    b'IDUuNDUgNSA5LjgzIDQuOCAxNy0uMjMgNC4yMy0xLjQ1IDguMjktNi45MyA3LjEzYTEwLjkz'
    b'IDEwLjkzIDAgMCAxLTYuMTYtNSAyNC4zNSAyNC4zNSAwIDAgMS0xLjgyLTJjLjYyIDYuMzYt'
    b'LjQ1IDEyLjg0IDEuOSAxNy43OGExNS4xOSAxNS4xOSAwIDAgMCAyNS4zOS00Ljc0YzguOTIt'
    b'MjQuNi0zLjg5LTY4LTMuODktODUuNjkgMC0yMS44MSA4LjE1LTM0LjU0IDEuNjUtNDMuNjVN'
    b'NTk0Ljg2IDE1NC40N2ExMC41NCAxMC41NCAwIDAgMS0uNjIgNi40OGMuNC01LjY4LjUxLTEw'
    b'LjU5LTMuNDYtMTMuNzUtMy42Ni0yLjEzLTguMjEgMS05LjU0IDUuNjggMC0xLjkzLTEuNDgt'
    b'Ni0zLTUuNDUtMiAwLTEuMjggNC4yOS0yLjg0IDYuMzFhNjAuNjkgNjAuNjkgMCAwIDAtMTcu'
    b'NTUgOS41N2MtMi4zIDEuNzktNC4xNyAyLjE5LTQuNDkgNC42OS0uNiA2LjI4IDUgNi42MiAx'
    b'Mi4yMSA1LjM0IDEuNTYgMS40Mi0yLjMzIDIuNjQtNCAyLjg0YTIuMjQgMi4yNCAwIDAgMCAx'
    b'LjMzIDIuNjQgNDUuNDQgNDUuNDQgMCAwIDAgMTEgLjRjMi44NC4yIDMuNjkgNS4zNC0xLjU5'
    b'IDcuODRhMTAzLjE4IDEwMy4xOCAwIDAgMC0zOSAyNy42NmMxMSA2LjczIDIxLjkzIDEzLjM1'
    b'IDMyLjgzIDIwIDUtMTUgMTQuMi0yOC42OSAyOC40LTQyLjIzYTMzLjggMzMuOCAwIDAgMCA5'
    b'LjMyLTIxLjM5IDE5LjI4IDE5LjI4IDAgMCAwLTkuMDYtMTYuNjEiLz48cGF0aCBkPSJNNTcw'
    b'LjEyIDE2MGEzLjY2IDMuNjYgMCAwIDAtMi44NCAzLjcyYy4xNCAxLjcgMy4wNyAxLjQyIDUu'
    b'MTEuNTFhMy4xNSAzLjE1IDAgMCAwIDIuMzMtMy43OGMtLjUxLTEuMzMtMi41LTEuMzEtNC41'
    b'NC0uNDUiIGZpbGw9IiNmZmYiLz48cGF0aCBkPSJNNTcwLjUyIDE2MC41OGExLjUxIDEuNTEg'
    b'MCAwIDAgMCAzIDEuNDggMS40OCAwIDAgMCAxLjU2LTEuMzl2LS4wOWExLjUxIDEuNTEgMCAw'
    b'IDAtMS40OC0xLjUzaC0uMDl6Ii8+PHBhdGggZD0iTTU3MC41MiAxNjAuNThhMS41MSAxLjUx'
    b'IDAgMCAwIDAgMyAxLjQ4IDEuNDggMCAwIDAgMS41Ni0xLjM5di0uMDlhMS41MSAxLjUxIDAg'
    b'MCAwLTEuNDgtMS41M2gtLjA5eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMjIuOTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGggZD0iTTU1Ni40'
    b'NiAxNjQuMWE5LjA2IDkuMDYgMCAwIDAtNSAxLjkzYy0xLjQ4IDMuMTUgMS45IDUuNDUgMi4y'
    b'MiA0Ljc0YTMuNzIgMy43MiAwIDAgMSAuNjUtMi44NGMuNzQtLjI2IDEuMTYuNzEgMS4zOSAx'
    b'LjI4YTcuMyA3LjMgMCAwIDAgLjc0LTUuMTF6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTU1'
    b'Ni40NiAxNjQuMWE5LjA2IDkuMDYgMCAwIDAtNSAxLjkzYy0xLjQ4IDMuMTUgMS45IDUuNDUg'
    b'Mi4yMiA0Ljc0YTMuNzIgMy43MiAwIDAgMSAuNjUtMi44NGMuNzQtLjI2IDEuMTYuNzEgMS4z'
    b'OSAxLjI4YTcuMyA3LjMgMCAwIDAgLjc0LTUuMTF6IiBmaWxsPSJub25lIi8+PHBhdGggZD0i'
    b'TTU2MS4yOSAxNzQuODRjLTIuNjEtLjItNS4xMS44Mi04LjE1LS44MmE2LjM5IDYuMzkgMCAw'
    b'IDAtOSAuMTdsLS4wOC4wOWMtMS44MiAxLTQuODMtLjQtNi45LS41N2E1LjExIDUuMTEgMCAw'
    b'IDAgNi4xMSA1LjA4YzIuODQtLjI2IDMuMDctMi4xMyA2LTIuMjRzMi44NCAyLjM5IDQuOCAy'
    b'LjU2YzQtLjQgNC4xMi0yLjg0IDcuMjctNC4yMyIgZmlsbD0iI2QyMDAwMCIvPjxwYXRoIGQ9'
    b'Ik01NzYuMjMgMTgxLjM0Yy0uNTEtMi4wNy0xLjg3LTIuMzMtNS0yIDEuODIgMCAyIDIuMzku'
    b'OTEgMy42OS0zLjM4IDQuMDYtMTMgOS4wOS0yMC4zNiAxNS4xOWExMDAuNTEgMTAwLjUxIDAg'
    b'MCAxIDIxLjc2LTExLjc2IDQuNzQgNC43NCAwIDAgMCAyLjY5LTUuMTJ6IiBmaWxsPSIjZmZm'
    b'Ii8+PHBhdGggZD0iTTU3Ni4yMyAxODEuMzRjLS41MS0yLjA3LTEuODctMi4zMy01LTIgMS44'
    b'MiAwIDIgMi4zOS45MSAzLjY5LTMuMzggNC4wNi0xMyA5LjA5LTIwLjM2IDE1LjE5YTEwMC41'
    b'MSAxMDAuNTEgMCAwIDEgMjEuNzYtMTEuNzYgNC43NCA0Ljc0IDAgMCAwIDIuNjktNS4xMnoi'
    b'IGZpbGw9Im5vbmUiLz48cGF0aCBkPSJNNTg4LjQ3IDE1MmMtMS4zNi0uOTEtMy40NC43MS0z'
    b'LjQ2IDMuMTUgMi41My0uNDUgMy4yNy43NyAzLjYxIDQuNDMgMS44Ny0xLjczIDItNi4yOC0u'
    b'MTQtNy41OCIgZmlsbD0iI2ZmZiIvPjxwYXRoIGQ9Ik01MDAuNTcgMTgwLjE1YzIuNDEtMy4z'
    b'NSAxMy4xOCAyLjg0IDcuODEgMTMuOTItLjYyIDIyLjcyIDE0LjgzIDIxLjM2IDI1LjM5IDE1'
    b'LjkzYTY0LjQxIDY0LjQxIDAgMCAwLTEwLjE3IDI0LjRjMCAuMzQtMTYuMzMtNy44Ny0yMC42'
    b'OC0xOS40My0yLjM5LTEwLTEwLTM0LjM3LTIuMzYtMzQuODUiLz48cGF0aCBkPSJNNDk1Ljc0'
    b'IDE4MC45NGEyLjg0IDIuODQgMCAwIDEgNCAuNmwuMTUuMjJhMS4yOCAxLjI4IDAgMCAwIC42'
    b'LTIuNDEgNC40MyA0LjQzIDAgMCAwLTQuNzUgMS41OXoiIGZpbGw9IiNmZmYiLz48cGF0aCBk'
    b'PSJNNDk1Ljc0IDE4MC45NGEyLjg0IDIuODQgMCAwIDEgNCAuNmwuMTUuMjJhMS4yOCAxLjI4'
    b'IDAgMCAwIC42LTIuNDEgNC40MyA0LjQzIDAgMCAwLTQuNzUgMS41OXoiIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9'
    b'Ii42MiIvPjxwYXRoIGQ9Ik00OTUgMTgzLjE2YTIuNDQgMi40NCAwIDAgMSAzLjQyLjQ3bC4x'
    b'My4xOWExLjA1IDEuMDUgMCAwIDAgLjQ4LTIgMy42MSAzLjYxIDAgMCAwLTQuMDMgMS4zNHoi'
    b'IGZpbGw9IiNmZmYiLz48cGF0aCBkPSJNNDk1IDE4My4xNmEyLjQ0IDIuNDQgMCAwIDEgMy40'
    b'Mi40N2wuMTMuMTlhMS4wNSAxLjA1IDAgMCAwIC40OC0yIDMuNjEgMy42MSAwIDAgMC00LjAz'
    b'IDEuMzR6IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIy'
    b'Mi45MyIgc3Ryb2tlLXdpZHRoPSIuNjIiLz48cGF0aCBkPSJNNDk4LjMgMTc4Ljc4YTIuNTMg'
    b'Mi41MyAwIDAgMSAzLjQ0IDFsLjExLjIxYTEuMTEgMS4xMSAwIDAgMCAuNzctMiAzLjg2IDMu'
    b'ODYgMCAwIDAtNC4zMi43OXoiIGZpbGw9IiNmZmYiLz48cGF0aCBkPSJNNDk4LjMgMTc4Ljc4'
    b'YTIuNTMgMi41MyAwIDAgMSAzLjQ0IDFsLjExLjIxYTEuMTEgMS4xMSAwIDAgMCAuNzctMiAz'
    b'Ljg2IDMuODYgMCAwIDAtNC4zMi43OXoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLW1pdGVybGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik01'
    b'NTcuMzQgMzQ0LjExYzIuNy0yMi40MS0yLjM5LTMxLjI0LTkuOTQtNDIuNiAxLjc5IDguOTIg'
    b'Mi4yNyAxNC41Ny02LjE2IDE2Ljc2LTIxLjgxIDExLjM2LTI0LjI1IDIyLjIxLTE3IDU1LjMz'
    b'IDIuMyA1LjE0LTMgMTMuODYtOS4yIDE4LjgtNyAuNzctMTUuNTQtMS45My0xOCA1Ljg1LS4x'
    b'NCA2LjU2IDUuMzcgMTEuNjcgMTUgMTAuNzkgMTUuMTEtNC4xMiAxNS40Mi0xOC45NCAyNS41'
    b'Ni0yOS4wOC0uNDUtNi43My0zLjg2LTEwLjM0LjkxLTE2LjEgNC40LTYuNTYgMTUuNzYtNi41'
    b'NiAxOC44LTE5Ljg4Ii8+PHBhdGggZD0iTTU2Ni42NiAyMzMuNjhjLTEwLjgyLTYuODItMjEu'
    b'Ny0xMy41NS0zMi41NS0yMC4zNC04LjA5IDEwLjQ1LTExIDE5LjY1LTE1IDMwLjQyLTIuODQg'
    b'Ni4xMS01LjA2IDUuMjUtOC44LTJzLTUuMDYtOC05LjE1LTEwLjI4aC0xNC41MWE3LjEgNy4x'
    b'IDAgMCAwIDAgMi42NGMwIDQuNDMgMCAxMS4zNiAxMC43MSAxNC43NyA0LjA2LjMxIDUuODUt'
    b'LjgyIDggMS40OCAzLjg2IDQuNTQgMi42NCAxNi41NiAxMC4yIDE2LjYxIDYuOS0uNTcgMTEu'
    b'MzYtNy4wNyAxOC40OS0xNi41LTEuNjggNC0yLjQxIDcuMjQtNi4zMSAxMC4yOCA1LjI1IDIy'
    b'LjcyIDExLjM2IDI2IDE4LjkyIDM3Ljg2IDUuODUgOS44OCAxMi44OSAxNy43MiAxMy4xMiAz'
    b'NC4zNC42IDguNTItMi40MSAxNC43Ny0xLjMzIDI0LjUxLjQ1IDQuODggMS40OCAxNS4wOCA5'
    b'LjgzIDIwLjc5IDcuMjEgNi40MiAxOC43MiAyLjg0IDI2Ljg0IDcuNTggMi44NCAyLjI0IDQu'
    b'NzQgMTAgMy4zMiAxNy4zMmEzLjcyIDMuNzIgMCAwIDEtMy41NSAzLjc4Yy04LTEuMTYtMTQu'
    b'Mi41MS0xNS40MiA1Ljg1LS40MyA1IDEzLjMyIDEwLjQ1IDE4LjQ5IDkuMzJzOS4yNi05Ljg4'
    b'IDEwLjMxLTE2VjM4NS44Yy0uNzEtMTIuNzItMTcuMjEtNi0xNC0yNy4zNSAyLjM5LTkuMzIg'
    b'MS40NS0xMy44LTEuNTktMjIuMTUgMC0xMS45MyAxLTIyLjcyLTYuMTktMzMuNTEtMTAuNjgt'
    b'MjIuMTUtMjUuNTYtNDIuNi0xOS44OC02OS4xMyIvPjxwYXRoIGQ9Ik01MDguODYgNDA3Yy0u'
    b'NjUtMS0xLjQ4LTEtMi41OC0uMjZhOC4xMiA4LjEyIDAgMCAwIC45NCA2LjczYy4zNi0yLjY4'
    b'IDIuMDQtNC45MiAxLjY0LTYuNDd6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTUwOC44NiA0'
    b'MDdjLS42NS0xLTEuNDgtMS0yLjU4LS4yNmE4LjEyIDguMTIgMCAwIDAgLjk0IDYuNzNjLjM2'
    b'LTIuNjggMi4wNC00LjkyIDEuNjQtNi40N3oiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLW1pdGVybGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9'
    b'Ik01MDUuMTQgNDA2LjgyYTEuNTkgMS41OSAwIDAgMC0yLjg0LS41N2MtLjkxIDIuODQuNzQg'
    b'NC40MyAxLjY1IDYuNDgtLjQtMy42MS43OS0zLjE2IDEuMTktNS45MXoiIGZpbGw9IiNmZmYi'
    b'Lz48cGF0aCBkPSJNNTA1LjE0IDQwNi44MmExLjU5IDEuNTkgMCAwIDAtMi44NC0uNTdjLS45'
    b'MSAyLjg0Ljc0IDQuNDMgMS42NSA2LjQ4LS40LTMuNjEuNzktMy4xNiAxLjE5LTUuOTF6IiBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyMi45MyIgc3Ry'
    b'b2tlLXdpZHRoPSIuNjIiLz48cGF0aCBkPSJNNTAxLjUxIDQwNC4zMmMwLTEtMi4yNy0xLjc5'
    b'LTIuNy0uNDUtLjg1IDIuODQgMSA0LjE3IDEuODIgNi4yMi0uNzctMy41My43Ni0zLjIyLjg4'
    b'LTUuNzd6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTUwMS41MSA0MDQuMzJjMC0xLTIuMjct'
    b'MS43OS0yLjctLjQ1LS44NSAyLjg0IDEgNC4xNyAxLjgyIDYuMjItLjc3LTMuNTMuNzYtMy4y'
    b'Mi44OC01Ljc3eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1p'
    b'dD0iMjIuOTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGggZD0iTTQ5OC43NSA0MDEuNDJj'
    b'MC0xLTEuMjgtMi4zLTIuMTktLjQtMS4wNSAyLjU2LjkxIDMuODYgMS42OCA1LjY4LTEuMjQt'
    b'My44Ni45Ni0zLjcuNTEtNS4yOHoiIGZpbGw9IiNmZmYiLz48cGF0aCBkPSJNNDk4Ljc1IDQw'
    b'MS40MmMwLTEtMS4yOC0yLjMtMi4xOS0uNC0xLjA1IDIuNTYuOTEgMy44NiAxLjY4IDUuNjgt'
    b'MS4yNC0zLjg2Ljk2LTMuNy41MS01LjI4eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2UtbWl0ZXJsaW1pdD0iMjIuOTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGggZD0i'
    b'TTU5MS4zMSA0MTkuNjVhMS43OSAxLjc5IDAgMCAwLTIuNTEtLjI4bC0uMS4wOGE1LjQyIDUu'
    b'NDIgMCAwIDAgMSA1LjM0Yy4zLTIuMTggMS45NS0zLjkyIDEuNjEtNS4xNHoiIGZpbGw9IiNm'
    b'ZmYiLz48cGF0aCBkPSJNNTkxLjMxIDQxOS42NWExLjc5IDEuNzkgMCAwIDAtMi41MS0uMjhs'
    b'LS4xLjA4YTUuNDIgNS40MiAwIDAgMCAxIDUuMzRjLjMtMi4xOCAxLjk1LTMuOTIgMS42MS01'
    b'LjE0eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMjIu'
    b'OTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGggZD0iTTU4Ny41NiA0MTkuNDVhMS43OSAx'
    b'Ljc5IDAgMCAwLTMtLjQ1Yy0uODUgMi4zLjc3IDMuNjEgMS42OCA1LjItLjMtMi44Ny45NS0y'
    b'LjUgMS4zMi00Ljc1eiIgZmlsbD0iI2ZmZiIvPjxwYXRoIGQ9Ik01ODcuNTYgNDE5LjQ1YTEu'
    b'NzkgMS43OSAwIDAgMC0zLS40NWMtLjg1IDIuMy43NyAzLjYxIDEuNjggNS4yLS4zLTIuODcu'
    b'OTUtMi41IDEuMzItNC43NXoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1p'
    b'dGVybGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik01ODQgNDE3'
    b'LjVjMC0uNzctMi4yNy0xLjQyLTIuNy0uNC0uODIgMi4zOSAxIDMuNDEgMS44MiA1LS45LTIu'
    b'ODQuNzItMi42NS44OC00LjZ6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTU4NCA0MTcuNWMw'
    b'LS43Ny0yLjI3LTEuNDItMi43LS40LS44MiAyLjM5IDEgMy40MSAxLjgyIDUtLjktMi44NC43'
    b'Mi0yLjY1Ljg4LTQuNnoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVy'
    b'bGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik01ODEuMTQgNDE1'
    b'LjE3YTEuMTEgMS4xMSAwIDAgMC0yLjEzLS4yNmMtMSAyIC45NCAzIDEuNyA0LjU0LTEuMzMt'
    b'My4xNS45NC0zLjAxLjQzLTQuMjh6IiBmaWxsPSIjZmZmIi8+PHBhdGggZD0iTTU4MS4xNCA0'
    b'MTUuMTdhMS4xMSAxLjExIDAgMCAwLTIuMTMtLjI2Yy0xIDIgLjk0IDMgMS43IDQuNTQtMS4z'
    b'My0zLjE1Ljk0LTMuMDEuNDMtNC4yOHoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ry'
    b'b2tlLW1pdGVybGltaXQ9IjIyLjkzIiBzdHJva2Utd2lkdGg9Ii42MiIvPjxwYXRoIGQ9Ik00'
    b'ODYuMTcgMjI5Ljc2YTUgNSAwIDAgMCAyLjIyIDUuNjhjLjM0IDItMS4yMiAzLjIxLTIuMTkg'
    b'MS42OGE4LjggOC44IDAgMCAxLS4wMy03LjM2eiIgZmlsbD0iI2ZmZiIvPjxwYXRoIGQ9Ik00'
    b'ODYuMTcgMjI5Ljc2YTUgNSAwIDAgMCAyLjIyIDUuNjhjLjM0IDItMS4yMiAzLjIxLTIuMTkg'
    b'MS42OGE4LjggOC44IDAgMCAxLS4wMy03LjM2eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAw'
    b'IiBzdHJva2UtbWl0ZXJsaW1pdD0iMjIuOTMiIHN0cm9rZS13aWR0aD0iLjYyIi8+PHBhdGgg'
    b'ZD0iTTQ4OCAyMzAuNTNjLS42MiAzLjYxLjQzIDMuNzIgMi4yMiA1LjIuMjMgMS44Ny0xLjU2'
    b'IDMtMi41MyAxLjUzYTYuNDIgNi40MiAwIDAgMSAuMzEtNi43M3oiIGZpbGw9IiNmZmYiLz48'
    b'cGF0aCBkPSJNNDg4IDIzMC41M2MtLjYyIDMuNjEuNDMgMy43MiAyLjIyIDUuMi4yMyAxLjg3'
    b'LTEuNTYgMy0yLjUzIDEuNTNhNi40MiA2LjQyIDAgMCAxIC4zMS02LjczeiIgZmlsbD0ibm9u'
    b'ZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMjIuOTMiIHN0cm9rZS13aWR0'
    b'aD0iLjYyIi8+PHBhdGggZmlsbD0iI2QyMDAwMCIgZD0iTTAgMGgyNDguMTR2NjAwSDB6Ii8+'
    b'PC9zdmc+', 'RU_NVS')

RU_NVS = b64_RU_NVS
index.append("RU_NVS")
index.append("Russia Novosibirskaya oblast")
catalog["RU_NVS"] = RU_NVS
catalog["Russia Novosibirskaya oblast"] = RU_NVS
country["Russia Novosibirskaya oblast"] = ('RU_NVS', '', 1)
lookup["RU_NVS"] = ('RU_NVS', '', 'Russia Novosibirskaya oblast', 1)
lookup["Novosibirsk"] = ('RU_NVS', '', 'Russia Novosibirskaya oblast', 1)
lookup["Russia Novosibirskaya oblast"] = ('RU_NVS', '', 'Russia Novosibirskaya oblast', 1)
details["RU_NVS"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+07:00","altname":"Novosibirsk"}
regional["RU_NVS"] = ('RU_NVS', 'Russia Novosibirskaya oblast', 1)
regional["Russia Novosibirskaya oblast"] = ('RU_NVS', 'Russia Novosibirskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_OMS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCI+DQo8'
    b'cmVjdCB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCIgZmlsbD0iI2UwMDAwMCIvPg0KPHJlY3Qg'
    b'd2lkdGg9IjE1MCIgaGVpZ2h0PSIzMDAiIHg9IjE1MCIgZmlsbD0iI2ZmZiIvPg0KPHBhdGgg'
    b'ZmlsbD0iIzAwZiIgZD0iTTIwMCwwCiAxOTgsNiAxOTYsMTIgMTk2LDE4QzE5NiwyOCAyMDQs'
    b'NDEgMjA0LDUxQzIwNCw2MSAxOTYsNzQgMTk2LDg0QzE5Niw5NCAyMDQsMTA3IDIwNCwxMTdD'
    b'MjA0LDEyNyAxOTYsMTQwIDE5NiwxNTBDMTk2LDE2MCAyMDQsMTczIDIwNCwxODNDMjA0LDE5'
    b'MyAxOTYsMjA2IDE5NiwyMTZDMTk2LDIyNiAyMDQsMjM5IDIwNCwyNDkKIDIwNCwyNTkgMTk2'
    b'LDI3MiAxOTYsMjgyQzE5NiwyODYgMTk4LDI5NCAyMDAsMzAwCkgyNTBDMjQ4LDI5NCAyNDYs'
    b'Mjg2IDI0NiwyODJDMjQ2LDI3MiAyNTQsMjU5IDI1NCwyNDlDMjU0LDIzOSAyNDYsMjI2IDI0'
    b'NiwyMTZDMjQ2LDIwNiAyNTQsMTkzIDI1NCwxODNDMjU0LDE3MyAyNDYsMTYwIDI0NiwxNTBD'
    b'MjQ2LDE0MCAyNTQsMTI3IDI1NCwxMTdDMjU0LDEwNyAyNDYsOTQgMjQ2LDg0QzI0Niw3NCAy'
    b'NTQsNjEgMjU0LDUxQzI1NCw0MSAyNDYsMjggMjQ2LDE4QzI0NiwxMiAyNDgsNiAyNTAsMHoi'
    b'Lz4NCjwvc3ZnPg==', 'RU_OMS')

RU_OMS = b64_RU_OMS
index.append("RU_OMS")
index.append("Russia Omskaya oblas")
catalog["RU_OMS"] = RU_OMS
catalog["Russia Omskaya oblas"] = RU_OMS
country["Russia Omskaya oblas"] = ('RU_OMS', '', 1)
lookup["RU_OMS"] = ('RU_OMS', '', 'Russia Omskaya oblas', 1)
lookup["Omsk"] = ('RU_OMS', '', 'Russia Omskaya oblas', 1)
lookup["Russia Omskaya oblas"] = ('RU_OMS', '', 'Russia Omskaya oblas', 1)
details["RU_OMS"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+06:00","altname":"Omsk"}
regional["RU_OMS"] = ('RU_OMS', 'Russia Omskaya oblas', 1)
regional["Russia Omskaya oblas"] = ('RU_OMS', 'Russia Omskaya oblas', 1)
#----------------------------------------------------------------------
b64_RU_ORE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxMzY3IiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X09yZW5idXJnX09ibGFzdC5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5p'
    b'bmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6'
    b'Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4'
    b'bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cu'
    b'dzMub3JnLzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3Zn'
    b'Ij4KICA8ZGVmcyBpZD0iZGVmczEzNzEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0i'
    b'bmFtZWR2aWV3MTM2OSIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2'
    b'NiIgYm9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2Fw'
    b'ZTpwYWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgog'
    b'IDxnIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIg'
    b'aWQ9ImcxMzczIj4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjgwIiBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVh'
    b'bGl0eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFB'
    b'QU5TVWhFVWdBQUFIZ0FBQUJRQ0FJQUFBQmQrU2JlQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFB'
    b'QUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1'
    b'bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBUwp4MGxFUVZSNDJ1MmNlWEFjMVozSGYr'
    b'LzFNZFBIM0NQTlNLUFJaVW1XSmRueWJXUXdqbzB4WUp2RWlZbGh3eEdDQXduSlpnbGhseXlC'
    b'CmhBUzJOZ2xIcmlVa3JKZXEzWVNGNEFRU3dEYVl5OGFYZk1tMmhLekx0bzZSTkJyTmZmVDA5'
    b'TjM3aHgyOGhHelZWdTJtaHQyWjcxOVQKOVg3ZDFmUHAxOS8zZTc5K3IxR29wZzNLK3NzTGx4'
    b'R1VRWmRCbDFVR1hRWmRCbDFXR1hRWmRGbGwwR1hRWmRCbGxVR1hRWmRWQmwwRwpYZG9pLzI5'
    b'ZGJvSXh6MjFOQThDY0hVNXZBWlZCLzZXa1VLYlZxVjM0QVdYUS8vc2RtVFlwRTJVTlZKMGpw'
    b'ajBhQXZCbjhSU0I3TmhVCmtlbFJVQm4wLzFTOW5aSzBJVlBkS0ljalZDSkZabDUyQ0FuS05H'
    b'R3dYcG40VE1iajBxcDg2cmt4aTNXM283UFgrbkgrSTZpNDd3d2wKREFtN0hrZ1RmN2ExdTBO'
    b'cS9kWU1BS1F5WkU0Z05BMXNKcHlMVXdEUTVGWFRCcUlvMDJIWFhRNE5BSWIrc2Fxci84K3pu'
    b'bklhM2l5MgpHaVdjZFV3R1ZldlBKb2M2cFk4MnlRamMyK0lVWldaekJJRk5YNFdxNjJqRjZx'
    b'eWlJa1ZGSzFablRRQi9wVXBnTTVzaktNcDBiNHZMCmY4NUNoam9sOW1laFVFQXQzZlN1Z0NE'
    b'aDFCVWR5WjlNR3dEYWgxc25BaXJMR3ptQjBIVEVzWWFpb0ZpQ1RHZkpkSVpJWjRoVWhvd24K'
    b'U0VWQkhHdG9Pc29KQk1zYjQxVWZvcWtCR0FEcTVwU3NvNlJMTCs3WVdUVFFVN3h4OXVHSXZp'
    b'WjNxcGZOeXZqa2NySG5sdFIvRG5BbgpDWjdWMHhuQ01LQnZrR0VaSXhLaitnZVpTSlNLeHFr'
    b'elEwd2tSbkdzMFRmSUdBYWtNd1RQNnA0UFcxRFBiY21lcFdKYUlrNzFjdnJhCjNObUhJMU44'
    b'MGV5amFJTmhRTUNSYWNyVlZxaXltdUVJNWJrMVNWQkc0ZDlkakhreHdDWGl2VDE4c0Y2ZUN0'
    b'UEQ1Nnl4T0pVVGlHaWMKWEh0RmppVE5hSnpNQ2NRN0IrekpOSUVBcXYxcVR3Ky9ScnpVYjBR'
    b'RTFaY0w2bEl4bkNCYjYyVkpRb1VCSmlBVXJXTVI5OW9yaWpNSwpBL2hPc2VGZUxsOG5OelRK'
    b'SG84MjJjdGFqOWcvMzdEeWZRdlRsVStlQzZoQ3U5UjNsa0VJQ0FMT2oxc0dScXhqSWF1czRL'
    b'a3dmZWc0ClB6RkpBMENWVDlWMU5IemU2bVFNWlpMbTh1UWp2cGFuSzF2WFo4S1JGcW0rcmNB'
    b'eVJ1UzgxWHk2c25NL1YwU2pMQnBvQU9oWm4ydDUKY0NiNm1qTzYxKzd0RXVJN1BIZHgxNFha'
    b'aXFPK0ZXK3c3TitPVGVTelpMNVpUbWRKeG1wWWFIUHBRbkZCbXpnNWJkRjFXSFdaMERKSApK'
    b'akF3VmlPVEpaMjhYdmV1cldPVXZxYmw2bjJCMVFVd2RqcXExa2JIbmN2emcwLzZpUXpSY0g5'
    b'a0lFY0VSaTJsQ0pxWW9VYm5LR3liCkpGdU42R2t1ZjZCNlI5WGlLeEw5R3lNOWU3MEw5dkRP'
    b'MVJQcGMzbERzdXN6VWRwcU5aMTJmVFpHV1dpVElLQTJvS29xU21lSlNKUlcKVkpUZWI2dWRk'
    b'dDFaM3pYTzEzeDFkQ2VqNXZxZFRlc0dwcE9HQW8yS2JWaytQa01GZitQbU5WUmFvQldBVTJz'
    b'RjVwNW91cHV2L2xldgpQRTFwUHJVeGF1UUVaVXQ2NmwxN1ZZUWs0NngvdDd2eFMwcXZkMjJ1'
    b'dVZFZUdHYThIazNYRVVHWU5BV1NoRTBUcG1mb1QyOUlkUzNOCk83cTViWlUzeEMxdVdra3do'
    b'bkpMYWdLcjJXdnB5V3hBWlEvd3ZqY2RTYzdnNzQ2TkZJaUtjWm9vSGRBNlF2QkFKQ2RoWjZ0'
    b'OEpreGIKcjg2cUtVSzJHaDFyeHFwSGtGNEFnYlJ1blRsNnlETlB6V1dqY200MlJubGMydFFN'
    b'ZlNGbFZoUThNMHZOeGlpM1V6ODNadGw3eU40VApiaDJ5emJsbmJMZEVNcC9JVEM1aVlnMDNu'
    b'TTJwU0dFTVltVitWTUYxVzFKNUNic1hpL3d1WjFGQUYyZG1HS05OK0VYSVZhR05oV2poCkdP'
    b'Zlo3WmhZTGJSZW42NnBVU1kyTlBrVnRPdTYxWTdxcWlrVFYyRmQ4a1VLTW1PYXVOSWRvYWhM'
    b'bWJLaTB0R0VIMk9kc1JTc3MvNkkKU1FUQXlJUm5OcjcrWHNSaTF1MDZOelZGRDczbXJOdkhK'
    b'elpsdUtWaVk1MmNqSkxvSzdVVnhhaU5GQ2U5cTFCUTVQNmFZWnV1OElaNgpmYVozaVQ1T2U1'
    b'd0pZVmR2OHo4MVgzdmd6S3Z6YjducDdhajk2VGVIdG5ZMVBMcDFrWk9qLzV0blByUi92L2o2'
    b'ZXh1Yk4vLzR5SzlkClRHN2NZUldXSzk2QUtqempIU2xnZDVyd0Y2a0NWYlE4MnA4Z1BBbmkz'
    b'cG9GeDkrdWUyTHpDKzM1bE51dDcvenRQR3pJZ0JFQUhEdzEKUVdEMDFQdkc3OGQ2dnJyYzNl'
    b'Wm5UQk9TZ253MlkvWm5MVEVaSVREbU80eTdsenNYMWJzdlRnVjFBd0FBSTZRck8vWXZlT2h6'
    b'NzlYNAowOTRGOE9BclcrdlNpUjlOOVZPbFdiMjdOekQvMWRwcmJGcmszYmZyTmk4WmxMOVRO'
    b'Y3NIc293M1NwQmd3ajFiRmwrM3NHYk5MNGNQCmtLM2ZDZ09FRkFBQVZZYklHRXFOVmJJZ2FQ'
    b'aEk0NHJ0L3p5K0RBN1BDemp5c3RZOUV0dnhPZjhzcHJPc3YzY1NpZDg1Njk2YTJ2dFcKblVB'
    b'NFg2bGRicHJ3MUhSL0tZSmVsby90MGdwWEtOMmZjSXpuUmkxR2sreWFTTk9tV2ErcUlRU2JG'
    b'Z2RuTTRVdkw2QzdYem1pMVhWQwphc2FSbnRqY1JOMTRZOFB5T1hNOU5rc2lKNi84OXU0UlI5'
    b'dm14UTJibHdRT2owVHYyOVJoUkFZYk5EbVlqL0JxT3RNa0M2T1dCVW8wCmxEc3haZ2FYNStN'
    b'bFdvL09FclJGelQ3VUg1cStVd2tzenNkZWN0MFY2K1B3cFhMRXdhSG80SFRtbGtadDNmeVp4'
    b'UTJlbHFvR0FsOXkKV0kvTmN1QjcxOTN5ek5HZHc5WjQ1dXlQYmxzR0FJY2lnd0R3WUdSZlFT'
    b'Zk1aclAybXN6TWFlNmU3YkdkODdOWndsS2lvQ1dDRkJuZgpWUXR2LzFMME4rdkd6aEpEMW80'
    b'ZkRxYmlsUDZ3LzBMQWxoVjFWN1JXK2h6TWYzV0dTb2YxSzJzYU5pMnUrZm1lb1V1NUk0RHJH'
    b'Nk9OClhpM3ptRDhUc3B3dnVENi84TFlDN1pJeExrWFF4Ni9QZXN4eGF5UXAwZTZmaGUvYzIz'
    b'djhiNjdkYWRVUW1VY3l3TEY3LzM3S0JBQ1EKc1dFeFBnUW82eE5CUS9iRUpmb3ZBYml3OGVK'
    b'REdBRENHRFlnb0VTczZDaTVVWGppeGEzOUZVdE5Hck5xSW5qbDJlT0t1T3cxZTJsTgp3UXQz'
    b'eFR0WEpNaWhtWk5TdTA1WVpybWFONmFYUzJHaEpwMnBIS05KVVY0cXlFRlJucjBtVnAyWDU0'
    b'ZTBvQ2dIUkRsNlZjemVuT05yCkJYQUx5MDlCclNnSFJkbW96VXBMa2wwOUVCUmxYWlp0cERu'
    b'cU1nNUc2eDhkL05JazF3UUlVVnIrdm9ydG03YUdUSS9tZWFzNG9JdjIKTk1XNytieUliNzF0'
    b'NkJIajV3dXloMG05b0pEOGp1Um5OMzQ5TXJGVS9DQXN1TWNtM3A2WXFsVXVYS3VjSmxNUlN1'
    b'Mno4dTliTDF6NgpWSzJTLzN3aXVNZjJ3U0hqeThTTlg0LzgrUHdYYytBaWRiRkwydnVJK2ZN'
    b'dE40MEplWnpvNWt2TE9rYXFWYlpUakF3eTlucTVvam43CmpkUWJHZWNiTDUrOC9LaHRpU0lq'
    b'VHkrVHVIQXpPQU9lbkZwL21kQmJyVXgrdXpvNFFkZWRwU09mU2RzbitKWnhHZ0FtYXhYdUg4'
    b'SmQKQzhURERqMytkd0Z2SGdPQXA0OVJaTVRvNmE3TThVOHRQR0pMWWMybHhaTmtac3pDTGhS'
    b'SGpuQXRZYkpVZWpTU2NiQkpzbmcxVThGeQpocURueXFzM0p1WXNpM042K3RnUHF5NlU1dzJB'
    b'eERkbjU3VVZqdlJ3MFJSSlBUd1RxbE5xSXFUckxadjZWNmx6RFVxb1RxRWVub2trCnlDTTlY'
    b'SHVIR0w5LzlrSytVcFBEeHg3ek8xRnkvWWFCVlJ1UzlGeEp5UkNtZ3EwVldyQkp3aklxSVkv'
    b'MkZIRC9HS05YcUJxRm1UbUkKOVNJRWFudGpLdnFhWld0L2pnYVl4U0E1OWRaN1psL2E1Um80'
    b'elQzN2d0ZGJvUVp2U0NmN0dNbGxTR2V0cEl5NEIyZFA5TE5QLzRzUApLWGg4aGw2MU9qdTZ5'
    b'NmtvMkdlQWZkd3liT0p0ZC9Ua0JNeDZETDVPVXlTa3hzbjBDNTZPVWJxRVFBTkFZSWI4N2Js'
    b'NTkwZTNOWE1qCnkxdWpmZjNNZ3Bac1RYV1l1alU1SWhIRUdCMFVjV1MxTUIyaFUzdnNGV2tp'
    b'NDlXclNUT2Zva3dEc0FtYTAxU2Qrb216VnQ4Wmhrb1EKYkt2TU1FYkZEbGNLdzlRNndmTEF6'
    b'SnpHS1g5QU9YNmFtenRIZW4vVWRjZnJEMVM5SjN4bVZDeVdSeGR0TURRUUN0R2NpZkFmK2xm'
    b'cwoyT2xkTkYvTTVJaWtocTFXSTlqTlhuUVlRQ1JodmlhU1FxY281SW5zUWI3eklGdndhMUtW'
    b'MW5tUXpSM2c4eUtSWDVqL1E1NmtTQk1aCkZ6MGgyTTFhR0RPcDRheEFMSm92dnZpYTk4MlJo'
    b'UWJnRU0wWnFNUUsvd0F3OElNd29hczltUnBkMUs4ZUduTXRFMzBWbXNlbG5YckoKMWQ3TFJE'
    b'SFVHQ0FjNEtsbStkb3R5YTR1NGJvMTJZckhmZFAxaWthYWxJUWxFcHJPV05mOGVMS3BXVnEx'
    b'SW1lYnBybWZWTG9sSE1WUQpMNkVqZ0RxdnpObDVJeDZuc3MrNTNqUTc3QmJoeHJhRHhxMlJ5'
    b'bmRzSlFTNmdJQzZMV0Z4NWIrdzZsai9WTVcvRVovY2Y4TEZLWEViCnF4aHh5dC9IeERINERM'
    b'QkoyTmZES2tPTTU1UHA4Q0NUUDI5SlY2bWRoemhmaUo1c2wxUU11YURxclZMTlJ3Sk43L0ky'
    b'Q1FOQUZJUEgKZ01SU1VYZnEzU2NkajcrK1pyZDczZld0M2QvOTlHN0tKZm1yVk9JVkoxazZv'
    b'RE5XYzNLdWt0Y1F5K2ltcHIwM3N5Sm1iZDAzdll6YQpYYmo1c0VJQXpHTHcvYkhtWWM4UTRp'
    b'dXVVUk1NaTlsNW1CTXhPck9rNEpta1V6VktZb3IyL01oZmtiejB6aVNLb2NxQW1qN21tYjYy'
    b'CngzTGJwc2wyRW1rM2Q3eGxaNlJrbWl6RUtlWVl4eGJqeldGeFBGb0JjRlFwZHB1UlNwTnVW'
    b'dEN3RlFCVWtuKzI0Y2FmZW9JZmpVOVcKSzVZOGJ1L21BSUExVFA4NDNmTHJVZVRXMlJ3UnI1'
    b'VS9HdjlUVDNCNy9VMHF5UU5BM3JCWkNTV1pJbTI4WWZjclNra05odFVTaWo3dgo1aGpkd2Vz'
    b'T3ViQVN2Mm1UWnl4S2l0QUxPeXJuLzBud1dMMGlWR21MRDNNbkF4ZFhqZm5qUkRKSmZ1S0Jj'
    b'TjFKcHVEVnp6Zi9LZXNkCmxmTUpYYklvcVNvWS9aVGpkMFRXY05wMWp0SGp6N3VySlZSQ29B'
    b'RkFueXViQVBFWWhYWHpCemU5K2ZTY3A5Yk1uZ0REaURQZU1mS1MKaTQ0M0tQbHFyZU13Q3dE'
    b'c3A5SjlWd2taakhxdnk4MXBsRGpPU0FUVjlpT3M1UGtRNnpHU2pGbTl5TkRYUms0OFZ2UHMx'
    b'emNjQlEzaQpNUW9RYUhQbDBrcnZKdjFhN1FyQjQ5SWRPblE4NTQ1T1VlNEU4Y3prYVFSR3dW'
    b'cjVKdSs4ME9zS3BKbXJ1RWdaQUdEWXV2SEpVTXZSCmdVM2ZuOFFZc2puQ08wVUJRUHNSdHVE'
    b'V0MrVEZ4V1I3YkM2SnFRUXdmamwxMnAwZ1lwTjB4Ni9kVGgzY1RyMzJNbUhTcjVVUWFKRXoK'
    b'MGdQTTZLdE84WGV1VUZEVmUxbHlWVDZMd0NBc0FHaUU4MmN3QUFDam9mbkgyQStPbXZzT3Yz'
    b'K1hrNlpNQUJBTCtOQ2oxWTQvenFjNwpqcktNaGdBZ2cyQ0U5UUVnZzdEa0VKQ3I4c2I3VEto'
    b'V3pmL1dOZnFxTXozQWlHeHgxamtXWjdtQlFNTFFsWUxsQ3FHaVFXWlpZN1NQClphMDZiVGMr'
    b'Ky96WFJNWDJDK1ZaNjNuS3BVS3ovcEZwRHNENWVaSmFyYnA2bWFyNG4rWnBad2xJVTZiVXBI'
    b'MloydGJxSDMvaTJ1ZlYKTE01TGVNNkNnaWppMkpoRk9zalAyOC96V3NtQVByWWwzWEpEYXZp'
    b'OHRkcW5hanFhNmVaL3RlK3l0L3hyNzVqMzh1WHBjZmVpVERSTwp6dHZ1aldzZ280c1BuUW1R'
    b'QVdRaVdLdWFBTENYUXNnRU81am9qemZBWW9LWGhLRTc0MTZQbG52ZkZtMW12cm52N3ZXejc5'
    b'eTgrcGgvClJaNGl6ZkFzMWRva0RlOXdMMy9aVVNyVzRlemhCa2FZcmlWNXAwTW5zQm5xcVhp'
    b'ajZqb05NODVYS1Z0Yk5oc25LWWMrL2RtVXVVUlUKdmh6SGpiSjBaL3lvbzJxSkJtdFZjemVG'
    b'ZGxOb2pXcXVWYzE5OXVDemxlM1RqRWU5TzI0c0VzTTNwa2lIbm8yVHpGd2h2TDFPUWR3dQoz'
    b'OGJwa3g2U01KME92V3RKL3N3dzR6ckpsbEE5V25ab2RnUDJ2ZTZvYXkra290U3I3blpEb3ln'
    b'MTEzYlZHZDZuT2dLS3c2YW5YRnFPCk5GTUQvSGJib3JFVDFaRzY0Sk56K0N1VDc5MHg3MkRM'
    b'VHZ2SVBHa3Y3ZHhPckpNdG5wNWszM2NISnkzdGttTitvYjVDemVRSVhVTnQKYS9ySjBDYVY1'
    b'RTgyQnBwbnc2WUpKdy94SHFjdU9UUUFxbFJBeis5bG9KYzU4OUJzUWNLbWlKa0prdkJMVmlY'
    b'ZGMzaGV3VHQwN2Nibwo0ZU84WkhMZk9YVkRtR2xEV0FXTVNTMm5FOVlqcm1Xcm5XZjhCRG5V'
    b'cUtSZHJERkltQUJKdnU2KzZCZHFjK0ZIbWwrT25pZFdMaFBlCmZ0MHpjTFRWNms0YmlJeWU5'
    b'RUViTGtqWXd4c2QzL09YWEZFSkFHYXV6cWxScXZWeFg1TnRzcmVDbVNMYWp6b1hpTEs2dVBw'
    b'OFc2djYKNkIvVzl4a3JUWVN4b1ZHYW9GRzhpVW5UUk4yejgxNzB0cHlPMXd4cmJUbkRDUWpy'
    b'Skl0TkxXVldlQzJKVzY0ZERVM1I3NGJhZnFMYwpydEQyRzJwMzNoVTYzYkxiSG1tWFROYjA3'
    b'K05MRWJSL3I4MTlsT3UvTFduWm5GNFpIRHdYWWlONmJSTXpuQkM0bjc1eHhjSGNPa29YCjF3'
    b'dHYwZGwwakF2cUpJTk1uUmZHQ1VQQ2hwTG02aUNiTUJFQmdFaWpVR2NNU2JUclFQenk3SFNH'
    b'eGxvc3l4Mk5MOTVhODdzYkZ4eXkKWGluTVZHa2R6M2hyM2kwYTVTS0RCb0JacDQ1dlNETzhq'
    b'Z0F1Q3c3N3piSCtvZnJoaks5UFdtNWk0cmFhWDkzTzlkOTNOS29wc2FPZQpkcXNjSnpYUnFo'
    b'VUtGbzlHTUlTaHFKUWRnNkVTM0tPQlg3WFduVGtRNytxTnoxV3k0dWlJLzJzclhyaXlhWVJs'
    b'RFo3VFNhZXVIZVBzClVqSFhkYUNpZndSMjJLY0ZuZ3JsQk1LVVVld1hsWnBEOTk2Y21KcTJq'
    b'OFVkVzY0YUcvMVdvSDNZTWtSYnIxOXdxMHc3Q2Ezd3hNQnoKZ0lrcXBYQjd4K2QwUktxVXJT'
    b'N1YvMHZqbFRuZm45clhYZWx6aU80S0tmYWNoOG9TbFhkSHdXTHluQkgrNitEY2FKSDNDQmU1'
    b'UndPQQpONDlUNzloeisyejRMZnZjTVRyT20yS2M4dXhoY1cybWtDQ0RlK3hXSFhsMTdUaGxw'
    b'aEVzU3cxK01SRmFMZ2xCVFQxTm1xTzJlcjRRCmZ1UE1xMXdPVHdZME5XNVd2T1RJNUVoeWl1'
    b'N3N0NmFQY09JK08vNjlzeTVSL0ozWTZHUDdXZU1NWmZJcUlnQTBnTWU5Z1Q2KzZxbFEKajhj'
    b'd1B3alFBQTZ4dHFjcTIyeDY0ZjdJWUxPcUNwVHBVRCttRy9CUitmdlIvOC9McEdYUVpaVkJs'
    b'MEdYVlFaZEJsMEdYVllaZEJsMApXV1hRWmRCbDBHV1ZRWmRCbDFVRy9mSFFmd0RoWFM0dkhY'
    b'Z2ZYd0FBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VBTWpBeU15MHdOQzB5Ck9GUXdOVG8xT1Rv'
    b'MU1Dc3dNRG93TUtNdTh5Y0FBQUFsZEVWWWRHUmhkR1U2Ylc5a2FXWjVBREl3TWpNdE1EUXRN'
    b'amhVTURVNk5UazYKTlRBck1EQTZNRERTYzB1YkFBQUFBRWxGVGtTdVFtQ0MKIiBpZD0iaW1h'
    b'Z2UxMzc1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'RU_ORE')

RU_ORE = b64_RU_ORE
index.append("RU_ORE")
index.append("Russia Orenburgskaya oblast")
catalog["RU_ORE"] = RU_ORE
catalog["Russia Orenburgskaya oblast"] = RU_ORE
country["Russia Orenburgskaya oblast"] = ('RU_ORE', '', 1)
lookup["RU_ORE"] = ('RU_ORE', '', 'Russia Orenburgskaya oblast', 1)
lookup["Orenburg"] = ('RU_ORE', '', 'Russia Orenburgskaya oblast', 1)
lookup["Russia Orenburgskaya oblast"] = ('RU_ORE', '', 'Russia Orenburgskaya oblast', 1)
details["RU_ORE"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Orenburg"}
regional["RU_ORE"] = ('RU_ORE', 'Russia Orenburgskaya oblast', 1)
regional["Russia Orenburgskaya oblast"] = ('RU_ORE', 'Russia Orenburgskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_ORL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxMzgyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X09yeW9sX09ibGFzdC5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtz'
    b'Y2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9z'
    b'b2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4bGlu'
    b'az0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4K'
    b'ICA8ZGVmcyBpZD0iZGVmczEzODYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFt'
    b'ZWR2aWV3MTM4NCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpw'
    b'YWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxn'
    b'IGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9'
    b'ImcxMzg4Ij4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjgwIiBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0'
    b'eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5T'
    b'VWhFVWdBQUFIZ0FBQUJRQ0FJQUFBQmQrU2JlQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNC'
    b'alNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4'
    b'QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBSgo4RWxFUVZSNDJ1MmNXMmdjMXhuSHYzUE9u'
    b'Sm5aMmRtcmRxM2JXcGJseEpFdnNsM1hkcHlMY1V2ZEpFNURvQ25CZVdoSklLR0VRRXNLCmh2'
    b'YWwwRDYwQkFKdFNrcEpTVW9ocGFVa2JRcDFtd1I2U2RxNE5pYXU1VXNWWDZSRVZuU3g3cXZW'
    b'enU3TW5EbVhQb3k4ZG9vZENMYnIKRlRuL2gyVjI5NncwODl0UC8vbC81NGlEUGl5dEI2MGJM'
    b'NndSYU5BYXRKWUdyVUZyMEZvYXRBYXQ5WWxsTk1OSlRGRnowYUEzOUZjZwpwZFlFZGZRcEIv'
    b'MzQ3bjBuTjkxL1k2L1RyN3ozd3BPMjB0YnhDZFZXUHFPdDQwWTZnSWh3V0g5czVtVi9Zcnk2'
    b'ZXZ2cjZUM1NjaFNoCkd2VDFVZHFmN21IbnB3TzNkVzRnY2VKQTZ1Nk5tYXcweStkMnZ2VmE5'
    b'ZlBmR0VtVU5yTDMvbFc4UjZlT2E1VXRnNi9LdjIycEh6VXQKdEdWanh3ZXMySTgzQm1CdDNk'
    b'cGRyZ2RQK0s5dTRFTzVZRkpYOUxWcVM2MmZtUExoOXRIK09mc2czdm1GOE5DNHlCdFI5ZDJX'
    b'SFUvYQpoMXBkdWNnQ1F6QmQwZGVxQklRS2tKQ3ExNjNsMUtKcDRLS2NhVW1TSGpHYXR3UkJ1'
    b'QklaSGVHb0JuMnRPdVRlaVFBd1Fsekk5V3dRClFJRlVHY3BMY2taS0thUU1KRG1WMjZtdDQx'
    b'clZ6c2JQKzRsdVhrRUlWdVVRd2JadGttU0NPa0lKcVR4ZnpBb256ZVlXckJXNm9xOUoKSjdP'
    b'M3orSnNIZGtoQjhiVjNDS2I5MWlsRmdFQUV6REdNeC9Rcm1hbXZKeHk5SzlYUFBhWnVZT2Iy'
    b'RW1Nd1VMVkRKbWZKdm01S0ZzUgpxV21yczc5d3Q4N1IxNnRYUWYyRlhmMnc2eXNqTDY2SGlp'
    b'OVZtMXc0bk5oMmZNWG5kR2Q0UGRYRHArK2xvNFBENTZwV2pubkl0RklCCndrS0loMGRlenF6'
    b'WjloSmZyMEZmSDYwaHRmMFA3aDRhNlRrOXViREc3dTFjZGV2Wm9jRldrYnh2Ni8yVE03TXZ2'
    b'YXNyK2pycEZNOU0KVGMrMEYvTHRoWHo4eW9aMWZSc0FHR09IQjhjQTFqWDUrVGRkNmtoSGl5'
    b'M2hIRmF5R000bHVPOXlMOGZLQURCSjh6OC9PdXE2cnVNNApydXMyRGdMR25wbnZBZ0FxV0RH'
    b'Y0kwcmt3L2wwVkxWRVVBem5xSXcwNkN2citWc3JiMzJwc0ZjTkh0blgvZDNpNkhQZHM2L2Ra'
    b'UUNBCm9VU05DUURnbk1jajQ0T1J5ZG5WY2g0QWR1UHhJL3U2SDFDRGIrNUp2YmkrdWovMzRa'
    b'RjkzWGZoQ1cwZFYxWWxpRnpYZmY2aGJRRHcKeU83UEFzREEwSEJKOHMxbzV0dTdiNmxVS2tv'
    b'cDB6UUJRRXJwZVY1blB2MkRMZjcrNHhPTGlBREFqeC9hRGdDRmx2ejJEYUNVS2dzSwpSRmYw'
    b'bGZURGlaYjVjcm54VkVyNTJzRGswNjF6ejl6VGExS3FsSkpTTXNZQWdERW1wU1NFM05hejZw'
    b'VzlwVHpVMytrZnVQeEh2WHJ3CitBblNvU3Y2eXByRW1WZU9uSHA0KzIyV1pVVlJkSDVpYWw5'
    b'ZmUzZXBRMG9waE1obXM0eXg5OThmOGp4djA2Yk5DQ0hidG9NZ0lJUTgKZTkvNnQwK2M5VHd2'
    b'aWlLRWtCRGkrY2tzTk0yU1FETzI0QVhISklTTWo0OGhoRHFMK2E2T05pa2xBR0NNWTE5bUxO'
    b'cXo1NHZqNCtPRwpZY1JtalRGV1N1M2FlQXRqYkg1K1BnZ0NqSEVlaFRwMWZPd1VVc2FwMVdv'
    b'WTQzUG56am1PbzVTS09XS01FVUlBZ0JBeURFTktpVEVHCmdNYXhZUml1NjViTDVlSGg0V3cy'
    b'dTRJd0RmcGo3UXlwMmRuWk8rNjRVeW5sKzc2VWtuTnVXWlpTaWhBU2d3WUFwWmJXdEJ1Z0dX'
    b'TysKNzVkS3BYUTZWUzZYMDVqcmh1WGoxSnJMOE5BSEFOT2ttVXdtREVOS2FSaUdZUmh5em9V'
    b'UXBWTHAyTEZqaFVMQjh6ekdtR0VZR0dOQwpDQ0VrbVV6NnZvOHhkbDIzMVZJUWFOQlhWejZi'
    b'cVN5b3c0Y1BXNVlkQncrTWNSUkZqdVBFUUJGQ2p1TWdoRXpUWkl3SklaUlNRZ2hLCktlZDhZ'
    b'bUtDRUF3QWVSTnAwRmNWbGR4TlptekxpaUdhcGhsRlVSeWNZeEZDR0dPV1pjVWhMMzRGQUV6'
    b'VHJOVnF0bTMzOWZWUlNobGoKR1JOcDY3aXFjbUt4VWdIRE1PcjFPaUdrVnFzaGhJSWdrRko2'
    b'WHRWeGtwN25ZWXlyMWFwbFdiVmFMWGJxUkNKUnI5Y1pZMUVVRVVJOAp6MU5LT2FTSnJxdnBi'
    b'b1o1OEFraGphUkJDR2xZaDJYWm5IUERNSlJTc1V2RXRVd3BGVUlnaE9LUjhhY1FRaG1iYXRC'
    b'WHIyZ1VJWVE0CjUzSFRFZU9MSDFPcFZES1p0Q3pMTUF6YnRpbWw4ZXlTWlZseHlvN0h4N0Vh'
    b'QUZLMnFVRmZQWEpRWVZsV1BwKzNMQ3VYeTFtV2xVZ2sKS0tWeENWTktxNTczMkY4dWJQcXo5'
    b'NGVqWjhOd3FTV0pUVHdlbjgxbUxjdEtKcE1keFJZTitxcHFvY0l3ak5naW9paUtlNy93b3Ny'
    b'bAo4Z2NUMC8yNG5TSDYrOW1rRU1MelBNL3pPT2N4OURoVHg1YVNUcm1ncEw0Wlhsa09FclZh'
    b'clFFNlR0Q1pUQ2J1VUJCQ2ZyZ1VOcVNDCktJb2EvUXNBVkt2VlJ1SEhuMDBLdjJZa05lZ3I5'
    b'ZDlKYWxsV0twVmlqTVdQaEJCS3FXVlpwbW1hcGdrdzBoaHNtaWFsTkhad0FFaW4KMDR5eE9H'
    b'Snp6azNUTEtMcEdtalFqU3IyRDdvWGpzWEhoMFQ3OUQ4SENDRkNpUGhSS0dFYUp1T01JRUlJ'
    b'R1Z1Y2R5LzhCZ0FXS2YzRgo0ZDZsWk0wWkFKaUdLWVFBQkJqaDJFQlVlY0NOSWdEQWtkS2dv'
    b'WjZjOFZZNjhmRmFmRExsUzRya0VaazZnTE5MSXk2ZmhpTUFLd0VBClBJRG5nbzh1b0lRQUFJ'
    b'L0M3R29WWXFXbXFESFMxclowbmI3VW9EK2lYdXAzSlVJdWtlQndJTXBlL3RaVGNQZkt6QW92'
    b'OG45Wk9UaHQKZUYvRE85YW1PNFVRTHl5OFBXWlVHc04yMk5VZUhIQ0pQMFFVZk4wWlhxWmtj'
    b'T252ZXRTM1NrN0lGU29vOFpFdmdCVWUzSGhYVzF1NwpFT0ordHV2MHlPQzIzczJjYzhkeFp0'
    b'OWFlRTc4b3pIU1ZTSmtoQnJpakpkc3JHTVJwb3liYWg1TkVlKzZGeTR4SFpTMkZ4bmxxbGxF'
    b'ClVlWXkxZzhrTjNkMXJZcnZqYTZUN0M1MHh0MDI1M3hMZGcxV1M4R2pqVWRaS1JkOG94b2Fa'
    b'MFhpMG0zQUV6ZTNwcG9DOUplSEdicFkKYnErVG5CRFEwZUtMRUgySGpvTUNBTUFLOVdWV3hT'
    b'MWl2RkoxeVpiRHNLUFllcWRZQlFCRXdmZVRvejRqN2ZtZ0dobC9wNm5Hc0EwagpOM2tSb0Ns'
    b'QTc2eksxYWVYM0hRUjRkL3hRcTFtcEZOOHJRcS9aNDZCZ3QycXA2MWxSYU8zVmtyRmMwbnhk'
    b'TWZLbFYzM3BEYWFTajVyCm5TOUUzRTFHZnAzOENncjg0dmRCQXJuLytFMmVNQ1hmU2hlYmdm'
    b'WHRvOUh2YjdWNEFnUEFhWndvUjdTb0lxcFVTb2xPRmRuQ3pZazIKRVFuRE1JckZJa0tvV3Ew'
    b'V2kwVUFtSnFhR2g0Wlhxd2MzWXdHU2lMaWdDWWo4OFdvOVIxanFad1JWNCsvc2ZqSWhadTgy'
    b'b0thWjZ1ZgpmaGQvZlc5cWFyVVZQNlZLUFFFelBrSHJxSDhpU29ZSURnYWw3VmJQYm5mZDFw'
    b'WHJHR05UbGRtM3kvLzVkM0Myanc3Wm9GWWJ3Um1lCnlDaitNOWtHRjYzRm1SZmYvT3ZpVStk'
    b'di92OHJvYWJhVTRrRHZOUmwvbmF6UFZhaUxMV1VHR3lsQW9TUWdvczNQTmdyZTExdS9JbWUK'
    b'OVZFRUFQRmI4YkNsTEZXWHhRdlJ2UVBCMDBNc3oxVXpYQnBxenMycmZBUURTWFFxUjZhVGVN'
    b'WWhNdzQrMzJKY2FET0N6UDlPNXRPYQo2QnlMT2l1eXBTNXpkZGxaRldzcmNsdEZwRlZ6WFJG'
    b'YVJydUVTWVRlTEpDZjdFaWNXV2NyakZyR282Y08xaDRkWWVaeU9IbTBITGRqCisya1AvV092'
    b'ZmVDTnFxV1d6VG1qWmJydlhRUkFsOVVKTDlmZERlaHlPMkc5QTQwR3JVRnJhZEFhOUtkZWhr'
    b'OU5UZUgva2FQaFJ5YzAKQlcwZEdyU1dCcTFCYTlCYUdyUUdyYVZCYTlBYXRKWUdyVUZyYWRB'
    b'YXRBYXRkYVAxWDduaTBtUUNpeXJOQUFBQUpYUkZXSFJrWVhSbApPbU55WldGMFpRQXlNREl6'
    b'TFRBMExUSTVWREV4T2pBMk9qRTVLekF3T2pBd3dYNVZzQUFBQUNWMFJWaDBaR0YwWlRwdGIy'
    b'UnBabmtBCk1qQXlNeTB3TkMweU9WUXhNVG93TmpveE9Tc3dNRG93TUxBajdRd0FBQUFBU1VW'
    b'T1JLNUNZSUk9CiIgaWQ9ImltYWdlMTM5MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_ORL')

RU_ORL = b64_RU_ORL
index.append("RU_ORL")
index.append("Russia Orlovskaya oblast")
catalog["RU_ORL"] = RU_ORL
catalog["Russia Orlovskaya oblast"] = RU_ORL
country["Russia Orlovskaya oblast"] = ('RU_ORL', '', 1)
lookup["RU_ORL"] = ('RU_ORL', '', 'Russia Orlovskaya oblast', 1)
lookup["Oryol"] = ('RU_ORL', '', 'Russia Orlovskaya oblast', 1)
lookup["Russia Orlovskaya oblast"] = ('RU_ORL', '', 'Russia Orlovskaya oblast', 1)
details["RU_ORL"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Oryol"}
regional["RU_ORL"] = ('RU_ORL', 'Russia Orlovskaya oblast', 1)
regional["Russia Orlovskaya oblast"] = ('RU_ORL', 'Russia Orlovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_PER = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxOTciIHdpZHRoPSIxMjAiIGhlaWdo'
    b'dD0iODAiIHZpZXdCb3g9IjAgMCAxMjAgODAiIHNvZGlwb2RpOmRvY25hbWU9IjEyMHB4LUZs'
    b'YWdfb2ZfUGVybV9LcmFpLnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlu'
    b'a3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0cDov'
    b'L3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzIGlkPSJkZWZzMjAxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9Im5h'
    b'bWVkdmlldzE5OSIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpw'
    b'YWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxn'
    b'IGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9'
    b'ImcyMDMiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZlQXNw'
    b'ZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5'
    b'IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNV'
    b'aEVVZ0FBQUhnQUFBQlFDQU1BQUFEbFJVRzdBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0Jq'
    b'U0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThB'
    b'QUFDaUZCTVZFWGFKUjMvLy84QWNiVDkvZjJpCmszaXBuSWJGdnJHZmozU2tsbi9ZMDh6Mzkv'
    b'ZXpxSmVZaG1PWmgyWEt4THIyOXZiMDlmV3l1N3FUa0ltSGhYK1JtNWlSWmt1VmNWR0sKbDVP'
    b'RWdYeVVsWkxMME5ENisvcTZ3OEdPUkQzVkpSMllLaDkvWUVkMFgwU3dKaDNPSlIyS1dWTFQy'
    b'ZGorL3Y2RGhYL1dKUjNJSlJ4NwpTenR4U3p2WUpSM0RKQnlMbUpidTcrNStmM3ZaSlIzS015'
    b'eU5XVTJQVUVYSk15M1NKQjJEajR1UW01bkFKQjIzYVdUZjN0NjBhR1RhCjJkbmMydHExY1cz'
    b'bTV1WEFTRUtuS0IraHJxM0t5Y2pHd3NMRnVybkp4OGZuNXViaDRPRHI2K3ZqNHVMRnRyVzl1'
    b'N3ZEd2NIWjJkam4KNStmUHpzM3U3dTduNStiVzFkVGk0dUhZMTlmT3pNemMxdGJBbUphNWdI'
    b'eTVnbjdHcEtIWjFkWER3c0MzcnF5N0tTTE5KUjJ2TVNyTAp5c201UzBDK1BUSzNQeld2UlR5'
    b'N1BqUzhZVmpJTGlUQVFEYXhWRSt6VUV6Q01TcTZzclRITENTNVNVR1hlM2lXZVhmQ01DbVVU'
    b'RFdSCmZGT2lpbDJWVGpXVFN6S2RnbEtlZzFLWFV6ZkFRRFdlUGpxVlVrL1BLQitKU3pTZWhG'
    b'T3FqbGlXVWphdlB6ckh4TWE2dDdyRndzT1cKallOMVprOThhVStLYjJHZWZIeWdXVmZRSkJ6'
    b'WEpSeXRwNmpoMytMWTFkZXNtcHZWSmg3SkxDU2VVVTJqa1pMWTF0bXBRVHkrTlM2YgpoNGZa'
    b'MTlyWDFOZTNNQ3E3czdURHY4S2ttcHVUaFlTaGhJU3ZySzZvcGFiUXpkRE9KeDZ5T0RPY2ZI'
    b'cXhRanlrVjFPdW9xT2RjSEN2CnBhYkhKeCtlWDF6SUxDU29Pelc1czdTcFZWS2RaV0xBdWJ6'
    b'QkxpYkVNaWpVSlIyNE1Tck5LQ0MvUlRxOVQwVEJibVhxMnRqQk55elYKSng3TktpSE1LaURa'
    b'SmgzWkpSN0tMQ0xOS2lEV0p4Ni9QREh6N2V6cDNOanM0TjM0OS9iV3Q3RERPQzdDT1M3aXlz'
    b'WDM5dlhyMzkzcgo0Tjd1NGQ3cjNOcVdldDVxQUFBQUFXSkxSMFFCL3dJdDNnQUFBQWQwU1Ux'
    b'RkIrRUlDUXNZRWJoS01ZWUFBQUhXU1VSQlZHamVZMkFnCkdUQmlBVXdrQTRaUmkwY3RIclY0'
    b'MU9KUmkwY3RIclY0MUdJeUxHWm1ZUjBZaTluWU9UZ0h3R0ptTG00ZVhqNStlbHNzSUNna0xD'
    b'SXEKSmk0aEtTVk5WNHRsWk9VWTVCVVVsUmlVVlZUcGFiR2F1Z1lEZzZhV3RnNERnNjRlUFMz'
    b'V04yQXdOR0l3Tm1Fd1pUQXpwMnRRVzFoYQpXZHZZMnRrN09EbzUwOVZpRjFjM2R3OVBMMjhY'
    b'SDE5YittWW5QLytBd0tEZ2tOQ3dNRHJuWStid2lNaW82SmpZT0xvWElQRUppVUNRCmxFeTJ4'
    b'WXlrZzVSVUVFaExCNElNTURPVERFUElzVGdMUFF5eVJ5Mm1yY1dHT2JtR0EySnhYbjUrd1lC'
    b'WVhGaFVYRElnRnBlV2xWY00KaU1XVlZkVTFFRll0SFMydXEyOW9iR3B1b2J2RnJXM3RIWjFk'
    b'M1QyOWZmMTB0WGpDeEVtVEowSEFsS2wwOWZHMDZUT2dGcytjUmQ4NApuajFuN3FSNVlKdm4w'
    b'OVZpalFVTEYwMWF2R1Rwc2tuTFY5RFY0cFdyTkZaUFdtTzRkdDM2ZVJ2b0c5UU1EQnZiTm0z'
    b'ZXNuWGI5aDMwCnMzZ24yT0tFUkFhTlhReTc5d0NaZStsazhUNzBhbkUvblN3K2NOQ1E0ZERo'
    b'STBjWkdJNGRQM0dTd2ZEVWFYSXNKcjJaQnRSMTV1dzUKUnJYekZ5NWVZbVM4Zk9XcUd0QVkw'
    b'Z0ZaRmtQQXRlc0k5OVBWWXVTQUc3VjQxT0pSaTBjdEhyVjQxT0pSaTBjdEhyVjQxT0pSaTBj'
    b'dApIczRXQXdBZGVLTFdhREVXWUFBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXhOeTB3'
    b'T0Mwd09WUXhNVG95TkRveE55c3dNRG93Ck1OTnBiWXdBQUFBbGRFVllkR1JoZEdVNmJXOWth'
    b'V1o1QURJd01UY3RNRGd0TURsVU1URTZNalE2TVRjck1EQTZNRENpTk5Vd0FBQUEKQUVsRlRr'
    b'U3VRbUNDCiIgaWQ9ImltYWdlMjA1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'RU_PER')

RU_PER = b64_RU_PER
index.append("RU_PER")
index.append("Russia Permskiy kray")
catalog["RU_PER"] = RU_PER
catalog["Russia Permskiy kray"] = RU_PER
country["Russia Permskiy kray"] = ('RU_PER', '', 1)
lookup["RU_PER"] = ('RU_PER', '', 'Russia Permskiy kray', 1)
lookup["Perm"] = ('RU_PER', '', 'Russia Permskiy kray', 1)
lookup["Russia Permskiy kray"] = ('RU_PER', '', 'Russia Permskiy kray', 1)
details["RU_PER"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Perm"}
regional["RU_PER"] = ('RU_PER', 'Russia Permskiy kray', 1)
regional["Russia Permskiy kray"] = ('RU_PER', 'Russia Permskiy kray', 1)
#----------------------------------------------------------------------
b64_RU_PNZ = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNDEyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1BlbnphX09ibGFzdC5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtz'
    b'Y2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9z'
    b'b2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4bGlu'
    b'az0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4K'
    b'ICA8ZGVmcyBpZD0iZGVmczE0MTYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFt'
    b'ZWR2aWV3MTQxNCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpw'
    b'YWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxn'
    b'IGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9'
    b'ImcxNDE4Ij4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjgwIiBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0'
    b'eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5T'
    b'VWhFVWdBQUFIZ0FBQUJRQ0FJQUFBQmQrU2JlQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNC'
    b'alNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4'
    b'QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBTwp5RWxFUVZSNDJ1MmNhV3hjMTNYSC8vZmV0'
    b'ODJiZWJOd09NT2RFaVZLMWk3WmxtMDVzVk9udGhHbkh3SjNjVjBVY0lKK1NGd1VoZU51CktM'
    b'b2dDTnFrUU5DaUN4cWdCUUtrcUQvVWNRSTBxZ3U3TGhwRjhpSkx0aGJMRWlXTG9rUkpRM0Va'
    b'a3JPdmI3bjM5QU1mSmN0ZldydGgKVFh2bWZMbzQ4K2JPblI4UHp2MmZjeStIT2Q5NUNCL1Z5'
    b'cjkwQkYzNzN4bnZJdWlDN29MdVdoZDBGM1FYZE5lNm9MdWd1OVlGM1FYZApCZDIxTHVndTZI'
    b'VnJiNTB5M3pwbGRrR3ZyYjE5eWd3Q1ZJcjg3ZlhIK2xNRmVtd3NxTHRNR1RRMkZxeTN0V21m'
    b'SnRDV1NWV1hCejZ6ClRLOExlazJzV09hNkRsOUNGK1MybUM5UnJuRVFrbkhWQmYwenNPV1N5'
    b'RjNWMnpVMlZSUXBRMGtGcGNFMjZOVlhMY0ZRSlRZZVYyYWMKaGtmOVRGcDJjL1JIdEl0VGVu'
    b'dE8yenNVeEcwVjcxRmNJYTJSOHFGOHBEWGlpcUp4aXRscTcwRGdMMmlYTHVsZDBCL0ZhZzJP'
    b'QnV0MwpGRGdSSXdIeW1xSXhrU0tmUzVjMUpsTE5ncVVKRUNNU2xIVVVYRlpyOEM3b0QyMlRr'
    b'L3JXRVFrQktNVGk1TGNZMTdFeERxNUk0OWdZCkIyUGt0WkZLRXhTZ1lYeFFUbDdVdXFBL3RP'
    b'bXVSaEpnTkwzSXBVL2tNYzJSeFRhaU1VUnRGRnVJWkh6NDhEMjZsdWRFUkFxRzN3WDkKNGMy'
    b'SEJHZXdWYldtbFdvOEdsRjFGL0dIQ25wTWlRZ2xQbDlvQUpaT3hUSXYxelZtS3pEbXFZOVRn'
    b'WHdpVlVlK0lHcHR1bEZtaTNrRApCa21ORFVXRGNzNjRrUmZTWnd5WURZUUVSdnVDbHVUTXAz'
    b'Y3VtSm0rb042bWZFSDBmVXp5NHhNQTJnL1l1VU5XZmthTGN5Sk5iWHZNCjdjdkswOHhRcEhS'
    b'RFpaT3k1UEZHaGNjNHVSeDdkcmhRbUxpbU94eXRHbmNTbEl3Rml5V2hnQ2JuZldtNXZDZ3V2'
    b'bUt5Z0ZjVStrZmsKN29mYnVrYi9EOStDcmZPYlNoTnZtT3duaHR0bWZXOXFLREl4b054eGxk'
    b'dW9qSHY5RWpFZFZHbnhsbVRGTXZjQ2xyQVYxOEJBSEtpMgpoRzBwSjBvc29ONjQ4aFZMY1BM'
    b'ZTBrZW51VG5ONVR5bkhpcitxaWVXR1QzaTdYckE3ZWlJbm5qRGpCODBXSWtYVHVpUUJFRE9j'
    b'VzJPCmJ6b0tjWnBIa2poL24vek1RMjFHdUhoSjMzK25SeEtYWnpRd2JCNE9HTWZKZDQwZFcz'
    b'MXdldU5JWk9jeGtTMURYdENnc0pJN1dJR3AKZnpKNzlnWHFvREVCckRYcjlRdGFLZEFoUTd4'
    b'aUxEd3F2Vi94cmpsazV0bUdQUFBlMWlBaEo3UTB3Sld3dnRCYUtJaWl6MTg4YkxmYgp2RlVY'
    b'SUp5K0lHMWJXcllxMW5sL2o4U3JXdnB0Y1RNM0cvZjUxL3ZnWm9uWFdiN0ErbDh4bEFQMUda'
    b'ZnpqZ1I5OWcxemNJTDdCQkxxCi9tOVVBWHo1ZTZPRkhrc044V3BkckR3VFJPa2IzeHZRRllz'
    b'WllPOS9jeFVBQ0tpZkFBd1Y2Y2QzSHcxZk55SWtIZHFZYVR6MzFSeUEKRTgvR1FlZy96ODhk'
    b'TmZjKzZIWWk2TnBGbmVvY2dMbXF5bDV2cGt2amlaL0o1RE16RlNBSHdKSU1BTlZaWlZMSFdv'
    b'SmV4enJhaDZveQpBTmtLcnExTnAySjZVcy9XQVVEVk9Ob2RXN0FZNEE0Qm9NdGk5cWh4MjZM'
    b'YmNtaStsRnFzTWUrMkdvUzVLck5RNmN0WG1IdWIzL0RsCjNmWEZ6OVhuTE5kL3YzL3VEVU5k'
    b'NFFCNGxHQjNxdXFJandjOEpUREQ1VExYWnNRdG1wNzZ5OTV6ZllNdUE0N21FLzhnN3lEQkFD'
    b'QlEKZnhvOXYyMndDY0w1Y3ZRdnZCM1FPQUNoNk51eGN3TlpsM004RmN6OWR1Rk9Wd3RuMDJh'
    b'RUtuQUF2RWNsdGdRZEd0SGo5N250bm5DYwpyTnp5ZjZ2bmZJcDVta0RTVVEvMFY1NmlLeXYr'
    b'cnh1VFcySk5VNmVJU1Z1ZDV1OUdKbGY4MzR4TURNWGN1S04wbmJoVTN4czhmWE9xClpEVWN0'
    b'Rk1Zdjl2dFVOQlJtd3JSc0daTHVpaVVPQUFtYVg5ZnJWcG5NVnVsa3FwVTVlTkdZK1daZXpP'
    b'MWFwMDdObVhUc3RGa20wVnoKeFQ5a3U5VTZpNWpvVGFsR2s1T3JoQ0lBeTBXZVdqM3dLa1Fw'
    b'YWxQSHBRN1BZeTkvTjJia2VCUXNBd0NRUG13REFIZ3J1REtqZi9ZdQo5OHg3eHN5OHR1Y09y'
    b'OUtTbUNJV1VLWEU5dS95emwvV0ExL2JOdVpITEdJbkpXbThWcVc3dHZ2VE43Um1pNDJQK3Vt'
    b'VWNvNjdBQXdECjlkVnNVUTM0eTg4bTVCZzk5bHMxWGFkT2llaUpJOWFCLzlETW1xQ0ZVUHpX'
    b'STNDaUNrQmZ2Wkhwa1Y3QWRtM3hCek9Cb2FNL0ZVU0wKclZTNTBaTlF1a0diUjRPaC9zQ3l5'
    b'STVRc3R6YzNLeWtFeXBxMDNDZkhPNlRpYmlLV0xUSEx3SndvcW9lQ1Q5UkxqQ3pKdTc1ZDNI'
    b'aApOYk9EVWtkMlM4Q3lKQmRaZkNBVUQ4dXI2amxnUE9sUXVjb05nNkkyRWFCcmtKb0lHTy9y'
    b'bGJQendyWW9ZaEhBaENBbHVNdjVTTDljCktnZ0Fkb1FBcGdtQ3pnRXdkbXZhZUVZRmVZWStT'
    b'by9MRGdJOVBPWmZIbExEMTluU0NlTlNuSTQ5b3FLZkM3TnBLV0p0MitRbllxcnQKc2xpVUVq'
    b'R2xHWEFkbys1WVd6YjRDWWVVZ21WUzBwSHhLTlZzYzg1MGh2b0R5NlNZVGFaQlNVY21IRFhG'
    b'bkhBYmVOQTcvcGk4RkVmaApsRDZTWTFlRzFmQUd2N1BrSGI4MzZEa3RFdk1jWUxsb3NQZmg5'
    b'bXJOcmVjckltTFJTTDlrREV0RmZ2aTlHQWxHWEp6TlJUSVJiL05JCjRIcXNVdWZISnlQSzBz'
    b'QXdOV05rRXNINGFOQm9zVWFMWDV2VEZvU2RSQlhBM29mYnJaOFlJMVVCa0JoUTFRTnJxUERX'
    b'cWVxNDV4ZWIKK1EzaHBqUmFZa3VMb2ZJbHppN05tYjFKdGRKMUNpU2JxWmdBd0RBNWJ3NWtw'
    b'T3N4enVINTdFYlZYR2wvVEM4YWcxblphREhCNGZrbwpWZ1h4TVBVdjU4VklNUnpuTjZyOVgy'
    b'cDFIR2hOb0xvdllERUNvT1hZMUtIVlBZcmg0T1VlVGFQTE9hM1pacTAyTzVSUHJienlVaTdO'
    b'CkdITHpXcTNCMmk1N09SZUs4SlBGT0JFV2xrVzV4bHR0ZG5vaGVyUC9OSG5JMUc1d0FDeEds'
    b'YjFTRTlSeG9BR2s3L2UxTVFVZ3VDNW8KOWxabGVLS1dYQzRKUTZkRVRQa0JMbEdZY00rNmlV'
    b'SlpNSWJlbEhJOW5QUENuZTZrMzFPdWNnQzlLZFYyMmNsNjh1WlVOQ3VDNnh5QQpOaVl6OS90'
    b'cm13elhMZWd0Kzd6R29GcHBkNXFMdDVxZ09TdGVheklwV2IzSm02VFZVbUdUWWlrZW5TdG9S'
    b'R2kybVdheXBYaDB4WC9lClNGMmQxUUVFQWV3SXZScGtiMDRWV2VBZ0FLZ1AwUGcrcjBOQjZ4'
    b'b3Q2aUhmZEJPZXY4cGEwYUZqaWFpdFNsWCsvRTk3dUJzS011R3AKbDQ0bTAwazV0eWgrZUNq'
    b'Si9WQWF4aXJlMFRlZHdZeThuTk9PSGJkWk5jd1Byc2Q2MitGNHlXUnJmWEs0cm8reWdrd0l5'
    b'L0hZd2tLNAoxS2QvTUpOell1K1cyM0pSdUpmTlg1YXpQL3kxRFFDKzhxT1pTdFErdXV3WXBp'
    b'cWNpSDJsT2ZQOTN4Z0Q4TlhuWnhpTW55N0ZaVnJXCi9qWDJqTXo5K2U5c0JUQS9xOFZjdHRM'
    b'Z2tMMXJmaE5oWGQvclVBck1JQUJVUmVsYW1LYTloUDdhWHJ0ODJIU254TW1OOW5KdnVFK1cK'
    b'MCtieE95TE4wMXJ0aEhGc1c2U2NEdjFCUkp6Y2FqZmUweHF2bVljZXRwelZiRis1S2xRRkFK'
    b'aEZjdTNQd2RkMVJETUwwQUFQcXM3YQpxMmw2T2FLaElyd1NxK3RjSDJGbE8vd0t4YWhnTGQ0'
    b'c013Qzh4WXZSa0dnNUttSlZLcFc1NFJHN0tpcEc2RzhWR1RVWkFLYUQxdjdHCndmcStxYVFU'
    b'Z3BDdmt1SGdZci81Q3hNVjJOQjlmT0Y4WlhZMW9xZXoxaGZQbFprQUYvaml1ZkxWckJYNkI2'
    b'd0QxK3E2RDBUeGMxUDEKeWY3d2VWcWRtVHdRWXgwZDBiekphRVVMU09CV0ZxWHREZmV6LzFp'
    b'OWZrblQvbGF3MVUyUEtkcmE4dS85cTJxcHdxMXZhVXl1dmtFaQpFOGp4UDZzcEc5ZC8zem0x'
    b'eXBRSVVBd0F1WXkxME5FUnplbzNSN2RXbWh1eWpXKzNSclo3UGJ2OHhXZXBuQWtqTk45blZm'
    b'N0FIOS92ClJUZks5cDk0K2Y2d05YZDF4Szcrc2JmNzU5dk9VSkQ4bS9xWmJhSHVaZ0pnWWNi'
    b'UXZjNk9hS1BFYnk3VHppck1BMEFyYlQ2d293SEEKdHVpZXpmVzJERk5FTzJzOXZMc0tJSk5T'
    b'KzRKNnF4eitBVzVzanUzZTJnYVFqQ3VDUHpNVzZtczdxN0M2TVJwbDF0RVJ2YlI2VkNnYwpz'
    b'bGVsbnRYMFBCOEFZcmJhT2RTNmVRNHJHcjV0S2dDYzA5aGdvRFhDU2s5M2cxUk1ydVNLZEZL'
    b'Tnl2QkV4czRvSGwvVjBUbXRvMEduCjB1cDhsQUdvUjJoa1BBU1hrcTVTREVBZ21STWxxK210'
    b'YW0zWDh4Z0FQMkMyUlRFMzlJOVNnd2czL1p0RUxXekdidlliVVFKd1BzWjYKZW1WSHA0NzZH'
    b'WDNQSnYrODRscUViVFNKRXdBc09MSEgvMjM3dG5nejM5SVhBN09WQ204aWxKM0k0eS90M0Js'
    b'dkxMZkVVbUJXRW1HTwp6bW14MzN0dDdMNVVwZERXODc1NWpHVUFjRUxFb3VzbUMzYlNIaVlu'
    b'em1nZERkclhTWjRUMnczVVRQYm1DL1ltdlZGQVFwbGlPcHVlClJocldiUStUSVhMWlZBNnBE'
    b'L2g5VFJ6V2hnNjNod0JnOVI3T3VGRS8rb0xkWDJMT0ZKT2U4Rk9kclRwU1l4SU01Q0YyV296'
    b'OTJQek4KNUx5VmIvN2ZwN1h5emE4bEZqWWROR1B2Q1BJQWhwNE5xcU1qT3ZOSGplbm43UEhq'
    b'WEMyenk1UENlZFIvNTRsVDMvbXYvcXMzVDFWWAo5SWJMWEM3S3ZuNGpFZzE2TFFCNndSMW8x'
    b'SHFNd0ZBeVl0NVc5WTNGV24vNHhNTFpnNUVyRjhVWWlQZlM1UU55OE11dGpnYTlhYWRuClBF'
    b'MW5aVlM3enNiaWFuS2VEL1RLdjM1eTl1cTAzdE1yVThrUGh1RnlpWC9wdWEwQURqNDFsZTM1'
    b'NFA1V0t2UENrdGkwMmVjYzc4enoKd2J2OGkxVWViS1FkVHpkSE52a2REZnJJM3p0YlR2QzlO'
    b'NWpNYzREVFJoL0FpODhtRGhUUTBwQ0xvVEtzckYzQjdrZmFrUWdCNkUycApIenc1QmVBbTVW'
    b'YUxUUnl5R21mMDVDelB1dVQ0ZUxFSGovOWRoUWptY1cwYklBcEtmdE0rc2w4OTlFeXRjMEY3'
    b'cittNHdPWTF0alJFClZyKzBtK3oxNTZOaVFwTjVBT2dGZWdYMGNUSDdZMk9wbjl3RXJGSEpU'
    b'UUxoUnBPNU04SW9vMitKanhZUVhCVlFJQ0FBZUI5ZS81ZW8KM1dSWDdwYnRCWkhKaTJ5ZXl4'
    b'YmhtUTZPNkxSRnRRZmxZSUQrU2FGT0Nad0NmNGN2akVsdEE2a3JYQlU0SlB4SkVRRkdWN3RR'
    b'ekFDTAprS3JjcXZSdW5teUxBU1YyQk1OVnZmK2ZEYnF4Y3JlUitEMUJTVWVxeGpzNmRmam5o'
    b'T1B6OTk4Qm1Ka1hDU1d2RjdUcWJ0bHpkekJTCm8rQ0M5bjZzNUlGdWIxeXdLR25iNURYQmlq'
    b'blJjOFJNWk9YTWtoZ0dBVkJGcG81cERsRFdPN3ZYRVJtVExNZEV2MnFrS08vQTRCaHMKWUtJ'
    b'dG5LRkFCMlFEWjVnUVQvcE9nUTM3MEs1eTFRUVVJTUVza0FkdmdISTIzREdsem1rSlRVVkdw'
    b'VCtLYXkyK2E5aGZpTUpUNksvRApMaks1d0NPam5TM3Y1TmZhMStZNDc2VnRuMjl2aWlzQWsy'
    b'Zk02SDhhWTVjWm14U3FJS2IzNGNtdjF3RFVHdnphdTFwbFdwZHRSZ0VpCnZjb2VDamJ1Q1Vh'
    b'aUNzQUx2NTdlL2k3bmFVVjN5Q3QzeXZwajN0MTdYUURsS3I5NDJGTEx6QnBjYzlEc2svaUw2'
    b'Rk5uemNVVG1sd1MKeHViZ3dCUC9jd2x6N0VlMmYwVVRHWm05TjlpeTIvMVkxdnlKL0JmbExY'
    b'dmNMWHMrQksvN24yaCs3R3Z1L3U1ZEYzUVhkTmU2b0x1Zwp1NkM3Q0xxZ3U2QzcxZ1hkQmQw'
    b'RjNiVXU2RStUL1RkOEZmYnZLMEFwdHdBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlN'
    b'aTB3Ck9TMHpNRlF3T0RveE1Eb3pNQ3N3TURvd01Mb1hZbVVBQUFBbGRFVllkR1JoZEdVNmJX'
    b'OWthV1o1QURJd01qSXRNRGt0TXpCVU1EZzYKTVRBNk16QXJNREE2TURETFN0clpBQUFBQUVs'
    b'RlRrU3VRbUNDCiIgaWQ9ImltYWdlMTQyMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_PNZ')

RU_PNZ = b64_RU_PNZ
index.append("RU_PNZ")
index.append("Russia Penzenskaya oblast")
catalog["RU_PNZ"] = RU_PNZ
catalog["Russia Penzenskaya oblast"] = RU_PNZ
country["Russia Penzenskaya oblast"] = ('RU_PNZ', '', 1)
lookup["RU_PNZ"] = ('RU_PNZ', '', 'Russia Penzenskaya oblast', 1)
lookup["Penza"] = ('RU_PNZ', '', 'Russia Penzenskaya oblast', 1)
lookup["Russia Penzenskaya oblast"] = ('RU_PNZ', '', 'Russia Penzenskaya oblast', 1)
details["RU_PNZ"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Penza"}
regional["RU_PNZ"] = ('RU_PNZ', 'Russia Penzenskaya oblast', 1)
regional["Russia Penzenskaya oblast"] = ('RU_PNZ', 'Russia Penzenskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_PRI = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iNTYz'
    b'LjgiIGhlaWdodD0iMzc2LjUiIGNsaXAtcnVsZT0iZXZlbm9kZCIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBpbWFnZS1yZW5kZXJpbmc9Im9wdGltaXplUXVhbGl0eSIgc2hhcGUtcmVuZGVyaW5n'
    b'PSJnZW9tZXRyaWNQcmVjaXNpb24iIHRleHQtcmVuZGVyaW5nPSJnZW9tZXRyaWNQcmVjaXNp'
    b'b24iIHZlcnNpb249IjEuMCIgdmlld0JveD0iMCAwIDE2MCAxMDYiIHhtbG5zPSJodHRwOi8v'
    b'd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiA8ZGVmcz4KICA8c3R5bGUgdHlwZT0idGV4dC9jc3Mi'
    b'Pi5zdHIxIHtzdHJva2U6IzAwOTNERDtzdHJva2Utd2lkdGg6MC4wNzYyfQogICAgLnN0cjIg'
    b'e3N0cm9rZTojMUYxQTE3O3N0cm9rZS13aWR0aDowLjA3NjJ9CiAgICAuc3RyMCB7c3Ryb2tl'
    b'OiNEQTI1MUQ7c3Ryb2tlLXdpZHRoOjAuMDc2Mn0KICAgIC5maWw0IHtmaWxsOm5vbmV9CiAg'
    b'ICAuZmlsMSB7ZmlsbDojMDA5M0REfQogICAgLmZpbDIge2ZpbGw6IzFGMUExN30KICAgIC5m'
    b'aWwwIHtmaWxsOiNEQTI1MUR9CiAgICAuZmlsMyB7ZmlsbDojRkZGNTAwfTwvc3R5bGU+CiA8'
    b'L2RlZnM+CiA8cmVjdCB4PSItMi43NzU2ZS0xNyIgeT0iLS40MjMyIiB3aWR0aD0iMTYwIiBo'
    b'ZWlnaHQ9IjEwNi44NSIgZmlsbD0iI2ZmZiIvPgogPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICA8cG9seWdvbiBjbGFzcz0iZmlsMCBzdHIwIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjAwNTYg'
    b'MCAwIDEuMDA1NiAtLjQ0MTk0IC0uMzAxOTUpIiBwb2ludHM9IjAuNDc3OSAtMC4wOTc3IDAu'
    b'NDc3NiA4NC45NTIgMTQwLjEgLTAuMDk4MiIgZmlsbD0iI2RhMjUxZCIgc3Ryb2tlPSIjZGEy'
    b'NTFkIiBzdHJva2Utd2lkdGg9Ii4wNzYyIi8+CiAgPHBvbHlnb24gY2xhc3M9ImZpbDEgc3Ry'
    b'MSIgdHJhbnNmb3JtPSJtYXRyaXgoMS4wMDU2IDAgMCAxLjAwNTYgLS40NDE5NCAtLjMwMTk1'
    b'KSIgcG9pbnRzPSIyMS45MTYgMTA2LjEgMTU5LjUyIDE3Ljg1IDE1OS41MiAxMDYuMSIgZmls'
    b'bD0iIzAwOTNkZCIgc3Ryb2tlPSIjMDA5M2RkIiBzdHJva2Utd2lkdGg9Ii4wNzYyIi8+CiAg'
    b'PGcgdHJhbnNmb3JtPSJtYXRyaXgoMS4wMDU2IDAgMCAxLjAwNTYgLS40NDE5NCAtLjMwMTk1'
    b'KSI+CiAgIDxwYXRoIGNsYXNzPSJmaWwyIiBkPSJtMTQuMDA3IDguNDQ3MWMwLjIwNjggMC4x'
    b'Nzk4IDAuNDk0NSAwLjUzMDQgMC41Mzk0IDAuNzczMSAwLjU1NzQgMC4wODk5IDEuMDA2OSAw'
    b'LjQ0OTUgMS40MTE1IDAuODU0MSAwLjU1NzMgMC4wMTc5IDEuMTUwNy0wLjA3MiAxLjU1NTIg'
    b'MC4yOTY2IDAuNTM5NCAwLjI3ODcgMS4wMzM5IDAuNjc0MyAxLjY1NDIgMC43NTUyIDAuOTA4'
    b'IDAuMDgwOSAxLjg3ODkgMC4wNTM5IDIuNzY4OS0wLjAxOCAwLjU1NzQtMC4wMTggMS4wMDY5'
    b'IDAuMTE2OSAxLjUxMDQgMC4yNjA3IDAuNzEwMiAwLjI0MjggMS41ODIyIDAuMjQyOCAyLjM3'
    b'MzMgMC4xNzA4IDAuNjQ3MyAwLjA1NCAyLjk5MzcgMC4xODg4IDMuMzM1MyAxLjAzMzkgMC4x'
    b'Nzk4IDAuMTQzOCAwLjM0MTYgMC4zMjM2IDAuNTQ4NCAwLjQxMzUgMC4xNzk4IDAuMDcyIDAu'
    b'MTUyOCAwLjMwNTcgMC4zNDE2IDAuMzc3NiAwLjYzODMgMC42NzQzIDIuMjI5NiAxLjM5MzUg'
    b'Mi45NzU3IDAuNDU4NSAwLjE5NzgtMC4yNDI3IDAuMDg5OS0wLjY0NzMgMC4xMDc5LTAuOTcw'
    b'OS0wLjc5MTEtMS41OTEzLTMuMjk5My0xLjg3ODktNC44MTg2LTEuNjk5MS0wLjUzMDQgMC4w'
    b'MTc5LTEuMDQyOSAwLjE0MzgtMS42MDAzIDAuMTA3OC0wLjk3OTkgMC0yLjU0NDEgMC4xNzA5'
    b'LTMuNDUyMS0wLjI2OTctMC41Mzk0LTAuMjMzNy0xLjAyNDktMC40NTg1LTEuNjE4Mi0wLjYy'
    b'MDMtMS4xNjg3LTAuMzUwNi0wLjgwMDItMS42MDkyIDAuMjA2Ny0xLjYwOTIgMS40MTE1LTAu'
    b'NTU3NCAyLjgwNDkgMS4wNTE4IDQuMDAwNiAwLjYyMDMgMC43MTAyIDAgMS4zNTc1LTAuMTc5'
    b'OCAyLjA3NjctMC4xMzQ4IDAuODQ1MS0wLjE2MTkgMS42NTQyIDAuMDQ0OSAyLjQ5OTIgMC4w'
    b'NTM5IDEuOTk1OCAwLjQxMzYgNC41NjcgMS4yMjI3IDQuOTYyNSAzLjYyMyAwLjI5NjcgMi4w'
    b'Njc3LTEuOTc3OCAzLjkxOTctNC4wMDA1IDMuMjQ1NCAwLjE2MTggMC43NDYyIDAuODI3IDIu'
    b'NTE3MiAxLjY2MzEgMi44MzE5IDAuMzc3NiAwLjIzMzcgMC44OSAwLjA4OTkgMS4yMzE2IDAu'
    b'NDA0NiAwLjI3ODcgMC43MzcxIDAuNDk0NSAxLjUxMDMgMC45MDggMi4yMjA1IDAuMDQ1IDAu'
    b'MzY4Ni0wLjk1MjkgMS42ODExLTEuMTMyNyAyLjIyMDVoLTQuMjQzM2MtMC4zODY2LTAuNTMw'
    b'NCAwLjM1MDYtMS44NDI5IDAuMjYwNy0xLjY4MTEgMC4zMDU3LTAuNDA0NSAwLjcyODItMC43'
    b'MTAyIDEuMTg2Ny0wLjgzNjEtMC4xNTI4LTAuMTI1OC0wLjI0MjctMC40MDQ1LTAuNDc2NS0w'
    b'LjM3NzYtMC42MDIzLTAuNDY3NC0xLjM0ODUtMC42NDcyLTEuODk2OS0xLjIyMjYtMC4wNjI5'
    b'IDAuMDgwOS0wLjE3MDggMC4xNjE4LTAuMTcwOCAwLjIyNDctMC41MjE0IDAuNjIwNC0wLjI4'
    b'NzcgMS42MDkzLTAuOTcwOSAyLjE0ODctMC44NzIgMC4zMTQ2LTEuMDQyOSAxLjIxMzYtMS41'
    b'NjQzIDEuNjgxMWgtNy44MzAzYy0wLjEyNTktMS4xNTk3IDAuMzg2Ni0yLjA2NzcgMS41MDEz'
    b'LTIuMzQ2NCAwLjAxOC0wLjA0NDkgMC4wNzItMC4xMDc5IDllLTMgLTAuMTUyOC0wLjQzMTUt'
    b'MC4zNTA2LTAuOTcwOS0xLjM5MzUtMS40NzQzLTEuNTkxMy0wLjM1OTYgMC41MzA0LTAuNDMx'
    b'NiAxLjA2OTktMC44MjcxIDEuNTQ2My0wLjQ0OTUgMC4wNjMtMC44OSAwLjM3NzYtMS4yOTQ2'
    b'IDAuNjI5My0wLjg0NSAwLjQ4NTUtMC45NDM5IDEuMzY2NS0xLjE4NjcgMS45Nzc4LTAuMTA3'
    b'OCAwLjA4MS0wLjIzMzcgMC4wMjctMC4zODY1IDAuMDI3aC00LjU0OWMwLjAzNi0xLjMzOTUg'
    b'MC45MDgtMi4yOTI1IDIuMjQ3NS0yLjQ1NDMgMC4yODc3LTAuNzI4MiAxLjEyMzgtMS4xNTA3'
    b'IDEuNDM4NC0xLjg2OTkgMC4xNzA4LTAuNzQ2MiAwLjI5NjctMS40ODM0IDAuNTkzNC0yLjE3'
    b'NTYtMC45ODg5LTAuNDIyNS0yLjAwNDgtMS41MTAzLTIuNDkwMy0yLjQ4MTMtMC4yODc3LTAu'
    b'MTg4OC0wLjY0NzMtMC4yNzg3LTAuODcyLTAuNTc1My0wLjQzMTUgOWUtMyAtMS4xNTA3LTAu'
    b'NDA0Ni0xLjUwMTMtMC4yNDI4LTAuMzA1NyAwLjAyNy0wLjY3NDMgMC4wNTQtMC45NDQtMC4w'
    b'ODA5LTAuNDY3NSAwLjE3MDgtMC45MTctMS41NzMyLTAuMzA1Ny0xLjk4NjggMC4zMTQ3LTAu'
    b'MTg4OCAwLjc2NDIgMC4wNzE5IDEuMDMzOS0wLjE2MTgtMC41OTMzLTAuMTUyOC0xLjIxMzcg'
    b'MC4zNzc2LTEuNzQ0MS0wLjMwNTctMC4yMjQ3LTAuMjc4NyAwLjE0MzktMC41ODQzLTAuMDk4'
    b'OS0wLjg0NS0wLjUwMzQtMC4wNjMtMC4zOTU1LTAuOTg4OS0wLjAyNjktMS4yMjI3IDAuMjMz'
    b'Ny0wLjA2MjkgMC40NDk1LTAuMTYxOCAwLjcwMTItMC4xNDM4IDAuMTk3OC0wLjEyNTkgMC4z'
    b'ODY2LTAuMjYwNyAwLjYyOTMtMC4yODc3IDAuODQ1MSAwLjA0NDkgMS4yOTQ2LTAuOTQ0IDIu'
    b'MjIwNS0wLjY5MjIgMC40NDA1IDAuMDUzOSAwLjkyNiAwLjA3MTkgMS4zODQ1IDAuMDQ0OSAw'
    b'LjM5NTYtMC4yNTE3IDEuMjc2Ni0wLjQ1ODUgMS42MDAyIDAuMDU0em0xMC42MTcgOS4yMjM4'
    b'Yy0wLjIwNjcgMC43NjQxIDAuMTcwOSAxLjg5NjkgMC4zOTU2IDIuNjM0MS0wLjM0MTYgMC4z'
    b'NTk2LTAuNzAxMiAwLjc2NDEtMS4xODY3IDEuMDE1OC0wLjI5NjYgMC4wMzYtMC42NDczIDAu'
    b'MTI1OS0wLjkyNTkgMC4yMzM4LTAuMDQ1LTAuNTc1NCAwLjE0MzgtMS4yMTM3LTAuMzY4Ni0x'
    b'LjUxOTMtMC4zMTQ3LTAuNTAzNS0wLjcyODItMS4xODY3LTAuODkwMS0xLjc3MTEgMS4xMjM4'
    b'LTAuMDUzOSAyLjA0MDgtMC40OTQ0IDIuOTc1Ny0wLjU5MzN6IiBmaWxsPSIjMWYxYTE3Ii8+'
    b'CiAgIDxwYXRoIGNsYXNzPSJmaWwzIiBkPSJtMTQuNDcgMjAuNzg3YzAgMC4wMjY5IDAgMC4w'
    b'NDQ5LTAuMDI3IDAuMDcxOS0wLjM1MDYtMC4wNjMtMC41NzUzIDAuMDcxOS0wLjQ0MDUtMC4z'
    b'MzI3bDAuNDY3NSAwLjI2MDh6bS0wLjE3MDgtMC43MDEzYzAuMzMyNiAwLjMwNTcgMC43NTUx'
    b'IDAuMzUwNiAxLjEwNTcgMC41MDM1LTAuMDYyOSAwLjI2OTctMS4wNTE4LTAuMTA3OS0xLjE4'
    b'NjYtMC4yMzM4LTllLTMgLTAuMTE2OCAwLjA4MDktMC4zOTU1IDAuMDgwOS0wLjI2OTd6bTEx'
    b'Ljg0OS0wLjE3MDggMC4zNDE3IDAuMDI3Yy0wLjIzMzggMC4xNTI4LTAuNTU3NCAwLjExNjkt'
    b'MC44NTQxIDAuMTQzOHYtMC4xODg4YzAuMDE4IDllLTMgMC40MDQ2LTAuMTc5OCAwLjUxMjQg'
    b'MC4wMTh6bS01LjgzNDUtMC4zMzI2LTAuNDg1NSAwLjQ3NjVjLTAuMTc5OC0wLjAxOC0wLjE3'
    b'OTggOWUtMyAtMC4xNzk4LTAuMTg4OCAwLjA4MS0wLjAyNyAwLjEyNTktMC4wNzIgMC4yMTU4'
    b'LTAuMDgwOXYtMC4wNDVjMC4xNzk4LTllLTMgMC4yNzg3LTAuMTk3OCAwLjQ0OTUtMC4yMTU4'
    b'djAuMDU0em0tNS43NzE2LTAuMTE2OWMwLjE3OTggMC4wNjI5IDAuMzk1NiAwLjA1NCAwLjU3'
    b'NTQgMC4xMTY5IDAuMzc3NiAwLjE5NzggMC44ODEgMC40MTM1IDEuMjY3NiAwLjcwMTItMC41'
    b'MDM1LTAuMTYxOC0xLjE0MTgtMC40MzE1LTEuNzE3MS0wLjM1MDYtMC4yNjk3LTAuMDcxOS0w'
    b'LjMxNDctMC4yOTY3LTAuMjYwNy0wLjU0ODQgMC4wNjI5IDAgMC4wOTg4IDAuMDQ1IDAuMTM0'
    b'OCAwLjA4MDl6bTEyLjQ0MiAwLjA4OTljLTAuNDA0NSAwLjAxOC0xLjI3NjYgMC4wNzE5LTEu'
    b'NTczMi0wLjIyNDdsMC4wMDg5LTAuMTE2OWMwLjYwMjQtMC4wNTM5IDEuMDQyOSAwLjI1MTcg'
    b'MS41NjQzIDAuMzQxNnptMy42OTQ5LTAuNjAyM2MtMC4xMjU4IDAuMjI0Ny0wLjg5IDAuNjU2'
    b'My0xLjA4NzggMC40NTg1IDAuMTcwOC0wLjEzNDkgMC44NDUxLTAuNDY3NSAxLjA4NzgtMC40'
    b'NTg1em0tMTAuMjQtMC4wODk5YzAuMDcxOSAwLjIzMzctMC45MTcgMC42NjUyLTEuMTg2NyAw'
    b'LjY2NTItMC4wNjI5LTAuMDYyOS0wLjA2MjktMC4xNTI4LTAuMTUyOC0wLjE4ODcgMC4xMDc4'
    b'LTAuMDk4OSAwLjI2OTcgMC4wMDg5IDAuNDA0NS0wLjA0NSAwLjM0MTYtMC4wMzYgMC42NjUz'
    b'LTAuMjA2OCAwLjkzNS0wLjQzMTV6bS01LjA0MzQgMC4yMDY4YzAuMTk3NyAwIDAuOTc5OSAw'
    b'LjU3NTMgMS4xODY2IDAuNzAxMnYwLjA0NDljLTAuNjM4Mi0wLjQxMzUtMS4zNjY0LTAuNDk0'
    b'NC0yLjAzMTctMC44MDAxIDAuMDE4LTAuMDcxOSAwLjAxOC0wLjE0MzggMC4wNTM5LTAuMTk3'
    b'OCAwLjMxNDctMC4wMjY5IDAuNTkzNCAwLjAxOCAwLjc5MTIgMC4yNTE4em00LjM4NzEtMC40'
    b'NTg1Yy0wLjIzMzcgMC4xOTc3LTAuNjU2MyA5ZS0zIC0wLjg1NDEgMC4yMjQ3LTAuMDgwOS0w'
    b'LjAxOC0wLjA3MTkgMC4wNzE5LTAuMTI1OCAwLjA4OTktMC4xNjE4IDAtMC40ODU1LTAuMDM1'
    b'OS0wLjU1NzQtMC4xODg4IDAuMTYxOCAwIDAuMzE0Ny0wLjAzNTkgMC40NzY1LTAuMDk4OSAw'
    b'LjM1MDYtMC4wMjY5IDAuNzEwMi0wLjA0NDkgMS4wNjA4LTAuMDg5OXYwLjA2M3ptMTAuNzYx'
    b'LTAuMjk2N2MwIDllLTMgOWUtMyAwLjAxOCAwLjAxNzkgMC4wMjctMC4xNzA4IDAuMDYyOS0w'
    b'LjM3NzUgMC4wOTg4LTAuNTM5NCAwLjIwNjctMC4yMTU3IDAuMDU0LTAuMzY4NSAwLjIyNDgt'
    b'MC41NTczIDAuMzE0N3MtMC4zOTU2LTAuMDE4LTAuNTkzNC0wLjAzNnYtMC4wNDQ5YzAuNjAy'
    b'NC0wLjIxNTggMS4wMzM5LTAuNDIyNiAxLjY3MjItMC40Njc1em0tNC40MjMxIDAuMDgwOWMw'
    b'LjI0MjcgMC4wMjcgMS4wODc4IDAuMjA2OCAxLjI3NjYgMC4zOTU2LTAuNzEwMy0wLjI5Njct'
    b'MS40NDc0IDAuMTA3OC0yLjExMjctMC4yNDI4LTAuMjMzNy0wLjQxMzUgMC43MzcyLTAuMTc5'
    b'OCAwLjgzNjEtMC4xNTI4em0tMTAuNDEtMC4xNzA4YzAuMzIzNyAwLjIwNjggMC42MjkzIDAu'
    b'NTIxNCAwLjkzNSAwLjcxOTItMC42MDI0LTAuMjE1OC0xLjI5NDYtMC41Mzk0LTEuOTMyOS0w'
    b'LjY0NzMtMC4wMjctMC42MzgzIDAuNzU1Mi0wLjExNjkgMC45OTc5LTAuMDcxOXptMTAuMTMy'
    b'LTAuNDY3NWMwLjM4NjUgMC4wODk5IDAuNzgyMSAwLjMxNDcgMS4xODY3IDAuNDIyNS0wLjUx'
    b'MjUgMC4wMTgtMC45NDQtMC4yMjQ3LTEuNDgzNC0wLjE1MjgtMC4wMzYtMC4wMjctMC40NTg1'
    b'LTAuMTcwOC0wLjI2MDctMC4zMjM2IDAuMjA2OC0wLjAxOCAwLjM1OTYgMC4wODA5IDAuNTU3'
    b'NCAwLjA1Mzl6bS05Ljk3IDAuMDgwOWMwLjIyNDggMC4xMDc5IDAuNDIyNiAwLjIzMzggMC42'
    b'NjUzIDAuMzE0N2wtMC4wMTggOWUtM2MwLjM5NTYgMC4zMTQ2IDAuODE4MSAwLjY0NzIgMS4y'
    b'MzE2IDAuOTE2OS0wLjA1MzkgMC4yNDI4LTAuMjI0NyAwLjUwMzUtMC40MDQ1IDAuNzE5Mi0w'
    b'LjEzNDkgMC4yNTE4LTAuMTc5OCAwLjU5MzQtMC4zMDU3IDAuODU0MS0wLjk2MTkgMC4yNDI3'
    b'LTIuNDcyMiAxLjQyMDQtMi41NjIxIDIuNTYyMmwtMy44Mjk4IDAuMDE4Yy0wLjA4MDktMC42'
    b'MDI0IDAuODQ1MS0wLjk4OSAxLjIyMjctMS4xNzc3IDAuMTg4OC0wLjA4MSAwLjQxMzUtMC4w'
    b'NjMgMC42MDIzLTAuMTI1OSAwLjUyMTQtMC43NDYyIDEuMzc1NS0xLjQyOTQgMS43MTcxLTIu'
    b'MjIwNiAwLjEzNDgtMC42MzgyIDAuMzA1Ny0xLjMzMDUgMC41MjE0LTEuOTUwOC0wLjA2Mjkt'
    b'MC4zNDE2IDEuMDY5OCAwLjA1MzkgMS4xNTk3IDAuMDgwOXptMTQuMzc1LTAuMjI0N2MtMC4x'
    b'MjU5IDAuMTM0OC0wLjM2ODYtOWUtMyAtMC41MTI0IDAuMTc5OC0wLjMwNTcgMC4xNzA4LTAu'
    b'NjExNCAwLjMzMjYtMC44OTkgMC41NjYzLTAuMjMzOCAwLjA2My0wLjM4NjYtMC4wODA5LTAu'
    b'NTg0NC0wLjE1MjggMC41NTc0LTAuMzE0NiAxLjM2NjUtMC41NzU0IDEuOTk1OC0wLjYzODN2'
    b'MC4wNDV6bS0xMC40NjQtMC4xNDM5Yy0wLjE5NzggMC4xOTc4LTAuNjIwMyAwLjE3MDgtMC44'
    b'MjcxIDAuMzU5Ni0wLjMxNDYgMC4wODA5LTAuOTg4OSAxLjA5NjgtMS4zODQ1IDAuNTU3NC0w'
    b'LjA2MjktMC4wMTgtMC4xNzA4LTAuMDI3LTAuMTcwOC0wLjA4OTkgMC4zNjg2IDAuMDI3IDAu'
    b'NjM4My0wLjIxNTggMC45NDQtMC4zNDE2di0wLjA0NWMwLjQxMzUtMC4yMDY3IDAuOTg4OS0w'
    b'LjM2ODYgMS40Mzg0LTAuNDQwNXptMTAuMDk2LTAuMzU5NmMtMC4yMzM3IDAuMTE2OS0wLjUz'
    b'OTQgMC4wOTg5LTAuNzY0MiAwLjI2OTctMC40MjI1IDAuMDcxOS0wLjY1NjIgMC40ODU1LTEu'
    b'MDY5OCAwLjU1NzQtMC4wMjY5LTAuMDYyOS0wLjQwNDUtMC4wMTgtMC40MjI1LTAuMjI0NyAw'
    b'LjQ0OTUgMC4wODk5IDAuNjQ3My0wLjM4NjYgMS4wMzM5LTAuNDQ5NiAwLjQyMjUtMC4wMjY5'
    b'IDAuODA5MS0wLjE1MjggMS4yMjI2LTAuMjA2N3YwLjA1Mzl6bS0xMC41MTgtMC4yMzM3Yy0w'
    b'LjEzNDkgMC4wNjI5LTAuMjQyOCAwLjEwNzktMC40MTM2IDAuMTI1OC0wLjQ2NzUgMC4yNjA3'
    b'LTAuOTM0OSAwLjYyMDQtMS4zNjY1IDAuOTYyLTAuMTYxOCAwLjA3MTktMC43MTAyIDAuMDgw'
    b'OS0wLjcxMDItMC4xODg4IDAuMjMzOCAwLjA2MjkgMS4xOTU3LTAuNjY1MyAxLjQ3NDQtMC43'
    b'NzMyIDAuMzE0Ni0wLjAyNjkgMC42ODMyLTAuMTA3OCAxLjAxNTktMC4xMjU4em05LjkxNi0w'
    b'LjMyMzdjLTAuODM2MS0wLjA1MzktMS4xNDE4IDEuMDA2OS0yLjAxMzggMC43ODIyLTAuMTA3'
    b'OS0wLjA1NC0wLjI2OTctMC4wMTgtMC4zNTk2LTAuMDg5OSAwLjE3OTgtMC4xMTY5IDAuNDk0'
    b'NS0wLjAyNyAwLjY0NzMtMC4yNjk3IDAuNTQ4NC0wLjIzMzggMS4wOTY4LTAuNDQwNSAxLjcy'
    b'NjEtMC40NDk1djAuMDI2OXptLTExLjA2Ny0wLjE3MDhjLTAuMTA3OCAwLjA2My0wLjM1MDYg'
    b'MC4xNTI5LTAuNDQwNSAwLjIwNjgtMC4yOTY2IDAuMjE1OC0wLjQ0OTUgMC42MjkzLTAuODAw'
    b'MSAwLjgxODEtMC4yNTE3IDAuMTA3OS0wLjUyMTQgMC0wLjc2NDEtMC4wNzE5IDAtMC4xNzA4'
    b'IDEuNzgtMS4wMTU5IDIuMDEzNy0xLjA1MTkgMC4wNzIgMC4wMjctOWUtMyAwLjA2My05ZS0z'
    b'IDAuMDk4OXptLTIuMDQ5Ny0wLjg5Yy0wLjE3MDggMC4zNzc2LTAuMzY4NiAxLjE2ODctMC42'
    b'NjUyIDEuNDI5NC0wLjE5NzggMC4wOTg5LTAuMzU5Ny0wLjA0NDktMC40MzE2LTAuMDE4IDAu'
    b'Mjg3Ny0wLjI3ODYgMC40NTg1LTAuNTg0MyAwLjc4MjItMC44OS05ZS0zIC0wLjE0MzggMC4x'
    b'OTc3LTAuNDQwNSAwLjI3ODctMC41Mzk0bDAuMDM1OSAwLjAxOHptLTAuNzY0MS0wLjUxMjRj'
    b'LTAuMDYzIDAuMjYwNy0wLjE0MzkgMC41NDg0LTAuMjE1OCAwLjgwOTEtMC4yNjA3LTAuMDI3'
    b'LTAuNTQ4NCAwLjU5MzMtMC43MjgyIDAuNzczMS0wLjE4ODggMC4wMTgtMC40MTM1IDAuMDE4'
    b'LTAuNDk0NC0wLjE3OTggMC41MjE0LTAuMDcxOSAxLjE4NjYtMS4zMTI1IDEuNTM3My0xLjY5'
    b'OTEtMC4wNTQgMC4wODk5LTllLTMgMC4yNDI3LTAuMDk4OSAwLjI5Njd6bTExLjgyMiAwLjYy'
    b'MDNjMC41NDgzIDAuMDM1OSAxLjcwODEgMC4wNDQ5IDIuMTMwNiAwLjQ2NzUtMC42NjUzLTAu'
    b'MDcyLTEuMzU3NSAwLjAzNTktMi4wMDQ4IDAuMDg5OS0wLjI4NzctMC4xMjU5LTAuNTQ4NC0w'
    b'LjMxNDctMC44MjcxLTAuNDQwNS0wLjA4OTktMC4wNDUtMC43MDEyLTEuMjMxNy0wLjY0NzMt'
    b'MS4xMzI4IDAuNTMwNSAwLjU4NDQgMC42Mjk0IDAuNzkxMSAxLjM0ODYgMS4wMTU5em0tMTIu'
    b'NzMtMS4zNDg1Yy0wLjA4MDkgMC41MzA0LTAuNzQ2MiAxLjg2MDktMS4zNjY1IDEuMjQwNiAw'
    b'LjcxMDItMC4yNzg3IDAuOTM0OS0wLjYyOTMgMS4zMjE1LTEuMjQwNmgwLjA0NXptNC4zMTUy'
    b'LTAuMDU0YzAuMjQyNyAwLjE4ODggMC4zNjg2IDAuNDk0NSAwLjYyOTMgMC42MzgzIDAuNDA0'
    b'NSAwLjMzMjctMC4wNTQgMC43MTkyLTAuMDI3IDEuMDE1OS0wLjE2MTgtMC4wMTgtMC4xNzA4'
    b'LTAuNDIyNS0wLjE3OTgtMC41MzA0IDAuMTI1OSAwLTAuNDU4NS0xLjA2OTgtMC40Njc1LTEu'
    b'MTIzOGgwLjA0NXptOS45MDctMC4zNTA2YzAuMDYyOSAwLjI5NjcgMC4xMjU5IDAuNjU2MyAw'
    b'LjI1MTcgMC45NTMtMC41Mzk0LTAuNTAzNS0wLjgwOTEtMC44MjcxLTAuOTM0OS0xLjYxODIg'
    b'MC4yMjQ3IDAuMTk3NyAwLjU4NDMgMC4yODc2IDAuNjgzMiAwLjY2NTJ6bS01LjgyNTUtMC43'
    b'MzcyYzAuMjY5NyAwLjQ3NjUgMC4zNTk2IDAuODk5IDAuNTQ4MyAxLjM1NzUgMCAwLjY0NzMg'
    b'MC42ODMzIDEuMTA1OCAwLjM3NzYgMS43OTgxLTAuMDYyOS0wLjUzOTUtMC4zNTA2LTAuODE4'
    b'MS0wLjY0NzMtMS4yMjI3LTAuMzA1Ni0wLjQwNDYtMC4xODg3LTEuNDIwNC0wLjMwNTYtMS45'
    b'MzI5aDAuMDI3em0tMi40NDUzIDllLTNjMC4wMjY5IDAuMjY5NyAwLjE3MDggMC40NDA1IDAu'
    b'MzE0NiAwLjcwMTMgMC4yNTE3IDAuNTg0MyAwLjM3NzYgMS4yNDA2IDAuMjA2OCAxLjg5Njkt'
    b'MC4wNjI5IDAuMjI0Ny0wLjEzNDkgMC40MzE1LTAuMTYxOCAwLjY0NzItMC4wNTQtMC4zODY1'
    b'IDAuMDM1OS0wLjg0NS0wLjA4MDktMS4yMTM2LTAuMTA3OS0wLjc3MzItMC4zNTk2LTEuNDgz'
    b'NC0wLjM3NzYtMi4yNDc1IDAuMDk4OSA5ZS0zIDAuMDUzOSAwLjE1MjggMC4wOTg5IDAuMjE1'
    b'N3ptNy4wNjYxIDAuMDYzYzAuMTg4OCAwLjUwMzQgMC4zNzc2IDEuMDMzOCAwLjcyODIgMS40'
    b'NjUzLTAuMzE0Ni0wLjE5NzctMC41NTc0LTAuMzc3NS0wLjg4MS0wLjU4NDMtMC4xNzA4LTAu'
    b'NDMxNS0wLjQ1ODUtMC43OTExLTAuNzE5Mi0xLjIxMzctMC4wMjctMC4wMzU5LTAuMDk4OS0w'
    b'LjAxOC0wLjExNjktMC4wODA5IDAuMzk1Ni05ZS0zIDAuNzE5MiAwLjE0MzkgMC45ODg5IDAu'
    b'NDEzNnptLTEuNjkwMS0wLjQwNDZjMC4xNDM4IDAuMDg5OSAwLjUxMjQgMC4yMjQ4IDAuNDg1'
    b'NSAwLjQ3NjUgMCAwLjE5NzggMC4yNzg3IDEuMzU3NSAwLjYzODMgMS4zNTc1IDAgMC4wOTg5'
    b'IDAuNDk0NCAwLjQzMTUgMC41NTczIDAuNTkzMy0xLjA5NjctMC41OTMzLTEuNTE5My0wLjk4'
    b'ODktMS44ODc5LTIuMTQ4NiAwLTllLTMgLTAuMzY4Ni0wLjMyMzYtMC4zNTk2LTAuMzc3NiAw'
    b'LjIzMzgtMC4wNjI5IDAuMzc3NiAwLjA4OTkgMC41NjY0IDAuMDk4OXptLTEuMzEyNS0wLjA3'
    b'MTljMC4xNTI4IDAuMDcxOSAwLjI5NjYgMC4xNzk4IDAuNDQ5NSAwLjI2OTcgMC4xMzQ4IDAu'
    b'MDQ0OSAwLjM4NjUgMi4wMTM4IDAuMjk2NiAyLjMwMTQtMC4xNTI4LTAuMzUwNi0wLjI2MDct'
    b'MC43NjQxLTAuNTIxNC0xLjA2OTgtMC4xMTY5LTAuNDEzNS0wLjE2MTgtMC44NTQtMC4zMDU2'
    b'LTEuMjQwNi0wLjA4OTktMC4xNjE4LTAuMjg3Ny0wLjE4ODgtMC4zNTA3LTAuMzU5NiAwLjE3'
    b'MDktMC4wMjcgMC4yNjA4IDAuMTE2OSAwLjQzMTYgMC4wOTg5em0tMC45MjYtMC4wODk5YzAu'
    b'MzQxNiAwLjE3OTggMC41Mzk0IDEuMTY4NyAwLjYzODMgMS41NzMyIDAuMTE2OSAwLjI2OTcg'
    b'MC4yOTY3IDAuNDU4NSAwLjQxMzUgMC43MzcyIDAuMDE4IDAuMjk2Ny0wLjA1MzkgMC41OTM0'
    b'IDAuMDcxOSAwLjg5bC0wLjA2MjktMC4wMDg5Yy0wLjI0MjctMC44MTgxLTEuMDQyOC0xLjQ5'
    b'MjQtMS4wNTE4LTIuMzEwNS0wLjEwNzktMC4zMTQ2LTAuNDEzNi0wLjkyNi0wLjcyODItMS4w'
    b'NTE4IDAuMjg3Ny0wLjA0NSAwLjQ3NjUgMC4xMTY4IDAuNzE5MiAwLjE3MDh6bS0xMi4yIDAu'
    b'NzQ2MmMtMC4xODg4IDAuMDQ0OS0wLjM3NzYgMC4yMDY3LTAuNjAyMyAwLjE1MjggMC4zOTU1'
    b'LTAuMzUwNiAwLjcwMTItMC43OTExIDAuOTcwOS0xLjIyMjctOWUtMyAwLjQwNDYtMC4xNDM4'
    b'IDAuNzY0Mi0wLjM2ODYgMS4wNjk5em03LjU2MDYtMS4yMjI3YzEuMTQxOCAwLjE5NzggMy44'
    b'NjU3LTAuNjExMyAzLjY3NyAxLjMzMDUtMC4zMjM3IDAuNjU2MyAwLjQwNDUgMS4wNjk5IDAu'
    b'MTUyOCAxLjczNTEtMC4xNTI4LTAuMjE1Ny0wLjE5NzgtMC43MjgyLTAuNDY3NS0wLjkzNDkt'
    b'MC4yNjk3LTAuNDEzNiAwLjAxOC0wLjg5MDEtMC4wMjctMS4zNjY1LTAuMTYxOC0wLjE3MDgt'
    b'MC4xNjE4LTAuNDk0NS0wLjUwMzQtMC40MzE2LTAuNzczMSAwLjcwMTMgMC4yNjA3IDEuODA3'
    b'LTAuMTQzOCAyLjUzNTIgMC4wMDg5IDAuMjYwOC0wLjEzNDkgMC41MTI1LTAuMDcyIDAuNzU1'
    b'Mi0wLjA1MzktMC4zNzc2LTAuMDE3OS0wLjgyNzEtMC4wMjY5LTEuMjQ5Ni0wLjM2ODYtMC42'
    b'NjUzLTAuNjAyNC0xLjIwNDctMC45NzEtMS44MzQtMC4xNzA4LTAuMjI0Ny0wLjE5NzctMC4x'
    b'MzQ4LTAuMzU5Ni0wLjE2MTgtMC42NzQyIDAuODcyIDAuMzg2NiAxLjcyNjEgMC4wNTQgMi42'
    b'ODgtMC4wNzE5LTAuMzMyNi0wLjE2MTgtMC42ODMyLTAuMzE0Ny0wLjk4ODktMC41MjE0LTAu'
    b'NDQ5NS0wLjAzNTktMS41MTAzLTAuODE4MS0xLjcyNjEtMC4zODY1IDAuMjA2OC0wLjMyMzYg'
    b'MS4xMjM4LTAuMTM0OCAxLjQyOTQtMC4zMDU3IDAtMC40MjI1LTEuNDY1My0wLjQ5NDUtMS42'
    b'NzIxLTAuMDE3OS0wLjE3OTgtMC4yNDI3LTAuMTA3OS0wLjI4NzctMC4yNjk3IDAuMjQyOCAw'
    b'LjA3MTkgMC40NzY1IDAuMTUyOCAwLjczNzIgMC4xNjE4em0tNC45ODk0LTAuMTc5OGMtMC4x'
    b'NzA4IDAuNTc1NC0xLjYxODIgMy4wMjk3LTIuMzQ2NCAxLjk4NjggMS4wNzg4LTAuMjYwNyAx'
    b'LjY5OTEtMS4wNjA4IDIuMjc0NC0xLjk1OTggMC4wMjctOWUtMyAwLjA0NS0wLjAzNiAwLjA3'
    b'Mi0wLjAyN3ptMy41MDYxLTAuMjUxN2MwLjcxMDIgMC41MjE0IDAuNDMxNSAwLjczNzIgMC4y'
    b'MDY3IDEuNDU2NCAwIDAuMzMyNiAwLjIyNDggMC41NzUzIDAuMjUxOCAwLjg5OS0wLjA1NCAw'
    b'LjUyMTQtMC4yODc3IDAuOTYxOS0wLjUyMTUgMS40MDI0LTAuMDUzOSAwLjUzOTQtMC42Mjkz'
    b'IDAuNzQ2Mi0wLjg1NCAxLjIwNDdoLTAuMDQ1YzAuMTM0OS0wLjQ3NjUgMC42NTYzLTAuNzM3'
    b'MiAwLjczNzItMS4yMzE2IDAuMDgwOS0wLjM5NTYgMC4xNzA4LTAuNzkxMiAwLjIzMzgtMS4y'
    b'MDQ3IDAtMC42NzQzLTAuNjIwMy0wLjI4NzctMC44NTQxIDAtMC4wMTgtMC4xNzA4IDAuMTQz'
    b'OS0wLjI3ODcgMC4xNzA4LTAuNDQwNSAwLjUzOTQtMC40NTg1IDAuNjQ3My0xLjQyOTQgMC42'
    b'MTEzLTIuMDg1N2gwLjA2M3ptLTAuNDMxNS0wLjMwNTdjMC4wMjY5IDAuMDk4OSAwLjE3MDgg'
    b'MC4xMjU5IDAuMTQzOCAwLjI2MDcgMC4wNzE5IDAuMDgwOS0wLjAxOCAwLjIwNjgtMC4wMjcg'
    b'MC4yODc3LTAuMzUwNiAwLjQzMTUtMC41NzUzIDEuMDE1OS0wLjgxODEgMS41MTAzIDAgMC4y'
    b'MTU4LTAuMzE0NiAwLjk0NC0wLjU4NDMgMC45NjIgMC4yNTE3LTAuNjQ3MyAwLjQ0MDUtMS4z'
    b'NDg1IDAuNzQ2Mi0yLjAxMzggMC4xMjU4LTAuNDQ5NSAwLjIwNjctMC42NzQyLTAuMTk3OC0w'
    b'LjkyNi0wLjE3MDggMC44NTQxLTAuNjkyMyAyLjA5NDctMS4yNDk2IDIuNzZoLTAuMDU0YzAu'
    b'MTQzOS0wLjI4NzcgMC42NTYzLTEuNTAxNCAwLjUxMjUtMS44MzQtMC4yMjQ4LTAuMDUzOS0w'
    b'LjIxNTggMC4yOTY3LTAuNDMxNiAwLjI0MjctMC4wODA5LTAuMjE1NyAwLjQ0OTUtMS4yODU1'
    b'IDAuNTU3NC0xLjQ1NjMgMC40MTM2LTAuMzIzNyAxLjAzMzktOWUtMyAxLjQwMjUgMC4yMDY3'
    b'em0tNy4wNDgyLTAuMTQzOGMwLjM3NzYgMC4zNDE2IDAuNTU3NCAxLjA0MjggMC4wODA5IDEu'
    b'MzkzNCAwIDAuNDU4NS0xLjExNDggMC4yNDI4LTEuMzM5NSAwLjI0Mjh2LTAuMDQ1YzAuNDEz'
    b'NS0wLjAxOCAxLjEzMjctMC4wOTg5IDEuMjY3Ni0wLjU5MzMgMC4wMzU5LTAuMjc4NyAwLjE1'
    b'MjgtMC42OTIzLTAuMTc5OC0wLjg3MjEtMC4xNzA5LTAuMTUyOC0wLjM1MDctMC4yNzg3LTAu'
    b'NTc1NC0wLjMwNTYtMC4xNzk4LTAuMTc5OCAwLjcxOTIgMC4xNzA4IDAuNzQ2MiAwLjE3OTh6'
    b'bTAuODU0LTAuMzMyN2MwLjMxNDcgMC42MzgzIDAuMjA2OCAxLjA2MDktMC4yOTY2IDEuNTY0'
    b'My0wLjE1MjktMC4xNTI4IDAuNTEyNC0xLjA1MTgtMC4xNzA5LTEuNDM4NC0wLjE5NzctMC4x'
    b'NzA4LTAuNjc0Mi0wLjM1OTYtMC45MjU5LTAuMjg3N3YtMC4wNjI5YzAuNTU3MyAwLjA4OTkg'
    b'MC44NTQtMC4yOTY3IDEuMzkzNCAwLjIyNDd6bTQuMjM0My0wLjE0MzhjMC4yMjQ4IDAuMzQx'
    b'Ni0wLjAyNjkgMS4xOTU3LTAuMjYwNyAxLjQ5MjQtMC4xMzQ4LTAuMDE4LTAuMDM1OS0wLjE3'
    b'OTgtMC4wODA5LTAuMjYwOC0wLjA3MTkgMC4xNTI5LTAuNzU1MiAxLjMzMDYtMC45MTcgMS4z'
    b'MzA2LTAuMDQ0OS0wLjI5NjcgMC42MjAzLTEuMzU3NSAwLjYzODMtMS43NjIxIDAuMDk4OS0w'
    b'LjE4ODggMC4xODg4LTEuMDY5OC05ZS0zIC0xLjI0MDZoMC4wNjNsMC41NjYzIDAuNDQwNXpt'
    b'LTMuMjAwNC0wLjQ5NDRjMC4xOTc4IDAuMzIzNiAwLjI2OTcgMC41NzUzIDAuNDA0NSAwLjkw'
    b'OGgwLjA2M2MtMC4wNTQgMC4yOTY2IDAuMDYyOSAxLjI3NjUtMC4yNDI4IDEuNDkyMy0wLjEz'
    b'NDgtMC4xODg4IDAuMjI0OC0xLjIxMzctMC4yMDY3LTEuMzU3NS0wLjE5NzggMC4xODg4LTAu'
    b'MzIzNyAwLjQyMjUtMC40NDA2IDAuNjQ3My0wLjA0NDkgMC4wMzU5LTAuMTE2OCAwLTAuMTUy'
    b'OCAwLjA1MzkgMC4wMTgtMC4wOTg5IDAuMTg4OC0wLjYyOTMgMC4yMjQ4LTAuNjgzMiAwLjAy'
    b'NjktMC4zMzI3LTAuMDI3LTAuOTE3IDAuMTUyOC0xLjE3NzcgMC4wMzYgMC4wNzE5IDAuMTM0'
    b'OCAwLjA3MTkgMC4xOTc4IDAuMTE2OXptMi4yNzQ1LTAuMDQ1YzAgMC4zMzI2LTAuMzIzNyAx'
    b'LjAwNjktMC40ODU1IDEuMzM5NS0wLjUzOTQgMC4zODY2LTEuMDE1OSAxLjcxNzEtMS42NTQy'
    b'IDEuODM0IDAuODAwMS0wLjYyOTMgMC42NjUzLTEuMzc1NSAwLjk1My0yLjIyMDUgMC40MzE1'
    b'LTAuMzUwNyAwLjU2NjMtMC45NzEgMC41MTI0LTAuMTA3OSAwLjA1MzktOWUtMyAwLjA4MDkg'
    b'MC4wNzE5IDAuMTI1OSAwLjAyNjkgMC4yNDI3LTAuMjQyNyAwLjA0NDktMC43MTAyIDAuMjg3'
    b'Ni0wLjk5NzkgMC4xMjU5LTAuMDQ0OSAwLjI2MDgtMC4wMjY5IDAuMjYwOCAwLjEyNTl6bS00'
    b'LjY2NTktMC4wNzE5IDAuMDI3IDAuMDQ0OWMtMC40NDA1IDAuMjUxOC0wLjg5IDAuNDU4NS0x'
    b'LjMzMDUgMC43NzMyIDAtMC4wNTQtMC4wNTQtMC4xNzk4IDAuMDQ0OS0wLjIwNjggMC40NDA1'
    b'LTAuMTYxOCAwLjY1NjMtMC44NTQgMS4yMjI3LTAuNjkyMmwwLjAzNTkgMC4wODA5em0zLjQ5'
    b'NzItMC43MTkyYy0wLjAzNiAwLjM5NTUtMC4yMDY4IDAuNjQ3My0wLjUzOTUgMC44MzYxLTAu'
    b'MDI2OS0wLjM1MDcgMC4zNjg2LTAuNjIwNC0wLjA2MjktMS4wMDY5IDAuMDM2LTAuMTUyOSAw'
    b'LjU3NTQtMC4wOTg5IDAuNjAyNCAwLjE3MDh6bTAuNDg1NCAwLjA0NDljLTAuMDE4IDAuMzY4'
    b'NiAwLjE1MjggMC45MjYtMC4zMTQ2IDEuMTg2Ny0wLjE3OTggMC0wLjMxNDcgOWUtMyAtMC4z'
    b'NTA2LTAuMjI0NyAwLjIxNTctMC40OTQ1IDAuNTAzNC0wLjgxODEgMC4yOTY2LTEuMzU3NSAw'
    b'LjI2MDctOWUtMyAwLjI0MjggMC4yNTE3IDAuMzY4NiAwLjM5NTV6bS0wLjE1MjgtMC43NjQx'
    b'YzAuMjA2OCAwLjIzMzcgMC40NzY1IDAuNDQwNSAwLjQ4NTQgMC43NTUxLTAuMDE3OSA5ZS0z'
    b'IC0wLjA0NDktOWUtMyAtMC4wNjI5IDAuMDE4IDAuMDcxOSA5ZS0zIDAuMDU0IDAuMDg5OSAw'
    b'LjA3MTkgMC4xMjU5IDAuMzU5NiAwLjE0MzggMC43ODIyIDAuMDk4OSAxLjA1MTkgMC40MzE1'
    b'IDAuMjY5NyAwLjA4OTkgMC40NTg1IDAuNDA0NiAwLjcxOTIgMC41Mzk0IDAuNDA0NSAwLjAz'
    b'NiAwLjg0NS05ZS0zIDEuMjMxNiAwLjA4OTkgMS42NjMyIDEuMjMxNiAzLjAzODYgMS4wMjQ5'
    b'IDQuOTk4NSAwLjk1MyAwLjYxMTMtMC4wMTggMS4yMjI2IDAuMTg4NyAxLjc4OSAwLjM1OTYg'
    b'MC42MjAzIDAuMTM0OCAxLjM0ODUgMC4wOTg4IDIuMDA0OCAwLjA2MjkgMC42ODMyIDAuMDUz'
    b'OSAxLjQyOTQgMC4xMzQ4IDIuMTAzNiAwLjI4Nzd2MC4wNDQ5YzAuNzM3MiAwLjA2MyAwLjg1'
    b'NDEgMC43NTUyIDEuNDgzNCAxLjAzMzkgMC4wNjI5IDAuMDYyOSAwLjA2MjkgMC4yMDY4IDAu'
    b'MTcwOCAwLjIwNjggMC45MDggMS4wMzM4IDEuODQyOSAxLjE2ODcgMy4xNzM1IDEuMDk2NyAw'
    b'LjIxNTctMC4xNzA4IDAuODAwMS0wLjM2ODYgMC44MzYtMC43MTAyIDAuMzA1Ny0wLjIyNDcg'
    b'MC4yNTE4LTEuMTUwNyAwLjE0MzktMS40MTE0LTAuMTE2OS0wLjgyNzEtMS42OTkxLTEuNjQ1'
    b'Mi0yLjQyNzMtMS45MzI5LTAuNjU2My0wLjA5ODktMS4zMzA1LTAuMTcwOC0yLjAwNDgtMC4y'
    b'MjQ3LTEuNzg5LTAuMDcyLTQuNDQxMSAwLjY3NDItNi4wMzIzLTAuMTk3OC0wLjU3NTQtMC4x'
    b'OTc4LTEuMjEzNy0wLjQyMjYtMS43NDQxLTAuNjgzMyAwLjEwNzktMC4zODY1IDEuMTQxOC0w'
    b'LjMzMjYgMS40MjA0LTAuMzMyNiAwLjk1MyAwLjIxNTggMi4wMjI4IDAuOTUzIDMuMDQ3NyAw'
    b'LjY3NDMgMS41MTkzLTAuMTg4OCAzLjI5OTMtMC4yNTE4IDQuODE4Ni05ZS0zIDEuNTI4MyAw'
    b'LjM3NzYgMy40MDcyIDEuMDUxOCAzLjkyODcgMi43MDYgMC41MDM0IDEuNzYyLTEuMzc1NSAz'
    b'LjM5ODItMy4xNDY1IDIuOTQ4Ny0wLjQzMTYtMC4wMzU5LTAuODAwMi0wLjE4ODgtMS4xOTU3'
    b'LTAuMzIzNiAwLjAyNyAwLjQwNDUgMC4zMjM2IDAuNzU1MSAwLjQ3NjUgMS4xNTk3IDAuMTg4'
    b'NyAwLjkwOCAwLjY3NDIgMi4wOTQ3IDEuNDExNCAyLjcwNiAwLjA3MTkgMC4zOTU2IDEuMzEy'
    b'NSAwLjYyMDMgMS42MTgyIDAuNjgzMyAwIDAuNjQ3MiAwLjQ3NjUgMS4zOTM0IDAuNzEwMiAx'
    b'Ljk1MDgtMC4xODg4IDAuNDg1NS0wLjcwMTIgMC45MDgtMC44MjcxIDEuNDU2NGwtMy4zODky'
    b'IDAuMDE4YzAuMDE4LTAuOTg4OSAwLjk4ODktMS41NTUzIDEuODk2OS0xLjU2NDMgMC4wMzU5'
    b'LTAuMDE4IDllLTMgLTAuMDUzOSAwLjAxOC0wLjA4MDktMC4yNjA4LTAuMzE0Ny0wLjY0NzMt'
    b'MC43MjgyLTAuODU0MS0xLjA2MDgtMC43NDYyLTAuMzIzNy0xLjM3NTUtMC44MDAyLTIuMDY3'
    b'Ny0xLjIxMzctMC4xNzA4LTAuMTE2OS0wLjIyNDgtMC4yOTY3LTAuMzY4Ni0wLjQzMTUtMC4z'
    b'OTU2LTAuMzA1Ny0wLjc4MjEtMC42MDI0LTEuMTQxNy0xLjAwNjktMS44MTYtMS4xNTA3LTMu'
    b'Mjk5NC0xLjAwNjktNS4yNzcyLTAuMzMyNi0wLjQ4NTQgMC4xMjU4LTAuOTk3OSAwLjEyNTgt'
    b'MS40MTE0IDAuMDUzOS0wLjEzNDktMC4xNzk4LTAuMTYxOC0wLjQwNDYtMC4yNTE3LTAuNjAy'
    b'MyAwLjAyNjktMC4xNjE5LTAuMTcwOC0wLjE5NzgtMC4yNjA3LTAuMzE0Ny0wLjQ0MDYtMC4x'
    b'MjU4LTAuODkwMS0wLjUwMzQtMS4yNTg2LTAuODQ1MSAwLjExNjggMC4wNzIgMC4wODA5IDAu'
    b'MzMyNyAwLjI0MjcgMC4zNzc2IDAuMTk3OCAwLjI3ODcgMC40OTQ0IDAuNDQ5NSAwLjc0NjIg'
    b'MC42MjAzIDAuMTA3OCA5ZS0zIDAuMTk3NyAwLjA0NSAwLjI2MDcgMC4xMzQ5IDllLTMgMC41'
    b'MjE0IDAuMjg3NiAwLjg5OSAwLjM2ODYgMS40MTE0IDAuNDU4NSAwLjcwMTMgMC42MzgzIDEu'
    b'NjQ1MiAxLjI3NjUgMi4yNDc2IDAgMC40OTQ0LTAuMTUyOCAxLjk0MTggMC4xNjE5IDIuMzM3'
    b'NCAwLjExNjgtMC4wMTggMC4xNzk4LTAuMTYxOCAwLjI1MTctMC4yNTE3IDAuMTc5OC0wLjQx'
    b'MzYgMC44MjcxLTAuOTA4IDEuMzEyNS0wLjgzNjEgMC4xNTI5IDAuMDE4IDEuNTAxNC0xLjA1'
    b'MTkgMS43NTMxLTEuMzAzNi0wLjA4MDktMC40Njc1LTAuMzc3Ni0wLjkxNy0wLjQ0OTUtMS40'
    b'Mjk0IDAuMDI3LTAuNTY2NC0wLjMxNDctMS4xNDE3IDAtMS42NDUyLTAuMTc5OC0wLjQ4NTUg'
    b'Mi4zMjg0IDAuNDk0NSAyLjM0NjQgMC41MDM1IDAuMDYyOSAwLjA1MzkgMC45Nzk5IDAuODgx'
    b'IDAuOTcwOSAwLjk2MTktMC4xNzk4IDAuMTQzOC0wLjE0MzggMC4zOTU2LTAuMzY4NiAwLjQ5'
    b'NDQtMC4zMTQ2IDAuNTAzNS0wLjYyMDMgMS4yOTQ2LTAuNjgzMiAxLjkyMzktMC4xODg4IDAu'
    b'MzE0Ny0wLjUzMDQgMC4zNzc2LTAuNTkzNCAwLjQzMTUtMC41MzA0IDAuMzk1Ni0wLjYwMjMg'
    b'MC45OTc5LTEuMTE0NyAxLjM3NTVoLTYuOTEzNGMwLjMzMjctMS4yNjc2IDAuOTg4OS0xLjEy'
    b'MzcgMS40MjA1LTEuMzQ4NSAwLjA4MDktMC4yMzM3IDAuMzUwNi0wLjczNzIgMC4wMTc5LTAu'
    b'ODU0LTAuMzg2NS0wLjQyMjYtMC43MjgyLTAuOTYyLTEuMTY4Ny0xLjM1NzUtMC4xNjE4LTAu'
    b'Mjk2Ny0wLjQ4NTQtMC40MzE2LTAuNzM3MS0wLjYyMDQtMC43NDYyLTAuMzU5Ni0xLjI5NDYt'
    b'MC43MzcxLTEuODI1LTEuMzU3NS0wLjY4MzMtMC40MzE1LTEuNDU2NC0wLjYwMjMtMi4xNzU2'
    b'LTAuOTI1OS0wLjY0NzMtMC40MzE2LTEuMTE0OC0wLjk1My0xLjY5OTEtMS40NjU0bC0wLjQx'
    b'MzYtMC44NTQxYy0wLjMyMzYtMC4yMTU3LTAuNzQ2MS0wLjI5NjYtMC45NTI5LTAuNjU2Mi0w'
    b'LjM2ODYtMC4xNzA5LTAuODA5MSAwLTEuMTIzOC0wLjMxNDcgMC4xODg4LTAuMDk4OSAwLjcy'
    b'ODItMC4zMzI2IDAuNzI4Mi0wLjU2NjQtMC4wNzE5LTAuMDQ0OS0wLjEyNTgtMC4xNjE4LTAu'
    b'MjQyNy0wLjEyNTgtMC40MTM1IDAuNTAzNC0xLjY1NDIgMS4xMzI3LTIuMTY2NiAwLjQwNDUg'
    b'MC4wODA5LTAuMTk3OC0wLjAzNi0wLjQyMjUgMC0wLjY1NjMgMC4wNDQ5IDAgMC4wODA5IDll'
    b'LTMgMC4xMTY5LTAuMDA4OS0wLjAzNi0wLjAyNy0wLjA4MDktMC4wMTgtMC4xMTY5LTAuMDM2'
    b'LTAuMDI3LTAuMTA3OSAwLjAzNi0wLjE3OTggMC4xMTY5LTAuMjUxNyAwLjExNjggMC4wODA5'
    b'LTAuMDM2IDAuMzk1NSAwLjIyNDcgMC4zMDU2IDAuMTUyOCAwLjE4ODggMC45MzUtMC4yMDY3'
    b'IDAuOTcwOS0wLjQ0OTUgMC4zOTU2LTEuMzQ4NS0xLjE4NjYtMC42MDIzLTEuNzg5LTAuODQ1'
    b'IDAuMDk4OS0wLjMwNTcgMC4wNTQtMC4zNDE3IDllLTMgLTAuNTY2NCAwLjM1OTYtMC4xOTc4'
    b'IDAuNDY3NS0wLjQ2NzUgMC40MzE1LTAuODcyMSAwLjg1NDEtMC41MzA0IDEuOTIzOSAwLjIx'
    b'NTggMi44MDQ5IDAuMjE1OC0wLjEyNTgtMC40MzE1IDAuMDg5OS0wLjQyMjUtMC4zOTU1LTAu'
    b'NjExMy0wLjM3NzYgMC4wNzE5LTAuNzgyMiAwLjA3MTktMS4xODY3IDAuMDcxOSAwLjA4OTkt'
    b'MC4wNDQ5IDAuMjk2Ni0wLjQyMjUgMC40NzY1LTAuNDEzNSAwLjI1MTctMC4yMjQ4IDEuOTIz'
    b'OC0wLjA3MiAyLjI1NjQtMC4wNjMgMC4xNjE5LTAuMDk4OSAwLjMxNDctMC4xOTc3IDAuNTEy'
    b'NS0wLjIxNTcgMC4xMjU4LTAuMTM0OSAwLjI4NzcgMC4wMzU5IDAuNDQ5NSAwem0tNS4zNDAx'
    b'IDEuMDMzOGMwIDAuMjUxOC0wLjI5NjcgMC43NTUyLTAuNTY2NCAwLjQ2NzVoOWUtM2MtOWUt'
    b'MyAtMC4wODk5LTAuMDQ0OS0wLjE4ODgtMC4wNDQ5LTAuMzE0NiAwLjA3MTktMC4xNjE5IDAu'
    b'NDU4NS0wLjI1MTggMC42MDIzLTAuMTUyOXptMC45NzA5IDEuNzYyMWMtMC4xMTY4IDAuMDM1'
    b'OS0wLjA5ODktMC4wODk5LTAuMTcwOC0wLjEzNDktMC4wNjI5IDAuMTA3OSAwLjAxOCAwLjI3'
    b'ODctMC4wNzE5IDAuMzk1Ni0wLjExNjktMC4wNjI5LTAuMTcwOC0wLjIxNTgtMC4yMzM3LTAu'
    b'MzIzNi0wLjEyNTkgMC4wNTM5LTAuMDcyIDAuMjA2Ny0wLjEzNDkgMC4zMjM2LTAuMTA3OS0w'
    b'LjA0NS0wLjI1MTctMC4zMTQ3LTAuMjUxNy0wLjQyMjVsMC44OTktMC4wMzZjOWUtMyAwLjA2'
    b'MjkgMCAwLjE0MzgtMC4wMzYgMC4xOTc4em0wLjU1NzQgMC4zNjg2Yy0wLjExNjkgMC4yNDI3'
    b'LTAuMzIzNiAwLjUzMDQtMC42NDczIDAuNTMwNCAwLTAuMzY4NiAwLjI2MDctMC41MzA0IDAu'
    b'NjQ3My0wLjUzMDR6IiBmaWxsPSIjZmZmNTAwIi8+CiAgPC9nPgogPC9nPgo8L3N2Zz4K', 'RU_PRI')

RU_PRI = b64_RU_PRI
index.append("RU_PRI")
index.append("Russia Primorskiy kray")
catalog["RU_PRI"] = RU_PRI
catalog["Russia Primorskiy kray"] = RU_PRI
country["Russia Primorskiy kray"] = ('RU_PRI', '', 1)
lookup["RU_PRI"] = ('RU_PRI', '', 'Russia Primorskiy kray', 1)
lookup["Primorsky"] = ('RU_PRI', '', 'Russia Primorskiy kray', 1)
lookup["Russia Primorskiy kray"] = ('RU_PRI', '', 'Russia Primorskiy kray', 1)
details["RU_PRI"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":"Primorsky"}
regional["RU_PRI"] = ('RU_PRI', 'Russia Primorskiy kray', 1)
regional["Russia Primorskiy kray"] = ('RU_PRI', 'Russia Primorskiy kray', 1)
#----------------------------------------------------------------------
b64_RU_PSK = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjcyMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1Bza292X09ibGFzdC5zdmcucG5nIgogICB4bWxuczpp'
    b'bmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIK'
    b'ICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFRE'
    b'L3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5'
    b'OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxu'
    b'czpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJk'
    b'ZWZzMTI3MjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcx'
    b'MjcyNCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9'
    b'IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'Y2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXll'
    b'ciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMjcyOCI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQXEKemts'
    b'RVFWUjQydTE5ZDRBVjFmWC81MDU5ODNyZDk3WXZXK2hGcENzV0VCQmI3Q1dnTWJFa3RwaG9Z'
    b'b3NsbHRpaXhpVEd4SXFLaW1CUQpGQkZGUkZHNjlGMldCYmIzZmIzWGVUUDM5OGNpb1NwK2Yr'
    b'd3VvT2ZQbVR0M1pzNjU5NVRQUGZkY1FpbkY0UkVGM3RzVitkUFg3b1p3CnhxSmg3eGhqWDlP'
    b'UitLZytpaU5LNDVzWExYajBWb2xuTTdKaU5VaithRUtuRVRROGQ5REdsYzN1UVFVT25tVytv'
    b'OE9HcnFCZUs3S0UKMkF6U29kcW9sTHBEc1Z5THdSdEpBUEJIa3dQemJYdnVWcmQ0S3ZKc0Fz'
    b'Y2U2dkY0V203MWhRZm0yL2U3bnBLejhWVEdadEFHWWttQgpZeXRidlZjOE5iZGp3UFFqeXpI'
    b'bU1Oc3RhNDZQZWJQK2lvOWEyMkx5OWNNdDI2OHB2M09zWGVJWUhHbGFieHI1Nkt2dmlqekhj'
    b'Nnc3CkZMTVp0SWVTWDVzL1l0RkozeTAvQUJ6SGhPSXA2NkhsRjAvTG5jR295NnhQWmJJRWFQ'
    b'T0ZCK1RaOW01ZzBtbUNzZVIzdkVJbjhnUTQKc0kyRzU2d0diVmNveHJNc3BYajYxWGM2U2lj'
    b'ZGNZNTl2d3cydTFObnptODZjMzVUcFRkMTVXQnp6VFVWRDV5VTg4QktUeUNsb0FkSQpNZWUv'
    b'M3N6ODVZMFBCWTZ4R2JWZG9aZzdGRXVrNVFQbEY0d2x6VHJOOTNhWWxyTk9rODRkalBtamlZ'
    b'T3pnQ0RmYWt6TFNpaVJFbm5XCnBCVUoyYWVCeTZ6dkRNYSs0eFZaVlRWb05VMmVjQ0NhM0h0'
    b'a3VFTXhkeWptTUdwbFZiM3QyZGNXazRIZ3hTUE9NZTQ3N3JWRzVjZlcKZW1kVmhSUkt6eWpX'
    b'UFhtcXE4SWlQTDg1OFBnNmJ6U2pQakxSaVo2aFdNR0p6MVJWTmo3MjR1K3Z2blJrc1lNUUlp'
    b'dnFucnZKakZ6WApHUkE0YmxpeE0zNkFhQStrU0NKZDdMQ1l0SWZrblliblBPRTR5ekF1czM1'
    b'bnU3L0FidHlmUnl6RE1DU2V5dWcwd3NHWnlEQjVGcjNJCnNaMmhlSHN3bW04MVdQV1N5TE02'
    b'VVI5T3B1ZXRxSHpqd3lWZmFrZXE5dnllWU5mQlJSaElLVSt2OS8xemt6K1ZwWU50NHVPbk9x'
    b'ZVYKNkYvZkZqcjMvZWF1ZUJZOVQ2bUM0WE5Tc1pXUHo1N2dFZ2FXRkE0WlBGRERzUWFOWU5K'
    b'SllFaXAwMHdJNDQ4bWJBYnQ5OWh2Q2dJUwppQ1VZUW13R0xjdVEvU2U5cXZvaVNidFJ5eklr'
    b'RUUyNnc3R0tQT3VCL1F6SXMxVTFlMGFWNVJGeTRDdW9ONUpRS1RWcHhVRUZ0bFp2CkpKck0x'
    b'TFQ1M2x1MHVDdVdiWTVrcWpMR1JNazVPUERKWHBpRmZVd2FmVXYvczFvQU5IcTQ5YXMwREVh'
    b'bzdmT2Z1TU5oMUxZSG92bFcKQTRDdVlNeGgwaDBvbUQzVTVBa1p0YUxMckZjcDlVZVRLcVVB'
    b'Y295NlBmeGtHY1pwMWltcXVyTTlJQ3VLdzZpbGxCN0licEhuaW5QTQpWUzN1NGNYNzZ4NUNT'
    b'STVKQnlBWVQ0WGk2VUtIMFJ0TlBqTnI3a0xUcVREb1llaHhQcEh2OEVnUHBVaWZXT2VOWk5T'
    b'dW13YmV1cXp6CjNaM2hYcE1wMTFWNzMxRG0zbCtjbDFXcEp4ekx0eHEvdTcyY1ZUWTNkUmts'
    b'TVpHVzgyMUdoMUhMSENDYmVGcnVDRVRDOFhSWnJ0V2kKMDdSNHd5YXRhRHFZaWZWR0VzbU03'
    b'QTNIaDVlNDl2aFFubkNjZGp2cmdGRXJTQUpmMWVLNy83bFhGMHVqVlpPcmQ5aEN2amVvMk94'
    b'TwozYjJpYTFsem5DR1lNY2o4ME1rNUFrc2VYdTE1OUJUbkxaLzNxZ2dCRk5RdWVlcktxWmRP'
    b'SEpaVlZVOG9idEtLaDdKUGxOSU5kWjJsCkxvdk5JTW1LMmhXTU5icURCa2xRVlNvS25KeFZ1'
    b'dDBRU2VBTDdhWTlsakl0WnhzOW9RUERnejFtTlpyS2RBYWplZzFmN0RCTEFyK1gKUXFadGdk'
    b'aHJIeTc1WUVQdHRzSXpJT3A2alNma01PUENaYzN4dTc3dTJ1SkpDU3k1ZW9qNTRZazVEb21i'
    b'c2FpdGwwVUlZRkR0d3JzdQptenJqOUZFTVF5TEpkREl0NnpTQ2ZsOUJ5bGxsUzZPN0xOZGkx'
    b'VXQ3cGt1N1B6cW8wQjVKcEUxYURRV05KVE4yby9aQTk3V3F4VE9pCjJNbnZHd1VHWThtTW91'
    b'cEVYcThSMnZ3UnJjRFBYdlRGOXJvR3U4T3UxZXJjWGU1Z1BMblZMOWVhaDJZdEJiM01FSEw0'
    b'b2IxS01hY20KOU1BcVQwdEV0bWpZdThiYVYzY2tGdFpGMGV2a3F2L2lzdjZHbTJaY1ZPWXc3'
    b'cWNhRlpXMmVFUCthTkpoMHVaYURIdkg0NTV3M0JkSgpEQ3F3ZDRYaXVSWjlNSjRDWU5sWFow'
    b'YVNhWjVqdDdkNFR5ek5QZEQvQ01aVHFZeWNZOUl2M3JUcmQ2OHNhaWsvRTZrb1VqRVlIV0Q1'
    b'CnZ2SVpmb0E3UXdnMEhNTjkrMmNxeFdGTC93aFRWOW5rNTBLZUx4OSs4WVFjemNoaFF3YjJy'
    b'ekRwTklGd29xRnU1NmhoZzYxNmFWUjUKSHNIdXoxTlY2bzBrS0tqSXNlbXNrcElWbllZUEox'
    b'SVduVVpSRC9JRGdXaWkxR25aM05BeHROZ3BjR3c0a1VyTFNyZkJNK2xFazFaOApiMVhWSTI5'
    b'KzFGSnhQZ2lCWklSazdGdTM3OWhUcFB0YVBCWHVlbDI0VlNScVVtRlRvdkcyUWR5ak4xN2hE'
    b'c1h5clFheTd6eWlsSFlFClk2M2UwSmlLZ21neXJhaDBiOGlOVW5namNiMUcwSXE4UDVvRXBS'
    b'M0JtS3lxeFhhVFNTc1NRaEpwZVVOajE5c0xQdjZrVFhHWFQ4SlIKUTk4L0MvZDJaNjRjdk51'
    b'ZGVXQ2w1OUZUbkgzLytZU0JxeUx1cW9oL2UySDI5cS9LUDExenpWa1RFcG1zVnVCbFJXRVpF'
    b'ay9MeWJSTQpBYnRlZXZuOXo5WnMybnJMcFdkbFZlcU54QjFHM1I0ZGsyUFNoZU9wemtUS3JO'
    b'T0lQTGR3emRabi92dVpvRE1XR25nRzhLVnBkWVJFCmlzZWhYSHRVQlYvL2w2Q2lHNTNwL2FE'
    b'aU1DbW5ZZm12aHR0L1ArTm5OcjBta2tncnFxb1ZlVW5nNjl6aHY4NmFPOWR0dUozNTFGQXkK'
    b'K3VjenJzcXpXd0FrMG5Jc2xWRXBKU0JHclNnSm5DZVMrT2ZjUmJPcmZCMGxwK0dvcDRPTDhG'
    b'RG96RU9yUFh2UW1hTldoQUFZZjh1WQp4UFloRHUyUXdRT3RKbU9ueDFlOWM5Y21kNnJHT1FH'
    b'aXRMVmlvWUZYMzZ2T3NwYVNVeWVkVVpDYnB4RTRocEJrSmx2ckNYKzg3T3VWCjJ4dlg2a2ZL'
    b'bG53Y0M4VGhlQ1RWVnJUT1ZyUk9WZWpxUnFRN2ljNEMyeVNVRVFCdzErK3NhOVZKd2xDYllk'
    b'Z2c5ZXZQWDEyYjV0SloKUWtGVzFQbFhvY3puR29IQ0ljZlF6eDVMNk13Um9Hem1ENkhYSHBq'
    b'bTFPajBXVVZkOEhYMWhXZWRLdkFjelNRM2JkelNsTlpkRVpzSgpoam0yeHVzeGhzNzhmOUxv'
    b'K25lLytybXVOcURFVXZLNDRlV0tvbWJrcktRUkFOVHQzTVhSekFsZmxNZEx4aDFiSXZ6K0VU'
    b'ZlNxVmx5ClNjbVNTMHFHT3pSdmJROE5tbFg3OEdyUHd4TnpyQnIyR0ZPdjJmU2pZMlZaTkVx'
    b'U05HNTRPUUNXWmFSdllaMnk4akpDbFVIWnhtUE8KYWh5dTBqaWpXUGZObFdXdm41WHYwbkV2'
    b'VndZSHo2cDdlcjB2dGRjeTN0RlArVTFmamkrejZBekcwc0tjZzZnamxpM0l6Um52eUI2MwpJ'
    b'anlxMEpuL0cvM2M1ZFBvOUFBQzRaaWlxQUJpaVZSM3lMOWhXd01Bd290R2tUbHVSZGhydVRN'
    b'OVI2Y1VFTUtLQUQ3OGJFMG1IdG00CmZyUFA0L0dIWWwrczI2N3JYcWxnV0lFOTVpUjRyS016'
    b'UDRUMFBBT1dTNlF5NlhoazArYXE4bjZGV212T3BwckdvbHhiT3BNRkFFcFUKbFI1WEl1eXIz'
    b'Smtlb295aUVKYjdldlhXQzA4WjVIRG1wam5kMXAwdGRvdUJFREswb251RmlMYkVDTVRqUW9S'
    b'OW5qdlRFMVRaa1o0Qwo2RFNDVnVTSVpKQllidnlJOG4wQUFVVlo1eGRnTzM3ZG1XT2R0cmJI'
    b'WW9tVTNXcjB4MlhDN2pOMk0zSTJsa2g5c2JXMVZpdzlUdHdaCnE0Wjk3QlJuelRVVjF3KzM3'
    b'QXhremwvUWN1Nzd6V05jMHM1ckt4NDd4V2tVamtuQlZ4UTZ0bXlwMW9oQ1ZtTnViZXY4N3ll'
    b'cnZZSEkKT3dzKzl3Y2pyNzI3VkN2eWtrNmYxWmlPSzQrMDBNRC9aMnJlMnBtbFp4VHJsalhI'
    b'eDc1VmYvUG5uWmNQTkZWZlUzSDljQXREanJGZgpyUW95TElNTjJ4cjZGYmp5YlRxVFhuSllq'
    b'V1lOckVaTlNaNk5RR2tKSlBwOC9iWkhQTkp1ZEtaN3lmZXQ3YUYzZDRhN2wzeVBPWFJtCnNY'
    b'aVNaODNuY2loMDZYUkdVVld5WnhEdnprRmpxanBpc0RsK1FtZU9Ya3FaaTFZT3VLYkxXSjVL'
    b'eTRUbFZGVUJRS21xVU5MdURvSmgKV2oyUlk5RkEvSWpRbVc1cWNZMTc1YU4xSUV5SEo1U1Jz'
    b'KzJlTU1leEJVNHpBVFZhTE1laUNBOTN2WER2M0pucmgxdjI1TTRjY3o5TQplY2xnTUJKQzhu'
    b'Sk1BczhWT0UxVVZWVktGVVd0ODZiZ09oNUZlTnlnTTd0SmE5N1lIUHdGdzZYVEdRQnBXVW5K'
    b'aXRjZlNXZlZ0R2c2CjNtYmhjWWJPZkdzNm1MWVlaRVdOeGxPeGVES2VTRXNpcDVHa2NEVGVR'
    b'dXpIandpUFMzUm1Ed1dKVVJBRWkwSFM2NlFjbTRHcTZoUGYKWk54MUtYZkZXVWZxRmFiV3J3'
    b'dWlhNXR0VTJMT0UzOUNaLzV2Rm84YTY1Y2N5dDM2SnZmTXlYL2YvTUpxRDFXeTI0TDg5QmQy'
    b'MWd5OQowdDMvckNPMWYwd0lOdncxOTc2dE43MTVqM0FuaWZsNytsK1A0ZHdaUzlOblF4TExY'
    b'TG93QWZXbFRkdklXRy9aaFNCRTA3VjFuTy9WCk84ZXZ1YUw2bVdqSjZZZTBpZjY2cWNuVkc4'
    b'Umg3WTZSUi9iRDdMdm1WMS95a0VGQ01JbWg3ejhlTEQrM3oyeGhOenJ6NitIV2JuZG0KN0Z2'
    b'MTNia3pWdzB4UDd6YTA2dm9URHhVdFBMUHB3d0lGb3B1amtWU0ZST0s1dGVuMXc4cnlmeHZ3'
    b'SG1XUFBmZWsvNFlQM2xrNXF4egowc0VJK24zeVRpcSsyVXJkYTh2dmcwYS9YNWNKVy9tSEtP'
    b'OFJucXBwam9OS0lYTGdzL0crbklXSENpcDZQeUcvZVBiMHBtMXRuL3lUCmpCbU11alpFNDRn'
    b'bjRRNmdxbzVZeW45TGFLUk1mUDNLc3dFZ21jYW1IZkNIb1pkUWtvY0NPMkpKREoxN3IyZmdG'
    b'YjAyM3NiVVBQajEKdGUrcENsbzZ5SWtyL3Awc21YaFV4SVhkNkV6M3pxYVhLNFB6ZDBYdUdt'
    b'dnZSWFNHUEhzN21UWWVBTVlNM24zSkU4Qlc5OW1KdFBEdwp3Ly8rK1dYMU9kWVYwOFpERWpG'
    b'MkVOeU5sS3BRQW1qencxUk1WS1lYMDJXejZXbTJqY2tvUVBGWnJUWHBIUDRUT2dNQXhhTUcz'
    b'WHJBCkxNcXhZc3J3NnFsVHAyN1pzdm1QRjIrZE5oNmdTQ2ZCOGRDWlNDb0pRVUxSUUxLNVFS'
    b'TTBqK2cxQ1E3ZTl1UU40NXNBaFAzMHk3YUsKWHNETmp3MTB4cWs3ZU0yUTh5YzAxVFNkUlNM'
    b'cXdLRUFrRWtEUUNvR2l3c1cxKzZoTm45cmlWSmMzaHRmcVdTSFZ2M2w3ZE1YNlBWZwpXSFNx'
    b'MGtyMndwL1FHZGpyMTAvWXRHUlhnYk8ybmEvSWx3RlFpbEFVOFJUeUhTQUVnMHJVNStaaFlB'
    b'bmlJYkE4VkFXU0hvcUtSMTZoCkp3NGtJT3lTN0FVOVYyMWlENW1ibDUwdHYvTDBqR3BHcHRF'
    b'QVZUam1UMTlOOFEwOCt5ZDBCak0rZWVHMzdmVlg2Qy81N2Z2bmpMQUgKdTN4eWxuT0FONmN5'
    b'cWkvV3NPQ0cxVllqTGM3RnRtb01yQUFuSU5BQmhrVW1oVHc3R1RNWVcrb1pCVDI4S0phS25i'
    b'enJ2a2VuckI1ZAprbFN6aU1ScFYxSjRjTTJweS9zLytoTTZBd0RPV0tpTzQ0S1NnVWFJWStT'
    b'VU5WdS81RlFGU2pES2lMdUcvL2JlQmY3L1hMMWoybmg4CnVCd3VNK1ZGd3ZJQWdVYUhFd2ZD'
    b'NjhNSWUrWVc1K3NQQnNka0xHVTlwRHpQM25uVG0xZHVOcGdCQW8rSHZMUysrTVhZOWU3KzUv'
    b'Y3gKd05ZbmVBcEFRUmcyMUZHcytoc3NRN3UxM3pkNVpUTnF2bG0yNUxVb3dWK2ExbC9BQ2dO'
    b'cTZnWmtGQlprdzZaMXo1MlVyNnJRQ0pBMAowSnVKUm92NnJiUndBQWwwVWdyQ0VFUjh1SFpV'
    b'KzFjTG5saGllYmtudnJwMDU0dHZYTE5GTDBISjRwa2wrYSswWGRBMDREcms5Q3BYCjJRY2Zm'
    b'UERBcXhMSG5GR3N2MnFJT1NHcm56Zkg1OVNFMTNZbXJoNWkrZk5KT1VhQlhkK1ZUQ3YwajJQ'
    b'c256VEdxdjNwSS9BVmNtcEUKM1FkM2p6Si80MDRuOUs2YmloS21oSHNYN0FCcSs0K3JDWGQ1'
    b'c3BsYWpaYU5wb1JUSjJ3Mkc5ZmJqSnYwNHRsdS82NWtmUHkwcUU0QwpwWkFETk11UjNDSVNT'
    b'OE9XUTVhc3hlbGpFUFdCTUJqZjM3dGdrek5oSFhqRTJUY3grdFpGRlkxVXhieTE1anRUci9p'
    b'THB2Yit4cWlqCklIZEdWY0dKY3J4bXlwQ0NNWjN2bmJyamp2NWNXd0gxN3I0cEdaZGMvdWRI'
    b'L2pEbnNXc2ZhVHpmN3BOV1dJWjIwcEZwYm56bWpUT3kKL1NhNmJXWjBlREdnR0lLRHZQUUJH'
    b'QmEvZTVvU0Fqa0xVVURSUUdLeWsxSm41c3pVTEtSaVI1eDlWaUdwTlFBRS9Td3BiYlNwVC9S'
    b'WApYK2JPc0JIM2xQQ3FYNTF6K2lNZmZ2bk94Ui9FS2pkTW9NMTMvRXJ0Q0t5cDNHaUJkZVRl'
    b'cU5oNDc4dnYvMmIxUWZ1NTUzWExHM2NFCjV5eUIxWVN0dTJBMW9kMkRYQ1BDUHFSaU5PUUJ5'
    b'V1dYTlpleU9WMks1Z2hIRjFzaXBiSElXbEhFS1Nlay9oNS8rT0hLN1EyRGJnVEQKSGkyejhF'
    b'QjA1c2ptemloR3B6dFJwL2lyeDhXWERpNld4NVEzT3MwcXo2TTBOM3p6NUNaRHg5cTlHMXVF'
    b'LzRHTmlvcC9MTTY1ZTI3SgpPOHYxTHkremZibE4zK2xEc1FzRVdMOGRqOTVBbnB0SE9SRmFB'
    b'd1FOMFpsUTZsSlBLZzhvOWlQdjBWU1czUERYejR1Nmc1bVpFLzFmClh2RGlQWjZMN0sxTGow'
    b'WVI5aEE2YzdwcDdYbUZOMTAzYWRYOFpRQmcxQ01VQlFDQkI2ZW05bTdabk1qWjg3cWIzaHg4'
    b'aHpyM2FkUGIKejd5bmU2ajIrc1R3UzU5K0M1SUdManZxMjZoR3hHMHppZG1FWkF3V0oxZ092'
    b'amI2NVBtVi9XcGVPUEpPbU5ieUloNjRiMEUvSll0RQpHQzRYN3B6V3NIam9uUmZzdklFa0kw'
    b'ZVhDSHRvWjlOV3Q2UFp6WTBkQWw4SUFLSngyRXdBOE5KWEJjSENmV3E3Vk9YLzZtOGY1MjVw'
    b'CkVOYnMwR3l0WTFTOUE1S3hvZkR5cm9FemljbHh6Yy9RTHc5bmpzYXdjaElQQVJGNjBuQ3dM'
    b'REpweUJuRXcyaDBDenB2SmRRakQrcUcKWGVQK29YL3BvbGZIMTNuNVlCZDhiYlNzTVB2Q2Vh'
    b'dCtIN2hLNzlseVZJaXdSNnNDZnpuOFAxTSt2TG5kUzdvcjBySHM3dmppNDg3UgorMVdpazgz'
    b'RlQ0ZnZPdWZCdktXVmhvQlExSDB4TXZwYUFDV1pUVU5LTWJBRW9oWXpwa05yaEVaSEFPak04'
    b'SGRRVno5aXl5TW5sQ1NECk9lTjd5RjFVREs1UGg3NTgxdGYzUDdXOFZMSVNob0dreGUvSDFM'
    b'OXB1MUVLN09oTEViWkc1UnVYZG94L3UyRlpjN3piRmo0L0pYZmUKanZEZ1diVXZWd2FQekRZ'
    b'dXdyaUxmN1o2cDY2N091U0pBd0ZneVNadFpjN01BOXQ2ODg5d3ozam5jV0VXUkQycFhRVUFE'
    b'SU5NOGpUTApwbjI4SkI2bWJ4TjZKVDNKcE5EVlNJTmU4THUrNkZGV2Vzb3VmTWI1MzhzWFhi'
    b'QzVUaE9QVW9PTm5GZ1V2U2wrSjdMcEhuMXZINk16Cmx2YU5RZEh1ODh1L1BnL3hKRTdvRHdC'
    b'ZjFlYkl6Z0VIZjBDamx6WDZockgzN3g0QXFlaWtIYmMvY21QOWZxMWlJUWdhQk9KZ2twUVEK'
    b'd25LUUNCWEtmdUI2UlRhdDZkeWFFOTdvNU54Nk5pVXdtU3hsWTRxdVRTbnNjRTJsMXFLRHNW'
    b'TllOZkNSUzJwT2ZTdHovNFRCY1kyVwpYRGUwNGJOMXoxY052UDI0UldjdUxlSHNzZVU1V3N2'
    b'ckgzVlJpdXN1QUFBVjVIQ0FhVXZMc2l2dy9ETTMxd3I3RmlHTUJwQk8wQ3dsCk5mVVlZSVhE'
    b'Qm8yV2hIejBuSnpWc1JwYlY4NGsxVloweUU0elNXUGJ5bjdKZGYybDVxSG1sZ3NtZGxVVXFB'
    b'S1Bya1lhOFVQUXdPSWsKbkI2cksxK1lVek5nUTN6RXp1SmZxdnI5Yy9nRHhWUC9zbTNWSzlM'
    b'ODBtR0VZY2xabHRWVjZFRVI5bkh1ektoTS9mMUR3Z1hxUDA0bwovSjh5WExoT2YzbnJiTmxl'
    b'OFIwUFZteDc5bThuL2Zlc0U2TUhrd0lJajlrZjQ2cXp3Yk5JeGVGdG82NFN3bXZnNmNLcUJ0'
    b'MmZLeSt0CkdmU0h2WEZxWThmcTB0UTMvYlZOSjFpYUx4M2o3cGRIQTUxZ1dCQUNWWVhGQ1ZC'
    b'a1VxQUF5NEhqMGRWQWpYYVNpR0hCTnR1YzJoTTMKV21ZbThrYnRZNTg2ZDZ3YmVIbHBvWnFN'
    b'MHBWMXhpdllGVDBYTFBaOTNabkoxYmRjbkxmQ3BGT3ZtUFkvdVBTazUzKzJmdWdoa2Y3OApx'
    b'cGR1YzczOCswdFRCNzI3WVR2bUxzVjVFOUhmUWkxTzBycURLbG5rbGhKVlJUcEJMUzZ5dlVQ'
    b'OHh4ZmxLWVhYY0ZrVEZ5KzNCYzhkCkZiWUpWS01Id3lEb29Wb0RFU1NrNGpCWVFGVWtvcEQw'
    b'Q1B1ZzBVSlJrSXhSaTVOa1phUVRrUFNJQmxIVEtUeTdZZVFhT3MxVGVuNzMKTVFiRytpWGZu'
    b'SG1uWFZCRkxSWnVNTXlNZmdTRHJjOFVhVS92YlBwaXlMK0dOSjc5N0lXdGV3ZWd2ejl4eFkz'
    b'TmF5SzVFdzRPNjNSVwpYM0RaL3NjYlpHU2taUmkwMkxJTGo5MkVkQlNxUWtJZXFtVEJDOUJi'
    b'UUZWb3RJU3FvT24wckd1ckE1MDBFWUU1aDJnTjZLeW5IUkVVCjlDY3NCemtGV1FERHdOMUVH'
    b'WWFrNG1CWUNCcm9MVWhHWWJSQmF5QnlCdGswVkFYZVZtck5KU1BFek53aDZ6cmQ2MTViUDZz'
    b'MlZwaFEKcFVrRk80cHoxSFFDREVGblZEd3crYW9QYkdHUDVzNDBLY1ZBNjk1WExqOHB1TGJw'
    b'cVJlRFR4MjRTRlJRLzg2Y1g2NHVjZTRmMGl4WgpnOXBXbkhZaW5GWUlQSGdMTWlsME5rRFFJ'
    b'SytDdUp0b05BQnJMZ0FJREtsdEFYV0Q1VUFJR2lxcHFpQ25tSWhhZU5zb0NKSXhtb2lnCllB'
    b'QWhRQ3BPQlJGeW1yQThlQUVBZ2g1b0RRQmd0RUpPZzJFUnlXTE9SN2h3SW00WTFXYTB0OGRD'
    b'VkpGQkZRS0FNUERFOVREMDRBYisKb3lKM3BqbzkrSnZxZloxQkdjL09xTDFEdmRYVS9PVSs4'
    b'eS9tK2JWbGxsV1RlZmJkbkc2VmU4K0xMa29oWjlIUWprbWowZWJHU2VXbwozMHlEYnNSQ01O'
    b'cFFQSVJra29qNFFTbDBKdUlvSklQNm82WUp2SUNpUWNUYlJsVUZybjdFNmtJOGpJZ1BFUjhF'
    b'RGNrdEpRQW80Q3dtCk9nc1J0UkExeUtUaGJhTkdDOVFzQ0lPUUY0Skk1RFEwQ241K0J1YXZn'
    b'Q2RCQ0FOSlQwd080dStrQkFpNmFXdTZaeXNxSG55eDZhRG8KekdVZnRmNXJjeUNlVmE4Wlpw'
    b'bC9mdUcwRXYzQ3V1Z1JXV3dLQ2ZtYjN2eGcybWpaL08ycER0MjJmOUxnOE1uQzhuVFZTazNu'
    b'VnNaVAppM2hRYWxtdERhVUtoajBlajJmN1dhdi90V2lzVlBvYkliWms3bWU0L2tLVTVLSThI'
    b'eDIxbEtySUxTV0pDRTNGb1RNUUpZdG9BSUlFCms0UDQybWtzUzlxOW1EQ09jQUtDWGNncEl0'
    b'a01qUVpoenlkNkM3RTRpY0dLUUFjNjZtallDemtGbGlXcEdMSlo2TTBRdGNUWFRqMHQKMEpt'
    b'SXhRbU5IcGtVSWo0YTZNQkpJOG5hV21RVm1FVW9XVmh5aUp6R25Fclg4M2dvcTNYMHBTTHRo'
    b'ZHdaYWk2bzUwNVlzR0huYlQvegpVUlZaR1ZRRko0QUM0OHFTRXdkdkFqWmxaSFIwWXYxT1hq'
    b'dnk0NGtUeHM5cHFsemMvTmd2YnI5dWEzMzdPLy9SUDNwTkxCR2tpa2dVCkdhb0trd1ArVGhy'
    b'b0JDK0NFeEgwVUFEMmZNSUxrUFRramM4aENpQU1sQ3hjL1VnMFFJTnVjQUtzTGdTN2FGYUcx'
    b'a0NNZG5BQ2tReGcKV2NneWVCRUU4TFJRWGlSR0cxRVZhclJCVG9IWFFOSWp0NVJrTTBoRWNN'
    b'bGt2UDBwTERya08rR1A0ckhGWmZOd2M3SndVSS9Pd3FPbQpLckMvYlZ6SHY3NjY2V09PUmNR'
    b'UEpRdHpEanpOMUZGSVVnbkVBdFNhUjFnT3p5OGNNT08ydFN5NzI1TUtwOVRWNjllWCtzODFK'
    b'MUtxCmlxSkJSTlFpN0lYRkJWOGJaUmhpY1lGaEVRK0JZU0Zxb1dUaGpXQjFKU2FmaUVnN1ZX'
    b'U1VEQ2UxRzZta1EyNFo2YXlueVcrWEZJc0cKa1hRU0dpMDRBUXdEbGtkWEk4MHBKckVnRE44'
    b'ZUNCUnlRMUhBOGRBWndZdUlCcnNqRlBySGQ4emI5V2UyOG9OOHBlZUI2L0V5TmtkTgo3b3l0'
    b'WUwzbWp2ditXLzNFRlUxYUk2SUJSSHh3RkpLd0Q3d0ljdzZSVS9CNEtOSDAyeU8vckVxRENY'
    b'WFhONjlQR1pYMnhlQW9KSUlHCm5RMDBGb1RPU093RnhOK0I5bDFVYXlLOENNbUFwbXBxc09D'
    b'RHRhU2huVTRhU0ZKeEFKRFRLRHVCUlAySUJwRlRUTUllS21kZ2NoQ3QKRWRwdk0wQmpRYkFj'
    b'V0I0TVFUcE9ZMEhvTGNUYlNsMGxSR2NHQUc4TDVVVFM3UzdZQzhtVDEwVW56clA3K2w5eTFD'
    b'MDI5VFNwT3R1cgo4aC9lV1duaCtHNFBuaW9LOUdid0loZ09MQTlYQ1FHN2V5OTFQRVBidzls'
    b'dnZsNlF5M3dTQzFHTEU3eUloa29hQzBKbkFpZWlkUWYxCnQxT2RoYkFjakRZUUJvb01xc0po'
    b'd2FWVGlEVVh1YVhFV1VLb2lzNTY2dStrT2dPeUdYQWk3UG5FdUc4SXA3ZEFNc0JSUUxKWm1C'
    b'ekUKVVVpTU5oUU1JS2s0dkMwMGswTElCMzhITmRvUURkQjRHRnhTK2ZQQXVmcXVqWDBwd3I2'
    b'cU94TXNQUDNPWGJlK3Y4N01jZUJFRXVpZwpEQU5CUkRZRE5RdEtRVmtUQUpYU1dGck5aTlZ3'
    b'b0hOYjV3Q2psUmlzcEtPZXFnb0VDWGxsSkJGRklnSmJIcXd1bUhNZ3A2RXFvQlJHCkJ3RXdi'
    b'aWdJQTcwWklROXRycVlNaTM3RFNOaEgyMnVwbWoxa0NFY3AzRTNVMjBaYmFxaXFvbVU3allX'
    b'cG80Z0FrSFJ3OVNNTUMyY0oKa2RQUW1jbk0wd0tuZWYvUjk3T3dUK3JPZEpaZWNrdlY3ZStz'
    b'dGR2emtWTk1RajVFZzlEb2tFbUQ1UUExRFlBaHhHbGd5K3pDV1JmZgpWSnduV0hNUkMxSUNt'
    b'QndvSGt3SUE0TUZPWVhFMTQ1NENNa1lZaUV3TE1wR0VJMFdad3hIN1NicWIwYzBpSFFDamtL'
    b'U1gwRTREbGtaCitSVWtwNWdjQ3AwbEJMWjgwcTJ1VzNkUVJ3RVJSS1RpeU1vdzJvamV2SHRC'
    b'b3R0U3BqUFl0bUluRzJqcUJSRWVqWFZuUE9VWDNsMGoKRit1ZUdtQkw2c3drazRLL0hRWWJV'
    b'Z21vMmY4dGhjc0tkdTNZTnRCZUZlaUVvNGpZQ3hCMG8zNHp0ZVRDNmlKR0IzZ04wWm1oS2do'
    b'NQphTkJOVklWYVhZUm1vY2pRbWNHTDBPaUlSb2RvQUhvTDdNVmtaWlYrMStxY0RIRlNSaHlk'
    b'dDNMaWlQMnR2a1pDeUlPQ0FTVHNCY1BBCjdDUWhEMDBub0RXQlVxSlNwQk9JK0tnMWo5QTBy'
    b'cnpZOUJndkhVVzJzSmZyem5TVVhYYkw4bk1ZZ1FRNnFhQ0JMUitaRktnQ09WN2IKN1VLckZG'
    b'M1I3R2R2M1ZMZ1NPbE11L0ZvYnlzRmdkRkNHcXRvS2dhREZiNDJLcWNSOFVObmhLZ2gzWDZw'
    b'cXg4UkpNaHBoRHhVVG1Oegp1L1hwUmRQK3Z1TE9hTVVYd3kvOHpGWTR1V25IdW1GbCs4aXZy'
    b'aFZ5RmlEUVdkQ3dsUW9hUkFLMHM1N2E4b2lvaFpwRklnS1dBOHVpCllBQWhCQnlQZXk3c0xH'
    b'dDU1K2h5WjNwNVoxUFZvTHNlK0xSL2ZnWGhCUVE2SVdnZ0djQ1RwdVVyVjJkVjJocVNJNUdR'
    b'bytMQytsWVMKVEFJVUhBK3RBUllYVWtrQTBCcEJLU1E5RWJYSUx5ZXFDcTBaN2dCWUZza29U'
    b'Y2FRak1LWVMvNit3RExyNnltVHJwb3o1YUxiMTZ6NgpYRmsvcEJTUGNpU3g4Q3ZNWFl3WDNr'
    b'ZTdCd0FLbmZqM2Z3R0E1NkUzdzlkR09SNlpGRlFWa29FNENvbWNBY2REWjBhd0M1a2tNaGw4'
    b'CnRNSE0rK3FQQ2tXNkI1M3A3WjFOZ3JRNE5pMFUzU1ZRTUF6VzFrdFBmajFxbGZIcVlZdldu'
    b'bmJ5aEZ3alo1VnNPcDIwcG9xNThEUzAKMXRDQ0FZUVR3UE5FMENDM2xMaWJxRFdQeE1OVVp5'
    b'YVNBWElhTFc0MHRXTlVLVkp4aUE3OGJYR1I0RHgzd3FXM251Rnd0TFhVM3ZYQwptN1BPZnNX'
    b'UlNwa0t5Sit1SUZSQjJFOXR1V1JaSlh4aFhIVU9KbzNHL0dXNDVBdzRTMGdpQWw0RGhxV0tq'
    b'SzRHcWgxT29uN0tza1RTClE2TkRJZ0tMRGFjTkRDYzNEKzRGRVg0L3dMYlpuZnJscDIwUHIv'
    b'RjZFdG1aZzgzenp5K2FYS3gvY0pYbnBIenQ0b1lqbE0xOUNBcWIKaHF4OGE2a3M2TDVzc04z'
    b'WmVIZFYrZTh5eG9JT1BpZTI0Wk9wRTBaRjAzUkgxVmQzbkx0VTRDRVpDTWREeVJLTkRwSWVn'
    b'Z1lhSFJFMApjTGRBb3lXQkxwb2daTTZuT1BkazZQVklzTUxzbFJQUzR0Z1JFMmNNNlYrV0NI'
    b'VDg0dVZQRFZ6ckhXTTJwK0l3R0lpa0I4dUNGNG5lCkRET2xZMDRrc3orR0w0U3FPcmhzc0p2'
    b'Z2JxRVdKK0VFSXVtaE54TmZCODB0SmQwNlNjbUNGMEVJMUNTc3RPSHJUVWpubmRCbnM3RHYK'
    b'ZHpZSjBwcVN1MnFhSTFsT0Z5M2VmWHlTYXJDLzVpK1ZYcHg5N2N5WmF0cXRrNkNxWUZna1k0'
    b'ajRxZDVNa2xGSUJrVDg0QVVVOUNmZAowTnFUYjBGZ2tQVFJuWEgreVFYRDcvMzdoeUxINkFU'
    b'U1ZML3IvamMvOWhSUDBkYlhDMGFTdzBOUmtFbkJhSU1PeU1ySUtTS1VZbklSCkxScEdrbEY4'
    b'c0E2U2h1VG5BNEM3a2VhV2syd0dyaElTRGNDY0F3QU1nMndHTEFlV2d5L01SY3FtOTQwdERL'
    b'U1VQNjF3RDVwViszSmwKY0lCVitQRENva1VYRmEvdlNnNTR0ZlpQSzl6UlRPOVZ6NlA5Sndi'
    b'THp0NGp2MjVLMnNxZWk1UzkvdjdIbERGL3VOS1lUc0hkUkNVOQppZ2FSc0E4dE5WVE93TmRH'
    b'V1E2eEVEZ2VsTUhPRHJ2V25QdkgrU1ByclF0L2ZmZHIrV2F1eU1McHVld2ZudnpuMm9wTEZh'
    b'MGxMT1JQCi9aTXpKQU4wZHhDWlRvSmxrVTRBZ002RWRCVHhLUEdrelg5WlVLRFJRMUZSTkpq'
    b'd0FnZ0xBSUlHNlRoQ0hnQlFGTVJDb0JRM251NisKMEgyUHZlN0Rua2grL01HMjhHaWpqTG5n'
    b'cjNISCtFMkxscnJ6eHcyS09FdUlwNVVhTE1UcWdzVkpDSVBpb1VTamhlekY4aXJMazI5cQo3'
    b'M2g2bVU1bkxQYTUrNWVXYUhqQ004em1MVnR1ZVBqWnVrbDM3dTR3bWQ2VmMzNGk5YUpKRDhJ'
    b'Z0hnSW5Rc2tpSHFZR0s4bXJJR0V2Cm5sbmJmMTdEYUwxWmQvMXpILzd5VlBlUUluQUU4VERO'
    b'cG9rZ0lSR0Z4WVYwRXFJVzhSQ01OaENDVnkvZUVKQTMzZnplUjB1R3Z2S2oKUUdkKzRQQVQx'
    b'NWI5WW1mZTZRSVB3c0JrSTV5QTFwMVVWUkVMZ25ZdkNWTnNiaDkxN1Yyejg1M09NcWR1NUtC'
    b'K0RqMXJFTEIwK1ZkUAp6ditpOWVRYjlvQXhrWXB6SExxMFRpS0JUZ29LclJHOGlFUVVPaE9o'
    b'S2dLZHNPU2dQbFhvUGVYdVp2dTB4ZUwxTjd4WTBPUW1CTERuCkU0TU5HaDBNVmxBS0pRdU9o'
    b'emtISVE4OHJaUVRVT3hTQjlsOFB5SjA1Z2VDNDRYOTJXMnp2elN6TEFnRFhvQTluM0E4R0E2'
    b'OEJnQ1MKSEp2STZNZWRlS0paUzBTT2VEdGE3M24ycFZQdi90YzE2N0cwK09LME1lOS9YZkVh'
    b'MnJCaHhuTVZaaWVSOU9oc3BLa1lXQjY4Q0RrRAprd08zekIyNnJjc01RTTBkNE81L2VjM1pj'
    b'LzYxcXIvT0RKWUR3OERmUWVNUlVCV2loSkFIeVJoMFpuQThTVVFwSVJoZjVPRUNQWFdVCjBE'
    b'RitFR3pVbDFmejJqaFQ5ZHRYYi9TMlVsc3V5V2JCODBqRzRXNml4VVBKNzk2Y3BPcE9JTFor'
    b'N1pGVVoweHA0SEppaGFNT25reVcKVFlNVnJtK2Y4WmZKMnlRRDNJM1VWVW9rUFh6dDFHQWxt'
    b'UVJPblRlenF2ZzMwUDJ2WnFuR3YvT3F5TjJDSEI1YVJxNmQ1R0VZWkZMdwpORk5YS2NuS1VE'
    b'TFFtdUR2Z01FS1hzVEp6NSszZnRoamZXa0wrN3J1ekNISVlPOFllMGQ1MTNucEJNdzVKSk9H'
    b'emdnS21IVUFpRWFMCnpWbmJwb0pyQUVBQ25OK2psZ0VZMkxpa2g2U0QyVW15R1lROHNPZVRp'
    b'QStaRkIwc2JLL1M3Vk56Tm1VYjhJcjJqUUZMZnZWVzRueXQKT0lzbzZSbW54ZkxLU2FDVEd1'
    b'MkVFUkgyd21oRDJFZnQrZVRpNHZYckV5Rm96VDhpZE9id1NhR0VZU0ZJRUVRRVBRaDdFWFJE'
    b'TXNEZgpnWW5telZCK3dBSm5XOW9WRDlQZHNJc2U4UkNWTTlDWm9EZVRhMGR2Wjl4MSt6dk1r'
    b'bkhIR1MvR2JDTmUyVGowcmtXalBxL1VaMlZ3CkFoRTBBSUhKRGtMZ0tDRFpERzQrczZ1czhh'
    b'MitCTmlPNWpPYmFtTDlSQWtzQzFFSGV6NlNNY3F3U0NmQXNKaGMzb0ZneCtGM3RUTloKWXJR'
    b'UmhnUExRbFdnTXhOZUFNdURFL0hLMm5MVjZEeW9KbEFLUjJ3MC83eHo2bE8zZi9XelhXN0Ju'
    b'QU9xSWhVSHBlQjRVQlZLRnBLSQo0VkoxM3lqU283OHFzRmV4RVlKZ0YzUm1FQ0MvbkJBR0FK'
    b'bzk3Qi9XWElvVGlnNi9LeE1Ub1JTRUlCV25jZ3FPUXBKT0lwUEV5MnRjCjcrVTlDOGx3cUFj'
    b'VHhTY0QyRDdzbnFuTEJwOGl2Ly82MVp2MFpxZ3FPQTZaTkRRNnhNTW8xN2IyOWl6c2paMU5S'
    b'NEtLdVNhV2d5MGYKSEk5QUZ5VU1FaEVrWTdqbncrSDFJLzc0QTdDZ1VPTzVoWnZsTkJnR3Ju'
    b'NUVheUpaR1ZFLzFabndYdU1ZeFpoN1dPT3A5UHozKzcxdworN3hCaElHcVFGRWdpRWhFSVVv'
    b'b3RrU1JqUGJTTER5R3FnSVg3WGpsb1hPMkJOM1FXOER4c0JlUXJBeXRFY0VJVm1jbi9ZQzZU'
    b'OW4wCjlMWUhmdmViRHBhSHZ4M21IQWdTR0JhU25pemVxTitTYytVUHdnVy9pb3hYYVEzTFFa'
    b'RVJDOEZrQjRCQ1N4S3Q0ZStZeWozdXpoeUYKWk94WWZlK0FPV1U1c3NFR1hnU2w0RVdBSXV6'
    b'RkU0djd0WlhQT0d3Y2o0NnJ2T3ZOYTdld1BPSWgyUEtnZHBzeENsN0VmemFPVE9mOApzRFdI'
    b'WnZPcE5VME15MEZWWUxJakZvUWlJNWdVSUdoK1FtZjJpc1ZEelRld2ovL2lKRy9JdlZ1bmR5'
    b'T1IyU3dnWXBIL3RPNGRLdDlQCnFqcDh5LzF6cjFyZXJaRzBKcWdxZUFGVUJTR1l2OUh5dGUy'
    b'R0g0ei9HUXQzZEdxQjNlQ1AzZ0tXUjJkSTJHL3I4bzhKblpGVHlDVDMKdnFCemI3a2g5cnNI'
    b'ejIvaWVEaUtTUGNDTE1jRGdFYUxXK2NOM2puZ3R3ZUppNUtSazdmZk5XWFg3Y2FXNWQ5QzVw'
    b'RlRLbTlaOHF1UApDaDJLS08yT25icTFMOE9pcm92L3k5YUxramsvdkthbzF0UVMyRC9yNHVj'
    b'bisyOTB6OHh0K2ZoSGg4NVkyNzY0UmZPRUpLZ0xXMFp1CjFaMmIwQmFVK0QrL3RmUzlXNmQz'
    b'ZGs4VTdEdVlubGlZLzFqNm1ZUmp5UDVhTittYjBENzdnMSsreG5OWXUwTjhlMk5wVk5VUE5u'
    b'ZjgKZm5yN2ZwdE11Mmw3aTNEVmduTzJqbmo0c01kWmVzKzhsMXJYZlRicXhnbUQ1UU5iM2ZU'
    b'VzRKY0s1dldCQ0x0aitXNTBwaVVpV3pUcwpYV1B0cXpzU0MrdWlQU3EvU2JSdXVuYlg5Y1Ar'
    b'cE5jb0RJT0dkblFHdUNFbFdZMkliNDh6Mzl1aTRjNTNTbWFSZThPNTR3L3M2cS9GCkhTY1g2'
    b'Vk9WVTJxYms0U2dYeDVNZW15cngrbWprRlZRVnJCUDQ3VTdOVmN0dmJweDZDMkh4eHBsY3VV'
    b'Tlo1YldWL3RkclhLQnlHWFAKeUt1NWJmcEJVaHBXTlU3N2FIM3k2WngvOXdIQTFsZm96R1hG'
    b'WEtERjkrRnlxcXJJS2xCVlVKcXQyb1ZMcCtDTDlUajc1SDBhdjcxYwoveHg1UEpzNzlLQmRy'
    b'ZHRjdFdicEI2ZWJremRmQmdBdFhkaFlnOUo4N0dwQk1MSmJoTzRBUkI1bUE0cnRtYmh3ZUlH'
    b'dnFvN3YrdXorCnFjMm5EUEcyZWJ3MlUxVXFqVFZWV0xRQ3VYYllUQ2pKQTRBMkQzTHRpTkZo'
    b'SjR3ZGphWWZFenJ6M0xMS1pkWHJHMzJGTTZiajJ2TngKMFdRd0RCaUMrY3ZRNzl0bGhxWHJF'
    b'RXNBd0NVbngvS0NxdzdWMVNJNndHdjVXZDdZbDdaM2xBUFlzQjJTQ0swR3BmbTRiT3J1TnZN'
    b'LwpoMUVIQUE2emFwTGJEK2NMaDZaMmZYVC85ZUhzb0NmZndMWTZmTEFjeXplQ1VrUVRXTFVW'
    b'eGQ4R2t6UGZHRi8yM0EwM0xvZ3Ryay85CnVOQ1o3ZjJtajVIS2I1cHgycFl2VGg1VFZ2L3VV'
    b'dnptb24ycXh5Z0t0dFZqNmpoUWl1cFdUVng3U0N3bWJTc1piV2ViMjFhY1BMUVQKUUNDQzZT'
    b'ZEJ1NWVUdjNpamZuMnJkRWtrdWQwMytkV2xPK3BLcnptY0x3eXJtdXYvTWEvQ3ZXRmNmOVAw'
    b'azhJQVppM0U0SDZZUEFiUwp0eDd4Kyt2TVd3dC9FM09OWmlPZXVURDNuZ2lQaWpPYk9FRk9K'
    b'ZjV3N3hWdi9Mb2VRSVlidXJGRkdsT3lmcy85YTE2dXFBK1lSMWU3ClkrWjc3MXU4M0Qvc3V3'
    b'N3RXYmk1RWJHUVMyWEdsa0VvZVdSWmwrbXN3bHM1RmdCV2JKZCt0LzZYWFNXbnh1ZTkvTTYv'
    b'NTErMzRVMTYKZUpYUlcvVWxIaitjQlE4TlBYZmFydXJ4L1F1aTZNNzUvOWJKQ2tiSkkrdW14'
    b'SWFQQnFBWWMzNk02TXdIZmdOanVlN1NXYktaK20rOApibGJIcnY4QzZ3SElXZnptdFFIdjV2'
    b'NU5yc2k3ZmRWYjgrNmQzcnk1K0x1N2FzaWZDT2JVSzMzbjYyczIzM09DTFZqOUhGZUNqSXpI'
    b'CkZ4YStHdnBseDhETFFPbDI3OFJiWDFuVVlqL2g4TDh3YlN2UkdPV0hucnBqOXZWUkFJcDV4'
    b'cUttMGFjN2J6ZG9rYzdnaWxmSFZBMjcKdHdjSCtkRVB3U1J5QmdCWTRIZ0I2VVQ3N0UrbDhL'
    b'ZkdwUEJOay9XOTVsRWJLdTZsR2dOVU5TYjFPM04yVlVoZi9IMm1ud0VBYTM3TQptdi9zem5V'
    b'cC9yWTVMM3dXVkUyTkpUT3BiZmRhNE02QkYrMk0vMkRHekd2blBmcGYxUCtiTTJtVmMwWlBY'
    b'N2x1N3ZSTHNLSmFjOS9uCkUxWU5lZ0pzRC9MNUdEdXppWWw0VkwwZHdRN29MVDJCZEJ3UnFt'
    b'ajlxbDVmbXQvNXFkODhNcEUzdXFkZjEvZDFaNDVQb2lwSUw4R1EKeDNqdXpFOTA5S016UDlI'
    b'MzB2OEQyL2JCUkNDY1hmWUFBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpJdE1ETXRN'
    b'VFJVTVRjNgpNRGs2TWpZck1EQTZNRER2a1ZDOEFBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVR'
    b'QXlNREl5TFRBekxURTBWREUzT2pBNU9qSTJLekF3Ck9qQXduc3pvQUFBQUFBQkpSVTVFcmtK'
    b'Z2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTI3MzAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'RU_PSK')

RU_PSK = b64_RU_PSK
index.append("RU_PSK")
index.append("Russia Pskovskaya oblast")
catalog["RU_PSK"] = RU_PSK
catalog["Russia Pskovskaya oblast"] = RU_PSK
country["Russia Pskovskaya oblast"] = ('RU_PSK', '', 1)
lookup["RU_PSK"] = ('RU_PSK', '', 'Russia Pskovskaya oblast', 1)
lookup["Pskov"] = ('RU_PSK', '', 'Russia Pskovskaya oblast', 1)
lookup["Russia Pskovskaya oblast"] = ('RU_PSK', '', 'Russia Pskovskaya oblast', 1)
details["RU_PSK"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Pskov"}
regional["RU_PSK"] = ('RU_PSK', 'Russia Pskovskaya oblast', 1)
regional["Russia Pskovskaya oblast"] = ('RU_PSK', 'Russia Pskovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_ROS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBzdGFuZGFsb25lPSJubyI/Pg0KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMjAwIiBoZWlnaHQ9IjgwMCIgdmll'
    b'd0JveD0iMCAwIDkgNiI+DQo8cmVjdCB3aWR0aD0iOSIgaGVpZ2h0PSI2IiBmaWxsPSIjYjUy'
    b'MzE1Ii8+DQo8cmVjdCB3aWR0aD0iOSIgaGVpZ2h0PSI0IiBmaWxsPSIjZmZkNzAwIi8+DQo8'
    b'cmVjdCB3aWR0aD0iOSIgaGVpZ2h0PSIyIiBmaWxsPSIjMDA1N2I3Ii8+DQo8cmVjdCB3aWR0'
    b'aD0iMS4yIiBoZWlnaHQ9IjYiIGZpbGw9IndoaXRlIi8+DQo8L3N2Zz4=', 'RU_ROS')

RU_ROS = b64_RU_ROS
index.append("RU_ROS")
index.append("Russia Rostovskaya oblast")
catalog["RU_ROS"] = RU_ROS
catalog["Russia Rostovskaya oblast"] = RU_ROS
country["Russia Rostovskaya oblast"] = ('RU_ROS', '', 1)
lookup["RU_ROS"] = ('RU_ROS', '', 'Russia Rostovskaya oblast', 1)
lookup["Rostov"] = ('RU_ROS', '', 'Russia Rostovskaya oblast', 1)
lookup["Russia Rostovskaya oblast"] = ('RU_ROS', '', 'Russia Rostovskaya oblast', 1)
details["RU_ROS"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Rostov"}
regional["RU_ROS"] = ('RU_ROS', 'Russia Rostovskaya oblast', 1)
regional["Russia Rostovskaya oblast"] = ('RU_ROS', 'Russia Rostovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_RYA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWw6c3BhY2U9InByZXNlcnZlIiB3aWR0aD0i'
    b'MTUwMCIgaGVpZ2h0PSIxMDAwIiB2ZXJzaW9uPSIxLjEiIHN0eWxlPSJzaGFwZS1yZW5kZXJp'
    b'bmc6Z2VvbWV0cmljUHJlY2lzaW9uOyB0ZXh0LXJlbmRlcmluZzpnZW9tZXRyaWNQcmVjaXNp'
    b'b247IGltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHk7IGZpbGwtcnVsZTpldmVub2Rk'
    b'OyBjbGlwLXJ1bGU6ZXZlbm9kZCINCnZpZXdCb3g9IjAgMCAzNjAwMCAyNDAwMCINCiB4bWxu'
    b'czp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayI+DQogPGRlZnM+DQogIDxz'
    b'dHlsZSB0eXBlPSJ0ZXh0L2NzcyI+DQogICA8IVtDREFUQVsNCiAgICAuZmlsNCB7ZmlsbDoj'
    b'MDA5MjNGfQ0KICAgIC5maWwzIHtmaWxsOiM0QzQ4NDB9DQogICAgLmZpbDcge2ZpbGw6Izcw'
    b'NjE0RX0NCiAgICAuZmlsNSB7ZmlsbDojQUEyQzJBfQ0KICAgIC5maWwwIHtmaWxsOiNEQTI1'
    b'MUR9DQogICAgLmZpbDYge2ZpbGw6I0Y1QzQ5MX0NCiAgICAuZmlsMSB7ZmlsbDojRjhDMzAw'
    b'fQ0KICAgIC5maWwyIHtmaWxsOndoaXRlfQ0KICAgXV0+DQogIDwvc3R5bGU+DQogPC9kZWZz'
    b'Pg0KICA8cmVjdCBjbGFzcz0iZmlsMCIgd2lkdGg9IjM2MDAwIiBoZWlnaHQ9IjI0MDAwIi8+'
    b'DQogIDxyZWN0IGNsYXNzPSJmaWwxIiB3aWR0aD0iMzYwMDAiIGhlaWdodD0iMTgwMDAiLz4N'
    b'CiAgPHJlY3QgY2xhc3M9ImZpbDIiIHdpZHRoPSIzNjAwMCIgaGVpZ2h0PSI2MDAwIi8+DQog'
    b'IDxnPg0KICAgPHBhdGggY2xhc3M9ImZpbDMiIGQ9Ik0xNzM1MCA3MjY2bDExMTkgLTVjODEs'
    b'MCAxMjEsNzAgMTIxLDE0OWwwIDBjMCw3OSAtMzYsMTI1IC0xNDgsMTEyIC00NDEsLTUxIC03'
    b'NDcsLTM1IC0xMDkyLDMyIC04MCwxNiAtMTQ4LC02NSAtMTQ4LC0xNDRsMCAwYzAsLTc5IDY2'
    b'LC0xNDMgMTQ4LC0xNDRsMCAweiIvPg0KICAgPHBhdGggY2xhc3M9ImZpbDQiIGQ9Ik0xNzg5'
    b'OSA2NjExYzMxNiwwIDU3NCwyNzggNTc0LDYxOCAwLDExIDAsMjEgLTEsMzIgLTEsMCAtMiww'
    b'IC0zLDBsLTExMTkgNWMtOSwwIC0xNywxIC0yNSwyIDAsLTEzIC0xLC0yNiAtMSwtMzkgMCwt'
    b'MzQwIDI1OCwtNjE4IDU3NSwtNjE4bDAgMHoiLz4NCiAgIDxwYXRoIGNsYXNzPSJmaWwzIiBk'
    b'PSJNMTkwMTUgMTE2MTdjMTQ0LDgyIDI4OCwxNzAgNDMyLDMwNSAtNSwxMzUgLTYyLDIwNiAt'
    b'MTcyLDIxMSAtODcsLTEzMiAtMjM5LC0yMTIgLTM5MiwtMjkwIDQ0LC03NSA4OCwtMTUwIDEz'
    b'MiwtMjI2eiIvPg0KICAgPHBhdGggY2xhc3M9ImZpbDQiIGQ9Ik0xOTI0OCAxNDAyM2wtMTIx'
    b'IDU1MmMxMSwyNjAgODYsNTkyIC0xODgsNjQ1IC0xMzAsLTE5IC0xMTYsLTUzIC0yMjYsNSAt'
    b'NjEsMTcgLTEyNSw1MSAtMTk3LDAgLTg5LC0yMyAtMTEzLC0xOCAtMTUxLDIzIC0yMDYsNDkg'
    b'LTMxNSwtMTA2IC0yODIsLTQwMWwtMTIxIC03MjVjNDI5LC04IDg1NywtMzkgMTI4NiwtOTls'
    b'MCAweiIvPg0KICAgPHBhdGggY2xhc3M9ImZpbDQiIGQ9Ik0xNjU5MyAxNDA3NmwxNzggODAw'
    b'Yy0zMiwyNDkgMjQsMzkwIDIwOCwzOTcgODYsLTM0IDEyMCwtNTMgMjMxLDQgNjAsMTggMTAw'
    b'LDE4IDE3MiwtMzMgODksLTIzIDEzOCwtMTMgMTc1LDI4IDI5MSwzNCAzNTQsLTEyMiAyNjMs'
    b'LTQwNmwxMDggLTc0M2MtNDQ1LDcgLTg5MCwtMTAgLTEzMzUsLTQ3eiIvPg0KICAgPHBhdGgg'
    b'Y2xhc3M9ImZpbDUiIGQ9Ik0xOTg1NyAxNDI5NmwwIDQ5NiA2NSA3NCAtMSAtNSAxMyAxMiA0'
    b'OSAzMyAzMjUgMTMzIDEzIDljLTEzLDEyIC0yNywyMiAtNDIsMzIgLTg1LDU0IC0xODIsODUg'
    b'LTI4MCwxMDggLTY5LDE0IC0xMzcsMjQgLTIwNywzMSAtNDksMTUgLTk4LDMwIC0xNDYsNDYg'
    b'LTE0Miw0OCAtMjgxLDEwNSAtNDIyLDE1NyAtNTcsMjIgLTExNCw0MSAtMTcyLDU4IDEzLC0x'
    b'MDggMjIsLTIxOSAyNSwtMzM2IDEwNSwtMTI1IDU4LC0zNjggNTAsLTU2OWwxMTggLTU0MmM0'
    b'LC00IDgsLTcgMTIsLTExIDEyMCwtMTcgMjQwLC0zNiAzNTksLTU3IDcsNDYgMTgsOTIgMzcs'
    b'MTM1IDcsMTQgMTQsMjcgMjIsNDAgMjEsMzAgNDMsNTMgNzIsNzVsMTEwIDgxIDAgMHptLTE2'
    b'NDYgOTQ0YzEwLDExMyAyMCwyMjYgMzAsMzM4IC04MSwxIC0xNjMsLTEgLTI0NCwtNGwtMTAg'
    b'MSAwIC0yYy0yNiwxIC01MywxIC04MCwxIC01MSwwIC0xMDIsMCAtMTUzLC0xbDMwIC0zMzRj'
    b'ODksLTYwIDk1LC0xOTAgMzYsLTM3M2wxMDggLTc0M2MxMiwwIDIzLC0xIDM0LC0xbDEyMSA3'
    b'MjVjLTIzLDIwOSAyNSwzNDggMTI4LDM5M2wwIDB6bS0xMzA2IDIxYzMsODMgOCwxNjUgMTQs'
    b'MjQ4IC0xMiwtMyAtMjUsLTYgLTM3LC05IC0xOTcsLTU0IC0zODMsLTEzMiAtNTY0LC0yMjYg'
    b'LTI3LC0xNCAtNTQsLTI5IC04MSwtNDMgLTE2NiwtMjAgLTMzNCwtNDYgLTQ5MCwtMTExIC01'
    b'NSwtMjUgLTEwNCwtNTMgLTE1MSwtOTMgLTMsLTMgLTYsLTUgLTksLTkgLTUsLTcgNiwtMjYg'
    b'MTAsLTMyIDY0LC0zMiAxMjksLTU5IDE5NywtODIgODAsLTI3IDE2MSwtNTAgMjQyLC03Nmwz'
    b'MSAtMTcgMjUgLTE5IDIxIC0yNCAxNiAtMjkgOSAtMzIgMCAtOCA2IDEyIDAgLTQ0NiAxOTQg'
    b'LTc1YzE4LC0xNiAzNiwtMzIgNTMsLTQ5IDIzLC0yNSA0MSwtNDkgNTgsLTc3IDQ4LDQgOTYs'
    b'OSAxNDQsMTJsMTc4IDgwMGMtMjcsMjEyIDksMzQ2IDEzNCwzODVsMCAwem0yNjY1IC0xNTYx'
    b'bDAgMGMxLC0xIDIsLTEgMiwtMSAwLDAgLTEsMCAtMiwxbDAgMHptNSAtMWMxLDAgMSwwIDEs'
    b'MCAwLDAgMCwwIC0xLDB6bTYgLTFjMCwwIDEsMCAxLDAgMCwwIC0xLDAgLTEsMHptMiAwYzEx'
    b'LC0xIDIyLC0zIDMzLC00bDMgLTU5NyAtMTYzIC0xMDkgMTI3IDcxMCAwIDB6bTM5IC0xMDAy'
    b'bDUgLTkyOCAtMTg4IDE0NmMzLDMgNSw1IDgsOCAtNCwxMTMgLTQ0LDE4MCAtMTIxLDIwM2wt'
    b'MTYgNDQgNjQgMzU3IDI0OCAxNzAgMCAwem0tNjM2IC0yMDQwbDEwNiA0NTcgMTE2IC0yODUg'
    b'LTE3NSAtMTMzYy0xNSwtMTMgLTMxLC0yNiAtNDcsLTM5bDAgMHptLTIyNzIgMzkyYzAsMCAw'
    b'LDAgMCwwbC0zNDYgMjA2IC00NSAyNSA3NCAxMTk1YzgsLTM4IDE3LC03NiAyNSwtMTE0IDk5'
    b'LC00NTQgMjAwLC05MDYgMzQ1LC0xMjkxIDAsMCAwLDAgMCwwIC0xMywtMSAtMjYsLTQgLTQw'
    b'LC03IC00LC01IC05LC0xMCAtMTMsLTE0bDAgMHoiLz4NCiAgIDxwYXRoIGNsYXNzPSJmaWww'
    b'IiBkPSJNMTkwNzcgMTUxNDRjLTEyLDQzMiAtMTAyLDc4NSAtMTg4LDEyMTAgLTI2LDgwIDEs'
    b'MjE3IDMsMjk4IDY1LDYwIDExNiwxMjAgMTY1LDE3OSAzNCw0OCAxMDcsODUgMTY3LDEzMCAx'
    b'MTQsNDUgMjA0LDEwOSAyMzMsMTk0IDU4LDEyNiA1NywxODYgLTQ3LDIxNiAtMjc4LDU3IC00'
    b'MDUsLTIgLTYwMywtMTA0IC03MCwtMzMgLTIwMiwtOTQgLTI3MiwtMTI3IC0xNDQsMiAtMTc2'
    b'LC0zMSAtMTYxLC0xNzIgMjYsLTk2IC0xMywtMzE4IDEsLTQxMCAtOTAsLTQyMSAtMTI0LC04'
    b'NzEgLTE2NCwtMTMxOCA0MiwxOSA5NCwyMiAxNTQsOCAzOCwtNDEgNjIsLTQ2IDE1MSwtMjMg'
    b'NzIsNTEgMTM2LDE3IDE5NywtMSAxMTAsLTU3IDk2LC0yMyAyMjYsLTQgNjIsLTEyIDEwNywt'
    b'MzkgMTM4LC03NnptLTIxNzIgMTE3YzE4LDQ4OCA5MCw5NzAgMjAzLDE0NTkgLTY1LDYwIC0x'
    b'MTYsMTE5IC0xNjYsMTc5IC0xNzgsOTEgLTM0MiwxODQgLTQwOCwyOTIgLTk2LDk2IC04MCwx'
    b'NjggNDcsMjE2IDI3OCw1NyA0OTAsLTE2IDY4OCwtMTE4IDcwLC0zMyAxNDAsLTY2IDIxMCwt'
    b'OTkgMTQ0LDIgMjM4LC00MSAyMjMsLTE4MSAtNDMsLTc5IC01NCwtMTc5IC01MCwtMjg5bDEz'
    b'MiAtMTQ4MWMtNDksMzMgLTEyNCw0NSAtMjI3LDMzIC0zNywtNDEgLTg2LC01MSAtMTc1LC0y'
    b'OCAtNzIsNTEgLTExMiw1MSAtMTcyLDMzIC0xMTEsLTU3IC0xNDUsLTM4IC0yMzEsLTQgLTI3'
    b'LC0xIC01MiwtNSAtNzQsLTEybDAgMHoiLz4NCiAgIDxwYXRoIGNsYXNzPSJmaWwyIiBkPSJN'
    b'MTczMTMgMTAxNzBsLTc1IDI5IC0xMjM3IC0zMjcyIC0yOTkgLTM2MyA5IDQ1NCAxMjA4IDMz'
    b'MDEgMTEgMCAtMTAwIDM4YzAsLTgzIC01MywtMTEzIC0xNTksLTkwIC05Miw1NSAtNjQsMTUy'
    b'IDksMjAxIDMxLDE0IDY5LDE0IDExMywxIDIwNiwtNzggNDExLC0xNTcgNjE2LC0yMzUgNDgs'
    b'NzYgMTE5LDkwIDE4NCwxMCAyOCwtMTEwIC00NSwtMTU4IC0xMzYsLTEzNWwtMTQ0IDYxIDAg'
    b'MHoiLz4NCiAgIDxwYXRoIGNsYXNzPSJmaWw2IiBkPSJNMTczMjcgMTAzMjRjLTE4Myw1NSAt'
    b'MzYwLDExNSAtNTQyLDE3MSAtMzYsMTkxIDMzLDM5OSAxNTksNDIwIDAsMiAwLDUgLTEsNyA3'
    b'NiwyMCAxNTcsMzIgMjM4LDI0IDg4LC00MiAxNzYsLTY2IDI2NCwtMTA4IDQ1LC00MyA2LC03'
    b'OCAzLC0xMDYgNDcsLTU2IDQxLC05OCAtNiwtOTEgLTM0LC0xNiAtMzcsLTM5IC04LC03MSAz'
    b'MiwtNjkgMTcsLTk4IC00NSwtODcgLTI3LC0xMiAtMjksLTMyIC05LC01OSAxNCwtODkgLTQs'
    b'LTEyMiAtNTMsLTEwMHoiLz4NCiAgIDxwYXRoIGNsYXNzPSJmaWwxIiBkPSJNMTgwNTcgNjk4'
    b'N2MtMTYsMCAtMzAsMTQgLTMwLDMxIDAsMTcgMTQsMzEgMzAsMzEgMTcsMCAzMSwtMTQgMzEs'
    b'LTMxIDAsLTE3IC0xNCwtMzEgLTMxLC0zMXptLTE0NyAtMzNjNjEsMyA4OCw0OCAxMDAsMTEx'
    b'IDY2LC0yIDExMSwzOCAxMjUsODUgLTQyLC00IC02NywtNSAtODYsMTQgLTE1LDE5IC0xNiw0'
    b'MCA3LDM3IDI1LDE4IDI3LDQyIDIxLDYybC0zMzMgMmMtNywtMjEgLTUsLTQ2IDIwLC02NCAy'
    b'MywzIDIyLC0xOCA3LC0zNyAtMTgsLTE5IC00MywtMTggLTg1LC0xNCAxMywtNDcgNTksLTg3'
    b'IDEyNCwtODUgMTIsLTYzIDM5LC0xMDggMTAwLC0xMTF6bS0xNDcgMzNjMTcsMCAzMSwxNCAz'
    b'MSwzMSAwLDE3IC0xNCwzMSAtMzEsMzEgLTE3LDAgLTMxLC0xNCAtMzEsLTMxIDAsLTE3IDE0'
    b'LC0zMSAzMSwtMzF6Ii8+DQogICA8cGF0aCBjbGFzcz0iZmlsMCIgZD0iTTE2NDU3IDkwNTdj'
    b'LTM3OSw0NDkgLTg1NCwxMzE5IC04NzUsMTU1NiAtNDIsMTY1IC00NywzOTIgLTQ1LDYyNSAt'
    b'NzMsMTI1MCAtNDksMjM3OCAtNzAsMzY3NSAyLC0zIDQsLTcgNiwtMTBsMjAgLTMxYzUzLC0y'
    b'OCAxMDYsLTUzIDE2MSwtNzUgOTUsLTM3IDE5MywtNjYgMjkwLC05NiAxMiwtMyAyNiwtNiAz'
    b'NywtMTNsLTI1MyAtMjIzYy00MCwtNjkgLTMzLC0xMjAgMSwtMTYxIDEsLTgxMiAxLC0xNjI0'
    b'IDIsLTI0MzcgMSwtMjI4IDEsLTQ1NiAxLC02ODRsLTQgLTg4IDIgLTEyOCA5IC0xMDFjNSwt'
    b'MzIgMTAsLTY0IDE3LC05NSA2LC0zMCAxNCwtNTggMjIsLTg3bDE3IC00OWM4LC0yMCAxNiwt'
    b'MzkgMjUsLTU4bDEwIC00MCA0NSA0NSAtMTAgMTUgLTE4IDQxYy04LDIwIC0xNSw0MCAtMjEs'
    b'NjAgLTEwLDM0IC0xOSw2NyAtMjYsMTAxIC01LDMxIC0xMCw2MSAtMTQsOTIgLTMsMzMgLTYs'
    b'NjYgLTgsOTggLTEsMzUgLTEsNzAgLTEsMTA1IDEsMjkgMyw1OCA1LDg3IC0xLDEwMTIgLTMs'
    b'MjAyNCAtNCwzMDM1bDAgNDRjMTcsLTEyIDM2LC0yMyA1NywtMzRsNDI4IC0xNjhjMzUsLTMy'
    b'IDc1LC03NyA3NSwtMTI3bC0xOTggLTMxODZjMywtMjcgNywtNTIgMTIsLTc4IDksLTM4IDIx'
    b'LC03MSAzOCwtMTA2IDExLC0yMCAyMiwtMzcgMzUsLTU0IDExOCwtMTM3IDI1NSwtMTA2IDQw'
    b'NSwtOTIgLTI5LC00OSAtMjQsLTEwOSA0MSwtMTQ4IDEwMCwtMjIgMTUzLDQgMTU5LDc3IDI2'
    b'LC0xNyA1MywtMzMgNzksLTUwbC00NTIgLTEyMzcgMCAwem03MjggMTAwMmMzMywtMzQgNjQs'
    b'LTY5IDk1LC0xMDYgNTcsLTY5IDEwOSwtMTQwIDE1OCwtMjE1IDM1LC01NSA2OCwtMTExIDk5'
    b'LC0xNjggNDQsLTg0IDgzLC0xNjkgMTE5LC0yNTYgMjgsLTcxIDU0LC0xNDIgNzcsLTIxNCAt'
    b'Mjk2LC00IC02MDksLTE3IC05MjgsLTQ2bDM4MCAxMDA1IDAgMHoiLz4NCiAgIDxwYXRoIGNs'
    b'YXNzPSJmaWwyIiBkPSJNMTc0ODAgMTA4NjRjOCwyMCAxMyw0MiAxMyw2NSAwLDkwIC03NCwx'
    b'NjQgLTE2NCwxNjQgLTY4LDAgLTEyNiwtNDIgLTE1MSwtMTAxbDMwMiAtMTI4IDAgMHoiLz4N'
    b'CiAgIDxwb2x5Z29uIGNsYXNzPSJmaWwzIiBwb2ludHM9IjE1ODI5LDY4MzIgMTcwNzksMTAy'
    b'NjEgMTcwNDUsMTAyNzQgMTU3OTQsNjg0NiAiLz4NCiAgIDxjaXJjbGUgY2xhc3M9ImZpbDAi'
    b'IGN4PSIxNzkxMCIgY3k9IjcxODQiIHI9IjUwIi8+DQogICA8cGF0aCBjbGFzcz0iZmlsNyIg'
    b'ZD0iTTE3Mzc1IDc1NDljLTgsMTMgLTE2LDI1IC0yMywzNyAzLDQ5IC0xOSw5OCAtNjQsMTQ3'
    b'IC0zMiw4MyAtMTAsMTI5IDY2LDEzOCAtMzMsMTEzIC05LDE4MyA1NCwyMjMgLTMwLDg2IC0y'
    b'NSwxODMgMTcsMjkzIDE4LDMzIDM2LDY2IDU0LDk5IC0xMTksMTk1IC00NywyMTIgNTIsMjEz'
    b'IDE3LDQ5IDQwLDk2IDEwNiw1OSA2OSwtOSAxMzksLTE4IDIwOCwtMjcgNDUsLTM4IDg0LC00'
    b'MCAxMTgsLTYgMTAzLDQxIDE5NSw0MCAyNzUsLTQgMjcsLTcgNTQsLTE0IDgxLC0yMSA0NCw4'
    b'IDM4LC00NCA3NiwtNTEgMjksLTUgNzAsLTEzIDcxLC00OCAtNTAsLTQ2IC04OSwtOTQgLTQy'
    b'LC0xNTMgLTQsLTM2IC04LC03MiAtMTMsLTEwOCA4LC0xMiAxNiwtMjQgMjQsLTM2IDQ0LC00'
    b'NSA3NywtOTIgMjQsLTE1MCAtNTQsLTU5IC01NSwtMTE3IC0xLC0xNzYgNDksLTM0IDg1LC02'
    b'OSAzNywtMTE0IC0yOCwtMTIgLTMyLC00MiAtMTIsLTkxIDYzLC0yMSA3OSwtNjAgNDYsLTEx'
    b'OCAtMzIsLTQ1IC02MywtODkgLTk1LC0xMzQgLTU2LC02IC0xMDksLTExIC0xNjEsLTE2IDU0'
    b'LDExNiA3MSwyOTcgMzEsNDQwIC0yNSw4OCAtNzQsMTUwIC0xNzMsMTU0bC04NSAtNjcgLTYz'
    b'IC0xMSA2IC0zMCAyMCAtNThjLTEyLC03OSAtMzgsLTE2MCAtMjAsLTIyN2w2NSA3IDIgMGMt'
    b'Miw0IC0zLDkgLTMsMTQgMCwyNCAyMCw0NCA0NCw0NCAyNSwwIDQ0LC0yMCA0NCwtNDQgMCwt'
    b'NCAwLC04IC0xLC0xMmwwIDAgNjAgLTExIDEgLTE2Yy0zNiwtMTUgLTg0LC0xNiAtMTM0LC0x'
    b'NiAtMjQsLTE1IC0xNCwtMzEgNywtMzkgNDUsLTE2IDkwLC0xNyAxMzUsLTMgMzcsNyA0Niww'
    b'IDI1LC0yMiAtODYsLTE4IC0xOTYsLTQ0IC0yOTIsMzEgLTExLDg5IC01LDE5NSAxNSwyNzcg'
    b'NiwzNiAtNCw1NSAtMzAsNTlsLTExOCAwIDMgNDIgLTIwNSA5MGMtMTMyLC0xNjUgLTE2Nywt'
    b'NDAzIC02NCwtNTg1IC01Niw3IC0xMTEsMTcgLTE2OCwyN2wwIDB6bTE5NCAxMDdjLTMwLC0y'
    b'IC0zNywyIC0yMywtMjEgNjYsLTQxIDEzMywtNDggMjMwLC0yOSAyMywxNSA0NSwzNyAzMyw2'
    b'NiAtMTksMzggLTE5LDQ1IC00NSw2MCAtMiwwIC0xOCwxMCAtMjAsMTAgLTQsMjAgLTIyLDM1'
    b'IC00MywzNSAtMjQsMCAtNDQsLTIwIC00NCwtNDQgLTIyLC0xIC00NCwtMSAtNjYsMiAtMTQs'
    b'LTcgLTE0LC0xOSAxLC0zNCA0MywtMTUgMTAzLC0xNSAxNjEsLTE1IDE4LC0xMyAxOCwtMjYg'
    b'MCwtMzkgLTM3LC0xMyAtMTEzLC0yNSAtMTg0LDlsMCAwem00NjYgNTA3Yy02NiwtNTUgLTE4'
    b'MSwtNjAgLTI3NSw1IC0yOCwyNyAtMTUsNDkgMTAsNjQgMTAwLDIwIDE4MiwxMyAyNTUsLTUg'
    b'NTAsLTE1IDUzLC0zNiAxMCwtNjRsMCAweiIvPg0KICAgPHBhdGggY2xhc3M9ImZpbDYiIGQ9'
    b'Ik0xNzU0MyA3NTIyYy0xMDMsMTgyIC02OCw0MjAgNjQsNTg1bDIwNSAtOTAgLTMgLTQyIDEx'
    b'OCAwYzI2LC00IDM2LC0yMyAzMCwtNTkgLTIwLC04MiAtMjYsLTE4OCAtMTUsLTI3NyA5Niwt'
    b'NzUgMjA2LC00OSAyOTIsLTMxIDIxLDIyIDEyLDI5IC0yNSwyMiAtNDUsLTE0IC05MCwtMTMg'
    b'LTEzNSwzIC0yMSw4IC0zMSwyNCAtNywzOSA1MCwwIDk4LDEgMTM0LDE2bC0xIDE2IC01OSAx'
    b'MSAtMSAwYzEsNCAxLDggMSwxMiAwLDI0IC0xOSw0NCAtNDQsNDQgLTI0LDAgLTQ0LC0yMCAt'
    b'NDQsLTQ0IDAsLTUgMSwtMTAgMywtMTRsLTIgMCAtNjUgLTdjLTE4LDY3IDgsMTQ4IDIwLDIy'
    b'N2wtMjAgNTggLTYgMzAgNjMgMTEgODUgNjdjOTksLTQgMTQ4LC02NiAxNzMsLTE1NCA0MCwt'
    b'MTQzIDIzLC0zMjQgLTMxLC00NDAgLTI3NiwtMjIgLTUwMiwtMTUgLTczMCwxN3ptMjYgMTM0'
    b'Yy0zMCwtMiAtMzcsMiAtMjMsLTIxIDY2LC00MSAxMzMsLTQ4IDIzMCwtMjkgMjMsMTUgNDUs'
    b'MzcgMzMsNjYgLTE5LDM4IC0xOSw0NSAtNDUsNjAgLTIsMCAtMTgsMTAgLTIwLDEwIC00LDIw'
    b'IC0yMiwzNSAtNDMsMzUgLTI0LDAgLTQ0LC0yMCAtNDQsLTQ0IC0yMiwtMSAtNDQsLTEgLTY2'
    b'LDIgLTE0LC03IC0xNCwtMTkgMSwtMzQgNDMsLTE1IDEwMywtMTUgMTYxLC0xNSAxOCwtMTMg'
    b'MTgsLTI2IDAsLTQwIC0zNywtMTIgLTExMywtMjQgLTE4NCwxMGwwIDB6bTQ2NiA1MDdjLTY2'
    b'LC01NSAtMTgxLC02MCAtMjc1LDUgLTI4LDI3IC0xNSw0OSAxMCw2NCAxMDAsMjAgMTgyLDEz'
    b'IDI1NSwtNSA1MCwtMTUgNTMsLTM3IDEwLC02NGwwIDB6Ii8+DQogICA8cGF0aCBjbGFzcz0i'
    b'ZmlsMyIgZD0iTTIxODYyIDE0MjI5bC0yNjUxIC0xODE0YzAsMiAtMSw0IC0yLDYgLTQyLDYy'
    b'IC05MywxMTQgLTE1NiwxNDYgLTM2LDU1IC01OCw4NSAtNzcsMTAxbDI3MTkgMTgxMWM5Miw0'
    b'NSAxNTksNTEgMjA0LDMzIDk4LC00MCA4NCwtMTk0IC0zNywtMjgzbDAgMHptLTMxNTQgLTIx'
    b'NTlsLTEzIC05IC02MCA4NGMtMTIsLTE2IC0zMSwtMjcgLTUzLC0yNyAtMzUsMCAtNjQsMjkg'
    b'LTY0LDY0IDAsMzAgMjAsNTQgNDcsNjJsLTcyIDEwMiAwIDEgMzkgMjZjNTksLTk1IDExNywt'
    b'MTkxIDE3NiwtMjg2IDAsLTYgMCwtMTEgMCwtMTdsMCAwem0tNzIgMzcybDM3IDI1YzEyLC0x'
    b'OSAyNCwtMzkgMzYsLTU4IDAsLTMyIC0xNywtMzggLTM3LC0xOCAtMTIsMTggLTI0LDM0IC0z'
    b'Niw1MWwwIDB6bTExOCA3OWwzMyAyMWMxMSwtMTcgMjIsLTM0IDM1LC01MSA5LC0zNSAyLC00'
    b'NSAtMzAsLTI4IC0xMywxOSAtMjUsMzggLTM4LDU4bDAgMHptMTAxIDY3bDM1IDIzYzEyLC0y'
    b'MCAyNCwtNDAgNDAsLTYxIC0yLC0yNyAtNiwtMzQgLTI3LC0yMCAtMTcsMTkgLTMyLDM4IC00'
    b'OCw1OGwwIDB6Ii8+DQogICA8cGF0aCBjbGFzcz0iZmlsNCIgZD0iTTE2ODIwIDEwNDU5bC0z'
    b'MSAxOGMtMSw2IC0zLDEyIC00LDE4IDAsMCAwLDAgMCwwIDE4MiwtNTYgMzU5LC0xMTYgNTQy'
    b'LC0xNzEgNDksLTIyIDY3LDEyIDUzLDEwMCAtMjEsMjcgLTE4LDQ3IDksNTkgNjIsLTExIDc3'
    b'LDE4IDQ1LDg3IC0yOSwzMiAtMjYsNTUgOCw3MSA0NywtNyA1MywzNSA2LDkxIDMsMjggNDIs'
    b'NjMgLTMsMTA2IC04OCw0MiAtMTc2LDY2IC0yNjQsMTA4IC04MSw4IC0xNjIsLTQgLTIzOCwt'
    b'MjQgMCwwIDAsMCAwLDAgLTMsNzkgLTY3LDE1NyAtMTc2LDE0NyAtMTU4LDQxNyAtMjYyLDkx'
    b'NCAtMzcwLDE0MDZsODEgMTMwMWMxMDIzLDc4IDIwNTksNDkgMzEwNSwtNzhsLTEyNyAtNzEw'
    b'IC00ODAgLTMyMGMxOSwtMTYgNDEsLTQ2IDc3LC0xMDEgNjMsLTMyIDExNCwtODQgMTU2LC0x'
    b'NDYgMSwtMiAyLC00IDIsLTZsMTYzIDExMSAtNjQgLTM1NyAxNiAtNDRjLTE1LDQgLTMyLDcg'
    b'LTUxLDggLTg3LC0xMzIgLTIzOSwtMjEyIC0zOTIsLTI5MCA0NCwtNzUgODgsLTE1MCAxMzIs'
    b'LTIyNiAxNDIsODEgMjgzLDE2NyA0MjQsMjk3bDE4OCAtMTQ2IDMgLTM4OWMtMiwtNDQgLTks'
    b'LTg1IC0yMiwtMTI4bC05IC0yNmMtMzUsLTg4IC05MSwtMTU2IC0xNjAsLTIxOWwtMjcgLTIy'
    b'IC0yMDQgLTE1NiAtMTE3IDI4NSAtMTA1IC00NTdjLTM1LC0zMCAtNzAsLTYwIC0xMDUsLTkx'
    b'IC00OCwtNDQgLTk0LC05MCAtMTQwLC0xMzZsLTEzMCAtMTQzIC0xNTcgLTIwMCAtMTQwIC0y'
    b'MDljLTQ0LC03MiAtODYsLTE0NCAtMTI3LC0yMTcgLTY5LC0xMjkgLTEzMywtMjYwIC0xOTQs'
    b'LTM5MyAtMjQsLTU1IC00OCwtMTEwIC03MSwtMTY1IC0xMSwwIC0yMywwIC0zNCwwIC0yNCw3'
    b'NiAtNDksMTUyIC03OCwyMjcgLTM3LDkzIC03NywxODQgLTEyMiwyNzQgLTMzLDYxIC02Nywx'
    b'MjEgLTEwMywxODEgLTUxLDgxIC0xMDYsMTU4IC0xNjUsMjMzIC00OCw1OSAtOTgsMTE2IC0x'
    b'NTIsMTcwbDQ1IC0xNyAxNDQgLTYxYzkxLC0yMyAxNjQsMjUgMTM2LDEzNSAtNjUsODAgLTEz'
    b'Niw2NiAtMTg0LC0xMCAtMTk2LDc1IC0zOTMsMTUwIC01ODksMjI1bDAgMHptMTg4OCAxNjEx'
    b'bC0xNCAtOSAtNTkgODRjLTEyLC0xNiAtMzEsLTI3IC01MywtMjcgLTM1LDAgLTY0LDI5IC02'
    b'NCw2NCAwLDMwIDIwLDU0IDQ3LDYybC03MiAxMDIgMCAxIDM5IDI2YzU5LC05NSAxMTcsLTE5'
    b'MSAxNzYsLTI4NiAwLC02IDAsLTExIDAsLTE3bDAgMHptLTcyIDM3MmwzNyAyNWMxMiwtMTkg'
    b'MjQsLTM5IDM2LC01OCAwLC0zMiAtMTcsLTM4IC0zNywtMTggLTEyLDE4IC0yNCwzNCAtMzYs'
    b'NTFsMCAwem0xMTggNzlsMzMgMjFjMTEsLTE3IDIyLC0zNCAzNSwtNTEgOSwtMzUgMiwtNDUg'
    b'LTMwLC0yOCAtMTMsMTkgLTI1LDM4IC0zOCw1OGwwIDB6bTEwMSA2N2wzNSAyM2MxMiwtMjAg'
    b'MjQsLTQwIDQwLC02MSAtMiwtMjcgLTYsLTM0IC0yNywtMjAgLTE3LDE5IC0zMywzOSAtNDgs'
    b'NThsMCAwem0tMTkxMSAtMTY3MmMwLDEgMCwxIDAsMSAwLDAgMCwwIDAsLTF6bTAgMmMwLDAg'
    b'MCwxIDAsMSAwLDAgMCwtMSAwLC0xem0wIDFjMCwwIDAsMSAwLDEgMCwwIDAsLTEgMCwtMXpt'
    b'MCAxYzAsMCAwLDAgMCwxIDAsLTEgMCwtMSAwLC0xem0tMSAxYzAsMCAwLDAgMCwxIDAsLTEg'
    b'MCwtMSAwLC0xem0tNjIwIDM2MGwzOTEgLTIzM2MtMTQyLC0xNTMgLTE3NywtMzQ1IC0xMjcs'
    b'LTUxNCAtNzMsLTggLTE1MCwtNyAtMjE0LDM2IC0yNiwyMCAtNDMsNDIgLTU3LDcyIC02LDE0'
    b'IC0xMSwyNyAtMTUsNDEgLTUsMjIgLTksNDMgLTExLDY1bDMzIDUzMyAwIDB6Ii8+DQogICA8'
    b'cGF0aCBjbGFzcz0iZmlsMCIgZD0iTTE4MDg0IDkxMDJjMzEsNzIgNjMsMTQ0IDk2LDIxNSA1'
    b'MywxMTAgMTA4LDIxOCAxNjcsMzI1IDUwLDg3IDEwMywxNzMgMTU5LDI1NyA0NSw2NyA5Miwx'
    b'MzIgMTQyLDE5NiA1MSw2NCAxMDMsMTI1IDE1OCwxODYgNDIsNDUgODUsODkgMTMwLDEzMiA0'
    b'Niw0MyA5Miw4NCAxNDAsMTI1bDUwIDQwIDM5NSAzMDNjNDEsMzUgNzcsNzEgMTEyLDExMiAx'
    b'NiwyMCAzMSw0MCA0NSw2MiAzOCw1OSA2NCwxMTkgODIsMTg3IDExLDQ1IDE2LDg3IDE4LDEz'
    b'M2wtOCAxNDIyIDMyNSAyMjNjLTI5LC01MjYgLTU5LC0xMDUyIC04OCwtMTU3OGwtMTggLTMx'
    b'NiAtOSAtODEgLTE0IC04MSAtMTkgLTgyIC0yNSAtODEgLTIzIC02MSAtNDQgLTEwMmMtMTAs'
    b'LTIxIC0yMSwtNDEgLTMxLC02MmwtNTcgLTk5IC0yMiAtMjMgNTggLTI5IDcgMjYgMTAgMThj'
    b'MjEsMzUgNDAsNzAgNTksMTA1IDE3LDM1IDMzLDcwIDQ5LDEwNSA5LDIxIDE3LDQyIDI1LDY0'
    b'IDEzLDM0IDI1LDY5IDM2LDEwNSA3LDI4IDE1LDU2IDIxLDg1IDYsMjggMTIsNTYgMTYsODQg'
    b'NCwyOCA4LDU2IDEwLDg1bDE0IDIzMmMzMiw1NzQgNjUsMTE0NyA5NywxNzIxbDE2OCAxMTYg'
    b'LTI1IC0zMTJjLTE1LC03MzAgLTYwLC0xNDc2IC0xMzYsLTIyMzcgLTI0MiwtNzE0IC01MjQs'
    b'LTEyMDEgLTg1NCwtMTYzMyAtMjMsMTYgLTYzLDI3IC0xMTcsMzcgLTI1MiwyNSAtNDc5LDQ5'
    b'IC03MzEsNzQgLTExNywxIC0yNDAsMiAtMzY4LDJsMCAwem0xNjg0IDQwOTRsLTQgNTI5Yy02'
    b'LDc3IC05LDE1MyAxLDIyOSA5LDUzIDIzLDEwNiA2OCwxMzlsMzM3IDI0OWMtMTcsLTMwNSAt'
    b'MzQsLTYwOSAtNTEsLTkxM2wtMzUxIC0yMzMgMCAwem00MDIgMjY4YzE3LDMwOCAzNSw2MTYg'
    b'NTIsOTI0bDEgNSA1NiA2MiAxMiAyNiA0IDI1IDAgMjMgLTExIDQxYy04LDE4IC0xNywzNCAt'
    b'MjksNTBsLTI2IDMwYy0zMSwzMSAtNjQsNTYgLTEwMCw4MGwtNjUgNDggMzE3IDEzMGMyMywx'
    b'NyA0NiwzMiA2OSw1MWwxNSAxNyAtMTE2IC0xMzkzIC0xNzkgLTExOSAwIDB6Ii8+DQogICA8'
    b'cGF0aCBjbGFzcz0iZmlsMyIgZD0iTTE2NDc4IDEzNzc2YzEwMzQsNzkgMjA4MCw0OCAzMTM4'
    b'LC04MmwzIC01OTcgMTQ5IDk5IC00IDUyOWMtNiw3NyAtOSwxNTMgMSwyMjkgOSw1MyAyMywx'
    b'MDYgNjgsMTM5bDMzNyAyNDljLTE3LC0zMDUgLTM0LC02MDkgLTUxLC05MTNsNTEgMzVjMTcs'
    b'MzA4IDM1LDYxNiA1Miw5MjRsMSA1IDU2IDYyIDEyIDI3IDQgMjQgMCAyMyAtMTEgNDFjLTgs'
    b'MTggLTE3LDM0IC0yOSw1MGwtMjYgMzBjLTMxLDMxIC02NCw1NiAtMTAwLDgwbC02NSA0OCAz'
    b'MTcgMTMwYzIzLDE3IDQ2LDMyIDY5LDUxbDIwIDI0IDE2IDM2IDEgNDEgLTE1IDQyIC0yOCAz'
    b'NGMtNDUsNDUgLTk0LDc4IC0xNTEsMTA3IC02OSwzNCAtMTM5LDU4IC0yMTMsNzggLTg1LDIx'
    b'IC0xNzEsMzYgLTI1OSw0NSAtMTIzLDM3IC0yNDQsODAgLTM2NCwxMjYgLTExOCw0NSAtMjM1'
    b'LDkyIC0zNTYsMTI5IC0yNCw2IC00OCwxMyAtNzEsMTkgOCwtNTMgMTUsLTEwNiAyMiwtMTYw'
    b'IDU4LC0xNyAxMTUsLTM2IDE3MiwtNTggMTQxLC01MiAyODAsLTEwOSA0MjIsLTE1NyA0OCwt'
    b'MTYgOTcsLTMxIDE0NiwtNDYgNzAsLTcgMTM4LC0xNyAyMDcsLTMxIDk4LC0yMyAxOTUsLTU0'
    b'IDI4MSwtMTA4IDE0LC0xMCAyOCwtMjAgNDEsLTMybC0xMyAtOSAtMzI1IC0xMzMgLTQ5IC0z'
    b'MyAtMTMgLTEyIDEgNSAtNjUgLTczIDAgLTQ5NyAtMTEwIC04MWMtMjksLTIyIC01MSwtNDUg'
    b'LTcyLC03NSAtOCwtMTMgLTE1LC0yNiAtMjIsLTQwIC0xOSwtNDMgLTMwLC04OSAtMzcsLTEz'
    b'NSAtMTA1NSwxODcgLTIxMTEsMTk1IC0zMTY3LDk5IC0xNywyOCAtMzUsNTIgLTU3LDc3IC0x'
    b'OCwxNyAtMzYsMzMgLTU0LDQ5bC0xOTQgNzUgMCA0NDYgLTYgLTEyIDAgOCAtOSAzMiAtMTYg'
    b'MjkgLTIxIDI0IC0yNSAxOSAtMzEgMTdjLTgwLDI2IC0xNjIsNDkgLTI0Miw3NiAtNjgsMjQg'
    b'LTEzMyw1MCAtMTk3LDgyIC00LDYgLTE1LDI1IC0xMCwzMiAzLDQgNiw2IDksOSA0Nyw0MCA5'
    b'Niw2OCAxNTEsOTMgMTU2LDY1IDMyNCw5MSA0OTAsMTExIDI3LDE0IDU0LDI5IDgxLDQzIDE4'
    b'MSw5NCAzNjcsMTcyIDU2NCwyMjYgMTIsMyAyNSw2IDM3LDkgNCw1MiA4LDEwNSAxMywxNTcg'
    b'MCwwIC0xLC0xIC0xLC0xIC0yNjAsLTU4IC01MDcsLTE2MyAtNzQwLC0yOTAgLTE3OCwtMjEg'
    b'LTM1OSwtNTQgLTUyNCwtMTI4IC0yMCwtMTAgLTQwLC0yMCAtNjAsLTMxIC00NywtMjcgLTky'
    b'LC01OCAtMTMwLC05NyAtMTYsLTIwIC0yNSwtMzYgLTM0LC02MCAtNCwtMTkgLTYsLTM1IC02'
    b'LC01NCAyLC0xOSA2LC0zNSAxMiwtNTMgNywtMTcgMTQsLTMzIDI0LC00OWwyMCAtMzFjNDAs'
    b'LTIxIDc5LC00MCAxMjAsLTU4IDE0LC01IDI3LC0xMSA0MSwtMTcgOTUsLTM3IDE5MywtNjYg'
    b'MjkwLC05NSAxMiwtNCAyNiwtNyAzNywtMTRsLTI1MyAtMjIzYy00MCwtNjkgLTMzLC0xMjAg'
    b'MSwtMTYxIDEsLTgxMiAxLC0xNjI0IDMsLTI0MzcgMCwtMjI4IDAsLTQ1NiAwLC02ODRsLTQg'
    b'LTg4IDIgLTEyOCA5IC0xMDFjNSwtMzIgMTAsLTY0IDE3LC05NSA2LC0zMCAxNCwtNTggMjIs'
    b'LTg3bDE3IC00OWM4LC0yMCAxNiwtMzkgMjUsLTU4bDEwIC00MCA0NSA0NSAtMTAgMTUgLTE4'
    b'IDQxYy04LDIwIC0xNSw0MCAtMjEsNjAgLTEwLDM0IC0xOSw2NyAtMjYsMTAxIC01LDMxIC0x'
    b'MCw2MSAtMTQsOTIgLTMsMzMgLTYsNjYgLTgsOTkgLTEsMzQgLTEsNjkgLTEsMTA0IDEsMjkg'
    b'Myw1OCA1LDg3IC0xLDEwMTIgLTMsMjAyNCAtNCwzMDM1bDAgNDRjMTcsLTEyIDM2LC0yMyA1'
    b'NywtMzRsNDI4IC0xNjhjMzUsLTMyIDc1LC03NyA3NSwtMTI3bC0xOTggLTMxODZjMywtMjcg'
    b'NywtNTIgMTIsLTc4IDksLTM4IDIxLC03MSAzOCwtMTA2IDExLC0xOSAyMiwtMzcgMzUsLTU0'
    b'IDExOCwtMTM3IDI1NSwtMTA2IDQwNSwtOTEgMTIsMjAgMjksMzggNTAsNTIgMzEsMTMgNjgs'
    b'MTQgMTExLDIgLTQ5LDE5NyAyMiw0MjMgMTUzLDQ0NSAwLDkxIC04MCwxODMgLTIxNywxNDcg'
    b'LTE1MywtMTU2IC0xOTIsLTM1NCAtMTQwLC01MjggLTczLC04IC0xNTAsLTcgLTIxNCwzNiAt'
    b'MjYsMjAgLTQyLDQyIC01Nyw3MiAtNiwxNCAtMTEsMjcgLTE1LDQxIC01LDIyIC05LDQzIC0x'
    b'MSw2NWwxODggMzAyOCAwIDB6bTMxNDQgLTEwODBsOCAtMTMxN2MtMiwtNDQgLTksLTg1IC0y'
    b'MiwtMTI4bC05IC0yNmMtMzUsLTg4IC05MCwtMTU2IC0xNjAsLTIxOWwtMjcgLTIyIC0zNzkg'
    b'LTI4OWMtNTEsLTQyIC0xMDIsLTg1IC0xNTIsLTEzMCAtNDgsLTQ0IC05NCwtOTAgLTE0MCwt'
    b'MTM2bC0xMzAgLTE0MyAtMTU3IC0yMDAgLTE0MCAtMjA5Yy00NCwtNzIgLTg2LC0xNDQgLTEy'
    b'NywtMjE3IC02OSwtMTI5IC0xMzMsLTI2MCAtMTk0LC0zOTMgLTI0LC01NSAtNDgsLTExMCAt'
    b'NzEsLTE2NSAtMTEsMCAtMjMsMCAtMzQsMCAtMjQsNzYgLTQ5LDE1MiAtNzgsMjI3IC0zNyw5'
    b'MyAtNzcsMTg0IC0xMjIsMjc0IC0zMyw2MSAtNjcsMTIxIC0xMDMsMTgxIC01MSw4MSAtMTA2'
    b'LDE1OCAtMTY1LDIzMyAtNDgsNTkgLTk4LDExNiAtMTUyLDE3MGwtMzAgMTIgLTUzIC0xNDBj'
    b'MzMsLTM0IDY0LC02OSA5NSwtMTA2IDU3LC02OSAxMDksLTE0MCAxNTgsLTIxNSAzNSwtNTUg'
    b'NjgsLTExMSA5OSwtMTY4IDQ0LC04NCA4MywtMTY5IDExOSwtMjU2IDI4LC03MSA1NCwtMTQy'
    b'IDc3LC0yMTQgLTI5NiwtNCAtNjA5LC0xNyAtOTI4LC00NmwtMTEzIC0yOTljMjI4LC0xNTAg'
    b'NDY3LC0yNzggNzIzLC0zNzMgMywwIDYsMCA4LDAgMSwyIDIsMyAyLDUgMTgsMzMgMzYsNjYg'
    b'NTQsOTkgLTExOSwxOTUgLTQ3LDIxMiA1MiwyMTMgMTcsNDkgNDAsOTYgMTA2LDU5IDY5LC05'
    b'IDEzOSwtMTggMjA4LC0yNyA0NSwtMzggODQsLTQwIDExOCwtNiAxMDMsNDEgMTk1LDQwIDI3'
    b'NSwtNCAyNywtNyA1NCwtMTQgODEsLTIxIDQ0LDggMzgsLTQ0IDc2LC01MSAyOSwtNSA3MCwt'
    b'MTMgNzEsLTQ4IC01MCwtNDYgLTg5LC05NCAtNDIsLTE1MyAtMywtMjIgLTUsLTQ0IC04LC02'
    b'NiAzLDAgNiwwIDksMCAzMzYsMTA2IDU5MiwzMDEgODQ5LDQ4NyA5Miw5MyA1MiwxMzIgLTkx'
    b'LDE1NyAtMjUyLDI1IC00NzksNDkgLTczMSw3NCAtMTE3LDEgLTI0MCwyIC0zNjgsMiAzMSw3'
    b'MiA2MywxNDQgOTYsMjE1IDUzLDExMCAxMDgsMjE4IDE2NywzMjUgNTAsODcgMTAzLDE3MyAx'
    b'NTksMjU3IDQ1LDY3IDkyLDEzMiAxNDIsMTk2IDUxLDY0IDEwMywxMjUgMTU4LDE4NiA0Miw0'
    b'NSA4NSw4OSAxMzAsMTMyIDQ2LDQzIDkyLDg0IDE0MCwxMjVsNTAgNDAgMzk1IDMwM2M0MSwz'
    b'NSA3Nyw3MSAxMTIsMTEyIDE2LDIwIDMxLDQwIDQ1LDYyIDM4LDU5IDY0LDExOSA4MiwxODcg'
    b'MTEsNDUgMTYsODcgMTgsMTMzbC04IDE0MjIgLTE0OCAtMTAxIDAgMHptNDczIDMyNGMtMjks'
    b'LTUyNiAtNTksLTEwNTIgLTg4LC0xNTc4bC0xOCAtMzE2IC05IC04MSAtMTQgLTgxIC0xOSAt'
    b'ODIgLTI1IC04MSAtMjMgLTYxIC00NCAtMTAyYy0xMCwtMjEgLTIxLC00MSAtMzEsLTYybC01'
    b'NyAtOTkgLTIyIC0yMyA1OCAtMjkgNyAyNyAxMCAxN2MyMSwzNSA0MCw3MCA1OSwxMDUgMTcs'
    b'MzUgMzQsNzAgNDksMTA1IDksMjEgMTcsNDIgMjUsNjQgMTMsMzQgMjUsNjkgMzYsMTA1IDcs'
    b'MjggMTUsNTYgMjEsODUgNiwyOCAxMiw1NiAxNiw4NCA0LDI4IDgsNTYgMTAsODVsMTQgMjMy'
    b'YzMyLDU3NCA2NSwxMTQ3IDk3LDE3MjFsLTUyIC0zNSAwIDB6bS0xODQwIDI3MDdjLTg3LDEg'
    b'LTE3NCwtMSAtMjYxLC00bC03IC0zIDAgMmMtNzAsMSAtMTQwLDEgLTIxMCwwIC0xMiwwIC0y'
    b'NCwwIC0zNiwtMWwxMyAtMTQ4YzUxLDEgMTAyLDEgMTUzLDEgMjcsMCA1NCwwIDgwLC0xbDAg'
    b'MiAxMCAtMWM4MSwzIDE2Myw1IDI0NCw0IDUsNTAgOSwxMDAgMTQsMTQ5bDAgMHoiLz4NCiAg'
    b'IDxwYXRoIGNsYXNzPSJmaWw2IiBkPSJNMTg5MzggMTE4NzFjLTIxLDE1IC00MSwzMiAtNTks'
    b'NTMgLTEwNSwtNDIgLTE3OCwtMzIgLTIyMiwyOCAzOCwzNSA1NCw4MCA1MSwxMzUgLTYzLDEw'
    b'MiAtMTI2LDIwNSAtMTg4LDMwNyA5LDcyIDQ2LDc4IDk2LDc4IDE5LC0yOCAzNywtNTMgNTYs'
    b'LTgxIDIwLC0yMCAzNywtMTQgMzcsMTggLTIyLDM1IC00Myw2OSAtNjUsMTA0IDcsMzcgNDEs'
    b'NDggNzgsNTUgMjQsLTM1IDQ3LC03MCA3MCwtMTA1IDMyLC0xNyAzOSwtNyAzMCwyOCAtMjQs'
    b'MzIgLTQzLDY1IC02Nyw5NyAxLDM0IDMyLDQwIDY0LDQzIDI5LC0zNCA1NCwtNjcgODQsLTEw'
    b'MSAyMSwtMTQgMjUsLTcgMjcsMjAgLTI3LDM2IC00Miw2OCAtNjksMTAzIDExLDI3IDM5LDM4'
    b'IDYxLDMzIDQ2LDAgNjQsLTE2IDEzMSwtMTE5IDYzLC0zMiAxMTQsLTg0IDE1NiwtMTQ2IDI2'
    b'LC03NiAzMCwtMTQxIDQsLTIxNyAxMywtMzUgMjUsLTcwIDM3LC0xMDUgLTc3LC05NyAtMTky'
    b'LC0xNjUgLTMxMiwtMjI4bDAgMHoiLz4NCiAgIDxwYXRoIGNsYXNzPSJmaWwxIiBkPSJNMTg2'
    b'OTggMTIwNTZsLTE3NiAtMTI2IC0yMDQgMjk0IDE3MiAxMjcgNzUgLTEwN2MtMjcsLTggLTQ3'
    b'LC0zMiAtNDcsLTYyIDAsLTM1IDI5LC02NCA2NCwtNjQgMjIsMCA0MSwxMSA1MywyN2w2MyAt'
    b'ODl6Ii8+DQogICA8cGF0aCBjbGFzcz0iZmlsMSIgZD0iTTIxNjYzIDE0MTIzYy0xMiwxMyAt'
    b'MTgsMzMgLTEzLDY3IDUzLDgyIDU1LDEzMSAtNjUsMTA5IC00MSwtMiAtNjksNSAtNzcsMjZs'
    b'MTk5IDEzMmMxNSw4IDMwLDE0IDQ2LDIwIDEzLDUgMjcsOSA0MSwxMyAxMiwzIDIzLDUgMzUs'
    b'NiAxMCwwIDIwLDEgMzAsMCA4LC0xIDE2LC0zIDI0LC01bDYgLTIgMTQgLTcgMTAgLTkgOSAt'
    b'OSA3IC0xMiA1IC0xMyA0IC0xNSAxIC0xNSAtMSAtMTcgLTMgLTE4IC02IC0xOSAtOCAtMTgg'
    b'LTEwIC0xOSAtMTIgLTE4IC0xNSAtMTggLTE3IC0xNyAtMjAgLTE2IC0xODQgLTEyNiAwIDB6'
    b'bS02NTQgLTQ0OGwtMjQgMzVjLTQ5LC0xNCAtOTUsLTcgLTExNiwyMyAtMjAsMzAgLTEyLDc1'
    b'IDE5LDExNmwtMzAgNDMgMTAxIDY3IDI0IC0zNmM1OSwyNiAxMTcsMjEgMTQxLC0xNCAyNSwt'
    b'MzUgOCwtOTAgLTM2LC0xMzZsMjEgLTI5IC0xMDAgLTY5IDAgMHptLTc3MSAtNTI4bC0zMSA0'
    b'NGMtNDksLTE0IC05NSwtNiAtMTE2LDI0IC0yMCwzMCAtMTEsNzQgMTksMTE1bC0zMSA0MyAx'
    b'MDEgNjggMjYgLTM2YzU4LDI1IDExNiwyMSAxNDEsLTE0IDI0LC0zNiA4LC05MSAtMzYsLTEz'
    b'NmwyNyAtMzkgLTEwMCAtNjl6bS03NjQgLTUyM2wtMzQgNDhjLTQ5LC0xNCAtOTQsLTcgLTEx'
    b'NSwyMyAtMjEsMzAgLTEyLDc1IDE4LDExNmwtMzQgNDkgMTAwIDY3IDMwIC00MmM1OCwyNiAx'
    b'MTcsMjEgMTQxLC0xNCAyNCwtMzUgOCwtOTAgLTM2LC0xMzZsMzAgLTQyIC0xMDAgLTY5em0z'
    b'NTAgMzU2YzI5LDAgNTIsMjMgNTIsNTIgMCwyOCAtMjMsNTEgLTUyLDUxIC0yOCwwIC01Miwt'
    b'MjMgLTUyLC01MSAwLC0yOSAyNCwtNTIgNTIsLTUyem03ODggNTI5YzI4LDAgNTIsMjMgNTIs'
    b'NTIgMCwyOCAtMjQsNTEgLTUyLDUxIC0yOSwwIC01MiwtMjMgLTUyLC01MSAwLC0yOSAyMywt'
    b'NTIgNTIsLTUyem03MjggNDkzYzI4LDAgNTIsMjQgNTIsNTIgMCwyOSAtMjQsNTIgLTUyLDUy'
    b'IC0yOCwwIC01MiwtMjMgLTUyLC01MiAwLC0yOCAyNCwtNTIgNTIsLTUyeiIvPg0KICAgPHBh'
    b'dGggY2xhc3M9ImZpbDAiIGQ9Ik0yMTc2NiAxNDI4OWMyOCwwIDUxLDIzIDUxLDUxIDAsMjkg'
    b'LTIzLDUyIC01MSw1MiAtMjksMCAtNTIsLTIzIC01MiwtNTIgMCwtMjggMjMsLTUxIDUyLC01'
    b'MXptLTc3MiAtNTIxYzI4LDAgNTIsMjMgNTIsNTEgMCwyOSAtMjQsNTIgLTUyLDUyIC0yOSww'
    b'IC01MiwtMjMgLTUyLC01MiAwLC0yOCAyMywtNTEgNTIsLTUxem0tNzgwIC01MjZjMjksMCA1'
    b'MiwyNCA1Miw1MiAwLDI5IC0yMyw1MiAtNTIsNTIgLTI4LDAgLTUyLC0yMyAtNTIsLTUyIDAs'
    b'LTI4IDI0LC01MiA1MiwtNTJ6bS03NTYgLTUyMWMyOSwwIDUyLDI0IDUyLDUyIDAsMjggLTIz'
    b'LDUyIC01Miw1MiAtMjgsMCAtNTEsLTI0IC01MSwtNTIgMCwtMjggMjMsLTUyIDUxLC01Mnoi'
    b'Lz4NCiAgIDxwYXRoIGNsYXNzPSJmaWwwIiBkPSJNMTk4NzUgMTQzMDlsMCA0NTEgMTMgLTcg'
    b'MiAtOSAyMCAtMzIgMjMgLTIyIDEyOSAtOTRjMjksLTIwIDU4LC00MiA3OSwtNzJsLTU0IC01'
    b'OSAtMjEyIC0xNTZ6bS0zNzQ5IDMyM2wwIC0zNTkgLTIyOCA4OGMtMTIsNyAtMjQsMTQgLTM1'
    b'LDI0IC0xNiwyMCAtMTIsMzYgLTEsNTBsMjUxIDE3MiAxMyAyNSAwIDB6Ii8+DQogICA8ZWxs'
    b'aXBzZSBjbGFzcz0iZmlsMSIgY3g9IjE3OTExIiBjeT0iODkzNCIgcng9IjExOCIgcnk9IjE0'
    b'MyIvPg0KICAgPHBvbHlnb24gY2xhc3M9ImZpbDMiIHBvaW50cz0iMTc5MTQsOTEwMCAxNzkx'
    b'NCwxMzg1OCAxNzkyMCwxMzg4MCAxNzg2OSwxMzg4MCAxNzg3NCwxMzg1OCAxNzg3NCw5MTAw'
    b'IDE3ODY5LDkwNzcgMTc5MjAsOTA3NyAiLz4NCiAgIDxwYXRoIGNsYXNzPSJmaWwxIiBkPSJN'
    b'MTgwNTEgOTQ0NmwyNiAwYzIxLDQyIDQyLDg0IDYzLDEyNWwtODkgMGMtMzMsMCAtNjEsLTI4'
    b'IC02MSwtNjJsMCAwYzAsLTM1IDI4LC02MyA2MSwtNjNsMCAwem0tMjkxIDJjMjYsOCA0NCwz'
    b'MiA0NCw2MWwwIDBjMCwzNCAtMjcsNjIgLTYwLDYybC00MSAwYzIwLC00MCAzOSwtODEgNTcs'
    b'LTEyM2wwIDB6bTI5MSAzNzlsMTkxIDBjMjMsMzkgNDYsNzggNzAsMTE3IC05LDUgLTE5LDgg'
    b'LTI5LDhsLTIzMiAwYy0zMywwIC02MSwtMjggLTYxLC02MmwwIDBjMCwtMzUgMjgsLTYzIDYx'
    b'LC02M2wwIDB6bS00NTAgMGwxNDMgMGMzMywwIDYwLDI4IDYwLDYzbDAgMGMwLDM0IC0yNyw2'
    b'MiAtNjAsNjJsLTIyNCAwYzIyLC0zMiA0NCwtNjQgNjUsLTk4IDYsLTkgMTEsLTE4IDE2LC0y'
    b'N3ptMjk2IC0zYzM2LDAgNjYsMzAgNjYsNjYgMCwzNiAtMzAsNjUgLTY2LDY1IC0zNiwwIC02'
    b'NSwtMjkgLTY1LC02NSAwLC0zNiAyOSwtNjYgNjUsLTY2em0wIC0zODFjMzYsMCA2NiwzMCA2'
    b'Niw2NiAwLDM2IC0zMCw2NSAtNjYsNjUgLTM2LDAgLTY1LC0yOSAtNjUsLTY1IDAsLTM2IDI5'
    b'LC02NiA2NSwtNjZ6bS02MDUgODM1YzMsMjEgMTksMzggMzgsNDQgMTUsLTYgMjcsLTYgMzYs'
    b'LTEgMjEsLTggMzUsLTI4IDM1LC01MSAwLC0xMSAtMywtMjEgLTksLTMwIC0zMywxMyAtNjcs'
    b'MjYgLTEwMCwzOGwwIDB6bS0zMiA0OWM0LDUgNyw5IDEwLDE0IC0xOSw2IC0zOCwxMiAtNTYs'
    b'MTggMTMsLTE1IDI5LC0yNSA0NiwtMzJ6bTExODkgLTExMmMzMCwwIDU1LDI0IDU1LDU1IDAs'
    b'MzAgLTI1LDU1IC01NSw1NSAtMzEsMCAtNTUsLTI1IC01NSwtNTUgMCwtMzEgMjQsLTU1IDU1'
    b'LC01NXptODUgMTEyYy0zOCw0NyAtNDUsMTEzIC0zMSwxODMgNDUsMTcgOTYsMTkgMTMyLC0y'
    b'NiAtMTAsLTgzIC01MCwtMTM3IC0xMDEsLTE1N2wwIDB6bS00ODAgLTgybDIzMiAwYzMzLDAg'
    b'NjAsMjkgNjAsNjNsMCAwYzAsMzQgLTI3LDYzIC02MCw2M2wtMjMyIDBjLTMzLDAgLTYwLC0y'
    b'OSAtNjAsLTYzbDAgMGMwLC0zNCAyNywtNjMgNjAsLTYzem0tNDYzIDBsMTU2IDBjMzMsMCA2'
    b'MSwyOSA2MSw2M2wwIDBjMCwzNCAtMjgsNjMgLTYxLDYzbC0yMzIgMGMtMzMsMCAtNjAsLTI5'
    b'IC02MCwtNjNsMCAwYzAsLTggMSwtMTYgNCwtMjMgNDEsMjQgODgsMTQgMTMyLC00MGwwIDB6'
    b'bTMxMCAtMmMzNiwwIDY1LDI5IDY1LDY1IDAsMzYgLTI5LDY1IC02NSw2NSAtMzYsMCAtNjYs'
    b'LTI5IC02NiwtNjUgMCwtMzYgMzAsLTY1IDY2LC02NXptLTU1NSA4OTRjLTMwLDAgLTU1LDI1'
    b'IC01NSw1NSAwLDMxIDI1LDU1IDU1LDU1IDMwLDAgNTUsLTI0IDU1LC01NSAwLC0zMCAtMjUs'
    b'LTU1IC01NSwtNTV6bS04NiAxMTNjMzgsNDcgNDUsMTEzIDMyLDE4MyAtNDUsMTcgLTk3LDE5'
    b'IC0xMzIsLTI2IDEwLC04MyA1MCwtMTM3IDEwMCwtMTU3bDAgMHptMTE4OSAtMTEzYzMwLDAg'
    b'NTUsMjUgNTUsNTUgMCwzMSAtMjUsNTUgLTU1LDU1IC0zMSwwIC01NSwtMjQgLTU1LC01NSAw'
    b'LC0zMCAyNCwtNTUgNTUsLTU1em04NSAxMTNjLTM4LDQ3IC00NSwxMTMgLTMxLDE4MyA0NSwx'
    b'NyA5NiwxOSAxMzIsLTI2IC0xMCwtODMgLTUwLC0xMzcgLTEwMSwtMTU3bDAgMHptLTExODgg'
    b'MzQ5Yy0zMCwwIC01NSwyNSAtNTUsNTUgMCwzMCAyNSw1NSA1NSw1NSAzMCwwIDU1LC0yNSA1'
    b'NSwtNTUgMCwtMzAgLTI1LC01NSAtNTUsLTU1em0tODYgMTEzYzM4LDQ3IDQ1LDExMiAzMiwx'
    b'ODIgLTQ1LDE4IC05NywyMCAtMTMyLC0yNiAxMCwtODMgNTAsLTEzNyAxMDAsLTE1NmwwIDB6'
    b'bTExODkgLTExM2MzMCwwIDU1LDI1IDU1LDU1IDAsMzAgLTI1LDU1IC01NSw1NSAtMzEsMCAt'
    b'NTUsLTI1IC01NSwtNTUgMCwtMzAgMjQsLTU1IDU1LC01NXptODUgMTEzYy0zOCw0NyAtNDUs'
    b'MTEyIC0zMSwxODIgNDUsMTggOTYsMjAgMTMyLC0yNiAtMTAsLTgzIC01MCwtMTM3IC0xMDEs'
    b'LTE1NmwwIDB6bS00ODAgLTU0NGwyMzIgMGMzMywwIDYwLDI4IDYwLDYzbDAgMGMwLDM0IC0y'
    b'Nyw2MiAtNjAsNjJsLTIzMiAwYy0zMywwIC02MCwtMjggLTYwLC02MmwwIDBjMCwtMzUgMjcs'
    b'LTYzIDYwLC02M3ptLTUzOSAwbDIzMiAwYzMzLDAgNjEsMjggNjEsNjNsMCAwYzAsMzQgLTI4'
    b'LDYyIC02MSw2MmwtMjMyIDBjLTMzLDAgLTYwLC0yOCAtNjAsLTYybDAgMGMwLC0zNSAyNywt'
    b'NjMgNjAsLTYzem0tMTY5IDg5MmMtMzAsMCAtNTUsMjUgLTU1LDU1IDAsMzEgMjUsNTUgNTUs'
    b'NTUgMzAsMCA1NSwtMjQgNTUsLTU1IDAsLTMwIC0yNSwtNTUgLTU1LC01NXptLTg2IDExM2Mz'
    b'OCw0NyA0NSwxMTMgMzIsMTgyIC00NSwxOCAtOTcsMjAgLTEzMiwtMjUgMTAsLTgzIDUwLC0x'
    b'MzcgMTAwLC0xNTd6bTExODkgLTE0OTdjMzAsMCA1NSwyNSA1NSw1NSAwLDMwIC0yNSw1NSAt'
    b'NTUsNTUgLTMxLDAgLTU1LC0yNSAtNTUsLTU1IDAsLTMwIDI0LC01NSA1NSwtNTV6bTg1IDEx'
    b'M2MtMzgsNDcgLTQ1LDExMiAtMzEsMTgyIDQ1LDE4IDk2LDIwIDEzMiwtMjYgLTEwLC04MyAt'
    b'NTAsLTEzNyAtMTAxLC0xNTZ6bS00ODAgLTgybDIzMiAwYzMzLDAgNjAsMjggNjAsNjJsMCAw'
    b'YzAsMzUgLTI3LDYzIC02MCw2M2wtMjMyIDBjLTMzLDAgLTYwLC0yOCAtNjAsLTYzbDAgMGMw'
    b'LC0zNCAyNywtNjIgNjAsLTYyem0tNTM5IDBsMjMyIDBjMzMsMCA2MSwyOCA2MSw2MmwwIDBj'
    b'MCwzNSAtMjgsNjMgLTYxLDYzbC0yMzIgMGMtMzMsMCAtNjAsLTI4IC02MCwtNjNsMCAwYzAs'
    b'LTM0IDI3LC02MiA2MCwtNjJ6bTUzOSA5MjNsMjMyIDBjMzMsMCA2MCwyOCA2MCw2MmwwIDBj'
    b'MCwzNSAtMjcsNjMgLTYwLDYzbC0yMzIgMGMtMzMsMCAtNjAsLTI4IC02MCwtNjNsMCAwYzAs'
    b'LTM0IDI3LC02MiA2MCwtNjJ6bS01MzkgMGwyMzIgMGMzMywwIDYxLDI4IDYxLDYybDAgMGMw'
    b'LDM1IC0yOCw2MyAtNjEsNjNsLTIzMiAwYy0zMywwIC02MCwtMjggLTYwLC02M2wwIDBjMCwt'
    b'MzQgMjcsLTYyIDYwLC02MnptLTE2OSA4OTJjLTMwLDAgLTU1LDI1IC01NSw1NSAwLDMwIDI1'
    b'LDU1IDU1LDU1IDMwLDAgNTUsLTI1IDU1LC01NSAwLC0zMCAtMjUsLTU1IC01NSwtNTV6bS04'
    b'NiAxMTNjMzgsNDcgNDUsMTEyIDMyLDE4MiAtNDUsMTggLTk3LDIwIC0xMzIsLTI2IDEwLC04'
    b'MyA1MCwtMTM3IDEwMCwtMTU2bDAgMHptMTE4OSAtMTEzYzMwLDAgNTUsMjUgNTUsNTUgMCwz'
    b'MCAtMjUsNTUgLTU1LDU1IC0zMSwwIC01NSwtMjUgLTU1LC01NSAwLC0zMCAyNCwtNTUgNTUs'
    b'LTU1em04NSAxMTNjLTM4LDQ3IC00NSwxMTIgLTMxLDE4MiA0NSwxOCA5NiwyMCAxMzIsLTI2'
    b'IC0xMCwtODMgLTUwLC0xMzcgLTEwMSwtMTU2bDAgMHptLTYzMyAtMTQ2OWMzNiwwIDY1LDI5'
    b'IDY1LDY1IDAsMzYgLTI5LDY1IC02NSw2NSAtMzYsMCAtNjYsLTI5IC02NiwtNjUgMCwtMzYg'
    b'MzAsLTY1IDY2LC02NXptMCAtNDYyYzM2LDAgNjUsMjkgNjUsNjUgMCwzNiAtMjksNjYgLTY1'
    b'LDY2IC0zNiwwIC02NiwtMzAgLTY2LC02NiAwLC0zNiAzMCwtNjUgNjYsLTY1em0xNTMgMTM4'
    b'N2wyMzIgMGMzMywwIDYwLDI4IDYwLDYzbDAgMGMwLDM0IC0yNyw2MiAtNjAsNjJsLTIzMiAw'
    b'Yy0zMywwIC02MCwtMjggLTYwLC02MmwwIDBjMCwtMzUgMjcsLTYzIDYwLC02M3ptLTUzOSAw'
    b'bDIzMiAwYzMzLDAgNjEsMjggNjEsNjNsMCAwYzAsMzQgLTI4LDYyIC02MSw2MmwtMjMyIDBj'
    b'LTMzLDAgLTYwLC0yOCAtNjAsLTYybDAgMGMwLC0zNSAyNywtNjMgNjAsLTYzem0tMTY5IDg5'
    b'MmMtMzAsMCAtNTUsMjUgLTU1LDU1IDAsMzEgMjUsNTUgNTUsNTUgMzAsMCA1NSwtMjQgNTUs'
    b'LTU1IDAsLTMwIC0yNSwtNTUgLTU1LC01NXptLTg2IDExM2MzOCw0NyA0NSwxMTMgMzIsMTgy'
    b'IC00NSwxOCAtOTcsMjAgLTEzMiwtMjUgMTAsLTgzIDUwLC0xMzcgMTAwLC0xNTd6bTExODkg'
    b'LTExM2MzMCwwIDU1LDI1IDU1LDU1IDAsMzEgLTI1LDU1IC01NSw1NSAtMzEsMCAtNTUsLTI0'
    b'IC01NSwtNTUgMCwtMzAgMjQsLTU1IDU1LC01NXptODUgMTEzYy0zOCw0NyAtNDUsMTEzIC0z'
    b'MSwxODIgNDUsMTggOTYsMjAgMTMyLC0yNSAtMTAsLTgzIC01MCwtMTM3IC0xMDEsLTE1N3pt'
    b'LTYzMyAtMTQ2OWMzNiwwIDY1LDI5IDY1LDY1IDAsMzYgLTI5LDY2IC02NSw2NiAtMzYsMCAt'
    b'NjYsLTMwIC02NiwtNjYgMCwtMzYgMzAsLTY1IDY2LC02NXptMTUzIDkyNmwyMzIgMGMzMyww'
    b'IDYwLDI4IDYwLDYybDAgMGMwLDM1IC0yNyw2MyAtNjAsNjNsLTIzMiAwYy0zMywwIC02MCwt'
    b'MjggLTYwLC02M2wwIDBjMCwtMzQgMjcsLTYyIDYwLC02MnptLTUzOSAwbDIzMiAwYzMzLDAg'
    b'NjEsMjggNjEsNjJsMCAwYzAsMzUgLTI4LDYzIC02MSw2M2wtMjMyIDBjLTMzLDAgLTYwLC0y'
    b'OCAtNjAsLTYzbDAgMGMwLC0zNCAyNywtNjIgNjAsLTYyem0zODYgLTQ2NWMzNiwwIDY1LDMw'
    b'IDY1LDY2IDAsMzYgLTI5LDY1IC02NSw2NSAtMzYsMCAtNjYsLTI5IC02NiwtNjUgMCwtMzYg'
    b'MzAsLTY2IDY2LC02NnptMTUzIDkyNmwyMzIgMGMzMywwIDYwLDI4IDYwLDYzbDAgMGMwLDM0'
    b'IC0yNyw2MiAtNjAsNjJsLTIzMiAwYy0zMywwIC02MCwtMjggLTYwLC02MmwwIDBjMCwtMzUg'
    b'MjcsLTYzIDYwLC02M3ptLTUzOSAwbDIzMiAwYzMzLDAgNjEsMjggNjEsNjNsMCAwYzAsMzQg'
    b'LTI4LDYyIC02MSw2MmwtMjMyIDBjLTMzLDAgLTYwLC0yOCAtNjAsLTYybDAgMGMwLC0zNSAy'
    b'NywtNjMgNjAsLTYzem0zODYgLTQ2NGMzNiwwIDY1LDI5IDY1LDY1IDAsMzYgLTI5LDY2IC02'
    b'NSw2NiAtMzYsMCAtNjYsLTMwIC02NiwtNjYgMCwtMzYgMzAsLTY1IDY2LC02NXptMCA0NjFj'
    b'MzYsMCA2NSwzMCA2NSw2NiAwLDM2IC0yOSw2NSAtNjUsNjUgLTM2LDAgLTY2LC0yOSAtNjYs'
    b'LTY1IDAsLTM2IDMwLC02NiA2NiwtNjZ6Ii8+DQogIDwvZz4NCjwvc3ZnPg==', 'RU_RYA')

RU_RYA = b64_RU_RYA
index.append("RU_RYA")
index.append("Russia Ryazanskaya oblast")
catalog["RU_RYA"] = RU_RYA
catalog["Russia Ryazanskaya oblast"] = RU_RYA
country["Russia Ryazanskaya oblast"] = ('RU_RYA', '', 1)
lookup["RU_RYA"] = ('RU_RYA', '', 'Russia Ryazanskaya oblast', 1)
lookup["Ryazan"] = ('RU_RYA', '', 'Russia Ryazanskaya oblast', 1)
lookup["Russia Ryazanskaya oblast"] = ('RU_RYA', '', 'Russia Ryazanskaya oblast', 1)
details["RU_RYA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Ryazan"}
regional["RU_RYA"] = ('RU_RYA', 'Russia Ryazanskaya oblast', 1)
regional["Russia Ryazanskaya oblast"] = ('RU_RYA', 'Russia Ryazanskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_SA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMTI4MCIgaGVpZ2h0PSI2NDAiPg0K'
    b'PHBhdGggZD0iTTAgMEgxMjgwVjY0MEgweiIgZmlsbD0iIzA5MCIvPg0KPHBhdGggZD0iTTAg'
    b'MEgxMjgwVjU2MEgweiIgZmlsbD0iI0ZGMjQwMCIvPg0KPHBhdGggZD0iTTAgMEgxMjgwVjUy'
    b'MEgweiIgZmlsbD0iI0ZGRiIvPg0KPHBhdGggZD0iTTAgMEgxMjgwVjQ4MEgweiIgZmlsbD0i'
    b'IzE5RiIvPg0KPGNpcmNsZSBjeD0iNjQwIiBjeT0iMjQwIiByPSIxMjgiIGZpbGw9IiNGRkYi'
    b'Lz4NCjwvc3ZnPg==', 'RU_SA')

RU_SA = b64_RU_SA
index.append("RU_SA")
index.append("Russia Saha Respublika")
catalog["RU_SA"] = RU_SA
catalog["Russia Saha Respublika"] = RU_SA
country["Russia Saha Respublika"] = ('RU_SA', '', 1)
lookup["RU_SA"] = ('RU_SA', '', 'Russia Saha Respublika', 1)
lookup["Sakha"] = ('RU_SA', '', 'Russia Saha Respublika', 1)
lookup["Russia Saha Respublika"] = ('RU_SA', '', 'Russia Saha Respublika', 1)
details["RU_SA"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00 | +11:00","altname":"Sakha"}
regional["RU_SA"] = ('RU_SA', 'Russia Saha Respublika', 1)
regional["Russia Saha Respublika"] = ('RU_SA', 'Russia Saha Respublika', 1)
#----------------------------------------------------------------------
b64_RU_SAK = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSIgc3RhbmRhbG9uZT0i'
    b'bm8iPz4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMjAwMTA5MDQv'
    b'L0VOIg0KICAgICJodHRwOi8vd3d3LnczLm9yZy9UUi8yMDAxL1JFQy1TVkctMjAwMTA5MDQv'
    b'RFREL3N2ZzEwLmR0ZCI+DQo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2'
    b'ZyINCiAgICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHht'
    b'bDpzcGFjZT0icHJlc2VydmUiDQoJIHdpZHRoPSI0NTBweCIgaGVpZ2h0PSIzMDBweCINCgkg'
    b'dmlld0JveD0iMCAwIDQ1MCAzMDAiPg0KPHJlY3Qgd2lkdGg9IjQ1MCIgaGVpZ2h0PSIzMDAi'
    b'IGZpbGw9IiM0N2E1YWUiIC8+DQo8cGF0aCBmaWxsPSJ3aGl0ZSIgZD0iTSAyMTcuMywyNjEu'
    b'OCBDIDIxNywyNjEuMSAyMTYuMiwyNjEgMjE2LjIsMjYxLjYgQyAyMTYuMiwyNjIgMjE2LjUs'
    b'MjYyLjMgMjE2LjgsMjYyLjMgQyAyMTcuMiwyNjIuMyAyMTcuNCwyNjIuMSAyMTcuMywyNjEu'
    b'OCB6IE0gMjE2LDI2MS4xIEMgMjE2LjMsMjYwLjYgMjE1LjgsMjU5LjYgMjE1LjIsMjU5LjYg'
    b'QyAyMTQuNSwyNTkuNiAyMTQuMiwyNjAuMSAyMTQuNSwyNjAuOSBDIDIxNC44LDI2MS41IDIx'
    b'NS42LDI2MS43IDIxNiwyNjEuMSB6IE0gMjE4LjksMjYwLjkgQyAyMTkuMywyNjAuNCAyMTku'
    b'MywyNjAuMiAyMTguOSwyNTkuNyBDIDIxOC4xLDI1OSAyMTcsMjU5LjQgMjE3LDI2MC4zIEMg'
    b'MjE3LDI2MC45IDIxNy40LDI2MS40IDIxOC4yLDI2MS41IEMgMjE4LjMsMjYxLjUgMjE4Ljcs'
    b'MjYxLjIgMjE4LjksMjYwLjkgeiBNIDIyMC4xLDI1OC4zIEMgMjIwLjEsMjU3LjQgMjE5LjUs'
    b'MjU2LjkgMjE4LjYsMjU3LjEgQyAyMTguMSwyNTcuMiAyMTcuOCwyNTcuNiAyMTcuOCwyNTgg'
    b'QyAyMTcuOCwyNTguNiAyMTgsMjU4LjggMjE4LjksMjU4LjggQyAyMTkuNiwyNTguOCAyMjAu'
    b'MSwyNTguNiAyMjAuMSwyNTguMyB6IE0gMjA2LjQsMjU1LjMgQyAyMDYuNCwyNTIuNyAyMDYu'
    b'NCwyNTIuNiAyMDguMiwyNTAuNiBDIDIwOS44LDI0OC45IDIxMCwyNDguNCAyMTAsMjQ3IEMg'
    b'MjEwLDI0NiAyMTAuMywyNDUuMSAyMTAuNiwyNDQuOCBDIDIxMSwyNDQuNiAyMTEuNSwyNDMu'
    b'OCAyMTEuOCwyNDMuMSBDIDIxMi4xLDI0Mi4zIDIxMi41LDI0MS44IDIxMi44LDI0MS44IEMg'
    b'MjEzLjEsMjQxLjcgMjEzLjksMjQxLjIgMjE0LjYsMjQwLjYgQyAyMTUuNCwyNDAgMjE2LjIs'
    b'MjM5LjQgMjE2LjUsMjM5LjQgQyAyMTYuOCwyMzkuNCAyMTcsMjM5LjMgMjE3LDIzOS4xIEMg'
    b'MjE3LDIzOC45IDIxNy42LDIzOC42IDIxOC4zLDIzOC41IEMgMjE5LjMsMjM4LjMgMjE5Ljcs'
    b'MjM4IDIxOS45LDIzNy4yIEMgMjIwLjMsMjM1LjcgMjE5LjYsMjM1LjQgMjE3LjcsMjM2LjEg'
    b'QyAyMTUuOCwyMzYuOCAyMTQuNSwyMzYuOSAyMTMuNiwyMzYuNCBDIDIxMy4yLDIzNi4yIDIx'
    b'Mi43LDIzNi4xIDIxMi41LDIzNi4zIEMgMjEyLDIzNi42IDIxMC44LDIzOSAyMTAuOCwyMzku'
    b'NiBDIDIxMC44LDIzOS44IDIxMC4zLDI0MSAyMDkuOCwyNDIuMyBDIDIwOC4zLDI0NS44IDIw'
    b'OC4yLDI0NiAyMDcuNywyNDggQyAyMDcuNCwyNDkuMiAyMDYuNywyNTAuNCAyMDUuOCwyNTEu'
    b'MyBDIDIwNSwyNTIuMSAyMDQuMiwyNTMuMiAyMDQsMjUzLjggQyAyMDMuOSwyNTQuMyAyMDMu'
    b'NiwyNTQuOSAyMDMuNCwyNTUuMiBDIDIwMi45LDI1NS44IDIwMy40LDI1Ni44IDIwNC4yLDI1'
    b'Ni44IEMgMjA0LjYsMjU2LjggMjA1LjEsMjU3LjEgMjA1LjQsMjU3LjQgQyAyMDYuMywyNTgu'
    b'NSAyMDYuNSwyNTggMjA2LjQsMjU1LjMgeiBNIDIyOC4xLDI0OS40IEMgMjI4LjYsMjQ4Ljkg'
    b'MjI5LDI0OC40IDIyOSwyNDguMSBDIDIyOSwyNDcuOCAyMjkuMSwyNDcuNiAyMjkuMywyNDcu'
    b'NiBDIDIyOS41LDI0Ny42IDIyOS44LDI0Ny4xIDIzMCwyNDYuNiBDIDIzMC40LDI0NS45IDIz'
    b'MC40LDI0NS43IDIyOS45LDI0NS41IEMgMjI4LjksMjQ1LjEgMjI4LjcsMjQ1LjIgMjI2Ljks'
    b'MjQ2LjggQyAyMjUuOSwyNDcuNiAyMjUsMjQ4LjMgMjI0LjcsMjQ4LjQgQyAyMjQuMSwyNDgu'
    b'NiAyMjQuNiwyNDkuNyAyMjUuNiwyNTAuMiBDIDIyNi41LDI1MC42IDIyNi44LDI1MC41IDIy'
    b'OC4xLDI0OS40IHogTSAxNzcuOSwyNDguNCBDIDE3Ny45LDI0OCAxNzguMiwyNDcuNSAxNzgu'
    b'NSwyNDcuMiBDIDE3OC44LDI0NyAxNzkuMiwyNDUuOSAxNzkuNSwyNDQuOSBDIDE3OS45LDI0'
    b'My4xIDE4MCwyNDIgMTc5LjksMjM1LjggQyAxNzkuOSwyMzMuOSAxODAsMjMxLjUgMTgwLjMs'
    b'MjMwLjQgQyAxODAuNywyMjguNiAxODAuOSwyMjguMyAxODIuNCwyMjcuNiBMIDE4NCwyMjYu'
    b'OCBMIDE4Ni40LDIyOC4xIEMgMTg5LjEsMjI5LjQgMTg5LjksMjI5LjUgMTkzLjEsMjI4LjQg'
    b'QyAxOTUuMywyMjcuNyAxOTUuNywyMjcuOSAxOTUuNywyMjkuOSBDIDE5NS43LDIzMS4xIDE5'
    b'Ni44LDIzNCAxOTcuMywyMzQgQyAxOTcuNCwyMzQgMTk3LjgsMjM0LjYgMTk4LjEsMjM1LjMg'
    b'QyAxOTguNCwyMzYgMTk4LjksMjM3LjEgMTk5LjMsMjM3LjkgQyAyMDAsMjM5IDIwMC4yLDIz'
    b'OS4xIDIwMC42LDIzOC41IEMgMjAwLjgsMjM4LjIgMjAxLDIzNi45IDIwMC45LDIzNS4yIEMg'
    b'MjAwLjgsMjMzLjcgMjAwLjksMjMyLjEgMjAxLjEsMjMxLjggQyAyMDEuNCwyMzEuMyAyMDEu'
    b'MiwyMzAuNCAyMDAuNiwyMjguOCBDIDIwMC4xLDIyNy41IDE5OS40LDIyNS43IDE5OSwyMjQu'
    b'NyBDIDE5OC4xLDIyMi4yIDE5Ni4zLDIyMC44IDE5NC43LDIyMS4yIEMgMTkzLjEsMjIxLjcg'
    b'MTkwLjMsMjIwLjggMTg4LjgsMjE5LjMgQyAxODcuNywyMTguMyAxODUuMywyMTMuOSAxODUu'
    b'MywyMTIuOSBDIDE4NS4yLDIxMS45IDE4MC41LDIwNy43IDE3Ni43LDIwNS4zIEMgMTc1LDIw'
    b'NC4zIDE3Mi40LDE5OC4zIDE3MS45LDE5NC40IEMgMTcxLjgsMTkzLjggMTcxLjYsMTkyLjMg'
    b'MTcxLjMsMTkxLjIgQyAxNzEuMSwxOTAuMSAxNzAuOSwxODguMSAxNzAuOCwxODYuOCBDIDE3'
    b'MC43LDE4NS40IDE3MC41LDE4My45IDE3MC4zLDE4My40IEMgMTcwLjEsMTgyLjggMTcwLDE4'
    b'Mi4xIDE3MC4yLDE4MS44IEMgMTcwLjQsMTgxLjUgMTcwLjYsMTgwLjMgMTcwLjgsMTc5LjIg'
    b'QyAxNzAuOSwxNzggMTcxLjMsMTc2LjUgMTcxLjYsMTc1LjggQyAxNzIuMywxNzQuMiAxNzIu'
    b'MywxNzIuNiAxNzEuNywxNjguNiBDIDE3MS4zLDE2NS40IDE3MS4zLDE2NS4zIDE3Mi4xLDE2'
    b'NC41IEMgMTcyLjUsMTY0IDE3My4xLDE2My43IDE3My4zLDE2My43IEMgMTczLjUsMTYzLjcg'
    b'MTc0LjMsMTYzLjIgMTc1LDE2Mi43IEMgMTc1LjcsMTYyLjIgMTc2LjUsMTYxLjcgMTc2Ljcs'
    b'MTYxLjcgQyAxNzYuOSwxNjEuNyAxNzcuMiwxNjEuNiAxNzcuMiwxNjEuNCBDIDE3Ny4zLDE2'
    b'MS4zIDE3OC42LDE2MC44IDE4MC4xLDE2MC4zIEMgMTg0LjMsMTU5LjEgMTg3LjIsMTU5LjUg'
    b'MTg5LjksMTYyIEMgMTkwLjQsMTYyLjQgMTkyLjIsMTYzLjYgMTkzLjksMTY0LjUgQyAxOTUu'
    b'OCwxNjUuNiAxOTguMSwxNjcuMyAxOTkuNSwxNjguNyBDIDIwMC44LDE3MC4xIDIwMiwxNzEg'
    b'MjAyLjEsMTcwLjkgQyAyMDIuMywxNzAuOCAyMDIsMTY5LjkgMjAxLjYsMTY4LjkgQyAyMDEu'
    b'MSwxNjcuOSAyMDAuNywxNjcgMjAwLjcsMTY2LjcgQyAyMDAuNywxNjUuNiAxOTkuNCwxNjQu'
    b'MSAxOTcuOSwxNjMuNyBDIDE5NC44LDE2Mi44IDE5Mi43LDE2MS4xIDE5MS40LDE1OC41IEMg'
    b'MTg5LjcsMTU1IDE4Ny42LDE1MS42IDE4Ni41LDE1MC4zIEMgMTg1LjksMTQ5LjcgMTg1LjIs'
    b'MTQ4LjYgMTg0LjksMTQ4IEMgMTg0LjYsMTQ3LjQgMTg0LjIsMTQ2LjggMTg0LjEsMTQ2Ljcg'
    b'QyAxODMuMiwxNDUuOCAxNzkuOSwxNDEuNCAxNzkuMywxNDAuMSBDIDE3OC44LDEzOS4zIDE3'
    b'Ny43LDEzNy43IDE3Ni44LDEzNi43IEMgMTczLjksMTMzLjMgMTczLjMsMTMyLjUgMTczLjEs'
    b'MTMxLjQgQyAxNzIuOSwxMzAuNyAxNzIuNiwxMzAgMTcyLjQsMTI5LjYgQyAxNzIuMSwxMjku'
    b'MyAxNzEuNSwxMjggMTcxLDEyNi43IEMgMTcwLjUsMTI1LjUgMTY5LjYsMTIzLjcgMTY5LDEy'
    b'Mi44IEMgMTY3LjUsMTIwLjYgMTY2LjcsMTE4LjcgMTY2LjcsMTE3LjMgQyAxNjYuNywxMTYg'
    b'MTY1LjMsMTE0LjEgMTY0LjQsMTE0LjMgQyAxNjQsMTE0LjMgMTYzLjMsMTE0IDE2Mi44LDEx'
    b'My42IEwgMTYxLjgsMTEyLjkgTCAxNjIuNSwxMTEuOCBDIDE2My40LDExMC43IDE2My40LDEx'
    b'MC45IDE2MS41LDEwNy42IEMgMTYwLjgsMTA2LjQgMTU5LjcsMTA1LjMgMTU5LjEsMTA1LjMg'
    b'QyAxNTguOSwxMDUuMyAxNTguNiwxMDUuOCAxNTguNSwxMDYuMyBDIDE1OC4zLDEwOC4yIDE1'
    b'Ny40LDEwNy45IDE1Ny41LDEwNiBDIDE1Ny42LDEwMy43IDE1Ni42LDEwMS42IDE1NC44LDEw'
    b'MC40IEMgMTUzLjgsOTkuNyAxNTMuMiw5OC44IDE1Mi44LDk3LjggQyAxNTIsOTUuNCAxNTEu'
    b'Nyw5My4zIDE1Mi4xLDkzLjIgQyAxNTIuMyw5My4yIDE1MS44LDkxLjQgMTUxLDg5LjMgQyAx'
    b'NDkuOCw4NS43IDE0OS43LDg1LjQgMTUwLjIsODQuMyBDIDE1MC43LDgzLjQgMTUwLjgsODMu'
    b'MyAxNTEsODMuOCBDIDE1MS4xLDg0LjIgMTUxLjEsODQuNyAxNTAuOSw4NS4xIEMgMTUwLjYs'
    b'ODUuNyAxNTAuOCw4Ny41IDE1MS4yLDg3LjUgQyAxNTEuNyw4Ny41IDE1Mi45LDgzLjQgMTUy'
    b'LjcsODIuNCBDIDE1Mi4zLDgwLjIgMTUxLjQsNzcuOSAxNTAuMyw3Ni4xIEMgMTQ5LjYsNzUg'
    b'MTQ4LjksNzMuNyAxNDguOCw3My4xIEMgMTQ4LjUsNzEuOSAxNDcuOCw3MiAxNDcuOCw3My4z'
    b'IEMgMTQ3LjgsNzQuNSAxNDcuMiw3NCAxNDQuOSw3MC44IEMgMTQyLjQsNjcuMiAxNDEuOSw2'
    b'Ni4xIDE0My4xLDY1LjcgQyAxNDQsNjUuNSAxNDQuNCw2NiAxNDQuOCw2Ny44IEMgMTQ1LjEs'
    b'NjguOSAxNDcuOSw3MS4yIDE0OC4xLDcwLjUgQyAxNDguMiw3MC4yIDE0Ny43LDY5LjIgMTQ3'
    b'LDY4LjEgQyAxNDYuNCw2Ny4xIDE0NS44LDY1LjkgMTQ1LjgsNjUuNSBDIDE0NS44LDY0LjYg'
    b'MTQzLjksNjIuOCAxNDMsNjIuOCBDIDE0Mi42LDYyLjggMTQyLjEsNjIuMyAxNDEuOSw2MS42'
    b'IEMgMTQxLjYsNjEgMTQxLDYwLjMgMTQwLjYsNjAuMSBDIDE0MC4xLDU5LjkgMTM5LjcsNTku'
    b'NCAxMzkuNyw1OSBDIDEzOS43LDU4LjMgMTM3LjYsNTUuMiAxMzYuNiw1NC40IEMgMTM2LDUz'
    b'LjkgMTM1LjcsNDkuNyAxMzYuMiw0OSBDIDEzNy4xLDQ3LjkgMTMzLjcsNDIuMyAxMzIuMSw0'
    b'Mi4zIEMgMTMxLjgsNDIuMyAxMzEuMyw0MS44IDEzMS4xLDQxLjMgQyAxMzAuNSw0MC4xIDEy'
    b'OS41LDQwLjIgMTI5LjMsNDEuNCBDIDEyOS4yLDQxLjkgMTI5LjUsNDIuNiAxMzAuMSw0My4y'
    b'IEMgMTMwLjcsNDMuOCAxMzAuOSw0NC4yIDEzMC42LDQ0LjIgQyAxMzAuMyw0NC4yIDEyOS45'
    b'LDQ0LjUgMTI5LjYsNDQuOCBDIDEyOS4zLDQ1LjEgMTI4LjksNDUuMiAxMjguNyw0NS4xIEMg'
    b'MTI4LjUsNDQuOSAxMjcuMSw0NC44IDEyNS43LDQ0LjggTCAxMjMuMSw0NC43IEwgMTI1LjMs'
    b'NDYuOCBDIDEyNy44LDQ5LjIgMTMwLjcsNTEuMiAxMzEuMiw1MC45IEMgMTMxLjgsNTAuNiAx'
    b'MzIuMyw1Mi43IDEzMi4yLDU1IEMgMTMyLjEsNTcuOSAxMzIuOCw1OC44IDEzMy42LDU2Ljkg'
    b'QyAxMzQuNiw1NC40IDEzNS43LDU0LjcgMTM1LjIsNTcuMyBDIDEzNC45LDU5IDEzNC4yLDU5'
    b'LjUgMTMzLjEsNTguOSBDIDEzMi41LDU4LjYgMTMyLjMsNTguNiAxMzIuMyw1OS4xIEMgMTMy'
    b'LjMsNTkuOSAxMzIuNSw2MC4zIDEzMi43LDYwLjIgQyAxMzIuOCw2MC4xIDEzMy4xLDYwLjUg'
    b'MTMzLjMsNjEuMSBDIDEzMy42LDYxLjYgMTMzLjYsNjIgMTMzLjQsNjIgQyAxMzMuMyw2MiAx'
    b'MzMuMiw2Mi42IDEzMy4zLDYzLjQgQyAxMzMuNCw2NC44IDEzMy4zLDY1IDEzMS41LDY2LjEg'
    b'QyAxMzAuNSw2Ni44IDEyOS42LDY3LjMgMTI5LjUsNjcuMSBDIDEyOS40LDY2LjkgMTI5LjIs'
    b'NjYgMTI5LjEsNjUgQyAxMjguOSw2NCAxMjguNiw2My4xIDEyOC41LDYzLjEgQyAxMjcuOSw2'
    b'My4xIDEyNS43LDY0LjQgMTI1LjcsNjQuNyBDIDEyNS43LDY0LjggMTI1LjEsNjUuNyAxMjQu'
    b'NCw2Ni41IEMgMTIyLjgsNjguNCAxMjIuOCw2OS40IDEyNC42LDcyLjYgQyAxMjYuNSw3Ni4x'
    b'IDEyNy43LDc5LjYgMTI3LjcsODEuNiBDIDEyNy43LDgzLjIgMTI4LjMsODYuMiAxMjkuNCw5'
    b'MC4xIEMgMTI5LjcsOTEgMTI5LDkyLjMgMTI4LjQsOTEuOSBDIDEyOC4yLDkxLjggMTI4LjEs'
    b'OTIuMSAxMjguMSw5Mi42IEMgMTI4LjEsOTMuMSAxMjcuOSw5My43IDEyNy43LDkzLjkgQyAx'
    b'MjcuMiw5NC40IDEyOC40LDk3LjIgMTI5LDk3IEMgMTI5LjksOTYuNiAxMzAuMyw5Ny41IDEz'
    b'MC43LDEwMSBDIDEzMS40LDEwNS44IDEzMS41LDEwNi40IDEzMi4xLDEwNi40IEMgMTMzLjIs'
    b'MTA2LjQgMTM0LjcsMTA4LjMgMTM0LjksMTA5LjggQyAxMzUsMTEwLjkgMTM1LjQsMTExLjcg'
    b'MTM3LDExMy4zIEMgMTM4LjEsMTE0LjQgMTM5LjIsMTE1LjIgMTM5LjMsMTE1LjEgQyAxMzku'
    b'OCwxMTQuOCAxNDEuMiwxMTUuMyAxNDEuMiwxMTUuOSBDIDE0MS4yLDExNi4xIDE0MS42LDEx'
    b'Ni42IDE0MiwxMTcgQyAxNDIuNCwxMTcuNCAxNDIuOCwxMTcuNiAxNDIuOCwxMTcuNSBDIDE0'
    b'Mi44LDExNy4zIDE0My4xLDExNy40IDE0My41LDExNy42IEMgMTQzLjksMTE3LjkgMTQ0LjIs'
    b'MTE4LjMgMTQ0LDExOC43IEMgMTQzLjksMTE5LjUgMTQ2LjIsMTIzLjMgMTQ3LjUsMTI0LjIg'
    b'QyAxNDguNSwxMjQuOSAxNDguNCwxMjUuOCAxNDcuMiwxMjUuNiBDIDE0Ni4yLDEyNS4zIDE0'
    b'Ni4xLDEyNS40IDE0NS41LDEzMC4zIEMgMTQ1LDEzMy40IDE0NS4yLDEzNCAxNDcuNSwxMzgu'
    b'OSBDIDE0OC4zLDE0MC41IDE0OC45LDE0MiAxNDguOSwxNDIuMyBDIDE0OC45LDE0Mi42IDE0'
    b'OS40LDE0My44IDE1MC4xLDE0NC45IEMgMTUwLjcsMTQ2LjEgMTUxLjMsMTQ3LjkgMTUxLjUs'
    b'MTQ5LjIgQyAxNTEuNiwxNTAuNSAxNTIuMSwxNTIuNSAxNTIuNiwxNTMuOCBDIDE1NC40LDE1'
    b'OC41IDE1NS4yLDE2Mi4zIDE1NS4zLDE2Ni4yIEMgMTU1LjUsMTcwLjMgMTU1LjYsMTcxLjcg'
    b'MTU2LjIsMTc1LjYgQyAxNTYuNywxNzguNCAxNTYuNSwxNzkuMiAxNTQuOCwxODEgTCAxNTMu'
    b'NiwxODIuMyBMIDE1NC42LDE4My4xIEMgMTU1LjIsMTgzLjYgMTU2LjEsMTg0LjIgMTU2Ljcs'
    b'MTg0LjQgQyAxNTcuMiwxODQuNyAxNTguMiwxODUuOCAxNTksMTg3LjMgQyAxNTkuNywxODgu'
    b'NiAxNjAuOSwxOTAuMyAxNjEuNSwxOTAuOSBDIDE2Mi45LDE5Mi4zIDE2My42LDE5My41IDE2'
    b'NS4zLDE5Ny41IEMgMTY1LjYsMTk4LjIgMTY1LjgsMjAwLjggMTY1LjgsMjA0LjcgQyAxNjUu'
    b'OCwyMTIuOCAxNjYuOCwyMTUuNiAxNzEuMSwyMjAuMyBDIDE3Mi43LDIyMiAxNzIuNywyMjIu'
    b'MyAxNzIsMjI0LjIgQyAxNzEuNywyMjQuOSAxNzEuNSwyMjUuNiAxNzEuNiwyMjUuNyBDIDE3'
    b'MS43LDIyNS44IDE3MS42LDIyNi4xIDE3MS4zLDIyNi41IEMgMTcwLjksMjI2LjggMTcwLjUs'
    b'MjI4LjEgMTcwLjQsMjI5LjUgQyAxNzAuMiwyMzAuOCAxNzAsMjMyLjIgMTY5LjgsMjMyLjUg'
    b'QyAxNjkuNSwyMzMuMiAxNzAuMSwyMzUuMiAxNzEsMjM2LjIgQyAxNzEuOSwyMzcuMyAxNzIu'
    b'OCwyMzkuOCAxNzMuNywyNDMuMSBDIDE3NC40LDI0NiAxNzUsMjQ3IDE3NS43LDI0Ni41IEMg'
    b'MTc1LjksMjQ2LjQgMTc2LjMsMjQ3IDE3Ni42LDI0Ny43IEMgMTc3LjIsMjQ5LjIgMTc3Ljks'
    b'MjQ5LjYgMTc3LjksMjQ4LjQgeiBNIDIyNy41LDIzMS4yIEMgMjI5LjYsMjI5LjMgMjMwLjEs'
    b'MjI4LjQgMjMwLjYsMjI2LjcgQyAyMzEsMjI1LjUgMjMyLDIyMy40IDIzMi44LDIyMiBDIDIz'
    b'My43LDIyMC43IDIzNC40LDIxOS4yIDIzNC40LDIxOC45IEMgMjM0LjQsMjE3LjkgMjM1LjUs'
    b'MjE3IDIzNi44LDIxNyBDIDIzOC4zLDIxNyAyNDAsMjE1LjIgMjQyLDIxMS43IEMgMjQ0LjIs'
    b'MjA3LjYgMjQ0LjgsMjA2LjkgMjQ2LjksMjA2IEMgMjQ5LDIwNS4xIDI1MSwyMDMuMiAyNTEu'
    b'MSwyMDIgQyAyNTEuMSwyMDEuNCAyNTEuMSwxOTguOSAyNTEsMTk4LjQgQyAyNTEsMTk4LjIg'
    b'MjUwLjUsMTk4LjEgMjQ5LjksMTk4LjEgQyAyNDguMywxOTguMSAyNDUuMywyMDAuMiAyNDQu'
    b'NiwyMDEuNyBDIDI0NC4zLDIwMi41IDI0My45LDIwMy4yIDI0My43LDIwMy4zIEMgMjQzLjQs'
    b'MjAzLjQgMjQzLjQsMjAzLjcgMjQzLjUsMjAzLjkgQyAyNDQsMjA0LjcgMjQxLjcsMjA3LjMg'
    b'MjM5LjcsMjA4LjIgQyAyMzguNywyMDguNiAyMzguNCwyMDguNSAyMzcuNCwyMDcuNyBDIDIz'
    b'NS43LDIwNi41IDIzNSwyMDcgMjM1LDIwOS42IEMgMjM1LDIxMS4xIDIzNC44LDIxMS44IDIz'
    b'NC4xLDIxMi41IEMgMjMzLjYsMjEzIDIzMy4yLDIxMy43IDIzMy4yLDIxNC4xIEMgMjMzLjIs'
    b'MjE0LjcgMjMzLDIxNC45IDIzMS4yLDIxNS4zIEMgMjMwLjUsMjE1LjQgMjMwLjIsMjE1Ljcg'
    b'MjMwLjQsMjE2LjEgQyAyMzAuNywyMTYuOSAyMzAuMiwyMTguNCAyMjkuMiwyMTkuNiBDIDIy'
    b'OC43LDIyMC4yIDIyOC4xLDIyMS4zIDIyOCwyMjEuOSBDIDIyNy44LDIyMi41IDIyNy4zLDIy'
    b'My4zIDIyNi45LDIyMy43IEMgMjI2LjIsMjI0LjIgMjI2LjIsMjI0LjQgMjI2LjYsMjI1LjMg'
    b'QyAyMjcuMiwyMjYuNyAyMjcuMiwyMjYuOSAyMjYuMSwyMjcuNCBDIDIyNS40LDIyNy43IDIy'
    b'NS4yLDIyOCAyMjUuNCwyMjguNSBDIDIyNS41LDIyOS4xIDIyNS4zLDIyOS40IDIyNC43LDIy'
    b'OS41IEMgMjI0LjIsMjI5LjYgMjIzLjksMjMwIDIyMy45LDIzMC43IEMgMjIzLjksMjMxLjcg'
    b'MjI0LjYsMjMzLjYgMjI0LjksMjMzLjYgQyAyMjUsMjMzLjYgMjI2LjIsMjMyLjYgMjI3LjUs'
    b'MjMxLjIgeiBNIDI2MC40LDE5My41IEMgMjYxLjcsMTkyLjYgMjYzLDE5MC44IDI2MywxODku'
    b'OSBDIDI2MywxODkuNSAyNjQsMTg4LjIgMjY1LjMsMTg2LjkgQyAyNjYuOCwxODUuNCAyNjcu'
    b'NiwxODQuMiAyNjcuNiwxODMuNiBDIDI2Ny42LDE4Mi4xIDI2OC41LDE4MC4yIDI2OS42LDE3'
    b'OC45IEMgMjcwLjIsMTc4LjMgMjcwLjgsMTc3LjMgMjcwLjksMTc2LjYgQyAyNzEuMSwxNzYg'
    b'MjcxLjQsMTc1LjMgMjcxLjYsMTc1IEMgMjcyLjUsMTczLjkgMjcxLDE3My42IDI2OC42LDE3'
    b'NC41IEMgMjY3LjUsMTc0LjkgMjY3LjIsMTc1LjMgMjY3LjEsMTc3IEMgMjY3LDE3Ny44IDI2'
    b'Ni45LDE3OC41IDI2Ni44LDE3OC41IEMgMjY1LjMsMTc5LjYgMjY0LjMsMTgwLjUgMjYzLjUs'
    b'MTgxLjcgQyAyNjIuNywxODIuOSAyNjIuNiwxODMuNSAyNjIuNywxODQuOSBMIDI2Mi45LDE4'
    b'Ni43IEwgMjYxLjEsMTg3LjUgQyAyNTkuMywxODguMyAyNTkuMiwxODguMyAyNTksMTkwLjQg'
    b'QyAyNTguOSwxOTEuNSAyNTguNywxOTIuOSAyNTguNSwxOTMuMyBDIDI1OC4yLDE5NC40IDI1'
    b'OC45LDE5NC41IDI2MC40LDE5My41IHogTSAyNzUsMTY3IEMgMjc1LDE2Ni4yIDI3NC41LDE2'
    b'NiAyNzMuOCwxNjYuNCBDIDI3My40LDE2Ni42IDI3My40LDE2Ni44IDI3My44LDE2Ny4zIEMg'
    b'Mjc0LjMsMTY4IDI3NSwxNjcuOCAyNzUsMTY3IHogTSAyNzUuNywxNjUuMSBDIDI3Ni4zLDE2'
    b'NC41IDI3NS41LDE2My43IDI3NC42LDE2My45IEMgMjczLjcsMTY0LjIgMjczLjYsMTY0LjUg'
    b'Mjc0LjMsMTY1LjEgQyAyNzQuOSwxNjUuNyAyNzUuMSwxNjUuNyAyNzUuNywxNjUuMSB6IE0g'
    b'MjcxLjYsMTYwLjkgQyAyNzEuNCwxNjAuMSAyNjkuOCwxNTkuOSAyNjkuNCwxNjAuNiBDIDI2'
    b'OC45LDE2MS4zIDI2OS45LDE2MiAyNzAuOSwxNjEuOCBDIDI3MS42LDE2MS43IDI3MS43LDE2'
    b'MS41IDI3MS42LDE2MC45IHogTSAyODcuOSwxNTMuMyBDIDI4OC4yLDE1MyAyODguNywxNTIg'
    b'Mjg5LjEsMTUxIEMgMjg5LjUsMTUwIDI4OS45LDE0OSAyOTAuMSwxNDguOCBDIDI5MC4zLDE0'
    b'OC42IDI5MC40LDE0OCAyOTAuNCwxNDcuNCBDIDI5MC40LDE0Ni45IDI5MC45LDE0NS42IDI5'
    b'MS40LDE0NC42IEMgMjkyLjUsMTQyLjYgMjkyLjIsMTQyLjEgMjkwLjUsMTQyLjkgQyAyODku'
    b'OCwxNDMuMiAyODkuNCwxNDMuOCAyODkuMiwxNDQuNyBDIDI4OC45LDE0Ni4zIDI4OCwxNDgu'
    b'OCAyODcuNiwxNDkuMiBDIDI4Ny41LDE0OS40IDI4Ny4zLDE0OS45IDI4Ny4zLDE1MC4zIEMg'
    b'Mjg3LjMsMTUxLjIgMjg2LjUsMTUyLjIgMjg1LjMsMTUyLjYgQyAyODQuNywxNTIuOCAyODQu'
    b'NiwxNTMgMjg1LDE1My40IEMgMjg1LjUsMTU0IDI4NywxNTQgMjg3LjksMTUzLjMgeiBNIDI5'
    b'My44LDEzNy44IEMgMjk0LjEsMTM3LjYgMjk0LjEsMTM3LjMgMjkzLjUsMTM2LjYgQyAyOTIu'
    b'OCwxMzUuNyAyOTIuOCwxMzUuNyAyOTIuMSwxMzYuMyBDIDI5MS42LDEzNi44IDI5MS42LDEz'
    b'Ny4xIDI5MiwxMzcuNiBDIDI5Mi41LDEzOC4yIDI5My4xLDEzOC4zIDI5My44LDEzNy44IHog'
    b'TSAyOTYuNSwxMzEuNSBDIDI5Ni43LDEzMS4xIDI5NS42LDEyOS43IDI5NS4yLDEzMC4xIEMg'
    b'Mjk0LjksMTMwLjQgMjk1LjQsMTMyIDI5NS45LDEzMiBDIDI5NiwxMzIgMjk2LjMsMTMxLjgg'
    b'Mjk2LjUsMTMxLjUgeiBNIDI5NS43LDEzMS4zIEMgMjk1LjYsMTMxLjIgMjk1LjUsMTMwLjkg'
    b'Mjk1LjUsMTMwLjcgQyAyOTUuNSwxMzAuNCAyOTUuNiwxMzAuNCAyOTUuOSwxMzAuNyBDIDI5'
    b'Ni4yLDEzMSAyOTYuMywxMzEuMyAyOTYuMiwxMzEuNCBDIDI5Ni4xLDEzMS41IDI5NS45LDEz'
    b'MS41IDI5NS43LDEzMS4zIHogTSAyOTcuOCwxMjYgQyAyOTcuOCwxMjQuNiAyOTcuMywxMjMu'
    b'NiAyOTYuNywxMjQgQyAyOTYuMiwxMjQuMyAyOTYuMSwxMjcuNCAyOTYuNSwxMjcuOCBDIDI5'
    b'NywxMjguMyAyOTcuOCwxMjcuMiAyOTcuOCwxMjYgeiBNIDI5OC4zLDExNy41IEMgMjk4LjQs'
    b'MTE3LjIgMjk4LjIsMTE2LjcgMjk3LjgsMTE2LjMgQyAyOTYuNSwxMTUuMSAyOTUuNCwxMTUu'
    b'OSAyOTYuNywxMTcuMiBDIDI5Ny42LDExOC4yIDI5OCwxMTguMyAyOTguMywxMTcuNSB6IE0g'
    b'Mjk2LDExMS44IEMgMjk1LjcsMTExLjYgMjk1LjIsMTExLjUgMjk0LjcsMTExLjcgTCAyOTMu'
    b'OCwxMTIgTCAyOTQuNywxMTIuNSBDIDI5NS44LDExMyAyOTYuNywxMTIuNiAyOTYsMTExLjgg'
    b'eiBNIDMxMS4zLDExMCBDIDMxMS4zLDEwOS41IDMxMC4yLDEwOC45IDMwOS41LDEwOC45IEMg'
    b'MzA5LjIsMTA5IDMwOSwxMDkuMSAzMDksMTA5LjMgQyAzMDksMTA5LjQgMzA5LDEwOS45IDMw'
    b'OSwxMTAuMyBDIDMwOSwxMTAuNyAzMDkuMywxMTEuMSAzMDkuNywxMTEuMiBDIDMxMC40LDEx'
    b'MS4zIDMxMS4zLDExMC42IDMxMS4zLDExMCB6IE0gMzAzLjQsMTAzLjMgQyAzMDMuNSwxMDMu'
    b'MiAzMDMsMTAzIDMwMi4yLDEwMyBDIDMwMS4xLDEwMyAzMDAuOSwxMDMuMiAzMDEuMywxMDMu'
    b'NSBDIDMwMS43LDEwNCAzMDMsMTAzLjkgMzAzLjQsMTAzLjMgeiBNIDMwMy40LDk3LjUgQyAz'
    b'MDMuNiw5Ni44IDMwNCw5NS44IDMwNC4zLDk1LjQgQyAzMDUuNCw5My40IDMwNC40LDkyLjIg'
    b'MzAyLjcsOTMuNSBDIDMwMi4yLDkzLjkgMzAyLDk0LjUgMzAyLDk2LjYgQyAzMDIsOTkuNCAz'
    b'MDIuNyw5OS45IDMwMy40LDk3LjUgeiBNIDMwMC43LDk0LjUgQyAzMDAuOSw5My42IDMwMC43'
    b'LDkyLjkgMzAwLjEsOTIuOSBDIDI5OS42LDkyLjkgMjk4LjIsOTQuNSAyOTguNCw5NC45IEMg'
    b'Mjk4LjgsOTUuNiAzMDAuNCw5NS4yIDMwMC43LDk0LjUgeiBNIDMxNC4yLDkyLjEgQyAzMTQu'
    b'Nyw5MS4zIDMxMy40LDkwLjUgMzEyLjEsOTAuOCBDIDMxMSw5MSAzMTAuNiw5MS43IDMxMS4y'
    b'LDkyLjMgQyAzMTEuNiw5Mi43IDMxNCw5Mi42IDMxNC4yLDkyLjEgeiBNIDMwNy4zLDg3LjQg'
    b'QyAzMDcuOSw4Ni43IDMwNy41LDg2LjEgMzA2LjIsODUuOCBDIDMwNS40LDg1LjYgMzA1LjIs'
    b'ODUuNyAzMDQuOSw4Ni40IEMgMzA0LjUsODcuNyAzMDYuMiw4OC40IDMwNy4zLDg3LjQgeiBN'
    b'IDMwMC41LDg1LjQgQyAzMDAuNSw4NC42IDI5OC45LDg0IDI5OC4xLDg0LjUgQyAyOTcsODUg'
    b'Mjk3LjcsODYgMjk5LjIsODYgQyAzMDAuMSw4NiAzMDAuNSw4NS44IDMwMC41LDg1LjQgeiBN'
    b'IDMwOC41LDgxLjYgQyAzMDkuMSw4MC42IDMwOS4xLDgwLjQgMzA4LjUsNzguNiBDIDMwOCw3'
    b'Ny4zIDMwNy44LDc2LjIgMzA4LDc1LjMgQyAzMDguMyw3My43IDMwNy45LDczLjIgMzA2LjIs'
    b'NzMuMiBDIDMwNSw3My4yIDMwNSw3My4zIDMwNS41LDc0LjQgQyAzMDUuOCw3NC44IDMwNS44'
    b'LDc1LjMgMzA1LjcsNzUuNiBDIDMwNS4yLDc2LjQgMzA1LjEsODEuMyAzMDUuNSw4Mi4xIEMg'
    b'MzA2LjEsODMuMiAzMDcuNyw4MyAzMDguNSw4MS42IHogTSAyOTguOSw3NC4yIEMgMjk4Ljks'
    b'NzMuOSAyOTguNiw3My4zIDI5OC4zLDcyLjggQyAyOTcuNyw3Mi4xIDI5Ny41LDcyIDI5Ny4x'
    b'LDcyLjUgQyAyOTYuNyw3Mi45IDI5Ni44LDczLjIgMjk3LjIsNzMuOSBDIDI5Ny45LDc0Ljgg'
    b'Mjk4LjksNzUgMjk4LjksNzQuMiB6IE0gMzEwLjIsNjIuOCBDIDMxMS43LDYyLjkgMzEyLjUs'
    b'NjIuNiAzMTIuNCw2MS45IEMgMzEyLjMsNjEuMyAzMTMuMiw1OS42IDMxNC44LDU3LjIgQyAz'
    b'MTYuMiw1NS4yIDMxNi4zLDU0LjIgMzE1LjYsNTEuMSBDIDMxNS4xLDQ5IDMxNS4xLDQ4Ljgg'
    b'MzE1LjcsNDguMyBDIDMxNi40LDQ3LjkgMzE2LjQsNDcuNyAzMTUuMyw0NS41IEMgMzE0LjYs'
    b'NDQuMiAzMTMuNiw0Mi45IDMxMy4xLDQyLjUgQyAzMTIuMSw0MS45IDMxMi4xLDQxLjkgMzEx'
    b'LjksNDIuNSBDIDMxMS43LDQyLjkgMzExLjQsNDMuOSAzMTEuMSw0NC43IEMgMzEwLjcsNDUu'
    b'OCAzMTAuNyw0Ni41IDMxMSw0Ny4yIEMgMzExLjcsNDkgMzExLjYsNTIuNCAzMTAuOSw1My4y'
    b'IEMgMzEwLjUsNTMuNiAzMTAsNTMuOCAzMDkuOCw1My43IEMgMzA5LjYsNTMuNiAzMDguNiw1'
    b'NC41IDMwNy42LDU1LjggQyAzMDYuNiw1Ny4xIDMwNS42LDU4LjEgMzA1LjQsNTguMSBDIDMw'
    b'NC45LDU4LjEgMzA1LjYsNTkuMiAzMDYuMyw1OS40IEMgMzA2LjcsNTkuNSAzMDcuMSw2MC4x'
    b'IDMwNy4zLDYwLjkgQyAzMDcuNyw2Mi44IDMwOC4yLDYzLjcgMzA4LjYsNjMuMiBDIDMwOC44'
    b'LDYyLjkgMzA5LjUsNjIuNyAzMTAuMiw2Mi44IHogTSAzMDMuNiw2MC40IEMgMzAzLjYsNTku'
    b'NSAzMDMuNSw1OS41IDMwMi4yLDYwLjEgQyAzMDEuNSw2MC41IDMwMS40LDYwLjcgMzAxLjcs'
    b'NjAuOSBDIDMwMi43LDYxLjUgMzAzLjYsNjEuMiAzMDMuNiw2MC40IHogTSAzMDYuMiw0NC43'
    b'IEMgMzA2LjQsNDMuNSAzMDUuMiw0Mi42IDMwNCw0Mi44IEMgMzAyLjUsNDMuMiAzMDEuOSw0'
    b'NCAzMDIuNCw0NC45IEMgMzAyLjksNDUuOSAzMDYsNDUuOCAzMDYuMiw0NC43IHogTSAzMTgu'
    b'Myw0My42IEMgMzE5LjIsNDIuNSAzMTkuMyw0MiAzMTkuMSw0MC40IEMgMzE4LjksMzguNCAz'
    b'MTguNSwzNy42IDMxNy42LDM3LjYgQyAzMTYuOSwzNy43IDMxNS4xLDM4LjggMzE1LjgsMzgu'
    b'OCBDIDMxNiwzOC44IDMxNS43LDM5LjEgMzE1LjIsMzkuNCBDIDMxNC41LDQwIDMxNC40LDQw'
    b'LjMgMzE0LjUsNDEuNiBDIDMxNC43LDQyLjggMzE1LjEsNDMuNSAzMTUuOCw0NC4xIEMgMzE2'
    b'LjQsNDQuNiAzMTcsNDUgMzE3LjEsNDUgQyAzMTcuMiw0NSAzMTcuOCw0NC4zIDMxOC4zLDQz'
    b'LjYgWiIgLz4NCjwvc3ZnPg0K', 'RU_SAK')

RU_SAK = b64_RU_SAK
index.append("RU_SAK")
index.append("Russia Sakhalinskaya oblast")
catalog["RU_SAK"] = RU_SAK
catalog["Russia Sakhalinskaya oblast"] = RU_SAK
country["Russia Sakhalinskaya oblast"] = ('RU_SAK', '', 1)
lookup["RU_SAK"] = ('RU_SAK', '', 'Russia Sakhalinskaya oblast', 1)
lookup["Sakhalin"] = ('RU_SAK', '', 'Russia Sakhalinskaya oblast', 1)
lookup["Russia Sakhalinskaya oblast"] = ('RU_SAK', '', 'Russia Sakhalinskaya oblast', 1)
details["RU_SAK"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+11:00","altname":"Sakhalin"}
regional["RU_SAK"] = ('RU_SAK', 'Russia Sakhalinskaya oblast', 1)
regional["Russia Sakhalinskaya oblast"] = ('RU_SAK', 'Russia Sakhalinskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_SAM = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNTMyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1NhbWFyYV9PYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5r'
    b'c2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8v'
    b'c29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxp'
    b'bms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnMgaWQ9ImRlZnMxNTM2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9Im5h'
    b'bWVkdmlldzE1MzQiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2NhcGU6'
    b'cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8'
    b'ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiIGlk'
    b'PSJnMTUzOCI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxp'
    b'dHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFO'
    b'U1VoRVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFD'
    b'QmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxF'
    b'OEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVQKaGtsRVFWUjQydTJjZVpRVTFiM0hiKzFW'
    b'WGRWNzkzVDNyTXcrd3l3c013eGhIUWFEa1UwZ0NxSzRQWSthRTdQNFlvelJIQmVTYUdJdwp4'
    b'dVJGZlNFdndlQTdnaHVJQ2tGWkhJRUJZUmpCbVdHWnZYdjIzdmVxcnIzZUg1Q3dPSjZROTE0'
    b'R0hmcjdYOWU1djc3M2Z1cFh2L3JkClg5MHFxS3M0QjZUMXJ4ZWNScEFHblFhZFZocDBHblFh'
    b'ZEZwcDBHblFhYVZCcDBHblFhZVZCdjBGU3RGWUd2Uy9YQ0ZHTjZwajRpU1oKQnYydmxaNFhW'
    b'QWlpUmVHck5XejBxelZjR1lHamR5QjJKdXdicERKM3BOS2cveitsQVNoZzFRbFpzT3kzSW1M'
    b'S3FQZUh3NHd0TnpGcQp5QldjRXF5a0REN1JsRXlsUThmL0xTTG5VVDJMOWRodDNFaUdQdHRy'
    b'ekFrNEE4ZHRtYVpvY0hkZVp0aWlTeHFHY2hua1BzNDkzNWd3CkVHbVAvbDg1TWdRTjF0RDZX'
    b'YXhGRVMzV0pLUG5ZVldETmNqRWtSQ2pXdnVOQUFBY2t3bGNLUzRkVGFYd2VBSENOOUwyZmpi'
    b'dDBmK2MKaG1iUWhUZU9LaktpcUxBa29xb0N4ek41QUlBcXcwTHFmSHJIdTNnTWw3MGpKcElT'
    b'RVZRMXJRdUhyRlFhOUJjcXBpT0hIWWFMajBnSQprbk9EUHhqVUt3cmtkRVZoUk5VMEtGNFJo'
    b'VkJWRVJFVmdoQlNsbEFRY3dnWkdZbEltSEZsUmlFSVJNSTBlZE1sSHEzQWtDZlRMR0JYCi84'
    b'SkZ2bWMxWHQwUlJPclJ6aXlib3lITW55SXBTVDUzRUFJZ1VLaFRJWWlpSkkvYnBpaUlxc0Jo'
    b'Z1RBYlVtcE5ZSERVWko4NUhOZXIKSGs0M3FjalBzY1NoeHJKNUN6cEhoOHlDbnpCMFNYLy84'
    b'd0dyeWJJMjZ0YVpTVUltZ3VxMTY5RUtEUFBaU0VYTmtNMldHTHpvbE1PYQpGajVxakFRWnY4'
    b'OGdTU2pIRWpnaGhVTE1VR2xDb1dRZExhWUl0WjhDRGxjMDZEY0lLWHpxdElFUGRsYkhZeFRj'
    b'QmwwUzVlMm1rdklSCll6YkhGMEhYdEVjSGluU08rV0dSeDlvK3kwVUN3QkZQK3ZJbXQ2NzQx'
    b'dEZiSDdZUEJWbk94NG00d3hFYkhyWlFwRVJTRWs0b2tURGQKMTV0QjZVUzlnY2N3bFVzU01L'
    b'cHdQS0ZwVUtxRFRreS83ZkNkVHdnNlBSWHlVVnpjWXpVTE1DYUlXR25kYVBDd2taU1ZheEcw'
    b'aENLUwppQVFjOUpTYS9yYVdYR2VjZm1YdWZjMTVNejVWRGFhS2lvR2FoYlhiMzQ0VG1vTEFC'
    b'bVBLWk9ZTXhoUkZTUllMYTdjbmpDYU9KQ1FFClVRbFNUaVpJa1VmVkFkVEVWQnhkOXhpU1lq'
    b'ZjZDYXk0YkgvdXpEbGRSNUtaU0cyZCs4UW4rWlpPRVZVMDZGb0xIVU1aQnE5SjM1bHQKZDJa'
    b'R3Q3OVdoNDRDUzlqdmlQdTJ3ZGxOSXAxOTdFTU5SajN6MWs1cDl6cGNVWk9adzNFWlFWVUVW'
    b'VVVKc2RxU1FJTlFWS1VvaVNRawpWMmJNYVlwUGJmZWZ2dUV1QUlDcDhmMnpRUCs2WUNzUDlo'
    b'aFp6dGR1UG5Ld3hHcEx0a3pLOUJ2cG9FbDNWZVlMaGYvNDh2ajNHbWNUCnB3T3Y0NmdoVTdj'
    b'd0RMM2g3Njl4MnBHSWRMTEV2RHBPdS9TUWdsUEVYL0sva1VLSWVuOGIxZk9VVWQ4dGkyaUt3'
    b'd1dCZ1JSRzB3Q0cKQ3hxY0lIVThoc3V5aUlqSW5QNmloMCtaOGpOVHdkdmQrL3BFekFKTEVW'
    b'KzNqMiswNjZaMUQ4UkxKbmRUcVdVRGlZOFpIU2cwcmFMSgo4YzRDSVUzVHhoLzBmOTEvUzNs'
    b'eEMwWW9HalZIVmpSRDN2V2hrNy9NTC9TZlBGRTErODRwS2NRRkFGQlZ6WmNRSkZtR3VaQU8w'
    b'a2pHClNESjZHTDBrVVpNRW5rOG01S1EvZ1ZJSTdjSVEyTTRRRUFRQUFIU2laZC9tb2Freitv'
    b'T2hIRHA3bWNqRlVMRWw2Zy9JRWlMcjF5eDcKK0tsclltV1lONlcybzJXa3ZISllGWTRsT1Rz'
    b'SlhuQm1SZU14U3UvSWFoSlhIRXZOdU1nVEFLQUJBQUNvQU1USGRCVUE5SDlyb0FJUQpPWDk0'
    b'RGJsUlFRNHlkRmVLOHluaEhZa3dCcXNKRkZVN3ptVFczMU43cmNUbzh2cEZsb0xaSThObWs0'
    b'WEYwVWcwQktPSTB0cXhkT0c5CkQ0N1puZ1FKRytpQmdZeUJGQXl1S0hPQU1XTDFNNXQzdmpQ'
    b'TlpHSkRQb3ltUWc1bjNOMXJMNW16T0srNjVscXBkZVJVVHMwb0tPNDUKdW1EVU94d3l2bGVx'
    b'Ynoxb2UvL1dwOG9BMURWbWU3dDI1bXZnajl1aC81eXAvZWtrdEpZRjlpdnBoZERSYTU3Zjh1'
    b'ckhoNVlWUG5BNAp2cXJNOXZWWmQ5cks1bDEzYldVZHgxLy9CYVZUYytaK3cxTzM2V0I1MDdD'
    b'K0tJNFp4cTR1Q2V3TjRLa202Tjl2VTI4WGdVNDhIeW11ClNMMlFKWnJUc0xmNFdLaHVRM1ox'
    b'aVpTS3R1OTYrZG9DYlNBNy9FZS9tL2pycWlyUDFpSFpRQlBvV3oxajE1UmQ0Yk9uL2VVMDhQ'
    b'ZEoKdFkyZlp2SlhYSHBtSlcyblIyQndkRUMyMXA1OXhyOTNEZC8xRUVFSTF4Qm9MaGFCNmVy'
    b'S3FZTVlOSnJML2pZRHNEaVFCNU9LcEk2UgpBdkdNSTg0Vks5MUhQanlTSVllR0VQcEtWMWpE'
    b'ck1Jcm1sVkw1Q3UrU2NTZkNTeFJXajRLTTlXS0xGOHJvRWZhOTdiczNMTjU0M3lqCmlkT1Jr'
    b'Um5ONjBLY0RFTUFoY2RZdUZuWWthcVNyd2NIVEtvQ0RBdnZCTkNWanBsRUlBQ0FOT3FaMWJ0'
    b'YVVXQlpRalp0ckQveHhxTnMKSkhqTjNBeW5MWmtoNkR5TlA5bjUvaHlUSTVNMG1WSUlwV2tn'
    b'S1YxZVlLTmovVGZPbnNMR291RmdRTk5wQVB3VFMraW9xQUlBV01ycQo5aTcxdTkyYUZDMHFD'
    b'ZGZjc1psa0ROY0s2TDIvV21JdXZtbitRL3NXVVV6elgrNGRyUHFCQmtFQUFPRnoxN1RRMTNv'
    b'MGlCem9jbk1ZClUxeGE3bzJNb0JtVHJyQVhYdFlBQUY0bWUvS1V1WFdGWXNYS3phSCtVNjEv'
    b'M1lTajNJTHZ2RHpCUThmT242ODYvUElLbVUrZWJYeDcKK0xOOU9LWHpWanh5RXM0RUFKQUti'
    b'eVF1ZDFpcGF2RlJrS1ZOcWlGRmRrYk5WSVdOWFhsZlZoTEdaUjRBOExGeFZxTDRIaGhCK3o5'
    b'NQpyYWY1aEJ3NXZPZTUyejk1NVljVEdiUTl4MDZvSnpOYzBZYXZuL253RDVzT3RidWIwWHhL'
    b'NGFlYzNwYi81aU9jejMzNXVnL0ZRT0ZVCkFDTUV6VmpNSmpVV3VOS2VOQTN2UCtiNjQ3MlRo'
    b'NDZvRUxKYnlHbjY4SU8yeHVQTFZwNmc2YmlKYkRKbVYwNWswRk5YLzhiaGlydGMKVWIvUE1D'
    b'ay8yQ0lZQUFBVzFrdDF2amg3eHU2MjkxNFlHMXA0bUxIWWJIcGFEZ3dLbmxaTjVBRUFtcGlT'
    b'ZlI0MWxSalRSRWtsZS83NgpRTU4xeDZHUE5nQUFKRlhycFF2ekN3TWpJNmFDSXIvT29KKzg2'
    b'TjhtTW1pQ1pwaFo3VWxrcmRuQlpFMUtoV1VVQXFDNDg0WGFtWDJuClduTklVaHpUS2dzVHVi'
    b'Q2ZFNlJuSC8zdWo1Yk11TkhHTHNCSFZtYWtubGc4dVVKeUo1dmVVcEtSeTB3UVNHWlp3dU8y'
    b'TDdxaFpVYnYKR3dBQUZpZHNMc1NjUVlleFovSlhISmo0TjBOelpnNVMveVEzOUk0OVk3RXdB'
    b'SnlocmdCa0gvQlllWUVzVy9ySVVIUU1rOUZZa2laMQpvcUxvTUJoSGNPZmtDL2ZEZFl2bWlL'
    b'bFV5ODRYcWVuWGt5VXpMOWhRNXVMcmY5YjI3dE1qUStiVEluRG1SMVdkcVdqVm5uRDN1NWsx'
    b'Cjl5UG9lRS84S3VUUlJ6YXVPL1hoVmpHd0IrZDMyakE1czNkektYVVl4blN6NzM2R050bkd6'
    b'aDhrcGFKdVhxbkRLS3ZhVDUvKzVhSFQKYmtIUmVGblRBSUFoVUQ5N0pxVFRLMUgvWlZhRmRR'
    b'M0ZEZmZpaE5KQWJtVlA3cU0xRG5nMytEc1BudG4xcTAvZi9NWEVCODN5em5EdgpSN0lFNDRH'
    b'bkJqLzl4R2dJaXRnazIvVEhCNDV0YXR2MjBOaWpwQmcyR1Q5WEUwMkUvYTgrdC82RkZ6ZHUz'
    b'THhsMDd2N0FBQkdIYUhKCk1tcDJYbXlpU2tManJ4dWtZQk0xYmF2WkVCYmdCTm0zSFkyL1pU'
    b'TExiWHQyUTJUaHhBOGR2TUI0QjlYYWVvSFRxbjVRdVdYZ1ZQU0EKTkhmSm1jZnpiTUVSYi82'
    b'WUpxVlRhanRPSEFZQU5IY09TRG9icHJNT2VvTktza3ZsWWthallkbmNHUmdDYTVjdTN6Vkox'
    b'QnNpQ0g5QQo2UGgwVi9DV1NycHplVzVUTkRVVmhyV0FueW9kOTZjZFY4R2piM2p3TWV1a3Fz'
    b'K09VU2pNQXdDTlJBcXJwUU0yU3hERGxYaGk3RHBHClZVbStCclJlejJEVGtXT29KWXNzbnFF'
    b'QkZkTHBFYk96Y2QvK0Y3ZTh3NUNvSE9pL0pDK0VZZStJeVpVWndiV2dRUm9HQ1p3VHN4aHEK'
    b'ZU45MnZuYmxMVFUzcmhubldTUHIxNjhmNXk0VlNUUTZYQmlUSHd3Njg4MDcrbG9TZHQzd1FM'
    b'KzkrZGkwSlE5K3I0OUhoK1dzeThzZApVcml6cTh1ZVZ6amdjWU9waXpGbklWazJTeE41b2Fj'
    b'Rk5saWxzZ2JXUHlLTmRzdFJIKzRxZ2hBVUFGQkZuOG5LdiszOVYwWXBrcy9DCmV3MGtucFVk'
    b'N3h4OW9PaHJpekx5aTQwTzEwUVBIWm8yZVBMQWdWZCs0WFRGOE15Ny9NWUdkVnJERHdldHBl'
    b'WmtvTHp5TG1NRVJKS1gKbTZoS1gzc3JtVDkxbEVkWVhvU0o4NCt4eWVJYWFmQzBLc2t3cGRj'
    b'MzNNNTNIazJkYVpKOGJqeTc3RndEc1dUbVR5dWZXRU40RGt2TwpsN0tidmRHb3Y3dVo4eDJY'
    b'Ukh6cGs5c05kc2RFRGgyaElRODhzSzZnd0dlMXh2WGk3OXVPQ210dXUvV2h4ZFd2SjV3QlZ1'
    b'U1ZNV0tuCnBzanV2bDQ4cjJvb0lVclNoZTFlc001SVZ0VnJiRVFhN2dBUVJKYk5JbklteTZH'
    b'UkMzZGRRWTBLNmp0eTRTdnJwbFhNdmZWTTB5bWIKYmxkSjJVaFd0dCs5WTlZRWo5R1c3RWxS'
    b'OUFjMU05MDZSbUNUaElVNjZuZDNtOTlmODlpOHJGVlRYRVo4alBFb29XSEU0b1JRakNXcwpQ'
    b'SGVKdjh2K1FhSzRoaWlZZnU0bmxsT21KQzZVUUYwTWRrOWR6aDltazVHdGEyTERIUTdyS1lI'
    b'RFNGSXNLdk9hcHI4NHdVRkRFRlMxCi9KRUF2VmNrbDl2enl3d0YzOXp6SHc5WDN2VHl5bXFu'
    b'QU9GamxhT0JNTndKRVRRQUFNSndvQ2lhY3I3RUo3amJsTWdJWGJzRVFPZk4KTUVlK0dnOXBr'
    b'Z2dBMEFDRXdWcVczYlJ3WnBXMTR0c25kcnhzS2w1amNPUUtwaDlMT2J2enBpK2UrT21kcWly'
    b'aTZKK05hRk0wb2pPaApIZ0toZW9hRCsrTjVvcUlKa0lGQmhpOXVUUG83dUlBSHIxMyt0eG9U'
    b'b1NiREVJd21qKy9VdUJnOWN5V0FMMHhCRXdVWUFEazBoRGtMCmNFaU1TeWdyQ3h0UEp5dEhS'
    b'b3pNSU1vTlNsSVFTMjRWZkg0QXpaM2dIaTJtdUE5K3VVTHdmY1RGaEx3Y053dXZZTzU2YTdk'
    b'dUdxOW8KR2dCK3RiQUE2YmdvRnhaRzlyMk9WaXhBYmRrQUFJU05vS29FQUNTT2RHUE9BdVBT'
    b'NzZEMlN6NElCZmNjaGtrYXRXWURBT3lrNk9VaApBSUEvcFg1U2VyTngxYlk0bDVlVjVVK0dB'
    b'dkcrTi9jOGY5OTRYOG9MdG8rTWM1ZEZubjJWeWlHejVHMms3eEJMRjJUcDhmT2xaMVZyCkQ2'
    b'YldKbjgybW5kUEFpa1pZNlhUOUlZR3dkU2MxVjl3cGNpSkExdXA2b1dvTlN0VCtJRDFkQjJ4'
    b'M1QvWlNrTG5reDNRNnc4NzNCOWYKSi95bG01clZTbHpuYzQ1cm1SUUN2KzhGVjBONTBrQUNH'
    b'TzZvTGNBUkNBQ2d5TUxPTS81ZWlmZ2dmcU03bzl5ZnR6SkdMNy9zOGFBUwo5Y0o2MjdrMCtZ'
    b'dlR4NVF0dXNWOGRwOFJ4RzhoWDYzWEplckt6bGVnK2hQUzBiYjJPR0dNd3FieG4rKzR4dWds'
    b'N2gyU1ZSZEU3VU5RCjFqSnBsNTJQc01qejU5eXQ5V1NiS2VETjFqbHo4a0k1YXROQVovY1JR'
    b'd3R2TGdMUWhUZGtFUUJBRENCRWxralBwUkk3UmZGejd3V3AKckhHMHZSNXF0TG9TM3JBWlY4'
    b'U016OTVyTjkxZDVUUUFBQ3lJOGpQdTU2L0lkN1RpMVhWeWk1aENKQWs1N0txZmdLRG41TFlp'
    b'Y1VGUApwR1lWdGIvYXYyb1B2R0NtbUVKeENuUy9VUjg2QkFaU3piWlpuVml1N0ZjZHJsaFhp'
    b'MmxMNmJMUC8waytQbml6NiszZkRkYkcxTXQzCjBpQ2E4bkRMU2QwOG9hMDFaOUNZZjlQb2xy'
    b'cEVzNzlqV05WV3FLN1pVakx3RXZtdFc4MDdmc0s4NUkxWkJwSVozc3ljdzlvNGdVYkEKa2dm'
    b'SHI1emtoeCt1M1N4cFdOUHA2Z3c0VkE0NjNWSUJZM085SDNJZEFKWFZqcDY4WU85WmV2SjAr'
    b'clFyTTdwQmVqQk1XczhaRnB0dwpHNkxtR3pGV0JsN1IwTWN5SWNXY3phRDVOSlJCSWdDR1dV'
    b'a0ZBR2dRYk5BU1M1MEhUS2JVODlGdjN5anNPbDQ2NzgvRTNUQ2RuV2tnCjJiYTlLNGczb3FO'
    b'VUtHbXF6T3hUQ2ZRUHNidmorRGp0d3gvWHJDTTdQdkRhcm9ZVEIzTVpSdkQzME1wSnJpTW9L'
    b'SkwwdmZDajYxTlAKTDZRUFp5T2pTWXg1VzFuZTc3WnhzTzVaLzJOTXpBdUhBd3V5ZE1sNDBv'
    b'QkFLd3IwTUFSNVpUdURRZDhzTlBBY1R3S2x6b2FEY0tBZwpjUHJSMklZb2JQUUdUZXY5RHkw'
    b'aVAwWklzSTdZOWl6L3hNS1JGMFJGOC9rNDN6R2NDeUV3b3U3ZlhkSGJiTTFLRGt6TUdQMW15'
    b'ZTNXClZIRCs4UDVQbFptSlVqMnF5UTJncWFiOWQ2WGtLY0lvblhYbmJzYlhab3JCZWRTUlZK'
    b'eGNqcjNuUTZ5WXdxNnFtV0lpRUJ4RjdBeU8KQWxVTmVBR0s4MEFoRUl1ZElRRUV5bTJVdHlD'
    b'RDdldFRKRkNuUDVGSVVrdU1lL2VNem5rUDFQOVdlSHErcVptVDI0Yk9uRzZ5M3J2Qgo5U1F0'
    b'c1NZK1hHVHIzSnU3UkVERzd4TUo0eG82QUFBcFROZGhxWXdSSmg3VjFiSE5OeVcyMjdqUi9J'
    b'SkFJR0E0MUZFRjU2QkIyUFRyCnhPMXZRVXREa0puQitCUk1SU0FMZzhpTCt0Zm5SVDgrb05R'
    b'TUJaTUFnVlZSTERPSWk5eVBrWkdPZU1iY28zM0J5ZkNwQ0RCK0lNL1oKcEh6elhYYitVdjBo'
    b'UDdEcVQvcXJwdzZnc0N5TlNyYVkveXhhUHNqa0JhbU1Mbk81QW8rcmsxM05OeDJ0YXNSc1lm'
    b'T2R3Y09IU2pnVwozNUt6eHNPZjM0ODdCWnhkamU1YmxiMy9iRi9POTRlZmZDOHlLVVU5YmdN'
    b'SjNuZGhNM3FqRjd5Sy9OUmlJTU5IZXE1SEQ5NmYzRkpkCjNmOWN6OTI3bFRrZTROakEzUWtn'
    b'U0pmSGtidkZvbUsvMmNVWFJFWUk2YXA5Zk9KcXZtZTR6WExUS3ZMMWU4NXVVQldJcGZReGF3'
    b'NncKMklIQk5JMzBQR2Q4UHMvYm0rTHdhWlc5MyszNVV5ekdUbmZxVnM4b1dsYWRlNjZ5Z1dE'
    b'WXpkVTU5OVZtUTdLSXlNTE5mVHRteis0YwpIVEZkSC8vb1dmbzNUaklGakJaZ3NjY3NUdHdJ'
    b'OVhRNWxvZisrMmJxdGJPR2lxczEyYXYvN3U2QWZwS0hMbjFhOTJNZXBRQUFBTU1XCjhNZVRM'
    b'RkUxYmRBN1pEclZsdFBxcXNGbzNXQm51eVBraCtQc05Oeld5a3l0anpYMkhEbko0am9sNHBR'
    b'TldXRXg0NTAzWjlUVXViTW4KUlh4aFVJRjR2R1FoQU9DSVljNGdudk10KzU4aWYwdGdycGF1'
    b'MnNyd0h5bzM0ZDRvZkg4L041Y3hpQ3NjZTIyMitJK2FmL1JXNWxvRgpRczQxME1uY2ozMi9l'
    b'bURldG82K3JHM2hwVm54UVFmcS83YmpKUlpqdm9UVCtmS0NCZ0RrSlR4endnZExsRzY5TDh3'
    b'WEdCL1BlRWFECkxpbWs2bVQyTjhNUHhmMEU2N0EwSTdYSExUT0RsUDNMT1pjdk5laUxsM3dh'
    b'Z05TeGRrYWpxcXhBeUdVbjRFdW9yOFkzbGY0ZUxqNHYKR2Y1cVRDSDlnY0UwNkRUb3ROS2cw'
    b'NkRUb05NSTBxRFRvTk5LZzA2RFRvTk9LdzE2SXVsL0FQVnA3Yit4R0NvVEFBQUFKWFJGV0hS'
    b'awpZWFJsT21OeVpXRjBaUUF5TURJekxUQTRMVEUyVkRBMU9qVXpPakkyS3pBd09qQXdUc2pp'
    b'aFFBQUFDVjBSVmgwWkdGMFpUcHRiMlJwClpua0FNakF5TXkwd09DMHhObFF3TlRvMU16b3lO'
    b'aXN3TURvd01EK1ZXamtBQUFBQVNVVk9SSzVDWUlJPQoiIGlkPSJpbWFnZTE1NDAiIC8+CiAg'
    b'PC9nPgo8L3N2Zz4K', 'RU_SAM')

RU_SAM = b64_RU_SAM
index.append("RU_SAM")
index.append("Russia Samarskaya oblast")
catalog["RU_SAM"] = RU_SAM
catalog["Russia Samarskaya oblast"] = RU_SAM
country["Russia Samarskaya oblast"] = ('RU_SAM', '', 1)
lookup["RU_SAM"] = ('RU_SAM', '', 'Russia Samarskaya oblast', 1)
lookup["Samara"] = ('RU_SAM', '', 'Russia Samarskaya oblast', 1)
lookup["Russia Samarskaya oblast"] = ('RU_SAM', '', 'Russia Samarskaya oblast', 1)
details["RU_SAM"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+04:00","altname":"Samara"}
regional["RU_SAM"] = ('RU_SAM', 'Russia Samarskaya oblast', 1)
regional["Russia Samarskaya oblast"] = ('RU_SAM', 'Russia Samarskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_SAR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNTQ3IiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1NhcmF0b3ZfT2JsYXN0LnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlu'
    b'a3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0cDov'
    b'L3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzIGlkPSJkZWZzMTU1MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJu'
    b'YW1lZHZpZXcxNTQ5IiBwYWdlY29sb3I9IiNmZmZmZmYiIGJvcmRlcmNvbG9yPSIjNjY2NjY2'
    b'IiBib3JkZXJvcGFjaXR5PSIxLjAiIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiIGlua3NjYXBl'
    b'OnBhZ2VvcGFjaXR5PSIwLjAiIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAg'
    b'PGcgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIgaW5rc2NhcGU6bGFiZWw9IkltYWdlIiBp'
    b'ZD0iZzE1NTMiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFs'
    b'aXR5IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFB'
    b'TlNVaEVVZ0FBQUhnQUFBQlFDQVlBQUFEU203R0pBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFB'
    b'Q0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3Vs'
    b'RThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFJCmowbEVRVlI0MnUyY2EyeGtWUjNBZitj'
    b'K1p1NjhwKzEyK3U1MisxamFaYnRRZDJGaEl5NmdpREhLWTRsUlZBekdSTlJQZmlCbzBKaUEK'
    b'd1E5K1VQa2dVY05xUWdJbUtCQ2lFVkZCTnZFRlFhQmQ2R1BicFkvdFRoL2J6cU16YzJmdW5m'
    b'dnd3NUxWWnBmVytHSFdhYzd2Mjl6egpTTzc1NWZ6UC81eDdNc0wzZlIvSmprV1JReUFGUzZS'
    b'Z2lSUXNrWUlsVXJCRUNwWkl3Vkt3UkFxdUEzeDNmZk52MzhSM2MxdldrWUxyCkNOYytCNEJU'
    b'bWNIM0hhcWxFMVJMSndBZnB6eTFxYzVPUmR2SkwrZjVSWXB6bjhDaGxZcVpwcVhqbzREQ3l1'
    b'UWQ2SHFNZ0pZbjBQU2cKRkZ5dkJNS0hzTHdLMFlpQ2hvb1FDZ2hCTkF6QllKQnlxVXdnZXIw'
    b'VVhOZnJzRDZNVUR4VUxZbGIzUURobzZnTklHSjQrbDZaWk5VNwpSdndvbFVvYXh6ZXBPaXRV'
    b'clZVY040OWxwUW5HYjl6eGdzVk8rQjVzMnlaLytjMVh1UG11Snk0cWN6eWZNd1dIc3dXSFl0'
    b'VkRBTkdBClFudFVvek9tb1N2aW9qWXZQZk41anQ3K09KcG15QkI5V1pNb3oyVmg1bytNdi80'
    b'WXhlSVoxczlOa0xaVC9PSms1bi9xNzR2RGpiVHAKaTZ5ZmU1cy9QWE0zZ3lOZlpmZkFSODZ2'
    b'M1ZKdzdUbjU2cU1zejcvQ1JtWWFCNU96cDE5aHBla1lUNTVXdURNOHpYUG13SC9WejdISQpE'
    b'TStXK3ZsWXI0T1gvVE8yblNHM2JqUHh6MGNwWk1jWlB2eDF1UVpmRG5KcmIrSUNybXZoZXlw'
    b'dnYvRVlBS3B2YzB0N2lGMFV0dTJqCnlTL3g0WFlEM2JNQUdILzlPTUxYY0YwTEQ0VzFsVGRs'
    b'a25XNUtKWUx1QzQ0bm9ld0ZaVDNKTGtpd1Bkbnd6emNXK0ZLNWYwUE1nYlYKTmI3YlgrSUhw'
    b'd05VbGVENXBBUUxIQi9YY3NEM0tWdDVLZml5ek43MFQwbkZsbEM4WlJSVm9JYzlJc25PQytW'
    b'emJpTXZycGE0dTlIaQozdERrUmUwL0c1amtub1l5TDY5V09PMmxMandQeHp0UkFnSXRxQ0M4'
    b'Vlpwankyd3NINWVDYTRscnZVdDI4VGpkWFlMZFhTWENCaWkrCng1Nmh1emZWZTc3WXc1amxz'
    b'amZaeElQSjZRdlBIMGhNTTl6VXlEdlZLcjh1ZEc5cXMyZndHRnJBUjllaHU2dEVWNWZQMnBt'
    b'ZjRWcXoKTXNtcTJkNU9qWkRORkZoYTloZ1lhQ0FXTWJCZGw3NlJMN0YwZW5OSWZycXdtNDdB'
    b'QkFrUjRiYmdMTGFyRUJFR2EvWTZUK1dITHVyNwp5b05mSStRK1RrQlRNU0k2TTZleWhBd1Zv'
    b'VWFsNEpxRkhhMkZ5YWtGV2x1YU9KczI4QnlQVkVzSVJibDBRUHJoK2hBSDlHV09Cbkw0Ck9q'
    b'eG5OdktXM1hYcHZoV0ZrQkZnNVp3SkJZZVNhVEkzbjJYazFtWVpvbXVGVXhtbk9XVndZTC9H'
    b'M3Y0aGNybXpWS3p3bG0zR3FxMDgKVTI1bHRCTGhMVHUxWlYzVENwRExwQm5zMjhmSXNFcHpj'
    b'd2luTWlrRjE0cnM3UDJNRFBjaHRCUlZPOHRBYjVGMDlzaTI3VzZLNVRqTQo5bGx4T25NOUEz'
    b'MUZiQ3VMMEZxNStxcGVjclAzeXhCZEt5cVZQQUhOWlc1bWc4Wmtsa1RqZFRUYTIrOTVEOFNo'
    b'b2laZ200T3VwbmlaCllPZ3c1MWJmSlpNVjdONGRwZXB1eUJsY0swTHhEeUFFYUxvZzJkQk1M'
    b'bGVtSlRtSzcxZTMzbHBWUGZSdDN0ajN5clEyakpMTGxXbEkKcHRCMEJVV0JVR3hFenVCYThk'
    b'Ym9MTkdnd3VEZUpET3pXY3hDbFpBQlF1aGJyOTArT0dLYkRGMEpVYlpzVmxmekZJcGwrdm9U'
    b'VEU2NgpsTzE1YnVxVGdtdkNrUnVPc3JIOFMrYm5UZHBiZ2dTNzR3aWhnZTlzUFR0OThMYWJ3'
    b'WDZWYUNUQTBGQVRsbVV6Lys0R1BWMEc4YllQCnlSQmRzMzJ3MWtrbVUyS2o0T0M2SWNwbEZk'
    b'Y1A0dHBiSDBiTWxUMFNZV1diUTVRcEhOZWdYTkZ3UFlOQ3lTT1RMYUpxblZKd3JRakUKNzJR'
    b'aDdaRk02T1EzU2l3dDVhaVVpd2h0MTlhQzdUQWJqcmRsSFZWTFlWdEZscGR5NVBJbDRuR1Z4'
    b'VFFFRW5kSXdiVkNWUTNNU2ovSgo2RFFkN2UzRVlvS3BpWG1Fa2lDdXYvOGlPMjNGbUN0VUVM'
    b'NTd5ZkpFUU9BclRZeFB6QktOQ1RvNk9rakdwaWxaZXhGS1FDWlp0ZVRnCm9TNXk1d3hpalJs'
    b'Nit2WVJEZjJPRXk4OHhJMGZmNGhIUDJnemxiR0JmMTlXOFh6Qnk0c0dmM1Y3dUcrZnl1YUxI'
    b'SUlyR2dNYzdrbngKMG0rL3hiNEJrNmIySzZtVVpzbm1ReHc4MkZXdncxU2ZnbjNmeGhEamVQ'
    b'RTllQjZZaFROVS9VNHlpejhtcy80Rmp2V01FYmpxOWdzQgp5dk04RkVYaDNyVWNxaEIwTnlV'
    b'dVBIdFBQM2IrZWRaWEsyd3MvWVJxU3hkbVlSNVFTQ1I2TWNSSmZMKzZiWmIrZjVtdjFPdWRy'
    b'TkxTCkE0eTk5aXk5dmJ1WW1Gem5pc0VteW1XTFdOUE5ZSjhpbnp1TEdqNUtMRGpQVTA5UGNk'
    b'dm5mazVBWFFPZ2JEZnkrMTk5bVUvZk5VREIKNnNZeFQ1QnM2RWJvZlJUV1hpWVlDbkpxTXNQ'
    b'UVVDTXpzMnRjZmMxbmlMUTlVcGN6dUc0RjI0VVhLYTg4Z3VlWk9MYU5yNFRKcnB1MAp0Y2VZ'
    b'V3lpaEtRR1NEUm9idVFVV3p1d2lHbk01TU55QzczdU1ubHloV05UcDdWNG5FdThrbjNWd3Fi'
    b'SzdNOGJTVXA3RzVqQytXMERYCkRSUVJKZFQ2YlFLeFcyU0lydTFXcVEzWFVURE5LbzVqa011'
    b'WFNNVEI4eTAwVGNFd2RLelMzOGhrd0ZmNnlPZmVJTHYyTmdDRlhBUWwKZUloTWRoUkZMR0pF'
    b'am1CVlhEeS9qSzc3TEo0eGFVaEcwRFNMY0VTZ2FDMTF1d2JYOWJYWmF1bE5TdW52c0p4ZUpK'
    b'WVVSQ05SSmlkWApxRllWa2trRDN4MGxrL1BKWkZ0WVh0SEpiMlRQWjh2eEpNMjdIRnAyclJD'
    b'UEMxVDlLckxaQ3NHZ3g5N0JGTVdpU1RIdmtXcnJKTmIrCk1IcGtwRzRGMS9XdFNqMHl3cW5G'
    b'UG1hbkZvaUVWZllQMmZUM0p5aWJKcVdTUlRwemtOWGlJVExMeDlsLzdmM2NjT3YzQURqeHdq'
    b'Y1kKZi8xSGVNWjl1TW9idEtXSzdPbFJDWVZqWk5lcnZEUHBZNW91ZTd3QnJoa1lxZWNoMmhr'
    b'WDN3RW14cDRuRnRPSml5ZkFLNk9FRHJDUwpIY0phdVFmUEUvUmV0MHc0Y3Y0Z3BGUllZZmEx'
    b'RG5UTlEwODlTU281amxjWnd4Y2hDdDQ5RklvZVF3Yyt1Uk9HWmVjSXZoU3VZL0hxCkh6NUZm'
    b'TmNSOWwvN3pVMWxZLzk0aEdMMk5RN2Y4alNxRnR5cFE3Q3pCVXZrWHpoSXdSSXBXQ0lGUzZS'
    b'Z2lSUXNrWUlsVXJBVUxObEIKQ0wrLy8rOXlHSGF5NFArOHVDU1JJVm9pQlV1a1lJa1VMSkdD'
    b'SlZLd0ZDeUhRQXFXU01FU0tWZ2lCVXVrWUlrVUxKR0NwV0NKRkN5UgpnaVZTc0VRS2xrakJF'
    b'aWxZQ3BaSXdSSXBXQ0lGUzJySnZ3RG1qWWFiZmJseHFnQUFBQ1YwUlZoMFpHRjBaVHBqY21W'
    b'aGRHVUFNakF5Ck15MHdOUzB3TTFReU16b3pNVG93T1Nzd01Eb3dNSjI2RW5VQUFBQWxkRVZZ'
    b'ZEdSaGRHVTZiVzlrYVdaNUFESXdNak10TURVdE1ETlUKTWpNNk16RTZNRGtyTURBNk1ERHM1'
    b'NnJKQUFBQUFFbEZUa1N1UW1DQwoiIGlkPSJpbWFnZTE1NTUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'RU_SAR')

RU_SAR = b64_RU_SAR
index.append("RU_SAR")
index.append("Russia Saratovskaya oblast")
catalog["RU_SAR"] = RU_SAR
catalog["Russia Saratovskaya oblast"] = RU_SAR
country["Russia Saratovskaya oblast"] = ('RU_SAR', '', 1)
lookup["RU_SAR"] = ('RU_SAR', '', 'Russia Saratovskaya oblast', 1)
lookup["Saratov"] = ('RU_SAR', '', 'Russia Saratovskaya oblast', 1)
lookup["Russia Saratovskaya oblast"] = ('RU_SAR', '', 'Russia Saratovskaya oblast', 1)
details["RU_SAR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+04:00","altname":"Saratov"}
regional["RU_SAR"] = ('RU_SAR', 'Russia Saratovskaya oblast', 1)
regional["Russia Saratovskaya oblast"] = ('RU_SAR', 'Russia Saratovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_SE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9y'
    b'OiBBZG9iZSBJbGx1c3RyYXRvciAyNS4yLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBW'
    b'ZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjxzdmcgdmVyc2lvbj0iMS4xIiBpZD0i0KHQ'
    b'u9C+0LlfMSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGlu'
    b'az0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeD0iMHB4IiB5PSIwcHgiDQoJIHZp'
    b'ZXdCb3g9IjAgMCAzNDAxLjYgMTcwMC44IiBzdHlsZT0iZW5hYmxlLWJhY2tncm91bmQ6bmV3'
    b'IDAgMCAzNDAxLjYgMTcwMC44OyIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSI+DQo8c3R5bGUgdHlw'
    b'ZT0idGV4dC9jc3MiPg0KCS5zdDB7ZmlsbC1ydWxlOmV2ZW5vZGQ7Y2xpcC1ydWxlOmV2ZW5v'
    b'ZGQ7ZmlsbDojQzIwMDAwO30NCgkuc3Qxe2ZpbGwtcnVsZTpldmVub2RkO2NsaXAtcnVsZTpl'
    b'dmVub2RkO2ZpbGw6I0ZGRDcwMDt9DQoJLnN0MntmaWxsLXJ1bGU6ZXZlbm9kZDtjbGlwLXJ1'
    b'bGU6ZXZlbm9kZDtmaWxsOiNGRkZGRkY7fQ0KPC9zdHlsZT4NCjxnPg0KCTxwb2x5bGluZSBj'
    b'bGFzcz0ic3QwIiBwb2ludHM9IjAsNTY2LjkgMzQwMS42LDU2Ni45IDM0MDEuNiwxMTMzLjkg'
    b'MCwxMTMzLjkgCSIvPg0KCTxwb2x5bGluZSBjbGFzcz0ic3QxIiBwb2ludHM9IjAsMTEzMy45'
    b'IDM0MDEuNiwxMTMzLjkgMzQwMS42LDE3MDAuOCAwLDE3MDAuOCAJIi8+DQoJPHBvbHlsaW5l'
    b'IGNsYXNzPSJzdDIiIHBvaW50cz0iMCwwIDM0MDEuNiwwIDM0MDEuNiw1NjYuOSAwLDU2Ni45'
    b'IAkiLz4NCjwvZz4NCjwvc3ZnPg0K', 'RU_SE')

RU_SE = b64_RU_SE
index.append("RU_SE")
index.append("Russia Severnaya Osetiya Respublika")
catalog["RU_SE"] = RU_SE
catalog["Russia Severnaya Osetiya Respublika"] = RU_SE
country["Russia Severnaya Osetiya Respublika"] = ('RU_SE', '', 1)
lookup["RU_SE"] = ('RU_SE', '', 'Russia Severnaya Osetiya Respublika', 1)
lookup["North Ossetia"] = ('RU_SE', '', 'Russia Severnaya Osetiya Respublika', 1)
lookup["Russia Severnaya Osetiya Respublika"] = ('RU_SE', '', 'Russia Severnaya Osetiya Respublika', 1)
details["RU_SE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"North Ossetia"}
regional["RU_SE"] = ('RU_SE', 'Russia Severnaya Osetiya Respublika', 1)
regional["Russia Severnaya Osetiya Respublika"] = ('RU_SE', 'Russia Severnaya Osetiya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_SMO = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iOTAw'
    b'IiBoZWlnaHQ9IjYwMCIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MjAwMC9zdmciPgogPGc+CiAgPHJlY3QgeD0iOS4xNzk3ZS02IiB5PSI0LjM4OTZlLTUiIHdp'
    b'ZHRoPSI5MDAiIGhlaWdodD0iNjAwIiBmaWxsPSIjYzYwMDAxIi8+CiAgPHBhdGggZD0ibTE0'
    b'Mi40IDczLjY2N2MtNC41MDkzIDAuMDYxODMtOS4xMzc4IDEuNDA2OS0xMy42NzMgNC40OTgt'
    b'MjAuMTQ5IDEzLjczMiAyLjYzNiAzOS45NTUgMi42MzYgMzkuOTU1bDAuMDExMiAwLjAxMTJj'
    b'MS45OTM0LTAuMDgxMyA0LjE4MzEgMC40MDc2NyA2LjY2MjggMS43ODM1IDUuNjE1Mi02Ljc4'
    b'MTggMTEuMzIxLTEzLjQwNSAyNi4xNDctNC4zNjM0IDMuMjI1NS0zLjIyNTUgNC45MTAxLTcu'
    b'MzAyMiAxMy4xMzUtNy4zMDIyczkuOTA5NSA0LjA3NjcgMTMuMTM1IDcuMzAyMmMxNC44MjYt'
    b'OS4wNDE1IDIwLjUzMS0yLjQxODQgMjYuMTQ3IDQuMzYzNCAyLjQ3OTctMS4zNzU4IDQuNjY5'
    b'NS0xLjg2NDggNi42NjI4LTEuNzgzNWwwLjAxMTItMC4wMTEyczIyLjc4NS0yNi4yMjIgMi42'
    b'MzYtMzkuOTU1Yy00LjUzNTUtMy4wOTExLTkuMTY0MS00LjQzNjEtMTMuNjczLTQuNDk4LTE2'
    b'LjEwNS0wLjIyMDg0LTMwLjc2OSAxNS44OTctMzQuOTE4IDI3LjA2Ni00LjE0ODktMTEuMTY5'
    b'LTE4LjgxNC0yNy4yODctMzQuOTE4LTI3LjA2NnoiIGZpbGw9IiNjNjAwMDEiIHN0cm9rZS13'
    b'aWR0aD0iLjM1ODk0Ii8+CiAgPHBhdGggZD0ibTE0Mi4yMSA3MS4wMDhjLTQuOTY0OC0wLjAz'
    b'NjY3LTEwLjA2MiAxLjE2NjMtMTUuMDE5IDQuMDcxNy0yNC43MDggMTQuNDgxIDAuNjA1NzEg'
    b'NDMuODEzIDAuNjA1NzEgNDMuODEzIDNlLTMgLTFlLTMgOGUtMyAxZS0zIDAuMDExMiAwIDEu'
    b'MTI4My0wLjQzNDg0IDIuMzEwNy0wLjcxMDUyIDMuNTY3LTAuNzYyNzVsLTAuMDExMi0wLjAx'
    b'MTJzLTIyLjc4NS0yNi4yMjItMi42MzYtMzkuOTU1YzQuNTM1NS0zLjA5MTEgOS4xNjQxLTQu'
    b'NDM2MSAxMy42NzMtNC40OTggMTYuMTA1LTAuMjIwODQgMzAuNzY5IDE1Ljg5NyAzNC45MTgg'
    b'MjcuMDY2IDQuMTQ4OS0xMS4xNjkgMTguODE0LTI3LjI4NyAzNC45MTgtMjcuMDY2IDQuNTA5'
    b'MyAwLjA2MTg0IDkuMTM3OCAxLjQwNjkgMTMuNjczIDQuNDk4IDIwLjE0OSAxMy43MzItMi42'
    b'MzYgMzkuOTU1LTIuNjM2IDM5Ljk1NWwtMC4wMTEyIDAuMDExMmMxLjI1NjMgMC4wNTIyIDIu'
    b'NDM4NyAwLjMyNzkxIDMuNTY3IDAuNzYyNzUgM2UtMyAxZS0zIDhlLTMgLTFlLTMgMC4wMTEy'
    b'IDAgMCAwIDI1LjMxNC0yOS4zMzIgMC42MDU3MS00My44MTMtNC45NTcyLTIuOTA1NC0xMC4w'
    b'NTUtNC4xMDg0LTE1LjAxOS00LjA3MTctMTYuMjE4IDAuMTE5NzktMzEuMDQzIDEzLjUyOS0z'
    b'NS4xMDkgMjQuNDc1LTQuMDY2LTEwLjk0Ni0xOC44OS0yNC4zNTUtMzUuMTA5LTI0LjQ3NXpt'
    b'LTYuMzAzOSA0Ny45MThjMC4xOTk0MyAwLjA3NTUgMC40MDIzMyAwLjE0ODA0IDAuNjA1NzEg'
    b'MC4yMzU1NS0wLjIwMTgyLTAuMDg3MS0wLjQwNzgtMC4xNjAyMS0wLjYwNTcxLTAuMjM1NTV6'
    b'bTgyLjgyNSAwYy0wLjE5OTQzIDAuMDc1NS0wLjQwMjMzIDAuMTQ4MDQtMC42MDU3MSAwLjIz'
    b'NTU1IDAuMjAxODItMC4wODcxIDAuNDA3OC0wLjE2MDIxIDAuNjA1NzEtMC4yMzU1NXoiIGZp'
    b'bGw9IiNmOGQ1MDEiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ry'
    b'b2tlLXdpZHRoPSIuNzUzNzciLz4KICA8cGF0aCBkPSJtMjE2LjIxIDE0NS44YTM4Ljg5OSA4'
    b'LjI0NjEgMCAxIDEtNzcuNzk4IDAgMzguODk5IDguMjQ2MSAwIDEgMSA3Ny43OTggMHoiIGZp'
    b'bGw9IiNjNjAwMDEiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ry'
    b'b2tlLXdpZHRoPSIuNzUzNzciLz4KIDwvZz4KIDxnIGZpbGw9IiNmMmYyZjIiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCI+CiAgPHBhdGggZD0ibTE3Ny4zMiAxMDgu'
    b'MjVjLTguMjI0OSAwLTkuOTA5NSA0LjA3NjctMTMuMTM1IDcuMzAyMi0xNC44MjYtOS4wNDE2'
    b'LTIwLjUzMS0yLjQxODQtMjYuMTQ3IDQuMzYzNC01Ljc4NDQtMy4yMDkzLTkuOTcwNC0xLjYz'
    b'My0xMy44NDIgMC44OTczNSA2LjMyMzUgOC4wMzYyIDExLjc0MSAxNi4yMzUgMTQuMjIzIDI0'
    b'Ljk5MSAwLTQuNTU0MiAxNy40MTctOC4yNDQ0IDM4LjktOC4yNDQ0IDIxLjQ4MyAwIDM4Ljkg'
    b'My42OTAyIDM4LjkgOC4yNDQ0IDIuNDgxOS04Ljc1NjUgNy44OTk1LTE2Ljk1NSAxNC4yMjMt'
    b'MjQuOTkxLTMuODcxMi0yLjUzMDQtOC4wNTcyLTQuMTA2Ny0xMy44NDItMC44OTczNS01LjYx'
    b'NTItNi43ODE4LTExLjMyMS0xMy40MDUtMjYuMTQ3LTQuMzYzNC0zLjIyNTUtMy4yMjU1LTQu'
    b'OTEwMS03LjMwMjItMTMuMTM1LTcuMzAyMnoiIHN0cm9rZS13aWR0aD0iLjcxNzg4Ii8+CiAg'
    b'PGcgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiPgogICA8cGF0aCBkPSJtMjM5LjU5IDExNC4yNGE0'
    b'LjE2OTcgNC4xNjk3IDAgMSAxLTguMzM5NCAwIDQuMTY5NyA0LjE2OTcgMCAxIDEgOC4zMzk0'
    b'IDB6Ii8+CiAgIDxwYXRoIGQ9Im0yNDMuOTUgMTA1LjQ4YTQuMTY5NyA0LjE2OTcgMCAxIDEt'
    b'OC4zMzk0IDAgNC4xNjk3IDQuMTY5NyAwIDEgMSA4LjMzOTQgMHoiLz4KICAgPHBhdGggZD0i'
    b'bTI0Ni4zIDk2LjQzNWE0LjE2OTcgNC4xNjk3IDAgMSAxLTguMzM5NCAwIDQuMTY5NyA0LjE2'
    b'OTcgMCAxIDEgOC4zMzk0IDB6Ii8+CiAgIDxwYXRoIGQ9Im0yNDIuODMgODkuNDQ5YTQuMTY5'
    b'NyA0LjE2OTcgMCAxIDEtMi44Mzc1LTcuODQxOCA0LjE2OTcgNC4xNjk3IDAgMSAxIDIuODM3'
    b'NSA3Ljg0MTh6Ii8+CiAgPC9nPgogIDxwYXRoIGQ9Im0yMzMuNjYgODAuMTQ4YTQuMTY5NyA0'
    b'LjE2OTcgMCAxIDEgNC45ODgtNi42ODMzIDQuMTY5NyA0LjE2OTcgMCAxIDEtNC45ODggNi42'
    b'ODMzeiIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiLz4KICA8cGF0aCBkPSJtMjMxLjA1IDcyLjc4'
    b'NmE0LjE2OTcgNC4xNjk3IDAgMSAxLTYuOTE1NS00LjY2MDcgNC4xNjk3IDQuMTY5NyAwIDEg'
    b'MSA2LjkxNTUgNC42NjA3eiIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiLz4KICA8ZyBzdHJva2Ut'
    b'd2lkdGg9Ii4zNTg5NCI+CiAgIDxwYXRoIGQ9Im0yMjEuODcgNjcuMjc5YTQuMTY5NyA0LjE2'
    b'OTcgMCAxIDEtOC4zMzk0IDAgNC4xNjk3IDQuMTY5NyAwIDEgMSA4LjMzOTQgMHoiLz4KICAg'
    b'PHBhdGggZD0ibTIxMS4xMiA2Ny4zNzNhNC4xNjk3IDQuMTY5NyAwIDEgMS04LjMzOTQgMCA0'
    b'LjE2OTcgNC4xNjk3IDAgMSAxIDguMzM5NCAweiIvPgogICA8cGF0aCBkPSJtMTk5LjMyIDcz'
    b'Ljg5NmE0LjE2OTcgNC4xNjk3IDAgMSAxLTIuODM0Ny03Ljg0MjggNC4xNjk3IDQuMTY5NyAw'
    b'IDEgMSAyLjgzNDcgNy44NDI4eiIvPgogICA8cGF0aCBkPSJtMTE1LjA0IDExNC4yNGE0LjE2'
    b'OTcgNC4xNjk3IDAgMSAwIDguMzM5NCAwIDQuMTY5NyA0LjE2OTcgMCAxIDAtOC4zMzk0IDB6'
    b'Ii8+CiAgIDxwYXRoIGQ9Im0xMTAuNjggMTA1LjQ4YTQuMTY5NyA0LjE2OTcgMCAxIDAgOC4z'
    b'Mzk0IDAgNC4xNjk3IDQuMTY5NyAwIDEgMC04LjMzOTQgMHoiLz4KICAgPHBhdGggZD0ibTEw'
    b'OC4zMyA5Ni40MzVhNC4xNjk3IDQuMTY5NyAwIDEgMCA4LjMzOTQgMCA0LjE2OTcgNC4xNjk3'
    b'IDAgMSAwLTguMzM5NCAweiIvPgogICA8cGF0aCBkPSJtMTExLjggODkuNDQ5YTQuMTY5NyA0'
    b'LjE2OTcgMCAxIDAgMi44Mzc1LTcuODQxOCA0LjE2OTcgNC4xNjk3IDAgMSAwLTIuODM3NSA3'
    b'Ljg0MTh6Ii8+CiAgPC9nPgogIDxwYXRoIGQ9Im0xMjAuOTcgODAuMTQ4YTQuMTY5NyA0LjE2'
    b'OTcgMCAxIDAtNC45ODgtNi42ODMzIDQuMTY5NyA0LjE2OTcgMCAxIDAgNC45ODggNi42ODMz'
    b'eiIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiLz4KICA8cGF0aCBkPSJtMTIzLjU4IDcyLjc4NmE0'
    b'LjE2OTcgNC4xNjk3IDAgMSAwIDYuOTE1NS00LjY2MDcgNC4xNjk3IDQuMTY5NyAwIDEgMC02'
    b'LjkxNTUgNC42NjA3eiIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiLz4KICA8ZyBzdHJva2Utd2lk'
    b'dGg9Ii4zNTg5NCI+CiAgIDxwYXRoIGQ9Im0xMzIuNzYgNjcuMjc5YTQuMTY5NyA0LjE2OTcg'
    b'MCAxIDAgOC4zMzk0IDAgNC4xNjk3IDQuMTY5NyAwIDEgMC04LjMzOTQgMHoiLz4KICAgPHBh'
    b'dGggZD0ibTE0My41MSA2Ny4zNzNhNC4xNjk3IDQuMTY5NyAwIDEgMCA4LjMzOTQgMCA0LjE2'
    b'OTcgNC4xNjk3IDAgMSAwLTguMzM5NCAweiIvPgogICA8cGF0aCBkPSJtMTU1LjMxIDczLjg5'
    b'NmE0LjE2OTcgNC4xNjk3IDAgMSAwIDIuODM0Ny03Ljg0MjggNC4xNjk3IDQuMTY5NyAwIDEg'
    b'MC0yLjgzNDcgNy44NDI4eiIvPgogIDwvZz4KIDwvZz4KIDxnIGZpbGw9IiNmOGQ1MDEiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCI+CiAgPHBhdGggZD0ibTE2My4w'
    b'MyA3My4xMTdjLTAuODQzNDIgMC43MTk3OC0xLjUzNTQgMS4wNjU4LTIuNjkyIDIuNTY4NyA2'
    b'LjIzNjQgNy43OTggMTEuMDQ5IDE3Ljk4NSAxMy4wMjMgMzIuOTQ0bDMuOTU5Ni0wLjM4MTM4'
    b'IDMuOTU5NiAwLjM4MTM4YzEuOTc0My0xNC45NTggNi43ODYzLTI1LjE0NiAxMy4wMjMtMzIu'
    b'OTQ0LTEuMTU2Ny0xLjUwMjktMS44NDg2LTEuODQ4OS0yLjY5Mi0yLjU2ODctNC4zODE0IDIu'
    b'MjE4LTguMTUyMiA1LjA1NzQtMTQuMjkgNS41MTg3LTYuMTM4MS0wLjQ2MTI3LTkuOTA4OS0z'
    b'LjMwMDctMTQuMjktNS41MTg3eiIgc3Ryb2tlLXdpZHRoPSIuNzUzNzciLz4KICA8cGF0aCBk'
    b'PSJtMTc0LjczIDQxLjk5OXY2LjQyMDZoLTQuODI2OHY0LjQyNjZoNC44MjY4djQuNjA3N2g1'
    b'LjE2MTl2LTQuNjA3N2g0LjgyNjh2LTQuNDI2NmgtNC44MjY4di02LjQyMDZ6IiBzdHJva2Ut'
    b'd2lkdGg9Ii4zNTg5NCIvPgogIDxwYXRoIGQ9Im0xODguMDcgNjcuODc3YTEwLjc1OSAxMC43'
    b'NTkgMCAxIDEtMjEuNTE3IDAgMTAuNzU5IDEwLjc1OSAwIDEgMSAyMS41MTcgMHoiIHN0cm9r'
    b'ZS13aWR0aD0iLjM1ODk0Ii8+CiAgPHBhdGggZD0ibTE2My4wMyA3My4xMTdjNC4zNDQ0IDku'
    b'MDE5MyAxMS45NDcgMTkuNjUyIDExLjk4IDM1LjI1NSAwLjcxMDUxLTAuMDc5NCAxLjQ3My0w'
    b'LjEyMzM5IDIuMzEwNy0wLjEyMzM5IDAuODM3NjUgMCAxLjYwMDIgMC4wNDQgMi4zMTA3IDAu'
    b'MTIzMzkgMC4wMzI5LTE1LjYwMiA3LjYzNTItMjYuMjM1IDExLjk4LTM1LjI1NS00LjM4MTQg'
    b'Mi4yMTgtOC4xNTIyIDUuMDU3NC0xNC4yOSA1LjUxODctNi4xMzgxLTAuNDYxMjctOS45MDg5'
    b'LTMuMzAwNy0xNC4yOS01LjUxODd6IiBzdHJva2Utd2lkdGg9Ii43NTM3NyIvPgogIDxwYXRo'
    b'IGQ9Im0xNzcuMzIgNTcuMTIyYy0xLjA0NzIgMC4wODA0MS0yLjUzNTUgMC4wMjg2MS0zLjI2'
    b'NDEgMC42NjYxMnY4Ljk2OTJjLTIuNDUzMi0wLjEyNDIzLTQuOTA4OC0wLjM1OTE0LTcuMzEz'
    b'NC0wLjg3NDkyLTAuMzQ2NjUgMS44ODU0LTAuMTkwNTMgMy44NjA4IDAuNDU5ODggNS42NjQ1'
    b'IDUuMDQ2IDAuOTUwMzMgMTAuMjI3IDEuMDMwNiAxNS4zMzYgMC42NTg1OCAxLjY0MjYtMC4x'
    b'MzU3MiAzLjI4Mi0wLjMzNTEgNC44OTg5LTAuNjU4NTggMC42NTA3Ni0xLjgwMzEgMC44MDY2'
    b'NS0zLjc3OTcgMC40NTk4OS01LjY2NDUtMi40MDQ2IDAuNTE2MjgtNC44NjAyIDAuNzUwNzEt'
    b'Ny4zMTM0IDAuODc0OTJ2LTkuMTMwNWMtMS4wNTMyLTAuMzM1ODYtMi4xNTg4LTAuNTA1Mzgt'
    b'My4yNjQxLTAuNTA0NzZ6IiBzdHJva2Utd2lkdGg9Ii4zNTg5NCIvPgogPC9nPgogPGcgZmls'
    b'bD0iIzk5OSIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiPgogIDxwYXRoIGQ9Im0xOTAuMzIgMTIx'
    b'Ljk5cy0yLjk3OTIgMy4xNjc0LTMuMjY4OSA1LjE5MThjLTAuMjkyNzQgMi4wNDUyIDEuNDEw'
    b'MSA1Ljc2ODcgMS40MTAxIDUuNzY4N3MzLjYyNTEtMy4yNjU2IDQuNjQ3LTQuOTk5NWMwLjYx'
    b'MDgxLTEuMDM2NSAxLjA1NzYtNC45MDM0IDEuMDU3Ni00LjkwMzRsLTEuMzc4MS0wLjA2NDFj'
    b'LTAuMjM3MyAzLjcwMjQtMi4wNTg4IDQuMjM2My0zLjMwMSA1LjkyODkgMCAwLTAuNTUwNy0w'
    b'Ljg0NDU0LTAuNTQ0ODMtMS40NDIyIDAuMDE4OS0xLjkyMzkgMi40MzU3LTQuOTk5NSAyLjQz'
    b'NTctNC45OTk1LTAuMjMzOTItMC44MTI1OC0wLjY2MDEtMC41Njc3NC0xLjA1NzYtMC40ODA3'
    b'M3oiLz4KICA8cGF0aCBkPSJtMjAzLjMzIDExNC43NXMtMi45NzkyIDMuMTY3NC0zLjI2ODkg'
    b'NS4xOTE4Yy0wLjI5MjczIDIuMDQ1MiAxLjQxMDEgNS43Njg3IDEuNDEwMSA1Ljc2ODdzMy42'
    b'MjUxLTMuMjY1NiA0LjY0Ny00Ljk5OTVjMC42MTA4LTEuMDM2NSAxLjA1NzYtNC45MDM0IDEu'
    b'MDU3Ni00LjkwMzRsLTEuMzc4MS0wLjA2NDFjLTAuMjM3MyAzLjcwMjQtMi4wNTg4IDQuMjM2'
    b'My0zLjMwMSA1LjkyODkgMCAwLTAuNTUwNjktMC44NDQ1My0wLjU0NDgyLTEuNDQyMiAwLjAx'
    b'ODktMS45MjM5IDIuNDM1Ny00Ljk5OTUgMi40MzU3LTQuOTk5NS0wLjIzMzkzLTAuODEyNTgt'
    b'MC42NjAxMS0wLjU2Nzc0LTEuMDU3Ni0wLjQ4MDcyeiIvPgogIDxwYXRoIGQ9Im0yMTEuMzYg'
    b'MTI3LjMycy0yLjc2NTUgMi45NDAyLTMuMDM0NCA0LjgxOTRjLTAuMjcxNzMgMS44OTg1IDEu'
    b'MzA5IDUuMzU0OSAxLjMwOSA1LjM1NDlzMy4zNjUxLTMuMDMxMyA0LjMxMzYtNC42NDA5YzAu'
    b'NTY3LTAuOTYyMTIgMC45ODE3My00LjU1MTYgMC45ODE3My00LjU1MTZsLTEuMjc5Mi0wLjA1'
    b'OTVjLTAuMjIwMjggMy40MzY4LTEuOTExMSAzLjkzMjQtMy4wNjQyIDUuNTAzNiAwIDAtMC41'
    b'MTExOS0wLjc4Mzk2LTAuNTA1NzQtMS4zMzg3IDAuMDE3NS0xLjc4NTkgMi4yNjEtNC42NDA5'
    b'IDIuMjYxLTQuNjQwOS0wLjIxNzE0LTAuNzU0MjktMC42MTI3NS0wLjUyNzAxLTAuOTgxNzMt'
    b'MC40NDYyNHoiLz4KICA8cGF0aCBkPSJtMjIwLjk4IDEyMi40NXMtMi43NjU1IDIuOTQwMi0z'
    b'LjAzNDQgNC44MTk0Yy0wLjI3MTc0IDEuODk4NSAxLjMwOSA1LjM1NDkgMS4zMDkgNS4zNTQ5'
    b'czMuMzY1MS0zLjAzMTMgNC4zMTM3LTQuNjQwOWMwLjU2Njk5LTAuOTYyMTIgMC45ODE3My00'
    b'LjU1MTYgMC45ODE3My00LjU1MTZsLTEuMjc5Mi0wLjA1OTVjLTAuMjIwMjggMy40MzY4LTEu'
    b'OTExMSAzLjkzMjQtMy4wNjQyIDUuNTAzNiAwIDAtMC41MTExOS0wLjc4Mzk2LTAuNTA1NzQt'
    b'MS4zMzg3IDAuMDE3Ni0xLjc4NTkgMi4yNjEtNC42NDA5IDIuMjYxLTQuNjQwOS0wLjIxNzE1'
    b'LTAuNzU0MjktMC42MTI3Ni0wLjUyNzAxLTAuOTgxNzMtMC40NDYyNHoiLz4KICA8cGF0aCBk'
    b'PSJtMTc1LjA2IDExMi42M3MtMi45NzkyIDMuMTY3NC0zLjI2ODkgNS4xOTE4Yy0wLjI5Mjc0'
    b'IDIuMDQ1MiAxLjQxMDEgNS43Njg3IDEuNDEwMSA1Ljc2ODdzMy42MjUxLTMuMjY1NiA0LjY0'
    b'Ny00Ljk5OTVjMC42MTA4MS0xLjAzNjUgMS4wNTc2LTQuOTAzNCAxLjA1NzYtNC45MDM0bC0x'
    b'LjM3ODEtMC4wNjQxYy0wLjIzNzMgMy43MDI0LTIuMDU4OCA0LjIzNjMtMy4zMDEgNS45Mjg5'
    b'IDAgMC0wLjU1MDctMC44NDQ1NC0wLjU0NDgzLTEuNDQyMiAwLjAxODktMS45MjM5IDIuNDM1'
    b'Ny00Ljk5OTUgMi40MzU3LTQuOTk5NS0wLjIzMzkyLTAuODEyNTgtMC42NjAxLTAuNTY3NzQt'
    b'MS4wNTc2LTAuNDgwNzJ6Ii8+CiAgPHBhdGggZD0ibTE2NC4zMyAxMjMuNTlzMi45NzkyIDMu'
    b'MTY3NCAzLjI2ODkgNS4xOTE4YzAuMjkyNzQgMi4wNDUyLTEuNDEwMSA1Ljc2ODctMS40MTAx'
    b'IDUuNzY4N3MtMy42MjUxLTMuMjY1Ni00LjY0Ny00Ljk5OTVjLTAuNjEwODEtMS4wMzY1LTEu'
    b'MDU3Ni00LjkwMzQtMS4wNTc2LTQuOTAzNGwxLjM3ODEtMC4wNjQxYzAuMjM3MyAzLjcwMjQg'
    b'Mi4wNTg4IDQuMjM2MyAzLjMwMSA1LjkyODkgMCAwIDAuNTUwNjktMC44NDQ1NCAwLjU0NDgy'
    b'LTEuNDQyMi0wLjAxODktMS45MjM5LTIuNDM1Ny00Ljk5OTUtMi40MzU3LTQuOTk5NSAwLjIz'
    b'MzkzLTAuODEyNTkgMC42NjAxMS0wLjU2Nzc0IDEuMDU3Ni0wLjQ4MDczeiIvPgogIDxwYXRo'
    b'IGQ9Im0xNTMuODYgMTE2LjkzczIuOTc5MiAzLjE2NzQgMy4yNjg5IDUuMTkxOGMwLjI5Mjcz'
    b'IDIuMDQ1Mi0xLjQxMDEgNS43Njg3LTEuNDEwMSA1Ljc2ODdzLTMuNjI1MS0zLjI2NTYtNC42'
    b'NDctNC45OTk1Yy0wLjYxMDgtMS4wMzY1LTEuMDU3Ni00LjkwMzQtMS4wNTc2LTQuOTAzNGwx'
    b'LjM3ODEtMC4wNjQxYzAuMjM3MyAzLjcwMjQgMi4wNTg4IDQuMjM2MyAzLjMwMSA1LjkyODkg'
    b'MCAwIDAuNTUwNjktMC44NDQ1NCAwLjU0NDgyLTEuNDQyMi0wLjAxODktMS45MjM5LTIuNDM1'
    b'Ny00Ljk5OTUtMi40MzU3LTQuOTk5NSAwLjIzMzkyLTAuODEyNTggMC42NjAxLTAuNTY3NzQg'
    b'MS4wNTc2LTAuNDgwNzN6Ii8+CiAgPHBhdGggZD0ibTE0My4zOSAxMjYuOHMyLjk3OTIgMy4x'
    b'Njc0IDMuMjY4OSA1LjE5MThjMC4yOTI3NCAyLjA0NTItMS40MTAxIDUuNzY4Ny0xLjQxMDEg'
    b'NS43Njg3cy0zLjYyNTEtMy4yNjU2LTQuNjQ3LTQuOTk5NWMtMC42MTA4MS0xLjAzNjUtMS4w'
    b'NTc2LTQuOTAzNC0xLjA1NzYtNC45MDM0bDEuMzc4MS0wLjA2NDFjMC4yMzcyOSAzLjcwMjQg'
    b'Mi4wNTg4IDQuMjM2MyAzLjMwMSA1LjkyODkgMCAwIDAuNTUwNy0wLjg0NDU0IDAuNTQ0ODIt'
    b'MS40NDIyLTAuMDE4OS0xLjkyMzktMi40MzU3LTQuOTk5NS0yLjQzNTctNC45OTk1IDAuMjMz'
    b'OTItMC44MTI1OCAwLjY2MDEtMC41Njc3NCAxLjA1NzYtMC40ODA3M3oiLz4KICA8cGF0aCBk'
    b'PSJtMTMzLjA1IDEyMC45czIuOTc5MiAzLjE2NzQgMy4yNjg5IDUuMTkxOGMwLjI5MjczIDIu'
    b'MDQ1Mi0xLjQxMDEgNS43Njg3LTEuNDEwMSA1Ljc2ODdzLTMuNjI1MS0zLjI2NTYtNC42NDct'
    b'NC45OTk1Yy0wLjYxMDgtMS4wMzY1LTEuMDU3Ni00LjkwMzQtMS4wNTc2LTQuOTAzNGwxLjM3'
    b'ODEtMC4wNjQxYzAuMjM3MyAzLjcwMjQgMi4wNTg4IDQuMjM2MyAzLjMwMSA1LjkyODkgMCAw'
    b'IDAuNTUwNjktMC44NDQ1NCAwLjU0NDgyLTEuNDQyMi0wLjAxODktMS45MjM5LTIuNDM1Ny00'
    b'Ljk5OTUtMi40MzU3LTQuOTk5NSAwLjIzMzkzLTAuODEyNTkgMC42NjAxMS0wLjU2Nzc0IDEu'
    b'MDU3Ni0wLjQ4MDczeiIvPgogPC9nPgogPGcgZmlsbD0iI2YyZjJmMiI+CiAgPGcgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIj4KICAgPHBhdGggZD0ibTE3OC40MyA4'
    b'NS40MzdhMy4yNzI2IDMuMjcyNiAwIDEgMS0yLjIyNDgtNi4xNTU1IDMuMjcyNiAzLjI3MjYg'
    b'MCAxIDEgMi4yMjQ4IDYuMTU1NXoiIHN0cm9rZS13aWR0aD0iLjM1ODk0Ii8+CiAgIDxwYXRo'
    b'IGQ9Im0xNzguMjEgOTEuMjQ0YTIuNjMxOCAyLjYzMTggMCAxIDEtMS43ODkyLTQuOTUwMiAy'
    b'LjYzMTggMi42MzE4IDAgMSAxIDEuNzg5MiA0Ljk1MDJ6IiBzdHJva2Utd2lkdGg9Ii4zNTg5'
    b'NCIvPgogICA8ZyBzdHJva2Utd2lkdGg9Ii4zNTg5NCI+CiAgICA8cGF0aCBkPSJtMTc3Ljk1'
    b'IDk2LjM1M2ExLjg2MjkgMS44NjI5IDAgMSAxLTEuMjY2NC0zLjUwMzkgMS44NjI5IDEuODYy'
    b'OSAwIDEgMSAxLjI2NjQgMy41MDM5eiIvPgogICAgPHBhdGggZD0ibTE3Ny45NSAxMDAuODRh'
    b'MS44NjI5IDEuODYyOSAwIDEgMS0xLjI2NjQtMy41MDM5IDEuODYyOSAxLjg2MjkgMCAxIDEg'
    b'MS4yNjY0IDMuNTAzOXoiLz4KICAgIDxwYXRoIGQ9Im0xNzcuOTUgMTA1Ljg0YTEuODYyOSAx'
    b'Ljg2MjkgMCAxIDEtMS4yNjY0LTMuNTAzOSAxLjg2MjkgMS44NjI5IDAgMSAxIDEuMjY2NCAz'
    b'LjUwMzl6Ii8+CiAgIDwvZz4KICA8L2c+CiAgPHBhdGggZD0ibTEwMS44NSAxNDUuNzF2MTAx'
    b'LjU0YzAgNDEuODM2IDMzLjc4OSA3NS43NDggNzUuNDY3IDc1Ljc0OCA0MS42NzggMCA3NS40'
    b'NjctMzMuOTEyIDc1LjQ2Ny03NS43NDh2LTEwMS41NGwtOC4zMzQxIDUuNDQwMi04LjM0NTQt'
    b'NS40NDAydjE3LjQ2NWgtMTYuODgxdi0xNy40NjVsLTguMzQ1NCA1LjQ0MDItOC4zMzQxLTUu'
    b'NDQwMnYxNy40NjVoLTE2Ljg5M3YtMTcuNDY1bC04LjMzNDEgNS40NDAyLTguMzQ1NC01LjQ0'
    b'MDJ2MTcuNDY1aC0xNi44ODF2LTE3LjQ2NWwtOC4zMzQxIDUuNDQwMi04LjM0NTQtNS40NDAy'
    b'djE3LjQ2NWgtMTYuODgxdi0xNy40NjVsLTguMzQ1NCA1LjQ0MDJ6IiBzdHJva2Utd2lkdGg9'
    b'Ii4zNTg5NCIvPgogPC9nPgogPHBhdGggZD0ibTEwMS44NSAxNDUuNzF2MTAxLjU0YzAgNDEu'
    b'ODM2IDMzLjc4OSA3NS43NDggNzUuNDY3IDc1Ljc0OCA0MS42NzggMCA3NS40NjctMzMuOTEy'
    b'IDc1LjQ2Ny03NS43NDh2LTEwMS41NGwtOC4zMzQxIDUuNDQwMi04LjM0NTQtNS40NDAydjE3'
    b'LjQ2NWgtMTYuODgxdi0xNy40NjVsLTguMzQ1NCA1LjQ0MDItOC4zMzQxLTUuNDQwMnYxNy40'
    b'NjVoLTE2Ljg5M3YtMTcuNDY1bC04LjMzNDEgNS40NDAyLTguMzQ1NC01LjQ0MDJ2MTcuNDY1'
    b'aC0xNi44ODF2LTE3LjQ2NWwtOC4zMzQxIDUuNDQwMi04LjM0NTQtNS40NDAydjE3LjQ2NWgt'
    b'MTYuODgxdi0xNy40NjVsLTguMzQ1NCA1LjQ0MDJ6IiBmaWxsPSJub25lIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMS4wNzY4Ii8+CiA8cGF0aCBkPSJtMTcyLjk1IDIyNi4yNWMt'
    b'My45MzM1IDAtNC44NzkzIDMuMDA2MS00Ljg3OTMgMy4wMDYxaC0zLjM4NzV2MS4zMDEybC0z'
    b'OC44NDQtMC40MDM4MWMtMi45OTI0LTAuNDI3MzEtMy40MDk3LTAuODUxNDEtNC42MjE0LTEu'
    b'Mjc4Ny0xLjMwMiAyLjIxMTMtMi40MzQxIDUuNjYyOC0yLjQzNDEgOC4wOTg2czEuMTMyMSA1'
    b'Ljg5ODUgMi40MzQxIDguMTA5OGMxLjIxMTctMC40MjczMSAxLjYyODktMC44NTE0MSA0LjYy'
    b'MTQtMS4yNzg3bDg3LjA0My0wLjg5NzM1YzQuNTA5OSAwLjU4MjgxIDguMzY0MyAxLjU5MTQg'
    b'OS45OTQyIDQuMDk0MiAwLjcyNzQ1IDAuMTI1MTMgMS4xNTI2IDEuMTY2OCAyLjMxMDcgMCAy'
    b'LjIxMS0xLjg4MiAxLjI0MjQtNC41ODU5IDIuODE1NC02LjI4MTQgMC43MjMxOS0wLjc3OTUy'
    b'IDEuNzY5NC0xLjIzNzEgMi45Mzg4LTEuNTcwNCAwLjUxOTkzIDEuNDMzOSAxLjUzMjQgMi40'
    b'MTE2IDIuNzAzMyAyLjQxMTYgMS42OTkyIDAgMy4wNzM0LTIuMDU2NiAzLjA3MzQtNC41ODc3'
    b'cy0xLjM3NDItNC41NzY1LTMuMDczNC00LjU3NjVjLTEuMTcwOSAwLTIuMTgzNCAwLjk3NzU3'
    b'LTIuNzAzMyAyLjQxMTYtMS4xNjk0LTAuMzM2NTItMi4yMTU2LTAuODAyMDYtMi45Mzg4LTEu'
    b'NTgxNi0xLjU3My0xLjY5NTUtMC42MDQ0OC00LjM5OTQtMi44MTU0LTYuMjgxNC0wLjQzNDI4'
    b'LTAuNDM3NTMtMC43NzIyMS0wLjU1NzE5LTEuMDU0NC0wLjUzODQxLTAuNDcwMjggMC4wMzEz'
    b'LTAuODAxNjMgMC40NjAyLTEuMjU2MyAwLjUzODQxLTEuNjI5OSAyLjUwMjgtNS40ODQ0IDMu'
    b'NTIyNi05Ljk5NDIgNC4xMDU0bC0zMi44MjEtMC4zMzY1MXYtMS4wNzY4aC0xLjc5NDdzLTEu'
    b'MzgzMy0zLjM4NzUtNS4zMTY4LTMuMzg3NXoiIHN0cm9rZS13aWR0aD0iLjM1ODk0Ii8+CiA8'
    b'cGF0aCBkPSJtMjM0LjQyIDIzNS45MmEwLjgzMzI1IDIuMzA3NSAwIDEgMS0xLjY2NjUgMCAw'
    b'LjgzMzI1IDIuMzA3NSAwIDEgMSAxLjY2NjUgMHoiIGZpbGw9IiNmZmYiIG9wYWNpdHk9Ii44'
    b'ODA5NSIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiLz4KIDxyZWN0IHg9IjEzMC45NyIgeT0iMjMx'
    b'Ljk1IiB3aWR0aD0iNzEuMzc1IiBoZWlnaHQ9IjEuNjY2NSIgcng9IjUuOTg0OSIgcnk9Ii44'
    b'MzMyNSIgZmlsbD0iI2YyZjJmMiIgc3Ryb2tlLXdpZHRoPSIuMzMzNzUiLz4KIDxnIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuNTM4NDEi'
    b'PgogIDxwYXRoIGQ9Im0xODYuOTYgMjQzLjE4LTQwLjU2IDAuNDE1MDN2MTEuMjM5aDIwLjI2'
    b'OWwyMC42MzkgMzQuMzU3aDI1LjA1OGwtMi4xMi0zLjI2NDFjLTUuMDYzLTguNDA5MyAwLjYy'
    b'ODU1LTE5LjYzMi0xMy4yNTgtMjEuNzM4bC0xMC4wMDUtMjEuMDA5eiIgZmlsbD0iI2Y4ZDUw'
    b'MSIvPgogIDxwYXRoIGQ9Im0xOTguOTYgMjQzLjA1LTExLjk4IDAuMTIzMzggMTAuMDA1IDIx'
    b'LjAwOWMxMy44ODcgMi4xMDY1IDguMTk1NCAxMy4zMjkgMTMuMjU4IDIxLjczOGwyLjEyIDMu'
    b'MjY0MSA5LjAyOTYtNi4zMjYzLTIuMTItMy4yNjQxYy01LjA2MjktOC40MDkzIDAuNjE3MzQt'
    b'MTkuNjIxLTEzLjI3LTIxLjcyN3oiIGZpbGw9IiNjNjAwMDEiLz4KICA8cGF0aCBkPSJtMTk4'
    b'Ljk2IDI0My4wNS01Ljk4OTggMC4wNTYxIDguNTI0OCAxNy45MTNjMTMuODg3IDIuMTA2NSA4'
    b'LjE5NTQgMTMuMzI5IDEzLjI1OCAyMS43MzhsMi4xMiAzLjI2NDEgNC41MjA0LTMuMTYzMi0y'
    b'LjEyLTMuMjY0MWMtNS4wNjI5LTguNDA5MyAwLjYxNzM0LTE5LjYyMS0xMy4yNy0yMS43Mjd6'
    b'IiBmaWxsPSIjYzYwMDAxIi8+CiA8L2c+CiA8ZyBmaWxsPSIjZjhkNTAxIj4KICA8ZyB0cmFu'
    b'c2Zvcm09Im1hdHJpeCguMzU4OTQgMCAwIC4zNTg5NCA1MC42NDUgLTU1Ljg5NSkiIHN0cm9r'
    b'ZT0iIzAwMCI+CiAgIDxnIHN0cm9rZS13aWR0aD0iMS41Ij4KICAgIDxwYXRoIGQ9Im0yOTcu'
    b'NjkgODEyYy00MC45MjggMC03NC4xMjUgMzMuMTk3LTc0LjEyNSA3NC4xMjVzMzMuMTk3IDc0'
    b'LjA5NCA3NC4xMjUgNzQuMDk0IDc0LjA5NC0zMy4xNjYgNzQuMDk0LTc0LjA5NC0zMy4xNjYt'
    b'NzQuMTI1LTc0LjA5NC03NC4xMjV6bTAgMTAuNjI1YzM1LjA2OCAwIDYzLjUgMjguNDMyIDYz'
    b'LjUgNjMuNXMtMjguNDMyIDYzLjQ2OS02My41IDYzLjQ2OS02My41LTI4LjQwMS02My41LTYz'
    b'LjQ2OSAyOC40MzItNjMuNSA2My41LTYzLjV6Ii8+CiAgICA8cGF0aCBkPSJtMjc4LjIyIDgy'
    b'Ni43MmM3LjIzMzUgNi43MjkzIDE1Ljg4NSAxMi44MiAxMy4zNDQgMTkuNjI1LTIuNTczMiA2'
    b'Ljg5MTQtMy4zNDgyIDguNjQ0LTMuMzQ4MiAxMC41IDAgNS4yMzE1IDQuMzQ4NCA5LjQ2ODgg'
    b'OS40NTc2IDkuNDY4OHM5LjQ4ODgtNC4yMzczIDkuNDg4OC05LjQ2ODhjMC0xLjg1Ni0wLjc3'
    b'NTA1LTMuNjA4Ni0zLjM0ODItMTAuNS0yLjU0MS02LjgwNTIgNi4xMTAyLTEyLjg5NiAxMy4z'
    b'NDQtMTkuNjI1LTMuNjYzMiAzLjIyMDYtMTAuOTk3IDUuNDM3NS0xOS40NjkgNS40Mzc1cy0x'
    b'NS44MDYtMi4yMTY5LTE5LjQ2OS01LjQzNzV6Ii8+CiAgICA8cGF0aCBkPSJtMjk3LjY5IDgy'
    b'Mi42MmMtNy4wOTM3IDAtMTMuOTExIDEuMTY2LTIwLjI4MSAzLjMxMjUgMy4zMDg1IDMuNjQz'
    b'MyAxMS4xMzcgNi4yMTg4IDIwLjI4MSA2LjIxODggOS4xNTYxIDAgMTYuOTgxLTIuNTY3NiAy'
    b'MC4yODEtNi4yMTg4LTYuMzcwMy0yLjE0NjUtMTMuMTg4LTMuMzEyNS0yMC4yODEtMy4zMTI1'
    b'eiIvPgogICAgPHBhdGggZD0ibTM1Ny4wNyA4NjYuNjVjLTYuNzI5MyA3LjIzMzUtMTIuODIg'
    b'MTUuODg1LTE5LjYyNSAxMy4zNDQtNi44OTE0LTIuNTczMi04LjY0NC0zLjM0ODItMTAuNS0z'
    b'LjM0ODItNS4yMzE1IDAtOS40Njg4IDQuMzQ4NC05LjQ2ODggOS40NTc2czQuMjM3MyA5LjQ4'
    b'ODggOS40Njg4IDkuNDg4OGMxLjg1NiAwIDMuNjA4Ni0wLjc3NTA1IDEwLjUtMy4zNDgyIDYu'
    b'ODA1Mi0yLjU0MSAxMi44OTYgNi4xMTAyIDE5LjYyNSAxMy4zNDQtMy4yMjA2LTMuNjYzMi01'
    b'LjQzNzUtMTAuOTk3LTUuNDM3NS0xOS40NjlzMi4yMTY5LTE1LjgwNiA1LjQzNzUtMTkuNDY5'
    b'eiIvPgogICAgPHBhdGggZD0ibTM2MS4xNiA4ODYuMTJjMC03LjA5MzctMS4xNjYtMTMuOTEx'
    b'LTMuMzEyNS0yMC4yODEtMy42NDMzIDMuMzA4NS02LjIxODggMTEuMTM3LTYuMjE4OCAyMC4y'
    b'ODEgMCA5LjE1NjEgMi41Njc2IDE2Ljk4MSA2LjIxODggMjAuMjgxIDIuMTQ2NS02LjM3MDMg'
    b'My4zMTI1LTEzLjE4OCAzLjMxMjUtMjAuMjgxeiIvPgogICAgPHBhdGggZD0ibTI3OC4yMSA5'
    b'NDUuNWM3LjIzMzUtNi43MjkzIDE1Ljg4NS0xMi44MiAxMy4zNDQtMTkuNjI1LTIuNTczMi02'
    b'Ljg5MTQtMy4zNDgyLTguNjQ0LTMuMzQ4Mi0xMC41IDAtNS4yMzE1IDQuMzQ4NC05LjQ2ODgg'
    b'OS40NTc2LTkuNDY4OHM5LjQ4ODggNC4yMzczIDkuNDg4OCA5LjQ2ODhjMCAxLjg1Ni0wLjc3'
    b'NTA1IDMuNjA4Ni0zLjM0ODIgMTAuNS0yLjU0MSA2LjgwNTIgNi4xMTAyIDEyLjg5NiAxMy4z'
    b'NDQgMTkuNjI1LTMuNjYzMi0zLjIyMDYtMTAuOTk3LTUuNDM3NS0xOS40NjktNS40Mzc1cy0x'
    b'NS44MDYgMi4yMTY5LTE5LjQ2OSA1LjQzNzV6Ii8+CiAgICA8cGF0aCBkPSJtMjk3LjY4IDk0'
    b'OS42Yy03LjA5MzcgMC0xMy45MTEtMS4xNjYtMjAuMjgxLTMuMzEyNSAzLjMwODUtMy42NDMz'
    b'IDExLjEzNy02LjIxODggMjAuMjgxLTYuMjE4OCA5LjE1NjEgMCAxNi45ODEgMi41Njc2IDIw'
    b'LjI4MSA2LjIxODgtNi4zNzAzIDIuMTQ2NS0xMy4xODggMy4zMTI1LTIwLjI4MSAzLjMxMjV6'
    b'Ii8+CiAgICA8cGF0aCBkPSJtMzU3LjA3IDg2Ni42NWMtNi43MjkzIDcuMjMzNS0xMi44MiAx'
    b'NS44ODUtMTkuNjI1IDEzLjM0NC02Ljg5MTQtMi41NzMyLTguNjQ0LTMuMzQ4Mi0xMC41LTMu'
    b'MzQ4Mi01LjIzMTUgMC05LjQ2ODggNC4zNDg0LTkuNDY4OCA5LjQ1NzZzNC4yMzczIDkuNDg4'
    b'OCA5LjQ2ODggOS40ODg4YzEuODU2IDAgMy42MDg2LTAuNzc1MDUgMTAuNS0zLjM0ODIgNi44'
    b'MDUyLTIuNTQxIDEyLjg5NiA2LjExMDIgMTkuNjI1IDEzLjM0NC0zLjIyMDYtMy42NjMyLTUu'
    b'NDM3NS0xMC45OTctNS40Mzc1LTE5LjQ2OXMyLjIxNjktMTUuODA2IDUuNDM3NS0xOS40Njl6'
    b'Ii8+CiAgICA8cGF0aCBkPSJtMzYxLjE2IDg4Ni4xMmMwLTcuMDkzNy0xLjE2Ni0xMy45MTEt'
    b'My4zMTI1LTIwLjI4MS0zLjY0MzMgMy4zMDg1LTYuMjE4OCAxMS4xMzctNi4yMTg4IDIwLjI4'
    b'MSAwIDkuMTU2MSAyLjU2NzYgMTYuOTgxIDYuMjE4OCAyMC4yODEgMi4xNDY1LTYuMzcwMyAz'
    b'LjMxMjUtMTMuMTg4IDMuMzEyNS0yMC4yODF6Ii8+CiAgICA8cGF0aCBkPSJtMjM4LjI5IDkw'
    b'NS41N2M2LjcyOTMtNy4yMzM1IDEyLjgyLTE1Ljg4NSAxOS42MjUtMTMuMzQ0IDYuODkxNCAy'
    b'LjU3MzIgOC42NDQgMy4zNDgyIDEwLjUgMy4zNDgyIDUuMjMxNSAwIDkuNDY4OC00LjM0ODQg'
    b'OS40Njg4LTkuNDU3NnMtNC4yMzczLTkuNDg4OC05LjQ2ODgtOS40ODg4Yy0xLjg1NiAwLTMu'
    b'NjA4NiAwLjc3NTA1LTEwLjUgMy4zNDgyLTYuODA1MiAyLjU0MS0xMi44OTYtNi4xMTAyLTE5'
    b'LjYyNS0xMy4zNDQgMy4yMjA2IDMuNjYzMiA1LjQzNzUgMTAuOTk3IDUuNDM3NSAxOS40Njlz'
    b'LTIuMjE2OSAxNS44MDYtNS40Mzc1IDE5LjQ2OXoiLz4KICAgIDxwYXRoIGQ9Im0yMzQuMTkg'
    b'ODg2LjFjMCA3LjA5MzcgMS4xNjYgMTMuOTExIDMuMzEyNSAyMC4yODEgMy42NDMzLTMuMzA4'
    b'NSA2LjIxODgtMTEuMTM3IDYuMjE4OC0yMC4yODEgMC05LjE1NjEtMi41Njc2LTE2Ljk4MS02'
    b'LjIxODgtMjAuMjgxLTIuMTQ2NSA2LjM3MDMtMy4zMTI1IDEzLjE4OC0zLjMxMjUgMjAuMjgx'
    b'eiIvPgogICAgPHBhdGggZD0ibTI0MS45MiA4NTcuODdjOS44NzMyLTAuMzU2NTMgMjAuMjk3'
    b'LTIuMTY3MiAyMy4zMTIgNC40NDE1IDMuMDUzNCA2LjY5MjQgMy43NDQ3IDguNDc5OCA1LjA1'
    b'NzEgOS43OTIyIDMuNjk5MiAzLjY5OTIgOS43NzAyIDMuNjIwNiAxMy4zODMgOGUtMyAzLjYx'
    b'MjctMy42MTI4IDMuNzEzNC05LjcwNTggMC4wMTQyLTEzLjQwNS0xLjMxMjQtMS4zMTI0LTMu'
    b'MDk5OC0yLjAwMzYtOS43OTIyLTUuMDU3MS02LjYwODctMy4wMTUyLTQuNzk4LTEzLjQzOS00'
    b'LjQ0MTUtMjMuMzEyLTAuMzEyOTcgNC44Njc2LTMuOTMxMiAxMS42MjEtOS45MjE2IDE3LjYx'
    b'MS01Ljk5MDQgNS45OTA0LTEyLjc0NCA5LjYwODYtMTcuNjExIDkuOTIxNnoiLz4KICAgIDxw'
    b'YXRoIGQ9Im0yNTIuNzkgODQxLjIxYy01LjAxNiA1LjAxNi05LjAxMiAxMC42NjEtMTEuOTk5'
    b'IDE2LjY4MyA0LjkxNTYgMC4yMzY3NCAxMi4yNzMtMy40NzgxIDE4LjczOC05Ljk0MzcgNi40'
    b'NzQzLTYuNDc0MyAxMC4xOTEtMTMuODIzIDkuOTQzNy0xOC43MzgtNi4wMjIyIDIuOTg2Ny0x'
    b'MS42NjcgNi45ODI3LTE2LjY4MyAxMS45OTl6Ii8+CiAgICA8cGF0aCBkPSJtMzUzLjQ0IDg1'
    b'Ny44N2MtOS44NzMyLTAuMzU2NTMtMjAuMjk3LTIuMTY3Mi0yMy4zMTIgNC40NDE1LTMuMDUz'
    b'NCA2LjY5MjQtMy43NDQ3IDguNDc5OC01LjA1NzEgOS43OTIyLTMuNjk5MiAzLjY5OTItOS43'
    b'NzAyIDMuNjIwNi0xMy4zODMgOGUtMyAtMy42MTI3LTMuNjEyOC0zLjcxMzQtOS43MDU4LTAu'
    b'MDE0Mi0xMy40MDUgMS4zMTI0LTEuMzEyNCAzLjA5OTgtMi4wMDM2IDkuNzkyMi01LjA1NzEg'
    b'Ni42MDg3LTMuMDE1MiA0Ljc5OC0xMy40MzkgNC40NDE1LTIzLjMxMiAwLjMxMjk3IDQuODY3'
    b'NiAzLjkzMTIgMTEuNjIxIDkuOTIxNiAxNy42MTEgNS45OTA0IDUuOTkwNCAxMi43NDQgOS42'
    b'MDg2IDE3LjYxMSA5LjkyMTZ6Ii8+CiAgICA8cGF0aCBkPSJtMzQyLjU2IDg0MS4yMWM1LjAx'
    b'NiA1LjAxNiA5LjAxMiAxMC42NjEgMTEuOTk5IDE2LjY4My00LjkxNTYgMC4yMzY3NC0xMi4y'
    b'NzMtMy40NzgxLTE4LjczOC05Ljk0MzctNi40NzQzLTYuNDc0My0xMC4xOTEtMTMuODIzLTku'
    b'OTQzNy0xOC43MzggNi4wMjIyIDIuOTg2NyAxMS42NjcgNi45ODI3IDE2LjY4MyAxMS45OTl6'
    b'Ii8+CiAgICA8cGF0aCBkPSJtMjQxLjkyIDkxNC4zNWM5Ljg3MzIgMC4zNTY1MyAyMC4yOTcg'
    b'Mi4xNjcyIDIzLjMxMi00LjQ0MTUgMy4wNTM0LTYuNjkyNCAzLjc0NDctOC40Nzk4IDUuMDU3'
    b'MS05Ljc5MjIgMy42OTkyLTMuNjk5MiA5Ljc3MDItMy42MjA2IDEzLjM4My04ZS0zIDMuNjEy'
    b'NyAzLjYxMjggMy43MTM0IDkuNzA1OCAwLjAxNDIgMTMuNDA1LTEuMzEyNCAxLjMxMjQtMy4w'
    b'OTk4IDIuMDAzNi05Ljc5MjIgNS4wNTcxLTYuNjA4NyAzLjAxNTItNC43OTggMTMuNDM5LTQu'
    b'NDQxNSAyMy4zMTItMC4zMTI5Ny00Ljg2NzYtMy45MzEyLTExLjYyMS05LjkyMTYtMTcuNjEx'
    b'LTUuOTkwNC01Ljk5MDQtMTIuNzQ0LTkuNjA4Ni0xNy42MTEtOS45MjE2eiIvPgogICAgPHBh'
    b'dGggZD0ibTI1Mi43OSA5MzEuMDFjLTUuMDE2LTUuMDE2LTkuMDEyLTEwLjY2MS0xMS45OTkt'
    b'MTYuNjgzIDQuOTE1Ni0wLjIzNjc0IDEyLjI3MyAzLjQ3ODEgMTguNzM4IDkuOTQzNyA2LjQ3'
    b'NDMgNi40NzQzIDEwLjE5MSAxMy44MjMgOS45NDM3IDE4LjczOC02LjAyMjItMi45ODY3LTEx'
    b'LjY2Ny02Ljk4MjctMTYuNjgzLTExLjk5OXoiLz4KICAgIDxwYXRoIGQ9Im0zNTMuNDQgOTE0'
    b'LjM1Yy05Ljg3MzIgMC4zNTY1My0yMC4yOTcgMi4xNjcyLTIzLjMxMi00LjQ0MTUtMy4wNTM0'
    b'LTYuNjkyNC0zLjc0NDctOC40Nzk4LTUuMDU3MS05Ljc5MjItMy42OTkyLTMuNjk5Mi05Ljc3'
    b'MDItMy42MjA2LTEzLjM4My04ZS0zIC0zLjYxMjcgMy42MTI4LTMuNzEzNCA5LjcwNTgtMC4w'
    b'MTQyIDEzLjQwNSAxLjMxMjQgMS4zMTI0IDMuMDk5OCAyLjAwMzYgOS43OTIyIDUuMDU3MSA2'
    b'LjYwODcgMy4wMTUyIDQuNzk4IDEzLjQzOSA0LjQ0MTUgMjMuMzEyIDAuMzEyOTctNC44Njc2'
    b'IDMuOTMxMi0xMS42MjEgOS45MjE2LTE3LjYxMSA1Ljk5MDQtNS45OTA0IDEyLjc0NC05LjYw'
    b'ODYgMTcuNjExLTkuOTIxNnoiLz4KICAgIDxwYXRoIGQ9Im0zNDIuNTYgOTMxLjAxYzUuMDE2'
    b'LTUuMDE2IDkuMDEyLTEwLjY2MSAxMS45OTktMTYuNjgzLTQuOTE1Ni0wLjIzNjc0LTEyLjI3'
    b'MyAzLjQ3ODEtMTguNzM4IDkuOTQzNy02LjQ3NDMgNi40NzQzLTEwLjE5MSAxMy44MjMtOS45'
    b'NDM3IDE4LjczOCA2LjAyMjItMi45ODY3IDExLjY2Ny02Ljk4MjcgMTYuNjgzLTExLjk5OXoi'
    b'Lz4KICAgPC9nPgogICA8cGF0aCB0cmFuc2Zvcm09Im1hdHJpeCguNDA5NjkgMCAwIC40MDk2'
    b'OSAxNzUuNzIgNTIzLjA4KSIgZD0ibTM0OS4yOSA4ODYuMTFhNTEuNjA3IDUxLjYwNyAwIDEg'
    b'MS0xMDMuMjEgMCA1MS42MDcgNTEuNjA3IDAgMSAxIDEwMy4yMSAweiIgc3Ryb2tlLXdpZHRo'
    b'PSIzLjI5MDUiLz4KICAgPHBhdGggdHJhbnNmb3JtPSJtYXRyaXgoLjE0MTQzIDAgMCAuMTQx'
    b'NDMgMjU1LjU4IDc2MC43OSkiIGQ9Im0zNDkuMjkgODg2LjExYTUxLjYwNyA1MS42MDcgMCAx'
    b'IDEtMTAzLjIxIDAgNTEuNjA3IDUxLjYwNyAwIDEgMSAxMDMuMjEgMHoiIHN0cm9rZS13aWR0'
    b'aD0iMTAuNjA2Ii8+CiAgPC9nPgogIDxnIHN0cm9rZS13aWR0aD0iLjM1ODk0Ij4KICAgPHBh'
    b'dGggZD0ibTIwMi4wNiAxNzMuMTJjLTEuODg4OSAxMi4xNzItMTIuMTkgMTkuNDEtMTIuMzI3'
    b'IDIzLjIwOC0wLjExMjQzIDMuMTAwOCA1LjY0NzkgOS4zNzg1IDYuNTI4MiAxNS4wNDJsNC43'
    b'MTExIDEuMzU3MiAwLjc2Mjc0LTIuMzg5MmMwLjkxMTA0LTQuMjY0MiA3ZS0zIC05LjAzNDgg'
    b'My40OTk3LTEyLjkyMi0xLjQ0MS0xLjI3NjYtMS45OTk0IDAuMjk2OTktMi44MDQyIDEuMDg4'
    b'bDIuNjI0OC05LjM0MzZjLTAuOTc4ODktMC41ODU2Ny0xLjcxMDcgMC4yOTc3OC0yLjUzNSAw'
    b'LjYzOTM2IDIuODc1Mi01Ljc0ODggMC4xNDk5NS0xMS4xNDktMC40NTk4OS0xNi42Nzl6IiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiLz4KICAgPHBhdGggZD0ibTE5'
    b'OC42MiAyMTIuMDVjLTAuODgwMzYtNS42NjMzLTYuNjM4OS0xMS45NDYtNi41MjY1LTE1LjA0'
    b'NyAwLjEzNzY4LTMuNzk3NiAxMC40MzktMTEuMDMzIDEyLjMyOC0yMy4yMDUgMC42MDk4NCA1'
    b'LjUzMSAzLjMyODQgMTAuOTMgMC40NTMyNCAxNi42NzkgMC44MjQzNS0wLjM0MTU3IDEuNTU5'
    b'Mi0xLjIyMDIgMi41MzgxLTAuNjM0NTJsLTIuNjI4NyA5LjMzNjVjMC44MDQ4NC0wLjc5MTA1'
    b'IDEuMzY5LTIuMzY0NCAyLjgxLTEuMDg3OC00LjE2MzIgNC42MzI3LTIuMDY2NyAxMC41MzUt'
    b'NC4yNjA0IDE1LjMxOSA5Ljg4NjItMTMuMjk0IDYuMzEtNDkuNDggMjUuNTYyLTM3LjA3NC0x'
    b'My45MzMtNi4zMzU0LTE0LjU1IDE1LjA1LTE4LjQ5MiAyOS4wOTcgNi4wNTA4LTYuNjI4MyA2'
    b'LjgzMDQtMzEuODQ0IDE4LjY5Ni0xNy45NjYtNy41OTM0LTcuMzU0OC0xMS43NDQgMTIuODM2'
    b'LTE3LjE3OCAyMi43NTQgNi43NTE1LTUuNjQ0IDEzLjUwMy0yMy45OTEgMjAuMjU0LTExLjY2'
    b'Ni0xNC43OTQtNC4wNTM2LTE1LjY3NyAyOC45OTktMzQuNDUzIDI3LjE1Ny0xNi4xNTEtMS41'
    b'ODQ5LTEyLjc2Ni0xOC4xODgtMTQuMzMzLTMyLjUxNy0wLjE4MzkyLTEuNjgyMi01LjEwNzMt'
    b'My4wNDA3LTQuODA0Mi01LjA3NjIgMC4yOTEzNy0xLjk1NjggMi42OTgzLTIuOTg5MyA1LjI1'
    b'NzUtMi4zNTY4IDcuODMyNyAxLjkzNTgtMC41ODMyMiAxOC4zOTMgMTQuNzc1IDI2LjI4N3oi'
    b'Lz4KICAgPHBhdGggZD0ibTE3OS4yOCAxODYuNzJjLTEuOTA5OSAwLjUyNDYyLTMuNjY5NyAx'
    b'LjQxNTktNS45MTEzIDEuMTY2Ni0wLjQxNDQ3IDEuOTUwNyAxLjMxNTQgMi4yNjg1IDIuMjIw'
    b'OSAyLjMxMDcgMS4zNzk2IDAuMDY0MiAzLjAyNjIgMC4xODY1NCA0LjgzNDUgMC4zMzY1MS0x'
    b'LjA2MjUtMC43Mjg0OC0xLjk3NS0xLjUwMjEtMS44Mzk2LTIuNDExNiAwLjA4MDktMC41NDM1'
    b'MyAwLjMzMDE1LTEuMDE3MSAwLjY5NTQ1LTEuNDAyMXoiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LWxpbmVqb2luPSJyb3VuZCIvPgogIDwvZz4KIDwvZz4KIDxnIHN0cm9rZS13aWR0aD0iLjM1'
    b'ODk0Ij4KICA8cGF0aCBkPSJtMTgxLjg5IDE4Ny40YzEuNjE1LTEuMDU4MyAyLjQ2OTYgMC4y'
    b'NTk3IDMuNDI5MiAxLjI0OTktMS4xNDMxLTAuMjk2NDYtMi4yODYxLTAuMDI5OS0zLjQyOTIt'
    b'MS4yNDk5eiIvPgogIDxwYXRoIGQ9Im0xODEuODkgMTc2LjQ2Yy0wLjY0NjA0IDAtMS4xNjY2'
    b'IDAuNTIwNTEtMS4xNjY2IDEuMTY2NiAwIDAuNjQ2MDUgMC41MjA1MSAxLjE3NzggMS4xNjY2'
    b'IDEuMTc3OCAwLjI1MDM1IDAuODk4ODYgMC40Mjc2OSAyLjEyMDYgMC41MjcxOSAzLjM4NzUg'
    b'MC4wOTMxIDEuMTg1NSAwLjEzOTY0IDIuMzQgMC4xNzk0NyAzLjM5ODcgMC4yNTA3OCAwLjAx'
    b'MDcgMC41MDQxNSAwLjAzNDkgMC43NjI3NSAwLjA3ODUtMC4wNDM5LTEuMDc4OS0wLjA5MjUt'
    b'Mi4yODI4LTAuMTkwNjktMy41MzMzLTAuMTAzNDItMS4zMTY5LTAuMjU0MTgtMi41OTM1LTAu'
    b'NTQ5NjItMy42MDA2IDAuMjY1MjYtMC4yMTQ0NCAwLjQzNzQ2LTAuNTQwODkgMC40Mzc0Ni0w'
    b'LjkwODU3IDAtMC42NDYwNC0wLjUyMDUyLTEuMTY2Ni0xLjE2NjYtMS4xNjY2em0tMi45ODM3'
    b'IDIuMTJjLTAuNjQ2MDQgMC0xLjE2NjYgMC41MjA1MS0xLjE2NjYgMS4xNjY2IDAgMC42NDYw'
    b'NSAwLjUyMDUxIDEuMTY2NiAxLjE2NjYgMS4xNjY2IDAuMTA4OTEgMCAwLjIxNDA0LTAuMDE3'
    b'IDAuMzE0MDctMC4wNDQ5IDAuODMwOTIgMS41OTA2IDEuNTU1OCAyLjk1MjcgMS43ODM1IDQu'
    b'ODc5MyAwLjIzNjY5LTAuMDYyOCAwLjQ4MzQ4LTAuMTA2NiAwLjc0MDMxLTAuMTM0Ni0wLjI1'
    b'NTYxLTIuMDc4Ny0xLjA1Mi0zLjU2NTItMS44OTU2LTUuMTgyMiAwLjE0MjI4LTAuMTkzNzMg'
    b'MC4yMjQzNC0wLjQyNTQzIDAuMjI0MzQtMC42ODQyMyAwLTAuNjQ2MDQtMC41MjA1Mi0xLjE2'
    b'NjYtMS4xNjY2LTEuMTY2NnptNy41Mzc3IDAuMTIzMzhjLTAuNjQ2MDQgMC0xLjE3NzggMC41'
    b'MjA1Mi0xLjE3NzggMS4xNjY2IDAgMC4zMjMwMiAwLjEzNjA0IDAuNjE4MzYgMC4zNDc3MiAw'
    b'LjgzMDA1LTAuNzU5NTIgMS41MzA3LTEuNDEyOSAzLjE1NzctMS42NDg5IDUuMDkyNSAwLjI1'
    b'OTQgMC4wNzA3IDAuNDkzNyAwLjE2NjM0IDAuNzE3ODggMC4yNjkyIDAuMjAzNTYtMS44OTY0'
    b'IDAuODQ5MjUtMy40OTUxIDEuNjE1Mi01LjAzNjQgMC4wNDg0IDZlLTMgMC4wOTU4IDAuMDIy'
    b'NCAwLjE0NTgyIDAuMDIyNCAwLjY0NjA0IDAgMS4xNjY2LTAuNTMxNzMgMS4xNjY2LTEuMTc3'
    b'OHMtMC41MjA1Mi0xLjE2NjYtMS4xNjY2LTEuMTY2NnoiLz4KICA8cGF0aCBkPSJtMTk4LjYy'
    b'IDIxMi4wNWMtMC44ODAzNi01LjY2MzMtNi42Mzg5LTExLjk0Ni02LjUyNjUtMTUuMDQ3IDAu'
    b'MTM3NjgtMy43OTc2IDEwLjQzOS0xMS4wMzMgMTIuMzI4LTIzLjIwNSAwLjYwOTg0IDUuNTMx'
    b'IDMuMzI4NCAxMC45MyAwLjQ1MzI0IDE2LjY3OSAwLjgyNDM1LTAuMzQxNTcgMS41NTkyLTEu'
    b'MjIwMiAyLjUzODEtMC42MzQ1MmwtMi42Mjg3IDkuMzM2NWMwLjgwNDg0LTAuNzkxMDUgMS4z'
    b'NjktMi4zNjQ0IDIuODEtMS4wODc4LTQuMTYzMiA0LjYzMjctMi4wNjY3IDEwLjUzNS00LjI2'
    b'MDQgMTUuMzE5IDkuODg2Mi0xMy4yOTQgNi4zMS00OS40OCAyNS41NjItMzcuMDc0LTEzLjkz'
    b'My02LjMzNTQtMTQuNTUgMTUuMDUtMTguNDkyIDI5LjA5NyA2LjA1MDgtNi42MjgzIDYuODMw'
    b'NC0zMS44NDQgMTguNjk2LTE3Ljk2Ni03LjU5MzQtNy4zNTQ4LTExLjc0NCAxMi44MzYtMTcu'
    b'MTc4IDIyLjc1NCA2Ljc1MTUtNS42NDQgMTMuNTAzLTIzLjk5MSAyMC4yNTQtMTEuNjY2LTE0'
    b'Ljc5NC00LjA1MzYtMTUuNjc3IDI4Ljk5OS0zNC40NTMgMjcuMTU3LTE2LjE1MS0xLjU4NDkt'
    b'MTIuNzY2LTE4LjE4OC0xNC4zMzMtMzIuNTE3LTAuMTgzOTItMS42ODIyLTUuMTA3My0zLjA0'
    b'MDctNC44MDQyLTUuMDc2MiAwLjI5MTM3LTEuOTU2OCAyLjY5ODMtMi45ODkzIDUuMjU3NS0y'
    b'LjM1NjggNy44MzI3IDEuOTM1OC0wLjU4MzIyIDE4LjM5MyAxNC43NzUgMjYuMjg3eiIgZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIi8+CiA8L2c+'
    b'CiA8ZyBmaWxsPSIjZjhkNTAxIj4KICA8cGF0aCBkPSJtMjAwLjQ4IDIyNS43MmMtMC44MDEy'
    b'MiAwLjA3MzUtMS42MzYgMC4wODM1LTIuNTEyNiAwLjAxMTJsLTEuMTU1MyAzLjcwMTZzLTEu'
    b'MjY2NiAwLjY3NzY4LTIuMTA4OCAxLjQyNDVsNC45MTMgMC4wNTYxYy05ZS0zIC0wLjU5NzEt'
    b'MC40OTM1NC0xLjY3MTMtMC40OTM1NC0xLjY3MTNzMC43NTAxMi0xLjkzNDMgMS4zNTcyLTMu'
    b'NTIyMXoiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiLz4KICA8cGF0aCBk'
    b'PSJtMTkzLjM5IDIyNC43OC0yLjc4MTggNC40NzU1Yy0xLjc0NjYgMC4zNjg1Ni0zLjY2OTgg'
    b'MC45MDYyLTMuMzk4NyAxLjg2MiAwLjMwNDQ2IDEuMDczNiAxLjYyMzItMC4yMjExMyAyLjIz'
    b'MjItMC4yNjkyLTAuMTU0NzUgMC43MDQ1OS0wLjIzMjk3IDEuMDM2IDAuNDI2MjQgMS4wOTky'
    b'IDAuNDQxNTcgMC4wNDI0IDAuNzUyNjctMC40MDI4MyAxLjM3OTctMC43NTE1MyAwLjU2OTY1'
    b'IDAuMzAyMDQgMC45NDA2NiAxLjM0OTggMS43Mjc0IDAuNzUxNTMgMC4yODkyOS0wLjQyNDIx'
    b'LTAuMDc4NS0yLjI4ODItMC4wNzg1LTIuMjg4MnMyLjEwNTQtMi45NjAxIDIuOTcyNS00LjIw'
    b'NjNjLTAuODkzMTktMC4xNjg4OS0xLjcxODYtMC40MDExNS0yLjQ3ODktMC42NzMwMXoiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMzU4OTQiLz4KICA8cmVjdCB4PSI5LjE3OTdl'
    b'LTYiIHk9IjUxMS4xNiIgd2lkdGg9IjkwMCIgaGVpZ2h0PSIzMCIvPgogIDxyZWN0IHk9IjM2'
    b'Ny4wNiIgd2lkdGg9IjkwMCIgaGVpZ2h0PSIzMCIvPgogPC9nPgogPGcgZmlsbD0iI2YyZjJm'
    b'MiI+CiAgPHBhdGggZD0ibTIyNS41MiAyMzEuMTZjLTAuOTQyMzYgMS4yOTM5LTEuMzgzNyAy'
    b'LjkwNzItMS40OTcgNC43MS0wLjAzNDYgMC41NTA5Ny0wLjAzNTMgMS40NDc5IDAuMDEyMSAx'
    b'Ljk5NzkgMC4xNTQ3NSAxLjc5NiAwLjczMjg0IDMuNDM2MiAxLjczMTcgNC43NDYgMC4zMzQ2'
    b'NiAwLjQzODgyIDAuODQxODkgMC4zNDQ1IDEuMDY5NC0wLjE1ODc2IDAuMTc1OTYtMC4zODky'
    b'NSAwLjA5MTUtMS4wOTA3LTAuMTc1OTEtMS41NzM5LTAuNjE2OTUtMS4xMTUtMC45MzEyMy0x'
    b'Ljg3MjItMS4wMzU2LTMuMDEzOC0wLjA1MDItMC41NDk0OC0wLjA0ODctMS40NDc0IDdlLTMg'
    b'LTEuOTk2NyAwLjEyMzYtMS4yMjY0IDAuNDg4MjQtMi4xNDI3IDEuMDY5Mi0zLjIyMyAwLjI2'
    b'MTQ2LTAuNDg2MTkgMC4yMjI1LTEuMjMxMS0wLjEwNjYxLTEuNjc0Ny0wLjIzNDU2LTAuMzE2'
    b'MDktMC43NDkwNC0wLjI1ODk4LTEuMDczOCAwLjE4N3oiIGNvbG9yPSIjMDAwMDAwIiBjb2xv'
    b'ci1yZW5kZXJpbmc9ImF1dG8iIGRvbWluYW50LWJhc2VsaW5lPSJhdXRvIiBpbWFnZS1yZW5k'
    b'ZXJpbmc9ImF1dG8iIG9wYWNpdHk9Ii45OTkiIHNoYXBlLXJlbmRlcmluZz0iYXV0byIgc29s'
    b'aWQtY29sb3I9IiMwMDAwMDAiIHN0b3AtY29sb3I9IiMwMDAwMDAiIHN0eWxlPSJmb250LWZl'
    b'YXR1cmUtc2V0dGluZ3M6bm9ybWFsO2ZvbnQtdmFyaWFudC1hbHRlcm5hdGVzOm5vcm1hbDtm'
    b'b250LXZhcmlhbnQtY2Fwczpub3JtYWw7Zm9udC12YXJpYW50LWVhc3QtYXNpYW46bm9ybWFs'
    b'O2ZvbnQtdmFyaWFudC1saWdhdHVyZXM6bm9ybWFsO2ZvbnQtdmFyaWFudC1udW1lcmljOm5v'
    b'cm1hbDtmb250LXZhcmlhbnQtcG9zaXRpb246bm9ybWFsO2ZvbnQtdmFyaWF0aW9uLXNldHRp'
    b'bmdzOm5vcm1hbDtpbmxpbmUtc2l6ZTowO2lzb2xhdGlvbjphdXRvO21peC1ibGVuZC1tb2Rl'
    b'Om5vcm1hbDtzaGFwZS1tYXJnaW46MDtzaGFwZS1wYWRkaW5nOjA7dGV4dC1kZWNvcmF0aW9u'
    b'LWNvbG9yOiMwMDAwMDA7dGV4dC1kZWNvcmF0aW9uLWxpbmU6bm9uZTt0ZXh0LWRlY29yYXRp'
    b'b24tc3R5bGU6c29saWQ7dGV4dC1pbmRlbnQ6MDt0ZXh0LW9yaWVudGF0aW9uOm1peGVkO3Rl'
    b'eHQtdHJhbnNmb3JtOm5vbmU7d2hpdGUtc3BhY2U6bm9ybWFsIi8+CiAgPHJlY3QgeD0iMjA2'
    b'Ljg4IiB5PSIyMzEuNjkiIHdpZHRoPSIxMS42MzIiIGhlaWdodD0iMi45Mzg1IiByeD0iMy4w'
    b'NTMzIiByeT0iMS40NjkzIiBvcGFjaXR5PSIuOTk5Ii8+CiAgPHJlY3QgeD0iMjA2LjY3IiB5'
    b'PSIyMzkuMzciIHdpZHRoPSIxMS42MzIiIGhlaWdodD0iMi45Mzg1IiByeD0iMy4wNTMzIiBy'
    b'eT0iMS40NjkzIiBvcGFjaXR5PSIuOTk5Ii8+CiAgPHJlY3QgeD0iMjA0LjcyIiB5PSIyMzUu'
    b'NTciIHdpZHRoPSIxNi40OTQiIGhlaWdodD0iMi45Mzg1IiByeD0iMi44ODUyIiByeT0iMS40'
    b'NjkzIiBvcGFjaXR5PSIuOTk5Ii8+CiA8L2c+Cjwvc3ZnPgo=', 'RU_SMO')

RU_SMO = b64_RU_SMO
index.append("RU_SMO")
index.append("Russia Smolenskaya oblast")
catalog["RU_SMO"] = RU_SMO
catalog["Russia Smolenskaya oblast"] = RU_SMO
country["Russia Smolenskaya oblast"] = ('RU_SMO', '', 1)
lookup["RU_SMO"] = ('RU_SMO', '', 'Russia Smolenskaya oblast', 1)
lookup["Smolensk"] = ('RU_SMO', '', 'Russia Smolenskaya oblast', 1)
lookup["Russia Smolenskaya oblast"] = ('RU_SMO', '', 'Russia Smolenskaya oblast', 1)
details["RU_SMO"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Smolensk"}
regional["RU_SMO"] = ('RU_SMO', 'Russia Smolenskaya oblast', 1)
regional["Russia Smolenskaya oblast"] = ('RU_SMO', 'Russia Smolenskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_SPE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNTAyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1NhaW50X1BldGVyc2J1cmcuc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cu'
    b'aW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRw'
    b'Oi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6'
    b'eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3'
    b'LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2'
    b'ZyI+CiAgPGRlZnMgaWQ9ImRlZnMxNTA2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9'
    b'Im5hbWVkdmlldzE1MDQiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiIGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2Nh'
    b'cGU6cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4K'
    b'ICA8ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2Ui'
    b'IGlkPSJnMTUwOCI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1'
    b'YWxpdHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FB'
    b'QUFOU1VoRVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFB'
    b'QUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0Nj'
    b'dWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVcKa0VsRVFWUjQydTFjZDJCVXhiYytj'
    b'N2VYYkhZMzJkMXNzcW1rVjFJSUNZU09kSWdVQVlPbzZNOENpRklWRUFSQlJZb2lKUlNmalll'
    b'aQpJS0FvdlNWMDBranZ2V2MzUGRtK2UrKzhQeElRTktHRThFemV5L2t2czVONzUzNzN6SGZP'
    b'K1dibW9zeEFYK2l6WjI5RUh3UjlRUGNCCjNXZDlRUGNCM1FkMG4vVUIzUWYwdjJtdE5OeEt3'
    b'NzF1MlBUZU1sQTFIZFJNYkdGQWNiWVVCalNvQ3JXeU1OK0krT1krb0x2UDdzak4KV2diUVRF'
    b'UzlBRnZVSWdDNDdFRktHcEdaUWZKTUtMQ2Exa2NkM1dCYUFnd3VtSzhoZ0VWeHJDbUVNUjB3'
    b'VDR3eEMvTTFoTTZaMHZZRwovdXNGWTFTeUtZS0R5eDFKbWdGNUpoQk5DckxlanZTSUoyaEdL'
    b'SGMwRTF5c1lsTmR2bmlqbWF3d2s0MW1rc1M0RjFOSExZWnFoUVBUCjBaSGw0SWk1WEVSUlpG'
    b'T2pvYkNRbFpQbGFqSSs1a1VZWmpDWndJUXcxNGNxVHlRWWpReUV5WEkyOEx3cFV5T1FKcUEv'
    b'SGsxVGQ5MUsKaVpES3lZWHRGOEJ4Y1pGNWVqbloyVFVxbGFxOHZQb2IxeVJ4dDZSbVU4OEZP'
    b'b25GWVdNczE2cFppS2dEYUJaWTB0emMyVjVlTHFORwpEd3NLN3NCSnE2cmlEdjJvUFhmV3Q3'
    b'NldBQ0F4cGlIVTJjVUZKR3JSSUJvTnFRd1V3YWNhbkNmN0txd2FyM3l2TTJFNmpVQm1Ta1Er'
    b'CmVsN21XMW5YTlRVTGVUeGk4QkNQNlROR0JBWFYxOVVWWldaVUZ4VnFtcG84Z29KOGc0Smc5'
    b'dXpiSjA4V2IvN01XZFBhUTRHV1lpejYKZEJOSEpEYnI5UUZPVGhLSmhNRmczTi9CYkRabnA2'
    b'VlZaV2FTSmlNaUNMR0Q0OGkzRjlBV0xqcTkvUXY2eVQvaitZS291cHJPa0daagp3SFdJSzhO'
    b'NkhiQzA0S2NRa3hxTkdUaEdqWVpMdzh3eUdvOTh4UEF5NVFxSDkxYzJYRHcvZXVueWpKczNj'
    b'NC84a3JaK0xhZXl3dFpzCmRxQVJlb3E2Uldlb3ZiemQ1NzBlTm1sU2pMcTFlY3RubHQwTk5P'
    b'b3VQVG90SUdqMjl3Zisxb2d4dnZiYmNkWEY4K2FzTEVWRG5aamUKL2w1MUZGWEM0VkwrL2Qy'
    b'aTV2Q3NySGhDMGVVVlM0TnlzenU3dUlxSld4aTRoWVBMRU1VejhKck5CTUZ0ZGNJRTE0QTgx'
    b'WTl3NTN5UgoySHY3TGpkLy8rUnIxeksyYi9Nc0x1SjE4a3ByYUhUYXN2ZUh6WDd4NTlkZURV'
    b'aEo2bDZnYVF2bDBtNjVrRm1saEdFanhOYlc5MXF5CjQrUE9MMzFQL3R0UjI4b0ttVUhQSWY1'
    b'Q2hJR1FoRFJMcXlyaXIxOVhqSi9vN080dURRdTdFeE1qVVhjOFoza2txbUJqeE1BdE1xQ1EK'
    b'aWNrM1lSRVdhMUdobktTVElOWjNpblVkUWJQNFlIWC9vY01BZ0dBeUx4ODVIS0RUQUlDZW91'
    b'Z0lVUUQ1REdhMWkydWpqMjlEL3lBVQpHS3hzVlRjWWpkVVV4VXUrd3lWUVR3UmFBTGhJYU9V'
    b'V0ducXY1ZXJQUHd2amJsbVRuWVlxUFVWVmlLMzFOZFVscGFXTy9nRTZtY3djCkc4UHFwSE9H'
    b'a0NTWmlFMEhIUU1vT29oSmd0ZENOTkhBclo3TzdUenB5QjgxTm1UNmpFdjc5aVR2MjFPOWUy'
    b'ZUV1Z1VBNGgyZHMxdGEKZGI1K3hwa3ZEdDc0YWY4NUx4bUVJaE5CSTdoY1czLy84SWlJNFBE'
    b'd0FwbThMalZWWk5EM09Pb0FnSUtKa1ZNMmZnSUFKcE9wamFPegpFeE9UTm04S0tNaDlTS3dE'
    b'QUF5UXgrYVNRNGVwaW91SDUrZDBuRE1ncUtmaHNqQ1RBUkJnekVMZ2M0UEpmbWhLRm04cHdv'
    b'RkI0cmpiCmJqcE5Xd3VKY1ZKb3VIenNlSVplTjJ6VzdKaWZEelhldUc3T3pIQnFicktrRVFD'
    b'UTVCOG9tUjNsNys5dmEydjd4N1l0cm9jTzlzVDAKanJvNzhTOSs4MThOcVNuUGZiVGVLeVRF'
    b'OWRBdkp6WnZzano1aDUzUjBPbmJCdkRRYStIOEdTMGdQVVd4aVE2b2dNQWdNU09yNjh4cgpv'
    b'VnFqSGc5SzR6MXlQTnptSnAvWVMvZS80YVRnMEplaTk5THA5RnNYTHZ3VU9jbS9zdHkyelFO'
    b'bzdYZTB0TFVkTjI1Y1RFeU1yYTB0ClYrSFFRd3NXVXRQdU9Mcms1TUQ0VzlkZWVlbnFyMGNZ'
    b'RE1hTU5SL1pmUEZWc3FQekkrdUtFTUFkb3Z5WG9rUlJvZDdJMXhNOVRvbmkKQy9oK2xOT2xO'
    b'bE8zZmtHbjA4MW1zMEduTFZWckdBL09NelBHZ3Y2Qlo4NmNDUW9LQWdCbFdXa05qZDRUZ2Ni'
    b'NmRrWXpWVmNDZ0ZkOQpMVzNUeHEvZmVMMnh2dDV2Y01UTUk4Y0taa1pWTVpsUEpTMFJPQ2Ja'
    b'bkpocGJzQlBWZzJxTVpiTiswOWhhc3F4OXhiOU9tWVUvNlBWCjAxc2EvMFpuMTIxc3E4M2tv'
    b'RUdETEMwdDgvUHk1Q0VEckwvYWxTT1Y5YXhnQ0FCS2dhWFBDN01BSVAyYnIyMzBPZ0RnQURo'
    b'VVY5NisKY0Y0dHRuTHc4UFNNR05MY3p5MHpNMVBXMnRLMWlGNEE1c2xSTkQ4WFd1RXRaSVdl'
    b'd0V2T1MyeHdYUzN2d0hjT1pTVTJldDNmZkxrRgpRN2FYajhmQ1JSTWlJOWxzZG5sUjBlbkRo'
    b'NzBEQTJ0YldnejkzUFFwZHdSUFhTNTJKMGViYTJzeHhnZ2h4T0ZBMDMxVHVLYXFZZTJxCkg4'
    b'K2VuZnJKcDRFalJub09ERHUzZGJQbzFCOFM4eE5Mbks0VW8xaWxZOUhCRVQyQllvY0JQS29y'
    b'M2VxVS8veXBIcUVLdi82T00yZEYKVFpqWTFuTGo3Tm1VTzBrTFAveXc3Yy9tNXVialNpWHps'
    b'NE5TczdtbmVMUkpwMk5QbkN5d3RNdzZkMGFxZXVDcE9CamJsSlZjdlhTUgpzbE1vWEYwOWg0'
    b'OVEyVHZsWm1iSjFFOVc3TElRS2xFWXRYcVE1ajhCQlNFQUs5cmYzVjlKMElxQ1ErWEwzeCt6'
    b'ZUttOW16c0FhTlRxCjN6ZCszTHAzdHlnbksvblhJN214c2FrMXluN2UzdUVqUjFhSUpRM3h0'
    b'd1drdVVjQUxVQ29VR3p0R2hSY21Ka2x6czc4NTlQYXREVFgKWGJxUVVGcnFGakhFd2NQRDVm'
    b'bXBOMVcxcUxDQSt5VEtXYTJMbVNEQUtyL3JYRjlKWjVTR1J6aXRYalB5N1FWeUorZTJDdmJT'
    b'd1lNcAphMWI3cGlUSkVGZ0J0dEZwSlRYVmpVeW13ZGF1TUR0NzZPVEpHV3ExWlVveWdicFl4'
    b'WFJuTUVRQTlWZGlBTUIxM0hobEp3UXFNNW04ClR2M3g2NXdYYzVJU3VUemVqSTJmME5hdXo1'
    b'UThRY0RCRk82eW90bUNjWktuanlKNi82eGQwYjZoQTl0ajRNbVR2OHg3V2ZUVlZ2L2EKQi9T'
    b'V1pnRDV1UEhoNGVINVo4OFU1K1JNZk9mZFRDdEpUOUdqblRQVHJ4MDc2aDBTb2d3TTduUVNJ'
    b'UlJZbUZmNjdvSVQyN1pTRkRVNAo4dm5SaHc2blJBeHJlanhuUVFSMElla2lNVTYyc3plcytt'
    b'anVvVis4Qmd4b1Q2c3ZYLzd4NVpmb2ExY0ZwS1Z3L2tIcmhSSERCMDJlCm9xcXFzazY1azNY'
    b'K0xKMU9aem82OVJTZ0xRRlUrL2RXbDVXRkxGNWF6SDFZVFdHdjB6bitkT0RRM0RuRjJWa2lL'
    b'NnVvbmJ0TjczK1kKTGJaK05FSHhnYzlCeGlkeDZoeStJQzF5K295anZ3MmJPYk85NWM2ZG93'
    b'dm5xMWNzQ2NwSUZhQU9nbWVjcDgrTXpWdjBPdDJaOTVkNwpORFcwZDZHb0hzSFJiU2JSYW03'
    b'RXhmV1BtbE5ySWRBbkpmQW9pc1M0UTJxaklTU3ZVK1dkUDFkb01Mb0doemo1K2xxUEhuT2pz'
    b'TWlpCnNyd3pBdFpTbUQzUXpHUWdZektOL1Jnem9KcEdMeDQyWXNpMjdZT21STkxwZEFCUVZW'
    b'V2RYTC9PdEdkbnY3SVNIanp3dXBRa3hTZVEKQmtQNjBPR3pkMFUzMWRlZmVHZEJTRTVtSFJB'
    b'MmJ5MFFTYVdaMFR0bGVuMVBBUm9BYkpzYXIxMkpEWHo5alRvYmVWMUcraG14eEV2ZAowcG5j'
    b'SVRJYVdVa0pseElTcElGQk5ncUYvNlRKT1J4K2RYYTJWVWVDam9xaTVFTXdnNGJxNHdtTGg5'
    b'YVFPb3pUdlh6dFY2OFo4OWJiCmZJR2dUUk0vdjM5ZjRhY2JmTEl6QlAvd3pUU0pMTnV2djA2'
    b'dnh5L1BtNzdtbzhzSER4WisvRkZBWlJrQ3lBOEtHYjFnNGZudnZ1MTMKTGJiTHdSQTl1LzNS'
    b'dVdJcjhSdnpGYjYrSXBuc3o2V0xCMlNrUHJ4L25xWEk0clgvakpyN01nQlVsNVZkMnJEZTgw'
    b'NEM5OEUrV2FScAo4QXFLcFBDZGJYUlhPcjJ6ckRsSGFzT2ZPWHZNdk5mUVhWemlUcC9LMmIr'
    b'dmYxa3g0eDlJVVFDSmJoN2p2dGpPNGZHNWZQNmRtTXNGClB4NTBUMDl0azYxenhkYkJlL1lM'
    b'cGRLenMxL3dWZFgwSU9xNFo5WTZYWDVTb254S3BNTEpTUjRhR24vNXNreWpma2gvSzRNZWJ0'
    b'K00KVFUyekd4QXF0YlgxbnhLWlRqRHFjclBGOTZsUjVTeHp2ekFnQ0ZRVWg2VFFRYzFTek9X'
    b'Vmo1MDQ0YXVkM21GaGJTZ1haR1dkWHIvTwo4dUFQL1pvYi96bXJ5aGlzaXZHVFptemZJUlNM'
    b'MlJ4T1FVNzJxWTBid2d0eTI4VG9NZzdQWWNNbmJvR0JoOTlkR0ZpUTExTmswZzZjCm1zTWxY'
    b'ZDJaVGs3c2ZxNFdkbmFsMjdiNEs2c2YrVjlaMWxMNS9JV0RwMDREZ0xMOC9DdWZidkJKVFc1'
    b'ajVGUzZjY1I3R0FCaXR5Si8KNGdFbXIwVkVlZkNBaUdVcm5EdzgybG8wYXZXWkw3WXh6NXh5'
    b'TlhiQVFscU1iemk2aEN4NHh6TTR1TG14c1NRdFRWZGNwTTNPc2toUApkVEFaQVNCZktKSXZY'
    b'eGs4ZHV4UHk1WUdYTG5FUUtqbkFuMy9kQzVDUkxtMTFLRlc2UUtQemhnYUVGRStmT1RrZFIv'
    b'ekJRS004ZW5vCjNYRDRrTE5HSFc4eXlsNHdrNENianpBQzcrcFRlb3JLZFhGelgvQk84T2pS'
    b'N2JmRE9QYlFUelVIRC9pck9sMktiTUc0aXFBQkFCMWoKbnRFb1lkRHBDTFZpek1DWVNSREpE'
    b'azZEUHYzY1FpUTY4OEdLd0l4VU9ucmExUmJVazgrdzVOc3E3QmE5RnpKMkhBQVVaMmZGYk56'
    b'QQpTVThlc0pncXE2VTR2N0F0Q1FJQThxVTJ0TWhwNDk5OGswWnJaNUwwNjllVDkrM3h6a3Ju'
    b'UHVIdGRCaGZIVFNFa1JCdlAvMkY4VXVXCkpsKytYTHJqQzE5bFRiYzhDK3JoaDRWVUJGRXdh'
    b'RWpVcHMxY0hnOWpmR0REK3JIOWZpNVNVb0lmMmFVTVZ2M2dJVlBYclJjSWhXMmQKcThyS1lu'
    b'ZnRrTWZHeU1nbkZ0c01HTkpIUHZmaTU1dHJxNnRiR2hxUzlrYmJKOFpiWTZxN0hnVDEvRk5a'
    b'R0NESHFaL0hzaFcrZ3dlWApsNVcxbkI1VldVZlZsUTRMVzdMY3hkdTdYYzh5bVU3djJtRTZm'
    b'c3hicSs3Q0xWb0I4a2VOaWRxOGxTQ0kydHJhNk9YTEhEUFNCbUt5Ckc1OEM5WmJqYjVWMFJz'
    b'M29zZE0rWExObDBXREVFcTdmRzN2dnA3aVRKd3UrMmU5ZldrenJFcE9XTUZuVTNGY25MWHhI'
    b'cTlYZU9INjgKSlNHT2xSRHZvdGQyNy9oUkx6cG5tR3NwMUV4OXdVYXpvMVZQbS9weEhnRGta'
    b'bVRjM3ZtVlcxSzhzS3M2VTdISm5PN202V2xuWjZpdQpJaXJMUGZVNkdrTFBZdkM5WTl0dUZa'
    b'T3BqQmcyWnNVSEVwbnN5eFduV1h4cFUxTlRYRnljdmIyOXhNTlRsNTRpTkJpNnFJSXg2TTRs'
    b'CkJWQlNjTmZ4MERONmhKNittN1FWSUQwZzBHNzMvam5idnBUSVpBQWdFV0J6UTltT045OXdW'
    b'U2k4dmIwbkxGdHV1eU02eWRHRjZ0a1AKOGd3cnc2YzBDaURmMFJuLzU2MHBhOWRKYkczYkds'
    b'T3ZYczI1Zm9pbGJKaFExRnh3OFh5QjN1ZzJZSURFVHVIeC9OUnJxbHF5b01BQwpVMzFBUHdr'
    b'ZEM0U04wMmRPMlBhbGUyQmdlL0ZkVkhScTdXcm1OMTgzaTdWQUlzZEdoc2hvWUNmRng5eTZK'
    b'UTRNRWx0Yis0NFkyZUxtCm5wV1pLZTNxeXU4enRSNFhEQ3NSb1F3YlBIclZhaHVGNGw3cWRu'
    b'SGZYdlBSdy8xYVd3RGdtbzhHR1NDaTRDK3h1MEJzTFhyanJTR3oKWmdPQVRxdTlzRzJMOE04'
    b'VDFxUzVEK2hPQ2pPQVlyOEFyL2tMZmNMQy8wcmRUcDhxL0hxZjMzMnAyMDEvRFRiQzRKd0hW'
    b'aFhVQUhraApBOGQvOHBtVlZBb0FOMCtmeXQvNTFRQlZUUi9RZnk5SlVxMmxnaGt6Sjc3eDVq'
    b'MWhzN3l3TUg3WFRwdHJzYUlIYVRjK1NFT1pVVmhhCkJ3VjJodFJHL3RiOElWT25BVUJMVTlP'
    b'Zm4yeXdqN2xvalhFZjBBQUF4VHllWWN6NDhjdFdjTGp0Mk9sMHVndjc5dEtPSCsxdzUzM0MK'
    b'UUEwbUlUU3g0M1d5UmtRckhUcHN5c2NiMjhUKzIzK2NxTnF6MjdNSHVQYS9HUXpyQ0ZwT2NH'
    b'akk1MXZEcDAyL2QwTGd5ckZqVjFhdQo4TDF4VmR6SklSZWxrNG5HQUhsWng2dGRITUEycGNX'
    b'M3pwMVRXMW5idWJvcVBEeHR4azlNcUs1bUZoZXhIMk5JUlFKaHZxKy9vTHFTCjlYOERhRDNH'
    b'V1I1ZU5oK3NIdmZlWXVIZHZldDVhV2xIbHkrVkgvM0ZUYU4reUlwUnJadUp3UUJwMGNQMmRV'
    b'alVyWTFYWXE4WEZIb08KSGNxM3NQQitia3lld0xJOE4xZWllMWhoblNXVmUzNitkZlRiODA4'
    b'Vmw5ams1OU1SNnQxQUY4amtyVkZ6cDI3YWJOZXZYMXVMVnFNNQp1MjFyNi9hdGZsV1ZqMXh5'
    b'YmZRMHNWbElsTWQ0ZURjK1JjbUxDbUl2WGdDRnZjekJ3Y1hQejJyMGN4ZHk4NFJWRmF5T2Jw'
    b'RnVZeHUrCk03cWZuMTlXUW9MdTRBOXRld2Q3SzlERmJHN0JzSkhqZCt6eUh6TGtYdEM3ZGV4'
    b'b3dzcjNQUkp1V3o3ZTVqYTFyNG5OUnZ4TXhpUDkKRFFIWU5EZFZYcjZVcEZSNURSNXNZV2ta'
    b'UENXeTJGSlluWjBsMXVzQW9KTEpOZ0RtWVp4cHF3amZzZHZlelMwbk1URjcxUXJQaHZyZQpH'
    b'Z3liQUNvR2hBMVl2TVRaeS90ZVkxNUtTc0x1blc1SjhmekhucVFreHJXemRIdzJRZ2RZdk1m'
    b'ZVRVcGluT3ZsMDMvbGg2NysvZ0JRClUxNSs2Wk1OMWttSmduVWJXRnp1amQyN3huMjh3YzNm'
    b'dnlBOVBYMzVFbzlhWmEvTU9zd1laemk3S2w1NWRXams4L2NhbXhzYkwrM2UKeVQ5OVV2R0Vo'
    b'MFEwbU1LdkdCZzAwSDNMRWhKUEp0UVU4M2d3YTg2RWhlOGdoQ2lLK256cGt0VmY3Ymh5OGFJ'
    b'Rm14MFVFVkZUVVg3dAo5WGsrendibFo2N2VGUWpGRVBuOHJIZmV2YmZPaERFKysvMTN0WWQr'
    b'Q21tbzdVcFJnMEhFQWt5aExtanl6aHFONGR1dmYwMUtEUDl3CjdkV3paOTllKzVGS3BXcXNy'
    b'aDQyZDY3SlpMcThhbVgvWjRaeTl3QmR6R1JwUGIwWkVna1lqZnFjYkhkbE5ac2dNRUJ5ZU1T'
    b'a2paOEsKeGVKN1BkT3VYMCtMM3VXZGsrblkxWUN1eDVqTFJEcFRGNHNRRmdMZjFEc1g1Nzlw'
    b'dDJDUlNDemVzMlh6d2c5V0FzQ1BLNVlQeUV3RApBQldGSzBSaWdpUWRXNXBFQk5GVGdEWmdT'
    b'QThKSGI1eXRjUGQvSUVreVppZkR6VWZQS0RsOGZoQklmZFFybE1xTDI3WkxMa2FHMFNhCm5r'
    b'YnpwVERRYU1pa3hWM0d3SWl4YVBSelk2Wk8vU0U2K3VYNUN3RGd5TmY3aGQ0K2lUbFovS0FR'
    b'bjFtemh3Y0VVQlNWY3UxYXlrOEgKM1JQanVEMEI2UFR3aUxuUmV5b0tDMzlmODZHdUlJL0da'
    b'TEVEQTFrSys0cXdRUXZXck4yL2ViUEJZR0F3R0RFL2ZOOTg2S0IvZDRSeQpFWTBvVVpKMWpk'
    b'aWpxMityZ3NFTW1qRXpLelhWMGQ3ZVFpRElURWd3bU1tWkN4YVVqUnAxOUx0djJUZHZaSC8z'
    b'RFkzRGNSZzNJZXJyCmIzNWF2ZEx2ek1sdVNhaTdIZ3h6QkpiRGovN2VwRklsTDNuWHExYlpK'
    b'bG5FQnc4Y3NXcTFrNHNMQUp6ODlwdnloQVJoZloxWFFTNnoKbTVKL004QXBueFl3bzhoY2l5'
    b'NWZKRThvTGc4YnRPaXpUV2F6K1hEVUxJR3lCdWI5Wi9LcjgwaVMvTzlsUzBLdnhpQUFKVUtt'
    b'K1l0Rwp2anJ2eUF2VCtwY1dQLzNJdTA1REtEQlliRzJkRkwzTDYyNE1LY040N0xyMVRpNHVw'
    b'NDRjK1c3TDVvYWZEdzJMdnhsUW1NZnN2aEtMCkR1QmlRNU5iUGhWN1VnU2EvZTU3QUhCaXky'
    b'YS8vRnlPV2kxVUtIYXNYbFd2VWlrR2hyZnh2d3pqeG9NSFNKSzBEQi84TDFNSFV5b0QKQUty'
    b'a3I3ZnRnRkRzNG5mWlFpRXBrYjYyNmZPajZXblFwZFRpb1ZrSHRwT2haaDUrK0pjbkhxNFUw'
    b'c2ROa3RqWTVONUo0cHc4UVVlbwoxa0x3NHVqbkdzNmZpNHVjeUVYb25sczRORFZrcHlUVHJh'
    b'MjdaZVJkZHczS29BTUF4TGU0dnhMclg1VHZlU2VCUlJBQWdFa1N1dHNJCmdNUnNNak9INnZM'
    b'MjJVeWhlT1JiYndGQXd2WXZuZlE2QUNCTUpwUEpSSWl0K3BsTjh2dVVyQm8yeDhuRDA5emM5'
    b'QzhEcmNuS0JnREIKaUZHR0IxT3RXa1RZREJtcTFXcWh2S3o3eXgvQS9kMXBIdTVFbHpWbTd0'
    b'anhmQXVMMktOSFhUUFMybHJjdE9vYnYvOFdOR3QycnJYawovanlTR2o5SktCUTJKOFQveTFv'
    b'SHI2RStUeWdlL2NvcnNXVmx1S2pRQW1NQUtHRXdqYSs4TmlKcXpwOWZidk5NVHVyMnRUc0dR'
    b'bGRhCmpRMkY0SzdyeXFtc2JMNWcrTll2bUN6V3pYVnJuWm9hMnRrVG9ZS1NFcTlac3kzQ0Iy'
    b'V29hcXRNNWxxWmplbjU2VlBlLytDUG5UdWQKTDUxai9Mc2N6UWRRN28xT2s5dSsrTm5uK1ZG'
    b'ekttL2N3RXhtd01pUmRvNU8xNDhmcy9qOStMUFl5WUFBN0IxUWF6MUFRNWNTZjZHdwp0YkV4'
    b'N3NUdlhvVjU5NmZ6QVJWbFo5OTR6WFB4MHVtNzk3UzF0RFkzSC8xNHZlelVIOTJWUnordDFs'
    b'SEo1clNNZk01ejJqU2ZvR0NLCm90TGpidWY5ZHR3NjlyTHMyWHdDeWdUUUVxV3RiOER1WjNs'
    b'ZHUwS3V5TXBJcC90MVZHM1hJVlRsNU1Ld2tXT2REdVhuZW1yVTNUZ2oKdTBkVXFzZTRrbWNC'
    b'bUxMWGFrVG9HUzcybDVPaysySlRYUXRsL3I1OTIyNXZzZTRSbGF3UXNtcmJ4b21lN1phS1pp'
    b'YkpZU0s1bUVqRwpsQ1g4L3dQNmY4MmNTZnFwbTFxVEhzSnA3TjQxOGw0R05BOElMZ2YwRkRB'
    b'QStvQit4bmFMd2FjUTlBSDlyQzFBeDRKZWFIMWZSTzhECnVnL29QdXNEdWcvb1BxRDdJT2dE'
    b'K3YrVS9RK2s4dEQvRnVOKzNRQUFBQ1YwUlZoMFpHRjBaVHBqY21WaGRHVUFNakF5TXkwd09T'
    b'MHgKTkZReE1qb3pNem93T1Nzd01Eb3dNS0l1SFVjQUFBQWxkRVZZZEdSaGRHVTZiVzlrYVda'
    b'NUFESXdNak10TURrdE1UUlVNVEk2TXpNNgpNRGtyTURBNk1ERFRjNlg3QUFBQUFFbEZUa1N1'
    b'UW1DQwoiIGlkPSJpbWFnZTE1MTAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'RU_SPE')

RU_SPE = b64_RU_SPE
index.append("RU_SPE")
index.append("Russia Sankt-Peterburg")
catalog["RU_SPE"] = RU_SPE
catalog["Russia Sankt-Peterburg"] = RU_SPE
country["Russia Sankt-Peterburg"] = ('RU_SPE', '', 1)
lookup["RU_SPE"] = ('RU_SPE', '', 'Russia Sankt-Peterburg', 1)
lookup["Saint Petersburg"] = ('RU_SPE', '', 'Russia Sankt-Peterburg', 1)
lookup["Russia Sankt-Peterburg"] = ('RU_SPE', '', 'Russia Sankt-Peterburg', 1)
details["RU_SPE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Saint Petersburg"}
regional["RU_SPE"] = ('RU_SPE', 'Russia Sankt-Peterburg', 1)
regional["Russia Sankt-Peterburg"] = ('RU_SPE', 'Russia Sankt-Peterburg', 1)
#----------------------------------------------------------------------
b64_RU_STA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNTkyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1N0YXZyb3BvbF9LcmFpLnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlu'
    b'a3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0cDov'
    b'L3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzIGlkPSJkZWZzMTU5NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJu'
    b'YW1lZHZpZXcxNTk0IiBwYWdlY29sb3I9IiNmZmZmZmYiIGJvcmRlcmNvbG9yPSIjNjY2NjY2'
    b'IiBib3JkZXJvcGFjaXR5PSIxLjAiIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiIGlua3NjYXBl'
    b'OnBhZ2VvcGFjaXR5PSIwLjAiIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAg'
    b'PGcgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIgaW5rc2NhcGU6bGFiZWw9IkltYWdlIiBp'
    b'ZD0iZzE1OTgiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFs'
    b'aXR5IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFB'
    b'TlNVaEVVZ0FBQUhnQUFBQlFDQUlBQUFCZCtTYmVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFB'
    b'Q0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3Vs'
    b'RThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFGCnNFbEVRVlI0MnUzY1cyeFRkUnpBOGY4'
    b'NVBlMDV2WGRkdDNYZHZXT0RkU3U3cWJBaGJoSmdzQ0VZaUhzQVZFUlVTRkNEYVBBQnpVS0UK'
    b'RjB3Z0NwTTR3eExCeUIzQ1pSQ1p3TGlOMW0yd3dUcFk2Y3F1ZEZ1N2J1MTZQeGNmYWpBbVBO'
    b'aVkxRlIvM3pScCttOVBUdkpwKzJ2UAphVktNYTBQUnE1VDdSNXZiRzFELyt5ZzJ3eEVFMEFB'
    b'TkFUUkFBelFFMEFBTkFUUkFBelFFMEFBTkFUUkFBelFFMEFBTkFUUkFBelFFCjBBQU5BVFJB'
    b'QXpRRTBBQU5SUkxHK1I4amhFVnBiNlQydWNzc3cxZ2VYTFgzdHdqSXBPVGMrWnFzd3Vkdnpy'
    b'Z1JQUjZ6MEJ3WDVWMEcKZzhIV2MrdUtGbnd0ajlPRVYwN3VYUjUwUHNGcGppQzRBT0pKMVRt'
    b'dmJUb1J2dXVKMmZUenZwM2I5aHpDY1J4R1I0VFBMWVpKQWhmYQp6cndhdmpuMmRFaEQzeE5U'
    b'aEpnM0xXRDlNcEpUaHRxQ3dTRExzZ2doNDVsZFVycUhvVU94UGpxSTZPK3k1ZHdYWGdjaEV0'
    b'aE1wcTdHCkd6MHV6L1FLSDZsV1RIVGNLVklJVUU3bGZWZVE5OW5PL1ZaY1VwdE5VaE9HS1kv'
    b'MDJNSDZOUnUzeFBpTWp2cm9lRHBrc2pTWERkc0oKTmlqdmFOSlRHRnU4a3NSWXAvTXlvdUls'
    b'UklFajUrVVBqMncvT2lLTDAwck5RbVVnUytxZXUrRk1Sbll1akk3STZuOTB3YXVzNi9mTwpK'
    b'Q2xzeHF3MFIxNXhyeTl1S3NCcEY1bFRTcnRjSHZ2aHMwZXRlWVg2bVpuNlFtV1d3TzVPWERz'
    b'eWFJMzlieDFSZjBVM2ZaL2Y1VXdSCitXMFphVm5wTTZyZGZkYkEySGlRYzh0VVBReEdURnUx'
    b'QkVIaDJneDFydTU4L2U0VUZUczhpaVF5MFVmMUJwalJrY1VRYVltQjlneE4KZ09IWUF6MHVl'
    b'OG9hcEVLVVp5RGRmWTJINkpHQ3NpbHhIa0pJMDM2MFBJbExGRHFFWHRrd29ZSURsc2kvM2ls'
    b'cnBNcmswUWxLa3Y1QgpnRlFScWhSQ2xjTEtNekRqRWJyMVpGQ1FFRjRKOGhXWVpqNGZ3d1Jx'
    b'RVp0YkFkQVJKL1dxZjdDOEZSVFhqSmtiL254bmNkTUYrZko4CmZhSVFtM3EyT05WM2E1UlQ3'
    b'M2UvVVZKU0NkQVI1NXJZV3pwdytySmRUOFV2ZkxaWVpmczBTN2V1UXVkODNiM3QyZUxNUlpz'
    b'YmJVc3IKUmpxdkh0Z0swSkZGMHlHK1VGbGVhVTYzZHR6MXp3c3ZLb2FiYTdUMzBuVzFTZElu'
    b'TmJwZVhlK3U4UHFWUG15Qi9mS3M1RnRKaVVvNApZSWtzdjgrakpxOTFqd2hIS1hVRjlaU2Ni'
    b'T3BvL28wT2pIM0xMOFlObjR6NlZqQXNDbkpEL0lIdGVsWDNwSUYrS01nc0VROE9ENWxZCmxv'
    b'M3BvL0JvUTB1a0NvZDBOMEpmTGM1dUZJbzNENWo1TzRvYWgzMFY4ekp2NGpneURZbzNOcTl2'
    b'OWM2aE1VR2kyRlc1SUxQRWN0Q0cKWmI2NGVndWM2NGc0QWRzZmtxN2lTZlFsRlZ0cEZuL2tL'
    b'S2VwdVE2MzBPWGhwU3I5NTJ2cmUxZHVXS3U1RVNlTlg3Witoem11dHNWZgpIcS9Sd1l5T2ZI'
    b'cDR4dU9ad3o4K3JybmUxdWtpVTArWktESGJuaUQzeWNSTStCSXZDOTBmRXpuZGpuM0htMjRa'
    b'UFZXODQ5ZFBmUmMrCnh3U2o0KzltN2IwdDlKMllDZ3FLRlJQTkYxcVFpanRscjJhTmQ0bUFy'
    b'Q1RiRlg3TXRJK0hFSU56ak9uU2xWWHB2MklNSHBycVl4a0cKWm5RRUJmeVRZb3JXYXJCMmc2'
    b'RlFxS1RVb1NTQnc4ZVFSN3BMZm5xQU8wTnlGWDlTVG5tWDVQYk5Gb2xzckRsQjd2VUdDTGQ5'
    b'bk9EegpZL29WemF1cnE0dm0vbFJKT1k4SG1jRGtiWjVRd3ZESEZhajc3WFhuRSt6a01KNi9y'
    b'Q2kxY0laK2lDM2I5T2FYb29GTzJ2d0xJU2R0ClRMeWM1NXpHdEM5VnJjWXdMSGFoLzRXVFNt'
    b'Y2JLbmpDMmNZN2Q1ZVU5Umw2WjhrRS9hMGRDMUZtR2o1Z3BST1NwUVN0Y041Y25HOFoKZFF2'
    b'anhQUzl2dGtidnpsbWJMbjB5dEtWOEdFWVdjdmZhMG5RWkZUUDdUeDhzWlJIalVsWVg2Sm5L'
    b'TVY3dW1CZVp0RWNIYzluSVlpaQpRUnQ1elY1OThXRVZRaGJMbys1WVYwWUlZWnpmSE1VZlo3'
    b'UEQxK08yWGtJZ1J3aHJQYjA4S2U5ams3RStyL1NkRithdlJ3aDFHUTY1CjNkTThQTFhiZU9Y'
    b'ZHovZTRKaWRsQ3NVZm16T3VXUDV4RnY3cTU3ODZPdjZmQVRSQUF6UUUwQUFOMEVBQTBBQU5B'
    b'VFJBQXpRRTBBQU4KQVRSQUF6UUUwQUFOQVRSQUF6UUUwQUFOQVRSQUF6UUUwSCtOaTEzbzN3'
    b'R1BjVC8zZ2hOVlJBQUFBQ1YwUlZoMFpHRjBaVHBqY21WaApkR1VBTWpBeU15MHdOQzB5T0ZR'
    b'd05Ub3pORG95TXlzd01Eb3dNSVZJb1ZBQUFBQWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdN'
    b'ak10Ck1EUXRNamhVTURVNk16UTZNak1yTURBNk1ERDBGUm5zQUFBQUFFbEZUa1N1UW1DQwoi'
    b'IGlkPSJpbWFnZTE2MDAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'RU_STA')

RU_STA = b64_RU_STA
index.append("RU_STA")
index.append("Russia Stavropol'skiy kray")
catalog["RU_STA"] = RU_STA
catalog["Russia Stavropol'skiy kray"] = RU_STA
country["Russia Stavropol'skiy kray"] = ('RU_STA', '', 1)
lookup["RU_STA"] = ('RU_STA', '', "Russia Stavropol'skiy kray", 1)
lookup["Stavropol Krai "] = ('RU_STA', '', "Russia Stavropol'skiy kray", 1)
lookup["Russia Stavropol'skiy kray"] = ('RU_STA', '', "Russia Stavropol'skiy kray", 1)
details["RU_STA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Stavropol Krai "}
regional["RU_STA"] = ('RU_STA', "Russia Stavropol'skiy kray", 1)
regional["Russia Stavropol'skiy kray"] = ('RU_STA', "Russia Stavropol'skiy kray", 1)
#----------------------------------------------------------------------
b64_RU_SVE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPCFET0NUWVBFIHN2ZyBQ'
    b'VUJMSUMgIi0vL1czQy8vRFREIFNWRyAxLjEvL0VOIiAiaHR0cDovL3d3dy53My5vcmcvR3Jh'
    b'cGhpY3MvU1ZHLzEuMS9EVEQvc3ZnMTEuZHRkIj4KPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciIHdpZHRoPSI2MDBweCIgaGVpZ2h0PSI0MDBweCIgdmlld0JveD0i'
    b'MCAwIDYwMCA0MDAiPgo8cmVjdCBmaWxsPSIjRkZGRkZGIiB3aWR0aD0iNjAwIiBoZWlnaHQ9'
    b'IjQwMCIvPgo8cmVjdCB5PSIxNDAiIGZpbGw9IiMxODdCQkYiIHdpZHRoPSI2MDAiIGhlaWdo'
    b'dD0iMTgwIi8+CjxyZWN0IHk9IjM0MCIgZmlsbD0iIzE1OTEzRCIgd2lkdGg9IjYwMCIgaGVp'
    b'Z2h0PSI2MCIvPgo8L3N2Zz4=', 'RU_SVE')

RU_SVE = b64_RU_SVE
index.append("RU_SVE")
index.append("Russia Sverdlovskaya oblast")
catalog["RU_SVE"] = RU_SVE
catalog["Russia Sverdlovskaya oblast"] = RU_SVE
country["Russia Sverdlovskaya oblast"] = ('RU_SVE', '', 1)
lookup["RU_SVE"] = ('RU_SVE', '', 'Russia Sverdlovskaya oblast', 1)
lookup["Sverdlovsk"] = ('RU_SVE', '', 'Russia Sverdlovskaya oblast', 1)
lookup["Russia Sverdlovskaya oblast"] = ('RU_SVE', '', 'Russia Sverdlovskaya oblast', 1)
details["RU_SVE"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Sverdlovsk"}
regional["RU_SVE"] = ('RU_SVE', 'Russia Sverdlovskaya oblast', 1)
regional["Russia Sverdlovskaya oblast"] = ('RU_SVE', 'Russia Sverdlovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_TA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPHN2ZyB4bWxucz0iaHR0'
    b'cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZlcnNpb249IjEuMSIgd2lkdGg9IjYwMCIgaGVp'
    b'Z2h0PSIzMDAiPgo8cmVjdCBmaWxsPSIjMDA4MDAwIiB3aWR0aD0iNjAwIiBoZWlnaHQ9IjE0'
    b'MCIvPgo8cmVjdCBmaWxsPSIjRkZGIiB3aWR0aD0iNjAwIiBoZWlnaHQ9IjIwIiB5PSIxNDAi'
    b'Lz4KPHJlY3QgZmlsbD0iI0YwMCIgd2lkdGg9IjYwMCIgaGVpZ2h0PSIxNDAiIHk9IjE2MCIv'
    b'Pgo8L3N2Zz4=', 'RU_TA')

RU_TA = b64_RU_TA
index.append("RU_TA")
index.append("Russia Tatarstan Respublika")
catalog["RU_TA"] = RU_TA
catalog["Russia Tatarstan Respublika"] = RU_TA
country["Russia Tatarstan Respublika"] = ('RU_TA', '', 1)
lookup["RU_TA"] = ('RU_TA', '', 'Russia Tatarstan Respublika', 1)
lookup["Tatarstan"] = ('RU_TA', '', 'Russia Tatarstan Respublika', 1)
lookup["Russia Tatarstan Respublika"] = ('RU_TA', '', 'Russia Tatarstan Respublika', 1)
details["RU_TA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Tatarstan"}
regional["RU_TA"] = ('RU_TA', 'Russia Tatarstan Respublika', 1)
regional["Russia Tatarstan Respublika"] = ('RU_TA', 'Russia Tatarstan Respublika', 1)
#----------------------------------------------------------------------
b64_RU_TAM = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNjIyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1RhbWJvdl9PYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5r'
    b'c2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8v'
    b'c29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6eGxp'
    b'bms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3Lncz'
    b'Lm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnMgaWQ9ImRlZnMxNjI2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9Im5h'
    b'bWVkdmlldzE2MjQiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2NhcGU6'
    b'cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8'
    b'ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiIGlk'
    b'PSJnMTYyOCI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxp'
    b'dHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFO'
    b'U1VoRVVnQUFBSGdBQUFCUUNBSUFBQUJkK1NiZUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFD'
    b'QmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxF'
    b'OEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVIKbVVsRVFWUjQydTJjZTVRY1ZabkF2M3R2'
    b'dmJ1cWU3cG5laWFUeVdReWszZkk1QUZEa0xBaGhFaVFCVkdVeDRJS2VnNmlxTWk2N2xsZApG'
    b'MWZkUGVzcXVvdTZDK3JpRVk5NzJJaUNpaXlJUjE1SkFJTUpTY2drUUY0bW1XVGUzVDM5cUs3'
    b'SHJmdllQNlpuSnBDa3dUMlFDWm4rCi91cXV1dmQyM1Y5OS9YM2YvZTVYaGZiT2JZVjNtbnox'
    b'Nm04ZVNzOStaMTJ6QXU5SXdSS2hkOWdWUTAxcW9HdWdhMUlEWFFQOVZvbTEKTXJ4dzNvWWE2'
    b'TGY1Y2gyWnVMcDBjZWNUQmdwcW9OOVdkUTZNT1g2N3VXLzFqS2RxY2ZUYktONlRabWx4L05W'
    b'Rml6ZjJycWxwOU5zbwpnZ0VTQUZMNHdxeUJmb3RGYlJWYU81LzQyaDYyMkwzalg4K1BubDha'
    b'UEZjRC9WWm9jUmsxM0pyUjVyR0tzVXZ6bEpsQlVnTEFLcmJoCks2MWZHaVRUeGh1UEhxK0Jm'
    b'ck9DZEpuNldBbHJBZ0I0QVFHQzlDY3lwRTRnUTJLSEdkaHYwZ1phK05GL2FQOUhRSEJZbVFr'
    b'QUtvcXUKYjdzL29SUnFvUDhNa1NGQ2pwaitnNHpTeElFRHl5b2tHU1UvbWxkbk1JaEFCakFq'
    b'ZnZRcjFoMTZrejljYW1SSWJkUUg3MWw3UzBmVApuL0s4cmdiNlRVUnY1NGV4TlFIU0pRQ1Vm'
    b'aE5URzhQcDN4a21EVUlVQ0FDWWl6MnpLNVEreUFCV3hUYk9uck1IQUlhRHhwU2F1MnZOCmJm'
    b'UDEzWS91dXdJQWRCeGUzUHprcFUyUDEwQ2ZWUHlYdFBwUDV0dlc5OXZyUEhwSW9ZZDFvRkh6'
    b'WGNQTUl3Q0FzTFRPQ1dRSU1vS3UKcGo5aWt3TkFsalhjdWZwejAwY09IZlZuN2hoWnZyYjVp'
    b'UWN2dmZMMmMvOTlTMjdGYVRVMWNsdDk0alM2bkFqUmc2cHprUnRiNFpNRQo4cmFhMW5JUEU0'
    b'NDBRbUlSQUNDaUlNSUFJTEN0R0MyQmhGeXljWW01RFFTc0g3aHBSZnFGejg3OWxoNEdkKzY4'
    b'NCtYQ1dUV05QbTRaCk1vc1psM25PUjB2bE9aSC9vdTY5YlBFOHhLOG9LRW1PNHlCOU1CZVZl'
    b'YUFDQUk1WDRqeEhMd0tBVjNLNjJsOFFMdUE2aUlueVRlMzMKaWp5OEtqcWY3SC8zTExUdGgr'
    b'VEQzODkrWkszN3dHbmgzaWR4SzRzdkR4ck9wYUtFUzcrS2lRQmhSeVN1THZmdlVaMGVaY1k5'
    b'L1R3RApwQm16WVlKWUJCZ2swb1RQdEJiSmh5VUFrRWFJZWtoZjNheFdka0F5S0NickZZdFp2'
    b'UVdTZ2s5dXZpOFI3UHY3NGozRlg4WDRDRWFxClRGeFZsdlg0QVhIbGVuTHJsTlBvUWoxTHpX'
    b'WWpQNHFMWVZ6M2taSzVMQlFsbkwvZmJwNGZlWE9wdDhzQ0JMSWtTQktBQUFoUVVsU00KNkpK'
    b'VndtUVpRSTZtVytJOWtnRmdNR09oWFN3QXdDNjZ0RG5ZOWFYQzNZWDFOaC9CeGtLYS9KakxY'
    b'Vno4TCt2YS9vZG5vTzFURGpRVwpDQ2VFMnN4S1QxaUZYOFhNODBObnJTY3BHdm1wazU0bUNy'
    b'MEUxNEZ3QWNjWmRnQUFSQkZJczVSak9Uc1pBSjFsNGxJRUFOZ0MwL0pFCkNiQURmUWNUdHhk'
    b'L05MTGVFVDZLL1VVUVcrTVhIekZMajFra3hVbTk1RmlkY3M1UW1CQnJpNndsb1RxRCtUdU1Z'
    b'SmRtWCtMcEhTelkKclFYZG1sa3ZyUE5DNlVsRUFNZEFlb0IwME9ZeVlJQk53QllnSFZJdGVW'
    b'a0FrRUJTSUgwcHl3QkpuUHkxVy9pNURRd2xQdURxQytqSQpUK0k4UjV6THk3SHpnOGdsTy9p'
    b'eWZyVjlxb0NtQ3RnM0ZsUExRbGtpeGNkanhqS3F6V1JJbGYxYmRXaGxkU3RDVWNMK0ZrT2Z4'
    b'L1Y1CmxGR0ZIdFZrcEFJbXdrTUlJd2xZWUJJcGVyR1V5SkhHWHExdEtKcG1RR0E2SWQxalpM'
    b'NlhVRnRaNHYzbHplM0x2ejE4MnpyOGpMa2sKVkZ0NDhlZU8zaHBkYkcvcXFuLzJhZTlDZ1l3'
    b'ejN4azZ0eFRvTTJhNFgwdmRWTUp4TGluT2xMVzdYcng2dEg0Z2RLVFRGaUdCQUVCZgpRQkVJ'
    b'eVVBeWdKUGxNQkFnQlpBS1V1THdWVTFLOEd6ckJYNTJYazRmdFRIM0s3Y3ZzdnNFSVlUeTdM'
    b'MXhaVHFuMTJvZkxmOGNUbTNCCndxbk9SMU1BVFlmU1hnMEEzSTJHZHBIWDk5OTJWdG8vdVBW'
    b'dlQrUXgzOXlnNGRpSDVoT2MvRXordTA0Z3YrN2MwZjZISHNsUTFLTTAKRlBLRVo3aVJQcE9k'
    b'b1FZZ0FKR0VBQUI2VUZVRklySFg2NnFHNUh5bHRJQVVOUFQ2VXdxU2JWcllxZVIxRUsvUHBp'
    b'TFpvUWFMOFloKwpmQzhpNTRjSGd0M2FhTHFLV2lyVFVtZCsxREhZcmNiVytnQUFBb0lYOWZR'
    b'SHk2Tmc1aGowMmRYUnY1MFZMb25SMVFjZnZPRGdROHNkCityM09jT09GZEtZV1BIa0J2YWZU'
    b'WHhhajUrLzV4WFdsalhNdCtzWFovb1lMMlNYeDhvWlY5QWRMYUpjVG52ZnEra3NISGpzclJy'
    b'OCsKUDl5ME9scHVWMVQ5eTRtdlJpK3FNa0lBWUwvYmUwUmRpekE1eGJPZWhLMHM5Um1UZjd4'
    b'Z2RJWkJ0Kzd2MU9Pem1Wd1JBc0JScW16TApSamQxcHE5YndIL0I1Z0xBUDYxTEtSaCt1aXZY'
    b'VC9WbnM5RW5PaHR1V0c1OUkxTi85cEo1SDE2Y2FrZzRqM1FmM1JrWXp3eXhXNVlrCjM3ZFEr'
    b'WDV1K3NLMjZaODVyeTVoNkEvdUhqZ1E2QUJ3RHZsOTU2RzkrUmRzQU5EblJMbjV5ZnZjMjAr'
    b'OWdrM095akRRWlBOTnBkTEQKTVRaRWdFRHVldm11VktXQ1lFR01YZGNpU3QyYlFoYWxscTk1'
    b'b0pmc0xWZTBvY09Ncm0wUmZUdWU2N0FCemJ2ZzEvMTRlNmtTRjgrMQorTlhUK2ZDT2pZMG1H'
    b'SXRXL2F5WHZPeFdldjIyZE9XYy95bklFSkdFTUsrbkg0TDdBdHc0VlJZc0JrVTlHd3o3RWg4'
    b'QWdBTWZtYmlNCkFwV0hDbDVYYzJ4RmMydzRnR3d3WVl1SFErUXh0RElsbGpUWHZYUzRQeElU'
    b'dG5nZ2tDNkhsVTNLOHViRXl3TnV5STZ4NERrcFF3UUEKem51OE80MWJKb1h5Wks0TXJUMGFT'
    b'ZkhSMzVmdVJLVEZBVCtUdHdDaGtNbW5za29FRThiVUZjcnpPUWlZWUVJOFVVNGpQTkhMbDJS'
    b'VApCb2NNaElUZmx4eUpKdVlsd2tvelhDKzJlR3NuYTc2VFZtNUFFQWdFMkJMQ3hZSk5JQnVL'
    b'Q0FENTVraGRKR0N2L1JxWEpRRzJGclUrCmI5RmlMMXMwWXQybGlWTk1vaDBsNWV0ZVIrdElJ'
    b'V3RwV2YrWVhsRWwzSTRzUlhqMmxBTU5BQ0FrR2lWNVhFRDJralgvWkozNnJCbDkKTU9PRXA0'
    b'NVlNNCtjWUVFREFJQXdTSmpNa3VwVERUckNVSGRqVWJ5cXkwalM3WHJpZWxkNmVPaEkvTTl3'
    b'MzlSSGtnbmRlYlB0ZFloZgpVMWJUVWJoRi8xbjV2VUJRY1lYOXFlaUhsV1RWR2JzeVhCb29B'
    b'UzVzMWdFZ2NXMlp2cUlhU3lrZWVlTWFnWHAvNk8vU2g4OUsyeXlpCkdHTlZWVjhlY3U4Y2Fo'
    b'MDBtOTdBQzFsQ1RiTmdsNkcwTUhlOUNRQ05NM0lYem43c0tmZTZNeGwwdkkyTnh4aFlGNlJE'
    b'QkFkVWtoVFYKZTcyWDd2aDhWekxWc01nMERNTTBFQ0JOMStjV2k2dnorVzl0MlBxQTFsWHQx'
    b'c1kxdWxmVDJpS2tWVzRuRzhMbnRXMS9DazRwNkZNZApkV0FDRUtCeDV3YUcxR2JUL3MxNmxT'
    b'N3JndTFmVzlPdWFLcGhHSXl4SUFoekk5bHNOc3VpcUtHaC92T3Iyajh3L0xzcTNYL0libUpM'
    b'ClZLUk5wS1ZrZ0N6cG4rSGhuV0JvdEpvQUFHU0lqdjVSeTMydnpqeDgwajlXSWlyODg2cFdB'
    b'RkNKSW9YZ1F2aWVoeERHR0JPRkJMNXYKR3NhSGxqVE9HL3pqeVVZNENtZGRHeno4T2VmTElx'
    b'aE1GbG15akt3ekhIVG9JalNXUmVJWmttaGoxZHZmck8vUk5BVWpKRUZLRUp3eAozVEE0NDV5'
    b'eE1LU3ArbnBBQ0NGNEgreXBQczVGK3VZSms1VVFoN1VaWnpqbzBuNlYyQldMN0czUll5Mjh1'
    b'aDljMlJvWEVtZ1lOcVRUClFvRHJ1anRmMm5INDhLRkNQbS9vZXJGWWlpSWFoR0hhTVZWYXFq'
    b'TE9LdmFDLzJMRlFCRmI3QWdYbmVHZzQ0ZFZWTWV4S1FGQWxEQXEKNHZ5MHFrck5xYUtRbUcw'
    b'UEQyZkNJT2plK2RKQWYvK3VuVHUzNzloV0xwY0p4bzd0cUtwcUdIcmN5NXhzREpzZFRPWUxi'
    b'SWdBQUNJQQpEV2lQZDk0WkRwb0FsSG9WODEyVlRWWmV3dlppV3FXOXJoazBwSnFtbXFZcHBE'
    b'aDN4WGwxeWRUczJYTVdMbGlrcWlyalBHSU1wRVJWCnQwdVdwbmFJUW1XbTVvcGdtM2FXSUtm'
    b'YVJrL0N5bkI0dHpicjdFcW1tT2VSbWF4bVBFSWE2b1pPUThwWVpOdE91ZXgyTHVrRUFOdDIK'
    b'b29nQ1NNTXdBQ0VoZUpWQkZzb0RvbHdCcmJXeWg4a2xVeUtwcE8xWFVhSmlwa1dlcUhxMUlG'
    b'ckJPUEFEaExIZ29sZ282SnF1S3FvUQpzbFFxUmhIVE5EMmZ6MnVhaG5FMWpVbXpqQmpMVytH'
    b'NGVDVzdaRXFBdGpoQ1k4OUZDQjloclZwaktjRjI3SkJTSVhnOGtmQjhQNG9pCkliamp4REZD'
    b'cnVzNnRvMEFSYlNhL1RGa0tNZHllR0RoVUowK0pVRERNWFg1U2tvd3Q1cDU1VklHbmc5U1Nr'
    b'QmwxN1ZNVTlNMVZWRmMKdDhRWWk4ZWRRckVZTWFicDFXNVhsaVJ4WW55NUlrRHlLWkc5a3dC'
    b'U1ZPQWlXMFRWZEJGVVZUVmpzVEFJTUVLR1lTQ0ViTnRtRWRNTgpvMWpJNTBmeWxtVUJTTTZx'
    b'c1J0VTBzZ1lNMUJNU2hZaFRUbnpOYnFFSndvRWlDbXBoNnRxTlBjOVQwakpHRU1BQ2lIWlRL'
    b'Ym55Skd5CjYwb0o4VVNjVW9vQXFXcTFXcTllM0lTMThhSTlGQlA5VTBLand6UVQ0M0JWR1Jh'
    b'cWJVZ2J1a0VVaFVXUmFSaDIzUG5kNDcrbGxJS0UKVjNidld2ZWV5eWlsSUNYam5GSmFwU0Jt'
    b'S0tnSGJUelJnUnZTUXoyczQ4elhhS09CeXpGemdWU0ljdFd1d1N0N0VhVkVVV2hFUzhWUwp1'
    b'ZXpsY2lPNWtaR0lSWVZDb2E0dWlRbkJHQkdGd01tZng4cVdrMWdkVDdCQWs1V1pFczVRYitC'
    b'eVBMOWpDRDVZVGFOanBxNnFxdUE4Cm1hcEhHT0V4dFVVSVNjNkdod2VsRkVKSXpxdlo2Qkhh'
    b'Z3N3S2FCR2lGaGlZR25HMEpZVTN4c3VRdG50UzBIK2w3QWw4Zi8vK2ZabHMKTmpNMEpJU1VJ'
    b'R094MkRsZFhTMHRNN2dVanBQd3ZmS1JucDVjTm5jRGRCTWVuamhscUtlRVdmbEY0WkptTmpR'
    b'bGJMUnFnT2dkMDJoTgpuakFWSGVQZVhUTjdQMzdWWmVOSGR1L2VmYVNuaHpObXhXSkhEaC95'
    b'L1lBelBqUXcyRHF6YmMyYU5hN3JBc0NjVjU3N1dtRmh6anF1CkJBOGhxdXBJa1pJaG5zWE5Z'
    b'bmhLZ0ZaTXdZdGpRY0pKSE5pbjBSYWIxZDMvd0VOQ1NpbUZsRkp5SWFSMEdwcWxFRUpJblpp'
    b'REJWZGsKOC90NitsakVtT0NDY3lua0IvTlAzMnZkY1B5QUVSQ2tTOGtRTCtBa0xrd0owSWpB'
    b'YUJrY2pEa3dRM0FRSEk2cGgxdmVNZVBxOTZ6aAp4d3BqbkhOMnpPZkt4OWQrM2J5OSszVUZ2'
    b'cWl5d3NSSWtRQWdRNlJJTm1WQWp4WnljTUFjQVVBakMxTWpSM1AxYmVOdDd0M2pQMzNrCmY0'
    b'VVE4clh5aGtjR0lnT09LVVZTd3JLdTZnQ2c4OUR6ZFFDUUZDbG9hb0FXRkpRNkhoMVdSbU1B'
    b'VjVNMlJXc09iSHJvR05CUDZZdWYKNHNmbzVQKzNJaVBsWmJFVFF6elFlRlNtQmdDUWVoNUk0'
    b'OVRQZWhLaURyK0lsVmtWbmVKNXJKMGZBc0RmdkhqL1pkc2ZWTmhiOWdJZgp6TUxHL05HWkdn'
    b'YUFydmp2WmFaeXIvUzUwYXRrOXBUUTZNSldJM1ZGdWJJZWVkYVk5cGRlVHo5Tzc0WHZidnJQ'
    b'd1QvY082REhUeGdTCkk0QkJaOXBEQ3kvZDBIa0ZBTlFWKzZhSlFPZFVudWlaQzRTUXBocUs3'
    b'UUJBRzk3NlJmZjczZ3VWNkVacDRvLzZhNmNFNk1RQW9RaXMKbFlIM3ZCSDFLZVZuekprWCty'
    b'bkZOSHJZYm1KaEV4djJsb1YyZXlRb3l1OVZuWDNhaElzc0Q2OGI2TDZOczUydFM5dWRHTUxI'
    b'UE9ZawpSYXV5OVFKN1N6b2Fmb2wzYmd3K0FBZ2hFZDJRdlB1NjNHUCtKcDBlVUFIQVhCWm0w'
    b'cWxENVJXbnZqcHNjdXFqM2VhbzlYTGYvWjBWCkhWRUFBT2t5Y1UySk96RDhZMXRmRWNRZEVE'
    b'NGlqaUJKQVFsUlBFcXl6eHQxQXhXZGVLNis0NzVWbjRpbXo2bFlZYm5ucXJyZnJBczMKbVNN'
    b'K0h5RzhnTEVwbnAvWjlSMzR3amZxUHordjcxRGhBWHQwZmFRMGNmdHkvNi90ZnpuSXVpWWhC'
    b'SmlzUjVUZGpxaDFyZTl2Tm9MdQpTcjRuZm9XSFprWVlBRnlNRXlMN0h3a0F3SEVSV3hrbzA3'
    b'alFSWG1JQkVWTUtYbDgwV1ZSeW1sblBXZkwzVTJsREN0aWI0TVI5U2tBClVQK3BBaThqR2Nk'
    b'RHNZYkcvWm5DZzVYeVVYMWVaS3dLdnh6N1FqZTdlRkxtTzVuUGd2dEpQdTI2c3VoUlNvOVZ0'
    b'a3J0ZFo0Mko0SVEKZ1VTNUg3K21DRkZ0WS9xY0NNZmtlTVdSOERIZHI5Q0RyMG1RcG00dVNv'
    b'NndKV2lQVW5va1ZobDJyUmQwR3JmVGY4M0Fnc21hTEpyYwo5MGRUQW9tYkM5b3dLZnh5UXZY'
    b'MGhaVFVjK0hpNkUrS3Q4MEE4V2JtQWViU1VKdkxjSnp6REtINzFPRGx5aC9GdWR3Yjdxei9k'
    b'UDV1CmhpZnpoUmxvMGwvVUhSRkkzRnpVaXFqd1M3dXlzNGNoT0NjVUlOSUxJOE1HbGlIUlFl'
    b'SnYxeVU3em9VUk1KZUcydXdJcDhVQm8rMGgKOVhLamQrVEc5WStPN2xVaFZjYmZYKzZiM2ZU'
    b'Wi9OMm51RWozZEFROXl0cThwcFJJQ2hGZ1VjTFk0Wm43NHFQQlJsbVg1SndnMmNHcwpKSmNC'
    b'Rmk0ZWZWUUM2Ukxia3Rua0FKcjF1TGI2MmR6Rm9WSlpFZjZNWFdsa0tYRUVtUEs1MU5uZnp0'
    b'NHg2WlJQRjlDalVveHhkU2tsCldMSnRwdVdkSVA0cUV4azBjRXprVHk2NnRUY3hQUnUxQ2Ez'
    b'dStHYTZ5SjFidDRFVDNKMVo2cEpacDhuc1RxTlhac2JMQko0M0FlQmsKRzlveGptS0RDZ0FV'
    b'NlB4aDFIR3lkaUZPUFZ1OGF0U3duRDVTZTM5MERYUU5kRTFxb0d1Z2E2QnJDR3FnYTZCclVn'
    b'TmRBMTBEWFpOVApJdjhINXdLOThJcDl6VHdBQUFBbGRFVllkR1JoZEdVNlkzSmxZWFJsQURJ'
    b'd01qTXRNRFF0TWpoVU1EWTZNVFU2TURZck1EQTZNRENmCk1UZTdBQUFBSlhSRldIUmtZWFJs'
    b'T20xdlpHbG1lUUF5TURJekxUQTBMVEk0VkRBMk9qRTFPakEyS3pBd09qQXc3bXlQQndBQUFB'
    b'QkoKUlU1RXJrSmdnZz09CiIgaWQ9ImltYWdlMTYzMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'RU_TAM')

RU_TAM = b64_RU_TAM
index.append("RU_TAM")
index.append("Russia Tambovskaya oblast")
catalog["RU_TAM"] = RU_TAM
catalog["Russia Tambovskaya oblast"] = RU_TAM
country["Russia Tambovskaya oblast"] = ('RU_TAM', '', 1)
lookup["RU_TAM"] = ('RU_TAM', '', 'Russia Tambovskaya oblast', 1)
lookup["Tambov"] = ('RU_TAM', '', 'Russia Tambovskaya oblast', 1)
lookup["Russia Tambovskaya oblast"] = ('RU_TAM', '', 'Russia Tambovskaya oblast', 1)
details["RU_TAM"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Tambov"}
regional["RU_TAM"] = ('RU_TAM', 'Russia Tambovskaya oblast', 1)
regional["Russia Tambovskaya oblast"] = ('RU_TAM', 'Russia Tambovskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_TOM = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNjgyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1RvbXNrX09ibGFzdC5zdmcucG5nIiB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtz'
    b'Y2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9z'
    b'b2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIiB4bWxuczp4bGlu'
    b'az0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sbnM9Imh0dHA6Ly93d3cudzMu'
    b'b3JnLzIwMDAvc3ZnIiB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4K'
    b'ICA8ZGVmcyBpZD0iZGVmczE2ODYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldyBpZD0ibmFt'
    b'ZWR2aWV3MTY4NCIgcGFnZWNvbG9yPSIjZmZmZmZmIiBib3JkZXJjb2xvcj0iIzY2NjY2NiIg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIiBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIiBpbmtzY2FwZTpw'
    b'YWdlb3BhY2l0eT0iMC4wIiBpbmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxn'
    b'IGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIgaWQ9'
    b'ImcxNjg4Ij4KICAgIDxpbWFnZSB3aWR0aD0iMTIwIiBoZWlnaHQ9IjgwIiBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIiBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0'
    b'eSIgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5T'
    b'VWhFVWdBQUFIZ0FBQUJRQ0FJQUFBQmQrU2JlQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNC'
    b'alNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4'
    b'QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBaApSRWxFUVZSNDJ1MTlkM3dVNWRiL016TTdz'
    b'NzFtc3ltN0lRa0o2VDJrMEJOQ015VElwU09Lb0lJWUVBUzV3a1d4WGhVRkJYSlJWRUJSCmxK'
    b'ZXFZSUFRSUpRVUNBUlNJTDFzZXJLNzJaTHR1MVBmUCtCM1FXejMraEg5eFpmelZ6Sjdubk9l'
    b'L2M3WnMrZDh6NU1KeERBTWVDZ1AKWHVDSEVEd0UraUhRRCtVaDBBK0JmZ2owUTNrSTlPOG9G'
    b'WmUrdm5YMUpBQ0FwbW1hcHYvNERiRCtqd0JOMTd6S1l0bWJSQmVQNVc2SgpqNG1iK056emY4'
    b'R0lKZ2ppNk96TW50WVdBTURoWFM5L3UzMFdBQ0J2NnJqcS9Mdy83SDJhaEprcXFadTZOTGEr'
    b'dkt5KzRPUmZNM1dnCktNclZheHNYUHFyWGFsSDlDUlZUOHZtYnN5TmFibXBmWHFuVDZmSy9l'
    b'dWxLL3M3L3ltQlo2ZmtUeHc4UkJQR3JtbnE5SGdCd2RQblQKV291Y29DQU94c3ljWnFaRGVP'
    b'Vm5DMDY5dFRIdjlRMS9xZFNoMSt0RCs5cjhLZmZKekpGa0psN1FLa1RiSy9NeGlaUW1XNzZP'
    b'amZiQQptKzFyL25OckJvUGhuMisrUVZHRWo3Y2lNU1h0RnpUTlpyTnhkRWhoVUxTeXZiR2pD'
    b'Wk05VCtsdGFLVEs1ZGw3T1RhbkFBYWdpUzBzCjh2SWUrOXpLdjBoRXQ1ZVhzUm5hQ0NIcFZ0'
    b'MDM1NlFYRzRVMURvNHdrd2wvbXNCSjZQdVdaRjFyMGFsdDZlWG52LzVQckVtbDBzY1cKTGdt'
    b'UFNZMklTZmxsVGJGWVhKczRMcm4xRmt6VCtYWlJwd0dWOGNtaVJvSGpNT2lCTVNQTTZsQUZ5'
    b'Y01qL3pxcGc0MWh6U2pYQUtNVgpDQzluUUdkMndwNUR5REVodGk0aldxWkxxREVFdHJXcElX'
    b'Y1hYNnI2QlNOOWZYMW1zeGtBQU1Pd3RiYk9xNzJNeStYZWZzbG9OUDRjCk5mYTNiNzY3b1F4'
    b'bUFjYU1lWnhTSitnc0NKOU5YL2ZrdHlKc2lnRWh1WjlIcEdYOE1VQWpyNy8rK29QMklmTHh2'
    b'V1UvV0cxZ0RwSXkKQTRJT1RVd0s4KzcrbjR0Q3hNbTRmV0w0UXQvdVhuM09waklmVmZCUExs'
    b'ZXIxWjkvbGx0eGZPMlgrdzdlcUdxd20zWFZ4UmMwR2owcQpGNWZmckYyOWZWMTUzb2VYODc3'
    b'czEya2k0OGRBRUhUdldwSWtRVlI4L3ExaUZwYzMrYWwvZm4vaWRKaTN1N3NmcWFYazZMTXZK'
    b'b3lmCkFFSFEyUytldHJzUkwxWElBd1VCK2dObzByeHZOZzIxZmpoRWhpLzVSQld2YytnenBt'
    b'Yk5tTFhucFRXeER1Ty9ZaEZCcUtobVk4VXYKTEYrelluRmxReFhKWjRJZ29rYUlvRzJzWUs0'
    b'YkJVRExjRzlHNGw0TkNLVmdCRFROUitoMWk3YWxqNS93NzRWV3ErWHM0UzA5Ti9jSAp5WjFi'
    b'cThRa1d4QmdzOGxFbU1RcjQ2blZhMXBiVzFOVFU2K1duRWtaV0ZDa0d6TmgyWWxCbnpvTVpu'
    b'ZEZKKzlHT3k4c0VHL0FlRlc5Ck4rTGo0N2ZrNWJ2bkxwVGIyRk10MXF1WGp2L2NXclZhclRk'
    b'ZDh4Y1FYSWltV0VCa1ppZzNaS01Sa3dXQkFTSHZnYndwV29oUkFSU2wKeDFtbnI1KzdkMjNK'
    b'UjhOajZaMXBJWll2U2owR2V0aTRHY3RhK05iYnU4cld2ZlB1dTNzMklTeWs0T3YxNG9hbnpV'
    b'NEVDSWI5RlhMMAo2RWtMQ200SnQ1L3pkSlBRU0xlMUU5T00yWkhScUc3YThNb2JuNzM4Nlho'
    b'UG1DK1UvdHhhUHAvdnhmUHVCakNGTWlRQVFnQXhBR0t6CkFWc09IRzVFYW9Rd0llT2dZUU1I'
    b'dUtSTXZFeDQ3MXJaOEg5MCsrV2VyeGQ2Q0tpaENzbUxUNjFKVEV3c0xTOU5mMmZpQWN0Ulhl'
    b'Y3QKMUZTRWs1RFZoWGlZRHovb2R2R0JsM2VIVnl6aFhpdGFaOUUveC9kbkdJNmJCVHg3T09V'
    b'UlRXbGZUTXE2a3JsMSt2dTlFUjlFSll5OQpyZHpSMFdFd0dIQWNqNGlJRUlsRUFBQXZMeSt2'
    b'Z09FU1J4NFhobUFCN1doQk9DaVZFV08xd3FDc1F1Z2lvU1EvUjVWVEFLUk1RaTgxCmZ0cVNl'
    b'MTJuVEZnTUFQQUpUSnpGNDE2L1VVSFE1SklqT1lXOElrekVlaW53QlhiNzluQ3YvaDRUeSty'
    b'R09DUDJ3akE4dUlGV3BrOFUKblQ4dVlhajlWdlZsbCtBeUluZzNTOWROOHAvekpiN241WmQ5'
    b'ZFhXR09YdlNwRWtZaGhVVUZKaHg4M1ZOcGQxazZ6dW9tVHQ2MXR5Wgpjd0VBcWFNeTJscSt4'
    b'NTJBRDlGaFlZNWVIZHBtUUowa3JKQVFRUjU0UGM1YWp0bTZ1MW5TNEd5RlFnRUE2T3pzUEhi'
    b'c0dFVlJLcFZLCklwRkVSMGQ3ZTN2dlB2cjV1MkFid1NXRDZtVlpacTdJa04rS3VHMnhQTHNi'
    b'YWpaNXY3Sm81S0J2V0ViT25IT202SnhmL3Y5Y1lBa2oKYWRldFNFR0VyNXZiajMxZzRyOTVS'
    b'YUFMSHlpL1ZsS1pmNElqOWFpcnJIalArY24rUi9hT1RoaWxOK2cvTzdBcjcyUmU5dFRzbEZI'
    b'cAplV2RTR2lzcmVnbmtNb1c0V0pBTk1Pd0JpT0l3a202MkNxZXNNRVN4aFcrdmZ3MEEwTlhW'
    b'dFhUNVVzOG9MOGdMUGxKM1BGbVlDRUdRCnQ3ZDNXMStIdjFrc2F4SkphVGpjTnBCdWFYcFA3'
    b'aXR0b3diYWtFaWl2eWRCeFQ5ZjQrdnJPNGlCZHJ2ZGVpOXhCOEtKcDV4NXFOaEQKaHQvbzRC'
    b'VGNFRXYwNUtVKy9kb0JBY0ZZbFM4OTFReXpZZFd3MUpUaDQxUFRBUUMrUHI0THNoNzdjTS9X'
    b'N0tuWktJcSt2RDUzM2pPegozS1ordGdzU3c0eUhCbVlZQmtBd2pkRjZpT1ZpTTBrQkNUd2VE'
    b'd0J3K09qaEZjdFdaRTNOdXUxOTV2bzV0Njk3Y0dYaDFVS2RIZjFrClFHMkY0QjBlWHMxdTdP'
    b'a3EvUVRjd2dOMEQ0SlZYRHdiRVJvWUdULzZBZVdRQndnMGp1UGxaei9WOXpieWllT0hwTkpI'
    b'Ykthbm5mb1YKVGY1dUNINjB6dWhORTlVSWQxNHpVeXBFM2hYNGVFWWx4S2FONzFUdnN0bHNB'
    b'b0VBQUNBUUNCck5UYWRQbnhhTHhRME5EUU5kZXBYZgpzRkdqUm9uRllvRkFBTU93eldheldx'
    b'M2w1ZVYxdFRYc1lKeGhHSklrTy9zNnAyVk51OXNjUWlLTlJtTTJtLzFrcWpZYWlWUzRlcTJv'
    b'CmRqcDdnZHdFOWtQUmxNdUFvRmFHTHBTTHpCZmVuZ3ozbHhvK0dqUHBzVUZXUnpjMjFIcFZq'
    b'WGJnVUZVblQyZGxtWXFnRkt2OU9DSXAKNFFqajNQWk9oSjJCV1NlYkJuYkdlb241bE41bnpH'
    b'V3MybWx6MFJIM2xCd2FycWhOWUVFdEZFVzVoeENJSGhZUENDRVRnQ0NJamJIZApLTzdHY0x2'
    b'SWdTaFlmaWFsRW5nSCtRWmRhU3hyakdsajJBQkFEQUNBcXNUVEFzWW1jUkl1Ny9wSXcwY1RB'
    b'dHhMeHVtdnF2bkpReDBIClBoWkpTQ3FDY29aU3JqZENsV01qN0FvUklSWEFlT0RhTWRtckJs'
    b'TkUxeFc4aWdteEdsdXlKNzk4ZElpZG0wb2ZxeEJmeXhmQUJPMmQKUkdVRjZGT0dPbHJhMkxs'
    b'UlBhWE4vRHBIZ1ZPYS9xWDN0d0MvdDBBRFFIYlByeDQvNjZ0ZTFnd1RNR1pqdWVKd0FBRDRm'
    b'N3dlRkE2WgpXN1hONTNJaGdBUmIzVTA2ckVuTHRqZ2hsUlRYczFsTDdQM3RDUHNsb1dwQmtp'
    b'a3IxdHFpWS9kYXhlNkdqOEFEQVBvQlJuUkw3Uld1CjBOUFhMK2k5OXpheHUzZWpMS2FvUWFD'
    b'eG9LaWJ6dnVIbW9jeHBTMThDQUFIRHNlb25KVjl2Z1ZSVTdkMjd2aTkzeDUwNlYvOEViaXQK'
    b'RDhadXNIaW4yR0pDQm9VRTRWSWVhY2VSVGozYXJtSHpsUkhaNmFFQncrTGNwdVl4MDFiVE5J'
    b'Mmk2R0RpT21RS1A1RllCa0dRUUNCRQpoTU1NbmVXOUpxQzFvSjRDVWlhbUJ4d3NNWmVNOVhQ'
    b'eE1hckxnTFk2SS9WRHZLK1lydjdlZ1FSNGliUGd1djRTaUhNQ0V3dHBadWFBCnFkUWlPTlVt'
    b'bWhCcG5ScHJ1YUJXYk42Nmt5dFdwWXdjSHhBK0VvWmhCRUVHWldlbzBXaXFHcXFuelg1cTBS'
    b'c2xVN0ptaTRSOHB3T0cKSVNZNTBNN0RtTy9LeFUwYUR0aEZSMzl6emE2MS9YcFZYdU1wN1JY'
    b'L2l0SVBQNkxDTUc5ejFoeFdOQU1wb0JtNFVRZXpWaHExU2c1UgoxY2s3MUREeXJmYy9Hekpr'
    b'U0wrK2Y5Q3pkemR1M2NnNXN5b0lDWXlMakl0TFNwczVhellESTN0UGR2RXcvSXV6VW5VbFNs'
    b'WUJNMEM4CmFNSlJweTJJTmYvc1Jpa2t5elpwcm5TbXYwTUZ3NUNHM1UrRG4yNmFzVjRXSmJy'
    b'NzBpaG5xTWhjTTNlRTJ0U0xUT295OThKWUc4SjIKSmliTWZ1YnRKNWUrNU9YbGRmamtrVXBq'
    b'VlhwTTJpQnVXQ2lLSWlCU00wdy9zK254Vi90ZVdqMTlsVWdrZWlabmVmYk1XWnYrK1phSApw'
    b'bkFzYms0aWJBU0FHQUQ2NGdJQjZQaEpPd0YydjlWWXpvaTBFVWxKU1FNREEwYWpjY2FoZWRY'
    b'UzJwOUlGUlEwQmh0UmFDc0NnanQ4CktVT1NvY0xhNDFWaVBjTGF4WlozS0ljdWZldmRwNUtT'
    b'Ym05djcrRXZWN2V1M3pEMHhaWWIxeVZLcFVIZEdqcHk5Q0FyNzFxYm1wcm4KVGdyYSs5MHp4'
    b'OWNXS2NvQUJIeU5YcXNreno0NmZucG9hQ2hOMHdjUEhwUTExVGhvR29KaEhvYWRHNDV2Vm0v'
    b'N2NSNVk0SnoxMmJNNwpNUXhERUVTdjEzTTRIQjZQVjk5UVAvNU1aai9QY0o5NnVtMzBvL3pN'
    b'UGJwOXQ3enFiMS9aR0xJK3pZREU0RnUrS3BWV21rZHN6ODJWCnlXUTRqaC9OLzNaTDhZYzNt'
    b'VG9nQkgrL09YWjJTeFVOUWZqNlRTUG1QekhJSXJxMTRJU3YwMWIvNHJJZDczMjA2WHh1Uisr'
    b'RjZRZ1oKQ09WR0Z2eHo2RGYreTRjOSs5emNaNjllVlUwZU0rYTIvcm16TC8vWUNNZkZudUdY'
    b'WFZGUjBXZlVlRXJselEzTmp6MzJHQURBYnJObgptU1o5Z2Z3UFlQK3dlTGMweVJTUHY1bTBj'
    b'VTdkUWtKQUFnQWdDRXJOZk9IV2pRUjRTTkdXUmFza0VzbWhVNGRmYVh5em1hY0d3UURWCklK'
    b'RmxLcXF2TmRSbHJVVjVjZE5uRFQ2YTFIUEVXQnNFcTNyVWpVdm5Md3FiZUhxa1ZjR0N6Mmxa'
    b'Rkp0dUZyVzljR0h0a2crV21VeW0KdXgrdUh3NUhib3VMNjM3N2s0V3JTOWJONlhzeWU5OU1v'
    b'OUhJNS9NUkJMSFpiTVBrd1d6VC9YWFliTzhadzRjUEg1R1ErcVJoTHFEdQpYT1R4ZUNsanBz'
    b'UWtUWkJJSkUvbkxwM1hzYmlacDRZb2FGcXg4TG52dlVOMThEREthWVFRK05QRC94NlBEU2Fn'
    b'TzdhOWM1UEYzY0x4Citnem1KenRXM3V6aVhHbmhQenB4eDF2dXY0K29rVUJEV1YrTERsZTJW'
    b'dWwwT3FmVCtRdDJLbVpEMTZWVkFJQU5JLzYrYnQwNmlxSVkKaHNuSXlJZ09pUm9DVkJCNXor'
    b'MmhRTTdFWjhWaXNaZVgxMVBaaTRNNy9IL3dKWWxobngvKzRwam1CRVJCOGtiSjZyMmVIMTkz'
    b'SmJ1ZApZd2hyRVNZOEZKL1cyMTVpTnB2Yld1cjAvZHBCQTNSVldYNC9xOStUSVEwUXk4N0FK'
    b'VFg4dlNXeVNLVlQyOU1XV3FzK1hXckp2aldFCnIrTjBkZXluQzhLT2ZiSVVBQUFCNkJjTWVs'
    b'aWtjOGJPQmdBWWpjYmJWN3dVWG42b2trdHk3dVpCSnhJd0pFQXVsd01Bb3FPang0bEcKMzJz'
    b'MkppYm1pMU5mWWc1MDZFV2ZVVFh5U2xLOGlldFRqdklERkVUY0NGZENmRVcyYUpQaFNCRDN5'
    b'dWpxQzU4T0dxQU5OejliTXFNNgpjWTM3SDNOME9jNSs4aXJUWmtBdk5RaDZkKzdJdVBDZERZ'
    b'TGxPREwwbkNvV2NobnRMQi95NHErZWhsbWhXQ3FSU0FBQW5wNmVFQVR0CjJiTW53QzlnVmVK'
    b'eW51MHUwQ1NmeWorZGp5Q0kzVzVIRU1UbXROOXJRU1FTVFlnZm44RUdEWTlyaC9zN2FRNmlK'
    b'UEh4UWJaSFZ0clgKVE80UFY5cGJkR3lkRmF1aFpvMlp2bjdRQUIweFpWT2psczhBMEZmQm1v'
    b'c2JGVjNFSXIyeHpZQ05kcG5Qb3VJREhGbDFGMGVPZ0JCUApvc1hzcC9yYkJSUkZmNXlpSjlu'
    b'U2t2cmpiaGR0QzhjOWZudm1BZ0JvYjI5WEtCUkdvN0c0dFpTRXlIdjd3UHpXQXFQUjJOWFZw'
    b'ZFZxCk9aeTc5K0RrR3h0T2I5L3l5S2dwMGs3aGdYTEppb3grSDlyOUNHbm1CRFBkUmhaQlFR'
    b'VTFBaUdITmtubVRsajBHWVpoZzZQcU1Kdk4KMXhmTzcvSVQ1TXpXbnBVTHJSQmN3ZUlGVTI0'
    b'QXdDV1dzSnJGRS9HSUpHOW5jcUJkYjJPNUdXZmo4U2VVT2VkL2pQS2JvMStGSUdqcAppZVVV'
    b'bStaeitmOXVqZ01DQXFSUzZmek5UMXdVbE5Jd0xiV0kzUWp1NERzQkFJZkFzVVd0QzFOVFUv'
    b'VjZQY08vVzdtNlpRcmV6dmR1Cm5vc2tMZkNYR2tsVEg1dUFZWC9hamZqRGxaMjhNaldVSG1h'
    b'cjdPU1FjT0dnYVZqYVc1cUpySlFtVk56dHliblZ6WEU3V1JvWWMwQncKTThJQkFPUmg0bytm'
    b'N1BFVUVDb1ppWk9ndzRESkJkYWJHcHBobUxzNW1nWTV4Rk9weXVTWnArYVBOQ1dsSTZNSCtz'
    b'MFNpUVNHWVpQSgp4R2F6ZVR5ZVdDek9lK083L1B6OG9LQ2drSkFRR0lZdlg3djhjdEhybHh3'
    b'bEphVWxxYW1wbDZ1djdFZVAzczdSbGRjdWhDSHZkRUlJCnA2M3BGY0w2RVU5ZVVzZUgyZEFu'
    b'UWsvWERaYXZoT0JpOUpiVENuOFpNU3U1OS9zOXE2Yzl2WFVRQU8zUWFTa0lsak5rYnhOTnYz'
    b'SjIKMFJORDkyM2VGSDdrODFxRUN3Q2dBTlNzeFh6RStLRnlNUVRBakVUemdBTkJJamZlbm9Q'
    b'Y1llc053b1VUSDMvMS9KdmZQbnFnczd1egp1Ylk1WGhuZjM5K3ZVcW1rMHJ2emNnUkJzckt5'
    b'N3JiYUthTys5TjU5K09oaGlBOHYzN255VTNvdmhkNnA3NnJQN3d4anc0VnhZa3NuCkZHSnda'
    b'N2lzVHpzTkd5U3FZcEhRMFFoN0NNaG9sWnVpSVZJNXYxbm1selQ4a2NGUjN2V2NPUWxCTUJv'
    b'Y0hqRnIvb0ZMaDRSQ1ljNmIKYjB1MzdkV21aWEs1WEM4UjJkYVBWWFh5Wmc4M2p3bXhBUUNL'
    b'cmZQR1RsNXdieDF0cCszQndjSERtZmpjNzNhNDNPN1pzMmZQblR0WApwVks1M1c2dDlwY0tM'
    b'eDhmbjhEZ3dMVmc0OGZ3SG9wRi9mdDZGeEc5dDFSVzBjV3Rjdk9jQURiQUxBK2EvSmV4QTdm'
    b'QVlUNXVEd0dwCjdrY2J0Und2VlhER3RLVSt2bjZESTNVRXpaZ25YZkZpbEZ5dTBXaVMxNC9V'
    b'Yk5hK1BtZmpxRW1UUjAyYWpPTjRZV0ZoM3BIZG5nTVYKR2pQclh4L0xwOXRNcG5IdSs3dHVG'
    b'dWp1N2s2T1NucXZZZnMzaHFOajgwYXNqTXg1ZFB3MGdpQnljM01uVHB5WWxuYUhBR0lZcHJP'
    b'egpVeXdXY3pnY0RvY0R3N0JHbzduUEd1SEVhMHJ5L2NRQUFvQkxNL21ZaUdhZ1liVGJuM0xI'
    b'd2c0R2hYc3RtTVEzYnVHc0NmZCtlUTRtCnJnTUFFTGMrcVVIV0FrSFFOUGlSeDJQbWpVc1pK'
    b'eEtKU0pMTXpjMDlzSDkvSW1rYlI5Z0VESFU1S0hiTXpEbWxRenJmYnQ1OE8wZHoKdWpETnV2'
    b'YVF6VkU2dnp0VnM4d3VDU1Q5S3lzcTVYM1NOeGUrdG1EdUFwUEoxTlhUMWRIV01YYnNXS1ZT'
    b'Q1FBZ0NPSzFuVys4eS81QgpobjF0MkQ4eUtqL3RNVUY4alBhVmtnNDM5R0dlSjJxaGZZY0do'
    b'VS9LSERWcVZGQlFVRjlmMzdwMTY5YXVYWnVTa2pJb2djNHJQVEh6CjJnS0NkNmNDRTFqNVdj'
    b'U2tsekxYeHNmR2JkLzBidjJCcnppQWRxSWNJUXc5c3ZxbEM0cW1PMEFEQUFBNE1tU2Z6cURM'
    b'c2IvNGs1WlIKSzR0RVNZWUQ1THNFbjI3WU9XUEdEQUFBU1pKeFc1TnJSWTMzYXI2c2VINWF6'
    b'eUYvaWJtcWs4TkNRRkVEdjk0U3NtejVtdlQwOU52SgpxcWFtNXJXM1h0UG90UVhIVDkrZUN3'
    b'OCttalI3Vk5aaGV0OVRGNWNaRldZQWdFMW9QMkQ1OXRDMm95OG12ZkQ2eW8wNzdGWmRjOU83'
    b'CkgzOG1Gb3NSQkxsNC9vMTcxeTZyWEJuR2hBRDVUMXNtaEhkdW50OW8vOExDd3V6c2JCUkZt'
    b'MXVhYTRXTjk2dWFUSjQ4SzRvdzBTcVgKbTRST3FWTjJmN0ZYSkJMaE9GNVlkUDdBelVQZnVV'
    b'NkFjR2FkZFBXRFEvbkJjaDNGdTNkZWlmWVZWalI5bC9UZW1tNnBxa3NJa3pBUQpRWFF5dkJu'
    b'T1hiOXJROEs0OFZzT0hKSEpaRDg1UGRKN21Fcmt2ejdacXZOcXpwcVp2V1hMRm9JZ0xHWUxv'
    b'TzVYWUFjRnVKUHlLdUFYCnJuUjRnZlR5dEt6RkpFbHUrMko3MUthRXFVMnp2dUlmdEhyWXc5'
    b'ekRWaTk1WWJBUy85cVdwbFRjMGJ4M1I4OW8yUWNUTFI4QThGR3gKeCs1dVREdlUwdWRuL2R6'
    b'OGRVRHRrQWtUSnR5VHhxRGY0TVV0d3grdG0zYys3Y1JycjcrVzgxek95cXRMYzFtZjNhY1RG'
    b'cDBhRnAwSwp3S3NBZ0VQZkhucnB6SWJHaURaR3dYQk5iTjllemhNMWpDSnEyTVVkeVdLMnk4'
    b'Wko0Qkt0a3FTM1lsSXlCdzNRUEM4ZkVVTlJicGY3ClVqK1pBWFVaMGZrSjV2cE9IMjZueU5U'
    b'UFA4RW16TUQ4dXpnaVVPSkdhNFVXNlQ5WFhvamJpZnNZNnZ2WTF6T041M3A4TllIRjNxSU8K'
    b'NGNZQlhScGhFUURtR2FRQzQ5aUJHUGRuWDdReFFvSWdCMVBxY05WVTljSG9ma3htQ01KY0JG'
    b'VGZ5eW1vRWZZT29PUEQ3RkVZOEs3dwpHS2kvZnUzaWViUFpiTFBaeWtvS2NiUHpOM29pd1ZC'
    b'NVlBdTN6ZXd5MXlPTnY2eExVL1N6MzB0bTFNSUZldlU0d25vUkZYWEFHR09rCjg2cEZaMnBG'
    b'ZFJvcG1yQXRjZlMwd1FTMHo4ejVSNE1WYmhUK3RrKzg2NUk4TGN4YVVDdGNQVkdubEpKTldy'
    b'YXZrMzdsUnJIL3MzOWIKTTM3azB2bGpqdS9LNFJYL1JwNGhwaWM4UUJsUUpMd1NyZ3dua2Z1'
    b'RDBhMHo1ZVZtYTNxN3VqclVETU5FMWhpOENjcVRvU1FNdFkvdAowU3hnbjRxWHVyM2c1OGZy'
    b'RFRaRUszcU1KUEVIVVlrOXdOU2hiOXcrWWNMQUdCTHFIMkJKdmlWV3RLdjhQUWtoaHk1cjVV'
    b'bmF5ZDMyCjN1TnNhU1p1MW5KUkZSdC9jcFJwdnlNYWdOcmY0Q2pZRVdnYU1MRWRtSWdybERI'
    b'M24ybG4zTVF3ZGxuUHR5TllNSDM4U3VxTDVzNHkKRnU4a1M2U0dzVllSZStwRTY5Z28yM1Fy'
    b'NnUrQngvczdZV2diMThDMHQ4VUdEZzBlTkJIdG43TE1SMEwyMjlBdUxScEk0ekVkanZPTgpR'
    b'ajZiMWx4bktWMzRjWW1FTjVMZUlmQlNldUVJekpUMUJFUFJjYi9GelUwcU8yN3Fnb0xGbEkx'
    b'MDJwMTk1dnM3UTY2Zm9zRTBoSTNnCkhYcllaTk81R05BTllXdWR1cStrOGxXTERiNEtzbDJQ'
    b'T1hGSTNZK3hXYlNFUjUzdUdPRWZNSFJ3UkxURGJpOWN2cGczSnVQc2hkRlAKVENrNmFKSzB3'
    b'T3g0MGxIdjRPNHFrdlVBTkRXTnlvaXlEdkVnUXFPSVJIK0gxb0tpU04rK2ErZ1BUdHI5cHkw'
    b'WFdGWDZkMHVzSTdCVwoyZGJiMWdMVVAxYmhJcTR3SDdjVGgvM0dONi9xR0RLY3N2TUJuVFhi'
    b'MmpmQWt2QW9td3NSY0dncGord3pvdzNta0xGUGZmTWdUdTQrCkVLQXJqeDJaVW5yeTFMV1NZ'
    b'VENBTThHc3hJSEtZbmFpelRtVWNoMnVsOGt4Y3NGSTA3NHJzbWlsVThxbmJuVnpoQnlhelFP'
    b'a2NnSncKWHYrdm5VVWpGdUFBQUxURjlUeHRmUjc4Nkc4VitTU1BtN3lqb0dTeHpneE1EaFlm'
    b'MEZ5R1BpNlVkRjdqYkp2ZkRVT2d4NFNpQ0xQbQpjMStOaWVVYkhwZ3BsZ3lhRnJ5anZyYm9t'
    b'Zmt0VGtKSE01VXN2a0pDZVpyeHgyMUdQcUFPczJVVlF0NzBCUE9qOFpaZUV5dmMxMjF4Cklq'
    b'MFdnVTR3SS9QSjkxTytIbHZocXY0ZGQrSUplL3pMTWRKcE1VRDhRSm56NHZ2NUhyZ0xseklV'
    b'RHNIREF2QVlQMGUwMG5Wd3Y1aEgKVWFta25RQ1FDNElGOGNuVDl1ei8zWWNzRDVEck9KcTc5'
    b'Y0xlM1RkaGpnUmlyQUx4NWczcnRTMU5GSXlRbnQ1QzBJdEJEZ1RDS2NKbApKYVU4cjNpRlFo'
    b'RWVIdDQ5MExPb1lPa2xTd2tEL1E2N1VpSEtiVEh2dVk2dEZuTElOdGFNVVpNV0hqaHdRQ3dX'
    b'U3lRU0JFRkVmSlFDCldHaG9hTmxiTDA5dHFmQmhTQUtBVHBqTll5aHdySFJZZU1SZ0lwVmVu'
    b'enNEOXZIMUhCYit6UmQ3M3RyOFFYcDYrcytXdHpSZFUxTXoKTURDUWxKVFVaK25URGVoZ0xr'
    b'dHYwT3VxenFwU3BtSWNEQUJnYzlrdTloUi9vdDVqQlZZQWdCU1N6Qjh5SjFZU2RYczB3ekNN'
    b'dnF0Zgo0aVhGMkNpQ3NqZ3dKek4wOHVvVnE0TjgyZEhKVXhJVGg5OW0rTzZQaHFOSHg0OGZm'
    b'MkZlbG5UcEM0NlAzL2ZyNjdDZzdOSFZYWU9NCnZXdTRlZE5ENFVrQnFMeTB4QTZUUlpwU0tV'
    b'ZGljQnU3ck4xYW04NnNINEJnbUlOeEFpVCttUWxURm95Ykx4UUltNXFhekdaelVsSVMKQUtE'
    b'aXhyVzQ3Z25GOEtaeDJUbi90bG1tdmpyMTNFd0J3ajg1NVZ0MXdSVkZZR0JFWXRLRno2WnE3'
    b'Sko1WVNYWDBWY3pacXpHY2Z6OAorZk1JZ2dRRkJmV1pOYjBEdlM2WFM4S1Y4Tmc4QmpDOWxs'
    b'Nk5WVnZYWFYvYlh2Zml5Rlh6NXN5N3k1eGNLVFczcXgvRXFURG9EM3VTCkkwVlIwVzhuMW5z'
    b'MTN6T01vWUdKQVFvWUVzTU1tOEhzYUtRdGRHVml6cHowMllXRmhmYWFENE1FTFVuKzVqTCt6'
    b'dFNNQmZlYWVxLzQKQXhWZnliMW1iUHRrYXhYQUV2NldPbVBJY1lvR2JTYnBxQlczS2lvcURw'
    b'NDVkSjJvck9FMTJJR2RhaWNCSHdCL0JQQitzQitPbVIzVApIbGE4N2VLRG1Ibi9tVUFEQU5y'
    b'YTJ4Wi8vRXdMMWthYjhVQWRLOGtEVW5mempQMXNEZ29paDlvWlB0N1p6YlFxU01BV1Q0dWVF'
    b'ZXl5CktSMkhmTVRFNVo2UUoxNCtjKzlRc2IyL1E4YVhudm40NDRLdnYvS09weEw4SFR5TUpt'
    b'bElMcVJ2WUs5OGRlMmJWbW1iM0FXY0RBSWIKSUZ5QStFZ0lQaUR0Rk5LTEl3aUxoaEdHd1Zr'
    b'K0JzNmFSOWVFUjQzd1ZDaTh2YjMvSWtBM1hTazltZnRCcWNtT0cvVzBod0xXOW9TUwpyblRT'
    b'UW1CSTF6ajJpV3FSVEVBdEcydUFqMUEyRzl3QWM4WlJ0aDBlZ1hvdVNaQms1dmlFRlJ2My90'
    b'aG1iMi92ckVlejU2WU8ySEVvCld1bWFHbXQ5ZHE5L1h4OWJTdHV6N1paTG1MQURRalV3NWlF'
    b'Zy81Wmc3cmVpSGdJeXIwck1NUFNVYUp0Y1FQaElxTUk2Z2FzYWlpU2QKNHZpa1dmdU9ERmFh'
    b'OUFjRW04TStxdTZhTDRPNGFEcWZ3TlVzdGhXR3l0bUNOTnc2NWN5QU9RS3VkbkRYSGZhZTVq'
    b'WUxZYXFleGJuSwpFdmhhemRVdUlZcWdWeHZ4WlNUSllyR3FxcXJhMjl0NVBKNlBqNDlTcVZU'
    b'M3FCRnZwRm5ISHVibFRnbHlucjRsaERvSkljUDBNZWlIClhDOS9DdmVuaVNtRXBZd1dITDBo'
    b'a2ZISkFRZVBvb0hEalZaMDhBTGxiblUvNDhLaE5oaVZ3aVRIWkhqUUNQeEJqMk9MekppVVhO'
    b'M3QKR2hZcEV0S2pvaHhoUG02Rmdva09jcFpLQlB0ajVXNFJraDVtLzI1bHV5U05DYWJkZXBo'
    b'bGdoRUlnR0dVbTZDZytvYW1EUnMyV0N5VwpycTZ1Z0lDQXBLUWttcUdWdTRQSGxrK1pQbnUr'
    b'RGZKUERyU3YyS2Y4MTJHUE9vYmJETE9CRU1Zd1FNQ1FDVUl1SW9Ka3dyNUdyNDN1CmNWQTB5'
    b'STR4cjgvVXNtQWFnWUdBVFRlMGNtSklaeXZDRGxYWFhUbTAveStTbzNYYVh1UHhPS01OY1JH'
    b'UVhFakJFQlBxN2Q3OG9UemEKNk5SbFlId1I0M0pEVjl0NXlsYTMxSXhiYUxpRnh6ZERzQlZG'
    b'd2hsM0FPR3E0c3Q5TWlaR1JVWHhlRHl4UXB4eE1RdG9tS1h1dVVHRgp4U1JKZXBEa2xaRWo5'
    b'VTduN1NtNGg1QktHT0tjbDJ5NjFzRHpQSS9Ia3c0TEN1OFdlVGFnM0JtSkF3bitUcDJWTlRu'
    b'S3V1R29UMVU5Ckw0cTBweE8yaU1ObmdpSWlCMzNxQUFBNDdSWUh3ZEhEVVFocXNlQWFJZWE0'
    b'MHNnYVpiQ3BLUHhDa1ZDTnNCTUl1NHVnTlJSU0lwRHgKS1NySmFoVlFWTEZjWHU4NzVDUzMw'
    b'eVUwd0YySFZucktaOCthZmEybUhDQUFFa0RnekpWeUx0Y3FZT0xuVFYrWlBpc3VPbGFuMDVX'
    b'VgpsVjI3WE5qYlV1YkFUVSttbTA1RGdsdm5PSUNCSXF5dU5OaDZSaTErTnMzUU80QWFiS3cx'
    b'azNTT042NnJtNXE0THk1Mm1zMS9rWWkrCk94Qnd1VzVXbGhuT0wvaitwSGlWVVhNRWs3a2dx'
    b'QS9DaElDc2g3Z2hkb2NHdzh3b0dwT1FRQ3FFYW5ubmFheVF3RWlJaEh3cTVlK00KZWVPeHh4'
    b'Nzc1dHY5aTNVNWdBQUpCOFBZSkpCUjdzSjVQVzRKRVdvTFd1ajUyTk9aaXhXZUNwdk5kdkhj'
    b'U1psbXF4aW92eXlWY3F2cApHTklCUWNBMTh3bVljNFhyTThyYmZvaWk2S1NjUmhSRk94b2J2'
    b'UHdEQnZHNWpwK1VFN3R6SU8xSk44R2NxaGFPdE5vb1BkQXc2Sk11ClE2bm5FSStONzMvMzlk'
    b'ZGN1VHd6ZStxdTJzK1BRSGswU2dNQXBCclJPTUZvTDcxODZld2xPSTVmcjdpKzIvaVZuaks0'
    b'Yk01TkVXK2UKM1gvUTVXdzdPVmRMWVRRQVFHSVhmUnE2M2Q5RFdWRjhwSy9oN1BTNGZxc0xl'
    b'ZWVnWXI3TE9JeHk4VDgvRmpkaUpBREFaT3h2K2lZRgpSRzlKU1p2eFY2dWpiMHYrbDJ0cDg2'
    b'MDQ4ZldiM1p6ME1Odm54UjduRzRRZS9xbGJ0MjdsOFhnMm0yM3JnZTMvN0hnZjl5WUJDM0Fz'
    b'CjdMOTdyMXcvOHlVZWorZDBPdTEyKysxejVuZlNrZFBKNVhKTkp0T3JDeFpVMmRwdmpUYVkv'
    b'VzBBQUlHV2wzM1ZhODFrZlk4SlRmQjMKbkx3cHVueUI1MC9qVDdyMGxrK09KcVNQdjBQbk9o'
    b'd0lnckRaN0w4bTBBQUFqVWF6Zk1Ga3B4VUs5WEhSb2hBRTFpNTdlVjl0YmExUwpxU1JKOHBs'
    b'ek9mWHREU0FHOXJZbzhtY2Zpd3YvOVlGQWIyL3Y4cVZMbjErMjdPVVRyMXlOYVJGMTg3TlBl'
    b'dzVQZFdiRU9HaUtxalA0ClZabkhEVDk5aVBEMm1WOVlEdjRNK1hPQWJxaXNPTGR3WmdwcHZ5'
    b'eFhwVzMrcUxLaE1UNCtQalkyOXM3TXBPbFd3cG1Sdmdidkd5c3UKZTNwNC9sZVdUNDJPT1N2'
    b'UW4vUkRwdCtVTHRyMWxTcGdhTW1SRFV6L2hSRkxpczgvTllmVDJwQ1FWK3diRVBnbklNMzg0'
    b'VUxUOUlIVQppTUp3TDFjdy8xcUV3bTYzMHpSOW4wN2FheE51TmR6NkRjYTd1cnFPTDVyN2Rr'
    b'ekFzVlhQM3V2eDlnOUhIcDlaWDM2TitUTUUvQ2xlCktZcTZIT1Z6YU9QNmlvc1hmbEpCcTlY'
    b'K1p1T1ZwL0x5VXNOZExoZnovNVA4T2FtRFlaaFQ3NzZSOXZ5TGZLRVEvTjhRNk9FL3ZQbGoK'
    b'NU9Fei9oOEMvUkRvaC9JUTZJZEFQd1Q2SVFSL2pQd3ZWQnBQMmRjb21Za0FBQUFsZEVWWWRH'
    b'UmhkR1U2WTNKbFlYUmxBREl3TWpNdApNRFF0TWpsVU1UQTZORGs2TWpJck1EQTZNRERSc3Zj'
    b'akFBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl6TFRBMExUSTVWREV3Ck9qUTVPakl5'
    b'S3pBd09qQXdvTzlQbndBQUFBQkpSVTVFcmtKZ2dnPT0KIiBpZD0iaW1hZ2UxNjkwIiAvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'RU_TOM')

RU_TOM = b64_RU_TOM
index.append("RU_TOM")
index.append("Russia Tomskaya oblast")
catalog["RU_TOM"] = RU_TOM
catalog["Russia Tomskaya oblast"] = RU_TOM
country["Russia Tomskaya oblast"] = ('RU_TOM', '', 1)
lookup["RU_TOM"] = ('RU_TOM', '', 'Russia Tomskaya oblast', 1)
lookup["Tomsk"] = ('RU_TOM', '', 'Russia Tomskaya oblast', 1)
lookup["Russia Tomskaya oblast"] = ('RU_TOM', '', 'Russia Tomskaya oblast', 1)
details["RU_TOM"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+07:00","altname":"Tomsk"}
regional["RU_TOM"] = ('RU_TOM', 'Russia Tomskaya oblast', 1)
regional["Russia Tomskaya oblast"] = ('RU_TOM', 'Russia Tomskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_TUL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iSVNPLTg4NTktMSIgc3RhbmRhbG9uZT0i'
    b'bm8iPz4KPCFET0NUWVBFIHN2ZyBQVUJMSUMgIi0vL1czQy8vRFREIFNWRyAyMDAxMDkwNC8v'
    b'RU4iCiAgICAiaHR0cDovL3d3dy53My5vcmcvVFIvMjAwMS9SRUMtU1ZHLTIwMDEwOTA0L0RU'
    b'RC9zdmcxMC5kdGQiPgo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIK'
    b'ICAgICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgeG1sOnNw'
    b'YWNlPSJwcmVzZXJ2ZSIKCSB3aWR0aD0iMTk0OXB4IiBoZWlnaHQ9IjEyOThweCIKCSB2aWV3'
    b'Qm94PSIwIDAgMTk0OSAxMjk4Ij4KCjxkZWZzPgoJPGxpbmVhckdyYWRpZW50IGlkPSJncmFk'
    b'MSIgeDE9IjEiIHkxPSIwIiB4Mj0iMCIgeTI9IjEiIGdyYWRpZW50VW5pdHMgPSAib2JqZWN0'
    b'Qm91bmRpbmdCb3giPgoJCTxzdG9wIG9mZnNldD0iMCUiIHN0b3AtY29sb3I9IiM2OTkiIC8+'
    b'CgkJPHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjZWVlIiAvPgoJPC9saW5lYXJH'
    b'cmFkaWVudD4KCgk8bGluZWFyR3JhZGllbnQgaWQ9ImdyYWQyIj4KCQk8c3RvcCBvZmZzZXQ9'
    b'IjAlIiBzdG9wLWNvbG9yPSIjNjg4IiAvPgoJCTxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1j'
    b'b2xvcj0iI2RlZCIgLz4KCTwvbGluZWFyR3JhZGllbnQ+CgoJPGxpbmVhckdyYWRpZW50IGlk'
    b'PSJncmFkMyI+CgkJPHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzliYSIgLz4KCQk8'
    b'c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IndoaXRlIiAvPgoJPC9saW5lYXJHcmFk'
    b'aWVudD4KCgk8bGluZWFyR3JhZGllbnQgaWQ9ImdyYWQ0Ij4KCQk8c3RvcCBvZmZzZXQ9IjAl'
    b'IiBzdG9wLWNvbG9yPSJ3aGl0ZSIgLz4KCQk8c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29s'
    b'b3I9IiM3YTkiIC8+Cgk8L2xpbmVhckdyYWRpZW50PgoKCTxsaW5lYXJHcmFkaWVudCBpZD0i'
    b'Z3JhZDUiIHgxPSIwIiB5MT0iMCIgeDI9IjAiIHkyPSIxIiBncmFkaWVudFVuaXRzID0gIm9i'
    b'amVjdEJvdW5kaW5nQm94Ij4KCQk8c3RvcCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjOGFh'
    b'IiAvPgoJCTxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2VlZSIgLz4KCTwvbGlu'
    b'ZWFyR3JhZGllbnQ+CgoJPHJhZGlhbEdyYWRpZW50IGlkPSJncmFkNiIgY3g9IjIwNyIgY3k9'
    b'IjI5MiIgcj0iMzAwIiBncmFkaWVudFVuaXRzID0gInVzZXJTcGFjZU9uVXNlIj4KCQk8c3Rv'
    b'cCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjZmU5IiAvPgoJCTxzdG9wIG9mZnNldD0iMTAl'
    b'IiBzdG9wLWNvbG9yPSIjZmQ1IiAvPgoJCTxzdG9wIG9mZnNldD0iMzMlIiBzdG9wLWNvbG9y'
    b'PSIjZDYwIiAvPgoJCTxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2ZjMSIgLz4K'
    b'CTwvcmFkaWFsR3JhZGllbnQ+CgoJPGxpbmVhckdyYWRpZW50IGlkPSJncmFkNyIgeDE9IjAi'
    b'IHkxPSIwIiB4Mj0iMCIgeTI9IjEiIGdyYWRpZW50VW5pdHMgPSAib2JqZWN0Qm91bmRpbmdC'
    b'b3giPgoJCTxzdG9wIG9mZnNldD0iMCUiIHN0b3AtY29sb3I9IiNmZTkiIC8+CgkJPHN0b3Ag'
    b'b2Zmc2V0PSIyNSUiIHN0b3AtY29sb3I9IiNkODAiIC8+CgkJPHN0b3Agb2Zmc2V0PSI2NSUi'
    b'IHN0b3AtY29sb3I9IiNmZTUiIC8+CgkJPHN0b3Agb2Zmc2V0PSI4NSUiIHN0b3AtY29sb3I9'
    b'IiNjNzAiIC8+CgkJPHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjZTgwIiAvPgoJ'
    b'PC9saW5lYXJHcmFkaWVudD4KCgk8bGluZWFyR3JhZGllbnQgaWQ9ImdyYWQ4Ij4KCQk8c3Rv'
    b'cCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjZmMzIiAvPgoJCTxzdG9wIG9mZnNldD0iMTUl'
    b'IiBzdG9wLWNvbG9yPSIjZTkwIiAvPgoJCTxzdG9wIG9mZnNldD0iNTUlIiBzdG9wLWNvbG9y'
    b'PSIjZmU0IiAvPgoJCTxzdG9wIG9mZnNldD0iOTAlIiBzdG9wLWNvbG9yPSIjZTgxIiAvPgoJ'
    b'PC9saW5lYXJHcmFkaWVudD4KCgk8bGluZWFyR3JhZGllbnQgaWQ9ImdyYWQ5Ij4KCQk8c3Rv'
    b'cCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjZDgxIiAvPgoJCTxzdG9wIG9mZnNldD0iMTAw'
    b'JSIgc3RvcC1jb2xvcj0iI2ZkNCIgLz4KCTwvbGluZWFyR3JhZGllbnQ+CgoJPGxpbmVhckdy'
    b'YWRpZW50IGlkPSJncmFkMTAiIHgxPSIwIiB5MT0iMCIgeDI9IjAiIHkyPSIxIiBncmFkaWVu'
    b'dFVuaXRzID0gIm9iamVjdEJvdW5kaW5nQm94Ij4KCQk8c3RvcCBvZmZzZXQ9IjAlIiBzdG9w'
    b'LWNvbG9yPSIjZWM1IiAvPgoJCTxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2Zl'
    b'OSIgLz4KCTwvbGluZWFyR3JhZGllbnQ+CgoJPGxpbmVhckdyYWRpZW50IGlkPSJncmFkMTEi'
    b'IHgxPSIwIiB5MT0iMCIgeDI9IjAiIHkyPSIxIiBncmFkaWVudFVuaXRzID0gIm9iamVjdEJv'
    b'dW5kaW5nQm94Ij4KCQk8c3RvcCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjYTgxIiAvPgoJ'
    b'CTxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2ZmYSIgLz4KCTwvbGluZWFyR3Jh'
    b'ZGllbnQ+CgoJPGxpbmVhckdyYWRpZW50IGlkPSJncmFkMTIiIHgxPSIwIiB5MT0iMCIgeDI9'
    b'IjAiIHkyPSIxIiBncmFkaWVudFVuaXRzID0gIm9iamVjdEJvdW5kaW5nQm94Ij4KCQk8c3Rv'
    b'cCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjZDcwIiAvPgoJCTxzdG9wIG9mZnNldD0iMTAw'
    b'JSIgc3RvcC1jb2xvcj0iI2Y5MSIgLz4KCTwvbGluZWFyR3JhZGllbnQ+Cgo8ZyBpZD0idGhp'
    b'bmciPgogICAgPHBhdGggZmlsbD0id2hpdGUiIGQ9Ik0gNDM0LDE5NSBMIDQ1MywyMTIgTCA2'
    b'MjIsMzcgTCA0NzksMjM0IEwgNDk4LDI0OSBMIC0xNjksMTAwOCBMIC0yMDAsMTAxOCBMIC0x'
    b'OTYsOTg1IFoiIC8+CiAgICA8cGF0aCBmaWxsPSJ1cmwoI2dyYWQzKSIgZD0iTSA0NjQsMjI2'
    b'IEwgNjIyLDM3IEwgNDc5LDIzNCBaIiAvPgogICAgPHBhdGggZmlsbD0idXJsKCNncmFkNCki'
    b'IGQ9Ik0gNDkxLDI1MCBMIDQ5OCwyNDkgTCAtMTY5LDEwMDggTCAtMTcyLDEwMDUgWiIgLz4K'
    b'ICAgIDxwYXRoIGZpbGw9InVybCgjZ3JhZDUpIiBkPSJNIDQ2MCwyMzAgTCA0OTEsMjUwIEwg'
    b'LTE3MiwxMDA1IEwgLTIwMCwxMDE4IFoiIC8+CiAgICA8cGF0aCBmaWxsPSIjYTk5IiBkPSJN'
    b'IC0xNzIsMTAwNSBMIC0xNjksMTAwOCBMIC0yMDAsMTAxOCBaIiAvPgo8L2c+Cgo8ZyBpZD0i'
    b'aGFtbWVyIj4KICAgIDxwYXRoIGZpbGw9InVybCgjZ3JhZDcpIiBkPSJNIDIwNywzNzEgQyAy'
    b'NjQsMzcxIDI0MywyNDkgMjM3LDIyMCBDIDIyNSwxNzEgMjI5LDE1OSAyMjksMzUgQyAyMjks'
    b'NCAxODUsNCAxODUsMzUgQyAxODUsMTU5IDE4OSwxNzEgMTc3LDIyMCBDIDE3MSwyNDkgMTUw'
    b'LDM3MSAyMDcsMzcxIFoiIC8+CiAgICA8cGF0aCBmaWxsPSJ1cmwoI2dyYWQ2KSIgZD0iTSAy'
    b'MDcsMzYwIEMgMjUxLDM2MCAyMzgsMjY0IDIzMSwyMzYgQyAyMTksMTg3IDIyMywxNTkgMjIz'
    b'LDM1IEMgMjIzLDE0IDE5MSwxNCAxOTEsMzUgQyAxOTEsMTU5IDE5NSwxODcgMTgzLDIzNiBD'
    b'IDE3NiwyNjQgMTYzLDM2MCAyMDcsMzYwIFoiIC8+CgogICAgPHBhdGggZmlsbD0idXJsKCNn'
    b'cmFkOCkiIGQ9Ik0gOTIsMTAwIEwgMzUyLDEwMCBMIDM1Miw4OSBDIDI4NSw4OSAyNjEsNTUg'
    b'MjUxLDMzIEwgOTEsMzMgWiIgLz4KICAgIDxyZWN0IGZpbGw9InVybCgjZ3JhZDEyKSIgeD0i'
    b'OTIiIHk9IjkyIiB3aWR0aD0iMjYwIiBoZWlnaHQ9IjgiIC8+CiAgICA8cGF0aCBmaWxsPSJ1'
    b'cmwoI2dyYWQ5KSIgZD0iTSA5MiwxMDAgTCAxMDAsOTIgTCAxMDAsNDIgTCA5MiwzMiBaIiAv'
    b'PgogICAgPHBhdGggZmlsbD0idXJsKCNncmFkMTApIiBkPSJNIDkyLDMyIEwgMjUxLDMyIEwg'
    b'MjQ1LDQyIEwgMTAwLDQyIFoiIC8+CiAgICA8cGF0aCBmaWxsPSJ1cmwoI2dyYWQxMSkiIGQ9'
    b'Ik0gMzUyLDkyIEwgMzUyLDg5IEMgMjg1LDg5IDI2MSw1NSAyNTEsMzMgTCAyNDUsNDIgQyAy'
    b'NDcsNDggMjcxLDg1IDMxNCw5MiBaIiAvPgo8L2c+CjwvZGVmcz4gICAKCjxnIHRyYW5zZm9y'
    b'bT0idHJhbnNsYXRlKDc2MywxMDgpIj4KCjxyZWN0IHg9Ii03NjMiIHk9Ii0xMDgiIHdpZHRo'
    b'PSIxOTQ5IiBoZWlnaHQ9IjEyOTgiIGZpbGw9InJlZCIgLz4KPHVzZSB4bGluazpocmVmPSIj'
    b'dGhpbmciIC8+Cjx1c2UgeGxpbms6aHJlZj0iI3RoaW5nIiB0cmFuc2Zvcm09InRyYW5zbGF0'
    b'ZSg0MjApIHNjYWxlKC0xLDEpIi8+CgogICAgPHBhdGggZmlsbD0id2hpdGUiIGQ9Ik0gLTM0'
    b'MSw1MjcgTCAtMjk3LDU1NCBMIDU0Miw1NjcgTCA1NDIsNTQ3IEwgNzYyLDUyNyBMIDU0Miw1'
    b'MDkgTCA1NDIsNDg4IEwgLTI5Nyw1MDEgWiIgLz4KICAgIDxwYXRoIGZpbGw9InVybCgjZ3Jh'
    b'ZDEpIiBkPSJNIC0zNDEsNTI3IEwgNTMxLDUyNyBMIDU0Miw1NjIgTCAtMjk1LDU0OSBMIC0y'
    b'OTcsNTU0IFoiIC8+CiAgICA8cGF0aCBmaWxsPSIjY2VkIiBkPSJNIDUzNyw1MjcgTCA1NDIs'
    b'NTQ3IEwgNTQyLDU2NyBMIDU0MCw1NjEgTCA1MzEsNTI3IFoiIC8+CiAgICA8cGF0aCBmaWxs'
    b'PSJ1cmwoI2dyYWQyKSIgZD0iTSA1MzcsNTI3IEwgNTQyLDUwOSBMIDU0Miw0ODcgTCA1MzEs'
    b'NTI3IFoiIC8+CiAgICA8cGF0aCBmaWxsPSJ1cmwoI2dyYWQzKSIgZD0iTSA1MzcsNTI3IEwg'
    b'NzYyLDUyNyBMIDU0Miw1NDcgWiIgLz4KICAgIDxwYXRoIGZpbGw9IiM1ODgiIGQ9Ik0gNTQw'
    b'LDU2MSBMIDU0Miw1NjcgTCAtMjk3LDU1NCBMIC0yOTUsNTQ5IFoiIC8+CiAgICAKPHVzZSB4'
    b'bGluazpocmVmPSIjaGFtbWVyIiAvPgo8dXNlIHhsaW5rOmhyZWY9IiNoYW1tZXIiIHk9Ijc0'
    b'MCIvPgoKPC9nPgo8L3N2Zz4K', 'RU_TUL')

RU_TUL = b64_RU_TUL
index.append("RU_TUL")
index.append("Russia Tulskaya oblast")
catalog["RU_TUL"] = RU_TUL
catalog["Russia Tulskaya oblast"] = RU_TUL
country["Russia Tulskaya oblast"] = ('RU_TUL', '', 1)
lookup["RU_TUL"] = ('RU_TUL', '', 'Russia Tulskaya oblast', 1)
lookup["Tula"] = ('RU_TUL', '', 'Russia Tulskaya oblast', 1)
lookup["Russia Tulskaya oblast"] = ('RU_TUL', '', 'Russia Tulskaya oblast', 1)
details["RU_TUL"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Tula"}
regional["RU_TUL"] = ('RU_TUL', 'Russia Tulskaya oblast', 1)
regional["Russia Tulskaya oblast"] = ('RU_TUL', 'Russia Tulskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_TVE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'DQo8c3ZnIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgaGVpZ2h0PSI2MDAi'
    b'IHdpZHRoPSI5MDAiIHZlcnNpb249IjEuMSIgdmlld0JveD0iMCAwIDkwMCA2MDAiPg0KCTx0'
    b'aXRsZT5GbGFnX29mX1R2ZXJfT2JsYXN0PC90aXRsZT4NCgk8cmVjdCB3aWR0aD0iOTAwIiBm'
    b'aWxsPSIjZDIwMDAwIiBoZWlnaHQ9IjYwMCIvPg0KCTxyZWN0IHdpZHRoPSIyNTAiIGZpbGw9'
    b'ImdvbGQiIGhlaWdodD0iNjAwIi8+DQoJPHJlY3QgeD0iNjUwIiBoZWlnaHQ9IjYwMCIgZmls'
    b'bD0iZ29sZCIgd2lkdGg9IjI1MCIvPg0KCTxnIHRyYW5zZm9ybT0ibWF0cml4KC45OTE2IDAg'
    b'MCAuOTkxNiAyNTEuMSA4Ni41MSkiPg0KCQk8cGF0aCBkPSJtMTYzLjkgMzA2LjEuMTMgMTkg'
    b'My44NiA0Ljc5aDY1LjQybDMuODYtNC43OS4xMy0xOWgtMjAuN3Y0LjE1aC0xMS43bC00LjM0'
    b'IDUuMTQtNC4zMi01LjE1aC0xMS43di00LjJoLTIwLjZ6bTEyMC4xIDB2MjkuMTdjLjU0IDIu'
    b'NzQgMS42IDUuMTQgNC40OCA2LjI0djJsMjUuNzQgMTguMjF2NC4zbDIyLjM0IDE2LjUuMTYg'
    b'MTguMjRoLTI3Mi4zbC4xNi0xOC4yNCAyMi4zNC0xNi41di00LjMybDI1Ljc0LTE4LjIxdi0y'
    b'YzIuODktMS4xIDMuOTQtMy40OSA0LjQ4LTYuMjR2LTI5LjJoLTIuODF2LTMyLjFoMS43YTE3'
    b'LjM1IDE3LjM1IDAgMCAxIC01LjIzIC02LjIxbC0uMzggMS44NWEzNC4zMSAzNC4zMSAwIDAg'
    b'MCAuNzIgMTIuOTNjLjg4IDMuOTQgMCA2LjY0LTQuNDggNi41OS0yLjg5IDIuODYtNS42MyAy'
    b'LjMxLTggLjI0YTQuNzkgNC43OSAwIDAgMSAtNS4zOSAtMy43N2MtMi4yLS45MS0yLjUyLTMu'
    b'ODguNzItNi44OHMzLTcgMi44MS0xMC44OGE0LjA1IDQuMDUgMCAwIDEgMS41IC00Ljc5IDcg'
    b'NyAwIDAgMSAxMCAtOS4xaDEuNTJhMTYuNDcgMTYuNDcgMCAwIDEgMTMuMTIgLTExLjI1di0u'
    b'MjRoLjEzYy0zLjA2LTcuMDcuMTYtMTYuMDcgMTAuMjMtMTkuODVoNC43OWwyLjgyLTQuMTN2'
    b'LTE3MS4yaDMuNTFsMTAuMzctOS40MSAxMC40NCA5LjMzaDMuN3Y3LjU1aDUuMjd2LTcuMzRo'
    b'OC4zM3YtMTEuNDNoMTFsNy4wOS02LjEgNyA2LjE4aDExdjExLjM1aDguMzN2Ny4zMmg1LjI1'
    b'di03LjQ4aDMuN2wxMC40NC05LjMzIDEwLjQ0IDkuMzNoMy41MXYxNzFsMi45MiA0LjI4aDQu'
    b'NjZjMTAuMDggMy43OCAxMy4zMSAxMi43NyAxMC4yMyAxOS44NWguMTZ2LjI0YTE2LjQ3IDE2'
    b'LjQ3IDAgMCAxIDEzLjEyIDExLjI1aDEuNTJhNyA3IDAgMCAxIDEwIDkuMTYgNC4wNSA0LjA1'
    b'IDAgMCAxIDEuNSA0Ljc5Yy0uMjEgMy44OC0uMzIgNy43MiAyLjgxIDEwLjg4czIuOSA2IC43'
    b'MiA2Ljg4YTQuNzkgNC43OSAwIDAgMSAtNS4zOSAzLjc3Yy0yLjQzIDIuMDktNS4xNyAyLjYz'
    b'LTgtLjI0LTQuNTMgMC01LjM1LTIuNjUtNC40OC02LjU5YTM0LjMyIDM0LjMyIDAgMCAwIC43'
    b'MiAtMTIuOTNsLS4zOC0xLjg1YTE3LjM2IDE3LjM2IDAgMCAxIC01LjIzIDYuMjFoMS42M3Yz'
    b'MS45MWgtMi44MXoiLz4NCgkJPHBhdGggZD0ibTE0MS43IDIzMy4xIDUuNjMtMS42YTcuODIg'
    b'Ny44MiAwIDAgMSA3LjU1IC0uMTloMi40NmMxLjA1LS42NyAyLjU1LS44MSAzLjYxLTEuNDhz'
    b'MS42LTEuMzcgMi41NC0uNTZ2Mi40M2EyLjc5IDIuNzkgMCAwIDAgMi44MSAtLjEgNS44MiA1'
    b'LjgyIDAgMCAwIDQuMjMgLTIuNzQgMi4xMiAyLjEyIDAgMCAxIDMgLS4ybC4yLjItLjM3IDIu'
    b'M2MyLjgyLjczIDUuMyAxLjA5IDUuMjgtMS4yNiAxLjc2LTEuNiAzLjQ2LTIuNTcgNC43OSAw'
    b'IDEuMDUgMS4xMyAyLjIyIDEuODcgNC4yMSAwYTEuNDggMS40OCAwIDAgMSAyLjEgMHEuNjEg'
    b'MS45MSAzLjM0IDBjLjc4IDEuNDggMS43NyAyLjQ3IDQuMjEgMGE0LjQ0IDQuNDQgMCAwIDEg'
    b'My44NiAwYzEuODQgMS4xOCA0LjMxIDMuNTQgMy42NSAwIC4yNy0xLjM0IDEuNDQtMi4yMyAy'
    b'LjU1IDAgMSAxLjEzIDIuMDYgMi4wNiAzLjA4LjIyYTEuNjkgMS42OSAwIDAgMSAyLjczIC4y'
    b'NGMuOTEgMS42IDIgMiAyLjcxLjI0cTEuMzQtMy40MSAyLjY2LjI0YTUuODIgNS44MiAwIDAg'
    b'MCAyLjg0IC4yNmMxLjI5LS44MyAyLjU3LTEuMzYgMy44Ni4xOGwyLS4yNC0uMTgtMS43NGgy'
    b'LjJsMS4zMSAyLjEycTEuMjggMS4xIDEuNDguMSAxLjIzLTEuNTIgMi40Ny4xNiAzLjE5IDEg'
    b'Mi45LTEuNmwyLjQ3LS40OCAzLjUxIDEuODJhMS43MSAxLjcxIDAgMCAwIDMgLjEzbC40NS0y'
    b'YzEuMDUtLjggMi4xMS0xLjIzIDMuMTkuODNsMS42IDEuMXExLjY4IDEuNDcgMi42NS4xbC42'
    b'Mi0xLjEyaDIuNDdsMiAyIDMuMTkuMTYgMy4zOC0uMzQgMS40IDMuNTQtMSAxLjA3LTQuMjgt'
    b'LjdxLTIuNDYgNC43OS00LjkxLS44MWgtMi4xNWwtMS4zNCAyLjcxLTEuMjgtMi40Ni0xLjc5'
    b'LS4xMS0uNTkgMS45MS0xLjI5LTEuNS0xLjYuNDgtMSAyLjIzLTEuNDQtMi4zOS0yLS41Ni0u'
    b'NTMgMi4yLTEuMzItMS43N2gtMi4ybC0uNjEgMy0xLjcxLTMtMS44LS4xNHEtLjMyIDEuNi0y'
    b'LjM5LjFjLTEuNi0xLjQ0LTIuMzgtLjYxLTMgLjU0LTIuNDQgMS44NS0zLjMuMjQtNC41LS42'
    b'OXEtMS4zNCAxLjM3LTIuMzMgMGwtLjkxLjM3cS0xLjgyLTEuNi0yLjIyLjcyYTIgMiAwIDAg'
    b'MSAtMi43MyAtLjMycS0xLTEuNzEtMi0uMjItLjM4IDEuNi0yLjg3LjM3bC0uODkgMS42LTIu'
    b'MjItMi4wOS0xLjktLjE5LTEuMTggMS41LTIuMTEtMS4xNnEtLjYyIDMuODEtNC4wNS0uNDkt'
    b'MS4wOS0xLjYtMi4xOS0uMjFsLS40NiAyLTEuMzEtMS42LTEuNS0uMTMtMSAxLjg0LS43OC4x'
    b'OS0xLjE2LTEuNzZjLTEuNzQtMS42LTIuMzYtLjgzLTIuNDYuOTFsMS44NCA0cS0yLjcxLS42'
    b'Mi0zLjY3LTQuNDJoLTEuMjRjLTIuMDYgMS40Mi0zLjEuMzctNC0xLjA1cy0xLjYtLjg1LTIu'
    b'NTQtLjE5cS0xLjUgMy40Ni02LjE2LS40OGMtLjgtMS42LTEuNi0xLTIuNDEtLjE5bC0uNjIg'
    b'MS42Yy0zLjA4LjY5LTUuMTUuMy01Ljg5LTEuNmExLjIgMS4yIDAgMCAwIC0xLjY4IC4yNGwt'
    b'MSAxLjUycS0uNyAxLjYtMi44MS41M2wtMi4xNy0yLjM5YS45NCAuOTQgMCAwIDAgLTEuNiAt'
    b'LjExcS0yLjQxIDEuMTYtMy4wNi0xLjZhMS42IDEuNiAwIDAgMCAtMi44NCAtLjIybC01Ljkz'
    b'IDIuMDZxLTIuMTUtLjQxLS44LTEuOSIgZmlsbD0iI2ExNWE0MSIvPg0KCQk8cGF0aCBkPSJt'
    b'MTcxLjYgMTg5LjJjMS4yOS0xLjkzIDMuMzgtMi44MSA0LjY0LTEuOTVzMS4yNCAzLjE5IDAg'
    b'NS0zLjM4IDIuODEtNC42NCAxLjk1LTEuMzItMy4xMSAwLTVtNTcuOSAwYy0xLjI5LTEuOTMt'
    b'My4zNy0yLjgxLTQuNjQtMS45NXMtMS4yNCAzLjExIDAgNSAzLjM3IDIuODEgNC42NCAxLjk1'
    b'IDEuMjQtMy4xMSAwLTUiIGZpbGw9IiMwMDlhZmYiLz4NCgkJPHBhdGggZD0ibTIwMC42IDE1'
    b'OS43YTMuNDMgMy40MyAwIDAgMCAzLjE5IC0yLjE5aC02LjM4YTMuNDMgMy40MyAwIDAgMCAz'
    b'LjIgMi4ybTAtMTYuN2EzLjQzIDMuNDMgMCAwIDEgMy4xOSAyLjE5aC02LjM4YTMuNDMgMy40'
    b'MyAwIDAgMSAzLjIgLTIuMm0zLjc5IDUwLjUxYy0uNDktMS41Mi0xLjczLTYuMTctMy44My02'
    b'LjI3LTIuMS4xLTMuMzQgNC43NS0zLjgzIDYuMjctLjY1IDIuMTMtLjc2IDQuNzMgMS4wNSA2'
    b'LjMyYTQuMTIgNC4xMiAwIDAgMCA1LjU1IDBjMS44MS0xLjU5IDEuNzEtNC4xOSAxLjA2LTYu'
    b'MzIiIGZpbGw9IiNkMjAwMDAiLz4NCgkJPHBhdGggZD0ibTIwOC4yIDI2Ni42YTQ3Ljk0IDQ3'
    b'Ljk0IDAgMCAxIC0xLjQzIDYuNDZ2LjEzaDY4LjJhMTMuNTIgMTMuNTIgMCAwIDAgMTEuNjIg'
    b'LTYuNTloLTc4LjRtLTgyLjE5IDYuNmg2OC4ybC4wNi0uMDhhMjYuNTQgMjYuNTQgMCAwIDAg'
    b'My4zNyAtNi41MWgtODMuMjhhMTMuNTIgMTMuNTIgMCAwIDAgMTEuNiA2LjZtMTYxLjMtMTku'
    b'MmExMy41NiAxMy41NiAwIDAgMCAtMTEuNjMgLTcuODUgMTcuMDYgMTcuMDYgMCAwIDEgLTcu'
    b'OTUgNWgtNjAuNGMuMjcuOTQuNTEgMS45LjcyIDIuODloNzkuMzZtLTkwLjctLjFhMjAuMSAy'
    b'MC4xIDAgMCAwIC0xLjg0IC0yLjg5aC02MS43YTE3LjA2IDE3LjA2IDAgMCAxIC03Ljk1IC01'
    b'IDEzLjU5IDEzLjU5IDAgMCAwIC0xMS42IDcuODVoODN6IiBmaWxsPSIjMDA4ZTFmIi8+DQoJ'
    b'CTxwYXRoIGQ9Im0yNDUuMSA0Ni43OGgtM2wzLTIuODJ6bTIuMzMtLjAyMmgzbC0zLTIuODJ6'
    b'bTIuNSA0MS4yNy0zLjc0LTEwLjc3LTMuNzMgMTAuNzdoNy40N20tNy41LTI4Ljc5IDMuNzMg'
    b'MTAuNzcgMy43NC0xMC43N2gtNy40N204LjggMTkuODd2LTEwLjk1bC0zLjA4IDUuNDcgMy4w'
    b'OCA1LjQ4bS0xMC4xLTEwLjk1djEwLjk1bDMuMDgtNS40OC0zLjA4LTUuNDdtMTEuNC0xMi4x'
    b'aC0xMi43YTEuNDIgMS40MiAwIDAgMCAtMS40IDEuNDR2MzIuMjdhMS40MiAxLjQyIDAgMCAw'
    b'IDEuNCAxLjQ0aDEyLjcyYTEuNDMgMS40MyAwIDAgMCAxLjQgLTEuNDR2LTMyLjI3YTEuNDMg'
    b'MS40MyAwIDAgMCAtMS40IC0xLjQ0em0tMTcuMyA0My44OXY4NC45NGwuMTguMjFhNCA0IDAg'
    b'MCAxIDUuNTUgLjcgNC42MyA0LjYzIDAgMCAxIC4zIC40NnYtNzQuMzNhMS43IDEuNyAwIDAg'
    b'MSAxLjYgLTEuNzZoNS4xM2ExLjcxIDEuNzEgMCAwIDEgMS42IDEuNzZ2ODguNDRhNCA0IDAg'
    b'MCAxIDMgNy4xOGMxLjQ4IDIuMDcgMyA0LjE4IDQuNDQgNi4zdi0xMTMuOWgtMjEuOG05LjQg'
    b'OTYuNjcgMS41OSAyLjA5di04NS4yMWgtMS41OXptLTkuNC0xNDYuMmgyMS45MXY0Ni41M2gt'
    b'MjEuOTF6bS0xMjcuMyAyMDkuNWEzLjM1IDMuMzUgMCAwIDEgLTMuMzUgMy4zNSAzLjM1IDMu'
    b'MzUgMCAwIDEgLTMuMzUgLTMuMzUgMy4zNSAzLjM1IDAgMCAxIDMuMzUgLTMuMzUgMy4zNSAz'
    b'LjM1IDAgMCAxIDMuMzUgMy4zNW0xOTIuMSAwYTMuMzUgMy4zNSAwIDAgMSAtMy4zNSAzLjM1'
    b'IDMuMzUgMy4zNSAwIDAgMSAtMy4zNSAtMy4zNSAzLjM1IDMuMzUgMCAwIDEgMy4zNSAtMy4z'
    b'NSAzLjM1IDMuMzUgMCAwIDEgMy4zNSAzLjM1bS05Ni4zOS0xMjYuNGEyLjg5IDIuODkgMCAw'
    b'IDEgLTIuODkgMi44OSAyLjg5IDIuODkgMCAwIDEgLTIuODkgLTIuODkgMi44OSAyLjg5IDAg'
    b'MCAxIDIuODkgLTIuODkgMi44OSAyLjg5IDAgMCAxIDIuODkgMi44OW0tNDQuOTktNDUuNS0z'
    b'LjczLTEwLjc3LTMuNzMgMTAuNzdoNy40Nm0tNy40LTI4Ljc5IDMuNzMgMTAuNzcgMy43My0x'
    b'MC43N2gtNy40Nm04LjcgMTkuODd2LTEwLjk1bC0zLjA4IDUuNDcgMy4wOCA1LjQ4bS0xMC0x'
    b'MC45NXYxMC45NWwzLjA4LTUuNDgtMy4wOC01LjQ3bTExOS4xIDIyMCA1LjA2LTQuNjhoLTEw'
    b'LjEybDUuMDYgNC42OG0wIDMuNi01LjA2IDQuNjhoMTAuMTJsLTUuMDYtNC42OG0zLjMtMS44'
    b'IDQuNjggNS4wNnYtMTAuMTJsLTQuNjggNS4wNm0tNi42IDAtNC42OCA1LjA2di0xMC4xMmw0'
    b'LjY4IDUuMDZtLTEzMy42LTEuOC01LjA2LTQuNjdoMTAuMTJsLTUuMDYgNC42N20wIDMuNiA1'
    b'LjA2IDQuNjhoLTEwLjEybDUuMDYtNC42OG0tMy4zLTEuOC00LjY4IDUuMDZ2LTEwLjEybDQu'
    b'NjggNS4wNm02LjYgMCA0LjY3IDUuMDZ2LTEwLjEybC00LjY3IDUuMDZtNjctMTYuMWgtNC4z'
    b'MmEyMC4wOSAyMC4wOSAwIDAgMCAxLjE3IC0yMi44aDQuMDljLjI4LjU3IDUuNjcgMTIuNS0u'
    b'OTQgMjIuOG0yLjgtMTAyLjJoLTkuMjZjLTExLjYyIDEzLjUzLTIwLjU1IDMwLjczLTI4LjIg'
    b'NTAuODdoMjAuMDlsMy40My0zYy45MS0uNzIgMS4yMS0xLjMyLjkzLTEuODJsLTMuMDYtNC40'
    b'MmExLjkgMS45IDAgMCAxIC0uMzggLTIuNjNjMS4yNi0xLjU4IDMuODgtMi4yMyA2LjU2LTIu'
    b'MjMtMi4yNy0xLjQtMS44Ny00LjM2IDEuODQtMy41MWwxLjcyLS41NmE4Ljc2IDguNzYgMCAw'
    b'IDEgLTUuMzMgLTRjLTEuODQtMy4yMi0xLjEtNi4zMi4zLTEwLjEyYTIxLjE3IDIxLjE3IDAg'
    b'MCAxIDMuMyAtNS43IDYuNjIgNi42MiAwIDEgMSA2LjczIC4yMiAyMC42NyAyMC42NyAwIDAg'
    b'MSAzLjE5IDUuNDdjMS40IDMuNzMgMi4xMiA2LjkzLjMgMTAuMTJhOC43NiA4Ljc2IDAgMCAx'
    b'IC01LjMzIDRsMS43Mi41NmMzLjctLjg1IDQuMSAyLjA5IDEuODQgMy41MSAyLjY4LjA4IDUu'
    b'My42NCA2LjU2IDIuMjNhMS45IDEuOSAwIDAgMSAtLjM4IDIuNjNsLTMgNC40NWMtLjI5LjQ5'
    b'IDAgMS4xLjkzIDEuODJsMy41NCAzaDIwLjE1Yy03LjY0LTIwLjE2LTE2LjU5LTM3LjM2LTI4'
    b'LjE5LTUwLjg5bTg4LjMgOTMuOGMtLjI5IDIuOTItLjM4IDUuNzEgMS40OCA4LjE1LjM2LTMu'
    b'MzcuNS02LjM3LTEuNDgtOC4xNW0tLjMgMTIuOGMtLjI5IDIuOS0uMzUgNS43IDEuNDggOC4x'
    b'Ny4zNS0zLjM5LjUtNi4zOS0xLjQ4LTguMTdtNy41IDBjLS4yNyAyLjktLjM0IDUuNyAxLjQ4'
    b'IDguMTcuMzYtMy4zOS41LTYuMzktMS40OC04LjE3bS0zLjctNS45Yy0uMjkgMi44Ni0uMzUg'
    b'NS42NSAxLjQ4IDguMTcuNC0zLjM4LjUyLTYuMzgtMS40OC04LjE3bTIuMi02LjdjLS4yOSAy'
    b'LjkyLS4zNCA1LjY2IDEuNDggOC4xNy4zNy0zLjM4LjUtNi4zOC0xLjQ4LTguMTdtLTkwLjct'
    b'OC4xaC4wM3YtLjA3bC0uMDMuMDdtLjEgMGEzNC40MyAzNC40MyAwIDAgMSAwIDUuNDRoODEu'
    b'MDZ2LTUuNDRoLTgxLjFtLTEwLjQ2IDBoLTg2Ljg0djUuNDRoODcuMThhMTQuODcgMTQuODcg'
    b'MCAwIDAgLS4zNCAtNS40NG0tOTAuMyAyMC43Yy0yIDEuNzktMS44NCA0Ljc5LTEuNDggOC4x'
    b'NyAxLjgxLTIuNDkgMS42Ny01LjI3IDEuNDgtOC4xN20tMy44LTUuOWMtMiAxLjc5LTEuODQg'
    b'NC43OS0xLjQ4IDguMTcgMS44NC0yLjUyIDEuNzgtNS4zMSAxLjQ4LTguMTdtMy41LTYuOXYu'
    b'MDhsLjAwMDEtLjAyLS4wMDAxLS4wNm0wIC4xYy0yIDEuNzktMS44MiA0Ljc5LTEuNDcgOC4x'
    b'NSAxLjgtMi41IDEuNzUtNS4yNiAxLjQ3LTguMTVtLTUuNiAwdi4wOGwuMDItLjAyLS4wMi0u'
    b'MDZtMCAuMWMtMiAxLjc5LTEuODIgNC43OS0xLjQ3IDguMTUgMS44MS0yLjUgMS43Ni01LjI1'
    b'IDEuNDctOC4xNW0tMS42IDEyLjZjLTIgMS43OS0xLjg0IDQuNzktMS40OCA4LjE3IDEuODIt'
    b'Mi40OSAxLjc3LTUuMjcgMS40OC04LjE3bTk5LjUgMjctMi45NCAyLjgxIDMuNjcgMy44MyAy'
    b'Ljk5LTIuNzQtMy43Mi0zLjltLS44LTE1Ljl2LTExLjA0aC0xMi4xNWwzLjM5IDMuOTdoNS45'
    b'MnY1LjU3bC04Ljk1IDcuMzF2MTIuMTloNy45OGwyLjktMy4zMy0yLjY1LTIuNDktMS4xIDEu'
    b'NTloLTIuNzF2LTcuMzhsNy4zNy02LjM5bS0yMi40LTMtMS4zNyAxLjM3IDIuMjMgMi4yNiAx'
    b'LjM3LTEuMzctMi4yMy0yLjI2bS0xLjcgOS03LjU3LTYuOTUtMS44NiAxLjUgNy4zMiA2LjY0'
    b'aDEwLjM5di00LjA3bC04LjI4IDIuODhtNy4zLTE3LjFoLTExLjI4djYuMjdsNy44OS0zLjky'
    b'IDguNzYgOC42OSAzLjAyLTIuMTctOC4zOS04Ljg3bS0xNiA0LjcuMTEtNC42OWgtMTEuNTNs'
    b'LS4xMS0uMDh2Ni4xbDEuNS4xdi00LjJoNy43MWMxIC4zMiAxLjEgMS4wNy40NSAyLjMzbC05'
    b'LjU3IDkuNTd2NC40N2g5Ljc3bC00Ljc5LTQuMTUuMS0zLjE5bS04LjI0IDExLjg0di0yNC4w'
    b'MmgtMi43M3YyNi4wNmgzNS41OXYtMi4wNGgtMzIuODZtNTAuNC0yMi44djExLjA0bDIuOTEt'
    b'MS40MnYtNS41N2g1LjkxbDMuMzYtNC4wNWgtMTIuMThtOC44IDIwLjcuMTEgNC4xNWgtMi41'
    b'MmwtOC43OC04LjIxLTIuMjUgMS43OCAxMC44OSAxMC45MiA2Ljk1LS40NXYtMTIuODlsLTQu'
    b'NCA0LjdtMTMuNS0xMi41LTIuMjQgMi4yNSAxLjM4IDEuMzggMi4yMy0yLjI1LTEuMzctMS4z'
    b'OG05LjQgMi03LjYyIDYuODgtOC4yOS0yLjg4djQuMDdoMTAuMzlsNy4zOS02LjU3LTEuODct'
    b'MS41bS0xMy4xLTEwLjItMTUuNzggMTYuMzggMS44NiAxLjQ2IDE1LjU1LTE1LjQ5IDcuODkg'
    b'My45MnYtNi4yN2gtOS41Mm0yNS45IDZ2LTYuMWwtLjIxLjA4aC0xMS41NGwuMTEgNC42OSA2'
    b'LjM4IDYuMjYuMSAzLjE5LTQuNzkgNC4xNWg5Ljg2di00LjQ3bC05LjU3LTkuNTdjLS42NS0x'
    b'LjI2LS41My0yIC40NS0yLjMzaDcuNzN2NC4ybTQuNDgtNy4zdjI0LjAyaC0zMi44OHYyLjA0'
    b'aDM1LjU5di0yNi4wNmgtMi43MW0yLjctLjF2LjA2aC4wMDAxdi0uMDZtLTk1LjcgNDguOXYt'
    b'MTguNzJoLTMuMTF2MjMuOTRoNS41NWE2LjE4IDYuMTggMCAwIDEgLTIuNDQgLTUuMjJtLTEu'
    b'NyA4LjEgNC4wNyA0LjMyaDMuNDN2LTQuMzJoLTcuNW0tNC4zLTEuMXYtMjcuNWgtMS42bC4x'
    b'OCAyOGExMC41NiAxMC41NiAwIDAgMCA1LjczIDcuNDJ2Ny45aDEuNnYtOC40M2ExMC45MyAx'
    b'MC45MyAwIDAgMSAtNS45MSAtNy4zOW0tNS4xLjJ2LTI4LjE4aC0yNC45MXYyOC42M2ExMi4w'
    b'NiAxMi4wNiAwIDAgMSAtMi4xMiA3LjE1aDI5Ljk0YTE1LjkyIDE1LjkyIDAgMCAxIC0yLjkx'
    b'IC03LjZtLTI5LjcgMTAuOWgzNC44djcuMmgtMzQuOHptMTI4LjktMzYuOHYxOC43MWE2LjE4'
    b'IDYuMTggMCAwIDEgLTIuNDQgNS4yMmg1LjU1di0yMy45M2gtMy4xMW0tNS45IDI2Ljh2NC4z'
    b'M2gzLjQzbDQuMTUtNC4zM2gtNy41OG0xMS45LTI4LjZ2MjcuNDhhMTEgMTEgMCAwIDEgLTUu'
    b'OSA3LjQydjguNDNoMS42OXYtNy45YTEwLjU2IDEwLjU2IDAgMCAwIDUuNzMgLTcuNDJsLjA4'
    b'LTI4aC0xLjZtMzAuMSAyOC4wOXYtMjguNmgtMjQuOTF2MjguMTZhMTYuMDggMTYuMDggMCAw'
    b'IDEgLTIuOSA3LjZoMjkuOTRhMTIuMDYgMTIuMDYgMCAwIDEgLTIuMTMgLTcuMTZtLTMwLjEg'
    b'MTAuNWgzNC44NXY3LjJoLTM0Ljg1em0zOCAzLjJ2Ni44MmgtNDIuMTlsLTQuNjEtNC41OC0u'
    b'NDYtOC4wN2MtNi4yMi4zLTkuNTctMi4yMy04Ljc4LTloLTYzLjk0Yy44MSA2LjctMi41NyA5'
    b'LjI2LTguNzggOC45NGwtLjQ2IDguMDctNC42IDQuNThoLTQyLjI1di02Ljg1bC0xOC44MyAx'
    b'My43OWgyMTMuN20tMjM5LjggMjMuOWgyNjZ2MTMuMThoLTI2NnptMjQ2LjgtMTQuOHY3LjAy'
    b'aC0yMjcuN3YtNy4wMmwtMTUuODEgMTEuNzhoMjU5LjNsLTE1LjgxLTExLjc4bS0yMjQuNS02'
    b'LjVoMjIxLjR2MTAuNzJoLTIyMS40em0xMTMuNy0yNjZhMi44OSAyLjg5IDAgMCAxIC0yLjg5'
    b'IDIuODkgMi44OSAyLjg5IDAgMCAxIC0yLjg5IC0yLjg5IDIuODkgMi44OSAwIDAgMSAyLjg5'
    b'IC0yLjg5IDIuODkgMi44OSAwIDAgMSAyLjg5IDIuODltMTUuOCAxNy40NmEyLjg5IDIuODkg'
    b'MCAwIDEgLTIuODkgMi44OSAyLjg5IDIuODkgMCAwIDEgLTIuODkgLTIuODkgMi44OSAyLjg5'
    b'IDAgMCAxIDIuODkgLTIuODkgMi44OSAyLjg5IDAgMCAxIDIuODkgMi44OW0tMzIuMyAwYTIu'
    b'ODkgMi44OSAwIDAgMSAtMi44OSAyLjg5IDIuODkgMi44OSAwIDAgMSAtMi44OSAtMi44OSAy'
    b'Ljg5IDIuODkgMCAwIDEgMi44OSAtMi44OSAyLjg5IDIuODkgMCAwIDEgMi44OSAyLjg5bTE0'
    b'LjMxLS43di0xMS4xN2gtMS4zOXYxMS4xN2gtMTAuNHYxLjM5aDEwLjR2MTEuMTdoMS4zOXYt'
    b'MTEuMTdoOS45NHYtMS4zOWgtOS45NG0tLjktMjguMTJjLTE0IDAtMjYuMTEgNi4zOC0zMS41'
    b'OCAxNS4zN3Y3OS43OXEyLjE4LTIuNDIgNC40LTQuNzlhNCA0IDAgMCAxIDUuMTIgLTVjLjgz'
    b'LS43OCAxLjY4LTEuNTUgMi41Mi0yLjNhNC4yMiA0LjIyIDAgMCAxIDEuMiAtNGMtLjU3LTEt'
    b'LjE4LTIuODEuNjktM3YtMi44MWE4LjU5IDguNTkgMCAwIDEgLTEuMjMgLTEyLjEgOC4zMSA4'
    b'LjMxIDAgMCAxIDIgLTEuNzdjLTEuMjQtNS4xNSA1LjQzLTkuNTcgMTAuNjEtNy4zNGwyLjUy'
    b'LS41M2E1Ljc4IDUuNzggMCAwIDEgLS4xIC04LjE5IDQuMyA0LjMgMCAwIDEgLjgxIC0uN3Yt'
    b'MTAuOGgtOC40YTUuODIgNS44MiAwIDEgMSAwIC02LjUxaDguNDF2LTkuMzRhNS44MSA1Ljgx'
    b'IDAgMSAxIDguMDcgLTEuNTUgNiA2IDAgMCAxIC0xLjU1IDEuNTV2OS4zNGg3Ljg0YTUuODEg'
    b'NS44MSAwIDEgMSAxLjU1IDguMDYgNiA2IDAgMCAxIC0xLjU1IC0xLjU1aC03Ljd2MTAuNjho'
    b'LjA2YTUuOCA1LjggMCAwIDEgMS41NSA4IDUuNjggNS42OCAwIDAgMSAtLjkxIDEuMDVsMi4y'
    b'My40NmM1LjE5LTIuMTcgMTEuODYgMi4xOSAxMC42MSA3LjM0YTguNjIgOC42MiAwIDAgMSAy'
    b'LjUxIDExLjkgOSA5IDAgMCAxIC0xLjc3IDJ2Mi44MWMuODYuMjEgMS4yNiAyIC42OSAzYTQu'
    b'MjQgNC4yNCAwIDAgMSAxLjIxIDMuOTFxMS4zMiAxLjE1IDIuNTkgMi4zNWE0IDQgMCAwIDEg'
    b'NSAyLjUyIDMuOTEgMy45MSAwIDAgMSAwIDIuNDljMS40NSAxLjUgMi44OSAzIDQuMzEgNC42'
    b'MXYtNzkuN2MtNS40LTkuMDItMTcuNS0xNS4zMi0zMS41LTE1LjMyem0tMTUuNyA3NC41Mmgz'
    b'MS42M3YxLjk5aC0zMS42M3ptMTEuMi0xOC43YTYuNDYgNi40NiAwIDAgMSA5LjE2IDBjLS4x'
    b'LTMuOC05LjItMy43LTkuMiAwbS05LjA2IDIuNSA1LjcxLTMuMDZjLTEuNzItMS44OS02LjMt'
    b'LjIzLTUuNzEgMy4wNm0tMi4yIDExLjV2LTYuNDljLTIuNDcuNjItMy4xOSA1LjQ0IDAgNi40'
    b'OW03LjkgMS4zdi04LjY1Yy0zLjI4Ljg1LTQuMjMgNy4yNiAwIDguNjVtMTUuOS04Ljd2OC42'
    b'NWM0LjIzLTEuMzkgMy4yOS03LjggMC04LjY1bTcuOSAxdjYuNDljMy4xOS0xLjA1IDIuNDct'
    b'NS44NyAwLTYuNDltLTcuOS04LjIgNS43MSAzLjA2Yy41Ny0zLjI4LTMuOTktNC45NC01Ljcx'
    b'LTMuMDZtLTUyLjYtOTcuNDZ2Mi44MmgzbC0zLTIuODJtLTUuNCAyLjgyaDN2LTIuODJsLTMg'
    b'Mi44Mm00LjMgNjYuNzR2ODUuMzRsMS41OS0yLjA5di04My4yNWgtMS41OW04NC4zIDczLjVh'
    b'MS44MyAxLjgzIDAgMCAwIC0xLjI4IC0uNTQgMS44NiAxLjg2IDAgMCAwIC0xLjA1IC4zMmwy'
    b'LjM1IDIuODRhMS44NiAxLjg2IDAgMCAwIC0uMSAtMi42em0tNzUuOC0uNmExLjgzIDEuODMg'
    b'MCAwIDAgLTEuMzEgLjU0IDEuODYgMS44NiAwIDAgMCAwIDIuNjJsMi4zNS0yLjg0YTEuODkg'
    b'MS44OSAwIDAgMCAtMS4xIC0uNHptLTMuNSAzLjd2Mi4zbC45MS0xLjEzYTQgNCAwIDAgMSAt'
    b'LjkxIC0xLjE3bS0xNS44LTkwLjE1djExNGMxLjUyLTIuMTIgMy00LjI2IDQuNTMtNi4zOGE0'
    b'IDQgMCAwIDEgMi4xOSAtNy4yNiAyLjcgMi43IDAgMCAxIC43MiAwdi04OC40YTEuNyAxLjcg'
    b'MCAwIDEgMS42IC0xLjc2aDUuMTJhMS43MSAxLjcxIDAgMCAxIDEuNiAxLjc2djc0LjUyYTMu'
    b'ODcgMy44NyAwIDAgMSAuNCAtLjY0IDQgNCAwIDAgMSA1LjU1IC0uN2wuMDgtLjF2LTg1aC4x'
    b'My0yMS44em05Ni41IDkxLjI1LjgxIDF2LTJhNC40MSA0LjQxIDAgMCAxIC0uODEgMW0tODku'
    b'OSAxMS42YTEuNSAxLjUgMCAwIDAgLS43NSAyLjc5bDEuNzQtMi40MWExLjQzIDEuNDMgMCAw'
    b'IDAgLS45IC0uNG0xMDEgLjcyYTEuNSAxLjUgMCAwIDAgLTEuMjggLS43MyAxLjQzIDEuNDMg'
    b'MCAwIDAgLTEgLjM4bDEuNzQgMi40MWExLjUgMS41IDAgMCAwIC42IC0yLjF6bS00OS4yLTE2'
    b'Ny45djQuMzZsMy4xOS0yLjQ4LTMuMTktMS44OG0tNyAxLjg4IDMuMTkgMi40OHYtNC4zNmwt'
    b'My4xOSAxLjg4bTIzLjcgMzYuNTkgNC4xIDJ2LTYuMzlsLTQuMSA0LjM5bS00MS41LTQuMzl2'
    b'Ni4zOWw0LjEtMi00LjEtNC4zOW0tOC4xIDE5LjM2djEuNmE0NS4wNSA0NS4wNSAwIDAgMSAy'
    b'My42IC0xMC42bC0zLjY0LTMuNDZ2LTMuNzJsLTE1LTE1LjQ1aC01Ljl2MjguMzZhNjYgNjYg'
    b'MCAwIDEgMTQgLTYuODFsLjEzLTEuNzQtNS42NiAyLjQ2Yy0xLjUzLjc4LTIuMzYuMzQtMi40'
    b'OS0xLjM2di0xM2MuMzUtMS4wOSAxLTEuMzkgMi40My0uOTNsMTAuNCAxMC4wN3Y1YTc3LjQx'
    b'IDc3LjQxIDAgMCAwIC0xNy44NyA5LjU4bTQyLjgtMzIuNTUtMi4yOCAyLjE1IDQuMzQgNC40'
    b'OSAyLjE1LTIuMy00LjIxLTQuMzRtNS40LTUuODMtMi43IDIuOCA1LjcyIDUuMDIgMi42OS0y'
    b'Ljc2di01LjA2aC01LjcxbS0zNC41IDBoLTUuNzF2NS4wNmwyLjY5IDIuNzYgNS43MS01LjAy'
    b'LTIuNjktMi44bTkuNSAxLjA0LTEwLjE2IDkuMTQgMy4yOCAzLjQyIDEwLjI1LTkuMDMtMy4z'
    b'Ny0zLjUzbTEtMTIuMzdoLTguNDN2OC41NWwyLjM4IDIuNzggMi44OS0yLjIzLTEuNDctMS45'
    b'YzAtMS4yLjI5LTIuMTkgMi4wOS0xLjcybDguNzMgOSA0LjI5LTMuNzdtMzMuNDIgMTUwaC4w'
    b'NmExLjYgMS42IDAgMSAwIDEuNiAxLjYgMS42NyAxLjY3IDAgMCAwIC0xLjY2IC0xLjZtLTc0'
    b'LjIgMGgtLjA2YTEuNjYgMS42NiAwIDAgMCAtMS41MyAxLjYzIDEuNiAxLjYgMCAxIDAgMS41'
    b'OSAtMS42M20zOC42IDcuNmExLjUgMS41IDAgMCAxIC0xLjUgMS41IDEuNSAxLjUgMCAwIDEg'
    b'LTEuNSAtMS41IDEuNSAxLjUgMCAwIDEgMS41IC0xLjUgMS41IDEuNSAwIDAgMSAxLjUgMS41'
    b'em03LjIgNS4yYTEuNSAxLjUgMCAwIDEgLTEuNSAxLjUgMS41IDEuNSAwIDAgMSAtMS41IC0x'
    b'LjUgMS41IDEuNSAwIDAgMSAxLjUgLTEuNSAxLjUgMS41IDAgMCAxIDEuNSAxLjVtLTE2LTEu'
    b'NWgtLjA2YTEuNTMgMS41MyAwIDEgMCAuMDYgMG0tMTAuMy0zNC40YTEuNjcgMS42NyAwIDAg'
    b'MCAtMS42IDEuNiAxLjYgMS42IDAgMSAwIDEuNiAtMS42bTM1LjEtLjJ2LS4wNmExLjYgMS42'
    b'IDAgMSAwIDEuNiAxLjYgMS42NyAxLjY3IDAgMCAwIC0xLjYgLTEuNTRtLTE3LjMuOGExLjU5'
    b'IDEuNTkgMCAxIDAgMS42MyAxLjU4IDEuNTkgMS41OSAwIDAgMCAtMS42MyAtMS41OG0tMjku'
    b'MiAyMmE0LjM3IDQuMzcgMCAwIDEgMS44OCAxLjQ3bDEuMzEtMi41MWE4LjM1IDguMzUgMCAw'
    b'IDEgLTMuMiAxbS0xNC4yOSAyMy4xNGg2LjE5bDEuNi0zLjdhMTMuMTMgMTMuMTMgMCAwIDEg'
    b'LTcuNzkgMy43bS01LjMtMTEuOXYtLjM3cS00LjMzIDYuMS04LjMxIDEyLjI5aDcuMDljLTEu'
    b'NzYtMy41MS0yLjM4LTcgMi4wNy0xMC4wNS43Ny0xLjg0LS43LTEuMzEtLjg1LTEuODdtMTgt'
    b'Mi45YTQuMzMgNC4zMyAwIDAgMSAtNCAtMi42NiA0LjM1IDQuMzUgMCAwIDEgLTYgLS45MyA0'
    b'LjI5IDQuMjkgMCAwIDEgLS42OSAtMy42OWMtMiAyLjU0LTMuODYgNS4wOS01LjczIDcuNjhh'
    b'My40MSAzLjQxIDAgMCAxIDMgMS42Yy40OC44MSAxLjI5LjQgMS43Ny0uMWwxLjYtMS44NGMx'
    b'LjI2LTEuMzcgMi45LTEuMTYgNC4xNi41My4xOCAxLjEtLjMgMi4zOCAxLjYgMi43M2E0LjQg'
    b'NC40IDAgMCAxIDMuMTkgLS42MmwxLjI4LTIuN2gtLjN6bS0xLjUtOWMtMi4wNi0xLjM5LTIu'
    b'NjMtNC4zNC0xLjc3LTcuNTNxLTIuNzggMy4yOC01LjQzIDYuNjJhNC4zMiA0LjMyIDAgMCAx'
    b'IDUuODkgMS42MyAzLjM1IDMuMzUgMCAwIDEgLjI0IC40OCA0LjMxIDQuMzEgMCAwIDEgMS45'
    b'IC0uNzcgNC4wOSA0LjA5IDAgMCAxIC0uODMgLS40M20xMC4yLTIwLjZ2LjAybC4wMi0uMDJo'
    b'LS4wMm0uMSAxLjNhNC4yMiA0LjIyIDAgMCAxIC0uMTEgLTEgMS4yOSAxLjI5IDAgMCAxIDAg'
    b'LS4zNWMtMS4zNCAxLjM2LTIuNjUgMi43My00IDQuMTJhNC43NyA0Ljc3IDAgMCAxIDYuMjkg'
    b'Mi40OSA0LjcyIDQuNzIgMCAwIDEgLjQgMmMuODUtMS4zNyAxLjcxLTIuNzMgMi42LTQuMDlh'
    b'NC4zMyA0LjMzIDAgMCAxIC01LjIgLTMuMnptNS44LTcuN2MtLjY1LjYyLTEuMzEgMS44NC0y'
    b'IDIuNDZoLjM3YTQuMzMgNC4zMyAwIDAgMSA0LjI5IDMuNzJjMS4yOS0xLjkgMi42OC00LjM0'
    b'IDQuMDktNi4xOGgtNi43OG02LjgzIDBoLjA2bTE2LjM0IDUwLjhhMTQuMjIgMTQuMjIgMCAw'
    b'IDAgLTE0LjYyIDBoMTQuNjVtMjcuNzctNC44IDIuMDYgNC43OWg2LjE5YTE0LjMxIDE0LjMx'
    b'IDAgMCAxIC04LjI1IC00Ljc5bTIxLjggNC44cS00LTYuMi04LjMxLTEyLjI5di4zN2MtLjEx'
    b'LjU2LTEuNTggMC0uOCAxLjg3IDQuNDUgMy4xIDMuODMgNi41NCAyLjA3IDEwLjA1aDcuMDlt'
    b'LTE1LjY1LTIyLjFhNC4zMiA0LjMyIDAgMCAxIC02LjY3IDQuNjggNC4zNSA0LjM1IDAgMCAx'
    b'IC00LjA3IDIuNmgtLjFsMS4yOCAyLjdhNC40MiA0LjQyIDAgMCAxIDMuMTkgLjYyYzEuOS0u'
    b'MzUgMS40Mi0xLjYzIDEuNi0yLjczIDEuMjYtMS42OSAyLjktMS45IDQuMTYtLjUzbDEuNiAx'
    b'Ljg0Yy40OC40OSAxLjI5LjkxIDEuNzcuMWEzLjQxIDMuNDEgMCAwIDEgMyAtMS42Yy0yLTIu'
    b'NS0zLjktNS4xLTUuOS03LjZtLTE1LjM2LTIuMDggMS4zMSAyLjUxYTQuMTkgNC4xOSAwIDAg'
    b'MSAxLjg1IC0xLjQ3IDguMiA4LjIgMCAwIDEgLTMuMTYgLTEuMDRtOC4xLTcuMmMuODYgMy4x'
    b'OC4yNyA2LjExLTEuNzkgNy41YTQuMSA0LjEgMCAwIDEgLS44MyAuNDMgNC4zMSA0LjMxIDAg'
    b'MCAxIDEuOSAuNzcgNC4zMyA0LjMzIDAgMCAxIDYuMTMgLTIuMTFxLTIuNjQtMy4zMy01LjQx'
    b'LTYuNTltLTEyLTEzLjEuMDIuMDAwMXYtLjAwMDFoLS4wMnYuMDhhNC44MSA0LjgxIDAgMCAx'
    b'IC0uMTggMS4yNiA0LjM0IDQuMzQgMCAwIDEgLTUuMzggMi45MmMxIDEuNDUgMS44OCAyLjkg'
    b'Mi43OSA0LjM3YTUgNSAwIDAgMSAuMzggLTIgNC43OSA0Ljc5IDAgMCAxIDYuMyAtMi40OWMt'
    b'MS4yNi0xLjQyLTIuNTctMi43OC0zLjkxLTQuMTRtLTEyLjctNi41di4wNmguMDhtNi43Mi4w'
    b'NGgtNi44MWMxLjQyIDEuNzYgMi43NiA0LjI0IDQuMjEgNi4xNmE0LjMzIDQuMzMgMCAwIDEg'
    b'NC4zMSAtMy45M2MtLjU2LS41My0xLjEzLTEuNjgtMS43MS0yLjIzbTcuNS05Mi4xNS01LjY2'
    b'LTIuNDYuMTMgMS43NGE2NS43MyA2NS43MyAwIDAgMSAxMy45MSA2Ljh2LTI4LjM0aC01Ljgy'
    b'bC0xNSAxNS40NXYzLjc2bC0zLjY0IDMuNDZhNDUuMDUgNDUuMDUgMCAwIDEgMjMuNiAxMC41'
    b'NXYtMS42MWE3Ny43MyA3Ny43MyAwIDAgMCAtMTcuODcgLTkuNTd2LTVsMTAuMzUtMTAuMDhj'
    b'MS40Mi0uNDYgMi4wNy0uMTYgMi40My45M3YxM2MtLjExIDEuNzItLjk0IDIuMTUtMi40MyAx'
    b'LjM3bS05LjgtNDAuMzZoLTcuMzVsLTUgMy42NyAzLjc1IDMuOTQgMS44NS0xLjYgMyAzLjE5'
    b'LTguNDUgNy40djE4Ljk0YTEuODUgMS44NSAwIDAgMSAtMy42MSAwdi0xNi45MWwtNS43OCA0'
    b'Ljg4djExLjM2bDcuODcgNi45MSA2LjE4LTYuMjYtLjE4LTE4LjM1IDcuNzItNi44di0xMC4z'
    b'N20tNzAuMyAxMS4wOGgyMS45MXY0Ni41M2gtMjEuOTF6bS0yNi44IDIyNi44LS4wMy0uMDZ2'
    b'MjUuOThoMjguOTN2LTI1LjkyaC0yOC45bTEzOC0uMXYyNmgyOC45di0yNS45OGwuMDMtLjAy'
    b'aC0yOC45M20tNDAuNC03OS41Yy0yIC4zOC00LTEuNi00LjU1LTQuMjRzLjY5LTUuMjUgMi43'
    b'LTUuNjNjMi0uMzcgNCAxLjYgNC41NSA0LjI0cy0uNyA1LjI0LTIuNyA1LjYzbS0yMy42LTQu'
    b'MmMtLjUxIDIuNjUtMi41NSA0LjYzLTQuNTUgNC4yNHMtMy4yMi0zLTIuNzEtNS42IDIuNTUt'
    b'NC42MSA0LjU1LTQuMjRoLS4wNmMxLjk5LjM1IDMuMjggMi45NSAyLjc3IDUuNm0tMjkuOS0x'
    b'MzcuM2gtMTIuN2ExLjQyIDEuNDIgMCAwIDAgLTEuNCAxLjQ0djMyLjI3YTEuNDIgMS40MiAw'
    b'IDAgMCAxLjQgMS40NGgxMi43MmExLjQzIDEuNDMgMCAwIDAgMS40IC0xLjQ0di0zMi4yN2Ex'
    b'LjQzIDEuNDMgMCAwIDAgLTEuNCAtMS40NHptMTE5LjIgMjQzLjNoLTIxLjd2LTE4LjczaDIx'
    b'Ljd6bS0xNTkuNy0xOC43aDIxLjd2MTguNzNoLTIxLjd6bTE4NS40IDg0LjhoLTIxMS4xYTUu'
    b'MTMgNS4xMyAwIDAgMCAwIDYuNjdoMjExLjFhNS4xMyA1LjEzIDAgMCAwIDAgLTYuNjdtMjEu'
    b'NSAzMGgtMjU0YTcuNTIgNy41MiAwIDAgMSAwIC04LjI1aDI1NGMxLjIxIDIuNiAxLjQ3IDUu'
    b'NzktLjAyIDguMjUiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZmlsbD0iI2ZmZDcwMCIvPg0KCTwv'
    b'Zz4NCjwvc3ZnPg0K', 'RU_TVE')

RU_TVE = b64_RU_TVE
index.append("RU_TVE")
index.append("Russia Tverskaya oblast")
catalog["RU_TVE"] = RU_TVE
catalog["Russia Tverskaya oblast"] = RU_TVE
country["Russia Tverskaya oblast"] = ('RU_TVE', '', 1)
lookup["RU_TVE"] = ('RU_TVE', '', 'Russia Tverskaya oblast', 1)
lookup["Tver"] = ('RU_TVE', '', 'Russia Tverskaya oblast', 1)
lookup["Russia Tverskaya oblast"] = ('RU_TVE', '', 'Russia Tverskaya oblast', 1)
details["RU_TVE"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Tver"}
regional["RU_TVE"] = ('RU_TVE', 'Russia Tverskaya oblast', 1)
regional["Russia Tverskaya oblast"] = ('RU_TVE', 'Russia Tverskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_TY = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iOTAwIiBoZWlnaHQ9IjYwMCIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6'
    b'Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48cGF0aCBkPSJtMCAwaDkwMHY2MDBIMCIgZmlsbD0i'
    b'IzYzYjFlNSIvPjxwYXRoIGQ9Im0zNzAgMzAwLTMzNS0zMzV2NjcwbDMzNS0zMzVoNTMwIiBm'
    b'aWxsPSIjZmZmIiBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0iMTAwIi8+PHBhdGggZD0i'
    b'bTM1LTM1IDMzNSAzMzVtLTMzNSAzMzUgMzM1LTMzNWg1MzAiIHN0cm9rZT0iIzYzYjFlNSIg'
    b'c3Ryb2tlLXdpZHRoPSIzMy4zIi8+PHBhdGggZD0ibTAgMHY2MDBsMzAwLTMwMCIgZmlsbD0i'
    b'I2ZlY2IwMCIvPjwvc3ZnPg0K', 'RU_TY')

RU_TY = b64_RU_TY
index.append("RU_TY")
index.append("Russia Tyva Respublika")
catalog["RU_TY"] = RU_TY
catalog["Russia Tyva Respublika"] = RU_TY
country["Russia Tyva Respublika"] = ('RU_TY', '', 1)
lookup["RU_TY"] = ('RU_TY', '', 'Russia Tyva Respublika', 1)
lookup["Tuva"] = ('RU_TY', '', 'Russia Tyva Respublika', 1)
lookup["Russia Tyva Respublika"] = ('RU_TY', '', 'Russia Tyva Respublika', 1)
details["RU_TY"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+07:00","altname":"Tuva"}
regional["RU_TY"] = ('RU_TY', 'Russia Tyva Respublika', 1)
regional["Russia Tyva Respublika"] = ('RU_TY', 'Russia Tyva Respublika', 1)
#----------------------------------------------------------------------
b64_RU_TYU = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMTIwMHB4IiBoZWlnaHQ9IjgwMHB4'
    b'IiB2aWV3Qm94PSIwIDAgOTAwIDYwMCIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzE5OTkveGxpbmsiPg0KPHJlY3QgZmlsbD0iIzAwOTIzZiIgd2lkdGg9IjkwMCIgaGVpZ2h0'
    b'PSI2MDAiLz4NCjxyZWN0IGZpbGw9IiMwMDUxYmEiIHdpZHRoPSI5MDAiIGhlaWdodD0iNDAw'
    b'Ii8+DQo8cmVjdCBmaWxsPSJ3aGl0ZSIgd2lkdGg9IjkwMCIgaGVpZ2h0PSIyMDAiLz4NCjxw'
    b'YXRoIGlkPSIxIiBkPSJNMzY3IDI4OGwyNCAzNiA2MiAwIDI0IC0zNm0tNDQgLTZsMTQgMTJt'
    b'LTUwIDBsMTQgLTEybS0yNiAtNmwzMiA0OCAxMCAwIDMyIC00OCIgZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSJnb2xkIiBzdHJva2Utd2lkdGg9IjEyIiBzdHJva2UtbGluZWNhcD0icm91bmQiLz4N'
    b'Cjx1c2UgeGxpbms6aHJlZj0iIzEiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDE0MCkiLz4NCjx1'
    b'c2UgeGxpbms6aHJlZj0iIzEiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDI4MCkiLz4NCjxwYXRo'
    b'IGZpbGw9IiNkODFlMDUiIGQ9Ik0wLDYwMCAwLDAgMjI1LDMwMHoiLz4NCjwvc3ZnPg==', 'RU_TYU')

RU_TYU = b64_RU_TYU
index.append("RU_TYU")
index.append("Russia Tyumenskaya oblast")
catalog["RU_TYU"] = RU_TYU
catalog["Russia Tyumenskaya oblast"] = RU_TYU
country["Russia Tyumenskaya oblast"] = ('RU_TYU', '', 1)
lookup["RU_TYU"] = ('RU_TYU', '', 'Russia Tyumenskaya oblast', 1)
lookup["Tyumen"] = ('RU_TYU', '', 'Russia Tyumenskaya oblast', 1)
lookup["Russia Tyumenskaya oblast"] = ('RU_TYU', '', 'Russia Tyumenskaya oblast', 1)
details["RU_TYU"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Tyumen"}
regional["RU_TYU"] = ('RU_TYU', 'Russia Tyumenskaya oblast', 1)
regional["Russia Tyumenskaya oblast"] = ('RU_TYU', 'Russia Tyumenskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_UD = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'PHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIg'
    b'eG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIGhlaWdodD0iMjcw'
    b'IiB3aWR0aD0iNTQwIj48cmVjdCB3aWR0aD0iMTgwIiBoZWlnaHQ9IjI3MCIvPjxyZWN0IHdp'
    b'ZHRoPSIxODAiIGhlaWdodD0iMjcwIiB4PSIxODAiIGZpbGw9IiNmZmYiLz48cmVjdCB3aWR0'
    b'aD0iMTgwIiBoZWlnaHQ9IjI3MCIgeD0iMzYwIiBmaWxsPSIjZDIxIi8+PHBvbHlnb24gZmls'
    b'bD0iI2QyMSIgcG9pbnRzPSIyNDUsNjAgMzQ1LDE2MCAxOTUsMTYwIDI5NSw2MCAyOTUsMjEw'
    b'IDE5NSwxMTAgMzQ1LDExMCAyNDUsMjEwIi8+PC9zdmc+Cg==', 'RU_UD')

RU_UD = b64_RU_UD
index.append("RU_UD")
index.append("Russia Udmurtskaya Respublika")
catalog["RU_UD"] = RU_UD
catalog["Russia Udmurtskaya Respublika"] = RU_UD
country["Russia Udmurtskaya Respublika"] = ('RU_UD', '', 1)
lookup["RU_UD"] = ('RU_UD', '', 'Russia Udmurtskaya Respublika', 1)
lookup["Udmurtia"] = ('RU_UD', '', 'Russia Udmurtskaya Respublika', 1)
lookup["Russia Udmurtskaya Respublika"] = ('RU_UD', '', 'Russia Udmurtskaya Respublika', 1)
details["RU_UD"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+04:00","altname":"Udmurtia"}
regional["RU_UD"] = ('RU_UD', 'Russia Udmurtskaya Respublika', 1)
regional["Russia Udmurtskaya Respublika"] = ('RU_UD', 'Russia Udmurtskaya Respublika', 1)
#----------------------------------------------------------------------
b64_RU_ULY = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxNzQyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1VseWFub3Zza19PYmxhc3Quc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cu'
    b'aW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRw'
    b'Oi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6'
    b'eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3'
    b'LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2'
    b'ZyI+CiAgPGRlZnMgaWQ9ImRlZnMxNzQ2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9'
    b'Im5hbWVkdmlldzE3NDQiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiIGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2Nh'
    b'cGU6cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4K'
    b'ICA8ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2Ui'
    b'IGlkPSJnMTc0OCI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1'
    b'YWxpdHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FB'
    b'QUFOU1VoRVVnQUFBSGdBQUFCUUNBWUFBQURTbTdHSkFBQUFCR2RCVFVFQUFMR1BDL3hoQlFB'
    b'QUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0Nj'
    b'dWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQUoKcjBsRVFWUjQydTJkV1d3YzlSM0hQ'
    b'M1B0ek96Tzdub3ZyNGtUY29LTklOQlNDaUtpZ3A1Q1FrV0tnSXEycUtyNjJJZXFmZWdEOE1a'
    b'TApENTZxcXFvRXBRODhBS3BhVkZSUUE3UVJhV210SkVvVEd0TEV1Wlk0VGh6YmUxK3pNN003'
    b'L3o2WTBrUVFZaWRFZUNmL2oyVEoycDM1CjIvUDd6dS80WHpNS3o1NFVTQ0tMS2swZ0JZNE1u'
    b'eE83K0lyeWgydEtZUDFhdWRBN3dwM2NiLytaak41RTdZUzh3U05TNENqUkZRNWwKUDQycURH'
    b'aUlFVkJraUk0VS85SHVKTjg1VGFIOEhudkVGMlVPamh3aTVGWnZIMXRqMDJTN0oyVU9IbmFj'
    b'b01wWHRkZjVUakhKTzRjUApzTHNCNTlRc2xackc5dUFuR05ZNnRtKzdsMmRtenJBei9ESlZZ'
    b'MXdLUEN3OHdSTjhJL01xRG9LajFZZFlVNTVqODB0TnpQc1hjUnhCCi9QY1c2Ky90RWs3bStk'
    b'bklNN2pLMCt4b2JlUEg0YThSU3JTQ1d1UkM5R1BkWC9HWS9Tb0pSUkFxQ25admluV2JON0oy'
    b'b1l4ZlUrblUKWU0xQ215MDNieVRtN3FNdlZHeWg4SFY3TjQ5N2o4c2N2TnA1MkhvRlZRRkZF'
    b'V2hhU0NaMkZqT1RKSXlGQklFZ0ZBS2hDSklieG9pTAphWFJOSUJBSUlmaVM5VGNab2xjN0Ni'
    b'V0RIaE9FZ1VMYjY2T1lBcmQyak1MMkpNbmNQSVUxQXc2VkJmWDZBc1dSSm1VM0pHc1l4TXlR'
    b'CmhPdEtnVmNkWGdlRUFNc0JJV2lGS2FCT3Q2Zml4WFIwSTA3YWZKUGtGM1NTMmZVWWlYWEVS'
    b'M2NSQksvUkRDMFNLU2pQQnhSeUlSMlIKUWhGOWhLcERyd1dxQnJHNEROR2ZGbmJRSmw0Y2hX'
    b'NWx5WHY3WlFLN3c4d0NOTHlRWERGRHVuZ2JHaUcrRzNMaTMyY3BIZGhQc3dFeApyVStxc0lY'
    b'RXlEaWgxbWV1Q2xWRlVBeFBMVFh1MW5BS09jeCtSd3I4YVpBTzZteTZmaFJyMEFQVEJxQmpG'
    b'RGhnUElsWmROQUhPak9ICnk0amVYd25VQVkxQkR6WFRZbUJYYUhnRGV2UlIrL3M0Yyt3NHVD'
    b'YU1hSnlJLzVCeit1YWxQeEN6c0VXZkxlTTVITDg1dEFJcnd6WmQKZUxQWjVZNDFEa0V5ejJ4'
    b'UE1EVTFSWkM5SHBUWUI4Y1VlaWQ1Mm4yUVhDb2dteDZRc0VKMFkrbHVGZ0pRSU9oRHoxZXBO'
    b'SFNxRFlXbgp0T2M0NW13N3p6SUJadmtVZDk5OU4rT21RR3RWK2NlWkRpY0NXK2JncThsOHJj'
    b'bE9WR0tkL1lSV21zQWFRWGZyOU9Pakh4eFRWL09NCnJIR3dCelZPenFkb053M2N0a2JmRnln'
    b'SU5FUEZqQTl3MGdHRmRKZlJVWVZ6clkzbmpYb0o5TllpbnBYbXpLa1pTdTBLWVNKSHA5R0UK'
    b'dUJUNHFsSTJSc0FWNE9xZ08yRHB4Sys3amt4N0VZSUI0YUNQbmRCNSsvZzI3TU5WZ3U3b3g3'
    b'WjMyR3FoM3FSUTNKZ21IWGJRZEIxaAphRlNMdDlBK084c3h6NGFlQm1vSVZsNVcwVmVibkM1'
    b'STVkS1UxUGYvOVZEZ2w4OWhPQ1pyYk1qWk5tNnJ5WU1QUHNWMTMwMHZxODNGClZwZEQwejVx'
    b'UE1WaUwrQ01yK0V2eklIUWxtSjZ1c0RtZEl4eXRVc0RUUXA4MVFvR01lQ3hpU1FWSzgycHVV'
    b'VkNNdzJHVFMrRTQwMDQKamc2RWZOdHEwUEtTdE9jYnkyNjcwS3Z4bTFyeVBKT1lZQ3o5WnZT'
    b'NjNIdmJPRXB5anVkbXBBZGZOZkpoQjg4ZFFOZGZFdmNpYkJCMQozTzdLT2dqcmFGMzB1MEJQ'
    b'b0ZibWlLa0NKMmpTTmxKUzRLdEJnTWJmWjl1a3RCQzRlRDZzcUFrK3UyR005ZXZYYytUSUVU'
    b'Uk5ZM0p5Cmt1bnBhWVFRVEV4TWNQVG9VUWFEQVpPVGs1UktKZjY1R0h4TVoxTGozWm16ZURH'
    b'SGdUSmNXVzJvK3NGMUxjRzBiM08wZlluakZJdGMKUHMrZVBYdFFWWlZVS3NXQkF3Y29Gb3Rz'
    b'M0xpUnFha3AwdW1sQ0xCNzkyNUdSMGVwQ2VOajJ6eldpM0d3WStEcXd6V3lwVVIxMmV3ZgpK'
    b'eXZjdnI1SXU5M0c4endLaFFMNWZCNU4wNWlkbmFYVDZlRDdQdGxzbGlObks5eC9LQk5GTTBS'
    b'M1JjY2JwOXNJSVJnZkgyZnQyclZVCktoVk0wMFRYZFZxdEZvVkNnUnR1dUFHQW5iUHRxSm9o'
    b'dWlzNjNtckgrWUhySW9SQVVSU0t4U0tsVW9rd0RCa2JHOE4xWFhxOUhxN3IKc3JOcFNZR0hL'
    b'dStFQTI0ZlVka3hQVWRTNlpOUEpuQjluN2JRUVFGYm5NWXhUY3F0RGwzRjRKYTB3LzZLejBD'
    b'TFNZR0hnYmhiNWJmZgp1eDFEWDk3bENTRjQ3WmU3V1l3WHBjRERRQ2RSNEpGbjMrVFJOUU5F'
    b'ZUFseEVieXlxTE5vVDhnUVBVeThZa3p5a0hLRW05Y1hpY2ZqCitMNlA3L3NJSVVpbFVuaWVo'
    b'Ky83bkpndjh6dDFJcXBtaVBiT2hxU1RKSi9Qazh2bDhEeVBkbnVwV2g0Ykc2TldxK0Y1SHBX'
    b'dUQzUFIKdFVHa0Y3N0hqYVdKZ1NBSU1Jei9EMlFZaGtFUUxJMWNaUndiQWs4S1BIUUVQVEtP'
    b'OVpFQ0s0cENHQzRsNTB6U0llWjNwY0REUnN6dgpra2ttUDFMZzh6Rk5rd1MrRkhqWWNBaUl4'
    b'WmI2dGYxK0gwMjcrRHh1SXNLVlNHUUZYb2xvanFGS2dZZk9nMWNnV2tLWEFnK2hCeS8vCjBo'
    b'eGRrUUlQblFldlFMU0VETkZENk1HRzlPQ0loK2lWZUxBVWVQaENkRXhaZ1FmTEVCM3BJa3Zt'
    b'NEtFc3NsYlNUWkloZWdpTHJCV0UKYUptRFpUZEpDaXk3U1ZMZ1ZldkJzb3FPYmhWdG1pYW02'
    b'RXVCaHcxYkZSZWRBNzdnUmtnazBQcXVGSGpvTHN4M2ljY3Z2WThvSG8ragpEWHd1dWZ4U0Ny'
    b'eUtFQ0dHOEpjbHNLcXFaQkp4Rkw4WFNWTkVjMmREcnd1K1I3MWVwMTZ2MDI2M1NTUVMxT3Qx'
    b'TkUxamNYR1IwNmRQCk16SXlRcmxjeHUrNTJONkFyaG1QbmkyaXRydndtNmtxRS9HUTBVRVRR'
    b'b0dtYTZpYVR1QjVxTHFLRUFJeEVNUXNpMzRRRUE0R3FMckcKdkxBNTRlazgzOGhKRDE3TmZI'
    b'OXJobnR1Mm5SWjUrNC9WdUw1WFRKRXIxb2VzczZ4dTZSUU9sZTVyUE1ydlFHUE9pb3ZOYk5M'
    b'anpHVQpJWHAxOGM1OUNyZHUyWEJGYlp5ZFgyRDg1UW9ZbHZUZzFVWVFCUGorbGExeDdnZUJM'
    b'TEpXSzJhbndvNjdZSExEMnNzNmY3NWM0YTRkCk5ieVI2RHplUDFJZTdDVnkvUFRRREQ4SzNz'
    b'T3l6QlYyblFXL2VMZU9sN3BlRmxtcm1kZmRIQy9jTXM2WjJWbUt4U0w1Zko2REJ3K1MKZkg4'
    b'YnkvL29kcnZjZU9PTkxDd3MwRzYzMmJKbEN3OU03UU5Ia3dJUEE3bGNqbXcyUzZsVVl1dldy'
    b'YWpxaHdmdGpoOC96dmo0T0tacApSdFVNRVg2dGp1TXdNek5Eb1ZCZ2RuYjJReDdjYkRZcEZv'
    b'dk16YzJSeldhbHdNTkd2VjVuMDZhbEFZOWFyVVltay9tUXdNbGtrbVF5Cnljek1ESTdqUk5J'
    b'TzE4U2J6eFJGV2RablV1QWhwZGZyTGVzekdhS0hpREFNT1hueUpLbFVpblhyMWxHcjFTNzRm'
    b'dTNhdFZTclZhclYKS3BabFNROGV4aHhzMnpiZGJoZE4wOGhrTWhmOFdKWkZ2VjdITUF3YWpZ'
    b'YjA0R0VoMFZuazFLays2VlFLOS8wWFhlM2R1NWRFSW5IQgpjYTdyVWlnVUFMQnRtMUtwUkx4'
    b'Ym9ldU1ScXYraU5KUTVaMWFoVjNmdWhYTHZMeEhFZ2I5UGw5N1lUOXYrWG5wd2F1UmNsL2pM'
    b'KzhjCkpYYVppU2NRc0JqSWtheFZ5eGZUSGc5OC9qTlgxQVY2WTNZdmh5clJzVWswUXJRUWJP'
    b'LytpNTgvZkErNnBsMWhVNEluWDM2YkYvV3QKb09sUzROVWk4TUg3QkJNYlBwbVpvRWFqUWVI'
    b'Rk9iQ0hmM1FyTWlGYTAvVmxMWFJmbGxIMDZHU3VhMklrNjFvbUdyZXFvbkRmbjg2aQpLcC9N'
    b'WTJNRmdGV1FBcThtRnVKajBsMWxpTDQyUTNSSG1pRzYvQmRob01ZL3ZJUWR5QUFBQUNWMFJW'
    b'aDBaR0YwWlRwamNtVmhkR1VBCk1qQXlNeTB3TkMweU9GUXdOVG8xT1Rvek9Dc3dNRG93TUZh'
    b'dXRNY0FBQUFsZEVWWWRHUmhkR1U2Ylc5a2FXWjVBREl3TWpNdE1EUXQKTWpoVU1EVTZOVGs2'
    b'TXpnck1EQTZNREFuOHd4N0FBQUFBRWxGVGtTdVFtQ0MKIiBpZD0iaW1hZ2UxNzUwIiAvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'RU_ULY')

RU_ULY = b64_RU_ULY
index.append("RU_ULY")
index.append("Russia Ul'yanovskaya oblast")
catalog["RU_ULY"] = RU_ULY
catalog["Russia Ul'yanovskaya oblast"] = RU_ULY
country["Russia Ul'yanovskaya oblast"] = ('RU_ULY', '', 1)
lookup["RU_ULY"] = ('RU_ULY', '', "Russia Ul'yanovskaya oblast", 1)
lookup["Ulyanovsk"] = ('RU_ULY', '', "Russia Ul'yanovskaya oblast", 1)
lookup["Russia Ul'yanovskaya oblast"] = ('RU_ULY', '', "Russia Ul'yanovskaya oblast", 1)
details["RU_ULY"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+04:00","altname":"Ulyanovsk"}
regional["RU_ULY"] = ('RU_ULY', "Russia Ul'yanovskaya oblast", 1)
regional["Russia Ul'yanovskaya oblast"] = ('RU_ULY', "Russia Ul'yanovskaya oblast", 1)
#----------------------------------------------------------------------
b64_RU_VGG = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iMzAw'
    b'cHgiIGhlaWdodD0iMjAwcHgiIGVuYWJsZS1iYWNrZ3JvdW5kPSJuZXcgMCAwIDMwMCAyMDAi'
    b'IHZlcnNpb249IjEuMSIgdmlld0JveD0iMCAwIDMwMCAyMDAiIHhtbG5zPSJodHRwOi8vd3d3'
    b'LnczLm9yZy8yMDAwL3N2ZyI+CiA8cmVjdCB3aWR0aD0iMzAwIiBoZWlnaHQ9IjIwMCIgZmls'
    b'bD0iI2ZmZiIvPgogPHBhdGggZD0ibTE3NC43MyAxNTVjMS42OTYgNy40MSA0LjQ2NCA4LjAz'
    b'NSA2Ljc4NSA1LjA5IDIuMDIzLTIuNTY4IDkuNDY1LTkuNjQ0LTIuMjMyLTI3LjA1NS0yLjAw'
    b'Ni0yLjk4Ny00LjgyLTcuMDUzLTIuNTg5LTEzLjAzNS44OTQtMi4zOTMuNjI1LTUtMi41ODkt'
    b'Ny43NjgtMi41Ljk4Mi0zLjMwNCA0LjI4NS0yLjIzMiA1LjQ0NnMxLjM4MSAxLjg3Ni0uMTc5'
    b'IDIuNzY4Yy0xLjg3NSAxLjA3MS0zLjY5IDguNjM4LjgwNCAxNS4yNjkgMy41NDIgNS4yMjQg'
    b'MTEuNjA4IDI0LjIxMiAyLjIzMiAxOS4yODV6bS0xLjk2NC0zMS42OTZjLTQuNTUzIDMuMDM2'
    b'IDIuMDU3IDkuNjM0IDQuMjg2IDE0LjEwNiAxLjggMy42MTEgMi4yMzEgNS41MzYgMi41IDgu'
    b'MjE1IDIuMTQzLTEuMTYgMS43MzctMi44MjMuMzU2LTUuODkzLTUuMTc4LTExLjUxNy02Ljk2'
    b'NC04LjkyOC03LjE0Mi0xNi40Mjh6bTE4LjgzOSAzOS43MzFjNy44NTctMi4yMzEgMTMuNDcy'
    b'Ljc4OSAxOS4xOTYgMS4wNzIgMTAuNTA4LjUyIDExLjQxOS03Ny40MzEtOS41NTQtNzEuMTYx'
    b'LTcuMTggMi4xNDctMTQuODIxIDQuMzc1LTE4Ljg0IDIuOTQ3LTQuMDE4LTEuNDI5LTYuNTE4'
    b'LTEuMjUtNi42OTUgMi41ODktLjA5NiAyLjA1My0xLjEyNy45NzMtMi41LjUzNi0zLjQxLTEu'
    b'MDg1LTUuOTgyIDIuNDExLS45ODIgMy41NzIgMy4xMDQuNzIxLTIuNjExIDUuMzI2LTUuNDQ3'
    b'IDYuNTE4LTQuNDY0IDEuODc1LS44OTcgNC4zOTggMS40MyAxLjYwNyAxLjc4NS0yLjE0NCA3'
    b'LjU4OS0yLjc2OSA5LjU1My40NDUgMS45NjUgMy4yMTUgMS44MjggNy4zNjMgNC45MTEgMTAu'
    b'NDQ3IDMuNTcxIDMuNTcxIDUuNjEyIDEwLjExMSAyLjk0NiA2LjMzOS00LjczMi02LjY5Ni05'
    b'LjY2NC04LjE0Mi0zLjg0LTEuMTYxIDExLjY5NyAxNC4wMTkgMTUuODA1IDIxLjA3MiAxNS4w'
    b'OSAyNS42MjUtLjQ3MSAzLjAwMS0uNzE1IDMuNDgyLjM1NyA0LjczMiAxLjA3MSAxLjI1IDIu'
    b'Mzc1IDIuMjA3LS43MTUgMi43NjgtMy45MjcuNzE1LTQuNjQyIDEuNzg2LTQuOTEgMy4xMjV6'
    b'bS03LjU0NC04MS44NzRjLTMuODQgMS4xMTYtOC45MzggNi4zMzMtMTMuNDM4IDQuMTA3LTMu'
    b'OTktMS45NzYtNC40Mi0zLjcwNi0yLjQxLTQuNTk5IDIuMDA4LS44OTMuODMyLTIuOTQyLjA4'
    b'OS0zLjkyOC0uNzc1LTEuMDI4LjM1Ni0zLjE3IDEuMDI2LTQuNTA5IDIuMDU0LS4zMTMgMi44'
    b'MTMgMS4yMDYgNi42MDcuODkzIDMuMjYtLjI2NSA4LjIxNSA4LjA4MSA4LjEyNiA4LjAzNnoi'
    b'IGZpbGw9IiNFQ0VDRUMiLz4KIDxwYXRoIGQ9Im0wIDBoMzAwdjIwMGgtMzAwdi0yMDB6bTE2'
    b'My45MyAxODEuMDdjMTguOTI5LjUzNiAzOC41NzEuNTM2IDUxLjc4Ni4zNTctMi44NTctNC4w'
    b'MTktMy42NTgtNC42MDEtNi42OTctOC44MzktMS42MTMtMi4yNTEuNTQzLTQuMSAxLjcxOS02'
    b'LjA2MS43NDItMS4yMzguMjU0LTMuMi0uMDIxLTQuMDI5LS43MTUtMi4xNDMtMS45NjUtMy45'
    b'MjktMi41LTYuNjA3LS41MzYtMi42NzgtMS4yNS0zLjU3MS0yLjg1Ny01LjcxNC0xLjYwNy0y'
    b'LjE0NC01LTYuNjA3LTYuNjA3LTkuMTA3cy00LjE5Ni01Ljk4MS00LjkxLTguNDgxYy0uNzE1'
    b'LTIuNS04Ljc1LTE2LjI1LTEyLjY4LTIwLjg5NC4wOS0uOTgxLjcxNS0xLjk2NCAxLjM0LTMu'
    b'MTI1IDMuOTI5LjUzNiAxMS41MTggMS44NzUgMTEuNDI5LTIuNDExLTMuODM5LS4wNzItNC42'
    b'MTQtLjM4OS0zLjkxNS0yLjkzNC0uOTM1LS43MDUtMy40MTYtLjIzOC01Ljk5Ni0xLjc5OCA1'
    b'LjE3OS0xLjE2MSA5LjgzNiAyLjg1NiAxMi45NDcgNS40NDYgMS43MzIgMS40NDMgMy43NTgg'
    b'MS4zNSA1LjYyOSAxLjI0NCA0LjI0OC0uMjQyIDcuNzA1LTMuMTQ2IDUuMTc0LTYuNzc5IDEu'
    b'MjU5LTIuNjczLjY3My00Ljk2Ni0uOTgyLTUuNjI1LTQuNjU0LTEuODU0LTEwLTcuOTQ2LTE1'
    b'LjcxNC01LjE3OS0xLjY5Ni0xLjc4Ni42MjUtMi4zMjEgMS42OTYtMy4xMjUgMS4wNzItLjgw'
    b'NCA1LjA2My0zLjEwOSA5LjQ2NS00LjM3NSA0LjEwMi0xLjE3OSAxMi4wOTQtNi4xMzIgMTMu'
    b'MzkzLTYuMDcxIDEzLjMwNC42MjUgMTQuNjQzLTIuNDExIDYuMzQtMi4xNDMuMzM1LS41NDIu'
    b'ODQzLS42NjUgMS40MDgtLjk2OSAxLjMyOS0uNzE0LjQ2Ny0xLjI4Ni0uNjE4LTEuMDM3LTEu'
    b'NDQ4LjMzMy00LjAxOSAxLjA4NS01LjYxMi4yMi4wNjgtLjMzOS40MTMtMS4zMDMgMS4yMDgt'
    b'MS42MzMgMi40MDctLjk5OSAyLjYzOS0zLjE2Ny0zLjYxOC4xMTUtMS45NDUgMS4wMi0yMC45'
    b'MjYgNy41OTctMjMuMjE1IDguMTI1LTQuNjQzIDEuMDcxLTEzLjkyOCAyLjUtMTcuMzIxIDMu'
    b'ODM5LTEuMzM5LS40NDYtMi4yMzEtMS4zMzktMy44MzktMi40MTEgMS43ODUtMS42MDcgMi4x'
    b'NDMtMi41ODkgMi4wNTMtMy43NSAxLjA0OS0uMzkyIDIuMTQzLS4yNDkgMy4yNTktLjcxNS4y'
    b'MzEtMS44MTMuNTE5LTMuNTItLjEzNC01LjA4OC0xLjYwMi4xNS0zLjIxNC0xLjA3Mi0zLjky'
    b'OC0xLjg3NS41OTItLjI4MyAxLjU0MS0uNjEgMi4xODgtLjcwNS0uMzUtMS43NDEtMS45MTIt'
    b'Mi45NzEtMy40MzgtMi45NTctOS4xMDcuMDg5LTEwLjgwNCA0LjgyMi0xMCA3LjU4OS4zODkg'
    b'MS4zNDItMS44NzUgMi43NjggMi4wNTMgNS45ODIgMS4zMjggMS4wODYuOTgyIDIuODU3LjI2'
    b'OSA1LjE3OC04LjE3NS43ODQtMTQuNzg5LTkuOTY2LTE4LjEyNS0xNS41MzYgNCAuOTI1IDQu'
    b'OTU0LjY5MSA1LjIxNi0uMjU4LjQ0Ni0xLjYyLTEuNTk3LTIuMzU0LTUuMDM4LTQuMjA2IDEw'
    b'LjI2NC0yOS4xMDQgMTYuOTYtNDcuODU0IDE1LjE3NC01MC42MjItMy43NS40NDctOC45Mjgg'
    b'MjAuNzE0LTE5LjI4NSA0OS41NTQtNC4zODYtLjQzOC01Ljc0NS0uMzUxLTUuOTYzIDEuMTU1'
    b'LS4xMjYuODc0IDEuMjQ5IDIuMzI3IDMuMTk1IDIuNzczLS40NDYgMi4yMzItLjI2OCAzLjMw'
    b'NC4yNjggNS45ODItMS40MzMgNC4yMDIgMi45OTEgNC45MzMgMy41MjcuNjQ3LjQ0Ni41MzYg'
    b'MS4wNTkgMS40OTIgMS4zODQgMi42NTYgMS40OTQgNS4zNTQgNS4zNTcgMTAgMTAuNzE0IDE0'
    b'LjU1NC45MDEgMi42NTkgMi4zMjEgNi4xNjEgMi4zMjEgNy44NTcgMCAyLjE2LS4xNzkgNC43'
    b'MzItLjE3OSA2LjQyOSAwIDEuNjk1LS45OTggMy43OTctLjE3OCA2LjYwNiAyLjI3OCA3Ljgx'
    b'OSA0LjkxIDExLjA3MSA1LjI2OCAxMy45MjlzNi42MDcgMTYuMDcxIDcuMTQzIDE4LjMwNGMu'
    b'NTM1IDIuMjMxIDEuOTY1IDYuNDI5IDIuNDEgOS45MTEuNDQ3IDMuNDgxIDIuMDU1IDE3Ljc2'
    b'OC4wOSAxOS43MzFzLTYuNjA3IDYuODc2LTYuNjk2IDYuODc2eiIgZmlsbD0iI0ZFMDAwMCIv'
    b'PgogPHJlY3QgeD0iMTcuMiIgd2lkdGg9IjE3LjIiIGhlaWdodD0iMjAwIiBmaWxsPSIjMDAw'
    b'MTg0Ii8+CiA8cmVjdCB4PSI1MS42IiB3aWR0aD0iMTcuMiIgaGVpZ2h0PSIyMDAiIGZpbGw9'
    b'IiMwMDAxODQiLz4KPC9zdmc+Cg==', 'RU_VGG')

RU_VGG = b64_RU_VGG
index.append("RU_VGG")
index.append("Russia Volgogradskaya oblast")
catalog["RU_VGG"] = RU_VGG
catalog["Russia Volgogradskaya oblast"] = RU_VGG
country["Russia Volgogradskaya oblast"] = ('RU_VGG', '', 1)
lookup["RU_VGG"] = ('RU_VGG', '', 'Russia Volgogradskaya oblast', 1)
lookup["Volgograd"] = ('RU_VGG', '', 'Russia Volgogradskaya oblast', 1)
lookup["Russia Volgogradskaya oblast"] = ('RU_VGG', '', 'Russia Volgogradskaya oblast', 1)
details["RU_VGG"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Volgograd"}
regional["RU_VGG"] = ('RU_VGG', 'Russia Volgogradskaya oblast', 1)
regional["Russia Volgogradskaya oblast"] = ('RU_VGG', 'Russia Volgogradskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_VLA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjMyMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1ZsYWRpbWlyX09ibGFzdC5zdmcucG5nIgogICB4bWxu'
    b'czppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2Fw'
    b'ZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQv'
    b'RFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcv'
    b'MTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4'
    b'bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlk'
    b'PSJkZWZzMTYzMjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZp'
    b'ZXcxNjMyNCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2'
    b'NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFk'
    b'b3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpw'
    b'YWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJs'
    b'YXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNjMyOCI+CiAg'
    b'ICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAg'
    b'IHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVy'
    b'aW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5n'
    b'O2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFB'
    b'QUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFB'
    b'QWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQVUK'
    b'VUVsRVFWUjQydTJkZVh4VTVibkhmK2VjT2JNbGs4eE1scG5zR3lGa0Q0UXNCQlJRVUFRVlZM'
    b'UnFyVmF0V3JXMXR0ZVdXbXUxcmJXdApWdXUxTHJqUXVoUlVSQlJFTUFJaXNpWWtJVEg3dnM1'
    b'a1pqS1RaRExibVRuTGUvOGdVRzR2OWw2UiszRkN6L2V2K2VTODUzenlQdCs4CjV6enZNKzk1'
    b'UStWdGt2RFZ5Ujg2K3VpYjEwTW1ES0RsRU1nS1pjSllvWnJ4eXdHYThhUHdob3puUzR5SDVU'
    b'RE5KSVhSN1BnUDVqeGEKRmJkYnpRUTRVZnQyL3oxTHpCK3RLL2dQaGhMa1lNMEFoWHFsYThQ'
    b'QzVYZm4vT2FWcWt0L1czSTdUVWtFMUROdHZ3UHdsL0tyV1Rvawp4eXVzRlJxVXpnMVZ5M09q'
    b'andQWU1uakh6eHZlbE1qMDBUKzFQaEdydGoxU2ZMY2NyL0JWU0lFOFgzSGxuT2hHQUFSVWpN'
    b'cE9VK0twClJpSmhIbTFjdnliMXRhWG03WExJd2xRaEFmV1hqdDl3b3VidmZmYzkxUERYeGFZ'
    b'ZHoxV3NVVEhjcVhadDdubE40d3Z1bmZOck9XVGgKaHVMVXB5Tmp5NjdiZjZ6UGswdEFxUmp1'
    b'VjhYM1BGdCs5WTlxMytORXpZa0d0YzRsZDg1K1BFRXpOQnBJbFFNWHB1bE1yeWVQZ0FLdwpl'
    b'ZUN1M3pjL3N5ais0L1dWSzdVSzc0bWprN3dSUUp4NlZJN2F6SmdYYnV6NzRSOWJuaXFMM2Ir'
    b'K2N0VUppekhLTVFEMlFMSWN0Umt6CnRYK2o5OGN2ZFA2cU5PYkFTNVVybzVYanl4UGVHdy9H'
    b'TzdoRU9XcmhxOUNnZE40eTYrbU5GeXhLaWVnOThaUG5PeDU5cGZ2QmVURUgKdHkwdFRJM3Nl'
    b'YXYvN2hOM1dwbHdUR2MwQ3QrTGxaZEhzQjVYMExSNWNmbm1nYnVxTFd1bkJIM2plS1Uxa0ph'
    b'b0dlUkU3ZGJCMitTUQpoYW5DbElqZVo4dXZBWERyd2IxZUlmcUIvSi9la3ZYMDk3TC9jS3Fk'
    b'TFpCaTFndy9XM0gxSFllcjNieFJEbHo0UU9WdGt0Uk1vSHA1CmxvTGliemh3Wk1nNzY4U0Jl'
    b'TFYxUmRMbUJNM3dGQjlkNTFwYzc3cmdzYm0zcjA1NWZiZjFtdnVQdlN0LzVSdGVvMUFnaWtP'
    b'T1N6YjEKM1h2S0h3QUhsL2hHNy8ybk4zMzQrS3ZPb09uVDBkVnkxTUpQb2NUK291RzEvN1dw'
    b'U0ppblcvOGdoMndtVFNwa1pJVXlza0laV2FHcwpVRVpXR01ZMEdyME45dzNYRzcyeXdwa0ty'
    b'eGNScEhpRElDdWNTWGhFcVYwVDZBM3l3NElRRENBalR4SUVXQVNoSjhpM2F3SmVTWnFKCm5W'
    b'TDhtOGp6UVRwWTVpeTdrWXNIOW42R2hHaGF1eXY2aTJab0EwemZiYlpobDdScUJmeEIxTHly'
    b'cnF5TmpTQzBQQXJEQ3drNGVKRjkKM3ZWY1docTRJRXp4S0Zza0thNXpiOTBPNWlyM2dpV1My'
    b'WVJnQ0prWnlGL0xIVmx1RjRsOEl3MHpldFZjOW1MZWJFWmJCeVFKb2dpNwpBL09xcElsSmxD'
    b'NlNiSFpJRWtJaHRIY2lPUkVaVlh4UFJFQldHRjZNSjNJTWcrRVJlTDB3R3FCU1lXQVFBNFBJ'
    b'ekpqK29GYkRvSWZQCmg2RVJLQlNZVE9Ka2hlRkYvTEFtR0FSRm9hY1B0WFZRS0hEb0NEN2Vq'
    b'VHR1UmZVZUhEZ0Vsa1Z0SGJwN3dUQUloUkE3ckpFVmZtUFkKd1IrOTJFR0FFRWkvZW5vd3VT'
    b'SkR3U0MrYUliZmorNWVESTlBb2NEWUdObzdZTE5EcmNid0NIcjY0UE9oc1FuQklDYTBQQUNS'
    b'b0VmTgpBYkFwUTdXVnpvblQxa2JMR2VuL0YwNVdVUDlwdEZpTjR5a1dlMEM2N3o2eWF6TVQv'
    b'N3c1YzFMVE9qYjUzamFTWUVacUNwcGJNV0pCCmZpN3NEdWdpMGRLR2lVbGtwS0d0QTZNMjNI'
    b'SXRWVENwR1RBR0RBODc1MldRTjE1azVsVktoWWxrcERJWThVeWlNdnlXRHAxWG85Q1MKNkkv'
    b'UVljU0NXZlBGOUN6eTFEM3F4Qnl4b2NJVlVJc3ByNXFMQzVDZWlwNWVNQXdLODlIUmhUMzcw'
    b'TldEZ2p5SUlob2FrWmFLdVVXSQozeER2aU9BbjFvejdwcWdYMXFubVhTaEd4WkRPYmhRdkZI'
    b'MGtIRlBWODBwaHdNaXpMTFJhYUxVb0tZTFN5N1ExMGFVM2NqbHYyR0VVCnhINVdsRkJTQkpV'
    b'U3VUbjQzbmVSbVlGMVA4RU4xOEZvUU9sY0pDY2kwTXQ2OC8zTHRvMUZwWXFEUnhYeDJZSXBI'
    b'bm85c3JOZ3M4RVIKSFk1cHp2bHdJK1ZBN05wUW1sOUZVeGl4Z0tiQjh6anc1NGlzM2tqMkpy'
    b'L0ZpcjQ2aFRmWm44V3oza2plNzhmQUVIcjdFV09FVm92MQpyOExwZ2lTaE1CK3pzNUZ0VURD'
    b'bDNHdFBLVElxQk1Fb1hQQm00a0RLcUQ1TERBYWhqd1lqMEFDNklyalpQcldzOE56bEwwcCs2'
    b'ajc3CmxCZGpQRUw5YkRDQXlYSEswa0lYMVJoclprMHdueXVESUtKS2tySUR4RXVURUtWaHNH'
    b'SXBWQ3BRQUFFb0NwSUVub2ZmaThGZVJLYUcKYkFIQ0JKaUJmU29XcUpreldmQ0t5ZjNncUdj'
    b'S3ZrbFljenpqYzUxWkJkTFJnMnpsMWdSWjRia2hKSkVGU3lYWE9FWXNHS1Y1VVlTNwpqMG5P'
    b'a1RwdkhVMk5KYXV1RlFIVTFxZFk3UVZyVnU0Ni9VUkJnT0lNdlJkUDFuTUFZT2Uya0UvMFQz'
    b'WW9oQ2pSRDVLd2pFdk5JSkdSClVDNFJzRlYrRnA2VElhZ0tpVDl6K0h3WUdFUjJGaFFpWld0'
    b'VExMeEtpRFJMNlNXQ2lPbnNReGRwWjVqcEtjR1VCKzFkdXM0ZTlkODIKM2ZEYXBrdUdSNWo2'
    b'NHpxZVAvUDFDWVgwZkNtbGtzOHBscFFjUS9scGp4ZUVJRUpIbW02eGhra2RibVlybkRLR0Zs'
    b'NGsxUjhISVJoegpvbUNSR0pjamRuVkR5YUs0R0pLU0FEajk2d2RKUW9RV3V6KzhvMmQ0aXlk'
    b'eUFSTjd5L0dPclllcXIyRFpNMStmVWhLakFUNGZ2RDZvCnpHSnVoWmlVaUlPSE1lYkM0cXNF'
    b'bmdvTGgwemNOWStjVGIzRFBiTGtpeTNmK0c4ZjQxVisyaVRtTGcvbDUySE1pU08xaUkrSFpS'
    b'U1MKaEJBUHp4VGxjcWZ0K09UYnJSMUpoQ3I3N0lDaXRYUHgvSkxHRVNjUng3TjBIRVNyUTZQ'
    b'UnBPUnNTRStiT3VQMXUzdlEzb25VWkF3TQpnbUxnY0NBcUNoVmw0SHhVeHc5alRVR2wvQ3c4'
    b'QjVRMUdYM2YxMjlQOGlndjlVWkdpQ3N2eFlGRG1MQlJyZStxNHVmekN5c0dGMWE4CjBONnA3'
    b'Qm53M0hiRG51bnA0OGhSSlpreTZLR0k1TGJ1VUQyNGJ1VExMazV4dE1KRk40eExLeStYVXBM'
    b'eHhpYlV2cU5zYll5WTU5SmwKeXhucE9jRk5pd1BYT2JRcFltNFNPYmFiR1dmaGRDRWpIY0Z4'
    b'S21aZnpPUjgyLzg4NWVCaFJFWEI2V296NmVBUElITVdkbjJDN0ZsZgpvaEJRYnpGZS9KSkRF'
    b'TkRWamFGaG1DUEloZXNuRHUrWjRwcFY1WWRqS1ZuaDEwMUgxV0pTaVpDZVRWNThCYmx6QkFP'
    b'TjUxL0NJNzlBCmNwTDA5MGFuNFV5bk5EUmlVUlY0Zmpvak5SclExQXhKQWsyRDQ3RCtWWURD'
    b'N0d5b1dKU1hBVURrdXJGWnN5QkorTUZQY05GaTJPejgKdXgvZ3B1dkZBMklRNGJHbjBzeE9a'
    b'K0w4eW81M05PTVR1UGN1S0JSUXNWaStkUHFRS3ZiTXF5Z2tBcjhmdXo5RlN4dWFtdkhDeTVp'
    b'WQpRUDhBQUd6L0NCY3NoRnFGa2tMd0FscGFBY0FRUndEUU5FcUxRRk5JVDhNMXE5SGZEMnFi'
    b'UGt5cXBUTyt3QlpaR0JKRkhEcUNraUk0CmgrbXFCUUFRQ29IZXFUdGplNVVTd1JBSzgyR3hJ'
    b'aUlDTEl2VUZPejlEQUI2KzFFNkY1S0VsemJBN29EUER3QXQ3MHgvOFhUakRmQk4KMERGR0hE'
    b'aU1sQlM0NDRMeXZQQWN3Qk5pVEpFeU01QmlwajcrbyticUc2ZEgzcGIzb2ZqdXhLbVUvL0Vu'
    b'aGRxYVF4d0hBR28xQWdIdwpQQXJ6TVNzVGFhbTRlalVNZWdBSUJrRUk3cmtUYzR2aEdzZXlw'
    b'WkFvWXJxWXE2a0RBSTBHcy9Pa3BvM3FvandZOUtCVGVGbmgxMFVrCk9MN0NZYWxqTjkwYzVi'
    b'QWgvWExPRkE4QXgrb1I0dUVhbzhqSnFUM0hrY3B5M3p0YnNQRnQ4RHcrM1ErZERzTWpzRHRn'
    b'ZDJERDYxQXEKQVNER2lKcGpBTERtQ3R4Lzc4bU1hWXEwdGNNeEJnQVZGYUJ6ZzBjL3B6ZCtL'
    b'MXFwSVhYRjQ3TENyOFVZeTVkL081aTVQS2dzQ0k3dQoxSlpYRWdERHcyaHRvbWJQUW1hK0pK'
    b'NmNlai84YzdhMm9haTdGM1VOS0oyTEJEUFcvUkk3cTNINEtJN1VvTGNQaTZvQTRLSWxPSFIw'
    b'CnVoUkEwd0FnTWNSa2drYU5EN2JRb2dnQWlTbFE3TkVsMytyUkZZZmlWL3RraFdkUGtKQ3VE'
    b'STlhQllxQ3NTeW90ck5qVGxpczJQMDYKaTNIR05ZNzBWQkRGdEVLV3hmeFM4Mk9QNExaYlVO'
    b'K0E3VHR3ejUxNGFCMThmbGlzMkx3VmRRMEFrSitMbkd3OC9TeUVrOHVES1FaNgpQWklTZ2NQ'
    b'YTNkWFU4QWg4azVSb0ZLY2txVEFmaGpoeVhPT1hGWjRsZmZyQXQxL3l2dnMrcktQSXprYmNY'
    b'ZTZCUVNRbElqRlgxS2VKCkpVVVk3S1VVL01udHlRamEyNXEzYmtOREk5UWFQUHdnOG5QUjNZ'
    b'UDFyK0x5eTNEeEV1ellPWDNaeXk4RHE4UmJtMDg5YktsZ0FJa0oKSUJtaHdtS1NrZ3hkckpS'
    b'NnJTODVDWHMvUTBjUFNsOTJmdU9WMHBrNkw1emoxbTU4VUgzdjc3bmFlZ1NEVUtvd1pxVUFR'
    b'cUlrUnplMQo1MTBGZXpqQ2NOMzAreExCSVBoUW9Ma1ZrMjVFUjZGNk43dyt0TGJqZ2lwVWxN'
    b'SHZ4OFFrV3R1Um53c0FzMmVocHZaaytWR2lqbTVRCng1U0VkRGs4UlFOQVN3TlZlUUZScVpB'
    b'M0I4bEpPUHBqUXdFbEt6d3JLS0QwV015SE4vbEJFZmYxVS9iOUtpb24xTjBqRWdraWpYbUwK'
    b'aGRFa0QwNnVjMUdya1Y5WXR2cXkzZFRKY0k5WThOeEw4SHJoR0lQZkQzMDBEdGRNMzBzRkFj'
    b'SnBDNTFXUEJBWUdvSmxGSFlIV3R1ZwptVkJhV2tTUGhZNXMxUTRScXNpcWs2c3paMCtFeEJS'
    b'YmRRQTZYMUVnM3h2emRzeUhRV2RjRXRFYmljY0xUWXprZGY5amdEQU1SWjAyClhKS1RzSFlO'
    b'OWgvRWduSjBkbU55RXVaNGZMZ1RqeitKOUZTTU9VL2VSeGtTR1FsQ2dXWFIxRWo1UnVtNFF6'
    b'cDN3SmZkRkcwT2p4bzMKem9NeXR3UkUrMWwyV1ZCenhWaFJHcWs3UmptY1NFL0RnQTBSMm4v'
    b'MW1Kby9EMDRYQkFFNTJkQm9VRnlJWlV2eDFydlFSK1BxazV0NgpxRFRrODROSVRrSjNEeXJu'
    b'dzFRaWlwYzRhejVrVlNJdGhVMGVNYk9uOXZXbDQxTi9Ic3IvWU5RUVMrYk5KMVliVXRKSWJn'
    b'NUtpcENmCkJ5bjByeDVUTmNkZ05PRENSY2pNUUZNek9BNHFGZm9IY09teTAwb0hJUlFYd1dq'
    b'RXhVdVJtVVdjRTBoS1JzVnFQbTJ6ZGZEbkk2MFoKSGxuaDEwVzNLTkRWajFmK0JxMFdQQStM'
    b'RlRFeDZLcFcxZFVoTmdZSzhVdDdSd2oyZm9iQ2ZFeTY4ZnBHckx3VVdpMysvQndhdjBCRQp4'
    b'T25sSDhvVWo4YjlqSDJBRHZFWXRTRVloTjJCelZzQnJlUlA0V1NGWC9zeDhGZGpWakoxMC9W'
    b'Z1diUzJ3MndDa1VBbDhlWGwwR2hBCnZuelpKOGVCWWFCVVluZ0UxWHZRK0FXQ1FVUm9jZUdp'
    b'Zjg2YURIb3NYQ0dPT0lndUVta3AwMjlpckx3VThORkYrMk5saFYrWFRJK20KNzIwdHo4Tm14'
    b'NUlMME5kQ3R6VFFsVlZFcFlKQmozL3hsaUFYeE1BQWp0V2pyUjJyVjJGaUVqd1Bwd3Q5ZmRq'
    b'KzBUK0hKelVWQnBadQpxS1ZFZ1NxZmo5NCtVQlJDTHhsVkZDVXJQQWRsMHFvSGZKM2RxS3JB'
    b'dGsxTTZqdHhVRW1sWlFSQWV6dUkvMHREYk5EanljZXgrMU1jCk9ZYUZDeENsd3dzdlk4NXNG'
    b'QlVpSy9NZnpRUWY1ZmNEd0hmdUVRY2FGYmJubzJzT1VXV2xHQnFCOHZZSk9TTTlGN05EQ2oy'
    b'ZFZHaU0KZnU5dTdieDJROTB5eHkzWEFrQWdnS2FIOU1NNTAxTjdKU3N4ak92VVdlT1RPSG9V'
    b'VXg3WTdIam1DWnhZKzdUOElyakdzVzgvaGtlbQo1L2dBaGx1WWR4cVZ0LzZlQTNEYnovaWR0'
    b'MEwxVU9MTzhvbkVTN21KUVNaRHpralBHaThsdGtYNVdtTjlJNnFnNlpGa2h3TWxiWWI2Cmhj'
    b'NmJmOGNCa0NTOHRVNGI0V1hYM2lsczNRWkNrSlVwckZ4V2YrcjBnUUVjT29yNlJuenJHcHhh'
    b'dTZaUWdHV1JtSWllNmQxMDhkSEgKS0xoSXlQc2s5b1BYR1FDNlNLellNRGthSHpEWFJmZlVL'
    b'dVp1TVhmcS9NMW1UNStLQzRISW8vQXIwSmJraWJyZEhSTWx1ZDJJUzhheApqeFhwK1ZMMS9v'
    b'a0YxL24zN1lkYWcrUFZpb1ZIWWx5czRIWWpHTVFISDhMbG9KUTAxSUhwemlxMTVPSktLU05I'
    b'eXNqQXdBRDZPbWozCktNMzdLVkZDeHdCSnpSZGVmb1V5SlJDV2hjdEs1VEkwOTRKNXM4cWFt'
    b'RW9FRWNvN0o1cmYwQ2FtQ2kwL0dNa3BrVVlzTU9qUjNjSVkKMzR4TDRKU3l3djhyY1luU3dB'
    b'aWlvc0N5V0xwVzJGTk5aZDNsbVhSamVBUUlVU0tGdlpkYjAxSmhxYUhUOHlRRmk1NCtrcWhV'
    b'Rkx5ZQpBS0EvT3NDdG5SajllNlM2TTJySFpiWjV1OHhtaWphZHJNWGxFbUpkUGp4aUpUb2RS'
    b'QjRUYnVyNEhaWXhLNWcrMnVtVzFGcGlOaEhUCkdwL0lVeFdMU0lpZkxzN0ZwRXJmNEpMU21h'
    b'Y3d6NkliZWtCWjhMSjl4eTdNemthVWhpTE5tc3pGZnBzTnExYWdyWU9VenhjWUJuVTEKbERT'
    b'RzhUR0sxUko3SHgyYlE1cExKaVNCcXZyVlZGbzZKcjQxVlhlbGRzbXV4QWxXR0gvY29vOGxB'
    b'KzNNWkxWV012T1VuV28rU3VmbQppR05EZEhTYWFJeW1ydmtPR1ovQXNYcVV6OGVlZlpoYmhE'
    b'MS8xS2lYKzdkdVIyNE91Q2xLOSt0RW5jaklDcjhDbGh4UENvOEZGVkFyCnFNNG5vcGYyUmRu'
    b'c3cybHBwSG9QRmk1QVp4ZXNGa3gwS1lSWVBpTUcrUVdvcXBSNEh1OHBQVmVzbkU1MmFCcmpa'
    b'aTVwUUduVkJSZGsKRXFNUkJRVmlZNDZIWlpGZ3hxclY0cmdMRm92azljTlN5N3FtUXZGeFNF'
    b'dkZyazl3MVpYNDREbmxKWjJ4MVk4NWIzakkzOU9IbENUUwpGQkdjTTZXVkZYNEY0Z2UweC82'
    b'VEFvV1VGbDFoVU9rU3hmUXNjdVFRbFo5TFJtMVFxMkJLUUx5SlAvRmQvQ2xpWTVDY2hPRVJP'
    b'TVl3CmFvTnlyWHRJNjA2UEpYR3hjSTFERndtekNTY21sQ2RtSFZsWmtDUnNZVUptRTdSYTlQ'
    b'U2lmRDUyZlVURjV3bllqc3E2Mk9NM2M2NzUKVTBNdVJaYnZteXg1ejBpRldTNXRsdXNmZi9W'
    b'R2hxbjVpZDZYR0l3c0NkUWZ4NElLMk95NGNCSHE2Nmc0RXpIRm83MFRmZjNvNnNhVQpCekZH'
    b'V0t5Z0tGUXRJVDRmekNac2ZSOUtOWFE2bUUxNDZsbmtaS080RUVZRFJxemdmTlRWVjVKdE94'
    b'QWJBNmNMK2tpS2UxK25GS2FECmx1VlJaKzM3NWw4MFBCL2U4cVdBWWt0VVJvTStOaGFyVjZG'
    b'OUx4dGNienkyTE1GNWZ6d1h3RnNMNHhMTWlJeEVXU202dWhEZ3dERGcKQXBoMFE1SkFVU2la'
    b'aXpWWHdPRUFnTXdNR1BUb2FLSGV2c293TlU2eGQ2WjhmRkU4LzZyQmE2ZXZYQVVhcUJ6UzUx'
    b'a2p3NnZLaVBPRgpXRkh4K2ZlTWtTSXp6elc5OHBPRVlMc3BVYlhXMmRLR2pGVFUvenA2TUQ2'
    b'WThVdnVrMjEwWGdrNThMS0sxd3ZhZE1IZW9oZ3FseGdOCk9meWNockJrOXUwQnM0azRETVQv'
    b'dzRRSUlKTlRnMVBqQ2QyK056MEtIeE1UaG9YaTgwYWhDbFNoSS9LZlJtY3NGSTRZU2N0U3RZ'
    b'OUYKenUySzVqdkphMyt3M2Z4VHZ2VUxpdTFXVlZuajJ4STlzOWRNUVlMd1pGeTVSdzJnTHNK'
    b'ZWRuMVFpT0hqK3Y5YmNBcEdkZUhaOGZOLwpHejNtTFFQREtlY0tqRVBKdTcvditOSDE0bHUv'
    b'VmVYc2lpc0REU0RQcXNNTHVyclprOHMzT3ZhK3FNcjlPSDcrTHRQd1o4RWtmc1k4CllxaThU'
    b'V2V6ZytOTS9GY2pQa2x5S1FSQkxXWDZ6NUNEN0N0d1Jmc1ZpaUcyU05ET3JINzl1MnhtQ1ND'
    b'Q3BpTWtKYjVrNGVmU2xwZ1oKMmk5NWIrNFpqNnhRVmlnaks1U1JGY29LWldTRk1ySkNHVm1o'
    b'ckZCR1ZpZ2pLNVNSRmNvS1pXU0ZNckpDR1ZtaHJGQkdWaWdqSzVTUgpGY29LWldTRk1ySkNt'
    b'YlBpdndEMjhyaWt1dmhCUUFBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNaTB4TVMw'
    b'eE9WUXlNVG95Ck56b3pPU3N3TURvd01GZkxMRkVBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1'
    b'QURJd01qSXRNVEV0TVRsVU1qRTZNamM2TXprck1EQTYKTURBbWxwVHRBQUFBQUVsRlRrU3VR'
    b'bUNDCiIKICAgICAgIGlkPSJpbWFnZTE2MzMwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'RU_VLA')

RU_VLA = b64_RU_VLA
index.append("RU_VLA")
index.append("Russia Vladimirskaya oblast")
catalog["RU_VLA"] = RU_VLA
catalog["Russia Vladimirskaya oblast"] = RU_VLA
country["Russia Vladimirskaya oblast"] = ('RU_VLA', '', 1)
lookup["RU_VLA"] = ('RU_VLA', '', 'Russia Vladimirskaya oblast', 1)
lookup["Valdimir"] = ('RU_VLA', '', 'Russia Vladimirskaya oblast', 1)
lookup["Russia Vladimirskaya oblast"] = ('RU_VLA', '', 'Russia Vladimirskaya oblast', 1)
details["RU_VLA"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Valdimir"}
regional["RU_VLA"] = ('RU_VLA', 'Russia Vladimirskaya oblast', 1)
regional["Russia Vladimirskaya oblast"] = ('RU_VLA', 'Russia Vladimirskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_VLG = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxODAyIiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1ZvbG9nZGFfb2JsYXN0LnN2Zy5wbmciIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlu'
    b'a3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIiB4bWxuczpzb2RpcG9kaT0iaHR0cDov'
    b'L3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiIHhtbG5zOnhs'
    b'aW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB4bWxucz0iaHR0cDovL3d3dy53'
    b'My5vcmcvMjAwMC9zdmciIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzIGlkPSJkZWZzMTgwNiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3IGlkPSJu'
    b'YW1lZHZpZXcxODA0IiBwYWdlY29sb3I9IiNmZmZmZmYiIGJvcmRlcmNvbG9yPSIjNjY2NjY2'
    b'IiBib3JkZXJvcGFjaXR5PSIxLjAiIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiIGlua3NjYXBl'
    b'OnBhZ2VvcGFjaXR5PSIwLjAiIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAg'
    b'PGcgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIgaW5rc2NhcGU6bGFiZWw9IkltYWdlIiBp'
    b'ZD0iZzE4MDgiPgogICAgPGltYWdlIHdpZHRoPSIxMjAiIGhlaWdodD0iODAiIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFs'
    b'aXR5IiB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFB'
    b'TlNVaEVVZ0FBQUhnQUFBQlFDQUlBQUFCZCtTYmVBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFB'
    b'Q0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3Vs'
    b'RThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFGCndVbEVRVlI0MnUzYmFVd1VaeGdIOFAv'
    b'c2ZiSHNjc2l5M0I2QUlCNmd0QlZ0TFBWRENiRUdiR09pclcyeFh1bWhNYVExaGxTZ0ttcGkK'
    b'WWt5YU5ERk5UZjFrNnBWbzI5U2pXREVVVTRoVXJDS0xDOGh5THJCSEI5amQyWm5wQjJrVlhL'
    b'eXNhNVBXNTUvOU1qc3o3NGZmdlB1Kwo3ek16eTRpaUNNcGp3akFoYVVaQ2t2OU9DSnFnQ1pv'
    b'U1JHUVR0bitwckZSWXJTRzdqQysvdktDa2hKUURRS3RyYTN1aW96T3VYVXV5CldBS2VJRERn'
    b'ZEdEeXdWZEQ3ZjZIMWhzakk0bDQwcUVqZkhTMGNkKys1amx6SHQzRjZ2SDFacHpmaXkvamNQ'
    b'NXpuSGdISEkwOVFVTXYKUEgxYWJyWGVLaXZyVGttWnNPdG1EbmdUL0NJRUl6Z2VQUW5vandy'
    b'Y0xnL2NMQ29hVUt1SmVGSm9oU0RrVlZUSVBaNzYzYnZ0VVE4Zwp6NlJ0WU9yVEdUdjZiME0r'
    b'aEI0TGRIMjQwVjlRbC83NmhCWmNPdDFQVzdZTWJ0MHFFdlRqVngzaExKdGRWaVpWcSt1cXFs'
    b'eGFMWUNtCitDVjYxV2lEOEZwYTkvSmlOOTRXc2NvaFRleGQxU1ZMYkRIbHNDckR3NmUzTFZ1'
    b'bVdMMmFjQjgzR2Y2ZE9Kdk50V2RQVzNsNVRYbjUKOHAwN3MyeFhZYnVhRCtEVTJBRjY4R2Fj'
    b'QklETDQwNTBHd3hEOGZGU29uM3lkWFJHUTBQWTBhT1NqSXlmUzB2NWgwcitld1Z3WEVSWAph'
    b'b0JUZXFkUGJ5Z3ZIeWtzSk5tcEZTeExUNTVVVlZkeml4ZGZXTFBtL2pmZG1XQ1h3c2FDZnhk'
    b'MnpmaVZIM0JuMHliSi9QbE1pRzdFClBFZlFESkIzNkpDa3BVVmN1N1orNVVvQWpBb3dRaFFo'
    b'TVVPVVRGajg2VDNKeVFBNGp1TTRqbkNuVm9Jci9mNlhLaXA4ZHJ0OTQ4YW0KM056b0JpaE9v'
    b'ODhCdmhKUjdMZ2o3K2JscVdKaUFCZ01CcFpsQ1hmSzl6cU1idmY4WGJ2OFhxL2w0NDhzMjVV'
    b'RDZ5Q1ZNdDU5cUg4VApub2RtVTFsbnA4RHpBQmlHOFhnOGhEdGxhQUJKN2UybXd3Zk1ub096'
    b'TjNobGFraWtpRXJFcittNHZPbEJjV2kyMlFTZkQ0REw1VEtaClRJUWJERFFBVTBiZDNKeEdo'
    b'eHQrUHhncFBGNGttOUZxUk92U3NRTWluYzZJcWlxWHl5VUlBczJIVDdxT2ZqUWRMekE5YlF3'
    b'dmlKeUEKTUEwc05zWVloZkFJcGtNbnlMSVFmZ25UYmlQYzZiU1BPS0FOSTlrZ2UzUmJHbndT'
    b'aUtJb1lhQlJnL2REcXdaRWNINlJqMkFHTXVFcwpSbzhlN3N3YjJXSHZhZm9hU1RiSUhwMXlC'
    b'MTB1TVdzT05DcDRmQ3FWd3VOd283VUR0KzVDTFNCZUMrTVMvTTVnWVJGc3ZhSy82eUl6CjYx'
    b'WENEWExvaVBvUlB6QnhDZWtsT2tPYXUrMmdOcnBveVBXWlZJcEZVVHN1WFc1S2NueWZzbGhr'
    b'R0loQXRON2FML0FTQ2RYaFFVMkcKMm50WlNmR2Z4TTE2eThrcVJOMEtZK3dydGw0czBpbFQ4'
    b'L01MZGxRNkIwV3RCdllodE5tUVdkQW52YmlCVm5oQjl1aUUzNW9NQjArMAo3a3ljbGpCVHFa'
    b'bzlNdXdyVEQxZ1lqOUY5UnQ2MmZKT04yUlNDQXhhYmtHd00ycS9sdWQ1ZWlvUUREU0FzQ3Mx'
    b'eXBrMXcza3JFTHZSCm1Ebzd2R0R6MERlbklqUjFxb2hUTHphamN4c0dabVRPMjNKWUVFVzMy'
    b'eDJoMWZvSU9EaG9BREUxWU5Wblk3NDZLL2RnVUk3aEl3aFQKUW0zQXZBL2dkU0YyYjIvcis1'
    b'eE1wYUlYb0lJZm84ZXFFZ3VTdm9ES0F5a3dqVVBFaC9DdnhSODJlTlBoRzBIODRLRDh3Z1VB'
    b'Q29XQwpjSjhLZWtMQ1dhaWxrRTBIZHc5Q0RpUUtMRGh5WkxTMjF1ZnorZjErOGcxKzZBZ1FE'
    b'cHBDYUF3WXpRQjgwUG5ja2YzOVRIYTIzVzZuCmx3MUMxcVBINGdEYW9QNXViQ3Z1ekJtRlhC'
    b'NGJHenZpOVJKeFNLSEh4OXplcnI1eUJZQkdxU1RpMEEwZGdUSjMvMzZiMVdwTlRDVGkKU1hw'
    b'MGlQcWd4dU5KUFhiTUpBaEVIQmphbjVzYnFnV3dXeTVYNWVVUjhmMHdFeW9ManVNYXRtMVRu'
    b'anNuT0owQkw4c01sdFgvMVUvNwo1SExiSk84aVNjMW1mdjM2bk5MUy83NVFpSjVnaUZPSklB'
    b'aVc2OWRyaTR0SEpKS2E3ZHU3T3pyRS8zMkFrSHlZSUdybDBlSGhiMHRLCjFoMC8vbno4NXBs'
    b'bk1uUThZZHFibTVQVDB3bjZtVU0vVDdNWS9mMk5La01LUVJNMFFWTUltcUFwQkUzUUJFMGhh'
    b'SUttRURSQkV6U0YKb0FtYVF0QUVUZEFVZ2lab0NrRVRORUZUQ0pxZ0tRUk4wQVJOSVdpQ3Bo'
    b'QTBRUk0waGFBSm1rTFFCRTNRbEtmTG45VVJLL1hsU3JDNwpBQUFBSlhSRldIUmtZWFJsT21O'
    b'eVpXRjBaUUF5TURJekxUQTNMVEF6VkRBMU9qUTNPakF4S3pBd09qQXd2MDhrVndBQUFDVjBS'
    b'VmgwClpHRjBaVHB0YjJScFpua0FNakF5TXkwd055MHdNMVF3TlRvME56b3dNU3N3TURvd01N'
    b'NFNuT3NBQUFBQVNVVk9SSzVDWUlJPQoiIGlkPSJpbWFnZTE4MTAiIC8+CiAgPC9nPgo8L3N2'
    b'Zz4K', 'RU_VLG')

RU_VLG = b64_RU_VLG
index.append("RU_VLG")
index.append("Russia Vologodskaya oblast")
catalog["RU_VLG"] = RU_VLG
catalog["Russia Vologodskaya oblast"] = RU_VLG
country["Russia Vologodskaya oblast"] = ('RU_VLG', '', 1)
lookup["RU_VLG"] = ('RU_VLG', '', 'Russia Vologodskaya oblast', 1)
lookup["Vologda"] = ('RU_VLG', '', 'Russia Vologodskaya oblast', 1)
lookup["Russia Vologodskaya oblast"] = ('RU_VLG', '', 'Russia Vologodskaya oblast', 1)
details["RU_VLG"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Vologda"}
regional["RU_VLG"] = ('RU_VLG', 'Russia Vologodskaya oblast', 1)
regional["Russia Vologodskaya oblast"] = ('RU_VLG', 'Russia Vologodskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_VOR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iODAw'
    b'IiBoZWlnaHQ9IjUzMy4zMyIgdmVyc2lvbj0iMS4wIiB4bWxucz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMjAwMC9zdmciPgogPGRlZnM+CiAgPGNsaXBQYXRoIGlkPSJuIj4KICAgPHBhdGggZD0i'
    b'bTMxOS4yMSA1NTcuNThjNi40MjMtNDUuMTY2IDEzLjkyMy05MC41ODUtMjQuMjQ0LTEyNS4y'
    b'Ni00Ni43NjIgOS40Njk1LTI4MC43OCA0LjQxNTMtMjY5LjcxIDEyMC4yMWwyOTMuOTUgNS4w'
    b'NTA4eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5k'
    b'IiBzdHJva2Utd2lkdGg9IjQiLz4KICA8L2NsaXBQYXRoPgogIDxjbGlwUGF0aCBpZD0ibSI+'
    b'CiAgIDxwYXRoIGQ9Im0zMTkuMjEgNTU3LjU4YzYuNDIzLTQ1LjE2NiAxMy45MjMtOTAuNTg1'
    b'LTI0LjI0NC0xMjUuMjYtNDYuNzYyIDkuNDY5NS0yODAuNzggNC40MTUzLTI2OS43MSAxMjAu'
    b'MjFsMjkzLjk1IDUuMDUwOHoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxp'
    b'bmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ii8+CiAgPC9jbGlwUGF0aD4KICA8Y2xp'
    b'cFBhdGggaWQ9ImwiPgogICA8cGF0aCBkPSJtMjg3Ljg5IDQ2MC42YzYuNDIzLTQ1LjE2Ni03'
    b'LjI5MDUtODUuNTM0LTUyLjUyOC0xMTAuMTEtNDYuNzYyIDkuNDY5NS0xNDMuNCAzNi43NC0x'
    b'MjkuMyAxMzAuMzFsMTgxLjgzLTIwLjIwM3oiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ii8+CiAgPC9jbGlwUGF0'
    b'aD4KICA8Y2xpcFBhdGggaWQ9ImsiPgogICA8cGF0aCBkPSJtMjk3LjMyIDE4Ny42M2M2LjQy'
    b'My00NS4xNjYtNy4yOTA1LTg1LjUzNC01Mi41MjgtMTEwLjExLTQ2Ljc2MiA5LjQ2OTUtMTQz'
    b'LjQgMzYuNzQtMTI5LjMgMTMwLjMxbDE4MS44My0yMC4yMDN6IiBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iNCIvPgog'
    b'IDwvY2xpcFBhdGg+CiAgPGNsaXBQYXRoIGlkPSJqIj4KICAgPHBhdGggZD0ibTE4Ny44OSAz'
    b'OTIuOTJjLTM3LjgzMy02MS45NS0xOTkuNzgtNjIuNDk0LTIxOS4yLTQuMDQwNi0xLjE3NjEg'
    b'OTcuNzk5IDEuNTAyNiAxOTMuNTggMTExLjEyIDIzMy4zNWwxMDguMDktMjI5LjN6IiBmaWxs'
    b'PSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13'
    b'aWR0aD0iNCIvPgogIDwvY2xpcFBhdGg+CiAgPGNsaXBQYXRoIGlkPSJpIj4KICAgPHBhdGgg'
    b'ZD0ibTE4Ny44OSAzOTIuOTJjLTM3LjgzMy02MS45NS0xOTkuNzgtNjIuNDk0LTIxOS4yLTQu'
    b'MDQwNi0xLjE3NjEgOTcuNzk5IDEuNTAyNiAxOTMuNTggMTExLjEyIDIzMy4zNWwxMDguMDkt'
    b'MjI5LjN6IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91'
    b'bmQiIHN0cm9rZS13aWR0aD0iNCIvPgogIDwvY2xpcFBhdGg+CiAgPGNsaXBQYXRoIGlkPSJo'
    b'Ij4KICAgPHBhdGggZD0ibTI4LjI4NCAzNjIuNjJjLTguNTU3NS02NC44NDcgMTAyLjI2LTc0'
    b'Ljk0MyAxMjcuMjgtNzYuNzcyIDUxLjcwMS00LjU0ODcgODkuNjEgNy4wOTQgNzkuODAyIDc0'
    b'Ljc1MS02Mi41ODQgODAuMTM1LTEzNy4yOCAxMC45NDYtMjA3LjA4IDIuMDIwM3oiIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdp'
    b'ZHRoPSI0Ii8+CiAgPC9jbGlwUGF0aD4KICA8Y2xpcFBhdGggaWQ9ImciPgogICA8cGF0aCBk'
    b'PSJtMjguMjg0IDM2Mi42MmMtOC41NTc1LTY0Ljg0NyAxMDIuMjYtNzQuOTQzIDEyNy4yOC03'
    b'Ni43NzIgNTEuNzAxLTQuNTQ4NyA4OS42MSA3LjA5NCA3OS44MDIgNzQuNzUxLTYyLjU4NCA4'
    b'MC4xMzUtMTM3LjI4IDEwLjk0Ni0yMDcuMDggMi4wMjAzeiIgZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjQiLz4KICA8'
    b'L2NsaXBQYXRoPgogIDxjbGlwUGF0aCBpZD0iZiI+CiAgIDxwYXRoIGQ9Im05NC45NTQgMzEw'
    b'LjA5Yy0zNS45MjEtNDQuODE3LTc0LjYwMi0zNy4xNzYtMTEzLjE0LTMyLjMyNS05LjE0OTcg'
    b'NjUuMjk1LTMuNTM1MSAxMTYuNDQgNTEuNTE4IDEyMC4yMWw2MS42MTktODcuODgzeiIgZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Ut'
    b'd2lkdGg9IjQiLz4KICA8L2NsaXBQYXRoPgogIDxjbGlwUGF0aCBpZD0iZSI+CiAgIDxwYXRo'
    b'IGQ9Im05NC45NTQgMzEwLjA5Yy0zNS45MjEtNDQuODE3LTc0LjYwMi0zNy4xNzYtMTEzLjE0'
    b'LTMyLjMyNS05LjE0OTcgNjUuMjk1LTMuNTM1MSAxMTYuNDQgNTEuNTE4IDEyMC4yMWw2MS42'
    b'MTktODcuODgzeiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49'
    b'InJvdW5kIiBzdHJva2Utd2lkdGg9IjQiLz4KICA8L2NsaXBQYXRoPgogIDxjbGlwUGF0aCBp'
    b'ZD0iZCI+CiAgIDxwYXRoIGQ9Im0tMTcuMTczIDE0OC40N2MzNS43MjUtNDkuMzc4IDEwNC4w'
    b'NS0xMC43NjMgMTEyLjEzIDIwLjIwMyAxNi4wMjggMzEuMzA1IDExLjEgOTguMTggNDcuNDc3'
    b'IDEzNy4zOGwtMTc4LjggNDAuNDA2IDE5LjE5My0xOTcuOTl6IiBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iNCIvPgog'
    b'IDwvY2xpcFBhdGg+CiAgPGNsaXBQYXRoIGlkPSJjIj4KICAgPHBhdGggZD0ibS0xNy4xNzMg'
    b'MTQ4LjQ3YzM1LjcyNS00OS4zNzggMTA0LjA1LTEwLjc2MyAxMTIuMTMgMjAuMjAzIDE2LjAy'
    b'OCAzMS4zMDUgMTEuMSA5OC4xOCA0Ny40NzcgMTM3LjM4bC0xNzguOCA0MC40MDYgMTkuMTkz'
    b'LTE5Ny45OXoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJy'
    b'b3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ii8+CiAgPC9jbGlwUGF0aD4KICA8Y2xpcFBhdGggaWQ9'
    b'ImIiPgogICA8cGF0aCBkPSJtMTkzLjc5IDAuNjAyYzAuMTg2MDEtMTcuMDQ3LTExLjcwNy00'
    b'OC44MDEtMjMuNDYtNDkuMTczLTU0Ljg3NSAyLjk1NDgtODQuMzU1LTgzLjU3Ny04OC4yOTgt'
    b'MTAxLjg3LTAuMzU4MDctMTIuODgtMy42NDE5LTIzLjYyLTEyLjY3NC0zMC4xNTQgMS43NzM5'
    b'LTE3Ljc2NCAyMS43NDUtMzAuOTQ2IDMyLjIxNi0yOS43NiA1LjA3MzQgOS45MjY2IDE1LjE4'
    b'NCAxNC44MTYgMjcuODU3IDE3LjE0MyAxNy40NyA2LjY5NzUgOTguNDY3IDQ5LjA4MiA4Ny4x'
    b'NDMgMTAyLjg2LTEuNDMyIDExLjY3MiAyOC4xMjYgMjguMjg3IDQ1IDMwLjcxNC0zNC4yOTkg'
    b'MTAuMzI2LTU2LjMzOCAzMC44NjktNjcuNzg0IDYwLjI0eiIgZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjQiLz4KICA8'
    b'L2NsaXBQYXRoPgogIDxjbGlwUGF0aCBpZD0iYSI+CiAgIDxwYXRoIGQ9Im0xODQuMzYgMjcz'
    b'LjU3YzAuMTg2MDEtMTcuMDQ3LTExLjcwNy00OC44MDEtMjMuNDYtNDkuMTczLTU0Ljg3NSAy'
    b'Ljk1NDgtODQuMzU1LTgzLjU3Ny04OC4yOTgtMTAxLjg3LTAuMzU4MDctMTIuODgtMy42NDE5'
    b'LTIzLjYyLTEyLjY3NC0zMC4xNTQgMS43NzM5LTE3Ljc2NCAyMS43NDUtMzAuOTQ2IDMyLjIx'
    b'Ni0yOS43NiA1LjA3MzQgOS45MjY2IDE1LjE4NCAxNC44MTYgMjcuODU3IDE3LjE0MyAxNy40'
    b'NyA2LjY5NzUgOTguNDY3IDQ5LjA4MiA4Ny4xNDMgMTAyLjg2LTEuNDMyIDExLjY3MiAyOC4x'
    b'MjYgMjguMjg3IDQ1IDMwLjcxNC0zNC4yOTkgMTAuMzI2LTU2LjMzOCAzMC44NjktNjcuNzg0'
    b'IDYwLjI0eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbGluZWpvaW49InJv'
    b'dW5kIiBzdHJva2Utd2lkdGg9IjQiLz4KICA8L2NsaXBQYXRoPgogPC9kZWZzPgogPGcgdHJh'
    b'bnNmb3JtPSJ0cmFuc2xhdGUoLTkuNDI4NiAyNzIuOTcpIj4KICA8Zz4KICAgPHJlY3QgdHJh'
    b'bnNmb3JtPSJ0cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiB4PSItMzQuMjg2IiB5PSItMzgu'
    b'MDk1IiB3aWR0aD0iODgwIiBoZWlnaHQ9IjYyMCIgZmlsbD0iI2RhMjUxZCIvPgogICA8cGF0'
    b'aCB0cmFuc2Zvcm09InRyYW5zbGF0ZSg5LjQyODYgLTI3Mi45NykiIGQ9Im0yNjQuMjkgMjIw'
    b'LjgzYzEwLjQ1MyAxMy44MjgtMzIuNzYxIDcwLjY4Ny03My41NzEgNjIuNS0xNi41MzMtNDcu'
    b'NTcyIDE3LjkwOC04Ni4wNDQgNzMuNTcxLTYyLjV6IiBmaWxsPSIjZmZmIiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iNCIvPgogICA8cmVj'
    b'dCB0cmFuc2Zvcm09InRyYW5zbGF0ZSg5LjQyODYgLTI3Mi45NykiIHg9Ii0yMC43MTQiIHk9'
    b'IjEwOC4zMyIgd2lkdGg9IjE2MC43MSIgaGVpZ2h0PSIyMDMuNTciIGNsaXAtcGF0aD0idXJs'
    b'KCNjKSIgZmlsbD0iI2ZmZDQwMCIvPgogICA8cmVjdCB0cmFuc2Zvcm09InRyYW5zbGF0ZSg5'
    b'LjQyODYgLTI3Mi45NykiIHg9IjM1LjcxNCIgeT0iNTMuMzMzIiB3aWR0aD0iMjI1IiBoZWln'
    b'aHQ9IjIzNy44NiIgY2xpcC1wYXRoPSJ1cmwoI2EpIiBmaWxsPSIjZmZmIi8+CiAgIDxwYXRo'
    b'IHRyYW5zZm9ybT0idHJhbnNsYXRlKDkuNDI4NiAtMjcyLjk3KSIgZD0ibTExMC43MSAyMDcu'
    b'OThjLTEyLjUyNC0xNS01Ny42NS05OC45MDUtMTE2LjQzLTYwLjcxNC05LjIxNjItNDYuNzQ4'
    b'IDM3Ljk0My0zMC4yNDYgNjMuOTI5LTM3LjUgMjkuMDQ5IDI4LjUwOCA1NS4zMDUgNjAuMzM4'
    b'IDUyLjUgOTguMjE0eiIgY2xpcC1wYXRoPSJ1cmwoI2QpIiBmaWxsPSIjZjE5ZTI5Ii8+CiAg'
    b'PC9nPgogIDxwYXRoIGQ9Im0tNy43NDQtMTI0LjUxYzM1LjcyNS00OS4zNzggMTA0LjA1LTEw'
    b'Ljc2MyAxMTIuMTMgMjAuMjAzIDE2LjAyOCAzMS4zMDUgMTEuMSA5OC4xOCA0Ny40NzcgMTM3'
    b'LjM4bC0xNzguOCA0MC40MDYgMTkuMTkzLTE5Ny45OXoiIGZpbGw9Im5vbmUiIHN0cm9rZT0i'
    b'IzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ii8+CiAgPGc+'
    b'CiAgIDxwYXRoIGQ9Im0xOTIuMjkgNi4wNzY1YzEyLjYwMS0yMi42MTktMC40ODk5LTU3Ljcz'
    b'OC0xMC02Ny44NTctOS4yMjg1LTEwLjEtMzcuOTU3LTYuNjk4MS01MC0yMS40MjktMjQuNTct'
    b'MjUuNDE4LTM3LjAyNS02Ny42MzctNDcuNS04OC4yMTQtMS40NzM3LTYuNjYyNi01Ljc3Nzkt'
    b'MTMuMTY3LTEzLjIxNC0xNi43ODZsLTcuODU3MSA0MC43MTRjMTkuMzc4IDc2LjA1MSA3OC43'
    b'OTUgMTA5LjcxIDEyOC41NyAxNTMuNTd6IiBjbGlwLXBhdGg9InVybCgjYikiIGZpbGw9IiNj'
    b'Y2MiLz4KICAgPHJlY3QgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiB4'
    b'PSItMjIuMjIzIiB5PSIyNjAuNTkiIHdpZHRoPSIxMDUuMDYiIGhlaWdodD0iMTE0LjE1IiBj'
    b'bGlwLXBhdGg9InVybCgjZSkiIGZpbGw9IiNmZmQ0MDAiLz4KICAgPHBhdGggdHJhbnNmb3Jt'
    b'PSJ0cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiBkPSJtODEuODIyIDMxOC4xN2MtMTguMzI2'
    b'LTMwLjA2NC03NS40MzYtMzMuOTg4LTg3Ljg4My0yNy43NzktMTIuMDMtMjUuODY1IDIwLjg2'
    b'MS0yNy41NDEgNDEuNDE2LTM1Ljg2IDc2LjA5MyAxMi40MTYgNDguNzMzIDM5Ljg0OSA0Ni40'
    b'NjcgNjMuNjR6IiBjbGlwLXBhdGg9InVybCgjZikiIGZpbGw9IiNmMTllMjkiLz4KICA8L2c+'
    b'CiAgPHBhdGggZD0ibTEwNC4zOCAzNy4xMThjLTM1LjkyMS00NC44MTctNzQuNjAyLTM3LjE3'
    b'Ni0xMTMuMTQtMzIuMzI1LTkuMTQ5NyA2NS4yOTUtMy41MzUxIDExNi40NCA1MS41MTggMTIw'
    b'LjIxbDYxLjYxOS04Ny44ODN6IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1s'
    b'aW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iNCIvPgogIDxyZWN0IHRyYW5zZm9ybT0i'
    b'dHJhbnNsYXRlKDkuNDI4NiAtMjcyLjk3KSIgeD0iMTUuNzE0IiB5PSIyNTUuNDgiIHdpZHRo'
    b'PSIyMzAuNzEiIGhlaWdodD0iMTM2LjQzIiBjbGlwLXBhdGg9InVybCgjZykiIGZpbGw9IiNm'
    b'ZmQ0MDAiLz4KICA8cGF0aCB0cmFuc2Zvcm09InRyYW5zbGF0ZSg5LjQyODYgLTI3Mi45Nyki'
    b'IGQ9Im0yMzcuNSAzMDMuMzNjLTQzLjkwMi0xMC42ODItMjA4Ljc3LTE0LjIzOC0xOTYuNzkg'
    b'NzUtNDYuNTQ5LTI0LjI3NC0xNi43ODEtNTYuMTc5LTEwLjcxNC04NS43MTQgNzIuNjQ5LTcu'
    b'OTQ1OCAxNTQuMDctMzkuMDA5IDIwNy41IDEwLjcxNHoiIGNsaXAtcGF0aD0idXJsKCNoKSIg'
    b'ZmlsbD0iI2YxOWUyOSIvPgogIDxwYXRoIGQ9Im0zNy43MTMgODkuNjQ2Yy04LjU1NzUtNjQu'
    b'ODQ3IDEwMi4yNi03NC45NDMgMTI3LjI4LTc2Ljc3MiA1MS43MDEtNC41NDg3IDg5LjYxIDcu'
    b'MDk0IDc5LjgwMiA3NC43NTEtNjIuNTg0IDgwLjEzNS0xMzcuMjggMTAuOTQ2LTIwNy4wOCAy'
    b'LjAyMDN6IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91'
    b'bmQiIHN0cm9rZS13aWR0aD0iNCIvPgogIDxyZWN0IHRyYW5zZm9ybT0idHJhbnNsYXRlKDku'
    b'NDI4NiAtMjcyLjk3KSIgeD0iLTM3LjM3NiIgeT0iMzEzLjEyIiB3aWR0aD0iMjA2LjA3IiBo'
    b'ZWlnaHQ9IjIzOS40MSIgY2xpcC1wYXRoPSJ1cmwoI2kpIiBmaWxsPSIjZmZkNDAwIi8+CiAg'
    b'PHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiBkPSJtMTcwLjcy'
    b'IDM4OC44OGMtMzguNzU5LTQyLjIzNy0xNTQuODUtNDIuMjE5LTE5Ni45OCAxMC4xMDItMy41'
    b'NzE5LTgwLjA3MiA2Ny4yNTktNjQuNzE0IDEyMi4yMy02OS43MDEgNjAuNjYxIDUuOTY1OSA4'
    b'Ni44MTcgMjUuMzUxIDc0Ljc1MSA1OS41OTl6IiBjbGlwLXBhdGg9InVybCgjaikiIGZpbGw9'
    b'IiNmMTllMjkiLz4KICA8cGF0aCBkPSJtMTk3LjMyIDExOS45NWMtMzcuODMzLTYxLjk1LTE5'
    b'OS43OC02Mi40OTQtMjE5LjItNC4wNDA2LTEuMTc2MSA5Ny43OTkgMS41MDI2IDE5My41OCAx'
    b'MTEuMTIgMjMzLjM1bDEwOC4wOS0yMjkuM3oiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ii8+CiAgPHJlY3QgeD0i'
    b'MTAxLjM1IiB5PSI2MC4zNTIiIHdpZHRoPSIyMTIuMTMiIGhlaWdodD0iMTU2LjU3IiBjbGlw'
    b'LXBhdGg9InVybCgjaykiIGZpbGw9IiNmZmQ0MDAiLz4KICA8cGF0aCB0cmFuc2Zvcm09InRy'
    b'YW5zbGF0ZSg5LjQyODYgLTI3Mi45NykiIGQ9Im0yNDcuOTkgMzUyLjUyYy03OC4yNiAyMy4x'
    b'NzQtMTQzLjY0IDUyLjkyNS0xMjguNzkgMTEyLjEzbC01NS41NTgtMS4wMTAyYzMyLjQ1LTc3'
    b'LjY0IDEwOC44My0xNDUuODEgMTg0LjM1LTExMS4xMnoiIGNsaXAtcGF0aD0idXJsKCNsKSIg'
    b'ZmlsbD0iI2YxOWUyOSIvPgogIDxwYXRoIGQ9Im0yOTcuMzIgMTg3LjYzYzYuNDIzLTQ1LjE2'
    b'Ni03LjI5MDUtODUuNTM0LTUyLjUyOC0xMTAuMTEtNDYuNzYyIDkuNDY5NS0xNDMuNCAzNi43'
    b'NC0xMjkuMyAxMzAuMzFsMTgxLjgzLTIwLjIwM3oiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ii8+CiAgPHJlY3Qg'
    b'dHJhbnNmb3JtPSJ0cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiB4PSIxNS43MTQiIHk9IjQw'
    b'OS4wNSIgd2lkdGg9IjMyNSIgaGVpZ2h0PSIxNDMuNTciIGNsaXAtcGF0aD0idXJsKCNtKSIg'
    b'ZmlsbD0iI2ZmZDQwMCIvPgogIDxnIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJy'
    b'b3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ij4KICAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUo'
    b'OS40Mjg2IC0yNzIuOTcpIiBkPSJtMTU4LjU3IDIyMi42MmMxMC45ODUtMTguNTM5IDIzLjcx'
    b'MS0zNS4zMzYgNDcuODU3LTQwLjcxNCIgZmlsbD0ibm9uZSIvPgogICA8cGF0aCB0cmFuc2Zv'
    b'cm09InRyYW5zbGF0ZSg5LjQyODYgLTI3Mi45NykiIGQ9Im01OS4yODYgOTIuMjYyYy04Ljc1'
    b'ODQgNy4zNTE1LTMwLjM4OS00LjI0MDMtMjIuODU3LTE5LjY0MyAxMS4xNS0xOS40MTIgMjYu'
    b'MTE1LTMwLjEwNSA0My45MjktMzQuMjg2IDEyLjY1NS0zLjMxNCAyNi45NzUgMTcuMzA5IDEy'
    b'LjE0MyAyNC4yODYiIGZpbGw9IiNmZmYiLz4KICAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoOS40Mjg2IC0yNzIuOTcpIiBkPSJtNDAuMzU3IDg5LjA0OGMxMC40NjEtMjIuNjM0IDI5'
    b'LjU1My0zNi42MzcgNTQuMjg2LTQ1IiBmaWxsPSJub25lIi8+CiAgIDxwYXRoIHRyYW5zZm9y'
    b'bT0idHJhbnNsYXRlKDkuNDI4NiAtMjcyLjk3KSIgZD0ibTIzOC40IDIzMi4zMWM0OC40NDUg'
    b'MzQuMzg1IDE0Mi4yOSA3OC4zNzkgMTM5LjQgMTYyLjYzIDI0LjI5NCAzMy4zMzUgNDQuNjc4'
    b'IDY2LjY3IDU1LjU1OCAxMDAuMDEgNS45OTU0IDIwLjIwMyAyNy42NjMgNDAuNDA2IDQ2LjQ2'
    b'NyA2MC42MDlsLTE1Mi41My05LjA5MTRjNDEuNjk0LTc1LjA0Mi00OS41ODUtMTk3LjY1LTY2'
    b'LjY3LTIxMy4xNC0yMS42ODMtMjAuMjc0LTQwLjUyLTQ2LjIzOS01OS41OTktNzEuNzIxbDM3'
    b'LjM3Ni0yOS4yOTR6IiBmaWxsPSIjZmZmIi8+CiAgPC9nPgogIDxwYXRoIHRyYW5zZm9ybT0i'
    b'dHJhbnNsYXRlKDkuNDI4NiAtMjcyLjk3KSIgZD0ibTUwLjAwMyA1NTkuNmMtMzIuMzY4LTEx'
    b'My4wNiAyMjcuNTMtMTE3LjEyIDI2NC42Ni0xMTEuNjJsLTEyLjYyNy0zMC4zMDVjLTEwNy40'
    b'MiAyNy42NjUtMjcyLjExLTcuMDgyOS0yODQuODYgMTIzLjc0bDMyLjgzIDE4LjE4M3oiIGNs'
    b'aXAtcGF0aD0idXJsKCNuKSIgZmlsbD0iI2YxOWUyOSIvPgogIDxnIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSI0Ij4K'
    b'ICAgPGc+CiAgICA8cGF0aCBkPSJtMzI4LjY0IDI4NC42MWM2LjQyMy00NS4xNjYgMTMuOTIz'
    b'LTkwLjU4NS0yNC4yNDQtMTI1LjI2LTQ2Ljc2MiA5LjQ2OTUtMjgwLjc4IDQuNDE1My0yNjku'
    b'NzEgMTIwLjIxbDI5My45NSA1LjA1MDh6Ii8+CiAgICA8cGF0aCB0cmFuc2Zvcm09InRyYW5z'
    b'bGF0ZSg5LjQyODYgLTI3Mi45NykiIGQ9Im00MDEuNDMgNTM0LjA1Yy0yNi42OTUtMTQuMzk3'
    b'LTQzLjcxNS0zNy4wODgtNTcuMTQzLTYyLjg1NyIvPgogICAgPHBhdGggdHJhbnNmb3JtPSJ0'
    b'cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiBkPSJtMzM3LjE0IDQ1NC43NmMtMy44MTc3LTU5'
    b'LjQyNC00Ni40MTktOTUuNTc3LTc2LjQyOS0xMzkuMjkiLz4KICAgIDxwYXRoIHRyYW5zZm9y'
    b'bT0idHJhbnNsYXRlKDkuNDI4NiAtMjcyLjk3KSIgZD0ibTIxOC41NyAyNTYuOWMxOS41NTQg'
    b'MjcuMjAyIDQxLjY4MyA1MS4zMTMgNzAuNzE0IDY3LjE0MyAyNi4yNzMgMTIuNTYgNTYuNTYy'
    b'IDM3Ljk1MiA4MCA2NSIvPgogICAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUoOS40Mjg2'
    b'IC0yNzIuOTcpIiBkPSJtMjg5LjI5IDMzNC4wNWM0Ny45NDggMzUgNzUuODE3IDcwIDkxLjQy'
    b'OSAxMDUgMTQuNTcgMzUuMjE1IDM2LjE1OCA2Ni45MjEgNjIuMTQzIDk2LjQyOSIvPgogICAg'
    b'PHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiBkPSJtMjU3LjE0'
    b'IDI4MC40OGM0MC4xNjUgMjcuODI3IDg0LjYxOSA1Mi43OTQgMTA4LjU3IDkxLjQyOSIvPgog'
    b'ICAgPHBhdGggdHJhbnNmb3JtPSJ0cmFuc2xhdGUoOS40Mjg2IC0yNzIuOTcpIiBkPSJtMzU3'
    b'Ljg2IDM0Ni45Yy0yNS4yMTYtNDMuNjkzLTg0LjA3LTY1Ljk4MS0xMjcuODYtOTcuODU3Ii8+'
    b'CiAgIDwvZz4KICAgPHBhdGggZD0ibTE5My43OSAwLjYwMmMwLjE4NjAxLTE3LjA0Ny0xMS43'
    b'MDctNDguODAxLTIzLjQ2LTQ5LjE3My01NC44NzUgMi45NTQ4LTg0LjM1NS04My41NzctODgu'
    b'Mjk4LTEwMS44Ny0wLjM1ODA4LTEyLjg4LTMuNjQxOS0yMy42Mi0xMi42NzQtMzAuMTU0IDEu'
    b'NzczOS0xNy43NjQgMjEuNzQ1LTMwLjk0NiAzMi4yMTYtMjkuNzYgNS4wNzM0IDkuOTI2NiAx'
    b'NS4xODQgMTQuODE2IDI3Ljg1NyAxNy4xNDMgMTcuNDcgNi42OTc1IDk4LjQ2NyA0OS4wODIg'
    b'ODcuMTQzIDEwMi44Ni0xLjQzMiAxMS42NzIgMjguMTI2IDI4LjI4NyA0NSAzMC43MTQtMzQu'
    b'Mjk5IDEwLjMyNi01Ni4zMzggMzAuODY5LTY3Ljc4NCA2MC4yNHoiLz4KICA8L2c+CiAgPGcg'
    b'c3Ryb2tlLWxpbmVqb2luPSJyb3VuZCI+CiAgIDxwYXRoIHRyYW5zZm9ybT0idHJhbnNsYXRl'
    b'KDkuNDI4NiAtMjcyLjk3KSIgZD0ibTI1MS4wNyAyMTMuNjljNy42MjQ3LTEuNjk3OCAxNy4w'
    b'OSA2LjIzMzYgMTAuMzU3IDguNTcxNC0yOC45ODEgMTIuMzk3LTUzLjk5NyAyNy4wMjEtNjcu'
    b'ODU3IDU2LjQyOS0zLjU3MTcgNy4xNDMzLTEwLjc5OSAwLjY2Mjc2LTkuNjQyOS01IDE0Ljgz'
    b'Ny0zNC4yNzkgMzIuNjMyLTQ3LjI3MyA2Ny4xNDMtNjB6IiBmaWxsPSIjZmZmIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iNCIvPgogICA8cGF0aCB0cmFuc2Zvcm09InRyYW5zbGF0'
    b'ZSg5LjQyODYgLTI3Mi45NykiIGQ9Im0xOTIuMDUgMjgwLjU3IDQuOTEwNy03Ljk0NjQiIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSI0LjkiLz4KICAgPHBhdGgg'
    b'ZD0ibTI2NC43OS00Ny45NDEgNy4yMzIyLTMuNDgyMSIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIj'
    b'ZmZmIiBzdHJva2Utd2lkdGg9IjQuOSIvPgogIDwvZz4KIDwvZz4KPC9zdmc+Cg==', 'RU_VOR')

RU_VOR = b64_RU_VOR
index.append("RU_VOR")
index.append("Russia Voronezhskaya oblast")
catalog["RU_VOR"] = RU_VOR
catalog["Russia Voronezhskaya oblast"] = RU_VOR
country["Russia Voronezhskaya oblast"] = ('RU_VOR', '', 1)
lookup["RU_VOR"] = ('RU_VOR', '', 'Russia Voronezhskaya oblast', 1)
lookup["Voronezh"] = ('RU_VOR', '', 'Russia Voronezhskaya oblast', 1)
lookup["Russia Voronezhskaya oblast"] = ('RU_VOR', '', 'Russia Voronezhskaya oblast', 1)
details["RU_VOR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Voronezh"}
regional["RU_VOR"] = ('RU_VOR', 'Russia Voronezhskaya oblast', 1)
regional["Russia Voronezhskaya oblast"] = ('RU_VOR', 'Russia Voronezhskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_YAN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI5MDAiIGhl'
    b'aWdodD0iNjAwIiB2aWV3Qm94PSIwIDAgMTU3NSAxMDUwIj4NCjxjbGlwUGF0aCBpZD0iYyI+'
    b'DQo8cGF0aCBkPSJNMCAwSDE1NzVWMTA1MEgweiIvPg0KPC9jbGlwUGF0aD4NCjxwYXRoIGQ9'
    b'Ik0wIDBIMTU3NVYxMDUwSDB6IiBmaWxsPSIjMDA4MGZmIi8+DQo8ZyBjbGlwLXBhdGg9InVy'
    b'bCgjYykiPg0KPHBhdGggZD0ibTAgMGgzdi0zaDF2MWgxdjJoLTF2LTFoMnYxaDF2MWgtM3Yx'
    b'aDF2MWgydi0xaC0xdjJoMXYxaDF2LTNoMXYxaDF2MmgtMXYtMWgydjFoMXYxaC0zdjFoMXYx'
    b'aDJ2LTFoLTF2MmgxdjFoMXYtM2gxdjFoMXYyaC0xdi0xaDJ2MWgxdjFoLTN2MWgxdjFoMnYt'
    b'MWgtMXYyaDF2MWgxdi0zaDF2MWgxdjJoLTF2LTFoMnYxaDF2MWgtM3YxaDF2MWgydi0xaC0x'
    b'djJoMXYxaDF2LTNoMXYxaDF2MmgtMXYtMWgydjFoMXYxaC0zdjFoMXYxaDJ2LTFoLTF2Mmgx'
    b'djFoMXYtM2gxdjFoMXYyaC0xdi0xaDJ2MWgxdjFoLTN2MWgxdjFoMnYtMWgtMXYyaDF2MWgx'
    b'di0zaDF2MWgxdjJoLTF2LTFoMnYxaDF2MWgtM3YzeiIgZmlsbD0iI2ZmZiIgdHJhbnNmb3Jt'
    b'PSIgcm90YXRlKC00NSA3ODcuNSA2OTApIHRyYW5zbGF0ZSg3MCAyMTcuNSkgc2NhbGUoMzUp'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiLz4NCjwvZz4NCjxwYXRoIGQ9Ik0wIDg1OEgxNTc1djMw'
    b'SDB6IiBmaWxsPSIjMDA4MGZmIi8+DQo8cGF0aCBkPSJNMCA4NzlIMTU3NXYyMUgweiIgZmls'
    b'bD0iI2YwMCIvPg0KPC9zdmc+', 'RU_YAN')

RU_YAN = b64_RU_YAN
index.append("RU_YAN")
index.append("Russia Yamalo-Nenetskiy avtonomnyy okrug")
catalog["RU_YAN"] = RU_YAN
catalog["Russia Yamalo-Nenetskiy avtonomnyy okrug"] = RU_YAN
country["Russia Yamalo-Nenetskiy avtonomnyy okrug"] = ('RU_YAN', '', 1)
lookup["RU_YAN"] = ('RU_YAN', '', 'Russia Yamalo-Nenetskiy avtonomnyy okrug', 1)
lookup["Yamalo.Nenets"] = ('RU_YAN', '', 'Russia Yamalo-Nenetskiy avtonomnyy okrug', 1)
lookup["Russia Yamalo-Nenetskiy avtonomnyy okrug"] = ('RU_YAN', '', 'Russia Yamalo-Nenetskiy avtonomnyy okrug', 1)
details["RU_YAN"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+05:00","altname":"Yamalo.Nenets"}
regional["RU_YAN"] = ('RU_YAN', 'Russia Yamalo-Nenetskiy avtonomnyy okrug', 1)
regional["Russia Yamalo-Nenetskiy avtonomnyy okrug"] = ('RU_YAN', 'Russia Yamalo-Nenetskiy avtonomnyy okrug', 1)
#----------------------------------------------------------------------
b64_RU_YAR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB3aWR0aD0iNzk3'
    b'IiBoZWlnaHQ9IjUzMSIgZmlsbC1ydWxlPSJldmVub2RkIiB2ZXJzaW9uPSIxLjEiIHZpZXdC'
    b'b3g9IjAgMCA2MzcuOCA0MjUuMiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3Zn'
    b'Ij4KIDxwYXRoIGQ9Im0wLjA0NyAwLjQ1NGg2MzcuOHY0MjUuMmgtNjM3Ljh2LTQyNS4yeiIg'
    b'ZmlsbD0iI2Y4YzMwMSIvPgogPHBhdGggZD0ibTI4NS45MyAzMTkuMDR2MWUtM2wxLjg3MS0y'
    b'LjE1NSAwLjk0MiA3LjIxOCAxLjY3MS0yLjMwNiAxLjU3NSA3LjEyNSAxLjUwMS0yLjUxM2Mw'
    b'LjU1MyAyLjA0MyAyLjIyMSA2LjEzNCAwLjU3NSA2LjgxOS01LjE1OCAxLjY3NS0xMS45ODgg'
    b'NC4zNTEtMTMuMzQzIDYuNTY4LTIuNzUyIDAuNTU0LTYuMTYxIDIuMTQzLTYuOTYzIDQuMzg3'
    b'IDEuODMxLTAuODYzIDMuNDAzLTEuMzIyIDUuNDQ4LTEuNDkzbDAuMjA1IDAuNTE1Yy0yLjQ4'
    b'MiAwLjY0Mi00LjczOSAyLjM1MS01LjUxIDQuMTk4IDEuNTI4LTAuNTc4IDQuMTc2LTEuNzA4'
    b'IDYuMTUyLTEuODMzbDAuMzczIDAuNTU3Yy0yLjQ1IDAuNzc4LTQuMzY0IDIuNjI5LTUuMTE1'
    b'IDQuMjMgMi4wNjMtMC41NzggNC4zMDEtMS43OTcgNi41NS0yLjE1bDAuNTA4IDAuNDA2Yy0y'
    b'LjMxMiAwLjk3My0zLjUyNCAyLjExLTQuNDk4IDMuNzQ1IDIuMjMxLTAuNTYxIDQuMjM4LTEu'
    b'MzAyIDYuNDkxLTEuNjcxIDAuMjk0IDAuMTk5IDIuMTU4IDAuMDM2IDIuNTYyLTAuMDExbDI0'
    b'Ljg2NC0yLjkxMWMxLjUwMS0wLjE3NiA0LjM2NiAwLjAzNyA0Ljc3NC0yLjU3MSAwLjI1NC0x'
    b'LjYyMSAwLjQ1Ni0zLjA4NSAwLjQ1NC00LjQ3OWwtMC4wMTEtMTYuMTI5IDEuOTgxIDIuNjcz'
    b'IDRlLTMgLTIxLjMwMiAxLjU1OS00LjM1NWMxLjkyMiA3LjkwOSA0LjQzNiAxMy4yNDggOC4x'
    b'MjYgMjEuNDM5bDAuMDM2IDAuMDk3IDAuMDEyLTAuMDI4YzZlLTMgOWUtMyAwLjAxMiAwLjAx'
    b'OCAwLjAxOSAwLjAyNyA4ZS0zIC0wLjA0NSAwLjAxNy0wLjA4NyAwLjAyNS0wLjEzMmwxLjIw'
    b'MS0yLjg3NCAzLjY2NyA3LjEyNiAwLjg3My0zLjE1IDQuNDg2IDYuNzAzIDAuNDI0LTIuODg5'
    b'YzEuMzEzIDIuMTA3IDMuODkgNy4xOSAyLjUzNSA3LjcxMS00LjUyNyAxLjc0My0xMC42NTMg'
    b'My4zNy0xMy45MDMgNy4zMDMtMi41MjUgMC41NDYtNS41NzUgMi4xMzgtNi4yMDEgNC4zOTkg'
    b'MS44MTktMC44NjYgMy4xODEtMS4yOTkgNS40OS0xLjY2OCAwLjA1MSAwLjE3MyAwLjEwNCAw'
    b'LjM0NyAwLjE2IDAuNTIxLTIuNDQ3IDAuNzcyLTQuNzQ3IDIuMzk4LTUuNDEgNC4zMTUgMS40'
    b'ODgtMC42NjEgNC4wNjEtMS42NTMgNi4zMi0xLjkgMC4wNjkgMC4xNTYgMC4xNDEgMC4zMTIg'
    b'MC4yMTYgMC40NjctMi40MDIgMC45MDctNC41MSAyLjU1NS01LjI5MSA0LjIzMiAyLjA0NS0w'
    b'LjU3MyA0LjQ2OC0xLjYyNiA2LjgzNy0xLjk5IDAuMTA4IDAuMTYxIDAuMzU3IDAuMzIgMC40'
    b'NzMgMC40ODEtMi4xOTMgMS0zLjY2OCAxLjc4LTQuNDk5IDMuNDg2IDIuMzczLTAuNjkyIDQu'
    b'OTQxLTEuMyA2Ljg0LTEuNjU0IDAuOTExIDAuMTkgMi4zNjUgMC4xODEgMy4wODQgMC4wODZs'
    b'MjUuNzA4LTMuNDIxYzEuNTEtMC4yMDEgMy4zOTctMC42ODIgMy42ODMtMi44NzQgMC4xODgt'
    b'MS40NDEgMC4xNDktMy4wOTktMC4wMTEtNC44ODJsLTEuODkxLTE1LjczMyAyLjQ5IDIuMzEz'
    b'LTQuMDMxLTIzLjAxOCAwLjAyMy0yNS45MTkgMy4zMzQgMi42NzggMC40MzctMzYuMTU4IDAu'
    b'MDM4LTEzLjAxNmM5ZS0zIC0zLjIzMi0wLjI1OC02LjYzNy0xLjgxNS0xMy41OTMtMC42NTkt'
    b'Mi45NDctMi45NTQtMTMuNDU1LTQuNDUzLTE1LjE5NGwtMC42MjEtMTguODc4IDIuNTkyIDAu'
    b'OTc4LTAuNzA5LTguMzI1IDIuMzg0IDEuMDU4LTEuNDQ1LTguMjY4IDIuNTA3IDAuODc1LTEu'
    b'NzUyLTguMTU5IDIuNjIxIDAuNjc4LTIuMzM2LTcuNzc0IDIuOTQ1IDAuODE0Yy0yLjAzLTgu'
    b'NDY3LTUuMDM5LTE2LjM3MS04LjU4MS0yMy4zMDlsMjQuMzkxLTE3LjU4NmMwLjUyOCAwLjM1'
    b'NiAxLjIwNiAwLjM4OSAxLjcwNiAwLjAyOWwwLjI2NC0wLjE5YzAuMzYxLTAuMjYgMC41NTct'
    b'MC42NzQgMC41NzMtMS4xMTZsMS4zMTktMS4wMjJjMC41OTEgMS4xMTkgMS4xMDYgMi4yNzcg'
    b'MS41MjYgMy40NjIgMC4zMDEgMC44OTYgMC41MzIgMS43ODUgMC42OTMgMi43MTQgMC4xMzUg'
    b'MC44NzUgMC4yIDEuNzM1IDAuMjA5IDIuNjE4LTNlLTMgMC44NjUtMC4wNjEgMS43MDctMC4x'
    b'OCAyLjU2Mi0wLjE3OSAxLjA4OS0wLjQ0OSAyLjEwMi0wLjg0MSAzLjEzMi0wLjEzNCAwLjMz'
    b'LTAuMjc1IDAuNjU0LTAuNDI0IDAuOTc4LTAuMzc4IDAuNzcyLTAuNzk2IDEuNTAxLTEuMjYy'
    b'IDIuMjI0LTEuMjAyIDEuNzk5LTEuODQ4IDIuNTItMy4yMzcgNC4xNjkgMS4wMjkgMC4wNzQg'
    b'MS41ODItMC4wMTMgMi41Ni0wLjIzNSAwLjM3OC0wLjA4NSAwLjk1OS0wLjI3MyAxLjMzLTAu'
    b'NDM1IDAuNzMtMC4zNDMgMS40MTItMC43MjIgMi4wOTItMS4xNTIgMC42NTctMC40MzQgMS4y'
    b'ODItMC44OTUgMS44OTUtMS4zODYgMC42MzQtMC41MjcgMS4yMjEtMS4wNzUgMS43OTEtMS42'
    b'NzMgMC41MzctMC41OSAxLjAyNS0xLjE5NCAxLjQ5LTEuODQ0IDAuNTE1LTAuNzU2IDAuOTYz'
    b'LTEuNTIyIDEuMzcyLTIuMzQzIDAuMjc3LTAuNTg3IDAuNTI0LTEuMTc2IDAuNzUxLTEuNzg2'
    b'IDAuMzA0LTAuODY4IDAuNTUtMS43MzYgMC43NTQtMi42MzQgMC4yMTMtMS4wMjQgMC4zNjUt'
    b'Mi4wNCAwLjQ2My0zLjA4NCAwLjEwMS0xLjM0NyAwLjA5OC0yLjY2LTAuMDE2LTQuMDA5LTAu'
    b'MDQ2LTAuNDQzLTAuMTAxLTAuODgxLTAuMTY1LTEuMzIzLTAuMTcyLTEuMDM2LTAuNC0yLjAz'
    b'Ni0wLjY5Ni0zLjA0NS0wLjIyOC0wLjcyNC0wLjQ4MS0xLjQyOS0wLjc2Ni0yLjEzNC0wLjIx'
    b'NS0wLjUwNC0wLjQzNy0xLjAwNS0wLjY2Mi0xLjUwNGwxLjQ0NS0xLjEyYzAuNTM0IDAuMzg5'
    b'IDEuMjQxIDAuNDM3IDEuNzU3IDAuMDY1bDAuMjY1LTAuMTljMC41NDYtMC4zOTQgMC43MTMt'
    b'MS4xMzcgMC40NTYtMS43OTZsMC4zNDgtMC4yNzFjMS4yOTYgMC40MyAyLjc3MyAwLjI1NCAz'
    b'Ljk2MS0wLjYwMiAxLjM3OS0wLjk5MyAyLjAxMS0yLjY0NyAxLjc3NS00LjIyNWwxLjM1OS0x'
    b'LjIzMmMxLjE1NiA3ZS0zIDIuMzEgMC4wODYgMy40NTYgMC4yNjggMC45MDkgMC4xNTQgMS43'
    b'ODMgMC4zNjIgMi42NzkgMC41OWwxNS41ODQtMTguNzI1LTIyLjY5NyA4Ljg1My0wLjA5NCAx'
    b'LjI1NGMtMC4xNTQgMS40OTQtMC40NTEgMi45MjctMC44NzYgNC4zNjQtMC4wNSAwLjE1OC0w'
    b'LjEwMSAwLjMxNS0wLjE1MyAwLjQ3MWwtMS42MDUgMC45MDFjLTEuNDIxLTAuNzIyLTMuMTkt'
    b'MC42NDgtNC41NjkgMC4zNDYtMS4xODMgMC44NTItMS44MTYgMi4xOTEtMS44MjQgMy41NTFs'
    b'LTAuMzYyIDAuMjRjLTAuNTQ2LTAuNDk2LTEuMzM5LTAuNTkyLTEuOTA0LTAuMTg1bC0wLjI2'
    b'MyAwLjE5Yy0wLjUzMyAwLjM4NC0wLjcwNiAxLjEwMi0wLjQ3NSAxLjc0OGwtMC42MzcgMC40'
    b'MjNjLTAuMzc4LTAuODE0LTAuNzUtMS42MzMtMS4xMDctMi40NTctMC40MDgtMC45ODMtMC43'
    b'MzgtMS45NzQtMC45OTktMy4wMDgtMC4yNDItMS4wMjYtMC40MDctMi4wNDctMC41MDQtMy4w'
    b'OTktMC4xMDktMS40MDQtMC4xMDUtMi43OTMgMC4wNDgtNC4xOTdsMC4xNi0wLjk4NWMwLjE0'
    b'Mi0wLjY2NSAwLjMxMi0xLjMwNyAwLjUxNi0xLjk1NyAwLjIyNy0wLjY1MyAwLjQ3OC0xLjI4'
    b'MSAwLjc2MS0xLjkxNCAwLjMwNC0wLjYyOSAwLjYyNi0xLjIzNCAwLjk4MS0xLjgzOCAwLjQ2'
    b'NC0wLjc0NCAwLjk1My0xLjQ0NCAxLjQ5NS0yLjEzNyAwLjMzLTAuNDAxIDAuNjY3LTAuNzg5'
    b'IDEuMDE5LTEuMTczIDAuNTk0LTAuNjE1IDEuMjA0LTEuMTgyIDEuODY0LTEuNzI4IDAuNDMy'
    b'LTAuMzM4IDAuODctMC42NjYgMS4zMy0wLjk2OCAxLjIxNC0wLjc4OCAyLjUyNy0xLjQxIDMu'
    b'ODE1LTIuMDY3bC0yLjc3OS0xLjM3NC0xLjA1OS0wLjQ4Ni0yLjEwNy0wLjg1Mi0yLjA5NS0w'
    b'LjY5LTIuMDg0LTAuNTI4LTEuMDM4LTAuMjAyLTEuMDM2LTAuMTYzLTEuMDM0LTAuMTIxLTEu'
    b'MDMyLTAuMDgtMS4wMy0wLjAzOS0xLjAyOCAxZS0zIC0xLjAyNyAwLjA0Mi0xLjAyNSAwLjA4'
    b'My0xLjAyNCAwLjEyNC0xLjAyMiAwLjE2NS0xLjAyIDAuMjA1LTEuMDIgMC4yNDUtMi4wMzYg'
    b'MC42MS0yLjAzMyAwLjc3LTIuMDMyIDAuOTI4LTIuMDMzIDEuMDg0LTIuMDM4IDEuMjM5LTIu'
    b'MDQzIDEuMzkyLTEuODAzIDEuMzU0LTEuNzAxIDEuNDA4LTEuNTk2IDEuNDY2LTEuNDgzIDEu'
    b'NTI5LTEuMzY2IDEuNTk2LTEuMjQyIDEuNjY3LTEuMTExIDEuNzQzLTAuNTA2IDAuOS0wLjQ2'
    b'OSAwLjkyLTAuNDM1IDAuOTQtMC4zOTcgMC45NjEtMC4zNiAwLjk4Mi0wLjMyMiAxLjAwMy0w'
    b'LjI4MyAxLjAyNS0wLjI0MyAxLjA0Ni0wLjIwMyAxLjA2OC0wLjE2MyAxLjA5LTAuMTIxIDEu'
    b'MTEzLTAuMDc5IDEuMTM1LTAuMDM3IDEuMTU4IDhlLTMgMS4xODIgMC4wNSAxLjIwNiAwLjA5'
    b'NSAxLjIyOSAwLjEzOSAxLjI1NCAwLjQ1NCAzLjE0M2MwLjk0OS0wLjkyMiAxLjg3Ni0xLjg3'
    b'MyAyLjg5Mi0yLjcyIDAuODA4LTAuNjU2IDEuNjQ1LTEuMjM1IDIuNTQ3LTEuNzUgMS4xMzIt'
    b'MC42MjcgMi4yOTYtMS4xMjQgMy41MjctMS41MTUgMS4wNTgtMC4zMTcgMi4xMTQtMC41Mzcg'
    b'My4yMDktMC42NzUgMS42LTAuMTgyIDMuMTY1LTAuMTg1IDQuNzY2LTdlLTNsMC44ODYgMC4x'
    b'MzJjMC44ODggMC4xNjMgMS43NDIgMC4zNzUgMi42MDMgMC42NDUgMC41NjcgMC4xOTIgMS4x'
    b'MTkgMC40MDIgMS42NyAwLjYzNSAwLjY4NCAwLjMwOSAxLjMzNiAwLjY0NCAxLjk4NSAxLjAx'
    b'OSAwLjkwMSAwLjU1IDEuNzI0IDEuMTQzIDIuNTI5IDEuODI2IDAuNCAwLjM1NyAwLjc4NSAw'
    b'LjcyMiAxLjE1NyAxLjEwNyAwLjI4MyAwLjI5OSAwLjU1NyAwLjYwMyAwLjgyNCAwLjkxMmwt'
    b'MS41MjcgMS4wMTRjLTAuNDI5LTAuMTMxLTAuODkyLTAuMDgtMS4yNTggMC4xODRsLTAuMjY0'
    b'IDAuMTkxYy0wLjUwNSAwLjM2My0wLjY4NiAxLjAyOC0wLjUwNyAxLjY0N2wtMjMuODI1IDE3'
    b'LjE3OGMtMS40MTMtMi40MDgtMi44ODYtNC42NjgtNC4zOTUtNi43NTZsMi40NjUgMC4wODQt'
    b'My44NzktNS41NDEgMi4zOTUtMC4xMDctNC4yODctNC4yNzIgMi4zNzktMC4zMDEtNC41MDEt'
    b'NC4yMzIgMi4zNDctMC40OTNjLTQuMzQzLTUuODM2LTEwLjMxMS0xMS45Ny0xNC4yMjQtMTQu'
    b'Njc1IDllLTMgLTZlLTMgMC4wMTctMC4wMTMgMC4wMjYtMC4wMTkgMCAwIDEuODIzLTAuODc5'
    b'IDEuODgxLTIuMjk4IDAuMDU4LTEuNDE4LTEuNzUxLTMuNzcxLTMuNzIyLTUuMTg3LTIuMDU5'
    b'LTEuNDc5LTQuMTM4LTEuNjY4LTUuMTYyLTEuMTE4LTAuNTY0IDAuMzAzLTEuMTM2IDAuOTkz'
    b'LTEuNjIxIDEuODEzLTEuMTEyLTAuNzY2LTIuMjE1LTEuNDQ2LTMuNDYxLTEuOTY0LTAuMDc1'
    b'LTAuMDQ2LTAuMTQ5LTAuMDkyLTAuMjIzLTAuMTM3LTAuMjU4LTAuMDk2LTAuNTEyLTAuMTct'
    b'MC43NjItMC4yMjctMC44MDItMC4yNi0xLjY3LTAuNDU0LTIuNjM4LTAuNTY0LTEuMDktMC4x'
    b'MjQtMi4yNDUtMC4xOTItMy40NDgtMC4yMDgtNS4yMTItMC4wNzItMTEuMzEzIDAuODEyLTE2'
    b'Ljc5NiAyLjE3NC0xLjk1IDAuNDg0LTUuNDU0IDMuNjMxLTUuNTA3IDMuNjMxbC0xMy44MzQg'
    b'MS4wMzJjLTMuMDg1LTAuMTE2LTEuOTQ1IDMuMTI4LTEuNjE4IDUuNDA0IDAuMjI1IDEuNTY2'
    b'IDAuNTAzIDMuMzg5IDAuNTAzIDMuMzg5IDUuNjE4IDEuNzc3IDguNjU5IDIuODk4IDEwLjM5'
    b'NCA0LjU4NCAwLjI0MiAwLjYwOCAwLjE4IDEuODQxIDAuMDI5IDIuMTk2LTEuMzkyLTAuNjcz'
    b'LTUuMjA5LTIuMzY3LTguNjIyLTIuMzAyLTAuMzY4IDAuMDQzIDAuMTE3IDEuODAxIDAuNTc3'
    b'IDMuNDkxIDAuMzU4IDEuMTE4IDIuMDIzIDIuMzIgNC4xNDggNC4wNDMgNS4zMDMgNC4yOTcg'
    b'Ny42MjggMTEuOTc3IDguNTY1IDE1Ljg0NGwtMWUtMyAwLjAyMiA1ZS0zIC02ZS0zYzAgMWUt'
    b'MyAxZS0zIDJlLTMgMWUtMyAyZS0zIDAtMWUtMyAxZS0zIC0yZS0zIDFlLTMgLTNlLTNsMS41'
    b'NDgtMS41MDYgMC4zMjkgNS41MzYgMS4zNTItMS42OTcgMS4wMjUgNS40NSAxLjExMS0xLjc4'
    b'IDIuMjQ2IDUuMDQ3IDFlLTMgNy4wNDNjLTEuODg2IDAuMDU5LTMuNzY4IDAuMDc4LTUuNTAz'
    b'IDAuMDQxLTQuNjM5LTAuMDk4LTcuMDg3LTAuMTMyLTEwLjMyMS0zLjM3NWwtMTcuNzY0LTE3'
    b'LjgxN2MtMS4yNzItMS4yNzctMy4zNTUtMy45MzgtNi44LTUuNjVsLTEyLjI2Ni02LjA5OWMt'
    b'Mi43NjEtMS4zNzMtNS44NzMtMi41NDUtOS4wMzEtMi4wNTMtMy4xMjEtMC45NDUtNi4xNS0x'
    b'LjY0OS03LjcyMS0wLjExNiAxLjkwOSAwLjQwNSAzLjY3NSAwLjkzMSA1LjQzIDEuNTY2LTAu'
    b'MjI0IDAuMjIxLTAuNDMyIDAuNDUxLTAuNjI1IDAuNjktMy4wMzItMC4xMzMtNi40NDQtMC41'
    b'MDUtNy41MiAxLjI2NSAyLjIxMy0wLjA5NSA0LjIzOCAwLjI4NiA2LjQwMiAwLjY2NC0wLjEy'
    b'IDAuMzE4LTAuMjEyIDAuNjQ0LTAuMjc2IDAuOTc0LTIuNjgyIDAuMTEyLTUuMzc5IDAuMjc4'
    b'LTYuMTY5IDEuODk2IDIuMDUxLTAuMjc4IDMuOTc5LTAuMTI2IDYuMDEgMC4wNDEtMC4wMTQg'
    b'MC4zNjktMC4wMjEgMC43MjUtMC4wMiAxLjA2Ni0yLjU3MyAwLjM0OS01LjA5MiAwLjc4OC01'
    b'LjcxIDIuNDE2IDEuOTYxLTAuNDUxIDMuODQzLTAuNDg3IDUuODE5LTAuNTA2IDAuMDUxIDAu'
    b'MzkzIDAuMTIgMC43NTQgMC4yMTEgMS4wNzktMi4wNTcgMC41MzItMy44NSAxLjIyOC00LjI0'
    b'IDIuNjMzIDEuNzM5LTAuNTcyIDMuNDQ0LTAuNzk1IDUuMjE4LTAuOTgyIDAuMDI1IDAuMDE5'
    b'IDAuMDQ5IDAuMDM3IDAuMDc1IDAuMDU1IDYuOTQ3IDQuODcyIDEyLjE3OCAxNC44NzggMTgu'
    b'NDUgMTcuNDk3bDEuODA2IDIuNjI3LTMuOTE2IDAuNTE5IDYuMjI0IDYuMDU5LTMuNTc0IDAu'
    b'NjI5IDYuNDc3IDUuNzg5LTMuNTQ0IDAuNzgxIDYuNzE4IDUuNTA3LTMuNTA4IDAuOTMxIDcu'
    b'MjIxIDUuNDIyLTMuNTkyIDEuMTI2IDEzLjYxNSA5LjMwOS0xOS40MjggNC43ODRjLTcuNTI4'
    b'IDEuODU0LTEwLjI5MSA0LjMwOC0xMi42NTMgNy41NDdsLTExLjA1IDE1LjE1NWMtMi44NjYg'
    b'My45MjktNC4wMzIgNi4zOTItNC4zMjIgOS44NzYtMC4wOTMgMC40MTEtMC4xMTMgMC44MTgt'
    b'MC4wNTkgMS4yMDMtMC40MjQgMS4wODItMC44MSAyLjE1NS0wLjk4OSAzLjEybC0xNi45MTYg'
    b'MTIuMTk1LTAuMzMyIDAuMzUzLTAuMjA0IDAuNDk4LTAuMDQzIDAuNDgxIDAuMDU0IDAuNDQg'
    b'MC4xMTcgMC40MTEgMC4xNjQgMC4zOSAwLjQzNiAwLjcyOCAwLjU1MyAwLjY0MyAwLjMxOCAw'
    b'LjI3NyAwLjM1MyAwLjI0MiAwLjQwMiAwLjE5IDAuNDY5IDAuMTEgMC41MzYtMC4wMzUgMC40'
    b'NC0wLjIwNSAxNi45OTQtMTIuMjUyYzAuMTI5IDAuMjUxIDAuMjk2IDAuNDcyIDAuNTEgMC42'
    b'NTYgMC4wNDgtMC4zOTMgMC4xMTEtMC43NzcgMC4xODQtMS4xNTZsMi4xNzMtMS41NjdjLTAu'
    b'MDE1IDEuNDcxIDAuMjMzIDIuNzA5IDEuMTIzIDMuMzQyIDAuMDQ4LTEuNjI2IDAuMzQ1LTMu'
    b'MTMzIDAuNzExLTQuNjY0bDEuMTM0LTAuODE3YzAuMDcyLTRlLTMgMC4xNDQtMC4wMSAwLjIx'
    b'Ny0wLjAxNS0wLjA2NiAyLjUxNCAwIDQuOTQ2IDEuNDYgNS43OTUtMC4xMy0yLjA5IDAuMTY5'
    b'LTQuMDIxIDAuNDg2LTYuMDYxIDAuMzM5LTAuMDY5IDAuNjg2LTAuMTYgMS4wMTgtMC4yNzYg'
    b'MC4xNjIgMi42MjcgMC40MDMgNS4yMyAyLjAwNCA1Ljk3My0wLjM4MS0yLjQ1NC0wLjEzOS00'
    b'Ljc0MSAwLTcuMjQ0IDQuODY4LTQuMDQ3IDEwLjQ2NC02LjgxMiAxNC42MTgtMTEuNjY1bDMu'
    b'MDMxLTAuNzQzLTEuMzU3IDMuMjk1IDguMjU2LTIuMzA0LTEuMjM5IDMuMzYyIDguMTUyLTIu'
    b'NjQ5LTEuMDk2IDMuNDEyIDcuOTIzLTIuOTQ5LTAuMTk0IDAuODQ1LTAuNjQ1IDIuNTUyIDEx'
    b'LjQ1Ni0yLjIxNyAwLjE4MSAwLjAzM2MtMS4xODIgMTEuNTAzLTEuODc1IDIxLjY1My0yLjI3'
    b'OSAzMy42MDhoMWUtM2wyLjI0My0wLjk0MS0xLjUyOCA2LjQ3NyAyLjEyMS0xLjA2MS0wLjkz'
    b'NCA2LjYyNCAxLjkyNC0xLjIxN2MwLjExMiAwLjkzMyAwLjIwOSA1LjUxNiAwLjY0NCA4Ljg5'
    b'M2wtNy43MjYgMTYuNDM4Yy0yLjk5IDYuMzYzLTQuMjYyIDE2LjgwNS0zLjQ3MiAyNC44MTUg'
    b'MS40MjggNy44NzkgMS43NSA5LjA0MyAzLjMgMTUuMjg0eiIgZmlsbD0iIzJjMmMyYiIvPgog'
    b'PHBhdGggZD0ibTM4OS4yNSAxMzIuNTVjLTEuNTM3IDEuMjUxLTMuMjY1IDIuMzQ1LTUuMTcg'
    b'Mi45NDIgMi44OS0zLjUxNiA0LjY3My02LjgzMSA0LjgwOS0xMS4zOTcgMC4xMDYtMy41NDQt'
    b'MC43MTctNi4zMS0yLjMxMS05LjQ2LTAuMS0wLjE5Ny0wLjIwMS0wLjM5MS0wLjMwNS0wLjU4'
    b'NWw3LjExMS01LjUxMiAwLjIwOCAwLjQ1YzEuOTgxIDQuMjkyIDIuNDc5IDguODQxIDEuNTYg'
    b'MTMuNDUzLTAuNzk0IDMuOTgzLTIuNjIyIDcuNDQtNS45MDIgMTAuMTA5em0tMy40NS0xOS4z'
    b'NTctMi42ODIgMi4wNzljMC4wOTYgMC4xOTUgMC4xMyAwLjM3IDAuMDMgMC42MDItMC4xMSAw'
    b'LjE1Ny0wLjI4MSAwLjI2Mi0wLjQ0NCAwLjM1NC0wLjI1MyAwLjA3Ni0wLjQyOC0wLjAxMi0w'
    b'LjYyNC0wLjE2OGwtMi42My0zLjYxOWMtMC4xNTItMC4yNTgtMC4yMzMtMC40NTctMC4xMDkt'
    b'MC43NDggMC4xMDktMC4xNTUgMC4yNzgtMC4yNiAwLjQ0My0wLjM1MyAwLjI1Mi0wLjA3NSAw'
    b'LjQyOCAwLjAxMSAwLjYyNiAwLjE2OGwwLjAyNiAwLjAzNiAyLjkzMS0xLjk0NGMtMC41NDkt'
    b'MC42ODktMS4xMzItMS4zNTItMS43NS0xLjk4NC0zLjUzOS0zLjYxOC04LjU0My01LjYwNC0x'
    b'My41NzQtNS42MDctMy4yMS0yZS0zIC02LjE1IDAuNjI1LTkuMDIxIDIuMDczLTEuMzA1IDAu'
    b'NjU5LTIuNTAzIDEuNDYxLTMuNjIxIDIuNDA5LTAuNDc4IDAuNDA0LTAuOTMxIDAuODM0LTEu'
    b'MzggMS4yNzQtMi4xNjEtMTMuNDU3IDMuMzYtMjIuMzU5IDEzLjA1MS0yOS4zMTQgMTAuNzI1'
    b'LTcuNjk3IDIwLjg0OS04LjgyMyAzMS45NTQtMy4xMjctMC44MDYgMC40MDctMS41NzggMC44'
    b'MzUtMi4zMjcgMS4zMzYtNC42MDQgMy4wNzUtOC4yMDMgOC43MzYtOC41MTMgMTQuMzQ4LTAu'
    b'MiAzLjYzIDAuMzY5IDcuMDY4IDEuODk1IDEwLjM3NGwxLjMzIDIuODggMi4zNDctMS41NTgt'
    b'MC4yNzItMC4zNzVjLTAuMTUzLTAuMjU4LTAuMjMzLTAuNDU3LTAuMTEtMC43NDcgMC4xMS0w'
    b'LjE1NiAwLjI3OS0wLjI2MSAwLjQ0NC0wLjM1MyAwLjI1Mi0wLjA3NiAwLjQyOCAwLjAxIDAu'
    b'NjI2IDAuMTY4bDAuNDE3IDAuNTc0IDEuNTgzLTEuMDVjLTAuMTctMS4yMjEgMC4zMjMtMi40'
    b'OTYgMS4zODktMy4yNjQgMS4yMTctMC44NzcgMi44MjYtMC44MzUgMy45ODktMC4wMTNsMi40'
    b'MTktMS4zNThjMC4wOTYtMC4yODEgMC4xODktMC41NjQgMC4yNzktMC44NDcgMC41MTQtMS43'
    b'MDUgMC44NTUtMy40NDIgMC45NjctNS4yMjRsMTguNjI5LTcuMjY2LTEyLjc5MiAxNS4zNzFj'
    b'LTAuODE4LTAuMjE3LTEuNjQ3LTAuMzgtMi40ODItMC41MDctMC43NTUtMC4xMDUtMS41MDgt'
    b'MC4xNzItMi4yNjItMC4yMDZsMTAuODMtOS44MjctNi45OTYgNS4wNDItNS4yNDMgNC43NTct'
    b'Mi4wNTMgMS44NjNjMC40MTMgMS4zNjQtMC4wNTggMi45MDMtMS4yNzYgMy43OC0xLjA2OSAw'
    b'Ljc3MS0yLjQ0IDAuODM0LTMuNTQ2IDAuMjhsLTEuNDg2IDEuMTUyIDAuMjYyIDAuMzYxYzAu'
    b'MTUzIDAuMjU4IDAuMjM0IDAuNDU5IDAuMTEgMC43NDgtMC4xMSAwLjE1Ny0wLjI4MSAwLjI2'
    b'MS0wLjQ0NSAwLjM1NC0wLjI1MiAwLjA3NS0wLjQyNy0wLjAxMi0wLjYyNC0wLjE2OWwtMC4z'
    b'NS0wLjQ4Mi0yLjUyNSAxLjk1OHYtMWUtM2wtNy40NCA1Ljc3eiIgZmlsbD0iI2ZmZiIvPgog'
    b'PHBhdGggZD0ibTM2Ni4yMiA4Mi45NzVjMi4yNDMtMS44ODkgNC42MDMtMy40OTIgNy4xOTct'
    b'NC44NjQgMy45OTctMi4xMTQgMTAuNjQ3LTQuNDY4IDE5LjU4OC0xLjYyNC0wLjY1NyAwLjYw'
    b'OS0xLjI2OSAxLjIzNy0xLjgzOSAxLjg5LTcuNDc1LTIuMDU5LTE0LjU4NS0wLjA2Ni0yMC45'
    b'MDQgNC40ODktNi4yODEgNC41My0xMC4zNzMgMTAuNjgxLTEwLjgwNCAxOC4zNjQtMC44Mjkg'
    b'MC4zNDQtMS42MzcgMC43MzItMi40MTggMS4xNzQtMC4wNTktMTAuMTIzIDYuMzU4LTE3LjA1'
    b'NCA5LjE4LTE5LjQyOXptMzguMzA1IDEyLjQ2NmMtMC4wOSAwLjI4NC0wLjE4MyAwLjU2Ni0w'
    b'LjI4IDAuODQ3bDYuMTgyLTMuNDcxIDYuOTg5LTUuMDM1LTEyLjc0NSA3LjE1N2MtMC4wNDcg'
    b'MC4xNjgtMC4wOTYgMC4zMzUtMC4xNDYgMC41MDJ6bS00LjY4MyAxLjU3NGMxLjg4OCAwIDMu'
    b'NDI4IDEuNTQgMy40MjggMy40MjhzLTEuNTQgMy40MjktMy40MjggMy40MjljLTAuNTUzIDAt'
    b'MS4wNzgtMC4xMzMtMS41NDEtMC4zNjhsLTAuNzE5IDAuNTU3LTAuMTA4IDAuMDg0LTAuNjU5'
    b'IDAuNTExLTEuOTQ5LTIuNjgzIDAuNzExLTAuNDcxIDAuMTA5LTAuMDczIDAuNzYxLTAuNTA1'
    b'Yy0wLjAyMi0wLjE1OC0wLjAzMy0wLjMxOC0wLjAzMy0wLjQ4MSAwLTEuODg4IDEuNTM5LTMu'
    b'NDI4IDMuNDI4LTMuNDI4em0tMS43OTEgNi4zNDljLTAuMDEyLTdlLTMgLTAuMDIzLTAuMDE0'
    b'LTAuMDM1LTAuMDIxLTdlLTMgLTVlLTMgLTAuMDE0LTllLTMgLTAuMDIxLTAuMDE0LTAuNTc4'
    b'LTAuMzcxLTEuMDM4LTAuOTExLTEuMzA5LTEuNTQ4IDAuMDk3IDAuMjMgMC4yMjIgMC40NTQg'
    b'MC4zNzQgMC42NjUgMC4yNjEgMC4zNjIgMC41NzkgMC42NTcgMC45MzUgMC44ODNtMS42NjEt'
    b'NS42NDJjMS4zMTEgMCAyLjM4MSAxLjA3IDIuMzgxIDIuMzgxIDAgMS4zMS0xLjA3IDIuMzgx'
    b'LTIuMzgxIDIuMzgxcy0yLjM4LTEuMDcxLTIuMzgtMi4zODFjMC0xLjMxMSAxLjA2OS0yLjM4'
    b'MSAyLjM4LTIuMzgxem0tMS42MDUgNS42NzdjLTAuMDEyLTdlLTMgLTAuMDIzLTAuMDE0LTAu'
    b'MDM1LTAuMDIxbS01LjA2My0wLjEgMS41OTIgMi4yMTEtMTEuMjQyIDguMzgyLTIuMDAxLTIu'
    b'Nzc5Yy0wLjAxNC0wLjAxOS0wLjAyOC0wLjAzNy0wLjA0Mi0wLjA1NmwtMC44MjEgMC41NDUg'
    b'Mi42MDMgMy41ODJjMC4wMjkgMC4wNTEgMC4wNTcgMC4wOTggMC4wOCAwLjE0NmwwLjQ2OC0w'
    b'LjM2M3YxZS0zbDExLjQtOC44NDEgMC43NzgtMC42MDMtMi4wMDctMi43NjItMC44MDggMC41'
    b'Mzd6bS02LjY3NSAxMC44MDkgMS45NDQtMS41MDhjMC43OTEgMS40MzYgMS40NjcgMi45MzEg'
    b'Mi4wMSA0LjQ2MiAxLjA2IDMuMTQ1IDEuMzc0IDYuNDQyIDAuODM0IDkuNzI4IDEuNTc4LTIu'
    b'ODQxIDIuMTc5LTYuMTM0IDIuMTAzLTkuMzYxLTAuMTAzLTIuMzMzLTAuNTgxLTQuNDgyLTEu'
    b'NDU1LTYuNjQ3LTAuMDk1LTAuMjIyLTAuMTkyLTAuNDQ0LTAuMjg5LTAuNjY1bC01LjE0OCAz'
    b'Ljk5IDFlLTMgMWUtM3ptNC43MjUtMTAuNjc3LTIuMDU5IDEuMzY2Yy0wLjUyNC0xLjExOS0x'
    b'LjAzNS0yLjI0Mi0xLjUwNy0zLjM4Mi0xLjc2NC00LjQ1OS0yLjIzNy05LjQzOC0xLjA4Mi0x'
    b'NC4xMTEgMC4zMzctMS4xOTggMC43NDYtMi4zMTcgMS4yNTUtMy40NTMgMC44MDItMS42NjEg'
    b'MS43MzUtMy4xNjMgMi44MzYtNC41NTMtNy4wMjYtMS43NTgtMTMuNjUxIDAuMjYyLTE5LjU0'
    b'NCA0LjUxMi01LjcwNyA0LjExNi05Ljc5MSA5LjcwOC0xMC4zOTIgMTcuMDc0IDMuOTYtMS4z'
    b'NzIgOC4xNTktMS41NzkgMTIuMjY5LTAuNzEzbDEuMDI1IDAuMjU1YzEuNzI4IDAuNDkzIDMu'
    b'MzExIDEuMTM5IDQuODg5IDIgMS45MDkgMS4xMDEgMy41NDggMi4zODMgNS4wNjYgMy45ODQg'
    b'MC4zNDggMC4zNzUgMC42ODYgMC43NiAxLjAxNiAxLjE1M2wtMi4wMjUgMS4zNDRjMC4yMTEg'
    b'MC4yNDYgMC40MTggMC40OTcgMC42MiAwLjc1bDUuOTkyLTMuOTc2IDIuMDUyLTEuMzYxLTAu'
    b'NDExLTAuODg5eiIgZmlsbD0iI2IxYjRiNiIvPgogPHBhdGggZD0ibTIxNC4wNiAyMzYuNjIg'
    b'MTcuMTc3LTEyLjM4NGMtMC4xODYtMS4xNzggMC4wNzUtMi42OTkgMC40MDItNC4yNDktMC4x'
    b'NzMtMC4wNy0wLjM0Ni0wLjE0NC0wLjUxOS0wLjIyMWwtMS41MjIgMS4wOThjLTAuMzgxIDAu'
    b'ODItMC43MTkgMS42NjQtMC45ODYgMi41NjktMC4zMzctMC40MDUtMC40OTUtMC45MDktMC41'
    b'MjQtMS40ODFsLTE2LjE4OSAxMS42NzNjLTAuOTk5IDAuNzIgMS4xNjMgMy43MTYgMi4xNjEg'
    b'Mi45OTV6bTE4LjQ5LTEzLjMzIDEuOTA4LTEuMzc2YzAuMDI5LTAuMzU2IDAuMDY3LTAuNzE5'
    b'IDAuMTA4LTEuMDg0LTAuMzg4LTAuMDY1LTAuNzczLTAuMTQ3LTEuMTU3LTAuMjQ4LTAuMzE1'
    b'IDAuOTA1LTAuNjE0IDEuNzk3LTAuODU5IDIuNzA4em03Mi4xMDktNTEuOTkxIDc2LjMxMi01'
    b'NS4wMTktMi4xNzItMi45ODktODQuNzYgNjEuMTExIDEwLjYyLTMuMTAzeiIgZmlsbD0iI2Uy'
    b'MWMyYSIvPgogPHBhdGggZD0ibTM3OS42NSAxMTQuNDctODEuNTM4IDU4LjczOC0yLjc4NiAw'
    b'LjgxNCA4My43NTUtNjAuMzM1IDAuNTY5IDAuNzgzem0tMTQ4LjI3IDEwNi44MS0yLjcxNiAx'
    b'Ljk1N2MwLjE3Mi0wLjU1OSAwLjM3My0xLjA5NiAwLjU5Mi0xLjYxOWwyLjMwOS0xLjY2M2Mw'
    b'LjAyMiA5ZS0zIDAuMDQ0IDAuMDE5IDAuMDY3IDAuMDI4LTAuMDkzIDAuNDM3LTAuMTc5IDAu'
    b'ODcyLTAuMjUyIDEuMjk3em0tMi44NDkgMi4wNTMtMTUuNjQzIDExLjI2OS0wLjU2Ni0wLjc4'
    b'NSAxNS44MTgtMTEuMzk2YzAuMDY4IDAuMzM4IDAuMTk0IDAuNjQ1IDAuMzkxIDAuOTEyeiIg'
    b'ZmlsbD0iI2YzOWI3ZSIvPgogPHBhdGggZD0ibTI4My40OCAzNDAuMjYgMi41MTEtMC42MDct'
    b'MC44MTctMC41MjItMS42OTQgMS4xMjl6bTE3Ljg3LTI0Ni43OWMtMS43NDItMC42MDQtMy4x'
    b'MzMtMC44MDEtNC41NDUtMC44NDQgMC4wNTctMi4xMDcgMi4xMDktMS40ODcgMi45OTYtMC45'
    b'MDEgMC42MDMgMC4zOTggMC45NiAwLjg5MSAxLjU0OSAxLjc0NXptLTUxLjQzMyA5Ny4xNDUg'
    b'MS44MjgtMC44NTktMC43MDgtMC4yNzItMS4xMiAxLjEzMXptLTcuMzA5IDcuOTM5IDEuODQx'
    b'LTEuNjEyLTAuOTE2LTAuMDgtMC45MjUgMS42OTJ6bTEuODgxIDIuMzExIDIuMDUtMS44ODMt'
    b'MS4wNDMtMC4wNjUtMS4wMDcgMS45NDh6bTU3LjcxMyA2OC40NTctMC4wNTgtMi40NTQtMC42'
    b'NSAwLjY1NCAwLjcwOCAxLjh6bTEuNDk5LTE0Mi41NCAwLjU1OS0yLjUyOC0wLjgzIDAuNTA2'
    b'IDAuMjcxIDIuMDIyem03LjcyMS01LjI3MyAwLjI1NC0yLjU3Ni0wLjc2NCAwLjYwMSAwLjUx'
    b'IDEuOTc1em0xLjc1Ny03LjcxNS0wLjU5MS0yLjUyLTAuNTI5IDAuODE1IDEuMTIgMS43MDV6'
    b'bTUuOTI0IDMuNzk5LTAuNTkxLTIuNTItMC41MyAwLjgxNSAxLjEyMSAxLjcwNXptNC45NTQt'
    b'MTUuNTY0LTEuMTUxLTIuMzE4LTAuMzI5IDAuOTE1IDEuNDggMS40MDN6bS0xLjYwNiA5LjA4'
    b'My0wLjczLTIuNDgzLTAuNDgzIDAuODQzIDEuMjEzIDEuNjR6bS0xMy45MzMgMTYuODYzIDEu'
    b'MTcxLTIuOTYxLTEuMTA3IDAuNDUzLTAuMDY0IDIuNTA4em04LjIwNi00LjA0OCAwLjI4Mi0z'
    b'LjA1OC0wLjkwMSAwLjcxOSAwLjYxOSAyLjMzOXptLTkuODkyIDIzLjU2IDEuNTk0LTIuOTI2'
    b'LTEuMjA3IDAuMzI5LTAuMzg3IDIuNTk3em01LjQzMS01LjE5OCAxLjIyOC0yLjI3OS0wLjkz'
    b'NyAwLjI1OS0wLjI5MSAyLjAyem0tNS4wNTggMS4wMTIgMS4yMjgtMi4yNzktMC45MzcgMC4y'
    b'NTktMC4yOTEgMi4wMnptLTQuNzQ3IDAuNzc4IDEuMjI4LTIuMjc5LTAuOTM3IDAuMjU5LTAu'
    b'MjkxIDIuMDJ6bS01Ni41NTIgNDkuODYzIDEuODQtMS42MTItMC45MTUtMC4wNzktMC45MjUg'
    b'MS42OTF6bTc2LjM3MyAyMS43MTggMS45OTktNS4zNzEtMS45NzUgMC44NTYtMC4wMjQgNC41'
    b'MTV6bTEzLjUwNC04LjMgMS4yOTktMy40OTMtMS4yODUgMC41NTctMC4wMTQgMi45MzZ6bS0z'
    b'LjQ3OCAzLjcyNiAxLjQ4Mi0zLjk4NS0xLjQ2NSAwLjYzNS0wLjAxNyAzLjM1em0tNTcuODQ2'
    b'LTEyLjk4NiAyLjQ0NS0wLjQ2LTAuNzgxLTAuNDE3LTEuNjY0IDAuODc3em0zMC4wNDUtMTgu'
    b'MTc2IDIuNDcxLTAuNzcyLTAuODUyLTAuNDY5LTEuNjE5IDEuMjQxem0tMjQuMjYxIDIxLjY3'
    b'IDIuNDcxLTAuNzcxLTAuODUyLTAuNDctMS42MTkgMS4yNDF6bTEyLjM4NCAwLjc5MiAyLjQ3'
    b'Mi0wLjc3MS0wLjg1Mi0wLjQ2OS0xLjYyIDEuMjR6bS0yMC43MzQtMTMuNTc5IDIuNDQ1LTAu'
    b'NDYxLTAuNzgxLTAuNDE2LTEuNjY0IDAuODc3em0yOC44NjItMi45NyAyLjQ3Mi0wLjc3MS0w'
    b'Ljg1Mi0wLjQ2OS0xLjYyIDEuMjR6bTUuMDA1IDQuOTIzIDIuNDcyLTAuNzcxLTAuODUyLTAu'
    b'NDY5LTEuNjIgMS4yNHptLTguODcxIDEuMzI5IDIuNDcyLTAuNzcxLTAuODUzLTAuNDY5LTEu'
    b'NjE5IDEuMjR6bS00LjMzNy00Ljk2NyAyLjQ3MS0wLjc3MS0wLjg1Mi0wLjQ2OS0xLjYxOSAx'
    b'LjI0em0tNy43MDEtMC4zNTcgMi40NzItMC43NzEtMC44NTItMC40NjgtMS42MiAxLjIzOXpt'
    b'LTE3LjkwMyA2Ljg3NyAyLjQ0NC0wLjQ2LTAuNzgtMC40MTctMS42NjQgMC44Nzd6bTE0LjM3'
    b'NSAwLjU3MyAyLjQ3Mi0wLjc3MS0wLjg1Mi0wLjQ2OS0xLjYyIDEuMjR6bTguNTk5IDEuOTA5'
    b'IDIuNDcyLTAuNzcxLTAuODUyLTAuNDY5LTEuNjIgMS4yNHptLTEzLjUyNS0xMi44MTQgMi40'
    b'NzEtMC43NzEtMC44NTItMC40NjktMS42MTkgMS4yNHptMjUuNzM2IDEzLjk5MiAyLjQ3MS0w'
    b'Ljc3MS0wLjg1Mi0wLjQ2OS0xLjYxOSAxLjI0em0tNS44NDItMTcuODA4IDIuNDcyLTAuNzcx'
    b'LTAuODUyLTAuNDY5LTEuNjIgMS4yNHptLTcuNDIgMS44ODUgMi40NzItMC43NzItMC44NTMt'
    b'MC40NjgtMS42MTkgMS4yNHptMjAuMTY0IDE4LjEzNiAyLjQ3MS0wLjc3MS0wLjg1Mi0wLjQ2'
    b'OS0xLjYxOSAxLjI0em0yMi45NjUtNTcuNTIyIDIuMTU3LTEuNDMyLTAuOTQ5LTAuMjEzLTEu'
    b'MjA4IDEuNjQ1em0tMTUuNTU4IDUuNzg2IDIuNjQ2LTMuNjI5LTEuNjcxIDAuMjI3LTAuOTc1'
    b'IDMuNDAyem0tMTMuMDQ2IDIuNzkxIDIuMDM0LTMuNzMzLTEuNTQgMC40Mi0wLjQ5NCAzLjMx'
    b'M3ptLTIuNDE3LTAuNzk2IDEuODQtMy44MzMtMS41MTYgMC40OTktMC4zMjQgMy4zMzR6bTMu'
    b'MjA3LTQuMDc3IDEuNTk0LTIuOTI2LTEuMjA3IDAuMzI5LTAuMzg3IDIuNTk3em05LjQxOSAw'
    b'LjkyNSAyLjI3NC0zLjU5Mi0xLjU2NSAwLjMxOC0wLjcwOSAzLjI3NHptMTguNTE0LTkuMDY4'
    b'IDIuMTU3LTEuNDMxLTAuOTQ5LTAuMjEzLTEuMjA4IDEuNjQ0em01LjE3OS0zLjg4NCAyLjM0'
    b'Mi0xLjEwMy0wLjkwOS0wLjM0OC0xLjQzMyAxLjQ1MXptLTEzLjI2NyA1LjMxOCAxLjYzLTIu'
    b'MDExLTAuOTY5IDAuMDgyLTAuNjYxIDEuOTI5em0xMi4xNC0wLjk0MyAyLjM0Mi0xLjEwNC0w'
    b'LjkwOC0wLjM0OC0xLjQzNCAxLjQ1MnptLTcuNDcyLTAuNjk4IDIuMTU3LTEuNDMyLTAuOTQ5'
    b'LTAuMjEzLTEuMjA4IDEuNjQ1em0tMTguOTEzIDkuODQ3IDIuMjc1LTMuNTkyLTEuNTY1IDAu'
    b'MzE4LTAuNzEgMy4yNzR6bS0xLjc4MiA1LjI1MyAyLjI3NC0zLjU5My0xLjU2NSAwLjMxOS0w'
    b'LjcwOSAzLjI3NHptMTMuMzYyLTkuNjQyIDEuODE2LTEuODQ1LTAuOTczLTAuMDEzLTAuODQz'
    b'IDEuODU4em0tMS40NTIgNi4xMDkgMS43ODItMi44MTUtMS4yMjYgMC4yNDktMC41NTYgMi41'
    b'NjZ6bTcuNjU2LTcuNjYzIDEuODE2LTEuODQ0LTAuOTczLTAuMDEzLTAuODQzIDEuODU3em0t'
    b'MC4xOSAzLjgxMSAyLjE2LTEuNDI5LTAuOTQ5LTAuMjEzLTEuMjExIDEuNjQyem0tMTAuMjgy'
    b'LTIuNTE5IDEuNzgyLTIuODE1LTEuMjI3IDAuMjQ5LTAuNTU1IDIuNTY2em0tMTQuNzI0IDIy'
    b'LjU0NyAyLjAzNC0zLjczNC0xLjU0MSAwLjQyLTAuNDkzIDMuMzE0em0wLjIxOC00Ljg3OCAy'
    b'Ljc0My01LjAzNC0yLjA3NyAwLjU2Ny0wLjY2NiA0LjQ2N3ptOC40NDQtOC45NzcgMi4yNzQt'
    b'My41OTMtMS41NjUgMC4zMTgtMC43MDkgMy4yNzV6bTEzLjYzMS0zNC4wNDktMC43MjktMi40'
    b'ODMtMC40ODQgMC44NDMgMS4yMTMgMS42NHptMTMuMDE5LTEuNjUzLTEuMDI3LTMuNDc3LTAu'
    b'Njc0IDEuMTgyIDEuNzAxIDIuMjk1em0tMS45OTUgMTUuMzg4LTAuMTgxLTQuODg0LTEuMjc2'
    b'IDEuMzIgMS40NTcgMy41NjR6bS0xNi44NjItNC4xODMgMC43Ni0yLjk3Ny0xLjAwNCAwLjU2'
    b'OCAwLjI0NCAyLjQwOXptMTIuNDk0LTI4LjA0NC0xLjE1Mi0yLjMxOC0wLjMyOSAwLjkxNCAx'
    b'LjQ4MSAxLjQwNHptLTQuMTk2IDE0LjU5LTAuNzMtMi40ODMtMC40ODMgMC44NDMgMS4yMTMg'
    b'MS42NHptNC4yNzggMTguOTI2LTAuMTgtNC44ODMtMS4yNzYgMS4zMTkgMS40NTYgMy41NjR6'
    b'bS03Ljc5OCAyLjQ1OSAwLjczOS00LjgzMS0xLjUwMSAxLjA1NyAwLjc2MiAzLjc3NHptNC43'
    b'NTctMjYuNjQyLTAuODg1LTIuNDMzLTAuNDMgMC44NzIgMS4zMTUgMS41NjF6bS0zNC4wMyAx'
    b'MDYuMTQgMS4xMTEtMi45ODUtMS4wOTggMC40NzYtMC4wMTMgMi41MDl6bTU5LjA5NiA5MS41'
    b'NjQtMC4wMjgtMi40NTUtMC42NTggMC42NDYgMC42ODYgMS44MDl6bS03LjI3MiA4LjI2MS0w'
    b'LjAyNy0yLjQ1NS0wLjY1OCAwLjY0NyAwLjY4NSAxLjgwOHptLTQuNTE3LTguMzczLTAuMDQx'
    b'LTMuNjQxLTAuOTc1IDAuOTU4IDEuMDE2IDIuNjgzem0tMTIuNjkzIDAuODc1LTAuMDMtMi42'
    b'NTYtMC43MTIgMC42OTkgMC43NDIgMS45NTd6bTE0LjQ2NCA0LjkzMSAwLjAzMi0zLjIyNi0w'
    b'Ljg4MiAwLjgzIDAuODUgMi4zOTZ6bS0wLjQyMS0xNi4zMjQgMC40OS0zLjE0Ni0wLjk4IDAu'
    b'Njg2IDAuNDkgMi40NnptLTMuNjQ3LTI5LjQyMyAxLjQ1NC0zLjc2Ny0xLjM5OSAwLjU4Ni0w'
    b'LjA1NSAzLjE4MXptOC42MzgtMC4wNiAwLjkzMy0yLjQxNS0wLjg5NyAwLjM3NC0wLjAzNiAy'
    b'LjA0MXptLTEuNjk3LTkuMjcyIDAuOTMzLTIuNDE2LTAuODk3IDAuMzc2LTAuMDM2IDIuMDR6'
    b'bS0xLjIyMi0xMzQuNTgtMC40Ni0yLjU0OC0wLjU3MSAwLjc4OCAxLjAzMSAxLjc2em0tOS41'
    b'NDItMTEuNzc0LTAuOTI1LTIuNDE3LTAuNDE1IDAuODc5IDEuMzQgMS41Mzh6bTMuNTI0IDE3'
    b'LjA5Mi0wLjUwNC00LjIyMS0xLjAxMiAxLjIzNCAxLjUxNiAyLjk4N3ptLTEyLjM4Mi01LjI0'
    b'OC0wLjMzLTMuMDUzLTAuNzQxIDAuODg0IDEuMDcxIDIuMTY5em0yLjU5MS0yLjUyOS0wLjM4'
    b'Ny0zLjU4MS0wLjg2OSAxLjAzNiAxLjI1NiAyLjU0NXptMy42OTktMTMuMjM3LTAuOTI0LTIu'
    b'NDE4LTAuNDE1IDAuODc5IDEuMzM5IDEuNTM5em0tMTMuMzQ4IDI2LjIwNCAxLjA1Mi00LjEy'
    b'MS0xLjM5IDAuNzg3IDAuMzM4IDMuMzM0em0tMy41NjItMC4yMSAxLjA2My0zLjQ2Ni0xLjIx'
    b'NSAwLjYxMyAwLjE1MiAyLjg1M3ptLTEuOTAyLTMuNTQxIDAuNzYtMi45NzctMS4wMDQgMC41'
    b'NjggMC4yNDQgMi40MDl6bTguNjQ1LTUuNjQ3LTAuMTE0LTMuMDY5LTAuODAxIDAuODI4IDAu'
    b'OTE1IDIuMjQxem0tMjIuOTA4IDkuMjAzIDEuMTItMi4zMzQtMC45MjQgMC4zMDQtMC4xOTYg'
    b'Mi4wM3ptMjkuNDQzLTI4Ljg0NS0wLjkyNS0yLjQxOC0wLjQxNSAwLjg3OSAxLjM0IDEuNTM5'
    b'em02LjYwNSAwLjg5My0xLjE1MS0yLjMxOC0wLjMyOSAwLjkxNCAxLjQ4IDEuNDA0em0zLjY0'
    b'NCA2LjczOC0wLjg0OS0yLjQ0Ni0wLjQ0MiAwLjg2NiAxLjI5MSAxLjU4em0yLjc2OSA1LjM5'
    b'Ni0wLjcyMi0yLjQ4Ni0wLjQ4NiAwLjg0MiAxLjIwOCAxLjY0NHptLTEwLjU3OC0yLjg5NS0w'
    b'LjgyOC0zLjUyOS0wLjc0IDEuMTQyIDEuNTY4IDIuMzg3em04LjMxMiA3LjM5NC0wLjgxNC00'
    b'LjE3My0wLjkxOCAxLjMwNiAxLjczMiAyLjg2N3ptMi40NDIgNS4wNjUtMC4zNDQtNC4yMzgt'
    b'MS4wNTggMS4xOTUgMS40MDIgMy4wNDN6bS04LjA4Ni03LjAxMy0wLjgyOC0zLjUyOS0wLjc0'
    b'MSAxLjE0MSAxLjU2OSAyLjM4OHptLTIuNTk2IDYuNzYxLTAuNTgxLTQuODUzLTEuMTYzIDEu'
    b'NDIgMS43NDQgMy40MzN6bS0zLjk2NyA5LjU2NSAwLjIxMi00Ljg4My0xLjM3NyAxLjIxMyAx'
    b'LjE2NSAzLjY3em0tMC4yOC02Ljg2OS0wLjE4MS00Ljg4NC0xLjI3NSAxLjMxOSAxLjQ1NiAz'
    b'LjU2NXptLTMuODQ0IDAuODQxIDAuMjEyLTQuODgyLTEuMzc3IDEuMjEzIDEuMTY1IDMuNjY5'
    b'em0tMTMuNzM1IDMuMTQxIDEuMzMzLTMuMzcyLTEuMjYgMC41MTYtMC4wNzMgMi44NTZ6bTAu'
    b'MDEgNS43MiAxLjU2My0zLjk1NS0xLjQ3OCAwLjYwNS0wLjA4NSAzLjM1em0tMy4zMzYtMC44'
    b'MjcgMS4xNy0yLjk2Mi0xLjEwNyAwLjQ1NC0wLjA2MyAyLjUwOHptLTEuNTcyLTMuODIzIDEu'
    b'MTcxLTIuOTYyLTEuMTA4IDAuNDUzLTAuMDYzIDIuNTA5em0tMy4xMjQgMy43NDkgMS4xNy0y'
    b'Ljk2Mi0xLjEwNyAwLjQ1My0wLjA2MyAyLjUwOXptMTMuNzYgMC41OTEgMS4wNTEtNC4xMjEt'
    b'MS4zODkgMC43ODcgMC4zMzggMy4zMzR6bTMuOTI4LTAuMjQgMS4xODYtNC42NC0xLjU2NiAw'
    b'Ljg4NiAwLjM4IDMuNzU0em0xNi40NDQtMTIuNzg3LTAuNzA3LTQuMTkyLTAuOTUyIDEuMjgy'
    b'IDEuNjU5IDIuOTF6bS0yMi43NjMgOS45NzkgMC44OTYtMy41MTMtMS4xODQgMC42NyAwLjI4'
    b'OCAyLjg0M3ptNS4zMjMgODEuNDM0IDEuNDgzLTMuOTg1LTEuNDY2IDAuNjM2LTAuMDE3IDMu'
    b'MzQ5em0tOC41MDMtMC42MzIgMS40ODItMy45ODYtMS40NjUgMC42MzYtMC4wMTcgMy4zNXpt'
    b'LTguMjcyLTAuNTE1IDEuNDgyLTMuOTg1LTEuNDY1IDAuNjM1LTAuMDE3IDMuMzV6bS00LjQw'
    b'MyAwLjM2NyAxLjQ4Mi0zLjk4NS0xLjQ2NSAwLjYzNS0wLjAxNyAzLjM1em0tNDIuMTI0LTI3'
    b'LjYxIDMuMjI1LTAuNTY0LTEuMDItMC41NjItMi4yMDUgMS4xMjZ6bS0zLjE1MiA0LjE2NSAz'
    b'LjYxMS0xLjE3NC0xLjI1Ny0wLjY3My0yLjM1NCAxLjg0N3ptMC44MTIgNC42MzQgMy42MTEt'
    b'MS4xNzMtMS4yNTctMC42NzMtMi4zNTQgMS44NDZ6bTUzLjEzOSAxOC4yNzEgMS40ODMtMy45'
    b'ODYtMS40NjYgMC42MzYtMC4wMTcgMy4zNXptOC42OTMtMC4zMjYgMS40ODItMy45ODYtMS40'
    b'NjUgMC42MzYtMC4wMTcgMy4zNXptMTMuMzg4IDUwLjAxNSAxLjUzMS0zLjk2Ni0xLjQ3MyAw'
    b'LjYxNi0wLjA1OCAzLjM1em0xNS42NTItMTAuNDUzIDAuOTMzLTIuNDE2LTAuODk3IDAuMzc2'
    b'LTAuMDM2IDIuMDR6bS0zMC4yNS0xNC40MjIgMC45LTQuMTU1LTEuMzU5IDAuODM3IDAuNDU5'
    b'IDMuMzE4em02Ljk3OSAwLjI5OCAwLjktNC4xNTUtMS4zNTkgMC44MzcgMC40NTkgMy4zMTh6'
    b'bS0yMS4xNTYgODQuMjc0IDAuNDgtMi40MDctMC43NzcgMC40OTYgMC4yOTcgMS45MTF6bS00'
    b'LjI0Ny0xMDMuNTIgMS40ODItMy45ODUtMS40NjUgMC42MzQtMC4wMTcgMy4zNTF6bTEuMzI3'
    b'IDE4LjIxOCAxLjExLTIuOTg1LTEuMDk3IDAuNDc2LTAuMDEzIDIuNTA5em01LjA1Mi0zLjY1'
    b'OCAxLjk5OC01LjM3MS0xLjk3NSAwLjg1Ni0wLjAyMyA0LjUxNXptMjAuMDYxLTEwLjAyOSAx'
    b'LjQ4Mi0zLjk4NS0xLjQ2NSAwLjYzNS0wLjAxNyAzLjM1em0tMi4wMzQgMjEuMjMyIDAuNDAy'
    b'LTMuMjE2LTAuOTc2IDAuNzI4IDAuNTc0IDIuNDg4em0tNC4zODYgMy44IDAuNDAyLTMuMjE2'
    b'LTAuOTc2IDAuNzI4IDAuNTc0IDIuNDg4em01LjM4OCAyLjE1NSAwLjQwMi0zLjIxNS0wLjk3'
    b'NiAwLjcyOCAwLjU3NCAyLjQ4N3ptLTczLjI0Ny01NS40ODkgMi45MjctMS45NjQtMS4yOTMt'
    b'MC4yODItMS42MzQgMi4yNDZ6bS0xLjEzNCA2LjY1MiAxLjQ4OC0xLjM2Ni0wLjc1Ny0wLjA0'
    b'OC0wLjczMSAxLjQxNHptNy41Ny0zLjcxOSAxLjgyOC0wLjg1OS0wLjcwOC0wLjI3Mi0xLjEy'
    b'IDEuMTMxem0tNC40NTktMC4wMTggMi4zODQtMS40MzUtMS4wMDgtMC4yNzMtMS4zNzYgMS43'
    b'MDh6bS04LjEzMyA0LjYwOSAyLjA1LTEuODgzLTEuMDQzLTAuMDY2LTEuMDA3IDEuOTQ5em0t'
    b'Mi4wMjYtMi4yNzQgMS45MDQtMS43NDgtMC45NjktMC4wNjEtMC45MzUgMS44MDl6bTI0LjUw'
    b'OS0xMy42MDkgMi40ODItMC43MzktMC44NDYtMC40OC0xLjYzNiAxLjIxOXptNTAuODc2LTMy'
    b'LjMzMSAxLjIyOS0yLjI3OS0wLjkzOCAwLjI1OS0wLjI5MSAyLjAyem04LjQxMy02LjI1IDEu'
    b'Njc0LTEuOTc0LTAuOTcxIDAuMDU5LTAuNzAzIDEuOTE1em0tNC4zMjcgMy45ODMgMS4yMjgt'
    b'Mi4yOC0wLjkzNyAwLjI2LTAuMjkxIDIuMDJ6bTQuNjcxLTcuODQxIDIuMzI4LTIuMzg0LTEu'
    b'MjUyLTAuMDExLTEuMDc2IDIuMzk1em0tMjQuNDg1IDIxLjI2MiAxLjg0LTMuODMzLTEuNTE2'
    b'IDAuNDk4LTAuMzI0IDMuMzM1em0wLjU3My01LjM3MiAxLjg0LTMuODMzLTEuNTE2IDAuNDk4'
    b'LTAuMzI0IDMuMzM1em02Ljk0OS0yLjgzNCAyLjM3MS01LjIxOC0yLjAzIDAuNzE1LTAuMzQx'
    b'IDQuNTAzem0tMS44MTgtNS4yNSAyLjc0My01LjAzMy0yLjA3NyAwLjU2Ni0wLjY2NiA0LjQ2'
    b'N3ptMy4zMjcgOC4wNzIgMS43NTktMy44NzEtMS41MDYgMC41My0wLjI1MyAzLjM0MXptMy45'
    b'MDMtMy4zMzEgMS43NTgtMy44NzEtMS41MDYgMC41MzEtMC4yNTIgMy4zNHptNC44MDUtNi4w'
    b'MTkgMS43ODItMi44MTYtMS4yMjYgMC4yNDktMC41NTYgMi41Njd6bS02LjY0OCAzLjg1OCAx'
    b'Ljc1OS0zLjg3MS0xLjUwNyAwLjUzLTAuMjUyIDMuMzQxem0zLjI1OC0zLjM3NSAyLjQwNC0z'
    b'Ljc5NS0xLjY1MyAwLjMzNi0wLjc1MSAzLjQ1OXptLTEyLjkgMi44MzcgMS44NC0zLjgzMy0x'
    b'LjUxNiAwLjQ5OC0wLjMyNCAzLjMzNXptMzkuNDg4IDQ3LjUyIDEuMjE2LTMuMjcxLTEuMjAy'
    b'IDAuNTIxLTAuMDE0IDIuNzV6bS0zLjI1NiA4LjM5NCAxLjIxNy0zLjI3LTEuMjAyIDAuNTIt'
    b'MC4wMTUgMi43NXptLTMuMDU0IDYuMjA2IDEuNDgyLTMuOTg1LTEuNDY1IDAuNjM1LTAuMDE3'
    b'IDMuMzV6bS0xLjA3MSA4LjI1OCAxLjQ4My0zLjk4NS0xLjQ2NiAwLjYzNS0wLjAxNyAzLjM1'
    b'em0tMi43OTktMy42NDcgMS40ODMtMy45ODUtMS40NjYgMC42MzUtMC4wMTcgMy4zNXptLTgu'
    b'MDc0LTIuMzUyIDEuNDgzLTMuOTg0LTEuNDY1IDAuNjM0LTAuMDE4IDMuMzV6bTUuMDc4LTYu'
    b'MTM5IDEuMzA2LTMuNTExLTEuMjkgMC41Ni0wLjAxNiAyLjk1MXptNi40NTYgNjMuMDAyIDIu'
    b'MDY1LTUuMzQ2LTEuOTg1IDAuODMxLTAuMDggNC41MTV6bTMuODIgMzUuMDM0LTAuMDQxLTMu'
    b'NjQxLTAuOTc1IDAuOTU5IDEuMDE2IDIuNjgyem0tMi44MjggMC44MzgtMC4wNDEtMy42NDEt'
    b'MC45NzUgMC45NTkgMS4wMTYgMi42ODJ6bTAuNjI5LTQuMzk5LTAuMDQxLTMuNjQxLTAuOTc1'
    b'IDAuOTU5IDEuMDE2IDIuNjgyem0tMy4yNDcgMC45NDMtMC4wNDEtMy42NDEtMC45NzUgMC45'
    b'NTkgMS4wMTYgMi42ODJ6bTAuNTI0LTQuMjk0LTAuMDQxLTMuNjQxLTAuOTc1IDAuOTU5IDEu'
    b'MDE2IDIuNjgyem01LjQgMC42MzktMC4wNDItMy42NDEtMC45NzUgMC45NTkgMS4wMTcgMi42'
    b'ODJ6bS01LjE3Mi02LjM1IDAuMzQ4LTQuMjM3LTEuMjM4IDEuMDA4IDAuODkgMy4yMjl6bS0z'
    b'LjI0NiAxLjI1NyAwLjM0OC00LjIzNy0xLjIzOCAxLjAwOCAwLjg5IDMuMjI5em04LjI3My0x'
    b'OC4xODMgMS41MzEtMy45NjctMS40NzMgMC42MTctMC4wNTggMy4zNXptLTEwLjk2NyA5Ljkz'
    b'OCAwLjY3OS00LjE5Ny0xLjMxNCAwLjkwNyAwLjYzNSAzLjI5em0tMy4xNDItMS45OSAwLjY3'
    b'OS00LjE5Ny0xLjMxNCAwLjkwNyAwLjYzNSAzLjI5em0tMy4xNzUtMi4yMiAxLjE0Ny0yLjk3'
    b'MS0xLjEwMyAwLjQ2Mi0wLjA0NCAyLjUwOXptLTAuMTA1LTUuNDQ2IDEuMTQ3LTIuOTcxLTEu'
    b'MTAzIDAuNDYzLTAuMDQ0IDIuNTA4em02LjUzNC04LjE3NiAyLjA2NS01LjM0Ni0xLjk4NiAw'
    b'LjgzMS0wLjA3OSA0LjUxNXptMS4wNDcgNC4yOTQgMi4wNjUtNS4zNDYtMS45ODUgMC44MzEt'
    b'MC4wOCA0LjUxNXptLTIuNjc3IDkuMDQ1IDEuNTMyLTMuOTY3LTEuNDczIDAuNjE3LTAuMDU5'
    b'IDMuMzV6bTMuMzA1IDAuOTA0IDIuMDY1LTUuMzQ2LTEuOTg1IDAuODMxLTAuMDggNC41MTV6'
    b'bS0xLjI1Ni0zLjk3OSAyLjA2NS01LjM0Ny0xLjk4NiAwLjgzMi0wLjA3OSA0LjUxNXptMi45'
    b'MzItMy45OCAyLjA2NS01LjM0Ni0xLjk4NiAwLjgzMS0wLjA3OSA0LjUxNXptMS4wNDctNi45'
    b'MTIgMi4wNjUtNS4zNDYtMS45ODUgMC44MzEtMC4wOCA0LjUxNXptLTYuNzggMi43MjggMS41'
    b'MzItMy45NjgtMS40NzMgMC42MTctMC4wNTkgMy4zNTF6bS0yMy4zNjItMzQuMDI0IDEuNDgy'
    b'LTMuOTg1LTEuNDY0IDAuNjM2LTAuMDE4IDMuMzQ5em0xNy40NDktMTQuNDMxIDEuNDgzLTMu'
    b'OTg0LTEuNDY1IDAuNjM1LTAuMDE4IDMuMzQ5em0tMi41MjgtOC4yNjIgMS45OTktNS4zNzEt'
    b'MS45NzUgMC44NTYtMC4wMjQgNC41MTV6bS0zLjM1OCA0LjEwNSAxLjk5OS01LjM3Mi0xLjk3'
    b'NSAwLjg1Ni0wLjAyNCA0LjUxNnptLTMuMzkyLTAuNzI3IDEuOTk5LTUuMzcxLTEuOTc1IDAu'
    b'ODU2LTAuMDI0IDQuNTE1em0tMTAuOTQgNC45MTEgMS40ODItMy45ODYtMS40NjUgMC42MzYt'
    b'MC4wMTcgMy4zNXptMTYuODkyIDQuNzIgMS40ODEtMy45ODUtMS40NjQgMC42MzUtMC4wMTcg'
    b'My4zNXptLTQuMDYxIDIuMTA1IDEuNDgyLTMuOTg1LTEuNDY1IDAuNjM1LTAuMDE3IDMuMzV6'
    b'bTE4Ljk0NC0xNy45NiAxLjQ4Mi0zLjk4NS0xLjQ2NSAwLjYzNi0wLjAxNyAzLjM0OXptLTMu'
    b'OTM0IDEuODE2IDEuNDgzLTMuOTg2LTEuNDY2IDAuNjM2LTAuMDE3IDMuMzV6bS0zMC4wMzcg'
    b'MTYuNzA0IDEuMTEtMi45ODQtMS4wOTcgMC40NzUtMC4wMTMgMi41MDl6bS0yLjk1LTIuOTMg'
    b'MS4xMS0yLjk4NS0xLjA5OCAwLjQ3Ni0wLjAxMiAyLjUwOXptMTQuMzk5IDYuNDM0IDEuNzcx'
    b'LTQuNzU3LTEuNzQ5IDAuNzU4LTAuMDIyIDMuOTk5em0xLjA5My05LjkwMyAxLjk5OS01LjM3'
    b'Mi0xLjk3NSAwLjg1Ni0wLjAyNCA0LjUxNnptLTMuODIgMC43NTUgMS45OTktNS4zNzEtMS45'
    b'NzYgMC44NTYtMC4wMjMgNC41MTV6bS0yLjg4NC0yLjE0MyAxLjk5OS01LjM3Mi0xLjk3NSAw'
    b'Ljg1Ni0wLjAyNCA0LjUxNnptMy4zMzMtNC41NDQgMS45OTktNS4zNzEtMS45NzUgMC44NTYt'
    b'MC4wMjQgNC41MTV6bS00LjgxNiAwLjYyOCAxLjk5OS01LjM3MS0xLjk3NSAwLjg1Ni0wLjAy'
    b'NCA0LjUxNXptOC4wNDYgNTEuNDIyLTAuODQxLTIuMzA3LTAuNDA3IDAuODI4IDEuMjQ4IDEu'
    b'NDc5em01LjcyOSAxLjc2My0wLjg0MS0yLjMwNy0wLjQwNiAwLjgyOCAxLjI0NyAxLjQ3OXpt'
    b'Mi44MTYtNi45MzctMC4wNTgtMi40NTQtMC42NSAwLjY1NCAwLjcwOCAxLjh6bS0xMS4xMDct'
    b'NS4zNzQtMC4wNTktMi40NTUtMC42NSAwLjY1NCAwLjcwOSAxLjgwMXptLTEyLjQwNS0yNC4y'
    b'MDggMC42ODMtMy4xNTQtMS4wMzIgMC42MzUgMC4zNDkgMi41MTl6bTM2LjcwMyA2LjI5NSAw'
    b'LjYzOS0yLjk1Mi0wLjk2NSAwLjU5NSAwLjMyNiAyLjM1N3ptLTIwLjQ3NSAxNi45ODYgMC40'
    b'MDItMy4yMTYtMC45NzYgMC43MjggMC41NzQgMi40ODh6bTE2LjYyMS05LjQ1MyAwLjQwMi0z'
    b'LjIxNS0wLjk3NiAwLjcyNyAwLjU3NCAyLjQ4OHptLTUuMjAyIDcuMDY4IDAuNDAzLTMuMjE2'
    b'LTAuOTc2IDAuNzI4IDAuNTczIDIuNDg4em0tNS4zOTggMS44NDQgMC40MDItMy4yMTUtMC45'
    b'NzYgMC43MjggMC41NzQgMi40ODd6bS0zLjczNiA3LjU5Mi0wLjMxNS0zLjIyNS0wLjc5MyAw'
    b'LjkyNSAxLjEwOCAyLjN6bS0zLjk2NC0xMS42MTMgMC40MDMtMy4yMTUtMC45NzYgMC43Mjgg'
    b'MC41NzMgMi40ODd6bTguNzU0LTQuMzc5IDAuNDAzLTMuMjE1LTAuOTc2IDAuNzI3IDAuNTcz'
    b'IDIuNDg4em0tNC4xODMgMy43MzggMC40MDItMy4yMTUtMC45NzYgMC43MjcgMC41NzQgMi40'
    b'ODh6bTE5LjkyMS01LjUzNCAwLjY0LTIuOTUyLTAuOTY2IDAuNTk1IDAuMzI2IDIuMzU3em0t'
    b'Ny40MS01LjU4NyAwLjY0LTIuOTUyLTAuOTY2IDAuNTk1IDAuMzI2IDIuMzU3em0wLjEzNi01'
    b'Ljg2NiAwLjktNC4xNTUtMS4zNTkgMC44MzcgMC40NTkgMy4zMTh6bTAuOTE4LTYuNjU2IDEu'
    b'MjgxLTMuNDQyLTEuMjY2IDAuNTQ5LTAuMDE1IDIuODkzem0tNy40MTEtMC45MTggMS40ODIt'
    b'My45ODYtMS40NjUgMC42MzYtMC4wMTcgMy4zNXptOC42NjktNi4xODggMS4xMS0yLjk4NC0x'
    b'LjA5NyAwLjQ3Ni0wLjAxMyAyLjUwOHptLTQuNjM2IDMuOTUxIDEuNDgzLTMuOTg2LTEuNDY2'
    b'IDAuNjM2LTAuMDE3IDMuMzV6bTMuMjgtNy4yODQgMS40ODMtMy45ODUtMS40NjUgMC42MzUt'
    b'MC4wMTggMy4zNXptMTUuMzk2LTEwLjAxNiAwLjkwMi0yLjQyNi0wLjg5MSAwLjM4Ni0wLjAx'
    b'MSAyLjA0em0tMjMuNjYzIDguNDQxIDEuOTk4LTUuMzczLTEuOTc0IDAuODU4LTAuMDI0IDQu'
    b'NTE1em0yNi45OTkgOC4zMTEgMC45MDMtMi40MjYtMC44OTIgMC4zODYtMC4wMTEgMi4wNHpt'
    b'MS44MjQtOC42NjggMC45MDMtMi40MjYtMC44OTIgMC4zODctMC4wMTEgMi4wMzl6bS00Ljc4'
    b'OCAyMi4xMzEgMC45MDMtMi40MjYtMC44OTIgMC4zODYtMC4wMTEgMi4wNHptLTQxLjE2OCA5'
    b'LjY1OCAwLjQwMi0zLjIxNS0wLjk3NiAwLjcyNyAwLjU3NCAyLjQ4OHptMzcuMzIzLTI1Ljg0'
    b'NSAwLjkwMi0yLjQyNi0wLjg5MSAwLjM4Ni0wLjAxMSAyLjA0em0wLjU1NSA3Ljc2OCAwLjkw'
    b'Mi0yLjQyNi0wLjg5MiAwLjM4Ni0wLjAxIDIuMDR6bS04LjQwOC00LjE5NSAwLjkwMy0yLjQy'
    b'Ni0wLjg5MiAwLjM4Ni0wLjAxMSAyLjA0em00Ljg0MSAxMS42MDEgMC45MDItMi40MjYtMC44'
    b'OTIgMC4zODYtMC4wMSAyLjA0em0tMy45OTUtNC45ODggMC45MDItMi40MjctMC44OTIgMC4z'
    b'ODctMC4wMSAyLjA0em0tMzUuNTg1LTcuODkzIDEuNDgyLTMuOTg0LTEuNDY1IDAuNjM0LTAu'
    b'MDE3IDMuMzV6bTExLjMyMiAzOC45MjMtMC4wNTctMi40NTQtMC42NSAwLjY1NCAwLjcwNyAx'
    b'Ljh6bS0xMS41NjgtMjQuNjg1IDAuNjgzLTMuMTU0LTEuMDMyIDAuNjM1IDAuMzQ5IDIuNTE5'
    b'em0yLjk4MS0xLjg1NyAwLjY4My0zLjE1NC0xLjAzMSAwLjYzNSAwLjM0OCAyLjUxOXptMS4x'
    b'MzcgNS43NTIgMC42ODMtMy4xNTQtMS4wMzEgMC42MzYgMC4zNDggMi41MTh6bS0zLjUzOSAz'
    b'LjI2MSAwLjY2LTIuNTczLTAuODY5IDAuNDkgMC4yMDkgMi4wODN6bTIuMjk2IDYuNTYtMC4w'
    b'NjMtMi42NTUtMC43MDMgMC43MDcgMC43NjYgMS45NDh6bTMuNzU4IDQuODg3LTAuMDYyLTIu'
    b'NjU2LTAuNzA0IDAuNzA4IDAuNzY2IDEuOTQ4em0yLjAzNi00LjYwNC0wLjA2My0yLjY1Ni0w'
    b'LjcwMyAwLjcwOCAwLjc2NiAxLjk0OHptLTAuMDE1LTcuNDg5IDAuNDAzLTMuMjE1LTAuOTc2'
    b'IDAuNzI4IDAuNTczIDIuNDg3em01LjkxOSAyLjU5NSAwLjk0Ny0zLjA5OS0xLjA4NyAwLjU1'
    b'IDAuMTQgMi41NDl6bS0zLjkxNS0yMC4zODcgMS40ODMtMy45ODUtMS40NjUgMC42MzYtMC4w'
    b'MTggMy4zNDl6bS0zLjMwOSAxMi44MDEgMC45LTQuMTU1LTEuMzU5IDAuODM2IDAuNDU5IDMu'
    b'MzE5em01LjQ5NCAzLjcyOCAwLjc2Ny00LjE4Mi0xLjMzMSAwLjg4IDAuNTY0IDMuMzAyem00'
    b'LjQ4Ni0zLjMxMSAwLjktNC4xNTUtMS4zNTkgMC44MzcgMC40NTkgMy4zMTh6bTQuMDktNC40'
    b'MSAwLjkwMS00LjE1NS0xLjM2IDAuODM3IDAuNDU5IDMuMzE4em0tNi43MDkgMC41NDMgMC45'
    b'LTQuMTU1LTEuMzU5IDAuODM3IDAuNDU5IDMuMzE4em0tMy45OTIgMS41NjUgMC45LTQuMTU1'
    b'LTEuMzU5IDAuODM2IDAuNDU5IDMuMzE5em0tMi4yMTUtNS41NDcgMS40ODItMy45ODUtMS40'
    b'NjQgMC42MzYtMC4wMTggMy4zNDl6bS0xMC41NTktMTMuMjA2IDEuMTEtMi45ODUtMS4wOTgg'
    b'MC40NzYtMC4wMTIgMi41MDl6bTQxLjAyOSA3LjA1NSAwLjkwMy0yLjQyNi0wLjg5MyAwLjM4'
    b'Ni0wLjAxIDIuMDR6bS0zNC43MjktMTQuMTM3IDEuNDgyLTMuOTg1LTEuNDY1IDAuNjM1LTAu'
    b'MDE3IDMuMzV6bS0yLjQyMyA1LjcxOSAxLjQ4Mi0zLjk4Ni0xLjQ2NSAwLjYzNi0wLjAxNyAz'
    b'LjM1em0xOC4zMDMgMi40MTIgMS40ODItMy45ODYtMS40NjUgMC42MzUtMC4wMTcgMy4zNTF6'
    b'bS0zLjI2MSAyLjI0MyAxLjQ4My0zLjk4NS0xLjQ2NSAwLjYzNS0wLjAxOCAzLjM1em0tMi44'
    b'ODggMi44MTIgMS40ODItMy45ODUtMS40NjQgMC42MzUtMC4wMTggMy4zNXptLTEwLjA2NiAw'
    b'LjM2IDEuNDgyLTMuOTg1LTEuNDY1IDAuNjM0LTAuMDE3IDMuMzUxem0wLjU1NCA0LjcyNCAx'
    b'LjQ4Mi0zLjk4NS0xLjQ2NCAwLjYzNS0wLjAxOCAzLjM1em0zNy45MTktMTcuMjI4IDAuOTA0'
    b'LTIuNDI2LTAuODkzIDAuMzg3LTAuMDExIDIuMDM5em0tMjkuNjk4LTAuOTAyIDEuOTk4LTUu'
    b'MzcyLTEuOTc1IDAuODU2LTAuMDIzIDQuNTE2em00LjQ3MS0wLjY5NiAxLjk5OC01LjM3My0x'
    b'Ljk3NCAwLjg1Ny0wLjAyNCA0LjUxNnptLTguNzk3IDEuODAxIDEuOTk5LTUuMzcxLTEuOTc1'
    b'IDAuODU2LTAuMDI0IDQuNTE1em0zOC4yNzUtMTIuMDkxIDAuOTAzLTIuNDI2LTAuODkzIDAu'
    b'Mzg2LTAuMDEgMi4wNHptLTM2LjYyMiA0OC4yNDQgMC40MDItMy4yMTYtMC45NzYgMC43Mjgg'
    b'MC41NzQgMi40ODh6bTQ4LjI1NiA3Ny40NjMtMC4wMjgtMi40NTUtMC42NTggMC42NDYgMC42'
    b'ODYgMS44MDl6bS00LjgwOC0xLjE0Ni0wLjAyOC0yLjQ1NS0wLjY1OCAwLjY0NiAwLjY4NiAx'
    b'LjgwOXptOC4wNTItMi44OTgtMC4wMjgtMi40NTUtMC42NTggMC42NDYgMC42ODYgMS44MDl6'
    b'bS0yOS40NjgtMjUuMDY1IDAuNDQyLTMuMjExLTAuOTg1IDAuNzE2IDAuNTQzIDIuNDk1em0y'
    b'Mi44MzEtMy45ODMgMC45MzMtMi40MTUtMC44OTcgMC4zNzUtMC4wMzYgMi4wNHptLTEuMjMz'
    b'IDguNjQ5LTAuMDI4LTIuNDU1LTAuNjU4IDAuNjQ2IDAuNjg2IDEuODA5em0tMTIuMjY4IDgu'
    b'MDgzLTAuMDQxLTMuNjQxLTAuOTc1IDAuOTU5IDEuMDE2IDIuNjgyem05LjY0NyAxLjE2Mi0w'
    b'LjAyOC0yLjQ1NS0wLjY1OCAwLjY0NiAwLjY4NiAxLjgwOXptLTYuMzY4LTQ3LjUwOSAxLjQ1'
    b'NS0zLjc2Ny0xLjM5OSAwLjU4Ni0wLjA1NiAzLjE4MXptNS45MjIgMzQuOTI5IDAuNzIyLTMu'
    b'MTQ1LTEuMDM5IDAuNjIyIDAuMzE3IDIuNTIzem0yLjgzNS0xMS4yNzMgMC40Mi0yLjY5LTAu'
    b'ODM4IDAuNTg3IDAuNDE4IDIuMTAzem0tMy4yMTMgNS42OTkgMC40OS0zLjE0Ny0wLjk4IDAu'
    b'Njg2IDAuNDkgMi40NjF6bTkuODcgMTkuMTA1LTAuMDI3LTIuNDU1LTAuNjU4IDAuNjQ2IDAu'
    b'Njg1IDEuODA5em0tMy4wMDctNy41NDEtMC4wMjgtMi40NTUtMC42NTcgMC42NDYgMC42ODUg'
    b'MS44MDl6bS01LjI0Ni0yOS41NDEgMC45MzItMi40MTYtMC44OTYgMC4zNzYtMC4wMzYgMi4w'
    b'NHptNC44NTEgMTAuNjcyIDAuOTMyLTIuNDE1LTAuODk3IDAuMzc1LTAuMDM1IDIuMDR6bS01'
    b'Ljc4NC0zLjkyOSAwLjkzMi0yLjQxNS0wLjg5NyAwLjM3NS0wLjAzNSAyLjA0em0tMTMuOTkt'
    b'MjguMTUgMS4zNDktMy40OTQtMS4yOTcgMC41NDMtMC4wNTIgMi45NTF6bS05LjcgMjUuMTU5'
    b'IDEuNTMxLTMuOTY2LTEuNDczIDAuNjE2LTAuMDU4IDMuMzV6bTIwLjM2OC0yLjYzMyAwLjkz'
    b'My0yLjQxNS0wLjg5NyAwLjM3NS0wLjAzNiAyLjA0em0yLjAwOCA0NS4yMTItMC4wMjgtMi40'
    b'NTUtMC42NTggMC42NDYgMC42ODYgMS44MDl6bTcuODM4LTIuNDM5LTAuMDI4LTIuNDU1LTAu'
    b'NjU4IDAuNjQ2IDAuNjg2IDEuODA5em0tMi45MTQtNy44MzUtMC4wMjgtMi40NTUtMC42NTgg'
    b'MC42NDYgMC42ODYgMS44MDl6bS0xNS45NTIgMS4zODgtMC4wMjctMi40NTUtMC42NTggMC42'
    b'NDYgMC42ODUgMS44MDl6bTYuMjk1IDUuMDk3LTAuMDI4LTIuNDU1LTAuNjU4IDAuNjQ2IDAu'
    b'Njg2IDEuODA5em0wLjE1LTQuODUtMC4wMjgtMi40NTUtMC42NTggMC42NDYgMC42ODYgMS44'
    b'MDl6bS0xOC41MjQtMjYuNTkxIDAuNzIzLTMuMTQ1LTEuMDQgMC42MjIgMC4zMTcgMi41MjN6'
    b'bTIuNzQ2IDIuMzAyIDAuNzIyLTMuMTQ1LTEuMDM5IDAuNjIzIDAuMzE3IDIuNTIyem0yLjI1'
    b'NyAzLjk0NiAwLjM0OC00LjIzNy0xLjIzOCAxLjAwOCAwLjg5IDMuMjI5em0tMy42ODYgMC43'
    b'OTUgMC42OTItMi41NjUtMC44NzUgMC40NzkgMC4xODMgMi4wODZ6bTIuOTU3IDcuMzQ4LTAu'
    b'MDMtMi42NTctMC43MTIgMC42OTkgMC43NDIgMS45NTh6bTIuNjI5IDMuNTg4LTAuMDMtMi42'
    b'NTYtMC43MTIgMC42OTkgMC43NDIgMS45NTd6bTMuMzk1IDIuMTc2LTAuMDI5LTIuNjU2LTAu'
    b'NzEyIDAuNjk5IDAuNzQxIDEuOTU3em05LjMwNi0xNC4wMTYgMC40OTEtMy4xNDYtMC45OCAw'
    b'LjY4NiAwLjQ4OSAyLjQ2em0tOS4yODYtMTUuNjM4IDEuNTMyLTMuOTY3LTEuNDczIDAuNjE4'
    b'LTAuMDU5IDMuMzQ5em0tMy4wMSAxMS4wNTUgMC45NTEtNC4xNDMtMS4zNjkgMC44MiAwLjQx'
    b'OCAzLjMyM3ptNS41MzEgOC4yMzkgMC44MTktNC4xNzItMS4zNDIgMC44NjMgMC41MjMgMy4z'
    b'MDl6bTQuNjM3LTguMDggMC45NTEtNC4xNDQtMS4zNjkgMC44MiAwLjQxOCAzLjMyNHptMi4z'
    b'MDctNC43OCAwLjk1Mi00LjE0NC0xLjM3IDAuODIgMC40MTggMy4zMjR6bS00Ljk3NSAyLjEw'
    b'MiAwLjk1MS00LjE0NC0xLjM2OSAwLjgyIDAuNDE4IDMuMzI0em0tNC4wMjcgMS4yNTMgMC45'
    b'NTEtNC4xNDQtMS4zNjkgMC44MjEgMC40MTggMy4zMjN6bS0xLjIxOC00LjgzMiAxLjUzLTMu'
    b'OTY3LTEuNDcyIDAuNjE3LTAuMDU4IDMuMzV6bTE0LjAwOC0xOS44OTYgMC45MzMtMi40MTUt'
    b'MC44OTcgMC4zNzUtMC4wMzYgMi4wNHptMy40ODQgMi4wNzYgMC45MzItMi40MTUtMC44OTYg'
    b'MC4zNzUtMC4wMzYgMi4wNHptMS43IDQuODcyIDAuOTMzLTIuNDE1LTAuODk3IDAuMzc1LTAu'
    b'MDM2IDIuMDR6bS01LjIwNCAxLjEwNSAwLjkzMy0yLjQxNC0wLjg5NiAwLjM3Ni0wLjAzNyAy'
    b'LjAzOHptLTEuNDk2IDkuMzU4IDAuOTMzLTIuNDE1LTAuODk3IDAuMzc2LTAuMDM2IDIuMDM5'
    b'em02Ljk4NS0yLjU2OSAwLjkzNC0yLjQxNS0wLjg5OCAwLjM3NS0wLjAzNiAyLjA0em0tMjQu'
    b'NjkxLTE4LjU1MyAwLjkzMy0yLjQxNS0wLjg5NyAwLjM3Ni0wLjAzNiAyLjAzOXptLTAuMjQ2'
    b'IDQuNTAxIDEuNTMxLTMuOTY2LTEuNDczIDAuNjE3LTAuMDU4IDMuMzQ5em0tMi45OTggNC42'
    b'OTYgMS41MzItMy45NjctMS40NzMgMC42MTctMC4wNTkgMy4zNXptMTQuMDI2LTMuMTExIDEu'
    b'NTMyLTMuOTY3LTEuNDczIDAuNjE3LTAuMDU5IDMuMzV6bTQuNTUgMi41NTkgMS41MzItMy45'
    b'NjctMS40NzQgMC42MTctMC4wNTggMy4zNXptLTAuMzM5IDUuOTYxIDEuMzIzLTMuNDI1LTEu'
    b'MjczIDAuNTMzLTAuMDUgMi44OTJ6bS02LjcwOCA3Ljg0IDEuODI5LTQuNzM2LTEuNzU5IDAu'
    b'NzM3LTAuMDcgMy45OTl6bTMuNTkyLTEwLjY4NCAxLjUzMS0zLjk2Ny0xLjQ3MyAwLjYxOC0w'
    b'LjA1OCAzLjM0OXptLTIuNjM2IDMuODI0IDEuNTMxLTMuOTY3LTEuNDczIDAuNjE3LTAuMDU4'
    b'IDMuMzV6bS0xMC4yNDEgMC44NDYgMS41MzItMy45NjctMS40NzMgMC42MTctMC4wNTkgMy4z'
    b'NXptLTIuNjI1LTAuNjQ4IDEuNTMxLTMuOTY3LTEuNDczIDAuNjE3LTAuMDU4IDMuMzV6bTE2'
    b'LjIzNiA1Ljg5MSAxLjUzMi0zLjk2Ny0xLjQ3MyAwLjYxNy0wLjA1OSAzLjM1em00LjI2Mi0y'
    b'MS4wMjcgMS40NTQtMy43NjctMS4zOTkgMC41ODYtMC4wNTUgMy4xODF6bS03LjkwNSAyLjQ4'
    b'OSAyLjA2NC01LjM0Ny0xLjk4NiAwLjgzMi0wLjA3OCA0LjUxNXptLTIuMjQ4LTIuMjYyIDIu'
    b'MDY1LTUuMzQ2LTEuOTg2IDAuODMxLTAuMDc5IDQuNTE1em0tMi43ODMgMy41NzEgMi4wNjQt'
    b'NS4zNDctMS45ODUgMC44MzItMC4wNzkgNC41MTV6bTExLjQ2NS0xMC4xMyAxLjQ1My0zLjc2'
    b'Ny0xLjM5NyAwLjU4Ni0wLjA1NiAzLjE4MXptMi4yNjIgMS40MDkgMC45MzItMi40MTUtMC44'
    b'OTcgMC4zNzUtMC4wMzUgMi4wNHptOS42NjYgMS44OTkgMC45MzItMi40MTUtMC44OTYgMC4z'
    b'NzUtMC4wMzYgMi4wNHptLTAuNzYxLTkuNTczIDAuOTMyLTIuNDE1LTAuODk2IDAuMzc1LTAu'
    b'MDM2IDIuMDR6bS0zLjQwMSA1LjY0NCAwLjkzMi0yLjQxNS0wLjg5NyAwLjM3Ni0wLjAzNSAy'
    b'LjAzOXptLTguNjgtNC4zNiAwLjkzMy0yLjQxNi0wLjg5NyAwLjM3Ni0wLjAzNiAyLjA0em0t'
    b'My4wOTUgOC4wNDMgMi4wNjQtNS4zNDctMS45ODUgMC44MzEtMC4wNzkgNC41MTZ6bS0xLjUz'
    b'Ni00LjIzNSAxLjUxNC0zLjkyLTEuNDU2IDAuNjEtMC4wNTggMy4zMXptMTMuMjA5IDY2LjU4'
    b'Ny0wLjAyOC0yLjQ1NS0wLjY1OCAwLjY0NiAwLjY4NiAxLjgwOXptLTEwLjU4MS0yNC4xNzEt'
    b'MC4wNDMtMy42NDEtMC45NzUgMC45NTkgMS4wMTggMi42ODJ6bS0yLjc3OS0yLjkxOSAxLjEw'
    b'Ni0zLjQ2OS0xLjIyNyAwLjYwMiAwLjEyMSAyLjg2N3ptNS4wMDUgMTEuNTQtMC4wNDItMy42'
    b'NDEtMC45NzUgMC45NTggMS4wMTcgMi42ODN6bS0wLjkzOCA0LjgtMC4wNDEtMy42NDEtMC45'
    b'NzUgMC45NTggMS4wMTYgMi42ODN6bTIuNTAzIDMuMTI5LTAuMDQtMy42NDEtMC45NzYgMC45'
    b'NTggMS4wMTYgMi42ODN6bTIuMTg0IDYuNzY0LTAuMDMyLTIuODg0LTAuNzczIDAuNzU5IDAu'
    b'ODA1IDIuMTI1em0tODUuODM0LTEzMS40NiAzLjIyNS0wLjU2NS0xLjAyLTAuNTYxLTIuMjA1'
    b'IDEuMTI2em0xLjgyNiA0LjY5MiAyLjQ1Mi0wLjQyOC0wLjc3Ni0wLjQyNy0xLjY3NiAwLjg1'
    b'NXptOTMuMDY3IDMyLjM4MiAwLjM0NC0yLjU2Ni0wLjc4MyAwLjU3NCAwLjQzOSAxLjk5Mnpt'
    b'LTIuODkyLTE3LjU5NiAwLjM0NS0yLjU2NS0wLjc4NSAwLjU3NCAwLjQ0IDEuOTkxem0tMC44'
    b'MzYgMjkuNzYxIDAuMzQ1LTIuNTY3LTAuNzg0IDAuNTc0IDAuNDM5IDEuOTkzem0tNjIuNjA2'
    b'IDQwLjczNSAxLjMzNy0zLjM3MS0xLjI2MiAwLjUxNS0wLjA3NSAyLjg1NnptOC4yMzMgMTEu'
    b'NjIgMC42OTUtNC4xOTUtMS4zMTcgMC45MDIgMC42MjIgMy4yOTN6bS01LjIyMy0wLjU3MSAy'
    b'LjExMy01LjMyOC0xLjk5MyAwLjgxNC0wLjEyIDQuNTE0em0yLjYwMS0xMi45MTcgMi4xMTQt'
    b'NS4zMjgtMS45OTMgMC44MTQtMC4xMjEgNC41MTR6bS0yLjY3NSA2Ljk4OCAyLjExMy01LjMy'
    b'OC0xLjk5MyAwLjgxNC0wLjEyIDQuNTE0em0zLjE1OCA0LjAxMiAyLjExNC01LjMyOC0xLjk5'
    b'NCAwLjgxNC0wLjEyIDQuNTE0em0tMC4wNTgtNS40NDUgMi4xMTMtNS4zMjktMS45OTIgMC44'
    b'MTQtMC4xMjEgNC41MTV6bTQuOTgzIDcuOTYyIDAuNjk0LTQuMTk0LTEuMzE3IDAuOTAyIDAu'
    b'NjIzIDMuMjkyem0yLjY4Ni00LjA2MSAxLjU2Ny0zLjk1Mi0xLjQ3NyAwLjYwMy0wLjA5IDMu'
    b'MzQ5em0tMS4zOTktMy40NDggMi4xMTMtNS4zMjgtMS45OTMgMC44MTQtMC4xMiA0LjUxNHpt'
    b'LTExLjgzNyAxLjU4OSAxLjMzNi0zLjM3MS0xLjI2MSAwLjUxNS0wLjA3NSAyLjg1NnptMi41'
    b'MTktNi44NzMgMS4zMzctMy4zNzEtMS4yNjEgMC41MTUtMC4wNzYgMi44NTZ6bS0zZS0zIC0z'
    b'Ljc5NiAxLjMzNy0zLjM3MS0xLjI2MiAwLjUxNS0wLjA3NSAyLjg1NnptLTEuODE0IDE2LjIz'
    b'OCAwLjY4NS0zLjU3Ny0xLjE0NyAwLjc0NSAwLjQ2MiAyLjgzMnptMi4wOTkgMy44NDYgMC42'
    b'ODUtMy41NzYtMS4xNDcgMC43NDQgMC40NjIgMi44MzJ6bS0wLjIwMyAxOS40MDggMC40LTIu'
    b'NDIyLTAuNzYgMC41MjEgMC4zNiAxLjkwMXptNC42NzQtMTIuMDA1IDAuNDAxLTIuNDIyLTAu'
    b'NzYxIDAuNTIxIDAuMzYgMS45MDF6bTEuNjI2LTEuOTQ0IDAuNjg1LTMuNTc2LTEuMTQ3IDAu'
    b'NzQ0IDAuNDYyIDIuODMyem0tMC40MzYtNC42MDYgMC42ODUtMy41NzctMS4xNDcgMC43NDUg'
    b'MC40NjIgMi44MzJ6bS03LjUxNiA0LjU5MiAwLjQzNC0yLjYyMS0wLjgyMyAwLjU2NCAwLjM4'
    b'OSAyLjA1N3ptMi4zMjIgMS41ODIgMC41MjYtMi4yOTUtMC43NTkgMC40NTQgMC4yMzMgMS44'
    b'NDF6bTMuNzY1IDUuNDE4IDAuNDAxLTIuNDIyLTAuNzYxIDAuNTIyIDAuMzYgMS45em01Ljg4'
    b'OS0xMy43MTggMC42OTUtNC4xOTUtMS4zMTYgMC45MDMgMC42MjEgMy4yOTJ6bS00LjE0OC03'
    b'LjUxMiAxLjU2Ny0zLjk1Mi0xLjQ3OCAwLjYwMy0wLjA4OSAzLjM0OXptMC4zNTMtNC44NDcg'
    b'Mi4xMTMtNS4zMjktMS45OTMgMC44MTQtMC4xMiA0LjUxNXptLTMuNTg5LTkuOTM4IDEuMzM2'
    b'LTMuMzcxLTEuMjYxIDAuNTE1LTAuMDc1IDIuODU2em0yLjcyMSA0NC41MjcgMC40MDEtMi40'
    b'MjItMC43NjEgMC41MjEgMC4zNiAxLjkwMXptMy43Ny0xMi45MzIgMC41MjYtMi4yOTUtMC43'
    b'NTggMC40NTMgMC4yMzIgMS44NDJ6bS0xMy45NTUtMTYuNDAxIDAuNTI3LTIuMjk1LTAuNzU5'
    b'IDAuNDU0IDAuMjMyIDEuODQxem0yLjc1NyAxOS40ODQgMC41MjctMi4yOTUtMC43NTggMC40'
    b'NTQgMC4yMzEgMS44NDF6bS0wLjk3Ny05Ljg5MyAwLjUyOC0yLjI5NS0wLjc1OSAwLjQ1NCAw'
    b'LjIzMSAxLjg0MXptMjEuNjc3LTEuOTg2IDAuNDAxLTIuNDIyLTAuNzYgMC41MjEgMC4zNTkg'
    b'MS45MDF6bS0xOC4xNzUgMy41MDQgMC41MjctMi4yOTUtMC43NTkgMC40NTMgMC4yMzIgMS44'
    b'NDJ6bTIuMTktMy4yOTggMC42ODUtMy41NzYtMS4xNDcgMC43NDUgMC40NjIgMi44MzF6bTku'
    b'NzUyIDAuODcgMS4xODYtMy42MzEtMS4yOTIgMC42MjIgMC4xMDYgMy4wMDl6bTIuODAxIDgu'
    b'OTQxIDAuNTk1LTMuMTcxLTEuMDE0IDAuNjYzIDAuNDE5IDIuNTA4em0wLjIyNS02Ljg0MSAw'
    b'LjQwMS0yLjQyMi0wLjc2IDAuNTIxIDAuMzU5IDEuOTAxem0tMy45OTYgOS43MTQgMC40MDEt'
    b'Mi40MjItMC43NiAwLjUyMiAwLjM1OSAxLjl6bTYuODc5IDAuNzE1IDAuNDAxLTIuNDIyLTAu'
    b'NzYxIDAuNTIxIDAuMzYgMS45MDF6bTEuMDMtNy41NzQgMC40MDEtMi40MjItMC43NiAwLjUy'
    b'MSAwLjM1OSAxLjkwMXptLTQuODkgMTcuOTcgMC4xMzctMi40NTEtMC43IDAuNiAwLjU2MyAx'
    b'Ljg1MXptMy44NC0zLjQzNyAwLjQwMS0yLjQyMS0wLjc2IDAuNTIxIDAuMzU5IDEuOXptLTMu'
    b'NTU3LTMuNzI0IDAuNDAxLTIuNDIyLTAuNzYgMC41MjEgMC4zNTkgMS45MDF6bS0xMi44ODkt'
    b'MC40NzMgMC40LTIuNDIyLTAuNzYgMC41MjEgMC4zNiAxLjkwMXptMC4wMjYtNS44NzkgMC40'
    b'MDEtMi40MjItMC43NjEgMC41MjEgMC4zNiAxLjkwMXptMTAuMzA1LTMuNDc0IDAuNTk1LTMu'
    b'MTcyLTEuMDEzIDAuNjY0IDAuNDE4IDIuNTA4em0tMTcuNzUtOC42OTEgMC40MzQtMi42MjEt'
    b'MC44MjMgMC41NjQgMC4zODkgMi4wNTd6bTAuNjg3IDYuODU2IDAuNDM1LTIuNjItMC44MjMg'
    b'MC41NjQgMC4zODggMi4wNTZ6bTE1LjgyMiAxNC44NzMgMC40MDEtMi40MjItMC43NjEgMC41'
    b'MjEgMC4zNiAxLjkwMXptLTIuMDg2LTE1LjQ3OCAwLjY5NC00LjE5NS0xLjMxNiAwLjkwMyAw'
    b'LjYyMiAzLjI5MnptLTUuNTc1IDAuNTExIDAuNTk1LTMuNTkyLTEuMTI3IDAuNzc0IDAuNTMy'
    b'IDIuODE4em0zLjM3IDUuNjg2IDAuNTk1LTMuNTkzLTEuMTI4IDAuNzczIDAuNTMzIDIuODJ6'
    b'bTAuOTQ5IDUuNDUxIDAuNDcxLTIuODQ2LTAuODkzIDAuNjEzIDAuNDIyIDIuMjMzem03LjYy'
    b'MS0xOC4yNzQgMS4wMTktMi41Ny0wLjk2MiAwLjM5Mi0wLjA1NyAyLjE3OHptNS4xOS0yLjg4'
    b'NyAxLjIyOC0zLjA5OC0xLjE1OSAwLjQ3My0wLjA2OSAyLjYyNXptLTYuODgzLTAuMDIyIDEu'
    b'NTY4LTMuOTUzLTEuNDc5IDAuNjAzLTAuMDg5IDMuMzV6bTMuMjQ2LTIuMjIyIDEuNTY3LTMu'
    b'OTUyLTEuNDc5IDAuNjAzLTAuMDg4IDMuMzQ5em0tOS4xMjUtMTMuMiAxLjU2Ny0zLjk1Mi0x'
    b'LjQ3OSAwLjYwMy0wLjA4OCAzLjM0OXptMi4xMjMgMy4wMDggMS41NjctMy45NTItMS40Nzkg'
    b'MC42MDMtMC4wODggMy4zNDl6bTIuMTE2IDMuNjE2IDEuNTY3LTMuOTUzLTEuNDc5IDAuNjAz'
    b'LTAuMDg4IDMuMzV6bTEuOTEyIDMuMDk1IDEuNTY3LTMuOTUyLTEuNDc4IDAuNjAzLTAuMDg5'
    b'IDMuMzQ5em0tOS43MzYtMTYuMzk4IDEuMzM3LTMuMzcyLTEuMjYyIDAuNTE1LTAuMDc1IDIu'
    b'ODU3em0xLjEyIDEwLjc2NSAxLjgwMi00LjU0NS0xLjY5OSAwLjY5NS0wLjEwMyAzLjg1em0w'
    b'LjU1OS02LjEyIDEuODAzLTQuNTQ2LTEuNyAwLjY5NS0wLjEwMyAzLjg1MXptMTUuNzQzLTEw'
    b'Mi4yMiAyLjA5OS0yLjM5NC0xLjE5NCAwLjA1NC0wLjkwNSAyLjM0em00MC40NTYtMjAuMTkx'
    b'IDIuNjYzLTMuMDM2LTEuNTE0IDAuMDY5LTEuMTQ5IDIuOTY3em0tMy42OC0xLjg4MiAzLjc3'
    b'OS00LjMwOS0yLjE1IDAuMDk3LTEuNjI5IDQuMjEyem0tMjguNTgyIDQ0Ljk4NiAyLjA4Ny0x'
    b'LjUzMy0wLjk1OC0wLjE2Ni0xLjEyOSAxLjY5OXptOC40NDMtMS40NTkgMS41NC0yLjA4MS0w'
    b'Ljk2NSAwLjEyNC0wLjU3NSAxLjk1N3ptMTUuNjMyLTE2LjEzMiAyLjUyOC0zLjQxOS0xLjU4'
    b'MyAwLjIwNS0wLjk0NSAzLjIxNHptLTYuMTAyIDQuOTYyIDIuNTI4LTMuNDE5LTEuNTgzIDAu'
    b'MjA1LTAuOTQ1IDMuMjE0em0tNC41NjctMS4yOTEgMi41MjktMy40MTgtMS41ODMgMC4yMDUt'
    b'MC45NDYgMy4yMTN6bTExLjg3Ny0xNS42NzEgMi41MjktMy40MTgtMS41ODQgMC4yMDQtMC45'
    b'NDUgMy4yMTR6bS0xMC45MjEgMjIuMTIxIDEuNTQtMi4wODItMC45NjUgMC4xMjUtMC41NzUg'
    b'MS45NTd6bTEzLjQzNS0yMC4xMzMgMS41NC0yLjA4MS0wLjk2NSAwLjEyNC0wLjU3NSAxLjk1'
    b'N3ptNi41NDMtMTAuNzQ1IDEuNTQtMi4wODEtMC45NjUgMC4xMjUtMC41NzUgMS45NTZ6bS0x'
    b'LjM2NSA2Ljg2IDEuNTQtMi4wODEtMC45NjUgMC4xMjUtMC41NzUgMS45NTZ6bS00LjI1IDgu'
    b'MzIgMS41NC0yLjA4MS0wLjk2NSAwLjEyNC0wLjU3NSAxLjk1N3ptLTExLjU0MiAyMi42NDcg'
    b'MS41NC0yLjA4MS0wLjk2NSAwLjEyNS0wLjU3NSAxLjk1NnptMTQuMjQxLTUwLjc0IDEuNzA3'
    b'LTEuOTQ2LTAuOTcxIDAuMDQ0LTAuNzM2IDEuOTAyem0tOC41NjUgNDIuOTk3IDEuNTQtMi4w'
    b'ODItMC45NjUgMC4xMjQtMC41NzUgMS45NTh6bS0xNC40NjMtMC4yMDIgMy4wOTktMi45MTIt'
    b'MS41OTUtMC4wODItMS41MDQgMi45OTR6bTYuMzU5LTExLjkyNCAzLjc3OS00LjMwOS0yLjE1'
    b'IDAuMDk3LTEuNjI5IDQuMjEyem0tMjMuMTc0IDIuMzcxIDIuNDY5LTAuNzgxLTAuODUzLTAu'
    b'NDY2LTEuNjE2IDEuMjQ3em0xMC4xMyAxMS4wMjEgMi41MDgtMC42NDMtMC44MjctMC41MTIt'
    b'MS42ODEgMS4xNTV6bS02Ljk1NCAzLjU4NSAyLjUwOC0wLjY0My0wLjgyNy0wLjUxMi0xLjY4'
    b'MSAxLjE1NXptLTYuMDE1LTkuNzA2IDMuNTE3LTAuODcyLTEuMTUxLTAuNzI2LTIuMzY2IDEu'
    b'NTk4em0xMC42MTgtNC44NzIgMi44MDItMy4xOTctMS41OTUgMC4wNzMtMS4yMDcgMy4xMjR6'
    b'bS0zLjUzIDQuMjAxIDQuMTI3LTEuMDIzLTEuMzUxLTAuODUyLTIuNzc2IDEuODc1em0xMi40'
    b'MDItMTQuOTUgMy4zNDYtMy44MTUtMS45MDMgMC4wODYtMS40NDMgMy43Mjl6bTcuMTAzLTEy'
    b'LjI5MSAyLjQ4Mi0yLjgzLTEuNDEzIDAuMDY0LTEuMDY5IDIuNzY2em0zLjY0OCAyMS4wNDMg'
    b'Mi41MjktMy40MTgtMS41ODQgMC4yMDQtMC45NDUgMy4yMTR6bTMuNjk4LTMuMjYyIDIuNTI5'
    b'LTMuNDE5LTEuNTg0IDAuMjA1LTAuOTQ1IDMuMjE0em02LjkwNy0xMi4wNyAyLjUyOS0zLjQx'
    b'OS0xLjU4NCAwLjIwNS0wLjk0NSAzLjIxNHptLTI1LjQ5OCAxOS4wNDEgMy43NzktNC4zMDkt'
    b'Mi4xNSAwLjA5Ny0xLjYyOSA0LjIxMnptLTcuNDAxLTUuNDg4IDIuNDgxLTIuODMtMS40MTIg'
    b'MC4wNjQtMS4wNjkgMi43NjZ6bTMuMDE0IDkuOTUgNC4xMjctMS4wMjMtMS4zNS0wLjg1Mi0y'
    b'Ljc3NyAxLjg3NXptLTYuMzczIDIuOTI2IDMuMjQ0LTAuNzY3LTEuMDUyLTAuNjc5LTIuMTky'
    b'IDEuNDQ2em0xMy42NzktNC43NTEgNC41NjMtMy40NjgtMi4xMjYtMC4zMzQtMi40MzcgMy44'
    b'MDJ6bTIuMzg1LTUuMTg4IDMuNzc5LTQuMzA5LTIuMTUgMC4wOTYtMS42MjkgNC4yMTN6bTE2'
    b'Ljc1Ni0zMC4wODkgMi42NjItMy4wMzYtMS41MTQgMC4wNjktMS4xNDggMi45Njd6bTAuNzkg'
    b'OS43NjggMy43OC00LjMwOS0yLjE1MSAwLjA5Ny0xLjYyOSA0LjIxMnptNi40MzYgMTQuNTUg'
    b'MS41NC0yLjA4MS0wLjk2NSAwLjEyNS0wLjU3NSAxLjk1NnptLTI1LjY0NSAxLjY4MiAzLjc3'
    b'OS00LjMwOS0yLjE1IDAuMDk3LTEuNjI5IDQuMjEyem01LjA3LTUuNjk0IDMuNzc5LTQuMzA5'
    b'LTIuMTUgMC4wOTctMS42MjkgNC4yMTJ6bTYuNTA4IDIuNDk3IDMuNzc5LTQuMzA5LTIuMTUg'
    b'MC4wOTctMS42MjkgNC4yMTJ6bS01LjE1MiAyLjI2NSAzLjc3OS00LjMwOS0yLjE1MSAwLjA5'
    b'Ny0xLjYyOCA0LjIxMnptMy42NTQtNS42ODYgMy43NzktNC4zMDgtMi4xNSAwLjA5Ny0xLjYy'
    b'OSA0LjIxMXptMy4xNDEtMTMuNTc5IDMuMDUyLTMuNDc4LTEuNzM3IDAuMDc4LTEuMzE1IDMu'
    b'NHptNy4xNTYgMjcuNzggMS41MzktMi4wODItMC45NjQgMC4xMjUtMC41NzUgMS45NTd6bS0x'
    b'NC45NTUtMTkuNDYyIDMuMzQ2LTMuODE1LTEuOTAzIDAuMDg2LTEuNDQzIDMuNzI5em0xMS41'
    b'MTktOS4zMDggMi42NjItMy4wMzYtMS41MTQgMC4wNjktMS4xNDggMi45Njd6bS0yNS42MzUg'
    b'MTYuMzYyIDIuMS0yLjM5My0xLjE5NSAwLjA1NC0wLjkwNSAyLjMzOXptMTAuNDA5LTguMjAy'
    b'IDIuNDgxLTIuODMtMS40MTMgMC4wNjQtMS4wNjggMi43NjZ6bS00LjcwMiA1LjQwMSAyLjQ4'
    b'Mi0yLjgzLTEuNDEyIDAuMDY0LTEuMDcgMi43NjZ6bS0xLjk1OSA2LjA5MiAyLjgwMi0zLjE5'
    b'Ny0xLjU5NSAwLjA3My0xLjIwNyAzLjEyNHptMTUuMDktOS4zNjEgMy43NzktNC4zMDktMi4x'
    b'NSAwLjA5Ny0xLjYyOSA0LjIxMnptLTAuODktMy40MjEgMy4zNDYtMy44MTUtMS45MDQgMC4w'
    b'ODctMS40NDIgMy43Mjh6bTUuNTg1IDMuOTk0IDMuNzgtNC4zMDktMi4xNTEgMC4wOTctMS42'
    b'MjkgNC4yMTJ6bS0wLjQyMS01LjEzOSAzLjc4LTQuMzEtMi4xNTEgMC4wOTctMS42MjkgNC4y'
    b'MTN6bS03Mi44NDUtMjIuMjY2IDAuNjQ3IDEuOTEzIDAuMzUtMC42NzMtMC45OTctMS4yNHpt'
    b'MC45NjUgNy40MTEgMC42NDcgMS45MTMgMC4zNS0wLjY3My0wLjk5Ny0xLjI0em0tNC44MDct'
    b'My4zODYgMC42NDcgMS45MTQgMC4zNS0wLjY3My0wLjk5Ny0xLjI0MXptMjEuMzIgMTYuMTMy'
    b'IDIuMjQxIDEuMjk3LTAuMjMyLTAuOTQ1LTIuMDA5LTAuMzUyem0tMTEuODkyIDEuOTc0IDEu'
    b'NzkxIDEuODcgMC4wNC0wLjk3Mi0xLjgzMS0wLjg5OHptLTE0Ljg3Mi05LjMwMiAxLjE5MSAy'
    b'LjI5OSAwLjMxMy0wLjkyMS0xLjUwNC0xLjM3OHptLTAuOTY4LTQuNTAzIDEuMTkxIDIuMjk5'
    b'IDAuMzEzLTAuOTIxLTEuNTA0LTEuMzc4em0yMy45ODggMjYuNDQ1IDIuOTA3IDIuMTctMC4x'
    b'NjktMS4zNTItMi43MzgtMC44MTh6bS04Ljc5OC0yNi43MTUgMC42NDcgMS45MTMgMC4zNS0w'
    b'LjY3My0wLjk5Ny0xLjI0em0tOS42NDYgMC4yMzUgMS4xOTIgMi4yOTggMC4zMTItMC45MjEt'
    b'MS41MDQtMS4zNzd6bTMuMjY0IDIwLjkxNCAzLjQwOCAyLjU0My0wLjE5Ny0xLjU4NC0zLjIx'
    b'MS0wLjk1OXptLTAuNjk2IDIuNzk1IDMuNDA3IDIuNTQzLTAuMTk3LTEuNTg0LTMuMjEtMC45'
    b'NTl6bTI2LjE5LTcuNjU2IDIuMjQxIDEuMjk3LTAuMjMyLTAuOTQ1LTIuMDA5LTAuMzUyem0t'
    b'MjkuMzcyLTMuMTU3IDEuNjY4IDEuOTggMC4xMDItMC45NjctMS43Ny0xLjAxM3ptNi41OTQg'
    b'MS4xNzUgMi43NzYgMy4yMiAwLjE1LTEuNTg5LTIuOTI2LTEuNjMxem0xMy43NzggOS41NzMg'
    b'Mi45MDcgMi4xNjktMC4xNjgtMS4zNTItMi43MzktMC44MTd6bTkuOTk2LTIuMDU5IDIuMjQx'
    b'IDEuMjk3LTAuMjMxLTAuOTQ1LTIuMDEtMC4zNTJ6bS01LjI2NC0zLjY4OSAyLjI0MiAxLjI5'
    b'Ny0wLjIzMy0wLjk0NS0yLjAwOS0wLjM1MnptLTIuOTc5IDIuNzQgMi4yNDEgMS4yOTctMC4y'
    b'MzItMC45NDUtMi4wMDktMC4zNTJ6bTMuODQ4IDIuNzU3IDIuMjQxIDEuMjk2LTAuMjMyLTAu'
    b'OTQ1LTIuMDA5LTAuMzUxem0zLjc5NyAzLjY0MiAyLjI0MSAxLjI5Ni0wLjIzMi0wLjk0NS0y'
    b'LjAwOS0wLjM1MXptLTQuNTU3IDAuMzM4IDIuOTA3IDIuMTY5LTAuMTY5LTEuMzUxLTIuNzM4'
    b'LTAuODE4em0tMTcuNjI2LTIyLjU4OCAxLjE5IDIuMjk5IDAuMzE0LTAuOTIxLTEuNTA0LTEu'
    b'Mzc4em0tNC4xNDkgMy43MjYgMS45MyAzLjc4OSAwLjUyNC0xLjUwOC0yLjQ1NC0yLjI4MXpt'
    b'LTQuNTY2LTQuOTM5IDEuOTMgMy43ODkgMC41MjQtMS41MDgtMi40NTQtMi4yODF6bTUuMDMz'
    b'IDEuMzExIDEuMTkxIDIuMjk5IDAuMzEyLTAuOTIxLTEuNTAzLTEuMzc4em0xMi44NDcgMS40'
    b'MzUgMS4xOTEgMi4yOTkgMC4zMTMtMC45MjEtMS41MDQtMS4zNzh6bS04Ljc4MyAzLjMgMS4x'
    b'OTEgMi4yOTkgMC4zMTMtMC45MjEtMS41MDQtMS4zNzh6bTEzLjA3MiA1LjUxMiAxLjc5MSAx'
    b'Ljg2OSAwLjA0LTAuOTcxLTEuODMxLTAuODk4em0tNi41OTYgMC44OTcgMS43OTEgMS44Njkg'
    b'MC4wNDEtMC45NzItMS44MzItMC44OTd6bTQuMDYyIDEuNDQxIDEuNzkxIDEuODcgMC4wNDEt'
    b'MC45NzItMS44MzItMC44OTh6bS02LjM5OS0xMS45OTYgMS4xOTEgMi4yOTkgMC4zMTMtMC45'
    b'MjEtMS41MDQtMS4zNzh6bTUuMjcgNi4yMjggMS4xOTEgMi4yOTkgMC4zMTItMC45MjEtMS41'
    b'MDMtMS4zNzh6bS01LjExOC0xLjQzMyAxLjE5MSAyLjI5OCAwLjMxMy0wLjkyMS0xLjUwNC0x'
    b'LjM3N3ptLTE1LjYyNy0wLjg1OCAxLjY2OCAxLjk3OSAwLjEwMi0wLjk2Ny0xLjc3LTEuMDEy'
    b'em0xLjYyOSA2LjExNSAxLjY2OSAxLjk4IDAuMTAyLTAuOTY4LTEuNzcxLTEuMDEyem00LjY3'
    b'MS0yLjYzMSAyLjc3NyAzLjIyIDAuMTUtMS41ODktMi45MjctMS42MzF6bS0zLjY2OS00LjE1'
    b'OSAyLjc3NyAzLjIyIDAuMTUtMS41ODktMi45MjctMS42MzF6bTExLjQ2NyA5LjAwNiAyLjc3'
    b'NiAzLjIyIDAuMTUxLTEuNTg5LTIuOTI3LTEuNjMxem0tOS4wMTgtMS4xNzMgMi43NzcgMy4y'
    b'MiAwLjE1LTEuNTg5LTIuOTI3LTEuNjMxem00LjI4IDAuNjYgNC4yOSAzLjgwMS0wLjA4Ny0y'
    b'LjE1MS00LjIwMy0xLjY1em05LjY5MyAyLjkzIDIuOTA2IDIuMTY5LTAuMTY4LTEuMzUyLTIu'
    b'NzM4LTAuODE3em0tMS45MDEgNS41OTEgNC41OTMgMy40MjktMC4yNjYtMi4xMzYtNC4zMjct'
    b'MS4yOTN6bS01LjgwOC00LjUxOCA0LjU5MyAzLjQzLTAuMjY2LTIuMTM3LTQuMzI3LTEuMjkz'
    b'em0tMC4xMzkgMy4zNDkgNC41OTQgMy40MjktMC4yNjctMi4xMzYtNC4zMjctMS4yOTN6bTUu'
    b'NzYzLTIuNDU1IDIuOTA3IDIuMTY5LTAuMTY5LTEuMzUxLTIuNzM4LTAuODE4em0tNC43OTUg'
    b'Ni44NDIgNC41OTQgMy40MjktMC4yNjYtMi4xMzctNC4zMjgtMS4yOTJ6bTcuMDk4IDIuOTM5'
    b'IDMuNDA3IDIuNTQzLTAuMTk3LTEuNTg1LTMuMjEtMC45NTh6bTcuMTI2LTIuMTMxIDIuOTA2'
    b'IDIuMTctMC4xNjgtMS4zNTItMi43MzgtMC44MTh6bS0xMC40MjktMS4zMTMgMy45MTkgMi45'
    b'MjQtMC4yMjgtMS44MjItMy42OTEtMS4xMDJ6bTUuNzY0IDIuMTM1IDMuOTE4IDIuOTI1LTAu'
    b'MjI3LTEuODIyLTMuNjkxLTEuMTAzem01NC4zODEgMTY4Ljk3IDMuNTM3LTAuMzAyLTEuMDAy'
    b'LTAuODgtMi41MzUgMS4xODJ6bTExLjU1NS0yLjAxOCAyLjM5MS0wLjUxOS0wLjc2My0wLjUx'
    b'My0xLjYyOCAxLjAzMnptLTMuMDI2LTIuMDQ4IDIuMzkxLTAuNTE5LTAuNzYyLTAuNTEzLTEu'
    b'NjI5IDEuMDMyem0tOS41NTYgNy44OTYgMS45NjMtMC40NzUtMC42MzktMC40MDgtMS4zMjQg'
    b'MC44ODN6bTE0Ljk5OC00LjE2MyAyLjAxNiAwLjEzNS0wLjQ4OC0wLjU4MS0xLjUyOCAwLjQ0'
    b'NnptLTQuNDk4IDEuMDgzIDIuMDE1IDAuMTM1LTAuNDg4LTAuNTgxLTEuNTI3IDAuNDQ2em0t'
    b'Ni4wNTggMS4zMjUgMi43NzMtMC4yMzctMC43ODYtMC42OS0xLjk4NyAwLjkyN3ptMi43OTMt'
    b'Mi43MDkgMi43ODEtMC4xMDEtMC43NTEtMC43MjctMi4wMyAwLjgyOHptLTIuMzQ0LTIuMjU1'
    b'IDMuNTM3LTAuMzAyLTEuMDAyLTAuODgtMi41MzUgMS4xODJ6bTEuMDg4LTIuNzU1IDIuMDEy'
    b'LTAuMTcyLTAuNTctMC41MDEtMS40NDIgMC42NzN6bS02LjA3IDMuMiAzLjQyNy0wLjgyOC0x'
    b'LjExNi0wLjcxMy0yLjMxMSAxLjU0MXptLTMuNDEzIDQuMTI4IDIuNzA1LTAuNjU0LTAuODgx'
    b'LTAuNTYzLTEuODI0IDEuMjE3em0tMC41OTctMi41NTYgMi41MTItMC42MDctMC44MTgtMC41'
    b'MjMtMS42OTQgMS4xM3ptLTQyLjgwMi0wLjgwNSAzLjUzNy0wLjMwMi0xLjAwMi0wLjg4LTIu'
    b'NTM1IDEuMTgyem0xMS41NTUtMi4wMTggMi4zOS0wLjUxOS0wLjc2Mi0wLjUxMy0xLjYyOCAx'
    b'LjAzMnptLTMuMDI2LTIuMDQ4IDIuMzktMC41MTktMC43NjItMC41MTMtMS42MjggMS4wMzJ6'
    b'bS05LjU1NiA3Ljg5NiAxLjk2Mi0wLjQ3NS0wLjYzOS0wLjQwOC0xLjMyMyAwLjg4M3ptMTQu'
    b'OTk4LTQuMTYyIDIuMDE1IDAuMTM0LTAuNDg4LTAuNTgtMS41MjcgMC40NDZ6bS00LjQ5OCAx'
    b'LjA4MiAyLjAxNSAwLjEzNS0wLjQ4OC0wLjU4MS0xLjUyNyAwLjQ0NnptLTYuMDU5IDEuMzI1'
    b'IDIuNzczLTAuMjM3LTAuNzg1LTAuNjktMS45ODggMC45Mjd6bTIuNzkzLTIuNzA5IDIuNzgx'
    b'LTAuMTAxLTAuNzUtMC43MjctMi4wMzEgMC44Mjh6bS0yLjM0My0yLjI1NSAzLjUzNy0wLjMw'
    b'Mi0xLjAwMi0wLjg4LTIuNTM1IDEuMTgyem0xLjA4Ny0yLjc1NSAyLjAxMy0wLjE3Mi0wLjU3'
    b'MS0wLjUtMS40NDIgMC42NzJ6bS02LjA2OSAzLjIgMy40MjYtMC44MjgtMS4xMTUtMC43MTMt'
    b'Mi4zMTEgMS41NDF6bS0zLjQxNCA0LjEyOCAyLjcwNS0wLjY1NC0wLjg4LTAuNTYzLTEuODI1'
    b'IDEuMjE3eiIgZmlsbD0iIzg4ODk4YiIvPgo8L3N2Zz4K', 'RU_YAR')

RU_YAR = b64_RU_YAR
index.append("RU_YAR")
index.append("Russia Yaroslavskaya oblast")
catalog["RU_YAR"] = RU_YAR
catalog["Russia Yaroslavskaya oblast"] = RU_YAR
country["Russia Yaroslavskaya oblast"] = ('RU_YAR', '', 1)
lookup["RU_YAR"] = ('RU_YAR', '', 'Russia Yaroslavskaya oblast', 1)
lookup["Yaroslavl"] = ('RU_YAR', '', 'Russia Yaroslavskaya oblast', 1)
lookup["Russia Yaroslavskaya oblast"] = ('RU_YAR', '', 'Russia Yaroslavskaya oblast', 1)
details["RU_YAR"] = {"continent":"Europe","capital":"","currency":"","web":"","lang":"","tz":"+03:00","altname":"Yaroslavl"}
regional["RU_YAR"] = ('RU_YAR', 'Russia Yaroslavskaya oblast', 1)
regional["Russia Yaroslavskaya oblast"] = ('RU_YAR', 'Russia Yaroslavskaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_YEV = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4NCjxzdmcgeG1sbnM9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB3aWR0aD0iMzYwIiBoZWlnaHQ9IjI0MCI+DQo8'
    b'cmVjdCB3aWR0aD0iMzYwIiBoZWlnaHQ9IjI0MCIgZmlsbD0iI2ZmZiIvPg0KPGcgc3Ryb2tl'
    b'LXdpZHRoPSI2Ij4NCjxwYXRoIGQ9Ik0wLDk2SDM2MCIgc3Ryb2tlPSIjZjAwIi8+DQo8cGF0'
    b'aCBkPSJNMCwxMDRIMzYwIiBzdHJva2U9IiNmOTAiLz4NCjxwYXRoIGQ9Ik0wLDExMkgzNjAi'
    b'IHN0cm9rZT0iI2ZjMCIvPg0KPHBhdGggZD0iTTAsMTIwSDM2MCIgc3Ryb2tlPSIjNmMzIi8+'
    b'DQo8cGF0aCBkPSJNMCwxMjhIMzYwIiBzdHJva2U9IiMzOWYiLz4NCjxwYXRoIGQ9Ik0wLDEz'
    b'NkgzNjAiIHN0cm9rZT0iIzAwYyIvPg0KPHBhdGggZD0iTTAsMTQ0SDM2MCIgc3Ryb2tlPSIj'
    b'NjA5Ii8+DQo8L2c+DQo8L3N2Zz4NCg==', 'RU_YEV')

RU_YEV = b64_RU_YEV
index.append("RU_YEV")
index.append("Russia Yevreyskaya avtonomnaya oblast")
catalog["RU_YEV"] = RU_YEV
catalog["Russia Yevreyskaya avtonomnaya oblast"] = RU_YEV
country["Russia Yevreyskaya avtonomnaya oblast"] = ('RU_YEV', '', 1)
lookup["RU_YEV"] = ('RU_YEV', '', 'Russia Yevreyskaya avtonomnaya oblast', 1)
lookup["Jewish Enclave"] = ('RU_YEV', '', 'Russia Yevreyskaya avtonomnaya oblast', 1)
lookup["Russia Yevreyskaya avtonomnaya oblast"] = ('RU_YEV', '', 'Russia Yevreyskaya avtonomnaya oblast', 1)
details["RU_YEV"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+10:00","altname":"Jewish Enclave"}
regional["RU_YEV"] = ('RU_YEV', 'Russia Yevreyskaya avtonomnaya oblast', 1)
regional["Russia Yevreyskaya avtonomnaya oblast"] = ('RU_YEV', 'Russia Yevreyskaya avtonomnaya oblast', 1)
#----------------------------------------------------------------------
b64_RU_ZAB = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZyB2ZXJzaW9uPSIxLjEiIGlkPSJzdmcxODc3IiB3aWR0aD0iMTIwIiBoZWln'
    b'aHQ9IjgwIiB2aWV3Qm94PSIwIDAgMTIwIDgwIiBzb2RpcG9kaTpkb2NuYW1lPSJGbGFnX29m'
    b'X1phYmF5a2Fsc2t5X0tyYWkuc3ZnLnBuZyIgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cu'
    b'aW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiIHhtbG5zOnNvZGlwb2RpPSJodHRw'
    b'Oi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIgeG1sbnM6'
    b'eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3'
    b'LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2'
    b'ZyI+CiAgPGRlZnMgaWQ9ImRlZnMxODgxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcgaWQ9'
    b'Im5hbWVkdmlldzE4NzkiIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiIGJvcmRlcm9wYWNpdHk9IjEuMCIgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIgaW5rc2Nh'
    b'cGU6cGFnZW9wYWNpdHk9IjAuMCIgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4K'
    b'ICA8ZyBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIiBpbmtzY2FwZTpsYWJlbD0iSW1hZ2Ui'
    b'IGlkPSJnMTg4MyI+CiAgICA8aW1hZ2Ugd2lkdGg9IjEyMCIgaGVpZ2h0PSI4MCIgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1'
    b'YWxpdHkiIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FB'
    b'QUFOU1VoRVVnQUFBSGdBQUFCUUJBTUFBQUFndGF5NkFBQUFCR2RCVFVFQUFMR1BDL3hoQlFB'
    b'QUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0Nj'
    b'dWxFOEFBQUFKRkJNVkVXend4TWFtVGtBa2ovLzF3RHUKMHdSbXJpYjh4d0RsWEFQWUhnWHlt'
    b'UUxiTGdYLy8vK3ZxeEh0QUFBQUFXSkxSMFFMSDlmRXdBQUFBQWQwU1UxRkIrY0ZGQUFxQUw5'
    b'bApBZ29BQUFFbFNVUkJWRmpEcGMvUlRjTkFFQWJocEFWS29BSWtJeVFLb0FHYTJCWW80YTlo'
    b'SzBpWnlHQnd6dG03MngzUCsvY3dsK3N6CjcvTDZlUUl2TDA4bjhQSnhCaS9YTXhodnJ4aHYv'
    b'MkM2L1l2aDlvYlo5b2JaOWg5RzIvK1liTzhZYk84WWJOL2grdlk5TG04M3VMcmQKNE9wMmk0'
    b'dmJCMXpiUHVMUzloR1h0aDl3WmZzUkY3WURuTjhPY0g0N3d1bnRFR2UzWTV6Y2puRnl1NE56'
    b'MnoyYzJ1N2l6SFlYWjdiNwpPTEU5d1BQdEVaNXVqL0IwZTRobjIyTnNHamJFN3plTzM3N0Vz'
    b'WXRqRThlejRSR2VEbyt3aTJNVHg0bmhMczRNZDdHTFl4UEh1ZUVZCko0ZGo3T0xZeEhGNk9N'
    b'RDU0UUM3T0RaeFhCays0dEx3RWJzNE5uRmNIRzV3ZGJqQkxvNU5ITmVIZHd5R2QremkyTVF4'
    b'R3Q0d0c5NncKaTJNVHgzUjR4WGg0eGM2dHZnRlhxWjc0dStoRjZnQUFBQ1YwUlZoMFpHRjBa'
    b'VHBqY21WaGRHVUFNakF5TXkwd05TMHlNRlF3TURvMApNam93TUNzd01Eb3dNR3QrZFhBQUFB'
    b'QWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNak10TURVdE1qQlVNREE2TkRJNk1EQXJNREE2'
    b'Ck1EQWFJODNNQUFBQUFFbEZUa1N1UW1DQwoiIGlkPSJpbWFnZTE4ODUiIC8+CiAgPC9nPgo8'
    b'L3N2Zz4K', 'RU_ZAB')

RU_ZAB = b64_RU_ZAB
index.append("RU_ZAB")
index.append("Russia Zabaykal'skiy kray")
catalog["RU_ZAB"] = RU_ZAB
catalog["Russia Zabaykal'skiy kray"] = RU_ZAB
country["Russia Zabaykal'skiy kray"] = ('RU_ZAB', '', 1)
lookup["RU_ZAB"] = ('RU_ZAB', '', "Russia Zabaykal'skiy kray", 1)
lookup["Zabaykalsky"] = ('RU_ZAB', '', "Russia Zabaykal'skiy kray", 1)
lookup["Russia Zabaykal'skiy kray"] = ('RU_ZAB', '', "Russia Zabaykal'skiy kray", 1)
details["RU_ZAB"] = {"continent":"Asia","capital":"","currency":"","web":"","lang":"","tz":"+09:00","altname":"Zabaykalsky"}
regional["RU_ZAB"] = ('RU_ZAB', "Russia Zabaykal'skiy kray", 1)
regional["Russia Zabaykal'skiy kray"] = ('RU_ZAB', "Russia Zabaykal'skiy kray", 1)
#----------------------------------------------------------------------
b64_RW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1ydyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMyMDYwM2QiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmYWQyMDEiIGQ9Ik0wIDBoNjQwdjM2MEgweiIvPgog'
    b'IDxwYXRoIGZpbGw9IiMwMGExZGUiIGQ9Ik0wIDBoNjQwdjI0MEgweiIvPgogIDxnIHRyYW5z'
    b'Zm9ybT0idHJhbnNsYXRlKDUxMSAxMjUuNCkgc2NhbGUoLjY2NjY3KSI+CiAgICA8ZyBpZD0i'
    b'cnctYiI+CiAgICAgIDxwYXRoIGlkPSJydy1hIiBmaWxsPSIjZTViZTAxIiBkPSJNMTE2LjEg'
    b'MCAzNS43IDQuN2w3Ni40IDI1LjQtNzguOC0xNi4zTDEwMC42IDU4bC03Mi0zNi4yTDgyIDgy'
    b'LjEgMjEuOSAyOC42bDM2LjIgNzItNDQuMy02Ny4zTDMwIDExMiA0LjcgMzUuNyAwIDExNi4x'
    b'LTEtMXoiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjcnctYSIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgdHJhbnNmb3JtPSJzY2FsZSgxIC0xKSIvPgogICAgPC9nPgogICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjcnctYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNm'
    b'b3JtPSJzY2FsZSgtMSAxKSIvPgogICAgPGNpcmNsZSByPSIzNC4zIiBmaWxsPSIjZTViZTAx'
    b'IiBzdHJva2U9IiMwMGExZGUiIHN0cm9rZS13aWR0aD0iMy40Ii8+CiAgPC9nPgo8L3N2Zz4K', 'RW')

RW = b64_RW
index.append("RW")
index.append("RWA")
index.append("Rwanda")
catalog["RW"] = RW
catalog["RWA"] = RW
catalog["Rwanda"] = RW
country["Rwanda"] = ('RW', 'RWA', 0)
lookup["RW"] = ('RW', 'RWA', 'Rwanda', 0)
lookup["Kigali Rwanda"] = ('RW', 'RWA', 'Rwanda', 0)
lookup["RWA"] = ('RW', 'RWA', 'Rwanda', 0)
lookup["Rwanda"] = ('RW', 'RWA', 'Rwanda', 0)
details["RW"] = {"continent":"Africa","capital":"Kigali","currency":"Rwanda Franc","web":".rw","lang":"rw | en-RW | fr-RW | sw","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_SA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InNhLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1LjMgMGg2ODIu'
    b'NnY1MTJILTg1LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNzYS1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoODApIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjMTY1ZDMxIiBkPSJNLTEy'
    b'OCAwaDc2OHY1MTJoLTc2OHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik02NS41IDE0'
    b'NS4xYy0uOCAxMi0yIDMzIDguMyAzNS4yIDEyLjMgMS4yIDUuNS0yMC44IDEwLTI0LjguOC0y'
    b'IDIuMy0yIDIuNC41djE4LjdjMCA2IDQgNy44IDcgOSAzLjItLjIgNS40IDAgNi42IDNsMS42'
    b'IDMyLjNzNy40IDIuMiA3LjgtMTguMWMuMy0xMi0yLjQtMjEuOS0uOC0yNC4yIDAtMi4zIDMt'
    b'Mi40IDUtMS4zIDMuMiAyLjIgNC42IDUgOS42IDQgNy42LTIuMiAxMi4yLTUuOSAxMi4zLTEx'
    b'LjdhNDcgNDcgMCAwIDAtMy41LTE2LjZjLjQtMS0xLjQtMy43LTEtNC43IDEuMyAyLjIgMy40'
    b'IDIgMy44IDAtMS4zLTQuMi0zLjMtOC4zLTYuNS0xMC0yLjctMi40LTYuNy0yLTggMy0uOCA1'
    b'LjcgMiAxMi40IDYuMSAxOCAuOSAyLjEgMi4xIDUuNyAxLjYgOC45LTIuMiAxLjMtNC40Ljct'
    b'Ni4zLTEuMiAwIDAtNi00LjUtNi01LjYgMS42LTEwLjIuMy0xMS40LS42LTE0LjMtLjYtMy45'
    b'LTIuNS01LjItNC03LjgtMS41LTEuNi0zLjUtMS42LTQuNSAwLTIuNyA0LjYtMS40IDE0LjUu'
    b'NSAxOSAxLjQgNC4xIDMuNSA2LjcgMi41IDYuNy0uOCAyLjMtMi41IDEuNy0zLjgtMWE2Ni42'
    b'IDY2LjYgMCAwIDEtMi4xLTE3LjRjLS41LTQuNi0xLjEtMTQuNC00LjItMTctMS44LTIuNC00'
    b'LjUtMS4yLTUuNSAxYTgyLjQgODIuNCAwIDAgMCAuMyAxMy40YzIgNy40IDIuNyAxNCAzLjcg'
    b'MjEuNS4zIDEwLjEtNS44IDQuNC01LjUtLjdhNDUgNDUgMCAwIDAtLjMtMTkuNGMtMS0yLjYt'
    b'Mi4xLTMuMi00LjYtMi44LTEuOSAwLTYuOCA1LjMtOC4yIDE0LjMgMCAwLTEuMiA0LjYtMS43'
    b'IDguNy0uNyA0LjYtMy43IDgtNS45LS42LTEuOC02LjMtMy0yMS42LTYtMTh6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZmZmIiBkPSJtOTkgMTk0LjItMzIgMTUuNGMuMy03LjMgMTUuMS0yMC40'
    b'IDI1LjMtMjAuNSA2LjUuMSA0LjkgMi41IDYuNiA1LjF6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZmZmIiBkPSJNOTMuMyAyMDQuMmMtMTYuOCA0My41IDM5LjUgNDkuNiA0NS44IDEuOC42LTIg'
    b'My0zLjkgMy40LS43LTEuMyA0My4zLTQzLjYgNDYuMi01MC44IDMyLjZhNDEuOSA0MS45IDAg'
    b'MCAxLTIuNS0xNC42Yy0xLTguNS01LjUtNS4yLTYuMiAzLjItLjcgNC43LS41IDYtLjUgMTAu'
    b'NSAyLjIgMzQuMiA1Ni43IDE5LjUgNjUuNi04LjcgNC43LTE1LjYtLjgtMjcuMSAxLjctMjcu'
    b'MSA1LjQgNS44IDEzIC44IDE0LjctMS4yLjctMSAyLjUtMS43IDMuNy0uNCA0LjIgMyAxMS42'
    b'IDEuNiAxMy4yLTMuNy45LTUuMyAxLjYtMTAuNyAxLjgtMTYuMi0zLjUgMS02IDEuNy02LjMg'
    b'My4ybC0uNyA0LjZjLS4zIDEuNS0zLjIgMS41LTMuNC0uNC0xLjMtNi02LjctNi43LTEwIDIu'
    b'NS0yLjEgMS44LTYuMSAyLjItNi41LS41LjUtNi4yLTItNy03LTQuMWwtNC44LTM2LjJjMiAw'
    b'IDQgMS41IDUuOS0uOS0yLTYuNS02LjUtMTkuNy05LTIwLjctMS4xLTEuNC0yLjEtLjUtMy43'
    b'LS4xLTIuNi44LTUgMy00LjIgNy40IDMgMTguOCA1IDMzLjEgOC4xIDUyIC41IDIuMS0xLjMg'
    b'NS0zLjcgNC43LTQtMi43LTUtOC4yLTEyLTgtNSAwLTEwLjYgNS41LTExLjMgMTAuNy0uOSA0'
    b'LjItMS4yIDguNyAwIDEyLjMgMy41IDQuMiA3LjcgMy44IDExLjQgMi45IDMtMS4zIDUuNS00'
    b'LjMgNi42LTMuNi43LjkuMSAxMC45LTE0LjMgMTguNS04LjcgNC0xNS43IDQuOC0xOS40LTIu'
    b'My0yLjMtNC41LjItMjEuNC01LjYtMTcuNXoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9'
    b'Ik0xNjUgMTYwYzMuMy0xLjIgMTkuMy0xOS42IDE5LjMtMTkuNmwtMi40LTJjLS45LS43LS44'
    b'LTEuNSAwLTIuMiA0LTIuNCAyLjctNy40LjctOS44YTkuNyA5LjcgMCAwIDAtOC43LjFjLTIu'
    b'OCAyLjctMy40IDctMS4yIDkuNiAyLjEgMSA0LjIgMy4yIDIuOCA0LjQtNi42IDctMjQuNSAx'
    b'OS4xLTIyLjQgMTkuNS40LjYgMTEuNS42IDExLjggMHptLTk3IDY1Yy02IDkuNi02LjUgMjMu'
    b'OS0zLjIgMjguMiAxLjggMiA0LjcgMi45IDYuOCAyLjIgMy44LTEuNiA1LjUtOS4zIDQuNi0x'
    b'Mi0xLjMtMi0yLjMtMi4zLTMuNi0uNy0yLjYgNS40LTMuNyAxLjctNC0xLjNhNzAgNzAgMCAw'
    b'IDEgLjgtMTUuMmMuNy00LjIgMC0zLTEuNC0xLjJ6bTI1Ny4xLTE1LjNjLTUuOC0xMi42LTEz'
    b'LjktMjUtMTYuNC0yOS43YTU1Ny42IDU1Ny42IDAgMCAwLTI0LjgtMzZjLTYuMi03LjQgMTAu'
    b'MiAzLjEtMi0xMS43bC04LjktNy41Yy0yLTEuNC02LjgtNC03LjYuMi0uNCAzLjgtLjIgNS44'
    b'LjQgOC45LjUgMiAzLjUgNS41IDUgNy41YTU2NSA1NjUgMCAwIDEgNTMuOCA4Ni41YzIuNi0x'
    b'LjMgMi0xNi4xLjUtMTguMnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0yOTkuNiAy'
    b'NTEuNWMtMS4yIDEuMyAyLjggNi44IDggNi44IDguNi0xIDE2LjItNS44IDIzLjItMTguNmEz'
    b'MyAzMyAwIDAgMCA1LjMtMTQuMiAzMTcgMzE3IDAgMCAwLTUuOC03Mi40Yy0uMy0yIDAtNC40'
    b'LjItNSAuNi0uNyAyLjUgMCAzLjUtMS43IDEuNS0xLjUtNC0xNC03LTE4LjctMS0yLjItMS41'
    b'LTMuNi0zLjMuMmEyNyAyNyAwIDAgMC0zIDEzLjZjNC4xIDI4LjUgNS40IDUzLjQgOCA4MS45'
    b'LjMgMi44LS4xIDYuOC0yIDguNGE4MC4yIDgwLjIgMCAwIDEtMjcuMSAxOS43em0xMTYuNS0u'
    b'MWMtNi4yIDMuNi02LjIgNy43LTEuMiA3LjggOC42LTEgMTguOC0xLjcgMjUuOC0xMi4zYTQx'
    b'IDQxIDAgMCAwIDQuMi0xNiAzMDMgMzAzIDAgMCAwLTQuNy03MS40Yy0uMi0yLTEuMS02Ljct'
    b'LjgtNy4zLjYtMS40IDMuNC4xIDQuNC0xLjUgMS40LTEuNS03LjMtMTIuNy0xMC40LTE3LjUt'
    b'MS0yLjItMS40LTMuNi0zLjMuMmEyMi4zIDIyLjMgMCAwIDAtMS44IDEzLjZjNC42IDMxIDgg'
    b'NTQuMiA4LjcgODEuNi0uNCAyLjYtLjUgNC0xLjcgNy4zLTIuNyAzLjQtNS43IDcuOC04LjUg'
    b'OS45LTIuOCAyLTguOCA0LTEwLjcgNS42eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0i'
    b'TTQyMC43IDIyMy43YzAtNy4zLjEtMTMuNS0uMS0xOWEzNCAzNCAwIDAgMC0zLTEzLjVjLTEu'
    b'OC00LjEtLjctNy40LTEuNi0xMS44LS44LTQuNC0uNi0xMS0xLjgtMTYuMS0uNC0yLTEuNC04'
    b'LjUtMS4xLTkuMi41LTEuNCAyLjQgMCAzLjQtMS42IDEuNC0xLjUtNS0xOC04LjItMjIuNy0x'
    b'LjEtMi4xLTMuMy0xLjQtNS44IDItMi41IDIuMy0xLjYgNy40LS42IDEyLjMgNi4xIDMyLjMg'
    b'MTAuOCA2MS42IDkuOCA5Mi4zLS40IDIuNiA5LTcuOCA5LTEyLjd6bS00NS43LTQwYy0zLjkt'
    b'LjItMTItNy43LTE0LjQtMTJhOCA4IDAgMCAxIC40LTYuNWMxLjUtMSAzLjctMiA1LjQtMSAw'
    b'IDAgMS43IDIuNCAxLjQgMi43IDIgMSAzIC41IDMuMi0uNC4xLTEuNS0uNi0yLjQtLjYtNCAu'
    b'OS00LjYgNi01LjMgOC0yLjQgMS40IDEuOCAyIDUuNSAyLjEgOCAwIDEuMy0yLS4yLTMuMyAw'
    b'LTEuMS40LTEuNCAxLjgtMS41IDMtLjIgMy4zLS42IDguNi0uNyAxMi41em0tNzEuOCA0OGMx'
    b'LTkuOC0uNC0yNy4zLS41LTMzLjFBNDc3IDQ3NyAwIDAgMCAyOTkgMTU0Yy0xLjItOC40IDMu'
    b'NC45IDIuOC00LTEuNS04LjMtNi4xLTE0LTExLjYtMjEuNS0xLjctMi41LTEuNy0zLTQuNC42'
    b'LTMgNi43LS40IDExLjQuNCAxNi43IDMuOSAxNy4yIDYuMiAzMyA3LjMgNDguN2EzOTMuNCAz'
    b'OTMuNCAwIDAgMSAuNCA0OWMzIC4xIDcuNi00LjcgOS4zLTExLjh6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJNNDM0IDIxNmMtNi45LTExLjYtMTcuMi0yNC0yMC0yOC43YTY1OCA2'
    b'NTggMCAwIDAtMjkuMi0zNy44Yy04LjUtOSA0LTEuNS0xLjYtOC41LTQuNy01LjEtNi02Ljgt'
    b'MTAuMS05LjktMi0xLjMtMy4yLTMuOC00IC41YTgzIDgzIDAgMCAwLS4yIDExLjJjMCAxLjcg'
    b'MS44IDUgMy40IDcgMjAuNyAyNS41IDQzLjQgNTEuNSA2MS42IDg0LjIgMi42LTEuMyAxLjct'
    b'MTYgMC0xOHoiLz4KICAgIDxwYXRoIGZpbGw9IiMxNjVkMzEiIGQ9Ik0xMjIuNiAxOTQuN2Mt'
    b'LjUuOS0xLjYgMi0xLjIgMy4xLjcgMSAxLjQgMS4zIDIuNiAxLjMgMS4xIDAgMi43LjMgMy0u'
    b'My42LS43IDEtMiAuNi0zLjMtMS4yLTMtNC40LTEuOC01LS44eiIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTM1NC4yIDM2Mi41YzkuMi40IDE1LjIuNSAyMy4zIDEuNGw5LjYtMWMx'
    b'MC42LTEgMTEgMTUuMSAxMSAxNS4xIDAgOS41LTMuNyAxMC04LjQgMTEtMi43LjQtNC0xLjYt'
    b'NS41LTMuNmExNCAxNCAwIDAgMS03IC40Yy0zLjktLjItNy43LS4yLTExLjUtLjUtNC0uMy02'
    b'LjIuNS0xMC4zLjEtLjggMS4zLTIgMy4xLTQuNCAyLjYtMi0uMy00LjUtNi0zLjgtMTAuNSAx'
    b'LjUtMy4yIDEtMi4xIDEtMy41LTM3LjYtMS03NS41LTIuNy0xMTIuMy0yLjItMjguOC4xLTU3'
    b'LjIgMS4zLTg1LjcgMi41LTE1LjItLjItMjYuOC0yLjYtMzQuOC0xNC4zLjggMCAzOC44IDIu'
    b'MSA0OS45IDEuNCAyMC41LS4yIDM5LjMtMS45IDYwLjItMi41IDQxLjIuNyA4Mi4xLjcgMTIz'
    b'LjMgMy42LTQtMi43LTQtOSAyLTEwLjYuNS0uNC44IDMuMSAxLjcgMyA0LjktLjMgMi43IDYu'
    b'MyAxLjcgNy42ek0xODguNiAxMzUuM2MtNi4yIDE3LjggMy42IDM3LjQgMTAuNCAzNS41IDUg'
    b'MiA4LTcuNCAxMC0xNy42IDEuNS0yLjkgMi41LTMuMiAzLjItMS43LS4yIDEzLjYgMSAxNi43'
    b'IDQuNSAyMC44IDcuOCA2IDE0LjMuOCAxNC44LjNsNi02LjFjMS40LTEuNSAzLjItMS41IDUu'
    b'MS0uMyAxLjkgMS43IDEuNiA0LjYgNS42IDYuNiAzLjQgMS40IDEwLjUuNCAxMi4yLTIuNSAy'
    b'LjItMy45IDIuOC01LjIgMy44LTYuNiAxLjYtMi4xIDQuMy0xLjIgNC4zLS41LS4zIDEuMi0x'
    b'LjkgMi4zLS44IDQuNSAyIDEuNCAyLjQuNSAzLjUuMiA0LTIgNy0xMC42IDctMTAuNi4xLTMu'
    b'Mi0xLjctMy0yLjktMi4ybC0zLjEgMi4xYy0yIC4zLTUuNyAxLjYtNy42LTEuMy0xLjktMy40'
    b'LTEuOS04LjMtMy4zLTExLjggMC0uMi0yLjYtNS41LS4yLTUuOCAxLjIuMiAzLjcuOSA0LjEt'
    b'MS4yIDEuMi0yLjEtMi42LTgtNS4zLTExLTIuMy0yLjUtNS41LTIuOC04LjYtLjItMi4yIDIt'
    b'MS45IDQuMi0yLjMgNi4zYTkuOCA5LjggMCAwIDAgMiA4LjdjMi4yIDQuMiA2LjEgOS43IDQu'
    b'OCAxNy41IDAgMC0yLjMgMy42LTYuMyAzLjEtMS43LS4zLTQuNC0xLTUuOC0xMS44LTEuMS04'
    b'IC4yLTE5LjQtMy4yLTI0LjctMS4zLTMuMy0yLjItNi40LTUuMi0uOS0uOCAyLjItNC4zIDUu'
    b'NS0xLjggMTIuMmEzNiAzNiAwIDAgMSAyIDE5Yy0xLjUgMi4yLTEuOCAyLjktMy43IDUtMi42'
    b'IDMtNS41IDIuMi03LjcgMS4xLTItMS4zLTMuNi0yLTQuNi02LjUuMi03IC42LTE4LjUtLjct'
    b'MjAuOS0xLjktMy44LTUtMi40LTYuMy0xLjJhNDcuNyA0Ny43IDAgMCAwLTExLjUgMjMuNWMt'
    b'MS44IDUuOC0zLjcgNC4xLTUgMS44LTMuMi0zLTMuNS0yNi43LTcuNC0yMi44eiIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0iTTIwNy40IDE3NC4xYzIuOS0yIDEuNi0zLjQgNS44Ljhh'
    b'NzIgNzIgMCAwIDEgOS4yIDMxLjNjLS4yIDIuNiAxLjYgNC4yIDIuNSAzLjYuNC02IDE1LjEt'
    b'MTQuNCAyOC42LTE1LjYgMi0uNSAxLTQuNCAxLjMtNi40LS44LTcuNSA0LjItMTQuMyAxMS4y'
    b'LTE0LjggOS42IDEuNCAxMi44IDYuNSAxMyAxNC4yLTEuMSAxNS0xNi43IDE3LjUtMjUuNCAx'
    b'OC43LTEuMy41LTEuOSAxLjEgMCAxLjhsMzYuNi4yIDEuOSAxYy4yIDEtLjYuMi0yIDIuNmEy'
    b'OS41IDI5LjUgMCAwIDAtMy43IDExLjVjLTEwLjkgMy42LTIyLjIgNS0zMy42IDYuNS00IDIt'
    b'NiA0LjctNS4yIDcuNyAxLjQgMy4zIDEwLjIgNi43IDEwLjIgNi44IDEuNyAxIDMuNiAzLjUt'
    b'LjUgOC42LTE3LjgtLjgtMzEuNy04LjQtMzYuNS0xOS4xLTEuNC0xLjEtMyAwLTQgMS40LTcg'
    b'OS0xMy44IDE3LTI1LjcgMjEuNC03IDEuOC0xNC4zLTEuMS0xNy43LTUuNy0yLjMtMi43LTIu'
    b'Mi01LjYtMy02LjItMy45IDEuNy0zNi45IDE1LjctMzIuNyA5LjEgOC04LjUgMjItMTQuOSAz'
    b'NC4yLTIzLjMuOS0yLjkgMi41LTEyLjUgNy4zLTE1LjYuMyAwLS43IDUuNi0uNiA4IDAgMi0u'
    b'MiAyLjcuMiAyLjIuOS0uNSAxNS43LTEyLjIgMTctMTUuOCAxLjQtMiAuMy03LjIuMy03LjQt'
    b'Mi44LTcuMi02LjctNy44LTguMS0xMS40LTEuMy00LjctLjctMTAuMSAyLTExLjcgMi40LTIu'
    b'MSA1LjItMS45IDcuOS41IDMgMi43IDUuNiA4IDYuNCAxMS45LS41IDEuNS00LTEtNS0uM2Ex'
    b'NiAxNiAwIDAgMSAzLjcgNy44YzIgOC4yIDEuNCAxMS40LS42IDE2LjctNi42IDEzLjktMTUg'
    b'MTgtMjIuNCAyMy4yLS4yIDAtLjMgMy41IDIuNCA1LjQgMSAxIDQuOSAxLjUgOS40IDBhNTQu'
    b'NSA1NC41IDAgMCAwIDIyLjMtMjMuMyA1MSA1MSAwIDAgMC0yLjQtMjIuMmMtMi45LTYuNy02'
    b'LjMtMTYuMi02LjMtMTYuNC0uMS00LjIuMi01LjYgMi03Ljd6bS05NS44LTM4LjZjNC4yIDIg'
    b'MTIuMiAxLjEgMTEuOC01LjdsLS4yLTMuMWMtLjgtMi0zLjItMS41LTMuNy41LS4yLjcuMyAx'
    b'LjgtLjMgMi4xLS40LjQtMS43LjItMS43LTEuNyAwLS42LS40LTEuMi0uNy0xLjYtLjItLjIt'
    b'LjQtLjItLjktLjItLjYgMC0uNi4xLS45LjYtLjEuNS0uMyAxLS4zIDEuNiAwIC43LS40Ljkt'
    b'LjggMS0uNiAwLS41IDAtMS0uMi0uMi0uMy0uNS0uNC0uNS0xbC0uMy0xLjZjLS4yLS4zLS42'
    b'LS41LTEtLjYtMi4zIDAtMi41IDIuNy0yLjMgMy43LS4yLjItLjMgNC45IDIuOCA2LjJ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjM1LjEgMTg3LjdjNC4yIDIgMTQuMy45IDEx'
    b'LjgtNS42bC0uMi0zLjJjLS45LTItMy4yLTEuNS0zLjcuNi0uMi42LjMgMS43LS40IDItLjMu'
    b'NC0xLjcuMi0xLjYtMS42IDAtLjYtLjQtMS4zLS43LTEuNy0uMy0uMS0uNC0uMi0xLS4yLS41'
    b'IDAtLjUuMi0uOC43LS4yLjUtLjMgMS0uMyAxLjYtLjEuNi0uNC44LS45IDEtLjUgMC0uNCAw'
    b'LS44LS4zLS4zLS4zLS42LS40LS42LS45bC0uMy0xLjZjLS4yLS4zLS42LS41LTEtLjYtMi4z'
    b'IDAtMi41IDIuNi0yLjQgMy42LS4xLjItLjIgNSAzIDYuMnptNzItMjEuNmM0LjIgMiAxMi4x'
    b'IDEuMSAxMS44LTUuNmwtLjItMy4yYy0uOS0yLTMuMi0xLjUtMy43LjUtLjIuNy4zIDEuOC0u'
    b'NCAyLjItLjMuMy0xLjcuMS0xLjYtMS44IDAtLjYtLjQtMS4yLS43LTEuNi0uMy0uMi0uNC0u'
    b'Mi0xLS4yLS41IDAtLjUuMi0uOC43bC0uMyAxLjVjLS4xLjctLjQgMS0uOSAxcy0uNCAwLS44'
    b'LS4yYy0uMy0uMy0uNi0uNC0uNi0uOXMtLjEtMS4zLS4zLTEuN2MtLjItLjMtLjYtLjQtMS0u'
    b'NS0yLjMgMC0yLjUgMi42LTIuNCAzLjYtLjEuMi0uMiA0LjkgMyA2LjJ6bTM3LjMgNTQuM2Mt'
    b'Ny4zIDguMy00LjEgMjItMi40IDI1IDIuNCA0LjggNC4zIDcuOSA5IDEwLjMgNC4zIDMuMSA3'
    b'LjcgMS4yIDkuNS0xIDQuMy00LjUgNC40LTE2IDYuNC0xOC4yIDEuNC00LjIgNS0zLjUgNi43'
    b'LTEuNmExNi41IDE2LjUgMCAwIDAgNi4yIDUuM2M0IDMuNSA4LjggNC4yIDEzLjYgMSAzLjIt'
    b'MS45IDUuMy00LjIgNy4yLTguOSAyLTUuNiAxLTMxLjYuNS00N2wtNC4yLTIxLjVjMC0uMi0u'
    b'NS0xMC4yLTEtMTIuNSAwLTEtLjMtMS4zLjctMS4yIDEuMSAxIDEuMiAxIDIgMS4zIDEgLjIg'
    b'Mi0xLjcgMS4zLTMuM2wtMTAtMTguNmMtLjgtLjgtMS45LTEuNi0zLjIuMmE3LjMgNy4zIDAg'
    b'MCAwLTIuNCA1LjVjLjMgNC40IDEgOC45IDEuMyAxMy4zbDQgMjIuNmMxLjMgMTYgMS42IDI5'
    b'LjIgMi45IDQ1LjMtLjIgNi44LTIuMyAxMi43LTQuMyAxMy42IDAgMC0zIDEuNy01LS4yLTEu'
    b'NS0uNi03LjQtOS45LTcuNC05LjktMy0yLjctNS0yLTcuMSAwLTYgNS44LTguNiAxNi40LTEy'
    b'LjcgMjMuOC0xIDEuNy00IDMtNy4yLS4xLTguMi0xMS4zLTMuNC0yNy4zLTQuNC0yMy4yek0z'
    b'MDkgMTI2LjdjMy44IDEuNSA2LjQgOS4yIDUuNiAxMy0uOCA0LjUtMi44IDkuNS00LjIgOC45'
    b'LTEuNi0uNiAxLTQuNi0uNS04LjgtLjgtMi44LTYtNy44LTUuNC05LjItMS0zLjEgMi4yLTQu'
    b'NSA0LjUtNHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zNTYuNiAyMjVjLjctOS4y'
    b'LS42LTE0LjgtLjgtMjAuMnMtNi4xLTQ2LjYtNy4zLTUwLjZjLTEuNS03LjggNS43LTEgNC45'
    b'LTUuNi0yLjUtNS42LTguNi0xMy45LTEwLjUtMTguOC0xLjItMi0uNy00LTMuMy0uNWE0Mi4z'
    b'IDQyLjMgMCAwIDAtMi4zIDE5LjJjNi4yIDMyLjMgMTIuNSA1OS4xIDExLjUgODkuOCAzIDAg'
    b'Ni4zLTYuNyA3LjgtMTMuM3ptNjQuNC04NS4zYzMuNSAxLjcgNS41IDExLjMgNS4xIDE0LS43'
    b'IDUtMi41IDEwLjQtMy44IDkuNy0xLjUtLjYuMy03LjQtLjQtOS41LS44LTMtNS41LTguNC01'
    b'LTEwLTEtMy40IDItNC44IDQuMS00LjJ6bS0yNTUuNyA2Ny45YzMuMyAxLjMgNS4zIDguMyA1'
    b'IDEwLjMtLjggMy43LTIuNSA3LjctMy44IDcuMS0xLjMtLjQuMy01LjQtLjMtNy0uMy0zLjct'
    b'NC45LTUuNy00LjgtNy4zLS44LTMgMi0zLjUgNC0zLjF6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'MTY1ZDMxIiBkPSJNMjQ0LjkgMjE4LjJjNC4yLjIgNi4zIDMuNiAyLjQgNS00IDEuMy03Ljcg'
    b'Mi40LTcuOCA4IDEuNSA4LTIgNS4yLTQgNC4yLTIuNC0xLjgtOS4yLTYtMTAuMi0xNS0uMS0y'
    b'LjEgMS42LTQgNC4zLTQgNCAxLjEgMTAgMS4yIDE1LjMgMS44eiIvPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTTc3LjQgMTI0LjRjNC44IDEuNCA1LjEgOC42IDQuOCAxMC43LS43IDMu'
    b'OC0yLjQgNy45LTMuNiA3LjQtMS40LS41IDAtNS43LS43LTcuMy0uNy0yLjItNC44LTYuNC00'
    b'LjQtNy42LS45LTIuNSAyLTMuNyAzLjktMy4yem05NS45IDMzLjZjLTMuOCAyLTUuMiA4LTIu'
    b'OSAxMS42IDIuMiAzIDUuNiAxLjkgNiAxLjkgMy43LjQgNS45LTYuOSA1LjktNi45cy4xLTIt'
    b'NC4yIDEuOWMtMS45LjMtMi0uNC0yLjUtMS40YTkgOSAwIDAgMSAuNS01LjdjLjctMS44LS43'
    b'LTIuNi0yLjgtMS40em0yOC0zNi40Yy0yIDEuMy01LjcgNS4yLTUuOCA5LjYtLjEgMi41LS42'
    b'IDIuNSAxIDQgMS4zIDEuOCAyLjQgMS43IDQuOC40YTUuMSA1LjEgMCAwIDAgMi4zLTMuNGMu'
    b'Ni0yLjgtMyAxLjQtMy40LTEuOC0uOC0zIDEuNS00LjIgMy43LTcgMC0yIDAtMy4zLTIuNy0x'
    b'Ljh6bTIyLjQgNGE1OS41IDU5LjUgMCAwIDAtMS42IDExLjFjLS42IDIuOCAzIDQgNC41LjQg'
    b'Mi40LTYuNSAyLjQtOS4zIDIuNi0xMi0uNy00LjMtMy42LTQuMi01LjUuNXptMTQyIDcyLjNj'
    b'LjQtLjUgMjAtMTQuNCAyMC0xNC40IDItLjcgMS41IDcuMi42IDcuMWE3Ny44IDc3LjggMCAw'
    b'IDEtMjAuNyAxNC4zYy0xIC43LTEuOS01LjMgMC03em0xNy43LS4yYzMuNSAxLjcgNC45IDEx'
    b'LjggNC41IDE0LjUgMCA1LjQtMy4zIDkuNi00LjcgOS0xLjQtLjcuMi02LjctLjUtOC44LS44'
    b'LTMtMy43LTguNS0zLjItMTAuMS0xLTMuNCAxLjgtNS4yIDQtNC42em0tMTE2IDQzLjRhMjYg'
    b'MjYgMCAwIDEgNS42LTQuOWMyLTEgMy44LjggMy43LjcuMyAyLTEuMiAzLjctLjcgNi4zLjQg'
    b'MSAuNyAyLjIgMi42IDEuOCAzLjEtMi41IDYtMi43IDktMi44IDIuNS4xIDIuNiA0LjIgMSA0'
    b'LjItNS43IDEuMi04LjIgMi44LTEyLjMgNC4zLTIgMS4yLTMuNi0uMy0zLjYtLjRzLTEuMS0x'
    b'LjEtLjQtMy43Yy4yLTItLjYtMy4yLTIuNC0zLTEuMi44LTIuNCAxLjItMy0uMy0uMy0xLS40'
    b'LTEuNi41LTIuMnptMTM2LjYgNS40Yy44IDEgMS40IDItLjEgMy44bC0zLjcgMy4yYy0uNiAx'
    b'LTEgMi44IDEgMy4zIDMuNiAxIDEyLTQuNSAxMi00LjYgMS40LTEgMS0zIC44LTMtLjgtLjkt'
    b'Mi42LS4zLTMuOC0uNS0uNiAwLTIuNS0uMi0xLjYtMmExMS40IDExLjQgMCAwIDAgMS42LTIu'
    b'OWMuNS0xLjIgMC0yLTItMi43LTIuMS0uNC0zLS4yLTUuMyAwLTEuMi4yLTEuNi44LTEuOSAy'
    b'LjMuMSAyLjMgMS41IDIuMiAzIDN6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMTY1ZDMxIiBkPSJN'
    b'MjY4LjEgMTg5LjdjLS41IDEtMi4zIDEtNCAwcy0yLjctMi42LTIuMS0zLjUgMi4zLS45IDQg'
    b'MCAyLjYgMi42IDIuMSAzLjV6bS04OS01My42Yy0xIC4zLTIuNC0uNi0zLTJzLS4zLTIuNi43'
    b'LTIuOSAyLjMuNyAzIDIgLjMgMi43LS44IDN6TTM1NS4yIDM3NWM5LjQuNCAxOC4yIDAgMjcu'
    b'NS41IDEuNyAxLjUuNSA1LS42IDQuOGwtNy44LS4zYy0uMS0zLTcuNy0yLjUtNy41LjEtNC4x'
    b'LjUtNy44LS4xLTEyLS4zLTEuMi0xLjUtMS00LjIuNC00Ljh6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'SA')

SA = b64_SA
index.append("SA")
index.append("SAU")
index.append("Saudi Arabia")
catalog["SA"] = SA
catalog["SAU"] = SA
catalog["Saudi Arabia"] = SA
country["Saudi Arabia"] = ('SA', 'SAU', 0)
lookup["SA"] = ('SA', 'SAU', 'Saudi Arabia', 0)
lookup["Riyadh Saudi Arabia"] = ('SA', 'SAU', 'Saudi Arabia', 0)
lookup["SAU"] = ('SA', 'SAU', 'Saudi Arabia', 0)
lookup["Saudi Arabia"] = ('SA', 'SAU', 'Saudi Arabia', 0)
details["SA"] = {"continent":"Asia","capital":"Riyadh","currency":"Saudi Riyal","web":".sa","lang":"ar-SA","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_SB = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNiIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InNiLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI3NiLWEpIiB0cmFuc2Zv'
    b'cm09InNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjMDAwMGQ2IiBkPSJNMCA1MDcu'
    b'MiA5ODcuNCAwSDB2NTA3LjJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDA2MDAwIiBkPSJNMTAy'
    b'NCAwIDI3LjIgNTEySDEwMjRWMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmYzAiIGQ9Ik0xMDI0'
    b'IDBoLTU0LjlMMCA0ODUuNFY1MTJoNTQuOUwxMDI0IDI3LjZWMHoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIGQ9Im03MS40IDkuMSAxMS44IDM0LjVoMzguNUw5MC42IDY0LjdsMTEuOSAz'
    b'NC40TDcxLjQgNzggNDAuMyA5OS4ybDExLjktMzQuNC0zMS4xLTIxLjNoMzguNHptMTkxLjEg'
    b'MCAxMS45IDM0LjVoMzguNWwtMzEuMiAyMS4yIDEyIDM0LjRMMjYyLjQgNzhsLTMxIDIxLjMg'
    b'MTEuOS0zNC40LTMxLjItMjEuM2gzOC41em0wIDE0NC41IDExLjkgMzQuNWgzOC41bC0zMS4y'
    b'IDIxLjIgMTIgMzQuNC0zMS4yLTIxLjMtMzEgMjEuMyAxMS45LTM0LjQtMzEuMi0yMS4zaDM4'
    b'LjV6bS05NS03MS40IDExLjkgMzQuNGgzOC40bC0zMSAyMS4zIDExLjggMzQuNC0zMS0yMS4z'
    b'LTMxLjIgMjEuMyAxMi0zNC40LTMxLjItMjEuM2gzOC41em0tOTYuMSA3MS40IDExLjggMzQu'
    b'NWgzOC41bC0zMS4xIDIxLjIgMTEuOSAzNC40LTMxLjEtMjEuMy0zMS4xIDIxLjMgMTItMzQu'
    b'NEwyMSAxODhoMzguNHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'SB')

SB = b64_SB
index.append("SB")
index.append("SLB")
index.append("Solomon Islands")
catalog["SB"] = SB
catalog["SLB"] = SB
catalog["Solomon Islands"] = SB
country["Solomon Islands"] = ('SB', 'SLB', 0)
lookup["SB"] = ('SB', 'SLB', 'Solomon Islands', 0)
lookup["Honiara Solomon Islands"] = ('SB', 'SLB', 'Solomon Islands', 0)
lookup["SLB"] = ('SB', 'SLB', 'Solomon Islands', 0)
lookup["Solomon Islands"] = ('SB', 'SLB', 'Solomon Islands', 0)
details["SB"] = {"continent":"Oceania","capital":"Honiara","currency":"Solomon Islands Dollar","web":".sb","lang":"en-SB | tpi","tz":"+11:00","altname":""}
#----------------------------------------------------------------------
b64_SC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNjIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDBaIi8+CiAgPHBhdGggZmlsbD0iI2Q5MjIyMyIgZD0iTTAgNDgwVjBoNjQw'
    b'djE2MHoiLz4KICA8cGF0aCBmaWxsPSIjZmNkOTU1IiBkPSJNMCA0ODBWMGg0MjYuN3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjMDAzZDg4IiBkPSJNMCA0ODBWMGgyMTMuM3oiLz4KICA8cGF0aCBm'
    b'aWxsPSIjMDA3YTM5IiBkPSJtMCA0ODAgNjQwLTE2MHYxNjB6Ii8+Cjwvc3ZnPgo=', 'SC')

SC = b64_SC
index.append("SC")
index.append("SYC")
index.append("Seychelles")
catalog["SC"] = SC
catalog["SYC"] = SC
catalog["Seychelles"] = SC
country["Seychelles"] = ('SC', 'SYC', 0)
lookup["SC"] = ('SC', 'SYC', 'Seychelles', 0)
lookup["Victoria Seychelles"] = ('SC', 'SYC', 'Seychelles', 0)
lookup["SYC"] = ('SC', 'SYC', 'Seychelles', 0)
lookup["Seychelles"] = ('SC', 'SYC', 'Seychelles', 0)
details["SC"] = {"continent":"Africa","capital":"Victoria","currency":"Seychelles Rupee","web":".sc","lang":"en-SC | fr-SC","tz":"+04:00","altname":""}
#----------------------------------------------------------------------
b64_SD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNkIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InNkLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI3NkLWEpIiB0cmFuc2Zv'
    b'cm09InNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBkPSJNMCAzNDEuM2gxMDI0VjUxMkgweiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMTcwLjZoMTAyNHYxNzAuN0gweiIvPgog'
    b'ICAgPHBhdGggZmlsbD0icmVkIiBkPSJNMCAwaDEwMjQuOHYxNzAuN0gweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iIzAwOWEwMCIgZD0iTTAgMHY1MTJsMzQxLjMtMjU2TDAgMHoiLz4KICA8L2c+'
    b'Cjwvc3ZnPgo=', 'SD')

SD = b64_SD
index.append("SD")
index.append("SDN")
index.append("Sudan")
catalog["SD"] = SD
catalog["SDN"] = SD
catalog["Sudan"] = SD
country["Sudan"] = ('SD', 'SDN', 0)
lookup["SD"] = ('SD', 'SDN', 'Sudan', 0)
lookup["Khartoum Sudan"] = ('SD', 'SDN', 'Sudan', 0)
lookup["SDN"] = ('SD', 'SDN', 'Sudan', 0)
lookup["Sudan"] = ('SD', 'SDN', 'Sudan', 0)
details["SD"] = {"continent":"Africa","capital":"Khartoum","currency":"Sudanese Pound","web":".sd","lang":"ar-SD | en | fia","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_SE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNlIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwNTI5MyIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZlY2IwMCIgZD0iTTE3NiAwdjE5'
    b'Mkgwdjk2aDE3NnYxOTJoOTZWMjg4aDM2OHYtOTZIMjcyVjBoLTk2eiIvPgo8L3N2Zz4K', 'SE')

SE = b64_SE
index.append("SE")
index.append("SWE")
index.append("Sweden")
catalog["SE"] = SE
catalog["SWE"] = SE
catalog["Sweden"] = SE
country["Sweden"] = ('SE', 'SWE', 0)
lookup["SE"] = ('SE', 'SWE', 'Sweden', 0)
lookup["Stockholm Sweden"] = ('SE', 'SWE', 'Sweden', 0)
lookup["SWE"] = ('SE', 'SWE', 'Sweden', 0)
lookup["Sweden"] = ('SE', 'SWE', 'Sweden', 0)
details["SE"] = {"continent":"Europe","capital":"Stockholm","currency":"Swedish Krona","web":".se","lang":"sv-SE | se | sma | fi-SE","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_SG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InNnLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY0MHY0ODBI'
    b'MHoiLz4KICAgIDwvY2xpcFBhdGg+CiAgPC9kZWZzPgogIDxnIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgY2xpcC1wYXRoPSJ1cmwoI3NnLWEpIj4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0t'
    b'MjAgMGg3MjB2NDgwSC0yMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNkZjAwMDAiIGQ9Ik0tMjAg'
    b'MGg3MjB2MjQwSC0yMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xNDYgNDAuMmE4'
    b'NC40IDg0LjQgMCAwIDAgLjggMTY1LjIgODYgODYgMCAwIDEtMTA2LjYtNTkgODYgODYgMCAw'
    b'IDEgNTktMTA2YzE2LTQuNiAzMC44LTQuNyA0Ni45LS4yeiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmZiIgZD0ibTEzMyAxMTAgNC45IDE1LTEzLTkuMi0xMi44IDkuNCA0LjctMTUuMi0xMi44'
    b'LTkuMyAxNS45LS4yIDUtMTUgNSAxNWgxNS44em0xNy41IDUyIDUgMTUuMS0xMy05LjItMTIu'
    b'OSA5LjMgNC44LTE1LjEtMTIuOC05LjQgMTUuOS0uMSA0LjktMTUuMSA1IDE1aDE2em01OC41'
    b'LS40IDQuOSAxNS4yLTEzLTkuMy0xMi44IDkuMyA0LjctMTUuMS0xMi44LTkuMyAxNS45LS4y'
    b'IDUtMTUgNSAxNWgxNS44em0xNy40LTUxLjYgNC45IDE1LjEtMTMtOS4yLTEyLjggOS4zIDQu'
    b'OC0xNS4xLTEyLjktOS40IDE2LS4xIDQuOC0xNS4xIDUgMTVoMTZ6bS00Ni4zLTM0LjMgNSAx'
    b'NS4yLTEzLTkuMy0xMi45IDkuNCA0LjgtMTUuMi0xMi44LTkuNCAxNS44LS4xIDUtMTUuMSA1'
    b'IDE1aDE2eiIvPgogIDwvZz4KPC9zdmc+Cg==', 'SG')

SG = b64_SG
index.append("SG")
index.append("SGP")
index.append("Singapore")
catalog["SG"] = SG
catalog["SGP"] = SG
catalog["Singapore"] = SG
country["Singapore"] = ('SG', 'SGP', 0)
lookup["SG"] = ('SG', 'SGP', 'Singapore', 0)
lookup["Singapore Singapore"] = ('SG', 'SGP', 'Singapore', 0)
lookup["SGP"] = ('SG', 'SGP', 'Singapore', 0)
lookup["Singapore"] = ('SG', 'SGP', 'Singapore', 0)
details["SG"] = {"continent":"Asia","capital":"Singapore","currency":"Singapore Dollar","web":".sg","lang":"cmn | en-SG | ms-SG | ta-SG | zh-SG","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_SH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNoIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAxMjE2OSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI0ZGRiIgZD0ibTc1IDAgMjQ0IDE4'
    b'MUw1NjIgMGg3OHY2Mkw0MDAgMjQxbDI0MCAxNzh2NjFoLTgwTDMyMCAzMDEgODEgNDgwSDB2'
    b'LTYwbDIzOS0xNzhMMCA2NFYwaDc1eiIvPgogIDxwYXRoIGZpbGw9IiNDODEwMkUiIGQ9Im00'
    b'MjQgMjgxIDIxNiAxNTl2NDBMMzY5IDI4MWg1NXptLTE4NCAyMCA2IDM1TDU0IDQ4MEgwbDI0'
    b'MC0xNzl6TTY0MCAwdjNMMzkxIDE5MWwyLTQ0TDU5MCAwaDUwek0wIDBsMjM5IDE3NmgtNjBM'
    b'MCA0MlYweiIvPgogIDxwYXRoIGZpbGw9IiNGRkYiIGQ9Ik0yNDEgMHY0ODBoMTYwVjBIMjQx'
    b'ek0wIDE2MHYxNjBoNjQwVjE2MEgweiIvPgogIDxwYXRoIGZpbGw9IiNDODEwMkUiIGQ9Ik0w'
    b'IDE5M3Y5Nmg2NDB2LTk2SDB6TTI3MyAwdjQ4MGg5NlYwaC05NnoiLz4KPC9zdmc+Cg==', 'SH')

SH = b64_SH
index.append("SH")
index.append("SHN")
index.append("Saint Helena")
catalog["SH"] = SH
catalog["SHN"] = SH
catalog["Saint Helena"] = SH
country["Saint Helena"] = ('SH', 'SHN', 0)
lookup["SH"] = ('SH', 'SHN', 'Saint Helena', 0)
lookup["Jamestown Saint Helena"] = ('SH', 'SHN', 'Saint Helena', 0)
lookup["SHN"] = ('SH', 'SHN', 'Saint Helena', 0)
lookup["Saint Helena"] = ('SH', 'SHN', 'Saint Helena', 0)
details["SH"] = {"continent":"Africa","capital":"Jamestown","currency":"Saint Helena Pound","web":".sh","lang":"en-SH","tz":"±0:00","altname":""}
#----------------------------------------------------------------------
b64_SI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNpIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InNpLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTE1IDBoNjgyLjZ2'
    b'NTEySC0xNS4xeiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI3NpLWEpIiB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSgxNC4xKSBzY2FsZSguOTM3NSkiPgogICAgPHBhdGggZmls'
    b'bD0iI2ZmZiIgZD0iTS02MiAwSDk2MnY1MTJILTYyeiIvPgogICAgPHBhdGggZmlsbD0iI2Q1'
    b'MDAwMCIgZD0iTS02MiAzNDEuM0g5NjJWNTEySC02MnoiLz4KICAgIDxwYXRoIGZpbGw9IiMw'
    b'MDAwYmYiIGQ9Ik0tNjIgMTcwLjdIOTYydjE3MC42SC02MnoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNkNTAwMDAiIGQ9Ik0yMjguNCA5M2MtNCA2MS42LTYuNCA5NS40LTE1LjcgMTExLTEwLjIg'
    b'MTYuOC0yMCAyOS4xLTU5LjcgNDQtMzkuNi0xNC45LTQ5LjQtMjcuMi01OS42LTQ0LTkuNC0x'
    b'NS42LTExLjctNDkuNC0xNS43LTExMWw1LjgtMmMxMS44LTMuNiAyMC42LTYuNSAyNy4xLTcu'
    b'OCA5LjMtMiAxNy4zLTQuMiA0Mi4zLTQuNyAyNSAuNCAzMyAyLjggNDIuMyA0LjggNi40IDEu'
    b'NCAxNS42IDQgMjcuMyA3LjdsNS45IDJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDAwMGJmIiBk'
    b'PSJNMjIyLjYgOTFjLTMuOCA2MS41LTcgODkuNy0xMiAxMDMuMi05LjYgMjMuMi0yNC44IDM1'
    b'LjktNTcuNiA0OC0zMi44LTEyLjEtNDgtMjQuOC01Ny43LTQ4LTUtMTMuNi04LTQxLjctMTEu'
    b'OC0xMDMuMyAxMS42LTMuNiAyMC42LTYuNCAyNy4xLTcuNyA5LjMtMiAxNy4zLTQuMyA0Mi4z'
    b'LTQuNyAyNSAuNCAzMyAyLjcgNDIuMyA0LjdhMjg0IDI4NCAwIDAgMSAyNy40IDcuN3oiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmRmMDAiIGQ9Im0xNTMgMTA5LjggMS41IDMuNyA3IDEtNC41'
    b'IDIuNyA0LjMgMi45LTYuMyAxLTIgMy40LTItMy41LTYtLjggNC0zLTQuMi0yLjcgNi43LTEg'
    b'MS41LTMuN3oiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im0yMDguMyAxNzkuNi0zLjkt'
    b'My0yLjctNC42LTUuNC00LjctMi45LTQuNy01LjQtNC45LTIuNi00LjctMy0yLjMtMS44LTEu'
    b'OS01IDQuMy0yLjYgNC43LTMuMyAzLTMuNy0yLjktMi43LTQuOC0xMC4zLTE4LjMtMTAuMyAx'
    b'OC4zLTIuNyA0LjgtMy43IDIuOS0zLjMtMy0yLjctNC43LTQuOS00LjMtMS45IDEuOC0yLjkg'
    b'Mi40LTIuNiA0LjctNS40IDQuOS0yLjkgNC43LTUuNCA0LjctMi43IDQuNi0zLjkgM2E2NS44'
    b'IDY1LjggMCAwIDAgMTguNiAzNi4zIDEwNyAxMDcgMCAwIDAgMzYuNiAyMC41IDEwNC4xIDEw'
    b'NC4xIDAgMCAwIDM2LjgtMjAuNWM1LjgtNiAxNi42LTE5LjMgMTguNi0zNi4zeiIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZmZGYwMCIgZD0ibTE2OS40IDgzLjkgMS42IDMuNyA3IDEtNC42IDIu'
    b'NyA0LjQgMi45LTYuMyAxLTIgMy40LTItMy41LTYtLjggNC0zLTQuMi0yLjcgNi42LTEgMS42'
    b'LTMuN3ptLTMzIDAgMS42IDMuNyA3IC45LTQuNSAyLjcgNC4zIDIuOS02LjMgMS0yIDMuNC0y'
    b'LTMuNC02LS45IDQtMy00LjItMi43IDYuNy0xIDEuNS0zLjd6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjMDAwMGJmIiBkPSJNMTk5LjcgMjAzaC03LjRsLTctLjUtOC4zLTRoLTkuNGwtOC4xIDQt'
    b'Ni41LjYtNi40LS42LTguMS00SDEyOWwtOC40IDQtNi45LjYtNy42LS4xLTMuNi02LjIuMS0u'
    b'MiAxMS4yIDEuOSA2LjktLjUgOC4zLTQuMWg5LjRsOC4yIDQgNi40LjYgNi41LS42IDguMS00'
    b'aDkuNGw4LjQgNCA2LjkuNiAxMC44LTIgLjIuNC0zLjcgNi4xem0tODYuNCA5LjUgNy40LS41'
    b'IDguMy00aDkuNGw4LjIgNCA2LjQuNSA2LjQtLjUgOC4yLTRoOS40bDguMyA0IDcuNS41IDQu'
    b'OC02aC0uMWwtNS4yIDEuNC02LjktLjUtOC4zLTRoLTkuNGwtOC4yIDQtNi40LjYtNi41LS42'
    b'LTguMS00SDEyOWwtOC40IDQtNi45LjYtNS0xLjN2LjJsNC41IDUuNnoiLz4KICA8L2c+Cjwv'
    b'c3ZnPgo=', 'SI')

SI = b64_SI
index.append("SI")
index.append("SVN")
index.append("Slovenia")
catalog["SI"] = SI
catalog["SVN"] = SI
catalog["Slovenia"] = SI
country["Slovenia"] = ('SI', 'SVN', 0)
lookup["SI"] = ('SI', 'SVN', 'Slovenia', 0)
lookup["Ljubljana Slovenia"] = ('SI', 'SVN', 'Slovenia', 0)
lookup["SVN"] = ('SI', 'SVN', 'Slovenia', 0)
lookup["Slovenia"] = ('SI', 'SVN', 'Slovenia', 0)
details["SI"] = {"continent":"Europe","capital":"Ljubljana","currency":"Euro","web":".si","lang":"sl | sh","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_SJ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNqIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2VmMmIyZCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTE4MCAwaDEyMHY0'
    b'ODBIMTgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDE4MGg2NDB2MTIwSDB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzAwMjg2OCIgZD0iTTIxMCAwaDYwdjQ4MGgtNjB6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzAwMjg2OCIgZD0iTTAgMjEwaDY0MHY2MEgweiIvPgo8L3N2Zz4K', 'SJ')

SJ = b64_SJ
index.append("SJ")
index.append("SJM")
index.append("Svalbard and Jan Mayen Islands")
catalog["SJ"] = SJ
catalog["SJM"] = SJ
catalog["Svalbard and Jan Mayen Islands"] = SJ
country["Svalbard and Jan Mayen Islands"] = ('SJ', 'SJM', 0)
lookup["SJ"] = ('SJ', 'SJM', 'Svalbard and Jan Mayen Islands', 0)
lookup["Longyearbyen Svalbard and Jan Mayen Islands"] = ('SJ', 'SJM', 'Svalbard and Jan Mayen Islands', 0)
lookup["SJM"] = ('SJ', 'SJM', 'Svalbard and Jan Mayen Islands', 0)
lookup["Svalbard and Jan Mayen Islands"] = ('SJ', 'SJM', 'Svalbard and Jan Mayen Islands', 0)
details["SJ"] = {"continent":"Europe","capital":"Longyearbyen","currency":"Norwegian Krone","web":".sj","lang":"no | ru","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_SK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNrIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2VlMWMyNSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzBiNGVhMiIgZD0iTTAgMGg2NDB2'
    b'MzIwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0iTTIzMyAzNzAuOGMtNDMtMjAuNy0xMDQuNi02MS45LTEw'
    b'NC42LTE0My4yIDAtODEuNCA0LTExOC40IDQtMTE4LjRoMjAxLjNzMy45IDM3IDMuOSAxMTgu'
    b'NFMyNzYgMzUwIDIzMyAzNzAuOHoiLz4KICA8cGF0aCBmaWxsPSIjZWUxYzI1IiBkPSJNMjMz'
    b'IDM2MGMtMzkuNS0xOS05Ni01Ni44LTk2LTEzMS40czMuNi0xMDguNiAzLjYtMTA4LjZoMTg0'
    b'LjhzMy41IDM0IDMuNSAxMDguNkMzMjkgMzAzLjMgMjcyLjUgMzQxIDIzMyAzNjB6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0iTTI0MS40IDIwOWMxMC43LjIgMzEuNi42IDUwLjEtNS42'
    b'IDAgMC0uNCA2LjctLjQgMTQuNHMuNSAxNC40LjUgMTQuNGMtMTctNS43LTM4LjEtNS44LTUw'
    b'LjItNS43djQxLjJoLTE2Ljh2LTQxLjJjLTEyLS4xLTMzLjEgMC01MC4xIDUuNyAwIDAgLjUt'
    b'Ni43LjUtMTQuNCAwLTcuOC0uNS0xNC40LS41LTE0LjQgMTguNSA2LjIgMzkuNCA1LjggNTAg'
    b'NS42di0yNS45Yy05LjcgMC0yMy43LjQtMzkuNiA1LjcgMCAwIC41LTYuNi41LTE0LjQgMC03'
    b'LjctLjUtMTQuNC0uNS0xNC40IDE1LjkgNS4zIDI5LjkgNS44IDM5LjYgNS43LS41LTE2LjQt'
    b'NS4zLTM3LTUuMy0zN3M5LjkuNyAxMy44LjdjNCAwIDEzLjgtLjcgMTMuOC0uN3MtNC44IDIw'
    b'LjYtNS4zIDM3YzkuNy4xIDIzLjctLjQgMzkuNi01LjcgMCAwLS41IDYuNy0uNSAxNC40IDAg'
    b'Ny44LjUgMTQuNC41IDE0LjRhMTE5IDExOSAwIDAgMC0zOS43LTUuN3YyNnoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjMGI0ZWEyIiBkPSJNMjMzIDI2My4zYy0xOS45IDAtMzAuNSAyNy41LTMwLjUg'
    b'MjcuNXMtNi0xMy0yMi4yLTEzYy0xMSAwLTE5IDkuNy0yNC4yIDE4LjggMjAgMzEuNyA1MS45'
    b'IDUxLjMgNzYuOSA2My40IDI1LTEyIDU3LTMxLjcgNzYuOS02My40LTUuMi05LTEzLjItMTgu'
    b'OC0yNC4yLTE4LjgtMTYuMiAwLTIyLjIgMTMtMjIuMiAxM1MyNTMgMjYzLjMgMjMzIDI2My4z'
    b'eiIvPgo8L3N2Zz4K', 'SK')

SK = b64_SK
index.append("SK")
index.append("SVK")
index.append("Slovakia")
catalog["SK"] = SK
catalog["SVK"] = SK
catalog["Slovakia"] = SK
country["Slovakia"] = ('SK', 'SVK', 0)
lookup["SK"] = ('SK', 'SVK', 'Slovakia', 0)
lookup["Bratislava Slovakia"] = ('SK', 'SVK', 'Slovakia', 0)
lookup["SVK"] = ('SK', 'SVK', 'Slovakia', 0)
lookup["Slovakia"] = ('SK', 'SVK', 'Slovakia', 0)
details["SK"] = {"continent":"Europe","capital":"Bratislava","currency":"Euro","web":".sk","lang":"sk | hu","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_SL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNsIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMDAwY2QiIGQ9Ik0wIDMyMC4zaDY0MFY0ODBIMHoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDE2MC43aDY0MHYxNTkuNkgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iIzAwY2QwMCIgZD0iTTAgMGg2NDB2MTYwLjdIMHoiLz4KICA8L2c+Cjwvc3Zn'
    b'Pgo=', 'SL')

SL = b64_SL
index.append("SL")
index.append("SLE")
index.append("Sierra Leone")
catalog["SL"] = SL
catalog["SLE"] = SL
catalog["Sierra Leone"] = SL
country["Sierra Leone"] = ('SL', 'SLE', 0)
lookup["SL"] = ('SL', 'SLE', 'Sierra Leone', 0)
lookup["Freetown Sierra Leone"] = ('SL', 'SLE', 'Sierra Leone', 0)
lookup["SLE"] = ('SL', 'SLE', 'Sierra Leone', 0)
lookup["Sierra Leone"] = ('SL', 'SLE', 'Sierra Leone', 0)
details["SL"] = {"continent":"Africa","capital":"Freetown","currency":"Leone","web":".sl","lang":"en-SL | men | tem","tz":"±0:00","altname":""}
#----------------------------------------------------------------------
b64_SM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjMTliNmVmIiBkPSJNMCAyNDBo'
    b'NjQwdjI0MEgweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MjQwSDB6'
    b'Ii8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiNmZDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlPSIjN2Q2YzAwIiBzdHJva2Utd2lkdGg9IjIuNCIgZD0iTTMxNyAzMzkuMkMzNjkuNiAz'
    b'MDAgNDI2IDIyMCAzNTkuOSAxNzcuOGMtMTIuMy0yLjQtMjYtMS43LTMyLjcgMy42LTMuNS0y'
    b'LTYuMy0xLjgtOS44IDEuOS0yLjUtMy01LTQuNC0xMC0yLjlhNDAuOCA0MC44IDAgMCAwLTMx'
    b'LjUtM0MyMTggMjExLjggMjUzLjQgMjk0IDMxNyAzMzkuMXoiLz4KICA8ZyBzdHJva2U9IiMz'
    b'YTlkNGYiPgogICAgPHBhdGggZmlsbD0iIzRmZDQ2YiIgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuNCIgZD0iTTQxNCAyNTAu'
    b'MXM2LTggNi4yLThjNS45LTMuNCA2LjUtNy45IDYuNS03LjkgNS45LTEuOCA0LTYuNyA0LjUt'
    b'Ny4zYTYuNCA2LjQgMCAwIDAgMS40LTcuMWMwLS44IDItOC40LS44LTkuNC4xLTgtNC44LTcu'
    b'My04LjgtMi00LjIgMS4yLTUuMSA0LjctMy42IDguNS01LjUgMC01LjcgOC00LjEgMTIuNC03'
    b'LjMtLjItMy4zIDgtMy41IDguNC0yLjQgMS4yIDEuOSAxMi44IDIuMyAxMi40em0tNDYgNjgu'
    b'MiAzLjYgMi4yYy44IDIuOCAzLjQgNC42IDUuMyA0LjEgMSA0LjMgNS42IDMuNyA5IDEuMiAy'
    b'LjcgNCA2IDQgMTAuNiAyLjcgNCAzIDkuMyAxLjcgMTIuOC0xLjQgMy43IDMgNi4yLjggOC4x'
    b'LTIuNSAzIC44IDUuMi4zIDYuMy0yLjYgNS43LS41IDIuOS01LjktMS44LTguMiAzLjctMy4y'
    b'IDcuOS0xMCAyLTExLTEuOC0xLjMtNS4zLTEtNy45LjItLjctMy00LjgtMy43LTkuNC0uNC0x'
    b'LjUtMy4zLTctMS43LTkuNS42LTMuMy0yLjgtNy4yLTIuOC0xMi45LjRMMzY4IDMxOC4zem0w'
    b'LTguN2MuNi0zLjgtMi0xMC42IDItMTEuMi0uNy02LjMuMy0xMy4zIDcuNS0xMi43IDEuMi01'
    b'LjkgMS0xMS40IDcuOC0xMi4yIDAgMCA1LjUtMTkuMSAxMS4yLTUuOSAyLjIgMy45IDEuOCAx'
    b'MC4yLTIuNyA5IC45IDQuNy0uNyA4LjktNS45IDguNyAyLjMgMy40IDEuNiA3LjktMSAxMGwt'
    b'MTkgMTQuM3ptMzMuMS0yMy45IDYtMS4yYzYtNCA4LjUtNS43IDExLjUtMS4yIDUuMS0xIDEw'
    b'LS42IDkuOCAzLjQgNiAuNSA2IDQuMyA1LjMgNy40IDEgNS4zLTEuNCAxMi4zLTUgMy44LTEx'
    b'LjktNy4yLTE4LjYtNi4yLTM3LjMtMmw5LjctMTAuMnptMy4xLTUuOWMuMi0uMiAxNy41LTQu'
    b'NyAxNS43LTEwIDQuOS0uOCA1LjktNS43IDYtNS43IDEwLjMtMy4yIDkuNy05LjEgOS43LTku'
    b'MSAyLjktMy4xIDgtNi4zIDYuOS0xMS44LjMtNi4zLjktMTAuMi03LjYtNi4xLTYuMy0uNi04'
    b'LjUgMy0xMC4zIDguNS0zLTMuNS03LjggMi4xLTguNCA3LjEgMCAwLTcuNyA3LjYtNy43IDcu'
    b'OGwtNi41IDEyIDIuMiA3LjN6Ii8+CiAgICA8cGF0aCBmaWxsPSIjNGZkNDZiIiBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMi40'
    b'IiBkPSJNNDA0LjUgMjY2LjRjLTQuMS0zLjEtNi40LTYuOS01LjctMTAuNi0yLjctMy43LTQu'
    b'Ni01LjktMi05LjJsLTItNy41Yy01LjQtMi0zLjEtNi41LTEuNy04LjEtMi41LTMuNS0yLjYt'
    b'Ny4yLS4yLTEwLjQgMC02LjUgNC42LTQgOC4zIDAgMCAwIDYuNCA0LjUgMS43IDguNSA0Ljcg'
    b'MS43IDYgNS43IDMuNCA3LjQgNC4xIDEuOCA0LjcgNS41IDIuNSA4IDQuMSAzLjIgMi42IDcu'
    b'NCAzLjggMTEuMWwtOC4xIDEwLjh6Ii8+CiAgICA8cGF0aCBmaWxsPSIjNGZkNDZiIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0i'
    b'Mi40IiBkPSJNNDExLjggMjM2Yy0uMi0uMS02LjktOC43LTUtOS4zLS41LTIuNi0yLjUtNS41'
    b'LTEuMy04LjEtMy4zLTMuNC0zLjQtNy4zLS44LTEwLjQtMi4yLTMtMS4yLTcuMSAxLjgtOS44'
    b'LTEtNSAyLjYtNi4yIDUuNy03LjEgMi4zLTggNi02IDguMi4yIDMuMiAyLjggMi43IDcgMS42'
    b'IDEwLjIgMy44IDIuNSAxLjUgNS43LS4yIDdsLTEwIDI3LjR6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjNGZkNDZiIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZS1saW5lam9pbj0icm91bmQi'
    b'IHN0cm9rZS13aWR0aD0iMi40IiBkPSJtNDEwLjggMTkzLjEtNS43LTUuN2MxLjUtMyAyLjct'
    b'OC4zLTEuNi0xMC44LTIuNC01LjctMTQuMi0xMi45LTE2LjEuOC0xLjgtNC4xLTUuNi04LjIt'
    b'OC4zLTMuNC02LjItNS4zLTkuNS0zLjctNi4zIDMgMCAwLTIuOSA0LjUgNC42IDggLjYuNi0y'
    b'LjQgOC4xIDYuNiA4LjMtMS43IDIuNiAxIDYuMiA0LjYgNi0yLjUgMy4xIDEuOCA2LjUgNC41'
    b'IDUuMi0xLjEgMy41LTEgNS4yIDMuOSA1LjdsNS41IDYuMyA0LjUgNi4xIDMuOC0yOS41eiIv'
    b'PgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Ut'
    b'd2lkdGg9IjIuMiIgZD0iTTQxNC4zIDI0Ni41Yy4zLS4zIDExLTI0LjggMTIuNC0zMi4yTTQx'
    b'NS40IDIwM3MxLjggMjAtMy4xIDM0LjZtLTI5LjctNTQuN3MyMS45IDIxIDI0IDI5LjdtLTgu'
    b'Ny0zMnMxLjQgMTcuMyA3LjUgMzQuM20zMSAyOC40UzQxNC42IDI2MS44IDQwNCAyNzhtMTEu'
    b'OCAzMHMtMjguOCA0LTQxLjQgNC4zbTMyIDhzLTM1LjgtLjgtMzguNC0zLjRtMjAuNS00M2Mw'
    b'IC40LTE4LjIgMzAuMy0xOC44IDQwIi8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiM2NWM3ZmYi'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjN2Q2YzAwIiBzdHJva2Utd2lkdGg9IjIu'
    b'NCIgZD0iTTMxNi45IDMzMy40Yy0zNy44LTM1LjYtNzYuNS0xMDIuNC0zOC0xMzYuMiA2Ljgg'
    b'My44IDE0LjkuNCAyNi00IDMuNCAzLjcgNy43IDQuNiAxMiAxLjhhOSA5IDAgMCAwIDEwLjct'
    b'Mi4xYzExIDYuMyAyNC45IDkuNiAyOC4yIDMuMyAzNy44IDM2LS42IDEwMy4yLTM5IDEzNy4z'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiM4ZmM3NTMiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMx'
    b'NyAzMzIuNGEyMTIuOCAyMTIuOCAwIDAgMS00Mi4zLTU3LjZjMi0xLjcgMi45LTIuMiAzLjkt'
    b'NSA1LjguOCA4LjkgMSAxNi41LS40IDEuNiA1LjggMS45IDEwLjYgNS41IDE1LjRsNy43LTE1'
    b'YTMzLjYgMzMuNiAwIDAgMCAxNi41IDBjMy4yIDQuMiAyIDEwLjcgNy43IDE1LjYgMy40LTEw'
    b'IDYuNy0xMC42IDEwLjEtMTYgNSAxLjggOC4yIDEgMTIuMy0uMyAyIDIuNSAxIDIuNCA1IDZh'
    b'MTkzLjcgMTkzLjcgMCAwIDEtNDIuOCA1Ny4zeiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0i'
    b'TTI3Mi42IDE2NC4zYTMuNCAzLjQgMCAxIDEtNi43IDAgMy40IDMuNCAwIDAgMSA2LjggMHpt'
    b'LTMuNS03LjdhMy40IDMuNCAwIDEgMS02LjYgMCAzLjQgMy40IDAgMCAxIDYuNyAwem0tNC03'
    b'LjFhMy40IDMuNCAwIDEgMS02LjcgMCAzLjQgMy40IDAgMCAxIDYuNyAwem0tMi44LTdhMy40'
    b'IDMuNCAwIDEgMS02LjcgMCAzLjQgMy40IDAgMCAxIDYuNyAwem0uNS03LjZhMy40IDMuNCAw'
    b'IDEgMS02LjcgMCAzLjQgMy40IDAgMCAxIDYuNyAwem0xNy42LTEyLjVhMy40IDMuNCAwIDEg'
    b'MS02LjcgMCAzLjQgMy40IDAgMCAxIDYuNyAweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0i'
    b'TTI3My44IDEyMy42YTMuNCAzLjQgMCAxIDEtNi43IDAgMy40IDMuNCAwIDAgMSA2LjcgMHpt'
    b'LTcuMyA0LjNhMy40IDMuNCAwIDEgMS02LjcgMCAzLjQgMy40IDAgMCAxIDYuNyAwem0yMi40'
    b'LTUuNGEzLjQgMy40IDAgMSAxLTYuNiAwIDMuNCAzLjQgMCAwIDEgNi42IDB6bTkuNC44YTMu'
    b'NCAzLjQgMCAxIDEtNi43IDAgMy40IDMuNCAwIDAgMSA2LjcgMHptOC4yLS41YTMuNCAzLjQg'
    b'MCAxIDEtNi42IDAgMy40IDMuNCAwIDAgMSA2LjcgMHoiLz4KICA8cGF0aCBmaWxsPSIjZmQw'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzdkNmMwMCIgc3Ryb2tlLXdpZHRoPSIx'
    b'LjEiIGQ9Ik0zMjUuOSAxMTcuNWE4LjYgOC42IDAgMSAxLTE3LjIgMCA4LjYgOC42IDAgMCAx'
    b'IDE3LjIgMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0zMzUgMTIyLjdhMy40IDMuNCAw'
    b'IDEgMS02LjggMCAzLjQgMy40IDAgMCAxIDYuNyAwem04LjYuN2EzLjQgMy40IDAgMSAxLTYu'
    b'NiAwIDMuNCAzLjQgMCAwIDEgNi43IDB6bTguNS0uNGEzLjQgMy40IDAgMSAxLTYuNyAwIDMu'
    b'NCAzLjQgMCAwIDEgNi43IDB6bTcuMS0uM2EzLjQgMy40IDAgMSAxLTYuNyAwIDMuNCAzLjQg'
    b'MCAwIDEgNi43IDB6bTguOSAxYTMuNCAzLjQgMCAxIDEtNi43IDAgMy40IDMuNCAwIDAgMSA2'
    b'LjcgMHptNyA0LjRhMy40IDMuNCAwIDEgMS02LjcgMCAzLjQgMy40IDAgMCAxIDYuNyAweiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNlNDAwMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIj'
    b'YWMwMDAwIiBzdHJva2Utd2lkdGg9IjIuNCIgZD0ibTI2OS40IDE1MS43IDguNiAxNi41aDc5'
    b'LjJsOS4yLTE1LjljLTUuNC0zLjctOS02LjUtMTYuNy00LjgtNC4zLTYuMi05LTcuMy0xNi02'
    b'LjctMi4xLTIuMS00LTMuNC03LjYtNGwtMTYuNi41Yy00LjQuNC03LjggMy44LTggMy44LTct'
    b'LjktMTMuNS0uNy0xNS4yIDYuMi02LjUtMS42LTExIC4yLTE2LjkgNC40eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Ut'
    b'd2lkdGg9IjEuMSIgZD0iTTM3OCAxMzUuM2EzLjQgMy40IDAgMSAxLTYuNyAwIDMuNCAzLjQg'
    b'MCAwIDEgNi43IDB6bS42IDhhMy40IDMuNCAwIDEgMS02LjcgMCAzLjQgMy40IDAgMCAxIDYu'
    b'NyAwem0tMi41IDcuMmEzLjQgMy40IDAgMSAxLTYuNyAwIDMuNCAzLjQgMCAwIDEgNi43IDB6'
    b'bS0zIDZhMy40IDMuNCAwIDEgMS02LjggMCAzLjQgMy40IDAgMCAxIDYuNyAwem0tMy43IDcu'
    b'NWEzLjQgMy40IDAgMSAxLTYuNyAwIDMuNCAzLjQgMCAwIDEgNi43IDB6bS00Ni44LTkuNmE1'
    b'IDUgMCAxIDEtMTAgMCA1IDUgMCAwIDEgMTAgMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBm'
    b'aWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9'
    b'Ik0zMjMuNiAxNDNhNiA2IDAgMSAxLTEyIDAgNiA2IDAgMCAxIDEyIDB6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13'
    b'aWR0aD0iMS4xIiBkPSJNMzIyLjcgMTMyYTUuNCA1LjQgMCAxIDEtMTAuOCAwIDUuNCA1LjQg'
    b'MCAwIDEgMTAuOCAweiIvPgogIDxwYXRoIGZpbGw9IiNmZDAiIGZpbGwtcnVsZT0iZXZlbm9k'
    b'ZCIgc3Ryb2tlPSIjN2Q2YzAwIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0iTTMxNS41IDEwOXYt'
    b'NC4ybC0zLjYtLjEuMi0zLjJoM3YtMi44aDQuNXYyLjVoMy41bC0uMSAzLjRoLTMuNnY0LjVo'
    b'LTR6Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjZmQwIiBzdHJva2Utd2lkdGg9'
    b'IjMuMyIgZD0iTTI3Ny42IDE2OC4yYy03LjEtMTItMTcuNi0yOC40LTExLTM1LjUgOC45LTEw'
    b'LjEgMjkuOS0xIDQzLjMtNi44IDEgMTEuNC0yLjIgMzAuNCAyLjkgMzQuM2wtNC44IDQuMmMt'
    b'My0zLjctOC40LTguOC0xNS4yLjItNC0zLjQtOC4zLTIuOC0xMC40IDEuNy0yIC4zLTEuOSAx'
    b'LjEtNC44IDEuOXptODAtLjVjNy4yLTEyIDE3LjYtMjguMyAxMS4xLTM1LjQtOS0xMC4xLTMw'
    b'LTEtNDMuMy02LjktMSAxMS41IDIuMiAzMC41LTMgMzQuNGw0LjggNC4yYzQuNy02LjUgMTAu'
    b'NC02LjcgMTUuMy4yIDMuOS0zLjQgNy45LTMgMTAuNCAxLjcgMiAuMyAxLjggMSA0LjggMS44'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNmZDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIj'
    b'N2Q2YzAwIiBzdHJva2Utd2lkdGg9IjIuNCIgZD0iTTI3Ny4zIDE3Ny4xYTQzNyA0MzcgMCAw'
    b'IDEgNzkuMyAwbDMuMS05Yy0yNy43LTUtNDYuOC01LjYtODMtLjZsLjYgOS42eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNjNzZlMmUiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTMxNC4xIDMyOS40'
    b'LjYtNC4yYzIuOS44IDUgLjUgNy40LS40bDIuNC0zLjctMS44LTIuMWMtMS42LjMtMyAxLjgt'
    b'NCAzLjEtMS42LjEtMy0uNy00LjYtMWwtMS41LTYuNGMtMS41LTEuOC00LjctMS43LTQgMS41'
    b'bC4zIDIuNWMuNiAxLjUuOSAzLjYgMS45IDQuN3YyLjZsMy4zIDMuNHptMS4yLTE4LjNjLTIg'
    b'MS00LjYtLjgtNy4zLTEuOS0yLjUtLjEtNC40IDItNy40IDEuMy42LTEuNiAxLjktMS45IDIu'
    b'OC0yLjgtLjctNC4xIDEuNS01LjUgMi4xLTUuNS42IDAgMy4xLjYgMy4xLjZsMi40LjNjMS41'
    b'IDIuNyAzLjUgNSA0LjMgOHoiLz4KICA8cGF0aCBmaWxsPSIjZmZlMTAwIiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZT0iI2U5YmYwMCIgc3Ryb2tlLXdpZHRoPSIyLjQiIGQ9Ik0zMDAu'
    b'OCAzNjZjNy0xMS40IDU2LjItMzQuNCAxMDIuNC04NC4yLTQ3IDQ1LjMtNzYuNCA1Ni40LTEx'
    b'NC44IDg0bDEyLjQuM3oiLz4KICA8cGF0aCBmaWxsPSIjOWQ0OTE2IiBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIHN0cm9rZT0iIzY4MzAwZSIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0zNjguNCAz'
    b'MTMuMmEzLjYgMy42IDAgMSAxLTcuMiAwIDMuNiAzLjYgMCAwIDEgNy4yIDB6bTM0LjQtMzQu'
    b'OWE0IDQgMCAxIDEtOC4xIDAgNCA0IDAgMCAxIDggMHptMTEuNC0yOS42YTMuNiAzLjYgMCAx'
    b'IDEtNy4xIDAgMy42IDMuNiAwIDAgMSA3LjEgMHpNNDAzIDIxMC4zYTMuNiAzLjYgMCAxIDEt'
    b'Ny4xIDAgMy42IDMuNiAwIDAgMSA3LjEgMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2E5YTlhOSIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9'
    b'Ik0yNzkuMSAyNjkuNnYtMTUuMmwtMS41LTEuMnYtMy42bDIuOC0uMy41LTE3LTEuOC0xLS4y'
    b'LTIuOHMyIC44IDIgLjNsLjUtMy40cy0xLjMtLjItMS4zLS43IDEuNi0xLjggMS42LTEuOC0u'
    b'OC0uOC0xLTEuM2wtLjgtMi44LjgtMi45LS41LTEuNS0xLjMtMi4zIDEuOC0xLjgtLjUtMi44'
    b'YTEwIDEwIDAgMCAxIDEuNS0yLjljLjMtLjIgMi4zLTMgMi4zLTNsNC40LTEgNS4xLjcgMi44'
    b'IDEuOC41IDQuNnMtLjUgMi44LS43IDIuOGwtMi4zIDFzLTIuNi4zLTIuOSAwIC44IDMuMi44'
    b'IDMuMnYzbC0uMiAzLjlzMCAxLjgtLjMgMi0uOCAxLS44IDFsLS4yIDQgNCAxLS4yIDIuMy0y'
    b'LjguMi41IDE1LjcgNC4xLjd2NC40bC0xLjggMS0uNSAxNS43aC0xNC40em02Mi40LjN2LTE1'
    b'LjJsLTEuNS0xLjN2LTMuNmwyLjgtLjIuNS0xNy0xLjgtMS0uMi0yLjhzMiAuNyAyIC4ybC41'
    b'LTMuM3MtMS4zLS4zLTEuMy0uOCAxLjYtMS44IDEuNi0xLjgtLjgtLjctMS0xLjNsLS44LTIu'
    b'OC44LTIuOC0uNi0xLjUtMS4yLTIuMyAxLjgtMS44LS42LTIuOWExMCAxMCAwIDAgMSAxLjYt'
    b'Mi44bDIuMy0zIDQuNC0xLjEgNS4xLjggMi44IDEuOC41IDQuNnMtLjUgMi44LS43IDIuOGwt'
    b'Mi4zIDFzLTIuNi4zLTIuOSAwIC44IDMuMS44IDMuMXYzLjFsLS4zIDMuOXMwIDEuNy0uMiAy'
    b'bC0uOCAxLS4yIDMuOSA0IDEtLjIgMi4zLTIuOC4zLjUgMTUuNiA0LjEuOHY0LjRsLTEuOCAx'
    b'LS41IDE1LjdoLTE0LjR6bS0zMS42LjV2LTE1LjJsLTEuNS0xLjJ2LTMuN2wyLjgtLjIuNS0x'
    b'Ny0xLjgtMS0uMi0yLjhzMiAuOCAyIC4zbC41LTMuNHMtMS4yLS4yLTEuMi0uNyAxLjUtMS45'
    b'IDEuNS0xLjktLjgtLjctMS0xLjJsLS44LTIuOS44LTIuOC0uNS0xLjUtMS4zLTIuMyAxLjgt'
    b'MS44LS41LTIuOWE5IDkgMCAwIDEgMS41LTIuOGMuMy0uMiAyLjMtMyAyLjMtM2w0LjQtMSA1'
    b'LjEuNyAyLjggMS44LjYgNC42cy0uNiAyLjgtLjggMi44bC0yLjMgMXMtMi42LjMtMi44IDAg'
    b'LjcgMy4xLjcgMy4xdjMuMWwtLjIgMy45czAgMS44LS4zIDJsLS44IDEtLjIgMy45IDQgMS0u'
    b'MiAyLjMtMi44LjMuNSAxNS43IDQuMS43djQuNGwtMS44IDEtLjUgMTUuN0gzMTB6Ii8+CiAg'
    b'PHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjgzIDI2OS41di0xMmg2LjZWMjcwbC02'
    b'LjctLjV6bTMxLjQgMSAuMy0xMi4yaDZ2MTEuOWwtNi4zLjJ6bTMxLS4zLS40LTExLjUgNi41'
    b'LS4ydjEybC02LS4zem0tNjAuOC0zNmgzLjh2Ni4xaC0zLjh6bTMwLjMuMmg1LjN2NmgtNS4z'
    b'em0zMSAuNWg0LjZ2NS43SDM0NnoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiNh'
    b'OGE4YTgiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJNMjg2LjYgMjA3YzQgNC42IDQuMyA0LjYg'
    b'NC4zIDQuNm0yNi4yLTQuNmMuOCAxLjUgMiA0LjggMy42IDUuMW0yOS4zLTQuNHMxLjMgMy42'
    b'IDMgNC4xIi8+CiAgPHBhdGggZmlsbD0iI2I5NzcwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBk'
    b'PSJNMjgyLjIgMTk0YzEyLTMuOS0yLjgtMTEuNi01LjMgMC0zLjguNy00LjMgMy41LTEyLjcg'
    b'Mi4zLTIwLjQgMzMtNS4zIDg2LjUgNTQuMSAxNDEuOC0xMDYuNC05MC42LTYzLjItMTU3LjYt'
    b'MzMuNy0xNTUgMTYgMSA4IDIxLTIuNCAxMXoiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiM3ZDZjMDAiIHN0cm9rZS13aWR0aD0iMi40IiBkPSJNMjg1LjYgMTc3czkuNyAyLjcg'
    b'OS43IDYuOG0wLTcuNXM2LjggMyA4LjMgNS42bTQ1LjEtNC41cy04LjYgMS4yLTEwLjUgMy44'
    b'bS0yLjYtM3MtNSA0LjEtNC41IDUuM20zLjQgMTIuN2MtLjgtLjMtNC4yLTQuOS0zLjQtMTAu'
    b'NW0tMjkuOCA3LjVzMi4zLTIuNiAyLjMtNy41bTEzLjUtMS45LjQgMTFtOS40LTEuNmMwLS43'
    b'IDMtNy45LS40LTExLjNtLTIwLjMtMS41cy0yLjYgNy4yLS43IDEzLjJtMjAtNi44cy00LjIg'
    b'MS4yLTYgM20tMTEuOC0xLjljMC0uMyA0LjYtMSA2IDEuNiIvPgogIDxwYXRoIGZpbGw9IiNj'
    b'NzZlMmUiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMwMC42IDMwMS45Yy4yIDAgMy44LS43'
    b'IDMuOC0yLjQgMS44LTEuMi41LTQuNS41LTQuNWwtMy40LS42LTQuNi01LjJjLS4yLTEuNi4z'
    b'LTMuMS0uNy00LjgtMy4yLjgtNSAzLjUtNiA2LjUuNyAxIC44IDIgMi4zIDIuOSAxLjUuMiAy'
    b'LjUtLjcgMy45LS40LjcgMS4zLjUgMi40LjggMy42IDEuOSAxLjMgMi4zIDMuMiAzLjQgNC45'
    b'em0tNC4xLTIyLjJ2LTYuMmwtNC40LS4yYy0uNiAxLTEuNiAxLjQtMi4yIDIuMmwtMy4xIDEu'
    b'NmMxLjMgMS41IDIuOSAyLjQgMy44IDMuMiAyLjMuNiA0LjEuNiA1LjktLjZ6bS0xMy44IDku'
    b'MS0yLjQtNGE3LjIgNy4yIDAgMCAxIDQuNy4zczEgMi41LjMgMy40Yy0uNC45LTIuNy41LTIu'
    b'Ni4zem0zNi41IDQuMWE0LjYgNC42IDAgMCAwIDIuNy0zLjNsLTQuNS01LjEtNC0uMWMtMS0x'
    b'LTIuNC0xLjItMy42LTEuMiAwIDAgMS4yIDIgMi44IDIuMyAxLjIgMi42IDYuMiA3LjQgNi42'
    b'IDcuNHptNC4zLjZjMC0uMSA0LTEuNCA2LTEuMy0uMS0xLjYgMy01LjMgMy01LjNsNS42IDcu'
    b'M2MtMSAuOC0yLjguNi00LjIuOCAwIDAtMi43IDIuNi0zIDIuN3MtNS4yIDEuMy03LjYtLjJj'
    b'LTEtMiAuMy00LjMuMi00em0zLjItMTIuOGExNCAxNCAwIDAgMCAwLTcuNmgtNi40bC00LjIg'
    b'MnMxLjMgNC4yIDMgMy44Yy43IDIuMSAyLjkgMS42IDQgMi40bDMuNi0uNnptMjQuOS02LjRj'
    b'LTEgMi43LTEuNCA1LjUtLjIgOCAxLjIuMyAyLjYgMSAzLjYuOGw1LjEtOS4yYy0zLjUtMS4x'
    b'LTYuNC0xLTguNi40eiIvPgogIDxwYXRoIGZpbGw9IiNiOTc3MDAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgZD0iTTM1My4xIDE5My4yYy0xMi0zLjkgMi44LTExLjcgNS4zIDAgMy45LjYgNC40'
    b'IDMuNSAxMi44IDIuMyAyMC4zIDMzIDUuMiA4Ni41LTU0LjIgMTQxLjggMTA2LjUtOTAuNiA2'
    b'My4yLTE1Ny42IDMzLjctMTU1LjEtMTYgMS04IDIxIDIuNCAxMXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjYzc2ZTJlIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zNTQuMyAyODQuN2MtLjIgMC0z'
    b'IDItMyAybC00LjIgMS43LTQuNC4xLTEtMyAzLjQtM2MtMi44LS41LTUuNy43LTggMi44IDAg'
    b'MCAwIDMuMyAyIDUgMS4xIDEuNCA0LjUgNCA0LjUgNGE3IDcgMCAwIDAgNS40LTFsNS4zLTgu'
    b'NnptLTIzLjIgMzAuMWMxLjQuNCAxMS4zLTEyLjcgMTEuMy0xMi43YTEwIDEwIDAgMCAwLTQu'
    b'OS01LjRzLTQuOCA1LjctNC45IDcuNmMtLjggMS43LTMgOC4zLTIgOS4yLS4xLjItLjUgMi45'
    b'LjUgMS4zeiIvPgogIDxwYXRoIGZpbGw9IiMwMDY4MDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'c3Ryb2tlPSIjMDA0MTAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9'
    b'IjIuNCIgZD0iTTI2Ni40IDMxNy40Yy0xNC44LTEyLjktMzQuOC0yMC02Mi43LTEwLjMgNy41'
    b'IDMuMiAxNS42IDQuMyAyMi41IDcuOWw0MC4yIDIuNHoiLz4KICA8cGF0aCBmaWxsPSJub25l'
    b'IiBzdHJva2U9IiMwMGE0MDAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRo'
    b'PSIyLjIiIGQ9Ik0yMjMuNCAzMDguM2MyOS4zLjYgMzcuOCA3LjkgMzYuMyA2LjciLz4KICA8'
    b'cGF0aCBmaWxsPSIjMDA2ODAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwNDEw'
    b'MCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIyLjIiIGQ9Ik0yNjcg'
    b'MzE5Yy04LjggMS42LTIwLjggMTAtMjQuNCA5LjctOS41LTEuMS0xOC41LTUtMjcuNy04LTMu'
    b'OC0xLjItNy43IDAtMTEuNiAwIDMyLjgtMTUuNSA0NC0xMy40IDYzLjctMS44eiIvPgogIDxw'
    b'YXRoIGZpbGw9IiMwMDY4MDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDA0MTAw'
    b'IiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuNCIgZD0iTTI0NS40'
    b'IDI5NnMtMTEgMS42LTE1LjkgMS45Yy00LjgtLjMtMTItNC44LTE5LjgtMTMtNC00LjYtMTMu'
    b'NC00LTEzLjQtNCAyMC42LTQuNCAzNi43LS4yIDQ5IDE1LjJ6bS0xNS0yMS4yYy0xNC45LTEt'
    b'MzMuNS0xNC4zLTM3LjctMzAuMiAwIC4yIDUuNSAzLjUgNC42IDQuMyAyNC40IDYuMiAyNiAx'
    b'MS4yIDMzLjEgMjUuOXptMjUgMjUuNWMyLjEtMTMuNSAyLjctMjIuNC0zLjYtMzAuNC01LjMt'
    b'Ni02LjYtOS43LTEwLjQtMTguMy0xLjEgMTcuOC01IDMyLjUgMTQgNDguN3pNMjMyIDI2M2Mx'
    b'MS0xNi4xIDEzLTI4LjMgMTEuMi00Ny41LS4zIDEuNS00IDExLTQuMiAxMS0xNi41IDEwLjMt'
    b'OS4yIDI2LjUtNyAzNi41eiIvPgogIDxwYXRoIGZpbGw9IiMwMDY4MDAiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgc3Ryb2tlPSIjMDA0MTAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJv'
    b'a2Utd2lkdGg9IjIuNCIgZD0iTTIyMi4yIDE4NWMxMSAxNi4xIDkuNCAzMS4zIDcuNiA1MC41'
    b'LS4zLTEuNS00LTExLTQuMi0xMS0xNi41LTEwLjMtNS41LTI5LjUtMy40LTM5LjV6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzAwNjgwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDQx'
    b'MDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0aD0iMi40IiBkPSJNMjMx'
    b'LjMgMjEwYzI2LjgtMTMuNiAxNi41LTMwLjcgMjEuNC00NC0xOC42IDEzLjktMjEgMjguNi0y'
    b'MS4zIDQ0eiIvPgogIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwYTQwMCIgc3Ryb2tl'
    b'LWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuMiIgZD0iTTIzNSAyMDYuNmMzLjQt'
    b'OS41IDEwLTI1LjYgMTAuNy0yNS42TTIyNyAyMjYuNGMtLjYtNi43LTQtMjQuNy00LjMtMjYu'
    b'NSIvPgogIDxwYXRoIGZpbGw9IiMwMDY4MDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tl'
    b'PSIjMDA0MTAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjIuNCIg'
    b'ZD0iTTIyOC4zIDI1Ni41Yy0xNS0xLTMxLTIxLjMtMzUuMy0zNy4xIDAgLjIgNS41IDMuNCA0'
    b'LjYgNC4yIDIxLjQgOS42IDIzLjYgMTguMiAzMC43IDMyLjl6bS00LjQtMTRjLTExLTE2LjEt'
    b'MTMtMjguMy0xMS4zLTQ3LjUuMyAxLjUgNCAxMSA0LjMgMTEgMTYuNCAxMC4zIDkuMSAyNi41'
    b'IDcgMzYuNXptOS45LTI4LjNjMjcuNy0xMi4zIDE5LjItMjUuMiAyNy40LTM4LjctMTguNiAx'
    b'My44LTI3LjEgMjMuNC0yNy40IDM4Ljd6Ii8+CiAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDBhNDAwIiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS13aWR0aD0iMi4yIiBk'
    b'PSJNMjM1IDIxMS40YTcwLjcgNzAuNyAwIDAgMCAxNS4yLTIwLjciLz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiPgogICAgPHBhdGggZmlsbD0iI2ZmZTEwMCIgc3Ryb2tlPSIjZTliZjAw'
    b'IiBzdHJva2Utd2lkdGg9IjIuNCIgZD0ibTMzMy42IDM2Ni40IDEzLjQuMmMtNDQuNy00Mi0x'
    b'MzAuNS02MC4yLTExOC42LTEzNy40LTEyLjMgODMuNyA3MC4xIDkxLjUgMTA1LjIgMTM3LjJ6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjOWQ0OTE2IiBzdHJva2U9IiM2ODMwMGUiIHN0cm9rZS13'
    b'aWR0aD0iMS4xIiBkPSJNMjM1LjQgMjEyLjdhNC4zIDQuMyAwIDEgMS04LjYgMCA0LjMgNC4z'
    b'IDAgMCAxIDguNiAwem0tMi42IDIzLjZhNCA0IDAgMSAxLTguMSAwIDQgNCAwIDAgMSA4IDB6'
    b'bTMuOCAzMy43YTMuNiAzLjYgMCAxIDEtNy4yIDAgMy42IDMuNiAwIDAgMSA3LjIgMHptMzEu'
    b'MyAzNy4yYTMuNiAzLjYgMCAxIDEtNy4yIDAgMy42IDMuNiAwIDAgMSA3LjIgMHptNC41IDEw'
    b'LjdhMy42IDMuNiAwIDEgMS03LjIgMCAzLjYgMy42IDAgMCAxIDcuMiAweiIvPgogIDwvZz4K'
    b'ICA8ZyBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgPGcgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2Utd2lkdGg9IjEuMSI+CiAgICAgIDxwYXRoIGQ9Ik0yODguMiAzNDlhMTUu'
    b'NSAxNS41IDAgMCAxLTQuOC01LjhsLTE0LTEuNS0uMiA4IDE5LS43eiIvPgogICAgICA8cGF0'
    b'aCBzdHJva2UtbGluZWpvaW49InJvdW5kIiBkPSJNMTg1LjMgMzM5LjZjOC4yIDEuNSAyMC41'
    b'LS44IDI0LjUgNC41IDQuOCA1LjQtMTUuMSAxMy45LTEyLjMgMTguNiA2LjIgNi41IDEyLjUg'
    b'My44IDE5LjQuMiAxLjctMy41IDMtOS44IDMuOC0xMS43LTIuNS01LjctOS4zLTguNi03LjUt'
    b'MTcuMyAxMS4zLTQuMiAzMy4yLTMuOSAzNS42LTIuMiAxLjggMy42LjEgNS4yLjUgOC4xLTEu'
    b'OSAzLjctNi43IDkuOC02LjcgMTMuMSAxMiA0LjIgMTUtLjYgMjUuOC0uNCAxMi42LjIgMjAu'
    b'MiAzLjYgMjMtMS40LTItNC40LTEzLjUtLjgtMTcuOC0zLjYtMi4yLS43LTMuNi0yLjUtNS41'
    b'LTQuNHMtNy4yLTItOC02LjljMi4yLTEwLjIgMTctOC42IDE5LjMtMTAuMmwzOC40IDIuN2M3'
    b'LS4yIDExIDEyLjMgMS41IDE2LTkuNCAzLjgtMzcuMS01LjUtNDkuMi45LS42LTIuNi05LjMt'
    b'Ni42LTkuOS02LjctMy43IDEtMTAuOS43LTEwLjkuNy0xLjcgMy4yLTMuOCA1LjYtNS41IDgu'
    b'OS04LTMuNS0xNS41IDIuNy0yNC4yLjlsLTEzLjYgMS41LTguNi0uOC0xMy4yIDMuOCA5LjQt'
    b'OC4zLTguMy02eiIvPgogICAgICA8cGF0aCBkPSJNMTg0LjcgMzM4YTMuNiAzLjYgMCAxIDEt'
    b'Ny4yIDAgMy42IDMuNiAwIDAgMSA3LjIgMHptLTEgMThhMy42IDMuNiAwIDEgMS03LjIgMCAz'
    b'LjYgMy42IDAgMCAxIDcuMyAweiIvPgogICAgPC9nPgogICAgPGcgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2Utd2lkdGg9IjEuMSI+CiAgICAgIDxwYXRoIGQ9Ik0zNDYuMyAzNDkuMWMyLjMtMi4x'
    b'IDMuOC0zLjUgNC43LTUuOGwxNC0xLjYuMyA4LTE5LS42eiIvPgogICAgICA8cGF0aCBzdHJv'
    b'a2UtbGluZWpvaW49InJvdW5kIiBkPSJNNDQ5LjEgMzM5LjZjLTguMSAxLjUtMjAuNC0uNy0y'
    b'NC40IDQuNS00LjkgNS41IDE1IDE0IDEyLjIgMTguNi02LjIgNi42LTEyLjUgMy45LTE5LjQu'
    b'My0xLjYtMy41LTIuOS05LjgtMy44LTExLjcgMi42LTUuOCA5LjMtOC42IDcuNi0xNy4zLTEx'
    b'LjQtNC4zLTMzLjMtNC0zNS42LTIuMy0xLjkgMy43LS4yIDUuMy0uNiA4LjIgMiAzLjYgNi44'
    b'IDkuOCA2LjggMTMtMTIgNC4zLTE1LjEtLjYtMjUuOC0uMy0xMi42LjItMjAuMyAzLjUtMjMt'
    b'MS41IDEuOS00LjMgMTMuNC0uOCAxNy44LTMuNSAyLjItLjggMy42LTIuNSA1LjUtNC41czcu'
    b'Mi0yIDgtNi44Yy0yLjItMTAuMi0xNy04LjctMTkuNC0xMC4ybC0zOC40IDIuNmMtNy0uMi0x'
    b'MC45IDEyLjMtMS41IDE2LjEgOS40IDMuOCAzNy4yLTUuNiA0OS4yLjguNy0yLjYgOS4zLTYu'
    b'NSAxMC02LjcgMy42IDEuMSAxMC44LjcgMTAuOC43IDEuOCAzLjMgMy44IDUuNyA1LjYgOSA4'
    b'LTMuNiAxNS41IDIuNyAyNC4yLjhsMTMuNSAxLjUgOC43LS43IDEzLjIgMy43LTkuNC04LjIg'
    b'OC4yLTZ6Ii8+CiAgICAgIDxwYXRoIGQ9Ik00NDkuNyAzMzhhMy42IDMuNiAwIDEgMCA3LjMg'
    b'MCAzLjYgMy42IDAgMCAwLTcuMyAwem0xIDE4YTMuNiAzLjYgMCAxIDAgNy4yIDAgMy42IDMu'
    b'NiAwIDAgMC03LjIgMHoiLz4KICAgIDwvZz4KICAgIDxwYXRoIGQ9Ik0zMTcgMzI5LjNjLTMu'
    b'Mi0uNi00LjQtLjQtNi42LS42bC01LjEgMTUuOGM4IC43IDE1LjMuNyAxNS4zLjctNC44LTEt'
    b'My43LTE1LjgtMy42LTE1Ljl6Ii8+CiAgPC9nPgogIDxnIGZvbnQtZmFtaWx5PSJUcmVidWNo'
    b'ZXQgTVMiIGZvbnQtc2l6ZT0iOSIgZm9udC13ZWlnaHQ9ImJvbGQiPgogICAgPHBhdGggZD0i'
    b'TTI4My40IDM0MC4ydi0xMC43aDEuOHY5aDV2MS43eiIgYXJpYS1sYWJlbD0iTCIvPgogICAg'
    b'PHBhdGggZD0iTTI5MS43IDM0MC43VjMzMGgxLjl2MTAuN3oiIGFyaWEtbGFiZWw9IkkiLz4K'
    b'ICAgIDxwYXRoIGQ9Ik0zMDAgMzQxLjVoLTMuM1YzMzFsMy4yLS4ycTEuNyAwIDIuNS43IDEg'
    b'LjggMSAyLjEgMCAxLjItMS4zIDIgMiAuNyAyIDIuOSAwIDEuNS0xLjIgMi4zLTEgLjgtMi44'
    b'Ljh6bS0xLjMtOS4xdjIuNWgxcTEuNyAwIDEuNy0xLjQgMC0xLjEtMS43LTEuMWgtMXptMCA0'
    b'djMuNWgxcTEuMiAwIDEuNy0uNC43LS4zLjctMS4zdC0uNS0xLjNxLS41LS41LTEuOS0uNWgt'
    b'MXoiIGFyaWEtbGFiZWw9IkIiLz4KICAgIDxwYXRoIGQ9Ik0zMDguNiAzMzN2Mi43aDMuNHYx'
    b'LjdoLTMuNHYzLjFoNXYxLjdoLTYuOXYtMTAuN2g2Ljd2MS43eiIgYXJpYS1sYWJlbD0iRSIv'
    b'PgogICAgPHBhdGggZD0ibTMyMi4yIDM0Mi40LTIuOC00LjVIMzE4djQuNWgtMS44di0xMC43'
    b'aDEuMmwxLjYtLjJxNC4yIDAgNC4yIDMuMiAwIDEtLjUgMS43LS43LjgtMS41IDEuMWwzLjMg'
    b'NC45em0tNC4yLTl2Mi44aC45bDEuNi0uMnEuNy0uMy43LTEuMyAwLS44LS41LTEuMi0uNy0u'
    b'My0yLS4zaC0uN3oiIGFyaWEtbGFiZWw9IlIiLz4KICAgIDxwYXRoIGQ9Ik0zMjkuOSAzMzN2'
    b'OWgtMnYtOWgtMy40di0xLjZoOC45djEuNnoiIGFyaWEtbGFiZWw9IlQiLz4KICAgIDxwYXRo'
    b'IGQ9Im0zNDAuNyAzNDAuNS0uOC0yLjFoLTMuN2wtLjcgMi4xaC0yLjFsNC4zLTEwLjhoLjhs'
    b'NC40IDEwLjh6TTMzOCAzMzNsLTEuMSA0aDIuNXoiIGFyaWEtbGFiZWw9IkEiLz4KICAgIDxw'
    b'YXRoIGQ9Im0zNDQuNCAzMzkuNy42LTEuN3ExLjIuNyAyLjIuNyAxLjcgMCAxLjctMS4ybC0u'
    b'NC0xLTEuNi0xLjEtMS43LTEtLjctMS0uMS0xLjJxMC0xLjMuOC0yLjIgMS0uNiAyLjMtLjYg'
    b'MS45IDAgMi45LjZsLS43IDEuN3EtMS0uOC0yLjItLjgtLjYgMC0xIC4zLS4zLjMtLjMgMSAw'
    b'IC44IDIgMS44IDEuMi41IDEuNyAxbC42IDEgLjIgMS40cTAgMS4zLTEgMi4xdC0yLjcuOXEt'
    b'MS42IDAtMi42LS45eiIgYXJpYS1sYWJlbD0iUyIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMGE0MDAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdp'
    b'ZHRoPSIyLjIiIGQ9Ik0yMzEuMyAzMTguNmMxMC4xIDEuMiAyNC4xLjMgMzAuMiAwTTIxNiAy'
    b'ODQuMmM4LjYgNi43IDI3LjEgMTAuNyAyNi44IDEwLjdtMTAuNyAxLjhjLTIuOC0xNC01Ljgt'
    b'MTcuNC04LjMtMjYuMm0tNDMuNS0xNS44YzE0LjMgNi40IDE2LjUgMTAuNiAyNS42IDE3bTUu'
    b'Mi0xNGMxLjItMTcuMyAzLjYtMjEuOSA3LjktMjUuOW0tMzguNy0yYzUuMiA1LjcgMjIuMiAy'
    b'My43IDIyLjIgMjMuN20tNy0zOS42YzYuNCA0LjUgNi40IDIxIDYuNCAyMSIvPgo8L3N2Zz4K', 'SM')

SM = b64_SM
index.append("SM")
index.append("SMR")
index.append("San Marino")
catalog["SM"] = SM
catalog["SMR"] = SM
catalog["San Marino"] = SM
country["San Marino"] = ('SM', 'SMR', 0)
lookup["SM"] = ('SM', 'SMR', 'San Marino', 0)
lookup["San Marino San Marino"] = ('SM', 'SMR', 'San Marino', 0)
lookup["SMR"] = ('SM', 'SMR', 'San Marino', 0)
lookup["San Marino"] = ('SM', 'SMR', 'San Marino', 0)
details["SM"] = {"continent":"Europe","capital":"San Marino","currency":"Euro","web":".sm","lang":"it_SM","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_SN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNuIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjMGI3MjI2IiBkPSJNMCAwaDIx'
    b'My4zdjQ4MEgweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmMCIgZD0iTTIxMy4zIDBoMjEzLjN2'
    b'NDgwSDIxMy4zeiIvPgogICAgPHBhdGggZmlsbD0iI2JjMDAwMCIgZD0iTTQyNi42IDBINjQw'
    b'djQ4MEg0MjYuNnoiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iIzBiNzIyNiIgZD0iTTM0MiAy'
    b'MTguOGg3MS44bC01Ni42IDQzLjYgMjAuNyA2OS4zLTU2LjYtNDMuNi01Ni42IDQxLjYgMjAu'
    b'Ny02Ny4zLTU2LjYtNDMuNmg2OS44bDIyLjctNzEuM3oiLz4KPC9zdmc+Cg==', 'SN')

SN = b64_SN
index.append("SN")
index.append("SEN")
index.append("Senegal")
catalog["SN"] = SN
catalog["SEN"] = SN
catalog["Senegal"] = SN
country["Senegal"] = ('SN', 'SEN', 0)
lookup["SN"] = ('SN', 'SEN', 'Senegal', 0)
lookup["Dakar Senegal"] = ('SN', 'SEN', 'Senegal', 0)
lookup["SEN"] = ('SN', 'SEN', 'Senegal', 0)
lookup["Senegal"] = ('SN', 'SEN', 'Senegal', 0)
details["SN"] = {"continent":"Africa","capital":"Dakar","currency":"CFA Franc BCEAO","web":".sn","lang":"fr-SN | wo | fuc | mnk","tz":"±0:00","altname":""}
#----------------------------------------------------------------------
b64_SO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InNvLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1LjMgMGg2ODIu'
    b'NnY1MTJILTg1LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCNzby1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoODApIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjNDBhNmZmIiBkPSJNLTEy'
    b'OCAwaDc2OHY1MTJoLTc2OHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMzYuNSAz'
    b'ODEuMiAyNTQgMzI3LjdsLTgyLjEgNTQgMzAuNS04Ny43LTgyLTU0LjJMMjIyIDIzOWwzMS40'
    b'LTg3LjUgMzIuMSA4Ny4zIDEwMS40LjEtODEuNSA1NC43IDMxLjIgODcuNnoiLz4KICA8L2c+'
    b'Cjwvc3ZnPgo=', 'SO')

SO = b64_SO
index.append("SO")
index.append("SOM")
index.append("Somalia")
catalog["SO"] = SO
catalog["SOM"] = SO
catalog["Somalia"] = SO
country["Somalia"] = ('SO', 'SOM', 0)
lookup["SO"] = ('SO', 'SOM', 'Somalia', 0)
lookup["Mogadishu Somalia"] = ('SO', 'SOM', 'Somalia', 0)
lookup["SOM"] = ('SO', 'SOM', 'Somalia', 0)
lookup["Somalia"] = ('SO', 'SOM', 'Somalia', 0)
details["SO"] = {"continent":"Africa","capital":"Mogadishu","currency":"Somali Shilling","web":".so","lang":"so-SO | ar-SO | it | en-SO","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_SR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzM3N2UzZiIgZD0i'
    b'TS4xIDBoNjQwdjQ4MEguMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNLjEgOTZoNjQw'
    b'djI4OEguMXoiLz4KICA8cGF0aCBmaWxsPSIjYjQwYTJkIiBkPSJNLjEgMTQ0aDY0MHYxOTJI'
    b'LjF6Ii8+CiAgPHBhdGggZmlsbD0iI2VjYzgxZCIgZD0ibTMyMCAxNTMuMiA1Ni40IDE3My42'
    b'LTE0Ny43LTEwNy4zaDE4Mi42TDI2My42IDMyNi44eiIvPgo8L3N2Zz4K', 'SR')

SR = b64_SR
index.append("SR")
index.append("SUR")
index.append("Suriname")
catalog["SR"] = SR
catalog["SUR"] = SR
catalog["Suriname"] = SR
country["Suriname"] = ('SR', 'SUR', 0)
lookup["SR"] = ('SR', 'SUR', 'Suriname', 0)
lookup["Paramaribo Suriname"] = ('SR', 'SUR', 'Suriname', 0)
lookup["SUR"] = ('SR', 'SUR', 'Suriname', 0)
lookup["Suriname"] = ('SR', 'SUR', 'Suriname', 0)
details["SR"] = {"continent":"Americas","capital":"Paramaribo","currency":"Surinam Dollar","web":".sr","lang":"nl-SR | en | srn | hns","tz":"-03:00","altname":""}
#----------------------------------------------------------------------
b64_SS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXNzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzA3ODkzMCIgZD0i'
    b'TTAgMzM2aDY0MHYxNDRIMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAxNDRoNjQw'
    b'djE5MkgweiIvPgogIDxwYXRoIGQ9Ik0wIDBoNjQwdjE0NEgweiIvPgogIDxwYXRoIGZpbGw9'
    b'IiNkYTEyMWEiIGQ9Ik0wIDE2OGg2NDB2MTQ0SDB6Ii8+CiAgPHBhdGggZmlsbD0iIzBmNDdh'
    b'ZiIgZD0ibTAgMCA0MTUuNyAyNDBMMCA0ODB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZjZGQwOSIg'
    b'ZD0iTTIwMC43IDE5NC44IDYxLjcgMjQwbDEzOSA0NS4xTDExNC45IDE2N3YxNDZ6Ii8+Cjwv'
    b'c3ZnPgo=', 'SS')

SS = b64_SS
index.append("SS")
index.append("SSD")
index.append("South Sudan")
catalog["SS"] = SS
catalog["SSD"] = SS
catalog["South Sudan"] = SS
country["South Sudan"] = ('SS', 'SSD', 0)
lookup["SS"] = ('SS', 'SSD', 'South Sudan', 0)
lookup["Juba South Sudan"] = ('SS', 'SSD', 'South Sudan', 0)
lookup["SSD"] = ('SS', 'SSD', 'South Sudan', 0)
lookup["South Sudan"] = ('SS', 'SSD', 'South Sudan', 0)
details["SS"] = {"continent":"Africa","capital":"Juba","currency":"South Sudanese Pound","web":"","lang":"en","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_ST = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1zdCIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMxMmFkMmIiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmNlMDAiIGQ9Ik0wIDEzNy4xaDY0MFYzNDNIMHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZDIxMDM0IiBkPSJNMCAwdjQ4MGwyNDAtMjQwIi8+CiAgPGcg'
    b'aWQ9InN0LWMiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDM1MS42IDI0MCkgc2NhbGUoLjM0Mjg2'
    b'KSI+CiAgICA8ZyBpZD0ic3QtYiI+CiAgICAgIDxwYXRoIGlkPSJzdC1hIiBkPSJNMC0yMDBW'
    b'MGgxMDAiIHRyYW5zZm9ybT0icm90YXRlKDE4IDAgLTIwMCkiLz4KICAgICAgPHVzZSB4bGlu'
    b'azpocmVmPSIjc3QtYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJz'
    b'Y2FsZSgtMSAxKSIvPgogICAgPC9nPgogICAgPHVzZSB4bGluazpocmVmPSIjc3QtYiIgd2lk'
    b'dGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoNzIpIi8+CiAgICA8'
    b'dXNlIHhsaW5rOmhyZWY9IiNzdC1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFu'
    b'c2Zvcm09InJvdGF0ZSgxNDQpIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNzdC1iIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InJvdGF0ZSgtMTQ0KSIvPgogICAg'
    b'PHVzZSB4bGluazpocmVmPSIjc3QtYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJh'
    b'bnNmb3JtPSJyb3RhdGUoLTcyKSIvPgogIDwvZz4KICA8dXNlIHhsaW5rOmhyZWY9IiNzdC1j'
    b'IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI3MDAiIHRyYW5zZm9ybT0idHJhbnNs'
    b'YXRlKC01MjMuMikiLz4KPC9zdmc+Cg==', 'ST')

ST = b64_ST
index.append("ST")
index.append("STP")
index.append("Sao Tome and Principe")
catalog["ST"] = ST
catalog["STP"] = ST
catalog["Sao Tome and Principe"] = ST
country["Sao Tome and Principe"] = ('ST', 'STP', 0)
lookup["ST"] = ('ST', 'STP', 'Sao Tome and Principe', 0)
lookup["Sao Tome Sao Tome and Principe"] = ('ST', 'STP', 'Sao Tome and Principe', 0)
lookup["STP"] = ('ST', 'STP', 'Sao Tome and Principe', 0)
lookup["Sao Tome and Principe"] = ('ST', 'STP', 'Sao Tome and Principe', 0)
details["ST"] = {"continent":"Africa","capital":"Sao Tome","currency":"Dobra","web":".st","lang":"pt-ST","tz":"±0:00","altname":""}
#----------------------------------------------------------------------
b64_SV = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1zdiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwZjQ3YWYiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDE2MGg2NDB2MTYwSDB6Ii8+CiAg'
    b'PGcgdHJhbnNmb3JtPSJtYXRyaXgoLjggMCAwIC44IC05Mi43IDApIj4KICAgIDxnIGZpbGw9'
    b'IiNmZmYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9'
    b'Ii4zIj4KICAgICAgPHBhdGggZD0iTTUxNSAzNTMuNGMxLjUgMCAzLjIgMCAxMC4xLTEuNyA3'
    b'LTEuNyAxMi43LTUuOSAxNC02LjUgMS40LS42IDMuMy0uNCAzLjMtLjRhOC40IDguNCAwIDAg'
    b'MC01LjgtMi44Yy0zIDAtMS45IDAtNC40IDEuMS0yLjYgMS04IDQuMy0xNyA0LjNoLS4xYy05'
    b'IDAtMTQuNy0zLjItMTcuMi00LjMtMi42LTEtMS40LTEtNC40LTEtMyAwLTUuMSAxLjktNiAy'
    b'LjcgMCAwIDItLjIgMy40LjQgMS40LjYgNy4xIDQuOCAxNCA2LjUgNyAxLjcgOC42IDEuNyAx'
    b'MC4xIDEuN3oiLz4KICAgICAgPHBhdGggZD0iTTQ4OC40IDM0Ny40Yy43LS40LS4yLTEuNi0u'
    b'Mi0xLjZsMi43LS42Yy0xLjMtLjYtMy4zLS40LTMuMy0uNC0uNS40LS40LjktLjUgMS4zIDAg'
    b'LjQgMCAxIC4yIDEuMy4zLjMgMSAwIDEgMHoiLz4KICAgICAgPHBhdGggZD0ibTQ5MSAzNDUu'
    b'Mi0yLjguNnMuOSAxLjIuMiAxLjdsNC44LTEtMi4zLTEuM3ptNTAuNyAyLjJjLS43LS40LjEt'
    b'MS42LjEtMS42bC0yLjctLjZjMS40LS42IDMuMy0uNCAzLjMtLjQuNi40LjUuOS42IDEuMyAw'
    b'IC40IDAgMS0uMyAxLjMtLjMuMy0xIDAtMSAweiIvPgogICAgICA8cGF0aCBkPSJtNTM5LjEg'
    b'MzQ1LjIgMi43LjZzLS44IDEuMi0uMSAxLjdsLTQuOC0xIDIuMi0xLjN6Ii8+CiAgICA8L2c+'
    b'CiAgICA8cGF0aCBkPSJtNDk1LjggMzQzLjMtMS4yIDMgLjYuM2MuOS4zIDEuOC4xIDIuMi0u'
    b'OS40LTEtLjEtMS44LTEtMi4xbC0uNi0uM3ptLjMuNmMuOC40IDEuMi45LjkgMS43LS4zLjgt'
    b'MSAuOC0xLjcuNWgtLjFsLjktMi4yeiIvPgogICAgPHBhdGggZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiBkPSJtNDk3LjYgMzQ3LjYtLjQtLjEgMS40LTMgLjMuMS0xLjMgM3oiLz4KICAgIDxwYXRo'
    b'IGQ9Ik01MDAuMiAzNDUuM2MtLjYgMC0xLjIuNC0xLjUgMS0uNCAxIDAgMS45LjggMi4zLjgu'
    b'MyAxLjggMCAyLjItMWExLjcgMS43IDAgMCAwLS45LTIuMiAxLjUgMS41IDAgMCAwLS42LS4x'
    b'em0wIC41aC41Yy42LjMuOCAxIC41IDEuNi0uMi42LTEgMS0xLjUuNy0uNS0uMy0uOC0xLS41'
    b'LTEuNi4yLS40LjUtLjcgMS0uN3oiLz4KICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'ZD0iTTUwMy44IDM0Ny40YzAtLjMtLjEtLjQtLjMtLjUtLjMtLjEtLjYgMC0uNy4ybC4yLjYu'
    b'My4yYy4zLjMuNS43LjMgMS4yYTEgMSAwIDAgMS0xLjMuNiAxIDEgMCAwIDEtLjYtMS4yaC40'
    b'Yy0uMS40IDAgLjcuNC45LjMgMCAuNi0uMS43LS40LjItLjQgMC0uNi0uMi0uOGwtLjItLjJj'
    b'LS4zLS4yLS41LS41LS4zLTEgLjEtLjUuNy0uNiAxLS41LjQuMi42LjQuNy44aC0uNHptMi40'
    b'LjEtLjUgMS45Yy0uMS41LS4xIDEgLjQgMS4yLjYuMS45LS4zIDEtLjhsLjYtMS45LjMuMi0u'
    b'NSAxLjljLS4yLjctLjggMS4xLTEuNSAxLS43LS4zLTEtMS0uNy0xLjZsLjYtMiAuMy4xem00'
    b'LjQgNC41LTEuOC0zLS41IDIuNGgtLjRsLjctMy40IDEuOCAzIC40LTIuNGguNHptLjggMCAu'
    b'NC0zLjJoLjNsLS40IDMuMnoiLz4KICAgIDxwYXRoIGQ9Ik01MTQuMiAzNDguOWExLjYgMS42'
    b'IDAgMCAwLTEuNyAxLjZjMCAxIC43IDEuNyAxLjYgMS44LjggMCAxLjYtLjcgMS42LTEuNyAw'
    b'LS45LS43LTEuNy0xLjUtMS43em0wIC41Yy42IDAgMSAuNiAxIDEuMmExLjEgMS4xIDAgMCAx'
    b'LTEuMSAxLjJjLS42IDAtMS4xLS42LTEuMS0xLjMgMC0uNi41LTEuMiAxLjEtMS4yeiIvPgog'
    b'ICAgPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtNTE5IDM1Mi4xLTIuNC0yLjMuMSAy'
    b'LjRoLS40bC0uMi0zLjQgMi41IDIuNC0uMi0yLjRoLjR6bTIuMS0uNS0uNi0zLjJoLjRsLjYg'
    b'Mi44LjktLjJ2LjR6bTEuOC0uMy0uOC0zLjJoLjRsLjcgMy4xeiIvPgogICAgPHBhdGggZD0i'
    b'TTUyMy45IDM0Ny43aC0uNGwtLjQuMi45IDMuMS43LS4xYy41LS4yIDEtLjYuOC0xLjItLjEt'
    b'LjQtLjQtLjctLjgtLjZsLjEtLjhjLS4yLS41LS41LS42LTEtLjZ6bTAgLjRjLjIgMCAuNCAw'
    b'IC41LjQuMi40LS4xLjUtLjQuNmgtLjFsLS4zLTFoLjFhMSAxIDAgMCAxIC4yIDB6bS41IDEu'
    b'M2MuMyAwIC42IDAgLjYuNC4yLjQtLjEuNS0uNC42bC0uMy4xLS4zLTFoLjR6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Im01MjcuMiAzNDggLjIuMy0xLjIuNC40IDEu'
    b'MiAxLjItLjUuMS40LTEuNS42LTEuMS0zLjEgMS42LS42di4zbC0xLjEuNS4zLjh6Ii8+CiAg'
    b'ICA8cGF0aCBkPSJNNTI4LjYgMzQ2LjJjLS4zIDAtLjUgMC0uOC4ybC0uNC4xIDEuMiAzaC4z'
    b'bC0uNC0xLjQgMS40LjkuNS0uMS0xLjUtMWMuNC0uMi42LS43LjQtMS4xYS45LjkgMCAwIDAt'
    b'LjctLjZ6bTAgLjQuMy4zYy4yLjUtLjIuNy0uNS44bC0uNS0xaC4xbC41LS4xeiIvPgogICAg'
    b'PHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtNTI5LjIgMzQ1LjggMS43LS44LjIuMy0u'
    b'Ny4zIDEuMiAyLjctLjMuMS0xLjItMi42LS43LjN6Ii8+CiAgICA8cGF0aCBkPSJtNTMyLjIg'
    b'MzQ0LjIuMiAzLjcuNC0uMnYtLjhsMS4zLS43LjYuNi40LS4zLTIuOS0yLjN6bS40LjkgMSAu'
    b'OC0uOC41LS4xLTEuM3ptMi43LTIuMi0xIC4zLS41LjMgMS43IDIuOC41LS4zYy45LS41IDEu'
    b'My0xLjQuNy0yLjMtLjQtLjYtLjktLjgtMS40LS44em0uMi41Yy4zIDAgLjYuMi44LjUuNC44'
    b'IDAgMS4zLS42IDEuN2wtMS4zLTEuOWguMWwxLS4zeiIvPgogICAgPGcgaWQ9InN2LWEiIHN0'
    b'cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiI+CiAgICAgIDxwYXRoIGZpbGw9'
    b'IiNlNjAwMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLXdpZHRoPSIuMSIgZD0iTTQ4'
    b'NSAzNTUuMmMuNiAwIDEtLjQgMS0xYS45LjkgMCAwIDAtMS0uOGMtLjQgMC0uOC40LS44Ljlz'
    b'LjQuOS45Ljl6bS01IDYuM2MuNSAwIC45LS40LjktMWExIDEgMCAwIDAtMS0uOCAxIDEgMCAw'
    b'IDAtLjkuOWMwIC41LjUuOSAxIC45em0tMTItMTkuOWMuNSAwIDEtLjQgMS0uOWExIDEgMCAw'
    b'IDAtMS0uOS45LjkgMCAwIDAtLjggMWMwIC40LjMuOC45Ljh6bS03LjMgMy43Yy41IDAgMS0u'
    b'NCAxLTEgMC0uNS0uNS0xLTEtMWExIDEgMCAwIDAtMSAxYzAgLjYuNCAxIDEgMXptLTEuNC0y'
    b'Mi4zYTEgMSAwIDAgMCAxLTFjMC0uNS0uNC0xLTEtMWExIDEgMCAwIDAtMSAxIDEgMSAwIDAg'
    b'MCAxIDF6bS02LjIgMS44YTEgMSAwIDAgMCAxLTEgMSAxIDAgMCAwLTEtMSAxIDEgMCAwIDAt'
    b'MSAxIDEgMSAwIDAgMCAxIDF6bTMuMi0xOS44YTEgMSAwIDAgMCAxLTEgMSAxIDAgMCAwLTEt'
    b'MSAxIDEgMCAwIDAtMSAxYzAgLjUuNCAxIDEgMXptLTUuNS0xOC4zYy41IDAgMS0uNCAxLTFh'
    b'MSAxIDAgMCAwLTEtMSAxIDEgMCAwIDAtMSAxYzAgLjYuNCAxIDEgMXptNyAxLjhhMSAxIDAg'
    b'MCAwIDEtMWMwLS41LS40LTEtMS0xYTEgMSAwIDAgMC0xIDEgMSAxIDAgMCAwIDEgMXptNy0x'
    b'NS4yYy41IDAgMS0uNCAxLTEgMC0uNS0uNS0xLTEtMWExIDEgMCAxIDAgMCAyem0tNS4zLTQu'
    b'MmExIDEgMCAwIDAgMS0xIDEgMSAwIDAgMC0xLTEgMSAxIDAgMCAwLTEgMSAxIDEgMCAwIDAg'
    b'MSAxem0xMC41LTEwLjNhMSAxIDAgMCAwIDEtMSAxIDEgMCAwIDAtMS0xIDEgMSAwIDAgMC0x'
    b'IDEgMSAxIDAgMCAwIDEgMXptLTIxLjUgNDYuM2MuNiAwIDEtLjQgMS0xcy0uNC0xLTEtMWEx'
    b'IDEgMCAwIDAtMSAxYzAgLjYuNSAxIDEgMXoiLz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTQ4NiAzNTguOXMtLjgtMy4yLS43LTMuOWwuOC0uNm0t'
    b'MS40IDUuN3MtMi44LjEtMy43LjRsLS4zLjhtLTEzLjQtMTUuNXMtLjItMy44LjYtNGMwIDAg'
    b'LjctLjQgMS4yLTFtLTQuNyAzLjhzLTIuMS0uMy0yLjcgMGMwIDAtLjIuNi0uNi44bS0uOC0y'
    b'My0uNy41Yy0uOC4zLTIuMyA0LTIuMyA0cy0yLjQtMS45LTMuNC0yaC0xLjFtLTQuOC0yMC4y'
    b'cy42LjYgMS4yLjNjMCAwIDMgMiAzLjEgMi43IDAgMCAzLjItMy4yIDMuOC0yLjkgMCAwIC4z'
    b'LjUgMS0uMW0tNS44LTE4LjZzLjMuNS45LjhjMCAwIDEuNCAyIDEuNCAzLjUgMCAwIDIuNS0y'
    b'LjMgMy4zLTIuMSAwIDAgLjkuMyAxLjUgMG0uMy0xOS41cy42LjggMSAuMmMwIDAgMS44IDIu'
    b'Mi44IDQgMCAwIDIuNS0uNyAzLjMtLjMgMCAwIC4zIDEgMS4yLjUiLz4KICAgICAgPGcgZmls'
    b'bD0iIzFmNjAxYSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9Ii4zIj4KICAg'
    b'ICAgICA8cGF0aCBkPSJtNTMyLjggMzc4LjMtNC41LS4zYy0uNiAwLTItMi43LTIuNi0zLjEt'
    b'LjYtLjUtMTAuOC01LjUtMTcuNS02LjVhOTUgOTUgMCAwIDEtMTktNiA4OCA4OCAwIDAgMS0y'
    b'Ni0xOS4yYy0yLjktNC4yLTYtMTQtNy4yLTE5LjItLjctMi41LTQtMTIuNC00LTE5LjJhODQg'
    b'ODQgMCAwIDEgMi4yLTE5LjQgMTExIDExMSAwIDAgMSAxNS4zLTI2LjhzLTEyIDE4LjctMTQu'
    b'MiAyNS45YTgxIDgxIDAgMCAwLTIuNSAyMS41Yy4xIDQuMiAzLjYgMTkuNiA4LjcgMzAuOSA0'
    b'LjEgOSA3LjcgMTAuMiAxNCAxNS4yIDMgMi40IDguOCA2LjIgMTMuNiA4LjYgNC44IDIuNCAx'
    b'NSA1LjUgMTcuOCA1LjkgMi43LjUgMTYuNCA0LjUgMTguMiA1LjQgMS44IDEgNi41IDUgNy43'
    b'IDYuM3oiLz4KICAgICAgICA8cGF0aCBkPSJNNDY0LjEgMzQzLjRjLjMtMS40LjQtMi40IDEt'
    b'Mi44YTE0IDE0IDAgMCAwIDIuMi0zLjVjLjMtMS4yIDAtMi4yIDAtMi44bC40LTIuN3MtLjct'
    b'Mi41LTEuMy0zYy0uNi0uNC0yLjItMi42LTIuNS0zLjIgMCAwIC4yIDEuMy0uMyAxLjlhNyA3'
    b'IDAgMCAwLS42IDNjMCAuOS4zIDMgMCA0LS4zIDEuMi0uNyAyLjItLjQgMy41bDEuNSA1LjZ6'
    b'bS0uNS0xLjVzLTMuNC00LjQtMy40LTYuMmMwLTEuOC0uMy0yLjktLjYtMy4zLS4zLS40LTIu'
    b'My0yLjctLjUtNS42LjgtMS4yIDEtMSAxLjQtMi40LjYtMS42IDEuOC0xLjYgMi0zLjMgMCAw'
    b'IC40IDIgLjUgMy42LjIgMS43LS4xIDIuMy0uMiAzLjItLjIuOS40IDIgLjQgMy4zIDAgMS40'
    b'LS4yIDEuOS0uMiAyLjcgMCAuNC0uNSA2LjIuNiA4em0zOC42IDIzLjUtNC0uNWMtLjcgMC0y'
    b'LjUtLjUtMy41LS45YTEwIDEwIDAgMCAxLTQtMi44Yy0yLjgtMy0yLjUtNC41LTMtNC42LTEt'
    b'LjIgMS41LS40IDIuOC0uMyAxLjEuMiAyLjggMSAzLjggMiAxLjIgMS4xIDMgMi4zIDMuNSAy'
    b'LjcuNi41IDEgLjcgMS43IDEuNS43IDEgLjYgMS41IDIuNyAzeiIvPgogICAgICAgIDxwYXRo'
    b'IGQ9Ik01MDYuMiAzNjcuNXMtNy4yLTMuMi04LTMuOGEyNSAyNSAwIDAgMS0yLjgtMi42Yy0u'
    b'Ny0uOC0zLjgtMi40LTQuMy0zLjQtLjMtLjctMi4zLTMuMy0zLjQtNS40LS41LTEgNC45LjMg'
    b'NC45LjMgNC40IDEuOCAyLjQuNiA0LjggMi40IDEuNSAxLjEgMi41IDIgMi45IDIuOS42IDEu'
    b'MyAxLjIgMy41IDEuOSA0LjcuNiAxLjIgMS43IDIuNyA0IDV6Ii8+CiAgICAgICAgPHBhdGgg'
    b'ZD0iTTUxMC4yIDM2OC40cy02LTEuNS04LjgtNS4yYy0yLTIuNi0yLTEuOC0yLjctMi43LTEt'
    b'MS0yLjYtMi4zLTQtNC41LjIuMy0xLjYtNS45LTEuNi02LjYgMC0uNCAyLjMuMyA0LjIgMSAx'
    b'LjUuNyAyLjQgMiAzLjggMi44IDEuNiAxIDEuOCAzLjcgMi41IDQuOSAxIDEuOCAxLjIgMi43'
    b'IDEuMiAzLjUgMCAxLjQuOCAxLjggMS4yIDMgLjUgMS4zIDIuMSAxIDQuMiAzLjh6bS05LjYt'
    b'Mi01LjktMi40Yy0uOC0uMS0xLS42LTIuMS0uOS0uOS0uMi0xLjctLjktMy44LS40LS45LjIt'
    b'NC42IDEtNS41LjYtMS0uNSAxLjMgMi41IDIuMyAzLjEgMS4xLjcgMi45IDEgNC40LjhoNC40'
    b'Yy43IDAgMS4yLjIgMi4zLS4xIDEtLjMgMS4zLS44IDMuOS0uN3oiLz4KICAgICAgICA8cGF0'
    b'aCBkPSJNNTA0IDM2Ni40cy01LjctMS40LTYuNy0xLjRsLTQuOC40Yy0xIC4yLTQuNS0uMi01'
    b'LjUuNC0xIC40LTUuNiAxLTYuOC44LTEuMi0uMyAyLjQgMy4yIDMuOSAzLjYgNC42IDEuMyAz'
    b'LjIgMS4xIDYuMi40IDEuOC0uNSA0LjQtLjYgNS40LS44LjktLjEuNy0uNyAyLTEuMiAxLjEt'
    b'LjUgMy4yLTEuOCA2LjMtMi4yeiIvPgogICAgICAgIDxwYXRoIGQ9Ik01MDguNyAzNjguOHMt'
    b'NS43LTIuNC0xMC4yLTEuMWwtNC4yIDFjLTEuNC4xLTIuNi0uNi01IC40LTEuMi40LTYuMiAy'
    b'LjUtNy41IDIuNC0xLjMtLjEgNCAzLjMgNS40IDMuMSA0LjYtLjYgOSAxIDExIDBsNC0xLjVj'
    b'MS0uNCAxLjUtMS4yIDIuMS0xLjcuNi0uNCAxLTEuNiA0LjQtMi42em0tMzAuNi0xMy4xcy0z'
    b'LjMtMy42LTQtNC4xbC0zLTIuNGMtLjYtLjYtMS4zLTItMy40LTIuNS0xLS4yLTMuMS0uNi0z'
    b'LjgtMS40LS42LS44LjEgMyAuOCA0YTguMSA4LjEgMCAwIDAgMy42IDIuNWMxLjUuNSAzLjMg'
    b'MS41IDQgMS45LjYuMyAxIC42IDIgLjggMS4xLjIgMS42IDAgMy44IDEuMnoiLz4KICAgICAg'
    b'ICA8cGF0aCBkPSJNNDgxLjMgMzU3LjJzLTUuNy00LTYuNS00LjRsLTMuNS0xLjNjLTEuMS0u'
    b'My00LTIuMy01LTIuMy0xLjIgMC0zLjMtLjEtNC4zLS44LTEtLjgtLjEgMi43IDEgMy43IDMu'
    b'NiAzLjIgMS4xIDIuMiA0LjEgMi44bDUuMSAxLjdjMSAuMyAxLS4zIDIuMy0uMiAxLjMgMCAz'
    b'LjgtLjIgNi44Ljh6Ii8+CiAgICAgICAgPHBhdGggZD0iTTQ4Mi42IDM1OC4zcy0yLjMtMS42'
    b'LTYuOS0yLjRjLTMtLjUtMy0uNi00LjEtMS0xLjQtLjQtMS43LS40LTQuMy0uNS0xLjItLjEt'
    b'Ni4yIDEuNS03LjQuOC0xLS42IDEuMyAxLjUgMi42IDIgMiAuOCAxLjggMiA0IDIuOCAyLjIu'
    b'NyA0LjcgMS42IDYgMS40IDEtLjIgMS44LS43IDMuMy0uOCAxLjQtLjIgNC0yLjMgNi44LTIu'
    b'NHptLjUtMS4yczEuMS01LjUuMS02LjhhNS4yIDUuMiAwIDAgMS0xLjItMi45IDExIDExIDAg'
    b'MCAwLTEuNi00LjNjLS42LS44LTEuOC00LjItMS41LTUuMSAwIDAtMy4yIDMuMS0zIDUuMXYy'
    b'LjRjLS4yLjkuNyAzLjkgMS4zIDQuOC42IDEgLjMgMy42IDEgNC4yLjUuNiA0LjEgMyA0Ljkg'
    b'Mi42eiIvPgogICAgICAgIDxwYXRoIGQ9Ik00ODIuNiAzNTguM2MuMy4xLTItMS44LTMtMi4z'
    b'LTEtLjQtNS4zLTEuNi01LjYtMi43LS4zLTEtMy43LTQuNi0zLjktNS42IDAtLjYtLjctMi0u'
    b'Ni0yLjguMi0uNy41LTIuNiAxLTMuNi40LTEuMSAxLjQtMy42IDIuNS00bDEuMiAzLjhjLjMg'
    b'MSAuNiAyLjMgMSAyLjkuNS42IDIgMy40IDIuMSA0LjVsMS4xIDUuM2MuMS43IDMgMy44IDQu'
    b'MiA0LjR6TTQ2NCAzNDMuNGMuMS44LTIuMy0uOC0zLjUtLjgtMS4yIDAtNC44LjUtNS43LS40'
    b'LS45LTEtMi4yLTIuNi0yLjctMi45LS41LS4zLTIuMS0zLTIuNi00LjUtLjQtMS41LTMuNi00'
    b'LjItNC00LjUgMCAwIDQuMy0uOSA3IC45czMgMS40IDMuNSAxLjZjLjYuMyA1LjMgNC4zIDUu'
    b'NiA1LjguMyAxLjUgMi4yIDQgMi40IDQuOHoiLz4KICAgICAgICA8cGF0aCBkPSJNNDY0LjEg'
    b'MzQzLjRzLTMuOS0yLjctNC44LTIuNmMtMSAuMi01LjItMy01LjQtNS0uMi0xLTIuMi0yLjUt'
    b'Mi42LTMuMS0xLTEuOC0xLjctNS45LTMuMi03bDUuMiAxLjNjMiAuMyAzLjYuNiA0LjMgMi4y'
    b'LjggMS43IDEuNCAzIDIgMy4yLjYuMiAxLjUgMi4zIDEuOCA0LjRhMzIgMzIgMCAwIDAgMi43'
    b'IDYuNnptLTcuNC0yMC41Yy43IDEgLjYtNiAuOS02LjhhMTEuMyAxMS4zIDAgMCAxIDEuNy0y'
    b'LjhjLjYtLjYuNi0yLjcuOS0zLjMuMy0uNi4xLTQuNy0uMy01LjhMNDU4IDMwNmMtLjYuNy0x'
    b'LjcgMS0yIDItLjMuOC0uOS44LTEuMyAxLjhhNS42IDUuNiAwIDAgMC0uNiAzLjZjLjMgMS4y'
    b'LjEgMS42LjEgMi43IDAgMSAxLjUgNS42IDIuNCA2Ljl6Ii8+CiAgICAgICAgPHBhdGggZD0i'
    b'TTQ1Ni45IDMyMy41cy0uMy0yIC40LTIuN2MuOC0uOCAxLjUtLjggMS44LTEuMi4zLS41LjIt'
    b'MSAuNS0xLjcuMy0uNiAxLTEuNiAxLTIgLjMtMS43IDEuMy0zLjYuNS01LjMgMCAwLTEuNy41'
    b'LTIuMS44LS41LjMtMS44IDEuNi0yIDIuOC0uMSAxLjMtLjMgMS41LS43IDIuMi0uNS44LTEg'
    b'My0uMyA0LjRhNy40IDcuNCAwIDAgMSAuOSAyLjd6bS00LjQtMjNzLS4zLTQuNC45LTUuOGMx'
    b'LjItMS4zIDEuNS0zLjkgNC4yLTUuM3YxLjljLjIuNy41IDIuOCAwIDMuNi0uNC43LTIgMi0y'
    b'IDIuNyAwIC42LTEgMi4xLTEuNyAyLjRsLTEuNC41eiIvPgogICAgICAgIDxwYXRoIGQ9Ik00'
    b'NTIuNSAzMDIuOHMwLTMgLjktNGMuOS0uOSAxLjQtMS40IDEuOC0yIC41LS41IDEtMiAyLTIu'
    b'NyAxLS42IDIuOC0yLjEgMy0yLjcgMCAwIC40IDMuOC0uNiA1LjhzLTEgMy0yLjMgMy40Yy0x'
    b'LjIuNS0xLjQuOC0xLjggMS0uNS40LTEuMi44LTEuOC44LS42IDAtMS4yLjQtMS4yLjR6bTMu'
    b'NSAyMC42Yy4xLjguNy0yLTIuNC0yLTMuMiAwLTUuOC0xLjItNi44LTIuM2wtMi4xLTIuM2E5'
    b'IDkgMCAwIDEtMS44LTMuMWMtLjItLjktMS00LjItMS00LjggMCAwIDEuNy4zIDIuNS45Ljcu'
    b'NiAyIC42IDIuOCAxIC44LjUgMS40IDEuNyAxLjkgMi4xLjQuNSAxLjcuNSAyLjMgMS40LjYu'
    b'OSAxLjcgMi45IDEuOSAzLjggMCAuOSAxLjIgMS44IDIgMi4yLjYuNS41IDIuMy42IDN6Ii8+'
    b'CiAgICAgICAgPHBhdGggZD0iTTQ1NS42IDMyMi4xcy0yLTIuNS0zLjEtMi41Yy0xIDAtMy44'
    b'LTIuNy00LTQgMC0xLjEtMS0zLjQtMS42LTMuOWEzLjYgMy42IDAgMCAxLTEuNS0zLjNjLjIt'
    b'MS44LjItNC44LjItNC44cy42IDEuOCAxLjUgMi4zYy45LjQgMi41IDEgMi44IDEuNi4zLjYg'
    b'MS41LjYgMiAyLjUuNSAxLjcuNSAxLjYuOCAyLjIuMy42IDEgMS40IDEuMyAyLjYuMyAxLjIg'
    b'MiA0LjMgMS43IDcuM3ptLTMtMTYuNmMtLjIuOCAxLjEtMS42LTEuNy0yLjRhOS42IDkuNiAw'
    b'IDAgMS01LjYtNGwtMS4zLTIuNmE5IDkgMCAwIDEtLjctMy40YzAtLjkuMi00LjEuNS00LjYg'
    b'MCAwIDEuNC43IDIgMS40LjQuOCAxLjcgMS4yIDIuMyAxLjguNS42LjcgMS45IDEgMi41LjMu'
    b'NSAxLjUuOSAxLjggMS44LjMgMSAuNyAzLjEuNiA0LS4xLjguNiAyIDEuMiAyLjYuNS42LS4x'
    b'IDIuMi0uMiAzeiIvPgogICAgICAgIDxwYXRoIGQ9Ik00NTIuNiAzMDQuM3MtMS4zLTIuOS0y'
    b'LjItMy4yYy0xLS4zLTIuNS0yLjctMi42LTMuOS0uMS0xLjItLjMtMy40LS43LTQtLjUtLjYt'
    b'MS4zLTIuNC0uNi00bDEuNi0zLjcgMS4zIDIuMWMuOCAxLjYgMS42IDEuNyAxLjcgMi4zLjEu'
    b'NyAxIDEgMS40IDIuMy41IDEuNyAwIDEuNiAwIDIuMy4yLjYuNyAxLjUuNiAyLjcgMCAxLjEu'
    b'NiA0LjUtLjUgNy4xem0yLjMtMTguMmMuMS0uNCAxLS45IDIuMS0xLjIgMS0uMyAyLjctMi43'
    b'IDMuNS0zLjMuNy0uNiAxLTEuNiAyLTIuMS45LS41IDEuNC0yLjQgMS43LTQuMmwtMy4zLjdh'
    b'Ny4yIDcuMiAwIDAgMC0yLjggMS44Yy0uNi44LTEuMiAyLTEuOSAyLjMtLjYuMy0xLjMgMi4x'
    b'LTEuMyAzLjN2Mi43eiIvPgogICAgICAgIDxwYXRoIGQ9Im00NTQuOCAyODQuOC0uMi0yLjZj'
    b'MC0uOS0uNi0zLjMuNy01LjMgMS0xLjMgNC4zLTMuOSA1LjItNCAwIDAgLjYgMi40LjQgMy4x'
    b'LS4xLjgtMSAzLjgtMS42IDQuMS0uNy4zLTIuNCAzLjktNC41IDQuN3oiLz4KICAgICAgICA8'
    b'cGF0aCBkPSJNNDU0IDI4Ni4xYy0uNC43LS4xLTIuMi0xLTMtMS0uNy0xLTEuOC0xLTNzLjIt'
    b'MiAuMy0yLjljLjItLjcgMi41LTMuOSAyLjMtNC44bDEuNyAzLjhjLjQgMS0uMyAyLjEtLjIg'
    b'MyAuMi45LjkgMi42LjMgMy41TDQ1NCAyODZ6bTgtMTUuNXMuMi0uNCAxLjUtLjQgMy4zLS4x'
    b'IDMuOS0uOGMuNi0uNiAxLjYtMS40IDIuMy0xLjdhNS4yIDUuMiAwIDAgMCAxLjgtMi4yYy4x'
    b'LS42IDEuMi0xLjggMS42LTEuOCAwIDAtMS42LS4yLTMuNC4zLTEuOC41LTQuNCAxLjQtNSAy'
    b'LjYtLjYgMS4yLTIuNyA0LTIuNyA0eiIvPgogICAgICAgIDxwYXRoIGQ9Ik00NjIuNSAyNzAu'
    b'M2MuMyAxIDIuOC0xIDMuNC0xLjhsMS41LTIgMS44LTIuNGMxLTEuNi43LTQuNi4zLTQuM2Ez'
    b'MSAzMSAwIDAgMS0yLjUgMS40Yy0uNSAwLTEuNC40LTEuNyAxLjEtLjMuOC0uNiAxLjgtMSAy'
    b'LjMtLjUuNS0zLjIgMi0xLjggNS43eiIvPgogICAgICAgIDxwYXRoIGQ9Ik00NjEuNiAyNzAu'
    b'M3MyLTEuNSAyLjgtMi4zYzEtLjguNS0yIDEtMi42LjMtLjYgMS40LTIgMS4xLTNsLS45LTMu'
    b'NC0xLjggMS44Yy0uOC44LS45IDEuNC0xLjIgMi4zLS4zLjktMSAxLjUtMS4yIDIuMi0uMy44'
    b'IDAgMi4zLjIgMy4ydjEuOHoiLz4KICAgICAgPC9nPgogICAgICA8ZyBmaWxsPSJub25lIiBz'
    b'dHJva2Utd2lkdGg9Ii4xIj4KICAgICAgICA8cGF0aCBkPSJNNDk0LjggMzY1LjJzLTEwLS4x'
    b'LTEwLjgtMS4zbTE2LjYgMi42cy02LjUgMS43LTEwIDEuM2MtMy41LS40LTUuMS4zLTUuOS4z'
    b'LS43IDAtNC41LTEuNS00LjUtMS41bTI3IDIuMi02IDEuM2MtMSAuMy02LjIgMi4yLTcuNyAy'
    b'LjJoLTVhMTggMTggMCAwIDEtNi4zLS40bTYuMi0xNXMzLjcgMi4zIDQuNCAzYy41LjggMy44'
    b'IDMuNSA0LjUgMy41bS05LTExLjFzNi41IDUuNiA3LjYgNi4zYzEgLjggNy40IDcgOC4xIDcu'
    b'OE00OTMuNiAzNTBzNS4xIDQgNS43IDUuN2MuNiAxLjcgMi4yIDMuNiAyLjIgMy42czIgNC4y'
    b'IDIuOCA0LjhjLjguNiAyLjMgMi4yIDQuMSAzLjRtLTQ0LTIxLjNzNS40IDQuNiA2LjkgNS40'
    b'bS05LjEtMi41czUuNCAzLjcgNy44IDQuNmMyLjQgMSA0LjQgMS43IDkuNiAyLjRtMi4xIDIu'
    b'MnMtNi0uMy03IDAtNS44LS44LTctMS4xbC02LjYtMS40bTExLjQtMTcuOXMtLjMgMy4zLjIg'
    b'NC43Yy40IDEuMyAyLjYgNS4zIDIuNCA2LjItLjEuOSAxLjIgNSAyLjQgNS43bTEuMi0xNnMt'
    b'MSAzLjMtLjYgNC40Yy41IDEgMS4yIDMgMS4yIDQuMiAwIDEuMi44IDMgMSAzLjguNC43LS4x'
    b'IDMuMy43IDRsMS42IDIuMm0tMzYuMS0yNi4zczQuOCAxLjkgNS40IDNjLjYgMS4zIDEuNSAx'
    b'LjYgMiAyLjJtMTAuMy05LjdzMS4zIDQuOSAxIDZjLS4zIDEuMi0uMyAzLjctLjMgNC42IDAg'
    b'LjktMS40IDQuNS0xLjMgNW0tMS4zLTE5LjYtLjYgNGMtLjEgMS4yIDAgMy4yLS4zIDQtLjMu'
    b'Ny0uOCA0LjggMCA2LjZNNDQ5IDMyNi4ybDQuOCA0LjJjLjkgMSA1IDUuMyA1LjEgNi40LjEg'
    b'MSAzIDQuMyAzLjkgNW0tMjAuNS0zMi41czQgNCA0LjIgNC45Yy4zLjkgMiAyLjMgMi44IDIu'
    b'OG0xMS40LTZzLTEuNSAyLjMtMS41IDNjMCAuOC0uNiAyLjctMS4yIDMuNS0uNC41LTEuNyAy'
    b'LjctMS41IDRtMy0xNi44LTEgMy42Yy0uMiAxLjUtMSAzLTEuMyA0LS4zLjgtMS41IDUuMi0x'
    b'IDcuOW0tMTAuNC0xNS43cy40IDIuMSAxLjUgMy4yYzEgMSAyLjcgMi42IDIuOCAzLjQuMiAx'
    b'IDEuNiA1LjQgMyA3YTUuNCA1LjQgMCAwIDEgMS43IDNtLTEwLjUtMzJzLjQgMi42LjcgMy40'
    b'Yy4zLjcgMS41IDQgMi43IDUuMW05LjUtNy43LS45IDNjLS4xIDEtMSAyLTEuMiAyLjRsLS43'
    b'IDJtNS41LTUuM2MtLjEuOS0xLjggMy42LTIgNC0uMS41LTEgMi42LTEuOSAzLjItLjkuNi0z'
    b'LjYgMi42LTMuNCAzLjRtLTQuNC0xNi41cy0uMiAzLjMuNCA0LjVhMzcuMiAzNy4yIDAgMCAx'
    b'IDEuNyA0Yy4zLjkuMyAyLjQuNCAzLjQuMiAxLjEuNiAzIDEuMiAzLjhtMTEuOC0yNS45LTMu'
    b'MiAzLjVjLTEgMS00LjggNS01IDUuOG00LjYtMTEuNnMtMi4xIDQuNy0yLjYgNS40bC0uOSAy'
    b'bS0yLTcuNXMuMiAzLjYgMCA0LjVhNy45IDcuOSAwIDAgMCAwIDIuOWMuMi40LS40IDMuNy0u'
    b'NSA0LjVtMTgtMjEuM3MtNC44IDIuOS01LjUgMy42bTIuNy03LjMtMy4zIDQuOC0uOCAxLjRt'
    b'LjMtNi43cy0xIDIuNi0xLjIgMy42YTM2IDM2IDAgMCAxLTIuMiA1LjYiLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNNDY5LjIgMjU4cy0uNCAxIDEuNC43Ii8+CiAg'
    b'ICAgIDwvZz4KICAgIDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3N2LWEiIHdpZHRoPSIx'
    b'MDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAgMCAxIDEwMzAgMCki'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiMwMDIwOWYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTUx'
    b'NC42IDM2Ni4xcy43LTEuOCAyLjItLjFjMCAwIDEuOSA0LjIuNSA0LjMtMS40LjItMi43LjUt'
    b'Mi45LS4zLS4xLS43LjItMy45LjItMy45eiIvPgogICAgPHBhdGggZmlsbD0iIzAwMjA5ZiIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNNTE2LjUgMzY1LjVzLjUtNi40IDEuNC02LjdjLjkt'
    b'LjMgMy42LTEuOCA1LjMtLjUgMS42IDEuNCAwIDgtLjUgOC43LS42LjYtMS41IDIuNS01IDJs'
    b'LS40LTEuNnMxLjgtLjIgMy0uOGMxLjItLjYgMS42LTEuMiAxLjUtMS44LS4yLS45IDAtNC4y'
    b'LTEtNC41bC0yLjMtLjgtMS43IDYuNS0uMy0uNXoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDIw'
    b'OWYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1p'
    b'dD0iMi42IiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJNNTE0LjQgMzcwcy02LjIgMy43LTMgOWwt'
    b'Mi4xLTEuM3MtMS4yIDIuMi0uMSAzLjRjMCAwLTQuMy0zLjgtMS04LjMgMy40LTQuNiA2LTQu'
    b'MyA2LTQuM2wuMiAxLjV6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDAyMDlmIiBmaWxsLXJ1bGU9'
    b'ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tl'
    b'LXdpZHRoPSIuMiIgZD0iTTUxNC40IDM2N3MtMi43LTEuOC02LjYtLjdjMCAwLTEuNy01LjYt'
    b'MS03LjQuMi0uOC44LS45LjgtLjlzLTItMS4yLTEuMyA0Yy42IDUuNCAxLjYgNi44IDEuNiA2'
    b'LjhzNS4yLjMgNi40LS4zbC4xLTEuNHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDIwOWYiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42'
    b'IiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJNNTE0LjQgMzY3cy01LjQtOS02LjgtOWMwIDAtMS41'
    b'LS4yIDItLjYgMS4yLS4xIDMuMiAwIDQgMS43IDEgMS42IDEuNyA1LjUgMiA2LjEgMCAwLTEg'
    b'LjMtMS4yIDEuOXoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMTEzMjIiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lk'
    b'dGg9Ii4yIiBkPSJNNTE0LjQgMzY3cy0zLjYtMS42LTQtMmMtLjUtLjUtMS4yLTUuNi0uOC01'
    b'LjMgMCAwLTEuNS0xLjctMi0xLjctLjMgMC0xLjMuOC0xIDIuNi4zIDEuOC43IDQuNSAxLjIg'
    b'NS43IDAgMCAyLjktMS4yIDYuNi44eiIvPgogICAgPHBhdGggZmlsbD0iIzAwMjA5ZiIgZmls'
    b'bC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYi'
    b'IHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik01MTcuNyAzNzBzMiAxLjMgMiAzLjVjMCAyLjMuOSA2'
    b'LjQgMi43IDcuMyAwIDAgLjUtMS43IDEtMiAwIDAgMS45IDIuMSAyLjUgMi4xIDAgMC0xLTIt'
    b'MS0yLjkgMC0uOS0xLTQuMy0yLTUuMi0uOC0xLTIuNi0zLTUuMi0zLjh2MXoiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiMwMTEzMjIiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJtNTE4LjUgMzU5'
    b'LjUtMS43IDYuNS41IDEuNHMuNi0uMi45LTFjLjMtLjcgMS4yLTYuMyAxLjctNi41bC0xLjQt'
    b'LjR6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDExZDMzIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik01MTQuNCAzNjkuM3MtMyAxLTQuMSAzLjJjMCAwLS40LTEuNSA0LTMuNnYuNHptMy40IDBz'
    b'MiAuOCAyLjYgMmwtMi42LTEuNXYtLjV6bS0zLjQtMS43cy00LjYuNy01LjYuNWMwIDAgMS4z'
    b'LjMgNS42IDB2LS41em03LjQtMi44cy41IDIuMy45IDIuMmMuNC0uMiAxLjItMy45IDEuMi01'
    b'LjYgMC0xLjctLjctMi4xLTEuNC0yLS43IDAtMSAxLjUtMSAyLjJhNDkgNDkgMCAwIDAgLjMg'
    b'My4yeiIvPgogICAgPHBhdGggZmlsbD0iIzAxMWQzMyIgZmlsbC1ydWxlPSJldmVub2RkIiBk'
    b'PSJNNTE2LjggMzY2czEuOSA0LjEuNSA0LjRjLTEuNC4yLjYuMS0uNC0yLjctLjQtMS4xLTEt'
    b'Mi41LTEuMy0yLjUgMCAwIDEuMS40IDEuMi44eiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9Ii4y'
    b'IiBkPSJNNTE0LjYgMzY2LjFzLjctMS44IDIuMi0uMWMwIDAgMS45IDQuMi41IDQuMy0xLjQu'
    b'Mi0yLjcuNS0yLjktLjMtLjEtLjcuMi0zLjkuMi0zLjl6Ii8+CiAgICA8cGF0aCBmaWxsPSJu'
    b'b25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0'
    b'aD0iLjIiIGQ9Ik01MTYuNSAzNjUuNXMuNS02LjQgMS40LTYuN2MuOS0uMyAzLjYtMS44IDUu'
    b'My0uNSAxLjYgMS40IDAgOC0uNSA4LjctLjYuNi0xLjUgMi41LTUgMmwtLjQtMS42czEuOC0u'
    b'MiAzLS44YzEuMi0uNiAxLjYtMS4yIDEuNS0xLjgtLjItLjkgMC00LjItMS00LjVsLTIuMy0u'
    b'OC0xLjcgNi41LS4zLS41eiIvPgogIDwvZz4KICA8ZyB0cmFuc2Zvcm09Im1hdHJpeCguOCAw'
    b'IDAgLjggLTkyLjcgMCkiPgogICAgPHBhdGggZmlsbD0iIzAwMjA5ZiIgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBkPSJNNTA5LjggMjU1LjljLS40LTEtLjQtNy40LS40LTguNGE2OCA2OCAwIDAg'
    b'MSAzLjgtMTEuMmMuNi0xIC41LTEuMi43LTEuOGwuOS0xLjJhMTAuOSAxMC45IDAgMCAxIDEu'
    b'MyA0LjFzLS42IDQuMS0xLjEgNmMtLjQgMS43LTEuNiA0LjMtMS44IDQuOC0uNiAxLjItLjUg'
    b'Mi40LS4yIDIuNWwtMy4yIDUuMnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVs'
    b'ZT0iZXZlbm9kZCIgZD0ibTUxNSAyNDcuMy41LjZjMS4zLTEuNSAxLjQtNC41IDEuNC00LjVs'
    b'LS45LTZzLS41IDQtMSA2Yy0uNCAxLjctMS42IDQuMy0xLjggNC44LS45IDIuMi0uMiAyLjQt'
    b'LjIgMi41bDItMy4zeiIvPgogICAgPHBhdGggZmlsbD0iIzAwMjA5ZiIgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBkPSJNNTE1LjUgMjQ3LjljMS4zLTEuNSAxLjQtNC41IDEuNC00LjVzMSA1IC40'
    b'IDZjLS41IDEtLjUuNy0uNCAxLjNsLTEuNC0yLjh6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25l'
    b'IiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0i'
    b'LjMiIGQ9Ik01MTcgMjUwLjdjLS4yLS42LS4yLS4zLjMtMS4zcy0uNC02LS40LTZsLS45LTZj'
    b'MC0xLjMtLjYtMy0xLjItNC4xbC0uOSAxLjJjLS4yLjYgMCAuOC0uNyAxLjgtLjYgMS0zLjYg'
    b'OS41LTMuOCAxMS4yIDAgMSAwIDcuNS40IDguNCIvPgogICAgPHBhdGggZmlsbD0iI2ZjMCIg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIy'
    b'LjYiIHN0cm9rZS13aWR0aD0iLjEiIGQ9Im01MTUgMjM0LjEtLjItMS4zYzAtLjIuNi45IDEg'
    b'LjcuOS4zIDEuOSAxLjUgMi4xIDEuOC0uNC41LTEuMyAxLjYtMiAxLjQtLjUtLjItLjQtMS0u'
    b'NS0xLjUtLjEtLjMtLjQtLjYtLjQtMXoiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIuMSIgZD0i'
    b'bTUxNSAyMzMuMy40LjRjLjIuMi40IDAgLjcuMi42LjQuOS44IDEuNiAxLjVtLTItMS40Yy44'
    b'LjQgMS4yIDEgMS44IDEuNyIvPgogICAgPHBhdGggZmlsbD0iI2ZjMCIgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13'
    b'aWR0aD0iLjEiIGQ9Im01MTQgMjMzLjQgMS4zLS42Yy4xIDAtLjcuOC0uNCAxLjIgMCAuOS0u'
    b'NyAyLjItMSAyLjUtLjYtLjEtMS4yLS4xLTEuOC0xLjEtLjItLjQuNC0uOC44LTEuMS4yLS4y'
    b'LjctLjggMS4yLS45eiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9Ii4xIiBkPSJtNTE0LjkgMjMz'
    b'LjItLjMuNS4xLjdjLS4yLjctLjUgMS0uOSAyIi8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iLjEi'
    b'IGQ9Ik01MTQuNCAyMzRjMCAuOS0uNSAxLjUtMSAyLjNoLjIiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJs'
    b'aW1pdD0iMi42IiBzdHJva2Utd2lkdGg9Ii4xIiBkPSJNNTE1LjQgMjMyLjhjLjYtLjcgMS43'
    b'LTEuNCAyLjMtMWwuNi42Yy4yLjMuMi41IDAgLjgtLjMuOC0xLjQuNC0yIDAtLjIgMC0uNi0u'
    b'NC0uOC0uM2wtLjMuMS4zLjEgMS44LjljLjUuMiAxLjUtLjUgMS40LTEgMC0uNS0uOS0xLjUt'
    b'MS4zLTEuNS0xIDAtMS44LjYtMi41IDEuNC4yLS4yLjQgMCAuNSAweiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2ZjMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1t'
    b'aXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iLjEiIGQ9Ik01MTQuOSAyMzIuOGMtLjYt'
    b'LjctMS43LTEuNC0yLjItMWwtLjYuNmMtLjMuMy0uMy41LS4xLjguMy44IDEuNC40IDIgMCAu'
    b'MiAwIC42LS40LjgtLjNsLjQuMS0uNC4xLTEuOC45Yy0uNS4yLTEuNC0uNS0xLjQtMSAwLS42'
    b'IDEtMS41IDEuNC0xLjUgMSAwIDEuNy42IDIuNCAxLjQtLjEtLjItLjQgMC0uNSAweiIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZjMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iLjEiIGQ9Ik01MTUgMjMy'
    b'LjRjLS4yLS4xLS41LjEtLjYuMyAwIC4yLjEuNi40LjYuMy4yLjggMCAuOS0uMyAwLS40LS4z'
    b'LS41LS42LS42eiIvPgogICAgPHBhdGggZmlsbD0iI2ZjMCIgZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiBkPSJNNTE1IDIyNi4zcy40IDIuNCAxLjYgNGMxLjIgMS44LTEuNCAxLjYtMS42IDIuMiAw'
    b'IDAtLjgtMS43LTEuNi0yLjIgMCAwIDEuMy0yIDEuNi00eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lk'
    b'dGg9Ii4xIiBkPSJNNTE1IDIyNi4zcy40IDIuNCAxLjYgNGMwIDAtMS40IDEuNi0xLjYgMi4y'
    b'IDAgMC0uOC0xLjctMS42LTIuMiAwIDAgMS4zLTIgMS42LTQiLz4KICAgIDxwYXRoIGZpbGw9'
    b'Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdp'
    b'ZHRoPSIuMSIgZD0ibTUxNSAyMjguOC43IDEuOHMtLjYuNC0uNy43YzAgMC0uMy0uOC0uNi0x'
    b'IDAgMCAuNi0uOC42LTEuNXoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgZD0ibTUxNSAzNDQuNS0uMy0uMmMtLjQtLjItMS4yLS4yLTEuMy0uNS0xLTEu'
    b'MS0uNC0zLjQgMC00LjggMS0yLjYgMS01IDEuNi03LjQuNiAyLjQuNyA0LjggMS42IDcuNC40'
    b'IDEuNCAxLjEgMy43LjEgNC44LS4yLjMtLjkuMy0xLjMuNWwtLjQuMnoiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiMwMDIwOWYiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTUxNSAzMzEuNWMuNiAy'
    b'LjUuNyA1IDEuNiA3LjYuNCAxLjMgMSAzLjQuMyA0LjUuNCAwIC43LS4xIDEtLjMuMiAwIC4z'
    b'IDAgLjQtLjJsLjQtLjVjLjMtLjIuNiAwIC45LS4ybC4xLS4yYy42LS4zIDEtLjYgMS4zLTEu'
    b'MS4xLS40LjItLjkgMC0xLjMgMC0uMyAwLS41LS4yLS44bC0uNS0xLjEtLjYtMS4yYTIuNCAy'
    b'LjQgMCAwIDAtLjMtLjVsLS4zLS42LS40LS40LS40LS4zcy0uMy0uMS0uMi0uMmwtLjMtLjEt'
    b'MS0yYTMgMyAwIDAgMS0uMi0xLjFINTE1em0wIDBjLS41IDIuNS0uNyA1LTEuNiA3LjYtLjMg'
    b'MS4zLTEgMy40LS4yIDQuNS0uNCAwLS43LS4xLTEuMS0uMy0uMSAwLS4zIDAtLjMtLjJhMS40'
    b'IDEuNCAwIDAgMC0uNS0uNWMtLjItLjItLjUgMC0uOC0uMmwtLjItLjJjLS41LS4zLTEtLjYt'
    b'MS4yLTEuMWEyLjUgMi41IDAgMCAxLS4xLTEuM2wuMi0uOC42LTEuMS42LTEuMmMwLS4yLjEt'
    b'LjQuMy0uNWwuMy0uNi40LS40LjQtLjMuMi0uMi4yLS4xIDEtMmMuMi0uMi4yLS44LjItMS4x'
    b'aDEuNnoiLz4KICAgIDxnIGlkPSJzdi1iIiBmaWxsPSJub25lIiBzdHJva2UtbWl0ZXJsaW1p'
    b'dD0iMi42IiBzdHJva2Utd2lkdGg9Ii4yIj4KICAgICAgPHBhdGggc3Ryb2tlPSIjMDExMzIy'
    b'IiBkPSJNNTE0LjMgMzMxLjZzLTEgNC0xLjYgNWMtLjYgMS4xLTMgMy0xLjQgNiIvPgogICAg'
    b'ICA8cGF0aCBzdHJva2U9IiMwMTFkMzMiIGQ9Ik01MTQuNCAzMzEuNnMtMSA0LTEuNiA1LjFj'
    b'LS42IDEuMS0zIDMtMS40IDYiLz4KICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyNzQzIiBkPSJN'
    b'NTE0LjUgMzMxLjZzLTEgNC4xLTEuNiA1LjJjLS42IDEtMi45IDMuMS0xLjMgNiIvPgogICAg'
    b'ICA8cGF0aCBzdHJva2U9IiMwMzMwNTQiIGQ9Ik01MTQuNiAzMzEuNnMtMSA0LjItMS42IDUu'
    b'M2MtLjYgMS0yLjkgMy0xLjIgNi4xIi8+CiAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2E2NSIg'
    b'ZD0iTTUxNC43IDMzMS42cy0xIDQuMy0xLjYgNS4zYy0uNiAxLTIuOCAzLjItMS4yIDYuMyIv'
    b'PgogICAgICA8cGF0aCBzdHJva2U9IiMwMTFkMzMiIGQ9Ik01MTQuMiAzMzEuNnMtMSA0LTEu'
    b'NiA1Yy0uNiAxLjEtMyAzLTEuNCA2Ii8+CiAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjc0MyIg'
    b'ZD0iTTUxNCAzMzEuNnMtLjkgMy44LTEuNiA1Yy0uNiAxLTMgMy0xLjQgNS45Ii8+CiAgICAg'
    b'IDxwYXRoIHN0cm9rZT0iIzAzMzA1NCIgZD0iTTUxNCAzMzEuNnMtMSAzLjctMS43IDVjLS41'
    b'IDEtMyAzLTEuNCA1LjkiLz4KICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzYTY1IiBkPSJNNTEz'
    b'LjggMzMxLjZzLS44IDMuNi0xLjYgNWMtLjYgMS0zIDMtMS40IDUuOSIvPgogICAgICA8cGF0'
    b'aCBzdHJva2U9IiMwMDIwOWYiIGQ9Ik01MTMuOCAzMzEuNnMtLjkgMy40LTEuNyA1Yy0uNiAx'
    b'LTMgMi45LTEuNCA1LjgiLz4KICAgICAgPHBhdGggc3Ryb2tlPSIjMDAyMDlmIiBkPSJNNTE0'
    b'LjggMzMxLjZzLTEgNC4zLTEuNiA1LjRjLS42IDEtMi44IDMuMy0xLjEgNi4zIi8+CiAgICA8'
    b'L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNzdi1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIx'
    b'MDAlIiB0cmFuc2Zvcm09Im1hdHJpeCgtMSAwIDAgMSAxMDMwIDApIi8+CiAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9r'
    b'ZS13aWR0aD0iLjIiIGQ9Im01MTguNiAzMzUuMi41LjUuMy41LjMuNS42IDEuMi41IDEuMS4z'
    b'LjhhMi41IDIuNSAwIDAgMS0uMSAxLjNjLS4yLjUtLjguOC0xLjMgMS4xbC0uMS4yYy0uMy4y'
    b'LS42IDAtLjkuMmExLjkgMS45IDAgMCAwLS40LjVsLS4zLjJjLS40LjItLjcuMy0xLjEuM2wt'
    b'LjIuM2MtLjIuMi0xIC4yLTEuMy40bC0uNC4yLS4zLS4yYy0uNC0uMi0xLjItLjItMS4zLS40'
    b'YS43LjcgMCAwIDEtLjItLjNsLTEuMi0uM3MtLjIgMC0uMy0uMmExLjQgMS40IDAgMCAwLS40'
    b'LS41Yy0uMy0uMi0uNiAwLS44LS4ybC0uMi0uMmMtLjYtLjMtMS0uNi0xLjItMS4xYTIuNSAy'
    b'LjUgMCAwIDEtLjEtMS4zbC4yLS44LjUtMS4xLjctMS4yYzAtLjIuMS0uNC4zLS41IDAtLjIu'
    b'MS0uNC4zLS41IDAtLjIuMy0uMy40LS41Ii8+CiAgICA8ZyBpZD0ic3YtYyI+CiAgICAgIDxn'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCI+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQ4'
    b'Ny40IDI5My42Yy0xLjUtMy43LTMtMTEuMy0zLTEzIC4zLTcuMS4yLTkuMy45LTE2LjVsNy4z'
    b'IDguM2MtLjIgMi44LS4yIDMuNyAwIDUuNS4xLjcuNSAzLjkgMSA1LjFsLTYuMiAxMC42eiIv'
    b'PgogICAgICAgIDxwYXRoIGZpbGw9IiMwMDIwOWYiIGQ9Ik00OTMuNiAyODNjLS41LTEuMy0u'
    b'OS00LjUtMS01LjEtLjItMS44LS4yLTIuNyAwLTUuNWw0LjUgNS0zLjUgNS42em0tMTguNiA3'
    b'YTc1LjYgNzUuNiAwIDAgMS0uMy00LjRjMC01LjEtLjYtOCAwLTEzLjQuNC00LjIgMS41LTku'
    b'OCAxLjMtMTQuNC0uMS0xLjMuMS0yLjYuMi0zLjlsOSAxMC4xYy0uNiA3LjMtLjUgOS41LS44'
    b'IDE2LjYgMCAxLjcgMS41IDkuMyAzIDEzbC0yIDMuMi0xMC40LTYuOXptNi4zIDEzLjdjLS42'
    b'LTEtMS0zLjktMS4yLTQuNS0uMy0xLjUtLjMtMi4zLS4yLTVsNSAzLjMtMy42IDYuMnptLTE0'
    b'LjMgMjRhNS4yIDUuMiAwIDAgMS0xLjgtMi4yYy0uNy0xLjgtLjUtMS43LTEtMy42LS4yLTEu'
    b'MS0uMi0yLjMtLjUtMy40LS4yLTEuMi0xLjgtNC44LTEuOC02LjItLjItNC44LTEuOC04LTEu'
    b'NC0xMy4yLjMtNCAxLjItOS40LjctMTMuNWwuMS0zLjYgMTAuMyA2LjdjLS40IDYuOC0uMiA4'
    b'LjgtLjIgMTUuNCAwIDEuNiAxLjMgOC4xIDMgMTFsLTcuNCAxMi42em0xNyAzLjhjMS45IDEu'
    b'NyA1LjQgMi42IDYgMyAxLjIgMSAzIDIuMyA2LjMgMi40IDIuMy4yIDMuMy0uNCA1LjctLjcg'
    b'Mi44LS4zLS4zLjEgMi4zLS41IDEuNC0uMyAxLjQtLjUgMy4yLTEgMS4zLS4zIDIuNy0uNiAz'
    b'LjUtMS44LjMtLjQuNi0uNy42LTEuNGgxLjhjLjIuNS0uMyAxLjUtLjUgMS44bC0uNS43Yy0u'
    b'Mi42LS4yLjQtLjcuOWwtLjguNmMtLjQuMy0uNy42LTEuMS43LTEuOC4zLTIuNS43LTQuMiAx'
    b'LjEtMS42LjUtLjcuNC0yIC43bC0yLjQuNy0yLjQuNmMtMi45LjctNS43LjUtOC42LjMtMS4x'
    b'IDAtNC0uNy01LTEuNC0xLjgtMS4yLTUuNy0xLjctNy40LTIuOS0uMy0uMi0xLjQtLjctMS42'
    b'LTEtMS43LTEuMy0zLTEuNy00LjgtMi44SDQ4NHoiLz4KICAgICAgICA8cGF0aCBmaWxsPSIj'
    b'MDAyMDlmIiBkPSJNNDk3LjcgMzMxLjVoMTRjLS4xLjctLjQgMS0uNyAxLjUtLjggMS0yLjIg'
    b'MS40LTMuNSAxLjctMS40LjQtMi45LS40LTQuNC0uNC0zLjctMS4xLTQuMS0yLjMtNS40LTIu'
    b'OHoiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNNDk3LjcgMzMxLjVjMS4zLjYg'
    b'MiAxLjcgNS40IDIuOCAxLjMgMCAyLjguNiA0IC42LTEuNS4zLTEuNS41LTIuOC44LTIuNi42'
    b'LjUuMi0yLjMuNS0yLjQuMy0zLjQgMS01LjcuOGExMSAxMSAwIDAgMS02LjMtMi41Yy0uNi0u'
    b'NC00LjEtMS4zLTYtM2gxMy43eiIvPgogICAgICA8L2c+CiAgICAgIDxnIGZpbGw9Im5vbmUi'
    b'IHN0cm9rZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iLjIiPgogICAgICAgIDxw'
    b'YXRoIHN0cm9rZT0iIzAyMjc0MyIgZD0iTTQ3Ni42IDI1OS43czEuNyAxNSA3LjUgMTQuNCIv'
    b'PgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjg0NyIgZD0iTTQ4NC4yIDI3NGMtMyAuMi00'
    b'LjktMy41LTYtN2E0Ni4zIDQ2LjMgMCAwIDEtMS41LTcuMyIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzAzMmI0YyIgZD0iTTQ4NC4yIDI3NGMtMy0uMS00LjktMy44LTUuOC03YTQzLjYg'
    b'NDMuNiAwIDAgMS0xLjctNy40Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyZDRmIiBk'
    b'PSJNNDg0LjIgMjc0Yy0yLjktLjMtNC45LTQuMS01LjgtNy4yYTQ4LjIgNDguMiAwIDAgMS0x'
    b'LjctNy4yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyZjUzIiBkPSJNNDg0LjIgMjcz'
    b'LjljLTIuOS0uNS00LjktNC40LTUuOC03LjJhNDMgNDMgMCAwIDEtMS43LTcuMiIvPgogICAg'
    b'ICAgIDxwYXRoIHN0cm9rZT0iIzA0MzI1OCIgZD0iTTQ4NC4yIDI3My44Yy0zLS42LTQuOS00'
    b'LjYtNS43LTcuMS0xLjEtMy4yLTEuOC03LjEtMS45LTcuMiIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzA0MzQ1YiIgZD0iTTQ4NC4yIDI3My44Yy0yLjktLjktNC45LTQuOS01LjYtNy4y'
    b'YTQ2IDQ2IDAgMCAxLTItNy4yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDQzNjVlIiBk'
    b'PSJNNDg0LjMgMjczLjdjLTMtMS01LTUtNS43LTcuM2E0OC43IDQ4LjcgMCAwIDEtMS45LTci'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDM4NjIiIGQ9Ik00ODQuMyAyNzMuN2MtMy0x'
    b'LjItNS01LjQtNS42LTcuM2E0Ny41IDQ3LjUgMCAwIDEtMi03LjEiLz4KICAgICAgICA8cGF0'
    b'aCBzdHJva2U9IiMwNTNiNjciIGQ9Ik00ODQuMyAyNzMuNmMtMy0xLjMtNS01LjYtNS42LTcu'
    b'My0xLTIuOC0yLTYuOC0yLTciLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNTNkNmEiIGQ9'
    b'Ik00ODQuMyAyNzMuNmMtMy0xLjYtNS02LTUuNS03LjRhNTAuMyA1MC4zIDAgMCAxLTIuMS03'
    b'Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZjZlIiBkPSJNNDg0LjMgMjczLjVjLTMt'
    b'MS43LTUtNi4yLTUuNC03LjRhNDUuNyA0NS43IDAgMCAxLTIuMi03Ii8+CiAgICAgICAgPHBh'
    b'dGggc3Ryb2tlPSIjMDY0MTcyIiBkPSJNNDg0LjQgMjczLjVjLTMtMi01LTYuNC01LjUtNy41'
    b'YTY2IDY2IDAgMCAxLTIuMi03Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDAyMDlmIiBk'
    b'PSJNNDc2LjcgMjU5YTQ3IDQ3IDAgMCAwIDIuMyA2LjljLjMuOCAyLjQgNS40IDUuNCA3LjUi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjI3NDMiIGQ9Ik00NzYuOSAyNTYuM3M0Ljgg'
    b'MTIgOCAxMC42Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyYTQ5IiBkPSJNNDg0Ljgg'
    b'MjY2LjljLTEuMy41LTMuMy0xLjgtNS00LjZhNjUuMiA2NS4yIDAgMCAxLTMtNiIvPgogICAg'
    b'ICAgIDxwYXRoIHN0cm9rZT0iIzAzMmQ0ZiIgZD0iTTQ4NC44IDI2Ni44Yy0xLjIuNS0zLjIt'
    b'MS44LTQuOS00LjZhODYgODYgMCAwIDEtMy02Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDMzMDU0IiBkPSJNNDg0LjggMjY2LjhjLTEgLjQtMy4yLTEuNy00LjktNC43YTkxLjUgOTEu'
    b'NSAwIDAgMS0zLTUuOSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0MzM1OSIgZD0iTTQ4'
    b'NC44IDI2Ni44Yy0uOC4zLTMuMS0xLjctNC44LTQuOC0yLTMuNC0zLTUuOC0zLTUuOCIvPgog'
    b'ICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0Mzc2MCIgZD0iTTQ4NC45IDI2Ni43Yy0uNy4zLTMu'
    b'MS0xLjctNC44LTQuOGwtMy4xLTUuOCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2E2'
    b'NSIgZD0iTTQ4NC45IDI2Ni43Yy0uNi4zLTMtMS43LTQuOC00LjlhNzQ5LjUgNzQ5LjUgMCAw'
    b'IDAtMy4yLTUuOCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2Q2YSIgZD0iTTQ4NC45'
    b'IDI2Ni43Yy0uNC4yLTMtMS42LTQuNy01YTI4MSAyODEgMCAwIDAtMy4yLTUuNyIvPgogICAg'
    b'ICAgIDxwYXRoIHN0cm9rZT0iIzA2NDE3MSIgZD0iTTQ4NC45IDI2Ni43Yy0uMiAwLTIuOS0x'
    b'LjYtNC43LTVMNDc3IDI1NiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAwMjA5ZiIgZD0i'
    b'TTQ3NyAyNTUuOXMxIDEuNCAzLjMgNS43YTEzLjYgMTMuNiAwIDAgMCA0LjUgNW04IDEyLjEg'
    b'My44LS43bS00LTMuMSA0LjEgMi4yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDY0MTcx'
    b'IiBkPSJtNDkyLjUgMjc1IDQuMiAyIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZTZj'
    b'IiBkPSJtNDkyLjUgMjc1LjIgNC4yIDIiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNTNi'
    b'NjciIGQ9Im00OTIuNSAyNzUuNCA0LjIgMS44Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDQzODYyIiBkPSJtNDkyLjYgMjc1LjYgNC4yIDEuNiIvPgogICAgICAgIDxwYXRoIHN0cm9r'
    b'ZT0iIzA0MzU1YyIgZD0ibTQ5Mi42IDI3NS44IDQuMiAxLjQiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwNDMyNTgiIGQ9Im00OTIuNiAyNzYgNC4zIDEuMiIvPgogICAgICAgIDxwYXRo'
    b'IHN0cm9rZT0iIzAzMmY1MyIgZD0ibTQ5Mi42IDI3Ni4xIDQuMyAxLjIiLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2U9IiMwMzJjNGQiIGQ9Im00OTIuNiAyNzYuMyA0LjQgMSIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZT0iIzAyMmE0OSIgZD0ibTQ5Mi42IDI3Ni41IDQuNC45Ii8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjMDY0MTcxIiBkPSJtNDkyLjggMjc4LjUgMy45LS41Ii8+CiAg'
    b'ICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZTZjIiBkPSJtNDkyLjggMjc4LjMgNC0uNCIvPgog'
    b'ICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2I2NyIgZD0ibTQ5Mi44IDI3OC4xIDQtLjMiLz4K'
    b'ICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDM4NjIiIGQ9Im00OTIuOCAyNzggNC0uMiIvPgog'
    b'ICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0MzU1YyIgZD0iTTQ5Mi44IDI3Ny43aDQiLz4KICAg'
    b'ICAgICA8cGF0aCBzdHJva2U9IiMwNDMyNTgiIGQ9Im00OTIuOCAyNzcuNSA0LjEuMiIvPgog'
    b'ICAgICAgIDxwYXRoIHN0cm9rZT0iIzAzMmY1MyIgZD0ibTQ5Mi44IDI3Ny4zIDQuMi4zIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyYzRkIiBkPSJtNDkyLjcgMjc3LjEgNC4zLjQi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjJhNDkiIGQ9Im00OTIuNyAyNzYuOSA0LjQu'
    b'NiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjc0MyIgZD0ibTQ5Mi43IDI3Ni43IDQu'
    b'NC43bS0yMi4xLjRzLjIgMy4yLjkgNC41YzEgMS45IDMuOSA0LjcgNy4yIDYuOCIvPgogICAg'
    b'ICAgIDxwYXRoIHN0cm9rZT0iIzAyMjg0NyIgZD0iTTQ4My4yIDI4OS4xYTI3LjIgMjcuMiAw'
    b'IDAgMS01LjUtNC42IDEzLjcgMTMuNyAwIDAgMS0xLjctMi4zYy0uNy0xLjQtMS00LjUtMS00'
    b'LjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJiNGMiIGQ9Ik00ODMuMyAyODkuMWEy'
    b'Ny4yIDI3LjIgMCAwIDEtNS40LTQuNyA5LjMgOS4zIDAgMCAxLTEuNy0yLjNjLS44LTEuNC0x'
    b'LjItNC41LTEuMi00LjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJkNGYiIGQ9Ik00'
    b'ODMuMyAyODkuMWEzMS4zIDMxLjMgMCAwIDEtNS4zLTQuNyAxMiAxMiAwIDAgMS0xLjctMi40'
    b'Yy0uOC0xLjUtMS4zLTQuNS0xLjMtNC41Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMy'
    b'ZjUzIiBkPSJNNDgzLjQgMjg5YTMxLjMgMzEuMyAwIDAgMS01LjMtNC43IDEzLjYgMTMuNiAw'
    b'IDAgMS0xLjctMi40Yy0uOC0xLjUtMS40LTQuNC0xLjQtNC40Ii8+CiAgICAgICAgPHBhdGgg'
    b'c3Ryb2tlPSIjMDQzMjU4IiBkPSJNNDgzLjUgMjg5Yy0yLjEtMS4zLTQtMy41LTUuMy00Ljhh'
    b'MTAgMTAgMCAwIDEtMS42LTIuNGMtMS0xLjUtMS42LTQuNC0xLjYtNC40Ii8+CiAgICAgICAg'
    b'PHBhdGggc3Ryb2tlPSIjMDQzNDViIiBkPSJNNDgzLjYgMjg5Yy0yLjEtMS40LTQtMy42LTUu'
    b'My00LjlhMTUuMSAxNS4xIDAgMCAxLTEuNi0yLjMgMjEuNCAyMS40IDAgMCAxLTEuNy00LjUi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDM2NWUiIGQ9Ik00ODMuNiAyODljLTItMS40'
    b'LTQtMy43LTUuMS01YTE0IDE0IDAgMCAxLTEuNy0yLjNjLTEtMS43LTEuOC00LjUtMS44LTQu'
    b'NSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0Mzg2MiIgZD0iTTQ4My43IDI4OWMtMi0x'
    b'LjQtNC0zLjgtNS4xLTVhMTUgMTUgMCAwIDEtMS42LTIuNCAyNiAyNiAwIDAgMS0yLTQuNSIv'
    b'PgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2I2NyIgZD0iTTQ4My44IDI4OWMtMi0xLjUt'
    b'NC00LTUtNS4xYTEzLjggMTMuOCAwIDAgMS0xLjctMi40Yy0xLjEtMS44LTItNC41LTItNC41'
    b'Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZDZhIiBkPSJNNDgzLjkgMjg5Yy0yLTEu'
    b'NS00LTQtNS01LjJhMTYuOCAxNi44IDAgMCAxLTEuNy0yLjRjLTEtMS44LTIuMS00LjUtMi4x'
    b'LTQuNSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2Y2ZSIgZD0iTTQ4NCAyODljLTIt'
    b'MS41LTQtNC4yLTUtNS4zYTE4LjcgMTguNyAwIDAgMS0xLjctMi40bC0yLjItNC40Ii8+CiAg'
    b'ICAgICAgPHBhdGggc3Ryb2tlPSIjMDY0MTcyIiBkPSJNNDg0IDI4OWMtMi0xLjYtMy45LTQu'
    b'My00LjktNS40YTE2LjEgMTYuMSAwIDAgMS0xLjYtMi40bC0yLjQtNC40Ii8+CiAgICAgICAg'
    b'PHBhdGggc3Ryb2tlPSIjMDAyMDlmIiBkPSJNNDc1IDI3Ni43czMgNS4zIDQuMyA2LjhjMSAx'
    b'IDIuOCA0IDQuOCA1LjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMTFkMzMiIGQ9Im00'
    b'NzUuMiAyOTAgMTAuMiA2LjYgMi0zLTEtMi43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDExZTM0IiBkPSJtNDc1LjIgMjg5LjkgMTAuMiA2LjVoLjFsMS43LTNzMC0uMy0uMy0uN2wt'
    b'LjYtMS43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyMDM3IiBkPSJNNDc1LjIgMjg5'
    b'LjljMi45IDEuOSA0LjEgMi43IDEwLjIgNi40bC4xLS4xIDEuNi0yLjktLjItLjdhMTguMSAx'
    b'OC4xIDAgMCAxLS42LTEuNiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjEzOSIgZD0i'
    b'TTQ3NS4yIDI4OS45YzIuOCAxLjggNC4zIDIuOCAxMC4yIDYuM2wuMS0uMSAxLjUtMi45LS4y'
    b'LS43LS41LTEuNSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjIzYiIgZD0iTTQ3NS4y'
    b'IDI4OS44YzIuNyAxLjggNC41IDIuOSAxMC4yIDYuM2wuMS0uMiAxLjQtMi44LS4xLS43YTgu'
    b'MiA4LjIgMCAwIDEtLjUtMS40Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyMzNkIiBk'
    b'PSJNNDc1LjMgMjg5LjhjMi41IDEuNyA0LjYgMyAxMC4xIDYuMWguMWMwLS4zIDEuMy0yLjkg'
    b'MS4zLTNsLS4xLS41YTkuNiA5LjYgMCAwIDEtLjQtMS41Ii8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlPSIjMDIyNTQwIiBkPSJNNDc1LjMgMjg5LjhjMi40IDEuNiA0LjcgMyAxMC4yIDZ2LS4x'
    b'bDEuMi0yLjh2LS42YTUgNSAwIDAgMS0uNC0xLjMiLz4KICAgICAgICA8cGF0aCBzdHJva2U9'
    b'IiMwMjI1NDEiIGQ9Ik00NzUuMyAyODkuOGMyLjMgMS42IDUgMyAxMC4yIDUuOXYtLjJsMS4x'
    b'LTIuOHYtLjVhNC44IDQuOCAwIDAgMS0uNC0xLjMiLz4KICAgICAgICA8cGF0aCBzdHJva2U9'
    b'IiMwMjI3NDMiIGQ9Ik00NzUuMyAyODkuOGExMTAgMTEwIDAgMCAwIDEwLjIgNS44di0uMmwx'
    b'LTIuOHYtLjVhNC4xIDQuMSAwIDAgMS0uMy0xLjIiLz4KICAgICAgICA8cGF0aCBzdHJva2U9'
    b'IiMwMjI4NDciIGQ9Ik00NzUuMyAyODkuN2E5Mi42IDkyLjYgMCAwIDAgMTAuMiA1Ljh2LS4y'
    b'YzAtLjMgMS0yLjggMS0yLjh2LS41Yy0uMy0uMy0uMy0uNy0uMy0xIi8+CiAgICAgICAgPHBh'
    b'dGggc3Ryb2tlPSIjMDIyYTQ5IiBkPSJNNDc1LjMgMjg5LjdhODAuNSA4MC41IDAgMCAwIDEw'
    b'LjIgNS42LjMuMyAwIDAgMCAwLS4xYzAtLjQuOC0yLjguOC0yLjhzLjItLjEgMC0uNHYtMSIv'
    b'PgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAzMmE0YSIgZD0iTTQ3NS4zIDI4OS43YTgwIDgw'
    b'IDAgMCAwIDEwLjIgNS41di0uMmwuNy0yLjdzLjItLjEgMC0uNHYtMSIvPgogICAgICAgIDxw'
    b'YXRoIHN0cm9rZT0iIzAzMmI0YyIgZD0iTTQ3NS40IDI4OS43YTY3LjggNjcuOCAwIDAgMCAx'
    b'MCA1LjRsLjItLjIuNS0yLjdzLjItLjEuMS0uNGMtLjEtLjMgMC0uNSAwLS44Ii8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjMDMyZDRmIiBkPSJNNDc1LjQgMjg5LjdhNjIuNCA2Mi40IDAg'
    b'MCAwIDEwIDUuM2wuMi0uMi40LTIuOHMuMyAwIC4yLS4zYy0uMi0uMyAwLS40IDAtLjciLz4K'
    b'ICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJlNTAiIGQ9Ik00NzUuNCAyODkuN2MxLjcgMSA2'
    b'IDMuNiAxMC4xIDUuMnYtLjJsLjQtMi43cy4zIDAgLjItLjNjLS4xLS4zIDAtLjMuMS0uNyIv'
    b'PgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAzMmY1MyIgZD0iTTQ3NS40IDI4OS42YTU0LjMg'
    b'NTQuMyAwIDAgMCAxMC4xIDUuMS41LjUgMCAwIDAgMC0uMmwuMy0yLjcuMi0uMmMtLjEtLjMg'
    b'MC0uMy4yLS42Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMzMTU2IiBkPSJNNDc1LjQg'
    b'Mjg5LjZjMS41IDEgNi4zIDMuOCAxMC4xIDVhLjUuNSAwIDAgMCAwLS4ybC4yLTIuN3MuNCAw'
    b'IC4zLS4yYy0uMi0uMyAwLS4yLjEtLjYiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDMy'
    b'NTgiIGQ9Ik00NzUuNCAyODkuNmE0NSA0NSAwIDAgMCAxMC4xIDQuOWwuMS0uMnYtMi43cy40'
    b'IDAgLjMtLjJjLS4xLS4yLjEtLjEuMy0uNCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0'
    b'MzM1OSIgZD0iTTQ3NS40IDI4OS42YzEuMy45IDYuNyA0IDEwLjEgNC43bC4xLS4yLS4xLTIu'
    b'NnMuNCAwIC4zLS4xYzAtLjMuMi0uMS4zLS40Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDQzNTVjIiBkPSJNNDc1LjQgMjg5LjZjMS4yLjggNi44IDQgMTAuMSA0LjZsLjEtLjItLjMt'
    b'Mi42LjUtLjFjLS4xLS4zLjIgMCAuMy0uNCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0'
    b'MzY1ZSIgZD0iTTQ3NS40IDI4OS42YzEuMS43IDcgNCAxMC4xIDQuNWwuMS0uMmMwLS43LS4z'
    b'LTIuNi0uNC0yLjZoLjVjMC0uMy4yIDAgLjQtLjMiLz4KICAgICAgICA8cGF0aCBzdHJva2U9'
    b'IiMwNDM3NjAiIGQ9Ik00NzUuNCAyODkuNmMxIC42IDcuMiA0LjEgMTAuMSA0LjRsLjEtLjNj'
    b'MC0uNi0uNC0yLjUtLjUtMi42IDAgMCAuNi4yLjUgMCAwLS4xLjMuMi41LS4xIi8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjMDQzODYyIiBkPSJNNDc1LjQgMjg5LjZjMSAuNSA3LjMgNC4y'
    b'IDEwLjEgNC4zbC4yLS4zYTEyLjUgMTIuNSAwIDAgMC0uNy0yLjZzLjYuMi41IDBjMC0uMS40'
    b'LjMuNiAwIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzYTY1IiBkPSJNNDc1LjUgMjg5'
    b'LjVjLjguNSA3LjQgNC4zIDEwIDQuMmwuMi0uMmMwLS44LS43LTIuNi0uOC0yLjZzLjYuMi42'
    b'IDBjMCAwIC4zLjQuNiAwIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzYjY3IiBkPSJN'
    b'NDc1LjUgMjg5LjVjLjcuNSA3LjYgNC40IDEwIDQuMWwuMi0uM2MwLS43LS44LTIuNC0uOS0y'
    b'LjVsLjYuMWMwLS4xLjUuMy43IDAiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNTNjNjgi'
    b'IGQ9Ik00NzUuNSAyODkuNWMuNi40IDcuOCA0LjQgMTAgNGwuMi0uM2E2IDYgMCAwIDAtMS0y'
    b'LjVsLjcuMWMwLS4xLjQuNC43LjEiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNTNlNmMi'
    b'IGQ9Ik00NzUuNSAyODkuNWMuNS4zIDggNC41IDEwIDMuOWEuNS41IDAgMCAwIC4yLS4zYzAt'
    b'LjgtMS0yLjUtMS4xLTIuNWwuNy4xcy41LjYuOC4zIi8+CiAgICAgICAgPHBhdGggc3Ryb2tl'
    b'PSIjMDUzZjZlIiBkPSJNNDc1LjUgMjg5LjVjLjQuMiA4IDQuNiAxMCAzLjhsLjItLjRjMC0u'
    b'OC0xLjEtMi40LTEuMi0yLjVsLjcuM3MuNi42LjkuMiIvPgogICAgICAgIDxwYXRoIHN0cm9r'
    b'ZT0iIzA1M2Y2ZiIgZD0iTTQ3NS41IDI4OS41Yy4zLjIgOC4yIDQuNiAxMCAzLjZsLjItLjNj'
    b'MC0uOS0xLjItMi40LTEuMy0yLjVsLjcuM3MuNi42IDEgLjQiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwNjQxNzEiIGQ9Ik00NzUuNSAyODkuNGMuMi4yIDguNCA0LjggMTAgMy42YS43'
    b'LjcgMCAwIDAgLjItLjNjMC0xLTEuMy0yLjQtMS40LTIuNWwuOC4zcy42LjcgMSAuNCIvPgog'
    b'ICAgICAgIDxwYXRoIHN0cm9rZT0iIzA2NDM3NCIgZD0iTTQ3NS41IDI4OS40Yy4xIDAgOC42'
    b'IDQuOSAxMCAzLjVsLjItLjNjMC0xLTEuNC0yLjQtMS42LTIuNWwxIC4zcy42LjggMSAuNiIv'
    b'PgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAwMjA5ZiIgZD0iTTQ3NS42IDI4OS40czkuNyA1'
    b'LjUgMTAuMSAzYzAtMS0xLjYtMi40LTEuNi0yLjRsLjkuM3MuNiAxIDEgLjYiLz4KICAgICAg'
    b'ICA8cGF0aCBzdHJva2U9IiMwMTFkMzMiIGQ9Im00NzQuNCAzMTUuMS03LjUgMTIuNmE1LjIg'
    b'NS4yIDAgMCAxLTEuOC0yLjJjLS42LTEuNy0uNS0xLjctMS0zLjZsLS40LTMuNGMtLjMtMS4y'
    b'LTEuOS00LjgtMi02LjIiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMTFkMzMiIGQ9Ik00'
    b'NjEuOCAzMTIuM2MwIDEuNCAxLjYgNSAxLjkgNiAuMiAxLjIuMiAyLjQuNSAzLjUuNCAxLjku'
    b'MyAxLjggMSAzLjZhNS4yIDUuMiAwIDAgMCAxLjcgMi4ybDcuNS0xMi41Ii8+CiAgICAgICAg'
    b'PHBhdGggc3Ryb2tlPSIjMDExZTM0IiBkPSJNNDYxLjggMzEyLjNjMCAxLjQgMS42IDUgMS44'
    b'IDYgLjMgMS4yLjMgMi4zLjYgMy40LjQgMS44LjMgMS44IDEgMy42LjIuOCAxLjIgMS44IDEu'
    b'NyAyLjFsNy41LTEyLjMiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMTFlMzQiIGQ9Ik00'
    b'NjEuOCAzMTIuM2MwIDEuNCAxLjYgNC45IDEuOCA2IC4zIDEgLjMgMi4yLjYgMy4zLjQgMS44'
    b'LjMgMS44IDEgMy41YTUuNSA1LjUgMCAwIDAgMS43IDIuMmw3LjUtMTIuMiIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZT0iIzAxMWYzNiIgZD0iTTQ2MS44IDMxMi4zYzAgMS4zIDEuNiA0Ljgg'
    b'MS44IDUuOS4zIDEuMS4zIDIuMy42IDMuMy40IDEuOC4zIDEuOCAxIDMuNWE1LjUgNS41IDAg'
    b'MCAwIDEuNyAyLjFsNy41LTEyIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDExZjM2IiBk'
    b'PSJNNDYxLjggMzEyLjNjMCAxLjMgMS42IDQuOCAxLjggNS45LjMgMSAuMyAyLjIuNiAzLjMu'
    b'NCAxLjcuMyAxLjcgMSAzLjQuMi44IDEuMiAxLjggMS43IDIuMWw3LjUtMTEuOSIvPgogICAg'
    b'ICAgIDxwYXRoIHN0cm9rZT0iIzAyMjAzNyIgZD0iTTQ2MS44IDMxMi4zYzAgMS4zIDEuNSA0'
    b'LjcgMS44IDUuOC4zIDEgLjMgMi4yLjYgMy4zLjQgMS43LjMgMS43IDEgMy40LjIuOCAxLjIg'
    b'MS43IDEuNyAyIC4yLjEgNy40LTExLjYgNy41LTExLjciLz4KICAgICAgICA8cGF0aCBzdHJv'
    b'a2U9IiMwMjIwMzciIGQ9Ik00NjEuOCAzMTIuM2MwIDEuMyAxLjUgNC42IDEuOCA1LjdsLjYg'
    b'My4zYy40IDEuNy40IDEuNyAxIDMuMy4yLjggMS4yIDEuOCAxLjcgMi4xLjIgMCA3LjMtMTEu'
    b'NSA3LjUtMTEuNiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjEzOSIgZD0iTTQ2MS44'
    b'IDMxMi4zYzAgMS4zIDEuNSA0LjYgMS44IDUuNy4zIDEgLjMgMi4yLjYgMy4yLjQgMS43LjQg'
    b'MS43IDEgMy4zLjMuOCAxLjIgMS43IDEuNyAyIC4yLjEgNy4zLTExLjMgNy41LTExLjQiLz4K'
    b'ICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjIxMzkiIGQ9Ik00NjEuOCAzMTIuM2MwIDEuMyAx'
    b'LjUgNC42IDEuOCA1LjYuMyAxIC4zIDIuMi42IDMuMi40IDEuNy40IDEuNyAxIDMuM2E1LjQg'
    b'NS40IDAgMCAwIDEuNyAyYy4zIDAgNy4zLTExLjIgNy41LTExLjMiLz4KICAgICAgICA8cGF0'
    b'aCBzdHJva2U9IiMwMjIxMzkiIGQ9Ik00NjEuOCAzMTIuM2MwIDEuMyAxLjUgNC41IDEuOCA1'
    b'LjYuMyAxIC4zIDIgLjYgMy4xLjUgMS43LjQgMS43IDEgMy4zLjMuOCAxLjIgMS43IDEuNyAy'
    b'IC4zIDAgNy4yLTExIDcuNS0xMS4yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyMjNi'
    b'IiBkPSJNNDYxLjggMzEyLjNjMCAxLjMgMS41IDQuNCAxLjggNS41LjMgMSAuMyAyLjEuNiAz'
    b'IC41IDEuOC40IDEuOCAxIDMuM2E1IDUgMCAwIDAgMS43IDJjLjMuMSA3LjItMTAuOSA3LjUt'
    b'MTEiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjIyM2IiIGQ9Ik00NjEuOCAzMTIuM2Mw'
    b'IDEuMiAxLjUgNC40IDEuOCA1LjQuMyAxIC4zIDIuMi42IDMuMS41IDEuNy40IDEuNyAxIDMu'
    b'MmE1LjIgNS4yIDAgMCAwIDEuNyAyYy4zLjEgNy4yLTEwLjggNy41LTEwLjkiLz4KICAgICAg'
    b'ICA8cGF0aCBzdHJva2U9IiMwMjIzM2QiIGQ9Ik00NjEuOCAzMTIuM2MwIDEuMiAxLjUgNC4z'
    b'IDEuOCA1LjRsLjYgM2MuNSAxLjcuNCAxLjcgMSAzLjJhNS4xIDUuMSAwIDAgMCAxLjggMmMu'
    b'MyAwIDctMTAuNiA3LjQtMTAuOCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjMzZCIg'
    b'ZD0iTTQ2MS44IDMxMi4zYzAgMS4yIDEuNCA0LjMgMS44IDUuM2wuNiAzIDEgMy4yYTcgNyAw'
    b'IDAgMCAxLjggMmMuMyAwIDctMTAuNiA3LjQtMTAuNyIvPgogICAgICAgIDxwYXRoIHN0cm9r'
    b'ZT0iIzAyMjMzZSIgZD0iTTQ2MS44IDMxMi4zYzAgMS4yIDEuNCA0LjMgMS44IDUuM2wuNiAz'
    b'IDEgM2E2IDYgMCAwIDAgMS44IDJjLjMuMSA3LTEwLjMgNy40LTEwLjUiLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2U9IiMwMjIzM2UiIGQ9Ik00NjEuOCAzMTIuM2MwIDEuMSAxLjQgNC4yIDEu'
    b'OCA1LjJsLjYgMyAxIDNhNSA1IDAgMCAwIDEuOCAyYy40IDAgNy0xMC4zIDcuNC0xMC40Ii8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyNTQwIiBkPSJNNDYxLjggMzEyLjJjMCAxLjIg'
    b'MS40IDQuMiAxLjggNS4zbC42IDIuOSAxIDNhNS4yIDUuMiAwIDAgMCAxLjggMmMuNCAwIDct'
    b'MTAuMSA3LjQtMTAuMyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjU0MCIgZD0iTTQ2'
    b'MS44IDMxMi4yYzAgMS4yIDEuNCA0LjIgMS44IDUuMmwuNiAyLjkgMSAzYy40LjcgMS4zIDEu'
    b'NSAxLjggMS44LjQuMiA3LTkuOCA3LjQtMTAiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMw'
    b'MjI1NDAiIGQ9Ik00NjEuOCAzMTIuMmMwIDEuMiAxLjQgNC4xIDEuOCA1LjFsLjcgMi45Yy40'
    b'IDEuNS40IDEuNiAxIDNhNSA1IDAgMCAwIDEuNyAxLjhjLjQuMSA3LTkuNyA3LjQtOS45Ii8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyNTQxIiBkPSJNNDYxLjggMzEyLjJjMCAxLjIg'
    b'MS40IDQgMS44IDVsLjcgMyAxIDIuOWE1LjIgNS4yIDAgMCAwIDEuNyAxLjhjLjQuMSA2Ljkt'
    b'OS42IDcuNC05LjgiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjI1NDEiIGQ9Ik00NjEu'
    b'OCAzMTIuMmMwIDEuMSAxLjQgNCAxLjggNWwuNyAyLjggMSAzYy4zLjYgMS4yIDEuNSAxLjcg'
    b'MS44LjUgMCA2LjktOS41IDcuNC05LjciLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjI3'
    b'NDMiIGQ9Ik00NjEuOCAzMTIuMmMwIDEuMSAxLjQgNCAxLjggNWwuNyAyLjdjLjQgMS41LjUg'
    b'MS41IDEgMi45YTYgNiAwIDAgMCAxLjcgMS44Yy41LjEgNi44LTkuMyA3LjQtOS41Ii8+CiAg'
    b'ICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyNzQzIiBkPSJNNDYxLjggMzEyLjJjMCAxLjEgMS40'
    b'IDQgMS44IDVsLjcgMi42IDEgM2E1IDUgMCAwIDAgMS43IDEuNmMuNS4yIDYuOC05IDcuNC05'
    b'LjMiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjI4NDUiIGQ9Ik00NjEuOCAzMTIuMmMw'
    b'IDEuMSAxLjQgMy45IDEuOCA0LjhsLjcgMi44IDEgMi44YTQuOSA0LjkgMCAwIDAgMS43IDEu'
    b'N2MuNi4yIDYuOC05IDcuNC05LjIiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjI4NDUi'
    b'IGQ9Ik00NjEuOCAzMTIuMmMwIDEuMSAxLjQgMy44IDEuOCA0LjhsLjcgMi43Yy40IDEuNC41'
    b'IDEuNCAxIDIuN2E1LjMgNS4zIDAgMCAwIDEuNyAxLjhjLjYuMiA2LjctOC45IDcuNC05Ii8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyODQ3IiBkPSJNNDYxLjggMzEyLjJjMCAxIDEu'
    b'MyAzLjcgMS44IDQuN2wuNyAyLjcgMSAyLjdhNC44IDQuOCAwIDAgMCAxLjcgMS43Yy42LjIg'
    b'Ni43LTguNyA3LjQtOC45Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyODQ3IiBkPSJN'
    b'NDYxLjggMzEyLjJjMCAxIDEuMyAzLjcgMS44IDQuNmwuNyAyLjcgMS4xIDIuN2E1IDUgMCAw'
    b'IDAgMS42IDEuN2MuNy4yIDYuNy04LjYgNy40LTguOCIvPgogICAgICAgIDxwYXRoIHN0cm9r'
    b'ZT0iIzAyMjg0NyIgZD0iTTQ2MS44IDMxMi4yYzAgMSAxLjMgMy43IDEuOCA0LjZsLjcgMi42'
    b'IDEuMSAyLjdhNSA1IDAgMCAwIDEuNiAxLjdjLjcuMSA2LjctOC40IDcuNC04LjciLz4KICAg'
    b'ICAgICA8cGF0aCBzdHJva2U9IiMwMjJhNDkiIGQ9Ik00NjEuOCAzMTIuMmMwIDEgMS4zIDMu'
    b'NiAxLjggNC42bC43IDIuNSAxLjEgMi43Yy40LjYgMS4xIDEuMyAxLjcgMS42LjYuMiA2LjYt'
    b'OC4yIDcuMy04LjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMjJhNDkiIGQ9Ik00NjEu'
    b'OCAzMTIuMmMwIDEgMS4zIDMuNSAxLjggNC41bC43IDIuNSAxLjEgMi42Yy40LjYgMS4xIDEu'
    b'NCAxLjcgMS42LjcuMyA2LjUtOCA3LjMtOC4zIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDMyYTRhIiBkPSJNNDYxLjggMzEyLjJjMCAxIDEuMyAzLjUgMS44IDQuNGwuNyAyLjVjLjUg'
    b'MS4zLjUgMS40IDEuMiAyLjYuMy42IDEgMS40IDEuNiAxLjYuNy4yIDYuNS04IDcuMy04LjIi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJhNGEiIGQ9Ik00NjEuOCAzMTIuMmMwIDEg'
    b'MS4zIDMuNCAxLjcgNC40bC44IDIuNCAxLjIgMi42YTUgNSAwIDAgMCAxLjYgMS42Yy43LjIg'
    b'Ni41LTcuOCA3LjMtOC4xIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyYjRjIiBkPSJN'
    b'NDYxLjggMzEyLjJjMCAxIDEuMiAzLjQgMS43IDQuMy40LjguNSAxLjcuOCAyLjRsMS4yIDIu'
    b'NmMuMy42IDEgMS4yIDEuNiAxLjUuNy4zIDYuNC03LjYgNy4zLTgiLz4KICAgICAgICA8cGF0'
    b'aCBzdHJva2U9IiMwMzJiNGMiIGQ9Ik00NjEuOCAzMTIuMmMwIDEgMS4yIDMuMyAxLjcgNC4z'
    b'LjQuNy41IDEuNi44IDIuM2wxLjIgMi42Yy4zLjUgMSAxLjIgMS42IDEuNS44LjIgNi40LTcu'
    b'NSA3LjMtNy44Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyYzRkIiBkPSJNNDYxLjgg'
    b'MzEyLjJjMCAxIDEuMiAzLjMgMS43IDQuMi40LjguNSAxLjYuOCAyLjRsMS4yIDIuNGMuMy42'
    b'IDEgMS4zIDEuNiAxLjYuOC4yIDYuNC03LjQgNy4zLTcuNyIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzAzMmM0ZCIgZD0iTTQ2MS44IDMxMi4yYzAgLjkgMS4yIDMuMiAxLjcgNC4xbC45'
    b'IDIuNGMuNCAxLjIuNSAxLjMgMS4xIDIuNGE1LjIgNS4yIDAgMCAwIDEuNiAxLjVjLjguMyA2'
    b'LjMtNy4yIDcuMy03LjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJjNGQiIGQ9Ik00'
    b'NjEuOCAzMTIuMmExMyAxMyAwIDAgMCAxLjcgNGwuOSAyLjRjLjQgMS4yLjUgMS4yIDEuMSAy'
    b'LjRhNC43IDQuNyAwIDAgMCAxLjYgMS40Yy45LjQgNi4zLTcgNy4zLTcuMyIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZT0iIzAzMmQ0ZiIgZD0iTTQ2MS44IDMxMi4yYzAgLjkgMS4yIDMuMSAx'
    b'LjcgNCAuNC44LjUgMS42LjkgMi4zLjQgMS4yLjUgMS4zIDEuMSAyLjMuMy42IDEgMS4zIDEu'
    b'NiAxLjUuOS4zIDYuMy02LjggNy4zLTcuMiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAz'
    b'MmQ0ZiIgZD0iTTQ2MS44IDMxMi4yYzAgLjggMS4yIDMgMS43IDQgLjQuNy41IDEuNS45IDIu'
    b'Mi40IDEuMi42IDEuMiAxLjEgMi40YTUgNSAwIDAgMCAxLjYgMS40YzEgLjMgNi4zLTYuNyA3'
    b'LjMtNy4xIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyZTUwIiBkPSJNNDYxLjggMzEy'
    b'LjJjMCAuOCAxLjIgMyAxLjcgNCAuNC42LjUgMS40LjkgMi4xLjQgMS4yLjYgMS4yIDEuMSAy'
    b'LjNhNS40IDUuNCAwIDAgMCAxLjYgMS41YzEgLjIgNi4zLTYuNiA3LjMtNyIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZT0iIzAzMmU1MCIgZD0iTTQ2MS44IDMxMi4yYzAgLjggMS4xIDMgMS43'
    b'IDMuOC40LjguNSAxLjUuOSAyLjIuNCAxLjIuNiAxLjMgMS4xIDIuM2E0LjggNC44IDAgMCAw'
    b'IDEuNiAxLjRjMSAuMyA2LjItNi40IDcuMy02LjgiLz4KICAgICAgICA8cGF0aCBzdHJva2U9'
    b'IiMwMzJmNTMiIGQ9Ik00NjEuOCAzMTIuMmMwIC44IDEuMSAzIDEuNyAzLjguNC43LjUgMS41'
    b'LjkgMi4xLjQgMS4xLjYgMS4yIDEuMiAyLjNhNSA1IDAgMCAwIDEuNSAxLjRjMSAuMyA2LjIt'
    b'Ni4zIDcuMy02LjciLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJmNTMiIGQ9Ik00NjEu'
    b'OCAzMTIuMmExMSAxMSAwIDAgMCAxLjcgMy43Yy40LjcuNSAxLjUuOSAyLjJsMS4yIDIuMWE1'
    b'IDUgMCAwIDAgMS41IDEuNGMxIC4zIDYuMi02IDcuMy02LjUiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwMzMwNTQiIGQ9Ik00NjEuOCAzMTIuMmExMiAxMiAwIDAgMCAxLjcgMy43Yy40'
    b'LjYuNSAxLjQuOSAybDEuMiAyLjJhNS4xIDUuMSAwIDAgMCAxLjYgMS40YzEgLjMgNi02IDcu'
    b'Mi02LjQiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzMwNTQiIGQ9Ik00NjEuOCAzMTIu'
    b'MmMwIC43IDEgMi43IDEuNyAzLjYuNC43LjUgMS40IDEgMmwxIDIuMmE0LjUgNC41IDAgMCAw'
    b'IDEuNyAxLjNjMSAuNCA2LTUuOCA3LjItNi4yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDMzMDU0IiBkPSJNNDYxLjggMzEyLjJjMCAuNyAxIDIuNyAxLjcgMy42bDEgMmMuNCAxIC42'
    b'IDEuMSAxLjEgMmE1LjQgNS40IDAgMCAwIDEuNiAxLjRjMSAuMyA2LTUuNyA3LjItNi4xIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMzMTU2IiBkPSJNNDYxLjggMzEyLjJjMCAuNyAx'
    b'IDIuNyAxLjcgMy41bDEgMmMuMyAxIC42IDEuMSAxLjEgMmE1LjQgNS40IDAgMCAwIDEuNSAx'
    b'LjRjMS4xLjMgNi01LjYgNy4zLTYiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzMxNTYi'
    b'IGQ9Ik00NjEuOCAzMTIuMmMwIC43IDEgMi42IDEuNyAzLjRsMSAyYy4zIDEgLjYgMS4xIDEu'
    b'MSAyYTUuNCA1LjQgMCAwIDAgMS41IDEuM2MxLjIuMyA2LTUuMyA3LjMtNS44Ii8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjMDQzMjU4IiBkPSJNNDYxLjggMzEyLjJjMCAuNyAxIDIuNiAx'
    b'LjcgMy40bDEgMS45Yy4zIDEgLjYgMSAxLjIgMiAuMy41IDEgMSAxLjQgMS4zIDEuMi4zIDYt'
    b'NS4yIDcuMy01LjciLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDMyNTgiIGQ9Ik00NjEu'
    b'OCAzMTIuMmE4IDggMCAwIDAgMS43IDMuM2wxIDJjLjMuOS42IDEgMS4yIDIgLjMuNCAxIDEg'
    b'MS40IDEuMSAxLjIuNCA2LTUgNy4zLTUuNSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0'
    b'MzM1OSIgZD0iTTQ2MS44IDMxMi4yYzAgLjYgMSAyLjQgMS43IDMuM2wxIDEuOGMuNCAxIC42'
    b'IDEuMSAxLjIgMiAuMy41IDEgMSAxLjQgMS4yIDEuMy4zIDYtNSA3LjMtNS40Ii8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjMDQzMzU5IiBkPSJNNDYxLjggMzEyLjJjMCAuNiAxIDIuNCAx'
    b'LjcgMy4ybDEgMS45Yy40LjguNiAxIDEuMiAxLjguNC41IDEgMSAxLjUgMS4yIDEuMi40IDUu'
    b'OC00LjcgNy4yLTUuMiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0MzQ1YiIgZD0iTTQ2'
    b'MS44IDMxMi4yYzAgLjYgMSAyLjQgMS43IDMuMWwxIDEuOWMuNC45LjcgMSAxLjIgMS44LjQu'
    b'NSAxIDEgMS41IDEuMiAxLjIuNCA1LjgtNC42IDcuMi01LjEiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwNDM0NWIiIGQ9Ik00NjEuOCAzMTIuMmMwIC42IDEgMi4zIDEuNyAzbDEgMS45'
    b'Yy40LjguNyAxIDEuMiAxLjguNC41IDEgMSAxLjUgMS4yIDEuMy40IDUuOC00LjUgNy4yLTUi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDM0NWIiIGQ9Ik00NjEuOCAzMTIuMmMwIC42'
    b'IDEgMi4yIDEuNyAzbDEgMS44Yy40LjkuNyAxIDEuMiAxLjguNC40IDEgMSAxLjUgMS4xIDEu'
    b'My40IDUuOC00LjMgNy4yLTQuOCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0MzU1YyIg'
    b'ZD0iTTQ2MS44IDMxMi4yYzAgLjUgMSAyLjIgMS43IDNsMSAxLjdjLjQuOC43IDEgMS4yIDEu'
    b'OC40LjQgMSAuOSAxLjUgMSAxLjMuNSA1LjctNC4xIDcuMi00LjYiLz4KICAgICAgICA8cGF0'
    b'aCBzdHJva2U9IiMwNDM1NWMiIGQ9Ik00NjEuOCAzMTIuMmMwIC41IDEgMi4xIDEuNyAzbDEg'
    b'MS42Yy40LjguNyAxIDEuMyAxLjcuMy41IDEgMSAxLjQgMS4xIDEuMy41IDUuNy00IDcuMi00'
    b'LjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDM2NWUiIGQ9Ik00NjEuOCAzMTIuMmMw'
    b'IC41IDEgMi4xIDEuNyAyLjlsMSAxLjZjLjQuOS43IDEgMS4zIDEuNy4zLjUgMSAuOSAxLjQg'
    b'MS4xIDEuNC40IDUuNy0zLjkgNy4yLTQuNCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0'
    b'MzY1ZSIgZD0iTTQ2MS44IDMxMi4yYzAgLjUgMSAyIDEuNyAyLjhsMSAxLjZjLjQuOC43IDEg'
    b'MS4zIDEuNy4zLjQgMSAuOSAxLjQgMSAxLjQuNSA1LjYtMy43IDcuMi00LjIiLz4KICAgICAg'
    b'ICA8cGF0aCBzdHJva2U9IiMwNDM3NjAiIGQ9Ik00NjEuOCAzMTIuMmMwIC41IDEgMiAxLjcg'
    b'Mi44bDEgMS41Yy40LjguNyAxIDEuMyAxLjcuMy40IDEgLjggMS40IDEgMS40LjQgNS42LTMu'
    b'NiA3LjItNC4xIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDQzNzYwIiBkPSJNNDYxLjgg'
    b'MzEyLjJjMCAuNSAxIDIgMS43IDIuN2wxIDEuNmMuNC43LjcuOCAxLjMgMS42LjMuNCAxIC44'
    b'IDEuNCAxIDEuNS40IDUuNi0zLjUgNy4yLTQiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMw'
    b'NDM4NjIiIGQ9Ik00NjEuOCAzMTIuMmMwIC41IDEgMS45IDEuNyAyLjZsMSAxLjZjLjQuNy43'
    b'LjkgMS4zIDEuNS4zLjQgMSAuOCAxLjQgMSAxLjUuNSA1LjUtMy4zIDcuMi0zLjkiLz4KICAg'
    b'ICAgICA8cGF0aCBzdHJva2U9IiMwNDM4NjIiIGQ9Ik00NjEuOCAzMTIuMmMwIC40IDEgMS44'
    b'IDEuNyAyLjZsMSAxLjVjLjQuNy43LjkgMS4zIDEuNWwxLjQgMWMxLjUuNCA1LjUtMy4yIDcu'
    b'Mi0zLjgiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDM4NjIiIGQ9Ik00NjEuOCAzMTIu'
    b'MmMwIC40LjkgMS44IDEuNyAyLjVsMSAxLjVjLjQuNy44LjggMS4zIDEuNWwxLjQgMWMxLjUu'
    b'NCA1LjUtMyA3LjItMy43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDQzOTYzIiBkPSJN'
    b'NDYxLjggMzEyLjJjMCAuNC45IDEuNyAxLjcgMi40bDEgMS41Yy40LjcuOC44IDEuMyAxLjVs'
    b'MS40LjljMS41LjUgNS41LTIuOCA3LjItMy41Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDQzOTYzIiBkPSJNNDYxLjggMzEyLjJjMCAuNC45IDEuNyAxLjcgMi40bDEgMS40Yy40Ljcu'
    b'OC44IDEuMyAxLjVsMS40LjljMS42LjUgNS41LTIuNyA3LjItMy40Ii8+CiAgICAgICAgPHBh'
    b'dGggc3Ryb2tlPSIjMDUzYTY1IiBkPSJNNDYxLjggMzEyLjJjMCAuNC45IDEuNiAxLjcgMi4z'
    b'bDEgMS40IDEuMyAxLjQgMS40IDFjMS42LjQgNS40LTIuNiA3LjItMy4zIi8+CiAgICAgICAg'
    b'PHBhdGggc3Ryb2tlPSIjMDUzYTY1IiBkPSJNNDYxLjggMzEyLjJjMCAuMy44IDEuNiAxLjcg'
    b'Mi4zbDEgMS4zYy41LjcuOC44IDEuNCAxLjQuMy40LjkuNyAxLjQuOSAxLjYuNSA1LjMtMi40'
    b'IDcuMS0zIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzYjY3IiBkPSJNNDYxLjggMzEy'
    b'LjJjMCAuMy44IDEuNSAxLjcgMi4ybDEgMS4zIDEuNCAxLjRjLjQuMy45LjcgMS40LjggMS42'
    b'LjUgNS4zLTIuMiA3LjEtMi45Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzYjY3IiBk'
    b'PSJNNDYxLjggMzEyLjJjMCAuMy44IDEuNSAxLjcgMi4xLjMuNS42IDEgMSAxLjMuNS43Ljgu'
    b'OCAxLjQgMS40bDEuNC44YzEuNi41IDUuMi0yIDcuMS0yLjgiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwNTNjNjgiIGQ9Ik00NjEuOCAzMTIuMmMwIC4zLjggMS40IDEuNyAyLjFsMSAx'
    b'LjMgMS40IDEuM2MuNC4zLjkuNiAxLjQuNyAxLjcuNiA1LjItMS45IDcuMS0yLjYiLz4KICAg'
    b'ICAgICA8cGF0aCBzdHJva2U9IiMwNTNjNjgiIGQ9Ik00NjEuOCAzMTIuMmMwIC4zLjggMS40'
    b'IDEuNyAybDEgMS4zIDEuNCAxLjIgMS40LjhjMS43LjUgNS4yLTEuOCA3LjEtMi41Ii8+CiAg'
    b'ICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzYzY4IiBkPSJNNDYxLjggMzEyLjJhNiA2IDAgMCAw'
    b'IDEuNyAybDEgMS4yIDEuNCAxLjJhNiA2IDAgMCAwIDEuNC44YzEuNy41IDUuMS0xLjcgNy4x'
    b'LTIuNCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2Q2YSIgZD0iTTQ2MS44IDMxMi4y'
    b'YzAgLjIuOCAxLjIgMS43IDJsMSAxIDEuNCAxLjNhNiA2IDAgMCAwIDEuNC44YzEuOC41IDUu'
    b'MS0xLjUgNy4xLTIuMyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2Q2YSIgZD0iTTQ2'
    b'MS44IDMxMi4yYTYgNiAwIDAgMCAxLjcgMS45bDEgMS4xIDEuNCAxLjEgMS40LjhjMS44LjUg'
    b'NS4xLTEuMyA3LjEtMiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2U2YyIgZD0iTTQ2'
    b'MS44IDMxMi4yYzAgLjIuNyAxLjEgMS43IDEuOGwxIDEuMWMuNS41IDEgLjcgMS41IDEuMWwx'
    b'LjMuOGMxLjguNSA1LjEtMS4yIDcuMS0yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUz'
    b'ZTZjIiBkPSJNNDYxLjggMzEyLjJjMCAuMi43IDEuMSAxLjYgMS44bDEuMSAxYy41LjUgMSAu'
    b'NyAxLjUgMS4xbDEuMy43YzEuOC42IDUtMSA3LjEtMS44Ii8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlPSIjMDUzZjZlIiBkPSJNNDYxLjggMzEyLjJjMCAuMS43IDEgMS42IDEuN2wxLjEgMWMu'
    b'NS41IDEgLjcgMS41IDEgLjQuNC44LjYgMS4zLjggMS44LjYgNS0xIDcuMS0xLjciLz4KICAg'
    b'ICAgICA8cGF0aCBzdHJva2U9IiMwNTNmNmUiIGQ9Ik00NjEuOCAzMTIuMmMwIC4xLjcgMSAx'
    b'LjYgMS42YTE0LjIgMTQuMiAwIDAgMCAxLjIgMWMuNC41LjkuNyAxLjQgMSAuNC4zLjkuNiAx'
    b'LjMuNyAxLjkuNiA1LS43IDcuMS0xLjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNTNm'
    b'NmYiIGQ9Ik00NjEuOCAzMTIuMmMwIC4xLjcgMSAxLjYgMS42bDEuMiAxIDEuNCAxIDEuMy42'
    b'YzIgLjUgNS0uNiA3LjEtMS40Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZjZmIiBk'
    b'PSJNNDYxLjggMzEyLjJjMCAuMS43LjkgMS42IDEuNWwxLjIgMSAxLjQgMSAxLjMuNmMyIC41'
    b'IDUtLjUgNy4xLTEuMyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2Y2ZiIgZD0iTTQ2'
    b'MS44IDMxMi4yYzAgLjEuNy44IDEuNiAxLjVsMS4yLjkgMS40IDEgMS4zLjVjMiAuNiA1LS4z'
    b'IDcuMS0xIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDY0MTcxIiBkPSJNNDYxLjggMzEy'
    b'LjJzLjcuOCAxLjYgMS40bDEuMi45IDEuNS45IDEuMi42YzIgLjYgNC45LS4yIDcuMS0xIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDY0MTcxIiBkPSJtNDYxLjggMzEyLjIgMS42IDEu'
    b'NCAxLjIuOCAxLjUuOSAxLjMuNWMyIC42IDQuOCAwIDctLjgiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwNjQxNzIiIGQ9Ik00NjEuOCAzMTIuMnMuNy43IDEuNiAxLjNsMS4yLjggMS41'
    b'LjggMS4zLjZjMiAuNiA0LjcuMiA3LS43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDY0'
    b'MTcyIiBkPSJNNDYxLjggMzEyLjFjMCAuMS43LjcgMS42IDEuM2wxLjIuOCAxLjUuOCAxLjMu'
    b'NmMyIC42IDQuNy4zIDctLjYiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNjQzNzQiIGQ9'
    b'Ik00NjEuOCAzMTIuMWMwIC4xLjYuNyAxLjYgMS4zbDEuMi43YTEyLjcgMTIuNyAwIDAgMCAy'
    b'LjggMS4zYzIgLjYgNC43LjUgNy0uNCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA2NDM3'
    b'NCIgZD0iTTQ2MS44IDMxMi4xcy42LjYgMS42IDEuMmwxLjIuN2ExNS43IDE1LjcgMCAwIDAg'
    b'Mi44IDEuM2MyIC42IDQuNy42IDctLjMiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMDIw'
    b'OWYiIGQ9Im00NjEuOCAzMTIuMSAxLjYgMS4yIDEuMi43IDEuNS42YTEyIDEyIDAgMCAwIDgu'
    b'My40bS0xMi42LTIuOXM2LjUgNS4xIDEyLjYgMyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0i'
    b'IzAyMjc0MyIgZD0iTTQ2MS42IDI5Mi4yczEuMiA4IDEuNyA5LjNjLjQgMSAzIDUuNiA2Ljkg'
    b'Ni43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyYTQ5IiBkPSJNNDYxLjYgMjkyLjJz'
    b'MS4zIDggMS44IDkuMmMuNSAxIDIuOCA1LjQgNi44IDYuOCIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzAzMmI0YyIgZD0iTTQ2MS42IDI5Mi4xczEuNCA4IDEuOSA5LjJhMTQgMTQgMCAw'
    b'IDAgNi43IDYuOSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAzMmU1MCIgZD0iTTQ2MS42'
    b'IDI5Mi4xczEuNSA4IDIgOS4xYy41IDEgMi41IDUgNi42IDciLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwMzMwNTQiIGQ9Ik00NjEuNiAyOTIuMXMxLjYgNy45IDIgOWExNS4yIDE1LjIg'
    b'MCAwIDAgNi43IDciLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDMzNTkiIGQ9Ik00NjEu'
    b'NiAyOTIuMXMxLjYgNy44IDIuMiA5YTE1LjggMTUuOCAwIDAgMCA2LjUgNyIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZT0iIzA0MzU1YyIgZD0iTTQ2MS42IDI5MnMxLjcgNy44IDIuMyA5Yy41'
    b'IDEuMSAyIDQuMyA2LjQgNyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0Mzc2MCIgZD0i'
    b'TTQ2MS43IDI5MnMxLjcgNy44IDIuMyA5Yy41IDEgMS45IDQgNi4zIDciLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2U9IiMwNTNhNjUiIGQ9Ik00NjEuNyAyOTJzMS44IDcuNyAyLjQgOC45Yy41'
    b'IDEgMS43IDMuOCA2LjIgNy4xIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzYzY4IiBk'
    b'PSJNNDYxLjcgMjkyczEuOSA3LjcgMi41IDguOGMuNiAxLjEgMS42IDMuNSA2LjEgNy4yIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZjZlIiBkPSJNNDYxLjcgMjkyczIgNy42IDIu'
    b'NiA4LjhjLjUgMSAxLjQgMy4yIDYgNy4yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDY0'
    b'MTcyIiBkPSJNNDYxLjggMjkyczIgNy41IDIuNiA4LjdjLjYgMS4xIDEuMyAzIDYgNy4yIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDAyMDlmIiBkPSJNNDYxLjggMjkyczIuMSA3LjUg'
    b'Mi43IDguNmMuNiAxLjEgMS4xIDIuOCA1LjkgNy4zIi8+CiAgICAgICAgPHBhdGggc3Ryb2tl'
    b'PSIjMDIyNzQzIiBkPSJNNDYyIDI4Ny4yczEuMSAxMS40IDkuMyAxNC42Ii8+CiAgICAgICAg'
    b'PHBhdGggc3Ryb2tlPSIjMDIyYTQ5IiBkPSJNNDYyIDI4Ny4yYy4xIDAgLjUgMy43IDIuMiA3'
    b'LjIgMS4zIDIuOCAzLjUgNS45IDcgNy40Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMy'
    b'YjRjIiBkPSJNNDYyLjEgMjg3LjJzLjUgMy44IDIuMiA3LjJhMTUgMTUgMCAwIDAgNyA3LjQi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJlNTAiIGQ9Ik00NjIuMSAyODcuMnMuNyAz'
    b'LjkgMi4zIDcuMWMxLjEgMi4zIDMuMyA1LjcgNi45IDcuNCIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzAzMzA1NCIgZD0iTTQ2Mi4yIDI4Ny4ycy43IDQgMi4zIDdjMSAyLjIgMy4yIDUu'
    b'NyA2LjggNy41Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDQzMzU5IiBkPSJNNDYyLjIg'
    b'Mjg3LjJjMCAuMS44IDQgMi40IDcgMSAyIDMuMSA1LjYgNi43IDcuNSIvPgogICAgICAgIDxw'
    b'YXRoIHN0cm9rZT0iIzA0MzU1YyIgZD0iTTQ2Mi4yIDI4Ny4yYzAgLjEgMSA0LjIgMi41IDdh'
    b'MTggMTggMCAwIDAgNi42IDcuNCIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0Mzc2MCIg'
    b'ZD0iTTQ2Mi4yIDI4Ny4xYzAgLjMgMSA0LjQgMi42IDcgLjggMS41IDMgNS40IDYuNSA3LjUi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNTNhNjUiIGQ9Ik00NjIuMiAyODcuMWEzMCAz'
    b'MCAwIDAgMCAyLjYgNi45Yy44IDEuNCAzIDUuNCA2LjUgNy41Ii8+CiAgICAgICAgPHBhdGgg'
    b'c3Ryb2tlPSIjMDUzYzY4IiBkPSJNNDYyLjMgMjg3LjFjMCAuMyAxLjIgNC41IDIuNiA2Ljgu'
    b'NyAxLjMgMi44IDUuNCA2LjQgNy43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZjZl'
    b'IiBkPSJNNDYyLjMgMjg3LjFhMzAgMzAgMCAwIDAgMi44IDYuOGMuNiAxIDIuNiA1LjIgNi4y'
    b'IDcuNiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA2NDE3MiIgZD0iTTQ2Mi4zIDI4Ny4x'
    b'YTMxIDMxIDAgMCAwIDIuOSA2LjdjLjUuOCAyLjUgNS4yIDYgNy43Ii8+CiAgICAgICAgPHBh'
    b'dGggc3Ryb2tlPSIjMDAyMDlmIiBkPSJNNDYyLjMgMjg3LjFjMCAuMyAxLjYgNC45IDMgNi42'
    b'LjQuNyAyLjQgNS4yIDYgNy44Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyNzQzIiBk'
    b'PSJNNDYyLjIgMjg0czIuNCA5LjIgOSAxMS41Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDIyODQ3IiBkPSJNNDYyLjIgMjg0cy45IDMuMyAzIDYuNGMxLjUgMi4yIDMuNiA0LjIgNiA1'
    b'Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyYTRhIiBkPSJNNDYyLjIgMjg0czEgMy4y'
    b'IDMgNi40YzEuNiAyLjEgMy43IDQuMyA2IDUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMw'
    b'MzJjNGQiIGQ9Ik00NjIuMiAyODRzMSAzLjEgMy4yIDYuM2MxLjUgMi4yIDMuNyA0LjQgNS44'
    b'IDUuMSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAzMmY1MyIgZD0iTTQ2Mi4yIDI4My45'
    b'czEgMy4xIDMuMyA2LjNhMTUgMTUgMCAwIDAgNS43IDUuMiIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzAzMzE1NiIgZD0iTTQ2Mi4yIDI4My45czEgMyAzLjMgNi4yYzEuNyAyLjMgNCA0'
    b'LjcgNS43IDUuMyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0MzM1OSIgZD0iTTQ2Mi4y'
    b'IDI4My44czEgMyAzLjQgNi4yYTE3IDE3IDAgMCAwIDUuNiA1LjQiLz4KICAgICAgICA8cGF0'
    b'aCBzdHJva2U9IiMwNDM1NWMiIGQ9Ik00NjIuMiAyODMuOGEyNy4xIDI3LjEgMCAwIDAgOSAx'
    b'MS42Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDQzNzYwIiBkPSJNNDYyLjMgMjgzLjhz'
    b'MSAyLjkgMy41IDYuMWEyMSAyMSAwIDAgMCA1LjQgNS40Ii8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlPSIjMDQzOTYzIiBkPSJNNDYyLjMgMjgzLjhzMSAyLjggMy41IDZhMjMgMjMgMCAwIDAg'
    b'NS40IDUuNSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2I2NyIgZD0iTTQ2Mi4zIDI4'
    b'My43czEuMSAyLjggMy42IDZhMjggMjggMCAwIDAgNS4zIDUuNiIvPgogICAgICAgIDxwYXRo'
    b'IHN0cm9rZT0iIzA1M2U2YyIgZD0iTTQ2Mi4zIDI4My43czEuMiAyLjcgMy43IDZhMzkgMzkg'
    b'MCAwIDAgNS4yIDUuNiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2Y2ZiIgZD0iTTQ2'
    b'Mi4zIDI4My43czEuMiAyLjcgMy44IDUuOWE0NCA0NCAwIDAgMCA1LjEgNS43Ii8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjMDY0MTcyIiBkPSJNNDYyLjMgMjgzLjZzMS4zIDIuNyAzLjkg'
    b'NmMyIDIuNSA0LjkgNS42IDUgNS43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDAyMDlm'
    b'IiBkPSJNNDYyLjMgMjgzLjZzMS4zIDIuNiAzLjkgNS44YzIuMSAyLjcgNSA1LjkgNSA1Ljlt'
    b'OC43IDEuMyA0LjYuOG0tNC4xIDIuNiA0LTEuNyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0i'
    b'IzA2NDE3MSIgZD0ibTQ3OS45IDI5Ni43IDQuNS43Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tl'
    b'PSIjMDUzZTZjIiBkPSJtNDc5LjkgMjk2LjkgNC42LjUiLz4KICAgICAgICA8cGF0aCBzdHJv'
    b'a2U9IiMwNTNiNjciIGQ9Im00NzkuOSAyOTcgNC42LjQiLz4KICAgICAgICA8cGF0aCBzdHJv'
    b'a2U9IiMwNDM4NjIiIGQ9Im00NzkuOSAyOTcuMiA0LjcuMyIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzA0MzU1YyIgZD0iTTQ3OS45IDI5Ny40aDQuNyIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzA0MzI1OCIgZD0iTTQ4MCAyOTcuNmg0LjYiLz4KICAgICAgICA8cGF0aCBzdHJv'
    b'a2U9IiMwMzJmNTMiIGQ9Im00ODAgMjk3LjcgNC43LS4yIi8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlPSIjMDMyYzRkIiBkPSJtNDgwIDI5Ny45IDQuNy0uMyIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzAyMmE0OSIgZD0ibTQ4MCAyOTggNC44LS41Ii8+CiAgICAgICAgPHBhdGggc3Ry'
    b'b2tlPSIjMDY0MTcxIiBkPSJtNDgwLjMgMjk5LjggNC4yLTEuNiIvPgogICAgICAgIDxwYXRo'
    b'IHN0cm9rZT0iIzA1M2U2YyIgZD0ibTQ4MC4zIDI5OS42IDQuMy0xLjUiLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2U9IiMwNTNiNjciIGQ9Im00ODAuMyAyOTkuNSA0LjMtMS40Ii8+CiAgICAg'
    b'ICAgPHBhdGggc3Ryb2tlPSIjMDQzODYyIiBkPSJtNDgwLjMgMjk5LjMgNC4zLTEuMyIvPgog'
    b'ICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0MzU1YyIgZD0ibTQ4MC4yIDI5OS4xIDQuNS0xLjIi'
    b'Lz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDMyNTgiIGQ9Im00ODAuMiAyOTkgNC41LTEu'
    b'MiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAzMmY1MyIgZD0ibTQ4MC4yIDI5OC43IDQu'
    b'Ni0uOSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAzMmM0ZCIgZD0ibTQ4MC4xIDI5OC42'
    b'IDQuNy0uOSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMmE0OSIgZD0ibTQ4MC4xIDI5'
    b'OC40IDQuNy0uNyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjc0MyIgZD0ibTQ4MCAy'
    b'OTguMiA0LjktLjYiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJiNGMiIGQ9Im00ODQu'
    b'MiAzMzEuNi0yLjYuMi05LjktLjIiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwMzJlNTAi'
    b'IGQ9Im00ODQuMyAzMzEuNi0yLjcuMy05LjgtLjIiLz4KICAgICAgICA8cGF0aCBzdHJva2U9'
    b'IiMwMzMwNTQiIGQ9Im00ODQuMyAzMzEuNi0yLjguNGMtLjUuMS05LjYtLjMtOS42LS4zIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDQzMzU5IiBkPSJtNDg0LjMgMzMxLjctMi44LjVj'
    b'LS43LjEtOS42LS41LTkuNi0uNSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0MzU1YyIg'
    b'ZD0ibTQ4NC4zIDMzMS43LTMgLjZjLS43LjItOS4zLS41LTkuMy0uNSIvPgogICAgICAgIDxw'
    b'YXRoIHN0cm9rZT0iIzA0Mzc2MCIgZD0ibTQ4NC4zIDMzMS43LTMgLjdjLS44LjMtOS4yLS42'
    b'LTkuMi0uNiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2E2NSIgZD0ibTQ4NC40IDMz'
    b'MS44LTMuMS44Yy0xIC4yLTkuMS0uNy05LjEtLjciLz4KICAgICAgICA8cGF0aCBzdHJva2U9'
    b'IiMwNTNjNjgiIGQ9Im00ODQuNCAzMzEuOC0zLjEgMWMtMS4yLjItOS0uOC05LS44Ii8+CiAg'
    b'ICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZjZlIiBkPSJtNDg0LjQgMzMxLjktMy4yIDFjLTEu'
    b'Mi4zLTguOS0uOS04LjktLjkiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNjQxNzIiIGQ9'
    b'Ik00ODQuNCAzMzJzLTEuOC43LTMuMiAxYy0xLjQuMy04LjgtMS04LjgtMSIvPgogICAgICAg'
    b'IDxwYXRoIHN0cm9rZT0iIzAwMjA5ZiIgZD0iTTQ3Mi41IDMzMnM3LjEgMS40IDguNiAxLjFj'
    b'MS41LS4zIDMuMy0xLjEgMy4zLTEuMSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMmE0'
    b'OSIgZD0ibTQ4NiAzMzcgNC44LjcgMi43LS4yIDIuMi0uNSIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzAzMmQ0ZiIgZD0iTTQ4NS44IDMzN3M0LjcuNyA1IC42bDIuNy0uMSAyLS41Ii8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMzMDU0IiBkPSJNNDg1LjUgMzM2LjlzNC45Ljgg'
    b'NS4zLjdsMi42LS4yIDItLjQiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDMzNTkiIGQ9'
    b'Ik00ODUuMyAzMzYuN3M0LjkuOSA1LjYuOGE1Ni45IDU2LjkgMCAwIDEgMi41LS4ybDEuNy0u'
    b'MyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0Mzc2MCIgZD0iTTQ4NSAzMzYuNnM1IDEg'
    b'NS45LjhsMi41LS4yIDEuNS0uMyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2E2NSIg'
    b'ZD0iTTQ4NC44IDMzNi41czUuMSAxIDYuMS44bDIuNC0uMiAxLjQtLjIiLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2U9IiMwNTNkNmEiIGQ9Ik00ODQuNSAzMzYuNHM1LjMgMSA2LjQuOWMuNy0u'
    b'MiAyLS4zIDIuNC0uM2EyNC40IDI0LjQgMCAwIDAgMS4yLS4yIi8+CiAgICAgICAgPHBhdGgg'
    b'c3Ryb2tlPSIjMDY0MTcxIiBkPSJNNDg0LjIgMzM2LjNzNS40IDEuMSA2LjguOWMuNy0uMiAx'
    b'LjctLjMgMi4yLS4zaDEuMSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAyMjc0MyIgZD0i'
    b'bTQ4Ni4zIDMzNy4yIDQuNC42IDIuOS0uMSAyLjQtLjYiLz4KICAgICAgICA8cGF0aCBzdHJv'
    b'a2U9IiMwMDIwOWYiIGQ9Ik00ODQgMzM2LjJzNS41IDEuMiA3IC45YzEuNS0uMyAzLS4zIDMt'
    b'LjNtMTEuOCAwIDQuMy0xLjZjMi42LTEgMy0zLjYgMy0zLjYiLz4KICAgICAgICA8cGF0aCBz'
    b'dHJva2U9IiMwMDIwOWYiIGQ9Im01MDUuNSAzMzYgMy4xLTEuM2MzLjgtMS40IDMuNC0zLjIg'
    b'My40LTMuMiIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2U2YyIgZD0ibTUwNS4yIDMz'
    b'Ni4xIDMuNC0xLjMgMS44LS44Yy41LS4zIDEuMi0xIDEuMy0xLjIuNC0uNS40LTEuMy40LTEu'
    b'MyIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA0Mzg2MiIgZD0ibTUwNSAzMzYuMyAzLjYt'
    b'MS40IDEuOC0uNyAxLjQtMS4yYy4zLS41LjQtMS41LjQtMS41Ii8+CiAgICAgICAgPHBhdGgg'
    b'c3Ryb2tlPSIjMDQzMjU4IiBkPSJtNTA0LjcgMzM2LjUgNC0xLjUgMS42LS43YTYgNiAwIDAg'
    b'MCAxLjUtMS4yYy4yLS4zLjUtMS42LjUtMS42Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDMyYzRkIiBkPSJtNTA0LjQgMzM2LjcgNC4yLTEuNSAxLjctLjcgMS42LTEuMy42LTEuNiIv'
    b'PgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2U2YyIgZD0ibTUwNS41IDMzNi45IDQuNi0x'
    b'LjhjLjgtLjMgMS43LTEgMi0xLjUuNi0uOS45LTIgLjktMiIvPgogICAgICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzA0Mzg2MiIgZD0ibTUwNS4xIDMzNi45IDUtMmMuNi0uMSAxLjctMSAyLTEuNC40'
    b'LS42LjctMiAuNy0yIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDQzMjU4IiBkPSJtNTA0'
    b'LjggMzM2LjkgNS40LTJhOC4xIDguMSAwIDAgMCAxLjktMS40Yy4zLS41LjYtMiAuNi0yIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMyYzRkIiBkPSJtNTA0LjUgMzM2LjkgNS43LTIu'
    b'MSAxLjgtMS40LjctMS44Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDIyNzQzIiBkPSJt'
    b'NTA0LjIgMzM2LjkgNi0yLjMgMS43LTEuMi42LTEuOCIvPgogICAgICAgIDxwYXRoIHN0cm9r'
    b'ZT0iIzAzMmI0YyIgZD0ibTUxMS4zIDMzMS42LTIuOC4yLTEwLjMtLjIiLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2U9IiMwMzJlNTAiIGQ9Im01MTEuMyAzMzEuNi0yLjguMy0xMC4yLS4yIi8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDMzMDU0IiBkPSJtNTExLjMgMzMxLjYtMi45LjRj'
    b'LS41LjEtMTAtLjMtMTAtLjMiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDMzNTkiIGQ9'
    b'Im01MTEuMyAzMzEuNy0zIC41Yy0uNi4xLTkuOC0uNS05LjgtLjUiLz4KICAgICAgICA8cGF0'
    b'aCBzdHJva2U9IiMwNDM1NWMiIGQ9Im01MTEuNCAzMzEuNy0zIC42Yy0uOS4yLTkuOC0uNS05'
    b'LjgtLjUiLz4KICAgICAgICA8cGF0aCBzdHJva2U9IiMwNDM3NjAiIGQ9Im01MTEuNCAzMzEu'
    b'Ny0zLjEuN2MtMSAuMy05LjctLjYtOS43LS42Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIj'
    b'MDUzYTY1IiBkPSJtNTExLjQgMzMxLjgtMy4yLjhjLTEgLjItOS41LS43LTkuNS0uNyIvPgog'
    b'ICAgICAgIDxwYXRoIHN0cm9rZT0iIzA1M2M2OCIgZD0ibTUxMS40IDMzMS44LTMuMyAxYy0x'
    b'LjEuMi05LjMtLjgtOS4zLS44Ii8+CiAgICAgICAgPHBhdGggc3Ryb2tlPSIjMDUzZjZlIiBk'
    b'PSJtNTExLjQgMzMxLjktMy4zIDFjLTEuMy4yLTkuMi0uOS05LjItLjkiLz4KICAgICAgICA8'
    b'cGF0aCBzdHJva2U9IiMwNjQxNzIiIGQ9Ik01MTEuNCAzMzJzLTEuOS43LTMuMyAxYy0xLjUu'
    b'My05LjItMS05LjItMSIvPgogICAgICAgIDxwYXRoIHN0cm9rZT0iIzAwMjA5ZiIgZD0iTTQ5'
    b'OSAzMzJzNy41IDEuNCA5IDEuMWMxLjYtLjMgMy41LTEuMSAzLjUtMS4xIi8+CiAgICAgIDwv'
    b'Zz4KICAgICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2UtbWl0ZXJs'
    b'aW1pdD0iMi42IiBzdHJva2Utd2lkdGg9Ii4yIiBkPSJNNDc1IDI5MGEzNCAzNCAwIDAgMS0u'
    b'Mi0zLjNjMC01LjItLjctOS0uMS0xNC41LjQtNC4yIDEuNS05LjggMS4zLTE0LjQtLjEtMS4z'
    b'LjEtMi42LjItMy45bDIxIDIzLjVNNDY3IDMyNy43YTUuMiA1LjIgMCAwIDEtMS45LTIuMmMt'
    b'LjYtMS43LS40LTEuNy0uOS0zLjYtLjItMS4xLS4yLTIuMy0uNS0zLjQtLjItMS4yLTEuOC00'
    b'LjgtMS45LTYuMi0uMS00LjgtMS43LTgtMS4zLTEzLjEuMy00IDEuMi05LjUuNy0xMy42bC4x'
    b'LTMuNiAyMy42IDE1LjZtMjguNSAzMy45Yy4yLjUtLjMgMS41LS41IDEuOWwtLjUuNmMtLjIu'
    b'Ni0uMi40LS43LjlsLS44LjZjLS40LjMtLjcuNi0xLjEuNy0xLjguMy0yLjUuNy00LjIgMS4x'
    b'LTEuNi41LS44LjQtMiAuN2wtMi40LjctMi40LjZjLTIuOS43LTUuNy41LTguNi4zLTEuMSAw'
    b'LTQtLjctNS0xLjQtMS44LTEuMi01LjctMS43LTcuNC0yLjktLjMtLjItMS40LS43LTEuNi0x'
    b'LTEuNy0xLjMtMy0xLjctNC44LTIuOCIvPgogICAgICA8ZyBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS1taXRlcmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iLjEiPgogICAgICAgIDxwYXRoIGZp'
    b'bGw9IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTQ4NC45IDI5Ny42LjYtLjgtMjQt'
    b'MTUuNi0uNC42em0tMjMuNy0xNi43Yy0uMi0xIDAtMi4xLjctMi4zIDAgMCAuNS0uMS44IDAg'
    b'LjQgMCAuNSAwIC43LjQuMy44LS43IDEuMy0xLjQgMS42LS4yIDAtLjYuMS0uNy4zbC0uMS40'
    b'LjMtLjMgMS43LS43Yy42LS4zLjctMS40LjMtMS43LS40LS40LTEuOC0uMy0yIDAtLjcuNy0u'
    b'OCAxLjctLjYgMi43IDAtLjIuMy0uMS4zLS40eiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNm'
    b'YzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTQ2MC44IDI4MS4zYy0xIDAtMi4xLjQtMi4y'
    b'IDF2LjljMCAuNC4yLjUuNi42LjguMiAxLjItLjggMS40LTEuNiAwLS4xIDAtLjYuMi0uN2wu'
    b'NC0uMi0uMy4zLS41IDEuOWMtLjIuNi0xLjMuOC0xLjYuNC0uNS0uMy0uNi0xLjctLjMtMiAu'
    b'Ny0uNyAxLjctMSAyLjctMS0uMi4xLS4yLjUtLjQuNHoiLz4KICAgICAgICA8cGF0aCBmaWxs'
    b'PSIjZmMwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik00NjAuNiAyODFjLS4zIDAtLjMuNC0u'
    b'MS42IDAgLjIuNS4zLjYuMi40LS4yLjYtLjYuNC0xLS4yLS4zLS42IDAtLjkuMXoiLz4KICAg'
    b'ICAgICA8cGF0aCBmaWxsPSIjZmMwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik00NTUuNiAy'
    b'NzcuOHMyLjUgMSA0LjUgMWMwIDAgLjEgMS44LjUgMi4zIDAgMC0xLjgtLjMtMi42IDAgMCAw'
    b'LTEuMS0yLjQtMi40LTMuM3oiLz4KICAgICAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJNNDU3'
    b'LjYgMjc5czEgLjQgMS44LjRjMCAwIDAgLjguMiAxIDAgMC0uNy0uMi0xIDAgMCAwLS40LTEt'
    b'MS0xLjR6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZjMCIgZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiBkPSJtNDYwLjggMjgyLjkuNi0xLjFjMC0uMiAwIDEgLjQgMSAuNS44LjcgMi4zLjcgMi43'
    b'LS43LjItMS4zLjYtMi4zLjItLjMtLjMgMC0xIDAtMS40LjItLjMuMy0xIC42LTEuNHoiLz4K'
    b'ICAgICAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJNNDYxLjMgMjgyLjJ2LjZjMC0uMi4zLjIu'
    b'My4zLjMuNy41IDEuMS42IDIuNG0tLjctMi4yYy4yIDEgLjQgMSAuNCAyLjR2LS4xbS0uNS0x'
    b'LjQuMiAxLjQtLjMuMiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNmYzAiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgZD0ibTQ5Ny4xIDI3Ny40LjctLjYtMjEuNC0yMy43LS40LjV6Ii8+CiAgICAg'
    b'ICAgPHBhdGggZmlsbD0iI2ZjMCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNNDc2LjYgMjUz'
    b'YzAtLjkuNi0yIDEuMi0ybC45LjFjLjMuMS40LjMuNS42LjEuOS0xIDEuMi0xLjcgMS4zbC0u'
    b'OC4xLS4yLjMuMy0uMWMuNi0uMiAxLjItLjIgMi0uMy41LS4xLjktMS4zLjYtMS42LS4zLS41'
    b'LTEuNi0uOC0yLS41LS44LjUtMSAxLjUtMS4yIDIuNSAwLS4yLjQtLjEuNC0uM3oiLz4KICAg'
    b'ICAgICA8cGF0aCBmaWxsPSIjZmMwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik00NzYuMSAy'
    b'NTMuNGMtLjktLjMtMi4xLS4yLTIuMy41bC0uMi44YzAgLjQgMCAuNS40LjcuNy40IDEuNC0u'
    b'NSAxLjctMS4yIDAtLjIuMi0uNi40LS43aC40bC0uMy4yLTEgMS43Yy0uMi41LTEuNC41LTEu'
    b'NyAwLS4zLS40IDAtMS43LjMtMiAuOC0uNiAxLjgtLjUgMi44LS4yLS4yIDAtLjMuMy0uNS4y'
    b'eiIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNmYzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0i'
    b'TTQ3NiAyNTNjLS4zIDAtLjMuNC0uMy42IDAgLjIuNC40LjYuMy40LS4xLjctLjQuNi0uOC0u'
    b'MS0uNC0uNi0uMi0uOS0uMXoiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjZmMwIiBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGQ9Ik00NzIgMjQ4LjdzMiAxLjYgNCAyYzAgMC0uMyAxLjkgMCAyLjQg'
    b'MCAwLTEuNy0uNy0yLjYtLjUgMCAwLS40LTIuNi0xLjUtNHoiLz4KICAgICAgICA8cGF0aCBm'
    b'aWxsPSJub25lIiBkPSJNNDczLjYgMjUwLjRzLjguNiAxLjYuOXYuOXMtLjctLjMtMS0uMmMw'
    b'IDAtLjItMS0uNi0xLjZ6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZjMCIgZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBkPSJtNDc1LjcgMjU0LjkgMS0xYzAtLjEtLjQgMSAwIDEuMy40LjguMSAy'
    b'LjMgMCAyLjctLjcgMC0xLjMuMy0yLS40LS40LS4zIDAtLjkuMy0xLjMgMC0uMy40LTEgLjct'
    b'MS4zeiIvPgogICAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik00NzYuNCAyNTQuNHYuNWwu'
    b'Mi43djIuMm0tLjMtMi41Yy4yLjkgMCAxLjYtLjEgMi41bTAtMWMtLjIuNC0uMi42LS4yIDFo'
    b'LS4zIi8+CiAgICAgIDwvZz4KICAgIDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3N2LWMi'
    b'IHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAgMCAx'
    b'IDEwMzAgMCkiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iI2ZjMCIgc3Ryb2tlPSIjMDAwIiBz'
    b'dHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtMzE5LjMgMTk3'
    b'LjktNDAuMiA2Ny4zaDgwLjV6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjZmZm'
    b'IiBzdHJva2UtbWl0ZXJsaW1pdD0iMi42IiBzdHJva2Utd2lkdGg9Ii4xIiBkPSJNMzE5LjMg'
    b'MjAyLjMgMjgzIDI2M2g3Mi43eiIvPgogIDxwYXRoIGZpbGw9IiMwMDdlOTMiIHN0cm9rZT0i'
    b'IzAwN2U5MyIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIuMiIgZD0i'
    b'TTI5My44IDI0NSAyODMgMjYzaDcyLjdsLTEwLjktMTh6Ii8+CiAgPGcgZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRoPSIuMSI+CiAgICA8cGF0aCBz'
    b'dHJva2U9IiMwODZhYWQiIGQ9Ik0zMTMgMjEyLjlhOSA5IDAgMCAxIDYuMi0yLjJoLjJjMi4z'
    b'IDAgNC43LjYgNi4zIDIuMiIvPgogICAgPHBhdGggc3Ryb2tlPSIjMDg2M2FhIiBkPSJNMzEz'
    b'IDIxM2E5IDkgMCAwIDEgNi4yLTIuMmguMmMyLjQgMCA0LjguNSA2LjMgMi4yIi8+CiAgICA8'
    b'cGF0aCBzdHJva2U9IiMwOTVmYTgiIGQ9Ik0zMTMgMjEzYTguOCA4LjggMCAwIDEgNi4yLTIu'
    b'MmguMmMyLjQgMCA0LjkuNiA2LjQgMi4zIi8+CiAgICA8cGF0aCBzdHJva2U9IiMwYTU4YTUi'
    b'IGQ9Ik0zMTIuOSAyMTMuMWE4LjcgOC43IDAgMCAxIDYuMy0yLjJoLjJjMi41IDAgNSAuNiA2'
    b'LjUgMi4zIi8+CiAgICA8cGF0aCBzdHJva2U9IiMwYTUyYTIiIGQ9Ik0zMTIuOCAyMTMuMmMx'
    b'LjYtMS43IDQtMi4zIDYuNS0yLjNoLjFjMi42IDAgNSAuNyA2LjUgMi40Ii8+CiAgICA8cGF0'
    b'aCBzdHJva2U9IiMwYjRkOWYiIGQ9Ik0zMTIuOCAyMTMuM2MxLjYtMS43IDQtMi4zIDYuNS0y'
    b'LjNoLjJjMi41IDAgNSAuNiA2LjUgMi40Ii8+CiAgICA8cGF0aCBzdHJva2U9IiMwYzQ3OWQi'
    b'IGQ9Ik0zMTIuNyAyMTMuNGMxLjYtMS44IDQtMi40IDYuNi0yLjRoLjJjMi42IDAgNSAuNyA2'
    b'LjYgMi41Ii8+CiAgICA8cGF0aCBzdHJva2U9IiMyNzBhN2YiIGQ9Ik0zMTIuMyAyMTRjMS45'
    b'LTIgNC4yLTIuNSA3LTIuNWguMmMzLjEgMCA1LjcgMSA3LjMgMy4yIi8+CiAgICA8cGF0aCBz'
    b'dHJva2U9IiMyNDExODMiIGQ9Ik0zMTIuMyAyMTRjMS45LTIgNC4yLTIuNiA3LTIuNmguMmMz'
    b'IDAgNS42IDEgNy4yIDMuMiIvPgogICAgPHBhdGggc3Ryb2tlPSIjMjIxNzg2IiBkPSJNMzEy'
    b'LjQgMjE0YzEuOC0yIDQuMS0yLjYgNy0yLjYgMyAwIDUuNyAxIDcuMiAzIi8+CiAgICA8cGF0'
    b'aCBzdHJva2U9IiMxZjFmOGEiIGQ9Ik0zMTIuNCAyMTMuOGMxLjgtMS45IDQuMi0yLjUgNi45'
    b'LTIuNWguMWMzIDAgNS42IDEgNy4yIDMiLz4KICAgIDxwYXRoIHN0cm9rZT0iIzFhMjU4ZCIg'
    b'ZD0iTTMxMi41IDIxMy43YzEuNy0xLjggNC0yLjQgNi44LTIuNGguMWMzIDAgNS41LjggNyAy'
    b'LjkiLz4KICAgIDxwYXRoIHN0cm9rZT0iIzE3MmQ5MSIgZD0iTTMxMi41IDIxMy43YzEuNy0x'
    b'LjkgNC4xLTIuNSA2LjctMi41aC4yYzIuOSAwIDUuNC44IDcgMi44Ii8+CiAgICA8cGF0aCBz'
    b'dHJva2U9IiMxNDMzOTMiIGQ9Ik0zMTIuNSAyMTMuNmMxLjctMS44IDQtMi40IDYuNy0yLjRo'
    b'LjJjMi44IDAgNS4zLjcgNyAyLjciLz4KICAgIDxwYXRoIHN0cm9rZT0iIzExM2I5NyIgZD0i'
    b'TTMxMi42IDIxMy41YzEuNi0xLjggNC0yLjQgNi42LTIuNGguMWMyLjggMCA1LjQuNyA3IDIu'
    b'NyIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmYwYTAwIiBkPSJNMzE1LjMgMjA5YTYuNSA2LjUg'
    b'MCAwIDEgNC0xLjJjMS41IDAgMi44LjMgNCAxIi8+CiAgICA8cGF0aCBzdHJva2U9IiNmMTAi'
    b'IGQ9Ik0zMTUuMyAyMDlhNi42IDYuNiAwIDAgMSA0LTEgNyA3IDAgMCAxIDQgMSIvPgogICAg'
    b'PHBhdGggc3Ryb2tlPSIjZmYxNTAwIiBkPSJNMzE1LjMgMjA5YTYuOCA2LjggMCAwIDEgNC0x'
    b'YzEuNSAwIDIuOS4yIDQgMSIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmYxYTAwIiBkPSJNMzE1'
    b'LjIgMjA5LjJhNi42IDYuNiAwIDAgMSA0LjEtMS4yYzEuNSAwIDMgLjMgNC4xIDEiLz4KICAg'
    b'IDxwYXRoIHN0cm9rZT0iI2ZmMjAwMCIgZD0iTTMxNS4yIDIwOS4yYTYuNyA2LjcgMCAwIDEg'
    b'NC4xLTEuMWMxLjUgMCAzIC4zIDQuMSAxIi8+CiAgICA8cGF0aCBzdHJva2U9IiNmZjI3MDAi'
    b'IGQ9Ik0zMTUuMSAyMDkuM2E2LjggNi44IDAgMCAxIDQuMi0xLjJjMS41IDAgMyAuMyA0LjIg'
    b'MS4xIi8+CiAgICA8cGF0aCBzdHJva2U9IiNmZjJmMDAiIGQ9Ik0zMTUuMSAyMDkuNGE2Ljkg'
    b'Ni45IDAgMCAxIDQuMi0xLjJjMS41IDAgMyAuMyA0LjIgMSIvPgogICAgPHBhdGggc3Ryb2tl'
    b'PSIjZjMwIiBkPSJNMzE1IDIwOS40YTYuOCA2LjggMCAwIDEgNC4zLTEuMSA3LjcgNy43IDAg'
    b'MCAxIDQuMyAxIi8+CiAgICA8cGF0aCBzdHJva2U9IiNmZjNjMDAiIGQ9Ik0zMTUgMjA5LjVh'
    b'Ni45IDYuOSAwIDAgMSA0LjMtMS4yYzEuNiAwIDMuMS4zIDQuMyAxLjEiLz4KICAgIDxwYXRo'
    b'IHN0cm9rZT0iI2ZmNDEwMCIgZD0iTTMxNSAyMDkuNmE3IDcgMCAwIDEgNC4zLTEuMiA4IDgg'
    b'MCAwIDEgNC4zIDEuMSIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmY0NjAwIiBkPSJNMzE1IDIw'
    b'OS43YTcgNyAwIDAgMSA0LjMtMS4zIDggOCAwIDAgMSA0LjQgMS4yIi8+CiAgICA8cGF0aCBz'
    b'dHJva2U9IiNmZmY1MDAiIGQ9Ik0zMTQgMjExLjJhOS43IDkuNyAwIDAgMSAxMC43IDAiLz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0iI2ZmZWIwMCIgZD0iTTMxNC4xIDIxMS4xYTkgOSAwIDAgMSA1'
    b'LjItMS41YzIgMCA0IC41IDUuMyAxLjYiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZmZTAwMCIg'
    b'ZD0iTTMxNC4xIDIxMWE5IDkgMCAwIDEgNS4yLTEuNWMxLjkgMCA0IC41IDUuMyAxLjYiLz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0iI2ZmZDYwMCIgZD0iTTMxNC4yIDIxMWE5IDkgMCAwIDEgNS4x'
    b'LTEuNmMxLjkgMCAzLjkuNSA1LjIgMS42Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZmNmMDAi'
    b'IGQ9Ik0zMTQuMiAyMTAuOWE5IDkgMCAwIDEgNS4xLTEuNSA5IDkgMCAwIDEgNS4yIDEuNSIv'
    b'PgogICAgPHBhdGggc3Ryb2tlPSIjZmZjNDAwIiBkPSJNMzE0LjMgMjEwLjhjMS4zLTEgMy4z'
    b'LTEuNSA1LTEuNWE4IDggMCAwIDEgNS4xIDEuNSIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmZi'
    b'YTAwIiBkPSJNMzE0LjMgMjEwLjdjMS40LTEgMy4zLTEuNSA1LTEuNXMzLjcuNSA1IDEuNSIv'
    b'PgogICAgPHBhdGggc3Ryb2tlPSIjZmZiMDAwIiBkPSJNMzE0LjQgMjEwLjZhOC40IDguNCAw'
    b'IDAgMSA1LTEuNGMxLjcgMCAzLjYuNCA1IDEuNCIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmZh'
    b'NjAwIiBkPSJNMzE0LjQgMjEwLjVhOC4xIDguMSAwIDAgMSA1LTEuNCA4IDggMCAwIDEgNC44'
    b'IDEuNCIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmY5YzAwIiBkPSJNMzE0LjUgMjEwLjRhOCA4'
    b'IDAgMCAxIDQuOC0xLjRjMS43IDAgMy42LjQgNC45IDEuNCIvPgogICAgPHBhdGggc3Ryb2tl'
    b'PSIjZmY5MTAwIiBkPSJNMzE0LjYgMjEwLjNhOCA4IDAgMCAxIDQuNy0xLjRjMS43IDAgMy41'
    b'LjUgNC44IDEuNCIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmY4NzAwIiBkPSJNMzE0LjYgMjEw'
    b'LjJhOCA4IDAgMCAxIDQuNy0xLjNjMS43IDAgMy41LjQgNC44IDEuMyIvPgogICAgPHBhdGgg'
    b'c3Ryb2tlPSIjZmY3ZDAwIiBkPSJNMzE0LjYgMjEwLjJhNy43IDcuNyAwIDAgMSA0LjctMS40'
    b'YzEuNyAwIDMuNC40IDQuNyAxLjMiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZmNzUwMCIgZD0i'
    b'TTMxNC43IDIxMGE3LjYgNy42IDAgMCAxIDQuNi0xLjJjMS43IDAgMy40LjQgNC43IDEuMiIv'
    b'PgogICAgPHBhdGggc3Ryb2tlPSIjZmY2YjAwIiBkPSJNMzE0LjggMjEwYTcuNiA3LjYgMCAw'
    b'IDEgNC41LTEuMyA4IDggMCAwIDEgNC42IDEuMiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmY2'
    b'MTAwIiBkPSJNMzE0LjggMjA5LjlhNy4zIDcuMyAwIDAgMSA0LjUtMS4zYzEuNiAwIDMuMy40'
    b'IDQuNiAxLjMiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZmNTcwMCIgZD0iTTMxNC45IDIwOS44'
    b'YTcuMyA3LjMgMCAwIDEgNC40LTEuMyA4IDggMCAwIDEgNC41IDEuMyIvPgogICAgPHBhdGgg'
    b'c3Ryb2tlPSIjZWJmNjA1IiBkPSJNMzEzLjkgMjExLjRhOS41IDkuNSAwIDAgMSA1LjQtMS43'
    b'YzIgMCA0LjEuNiA1LjUgMS43Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNkNmVjMDkiIGQ9Ik0z'
    b'MTMuOCAyMTEuNWE5LjEgOS4xIDAgMCAxIDUuNS0xLjdjMiAwIDQuMi42IDUuNiAxLjciLz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0iI2MyZTMwZSIgZD0iTTMxMy44IDIxMS42YTkgOSAwIDAgMSA1'
    b'LjUtMS43YzIgMCA0LjIuNSA1LjYgMS43Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNhZGQ5MTIi'
    b'IGQ9Ik0zMTMuNyAyMTEuN2E4LjggOC44IDAgMCAxIDUuNi0xLjhjMiAwIDQuMi42IDUuNiAx'
    b'LjgiLz4KICAgIDxwYXRoIHN0cm9rZT0iIzk5Y2YxNiIgZD0iTTMxMy42IDIxMS44YTguOCA4'
    b'LjggMCAwIDEgNS43LTEuOGMyIDAgNC4zLjYgNS43IDEuOCIvPgogICAgPHBhdGggc3Ryb2tl'
    b'PSIjODVjNjFhIiBkPSJNMzEzLjYgMjExLjlhOC43IDguNyAwIDAgMSA1LjctMS45YzIgMCA0'
    b'LjMuNyA1LjcgMS45Ii8+CiAgICA8cGF0aCBzdHJva2U9IiM3MGJjMWYiIGQ9Ik0zMTMuNSAy'
    b'MTJhOC40IDguNCAwIDAgMSA1LjgtMS45YzIgMCA0LjQuNiA1LjggMS44Ii8+CiAgICA8cGF0'
    b'aCBzdHJva2U9IiM1Y2IzMjMiIGQ9Ik0zMTMuNSAyMTIuMWE4LjQgOC40IDAgMCAxIDUuOC0y'
    b'YzIuMSAwIDQuNC43IDUuOCAyIi8+CiAgICA8cGF0aCBzdHJva2U9IiM0N2E5MjgiIGQ9Ik0z'
    b'MTMuNCAyMTIuMmE4LjQgOC40IDAgMCAxIDUuOS0yYzIuMSAwIDQuNC43IDUuOSAxLjkiLz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0iIzBkNzRhNCIgZD0iTTMxMy4xIDIxMi43YTguOCA4LjggMCAw'
    b'IDEgNi4yLTIgOSA5IDAgMCAxIDYuMyAyIi8+CiAgICA8cGF0aCBzdHJva2U9IiMxMjdhOTci'
    b'IGQ9Ik0zMTMuMSAyMTIuN2E4LjcgOC43IDAgMCAxIDYuMi0yLjIgOSA5IDAgMCAxIDYuMiAy'
    b'LjEiLz4KICAgIDxwYXRoIHN0cm9rZT0iIzE3ODA4YiIgZD0iTTMxMy4yIDIxMi42YTguNyA4'
    b'LjcgMCAwIDEgNi4yLTIgOSA5IDAgMCAxIDYgMiIvPgogICAgPHBhdGggc3Ryb2tlPSIjMWE4'
    b'NDdkIiBkPSJNMzEzLjIgMjEyLjZhOC43IDguNyAwIDAgMSA2LjEtMi4xIDkgOSAwIDAgMSA2'
    b'LjEgMiIvPgogICAgPHBhdGggc3Ryb2tlPSIjMWU4YTZkIiBkPSJNMzEzLjIgMjEyLjVhOC41'
    b'IDguNSAwIDAgMSA2LjEtMmMyLjMgMCA0LjYuNiA2IDIiLz4KICAgIDxwYXRoIHN0cm9rZT0i'
    b'IzIzOGY1ZSIgZD0iTTMxMy4zIDIxMi41YTguNSA4LjUgMCAwIDEgNi0yLjFjMi4yIDAgNC42'
    b'LjYgNiAyIi8+CiAgICA8cGF0aCBzdHJva2U9IiMyYjk0NGUiIGQ9Ik0zMTMuMyAyMTIuNGE4'
    b'LjMgOC4zIDAgMCAxIDYtMmMyLjIgMCA0LjYuNiA2IDIiLz4KICAgIDxwYXRoIHN0cm9rZT0i'
    b'IzJmOWIzZSIgZD0iTTMxMy4zIDIxMi4zYzItMS42IDMuNy0yIDYtMiAyLjIgMCA0LjUuNyA2'
    b'IDIiLz4KICAgIDxwYXRoIHN0cm9rZT0icmVkIiBkPSJNMzIzLjIgMjA4LjhhNi44IDYuOCAw'
    b'IDAgMC0zLjktMSA2LjYgNi42IDAgMCAwLTQgMSIvPgogICAgPHBhdGggc3Ryb2tlPSIjMmEw'
    b'MDdjIiBkPSJNMzI2LjkgMjE0LjljLTEuNi0yLjMtNC4zLTMuNC03LjUtMy40LTMgMC01LjIu'
    b'Ny03LjIgMi43Ii8+CiAgICA8cGF0aCBzdHJva2U9IiMwNjcxYjAiIGQ9Ik0zMjUuNiAyMTIu'
    b'N2MtMS41LTEuNS00LTItNi4zLTJhOSA5IDAgMCAwLTYuMiAyLjEiLz4KICAgIDxwYXRoIHN0'
    b'cm9rZT0iIzBjNDE5YSIgZD0iTTMyNi4yIDIxMy43Yy0xLjYtMi00LjEtMi42LTYuOS0yLjYt'
    b'Mi42IDAtNSAuNi02LjcgMi4zIi8+CiAgICA8cGF0aCBzdHJva2U9IiNmZjAiIGQ9Ik0zMjQu'
    b'OCAyMTEuM2E5LjEgOS4xIDAgMCAwLTUuNS0xLjZjLTEuOCAwLTQgLjUtNS40IDEuNiIvPgog'
    b'ICAgPHBhdGggc3Ryb2tlPSIjZmY0ZDAwIiBkPSJNMzIzLjcgMjA5LjdhOC4xIDguMSAwIDAg'
    b'MC00LjQtMS4yIDcgNyAwIDAgMC00LjQgMS4yIi8+CiAgICA8cGF0aCBzdHJva2U9IiMzM2Ew'
    b'MmMiIGQ9Ik0zMjUuMiAyMTIuMmE5LjUgOS41IDAgMCAwLTUuOS0yIDguMyA4LjMgMCAwIDAt'
    b'NiAyIi8+CiAgPC9nPgogIDxnIGZpbGw9Im5vbmUiIHN0cm9rZS1taXRlcmxpbWl0PSIyLjYi'
    b'IHN0cm9rZS13aWR0aD0iLjEiPgogICAgPHBhdGggc3Ryb2tlPSIjZmVmMmVjIiBkPSJNMzEy'
    b'IDIxNC41YTE2LjMgMTYuMyAwIDAgMSA3LjMtMS44YzIuNiAwIDUuNCAxIDcuNiAyLjFsNy43'
    b'IDEzYTE1LjMgMTUuMyAwIDAgMS0zMC42IDBsOC0xMy4zeiIvPgogICAgPHBhdGggc3Ryb2tl'
    b'PSIjZmVmMmVhIiBkPSJNMzE5LjMgMjEyLjljMi42IDAgNS4zIDEgNy41IDIuMWw3LjYgMTIu'
    b'N2MwIDguMy02LjggMTUuMi0xNSAxNS4yLTguNCAwLTE1LjEtNi43LTE1LjItMTUuMWw3Ljkt'
    b'MTNhMTUuOCAxNS44IDAgMCAxIDcuMi0yeiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmVmMGU2'
    b'IiBkPSJNMzE5LjMgMjEzLjNjMi41IDAgNS4yIDEgNy4zIDJsNy40IDEyLjRjMCA4LjEtNi42'
    b'IDE0LjktMTQuNyAxNC45YTE0LjcgMTQuNyAwIDAgMS0xNC43LTE0LjhsNy42LTEyLjdhMTUu'
    b'NiAxNS42IDAgMCAxIDctMS44eiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmVlZGUzIiBkPSJN'
    b'MzE5LjMgMjEzLjdjMi40IDAgNSAuOSA3IDIgLjIgMCA3LjMgMTEuOSA3LjMgMTJhMTQuNCAx'
    b'NC40IDAgMCAxLTE0LjMgMTQuNGMtNy45IDAtMTQuMi02LjMtMTQuMy0xNC4zIDAtLjIgNy4z'
    b'LTEyLjMgNy40LTEyLjRhMTYgMTYgMCAwIDEgNi45LTEuN3oiLz4KICAgIDxwYXRoIHN0cm9r'
    b'ZT0iI2ZlZThkYyIgZD0iTTMxOS4zIDIxNC4zYzIuMyAwIDQuOC45IDYuOCAyIC4yIDAgNi44'
    b'IDExLjIgNi44IDExLjUgMCA3LjUtNi4xIDEzLjctMTMuNiAxMy43cy0xMy42LTYtMTMuNy0x'
    b'My43YzAtLjMgNi45LTExLjcgNy4xLTExLjggMi0xIDQuMi0xLjcgNi42LTEuN3oiLz4KICAg'
    b'IDxwYXRoIHN0cm9rZT0iI2ZlZTZkNSIgZD0iTTMxOS4zIDIxNC43YzIuMyAwIDQuNy44IDYu'
    b'NiAxLjkuMi4yIDYuNiAxMC44IDYuNiAxMS4yIDAgNy4zLTYgMTMuMy0xMy4yIDEzLjNzLTEz'
    b'LjItNi0xMy4yLTEzLjNjMC0uNCA2LjUtMTEuMyA2LjgtMTEuNSAyLTEgNC0xLjYgNi40LTEu'
    b'NnoiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZlZTNjZiIgZD0iTTMxOS4zIDIxNS4zYzIuMiAw'
    b'IDQuNS44IDYuMiAxLjguNC4yIDYuNCAxMC4yIDYuNCAxMC43IDAgNy01LjcgMTIuNy0xMi42'
    b'IDEyLjctNyAwLTEyLjYtNS42LTEyLjctMTIuNyAwLS40IDYuMi0xMC43IDYuNi0xMWExMy4z'
    b'IDEzLjMgMCAwIDEgNi0xLjV6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZWUwY2MiIGQ9Ik0z'
    b'MTkuMyAyMTUuN2MyLjEgMCA0LjMuOCA2IDEuOGE3NiA3NiAwIDAgMSA2LjIgMTAuM2MwIDYu'
    b'Ny01LjUgMTIuMy0xMi4yIDEyLjNhMTIuMiAxMi4yIDAgMCAxLTEyLjMtMTIuM2MwLS41IDYt'
    b'MTAuMyA2LjQtMTAuNiAxLjgtMSAzLjctMS41IDUuOS0xLjV6Ii8+CiAgICA8cGF0aCBzdHJv'
    b'a2U9IiNmZWRlYzYiIGQ9Ik0zMTkuMyAyMTYuMWMyIDAgNC4yLjggNS45IDEuNy40LjMgNiA5'
    b'LjQgNiAxMGExMiAxMiAwIDAgMS0xMiAxMS45IDExLjggMTEuOCAwIDAgMS0xMS43LTExLjlj'
    b'MC0uNiA1LjYtMTAgNi0xMC4yYTEyLjUgMTIuNSAwIDAgMSA1LjgtMS41eiIvPgogICAgPHBh'
    b'dGggc3Ryb2tlPSIjZmRjZGFhIiBkPSJNMzE5LjMgMjE4LjhjMS42IDAgMy4yLjUgNC41IDEu'
    b'My45LjUgNC42IDYuNyA0LjYgNy43YTkuMiA5LjIgMCAwIDEtOS4xIDkuMiA5LjIgOS4yIDAg'
    b'MCAxLTkuMi05LjJjMC0xIDMuOS03LjQgNC43LThhOS42IDkuNiAwIDAgMSA0LjUtMXoiLz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0iI2ZkY2RhYSIgZD0iTTMxOS4zIDIxOWE5IDkgMCAwIDEgNC40'
    b'IDEuMmMxIC42IDQuNSA2LjYgNC41IDcuNmE5IDkgMCAxIDEtMTcuOSAwYzAtMSAzLjctNy4y'
    b'IDQuNi03LjdhOS4yIDkuMiAwIDAgMSA0LjQtMS4xeiIvPgogICAgPHBhdGggc3Ryb2tlPSIj'
    b'ZmRjNTllIiBkPSJNMzE5LjMgMjIwYTggOCAwIDAgMSA0IDEuMWMxIC42IDQgNS41IDQgNi43'
    b'YTggOCAwIDAgMS04IDggOCA4IDAgMCAxLTgtOGMwLTEuMiAzLTYuMyA0LjEtNi44IDEuMi0u'
    b'NyAyLjUtMSAzLjktMXoiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZkYzU5ZSIgZD0iTTMxOS4z'
    b'IDIyMC4yYTcuOCA3LjggMCAwIDEgMy45IDEgMTYgMTYgMCAwIDEgMy44IDYuNiA3LjggNy44'
    b'IDAgMCAxLTcuNyA3LjggNy43IDcuNyAwIDAgMS03LjgtNy43YzAtMS40IDMtNi4xIDQtNi44'
    b'YTcuOSA3LjkgMCAwIDEgMy44LTF6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZWYwZTkiIGQ9'
    b'Ik0zMTkuMyAyMTNjMi41IDAgNS4yIDEgNy40IDIuMmw3LjUgMTIuNWExNSAxNSAwIDAgMS0x'
    b'NC45IDE1IDE1IDE1IDAgMCAxLTE0LjktMTQuOWw3LjctMTNhMTUuNiAxNS42IDAgMCAxIDcu'
    b'Mi0xLjd6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZWVkZTMiIGQ9Ik0zMTkuMyAyMTMuNWMy'
    b'LjUgMCA1LjEgMSA3LjEgMiAuMi4xIDcuNCAxMi4xIDcuNCAxMi4zYTE0LjUgMTQuNSAwIDAg'
    b'MS0yOSAwbDcuNS0xMi42YTE1LjEgMTUuMSAwIDAgMSA3LTEuN3oiLz4KICAgIDxwYXRoIHN0'
    b'cm9rZT0iI2ZlZWJkZiIgZD0iTTMxOS4zIDIxNGMyLjQgMCA1IC44IDcgMS45LjEgMCA3IDEx'
    b'LjYgNyAxMS45IDAgNy43LTYuMyAxNC4xLTE0IDE0LjFzLTE0LTYuMy0xNC0xNC4xYzAtLjIg'
    b'Ny0xMi4xIDcuMi0xMi4yYTE0LjkgMTQuOSAwIDAgMSA2LjgtMS43eiIvPgogICAgPHBhdGgg'
    b'c3Ryb2tlPSIjZmVlYmRkIiBkPSJNMzE5LjMgMjE0YzIuNCAwIDQuOSAxIDYuOSAyIC4xLjIg'
    b'NyAxMS41IDcgMTEuOGExNCAxNCAwIDAgMS0xNCAxNCAxNCAxNCAwIDAgMS0xMy44LTE0YzAt'
    b'LjIgNy0xMS45IDcuMi0xMiAyLTEgNC4yLTEuNyA2LjctMS43eiIvPgogICAgPHBhdGggc3Ry'
    b'b2tlPSIjZmVlOGQ5IiBkPSJNMzE5LjMgMjE0LjVjMi4zIDAgNC44LjkgNi43IDIgLjIgMCA2'
    b'LjcgMTEgNi43IDExLjMgMCA3LjQtNiAxMy41LTEzLjQgMTMuNXMtMTMuNC02LTEzLjUtMTMu'
    b'NWMwLS4zIDYuNy0xMS41IDctMTEuNyAyLTEgNC4xLTEuNiA2LjUtMS42eiIvPgogICAgPHBh'
    b'dGggc3Ryb2tlPSIjZmVlNmQzIiBkPSJNMzE5LjMgMjE1YzIuMiAwIDQuNi43IDYuNSAxLjgu'
    b'My4xIDYuNSAxMC42IDYuNSAxMSAwIDcuMS01LjkgMTMuMS0xMyAxMy4xYTEzLjEgMTMuMSAw'
    b'IDAgMS0xMy0xM2MwLS41IDYuNC0xMS4zIDYuNy0xMS40YTEzLjggMTMuOCAwIDAgMSA2LjMt'
    b'MS42eiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmVlM2QyIiBkPSJNMzE5LjMgMjE1LjFjMi4y'
    b'IDAgNC41LjggNi40IDEuOC4zLjIgNi40IDEwLjUgNi40IDEwLjkgMCA3LTUuOCAxMy0xMi44'
    b'IDEzYTEzIDEzIDAgMCAxLTEyLjktMTNjMC0uNCA2LjMtMTEgNi43LTExLjFhMTMuOCAxMy44'
    b'IDAgMCAxIDYuMi0xLjZ6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZWUwY2MiIGQ9Ik0zMTku'
    b'MyAyMTUuNWMyLjIgMCA0LjQuOCA2LjEgMS44LjUuMiA2LjMgMTAgNi4zIDEwLjUgMCA2Ljgt'
    b'NS42IDEyLjUtMTIuNCAxMi41YTEyLjUgMTIuNSAwIDAgMS0xMi41LTEyLjVjMC0uNSA2LTEw'
    b'LjYgNi41LTEwLjhhMTMgMTMgMCAwIDEgNi0xLjV6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNm'
    b'ZWRlYzgiIGQ9Ik0zMTkuMyAyMTZjMiAwIDQuMi43IDYgMS42LjQuMyA2IDkuNiA2IDEwLjJh'
    b'MTIgMTIgMCAwIDEtMTIgMTIgMTIgMTIgMCAwIDEtMTItMTIgODggODggMCAwIDEgNi4yLTEw'
    b'LjRjMS43LTEgMy42LTEuNSA1LjgtMS41eiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmRkYmM1'
    b'IiBkPSJNMzE5LjMgMjE2LjNjMiAwIDQuMS44IDUuOCAxLjdhODcgODcgMCAwIDEgNS44IDku'
    b'OGMwIDYuNC01LjIgMTEuNy0xMS42IDExLjctNi40IDAtMTEuNi01LjItMTEuNi0xMS43IDAt'
    b'LjYgNS41LTkuNyA2LTEwYTEyLjEgMTIuMSAwIDAgMSA1LjYtMS41eiIvPgogICAgPHBhdGgg'
    b'c3Ryb2tlPSIjZmRkYmMyIiBkPSJNMzE5LjMgMjE2LjVjMiAwIDQgLjggNS43IDEuNy41LjMg'
    b'NS43IDkgNS43IDkuNiAwIDYuMy01LjEgMTEuNS0xMS40IDExLjVzLTExLjQtNS4xLTExLjUt'
    b'MTEuNWMwLS43IDUuNC05LjYgNi05LjlhMTIgMTIgMCAwIDEgNS41LTEuNHoiLz4KICAgIDxw'
    b'YXRoIHN0cm9rZT0iI2ZkZDliZiIgZD0iTTMxOS4zIDIxNi43YzIgMCA0IC43IDUuNiAxLjYu'
    b'NS40IDUuNiA4LjggNS42IDkuNWExMS4yIDExLjIgMCAwIDEtMjIuNCAwYzAtLjcgNS4yLTku'
    b'NCA1LjgtOS43YTExLjkgMTEuOSAwIDAgMSA1LjQtMS40eiIvPgogICAgPHBhdGggc3Ryb2tl'
    b'PSIjZmRkOWJmIiBkPSJNMzE5LjMgMjE3YzIgMCAzLjkuNiA1LjQgMS41YTU1IDU1IDAgMCAx'
    b'IDUuNiA5LjNjMCA2LTUgMTEtMTEgMTFzLTExLTQuOC0xMS0xMWMwLS43IDUtOS4yIDUuNy05'
    b'LjVhMTEuNSAxMS41IDAgMCAxIDUuMy0xLjR6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGQ2'
    b'YmMiIGQ9Ik0zMTkuMyAyMTcuMWMxLjkgMCAzLjguNyA1LjMgMS42LjcuMyA1LjUgOC4zIDUu'
    b'NSA5LjEgMCA2LTQuOSAxMC45LTEwLjggMTAuOWExMC44IDEwLjggMCAwIDEtMTAuOC0xMC45'
    b'YzAtLjggNS05IDUuNi05LjNhMTEgMTEgMCAwIDEgNS4yLTEuNHoiLz4KICAgIDxwYXRoIHN0'
    b'cm9rZT0iI2ZkZDZiOSIgZD0iTTMxOS4zIDIxNy4zYzEuOCAwIDMuNy43IDUuMiAxLjUuNy40'
    b'IDUuMyA4LjIgNS4zIDkgMCA1LjgtNC43IDEwLjctMTAuNSAxMC43YTEwLjYgMTAuNiAwIDAg'
    b'MS0xMC42LTEwLjdjMC0uOCA0LjgtOC44IDUuNS05LjJhMTEgMTEgMCAwIDEgNS0xLjN6Ii8+'
    b'CiAgICA8cGF0aCBzdHJva2U9IiNmZGQ0YjgiIGQ9Ik0zMTkuMyAyMTcuNmMxLjggMCAzLjcu'
    b'NiA1LjIgMS40LjYuNCA1LjIgOCA1LjIgOC44IDAgNS43LTQuNyAxMC41LTEwLjQgMTAuNXMt'
    b'MTAuNC00LjctMTAuNC0xMC41YzAtLjggNC42LTguNiA1LjMtOWExMC44IDEwLjggMCAwIDEg'
    b'NS0xLjJ6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGQ0YjYiIGQ9Ik0zMTkuMyAyMTcuN2Mx'
    b'LjggMCAzLjYuNyA1IDEuNS44LjQgNS4yIDcuNyA1LjIgOC42IDAgNS42LTQuNiAxMC4zLTEw'
    b'LjIgMTAuM2ExMC4yIDEwLjIgMCAwIDEtMTAuMi0xMC4zYzAtLjkgNC41LTguNCA1LjItOC44'
    b'YTEwLjggMTAuOCAwIDAgMSA1LTEuM3oiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZkZDJiMiIg'
    b'ZD0iTTMxOS4zIDIxOGMxLjcgMCAzLjUuNiA1IDEuNC43LjQgNSA3LjUgNSA4LjQgMCA1LjUt'
    b'NC42IDEwLTEwIDEwcy0xMC00LjQtMTAtMTBhMzkgMzkgMCAwIDEgNS4xLTguNiAxMC43IDEw'
    b'LjcgMCAwIDEgNC45LTEuM3oiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZkZDFiMCIgZD0iTTMx'
    b'OS4zIDIxOC4yYzEuNyAwIDMuNS42IDQuOSAxLjQuNy40IDQuOSA3LjMgNC45IDguMiAwIDUu'
    b'NC00LjUgOS45LTkuOCA5LjlzLTkuOC00LjQtOS44LTkuOWMwLS45IDQuMi04IDUtOC40YTku'
    b'OCA5LjggMCAwIDEgNC44LTEuM3oiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZkZDBiMCIgZD0i'
    b'TTMxOS4zIDIxOC40YzEuNyAwIDMuNC42IDQuOCAxLjMuOC41IDQuNyA3LjEgNC43IDguMWE5'
    b'LjUgOS41IDAgMSAxLTE5LjEgMGMwLTEgNC4xLTcuOCA1LTguM2E5LjggOS44IDAgMCAxIDQu'
    b'Ni0xLjF6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGQwYWQiIGQ9Ik0zMTkuMyAyMTguNmE5'
    b'LjggOS44IDAgMCAxIDQuNyAxLjNjLjguNSA0LjYgNyA0LjYgOCAwIDUtNC4yIDkuMy05LjMg'
    b'OS4zcy05LjQtNC4xLTkuNC05LjRjMC0xIDQtNy42IDQuOC04YTkuNiA5LjYgMCAwIDEgNC42'
    b'LTEuMnoiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZkY2FhNiIgZD0iTTMxOS4zIDIxOS4yYzEu'
    b'NSAwIDMgLjUgNC40IDEuMi45LjUgNC4zIDYuMyA0LjMgNy40YTguOCA4LjggMCAwIDEtOC43'
    b'IDguOCA4LjggOC44IDAgMCAxLTguOC04LjdjMC0xLjIgMy42LTcuMSA0LjUtNy43YTkuMSA5'
    b'LjEgMCAwIDEgNC4zLTF6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGNhYTQiIGQ9Ik0zMTku'
    b'MyAyMTkuNGE5LjEgOS4xIDAgMCAxIDQuMyAxLjJjLjkuNSA0LjIgNiA0LjIgNy4yYTguNiA4'
    b'LjYgMCAwIDEtOC41IDguNiA4LjYgOC42IDAgMCAxLTguNi04LjVjMC0xLjIgMy41LTcgNC40'
    b'LTcuNWE5IDkgMCAwIDEgNC4yLTF6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGM4YTQiIGQ9'
    b'Ik0zMTkuMyAyMTkuNmMxLjUgMCAzIC41IDQuMiAxLjJhMTkgMTkgMCAwIDEgNC4xIDcgOC40'
    b'IDguNCAwIDAgMS0xNi43LjFjMC0xLjIgMy4zLTYuNyA0LjMtNy4zYTguNSA4LjUgMCAwIDEg'
    b'NC0xeiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmRjOGExIiBkPSJNMzE5LjMgMjE5LjhjMS40'
    b'IDAgMi45LjUgNCAxLjEgMSAuNiA0LjEgNS43IDQuMSA3YTguMiA4LjIgMCAwIDEtOC4xIDgu'
    b'MSA4LjIgOC4yIDAgMCAxLTguMi04LjFjMC0xLjMgMy4yLTYuNiA0LjItNy4xIDEuMi0uNiAy'
    b'LjUtMSA0LTF6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGMzOWIiIGQ9Ik0zMTkuMyAyMjAu'
    b'NGMxLjMgMCAyLjcuNCAzLjcgMWExNSAxNSAwIDAgMSAzLjggNi40IDcuNSA3LjUgMCAwIDEt'
    b'Ny41IDcuNiA3LjUgNy41IDAgMCAxLTcuNi03LjVjMC0xLjQgMi44LTYgMy45LTYuNmE3Ljcg'
    b'Ny43IDAgMCAxIDMuNy0xeiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmRjMzk4IiBkPSJNMzE5'
    b'LjMgMjIwLjZjMS4zIDAgMi42LjQgMy42IDFhMTMgMTMgMCAwIDEgMy43IDYuM2MwIDQtMy4z'
    b'IDcuMy03LjMgNy4zYTcuMyA3LjMgMCAwIDEtNy40LTcuMyAxNCAxNCAwIDAgMSAzLjgtNi40'
    b'IDcuNyA3LjcgMCAwIDEgMy42LTF6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGMwOTciIGQ9'
    b'Ik0zMTkuMyAyMjAuOGE3LjUgNy41IDAgMCAxIDMuNiAxIDEzIDEzIDAgMCAxIDMuNSA2YzAg'
    b'NC0zLjIgNy4yLTcuMSA3LjJhNy4xIDcuMSAwIDAgMS03LjItNy4xYzAtMS41IDIuNS01LjYg'
    b'My43LTYuM2E3LjMgNy4zIDAgMCAxIDMuNS0uOHoiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2Zk'
    b'YzA5NSIgZD0iTTMxOS4zIDIyMWE3IDcgMCAwIDEgMy41IDFjMS4xLjcgMy40IDQuNCAzLjQg'
    b'NS45YTcgNyAwIDAgMS03IDcgNyA3IDAgMCAxLTYuOS03YzAtMS41IDIuNC01LjQgMy42LTZh'
    b'Ni44IDYuOCAwIDAgMSAzLjQtLjl6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGJlOTIiIGQ9'
    b'Ik0zMTkuMyAyMjEuMmE3IDcgMCAwIDEgMy40IDFjMS4xLjYgMy4zIDQuMiAzLjMgNS43YTYu'
    b'NyA2LjcgMCAxIDEtMTMuNSAwYzAtMS41IDIuMy01LjIgMy41LTUuOSAxLS41IDItLjggMy4z'
    b'LS44eiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmRiZTkwIiBkPSJNMzE5LjMgMjIxLjRjMS4x'
    b'IDAgMi4zLjQgMy4zIDEgMS4xLjYgMy4yIDQgMy4yIDUuNWE2LjUgNi41IDAgMCAxLTYuNSA2'
    b'LjUgNi41IDYuNSAwIDAgMS02LjYtNi41YzAtMS42IDIuMS01IDMuNC01LjdhNi42IDYuNiAw'
    b'IDAgMSAzLjItLjh6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmZGJiOGYiIGQ9Ik0zMTkuMyAy'
    b'MjEuNmMxLjEgMCAyLjIuMyAzLjIuOSAxLjIuNyAzIDMuOCAzIDUuNGE2LjMgNi4zIDAgMCAx'
    b'LTYuMiA2LjMgNi4zIDYuMyAwIDAgMS02LjQtNi4zIDkgOSAwIDAgMSAzLjMtNS41YzEtLjUg'
    b'Mi0uOCAzLS44eiIvPgogICAgPHBhdGggc3Ryb2tlPSIjZmRiYjhkIiBkPSJNMzE5LjMgMjIx'
    b'LjhjMSAwIDIuMi4zIDMgLjlhOCA4IDAgMCAxIDMgNS4yIDYuMSA2LjEgMCAwIDEtNiA2IDYu'
    b'MSA2LjEgMCAwIDEtNi4xLTZjMC0xLjYgMS44LTQuNiAzLTUuM2E2IDYgMCAwIDEgMy0uOHoi'
    b'Lz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZkYjk4YSIgZD0iTTMxOS4zIDIyMmE1LjggNS44IDAg'
    b'MCAxIDMgLjhjMS4yLjggMi45IDMuNSAyLjkgNWE2IDYgMCAwIDEtNiA2IDYgNiAwIDAgMS01'
    b'LjgtNmMwLTEuNiAxLjYtNC4zIDMtNWE2IDYgMCAwIDEgMi45LS44eiIvPgogICAgPHBhdGgg'
    b'c3Ryb2tlPSIjZmRiOThhIiBkPSJNMzE5LjMgMjIyLjJhNS44IDUuOCAwIDAgMSAyLjguOCA3'
    b'IDcgMCAwIDEgMi45IDQuOSA1LjcgNS43IDAgMCAxLTExLjQgMCA3IDcgMCAwIDEgMi45LTUg'
    b'NS41IDUuNSAwIDAgMSAyLjgtLjd6Ii8+CiAgICA8cGF0aCBzdHJva2U9IiNmY2I2ODciIGQ9'
    b'Ik0zMTkuMyAyMjIuNGMxIDAgMiAuMyAyLjguOGE2LjUgNi41IDAgMCAxIDIuNiA0LjcgNS41'
    b'IDUuNSAwIDEgMS0xMSAwYzAtMS43IDEuNS00IDIuOS00LjhhNiA2IDAgMCAxIDIuNy0uN3oi'
    b'Lz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZjYjY4NSIgZD0iTTMxOS4zIDIyMi42YzEgMCAxLjku'
    b'MyAyLjcuOGE1LjkgNS45IDAgMCAxIDIuNSA0LjUgNS4zIDUuMyAwIDAgMS01LjIgNS4zIDUu'
    b'MyA1LjMgMCAwIDEtNS4zLTUuMyA1LjkgNS45IDAgMCAxIDIuNy00LjYgNSA1IDAgMCAxIDIu'
    b'Ni0uN3oiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZjYjQ4NSIgZD0iTTMxOS4zIDIyMi44YzEg'
    b'MCAxLjguMyAyLjYuN2E1LjMgNS4zIDAgMCAxIDIuNCA0LjQgNSA1IDAgMSAxLTEwLjEgMGMw'
    b'LTEuOCAxLjEtMy42IDIuNi00LjRhNSA1IDAgMCAxIDIuNS0uN3oiLz4KICAgIDxwYXRoIHN0'
    b'cm9rZT0iI2ZjYjQ4MiIgZD0iTTMxOS4zIDIzMi44YTQuOSA0LjkgMCAwIDAgNC44LTQuOWMw'
    b'LTIuNy0yLjItNC45LTQuOC00LjlhNC45IDQuOSAwIDAgMC01IDQuOSA0LjkgNC45IDAgMCAw'
    b'IDUgNC45eiIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSIjZmZmIiBmaWxsLXJ1bGU9ImV2ZW5v'
    b'ZGQiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiIgc3Ryb2tlLXdpZHRo'
    b'PSIuMSIgZD0iTTMxOS4zIDIzMi44YTQuOSA0LjkgMCAwIDAgNC45LTQuOSA0LjkgNC45IDAg'
    b'MCAwLTQuOS00LjggNC45IDQuOSAwIDAgMC00LjkgNC44IDQuOSA0LjkgMCAwIDAgNSA0Ljl6'
    b'Ii8+CiAgPGcgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4xIj4KICAgIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIGQ9Im0zMjAuNCAyMjMuMS41LTIuNm0tMSAyLjYuMi0yLjdtLS44IDIuNnYt'
    b'Mi42bS0uNSAyLjctLjMtMi43bS0uMiAyLjctLjYtMi42bS4xIDIuOC0uOC0yLjZtLjMgMi43'
    b'LTEtMi40bS42IDIuNi0xLjQtMi4zbTEgMi42LTEuNi0yLjFtMS4yIDIuNS0xLjktMm0xLjUg'
    b'Mi4zLTItMS44bTEuNyAyLjItMi4yLTEuNW0xLjggMi0yLjItMS40bTIgMS44LTIuNC0xbTIu'
    b'MiAxLjUtMi41LS45bTIuNCAxLjQtMi42LS42bTIuNSAxLTIuNi0uMm0yLjYuOGgtMi43bTIu'
    b'Ny41LTIuNi4zbTIuNy4yLTIuNi42bTIuNy0uMS0yLjUuOG0yLjctLjMtMi40IDFtMi42LS42'
    b'LTIuOCAxLjhtMy4xLTEuMy01LjcgNG02LTMuNi02LjEgNS40bTYuNS01LTUuMSA1LjZtNS41'
    b'LTUuMy0zLjkgNS4xbTQuMy00LjgtNCA3bTQuNS02LjgtMi4zIDVtMi43LTQuOC0yLjIgN20y'
    b'LjctNi45LTEgNC43bTEuNi00LjYtLjcgNy4ybTEuNy03LjIuMiAyLjZtLjMtMi43IDEuNSA2'
    b'LjhtLTEtNyAxLjMgNC4xbS0uOC00LjIgMyA2LjdtLTIuNi03IDMuMyA1LjhtLTIuOC02IDQu'
    b'NyA2LjJtLTQuMy02LjUgNC4xIDQuOG0tMy44LTUuMiA2LjIgNS43bS01LjktNiAzLjQgMi40'
    b'bS0zLTIuOSAyLjIgMS4zbS0yLTEuNyAyLjQgMW0tMi4yLTEuNSAyLjUuOE0zMjQgMjI5bDIu'
    b'Ni41bS0yLjUtMSAyLjYuMm0tMi42LS44aDIuNm0tMi42LS41IDIuNi0uMm0tMi43LS4zIDIu'
    b'Ni0uNW0tMi43IDAgMi41LS44bS0yLjcuNCAyLjQtMS4xbS0yLjYuNiAyLjMtMS4zbS0yLjYu'
    b'OSAyLjEtMS42bS0yLjQgMS4xIDItMS43bS0yLjQgMS40IDEuOC0ybS0yLjIgMS42IDEuNi0y'
    b'bS0yIDEuOCAxLjMtMi4zbS0xLjggMiAxLjEtMi40bS0xLjYgMi4zLjktMi41bS0yLjQtNHYt'
    b'Mk0zMTcgMjE3bC0uNC0ybS0xLjggMi43LS44LTEuOG0tMS4yIDMtMS4yLTEuN20tLjUgMy4y'
    b'LTEuNi0xLjNtLjIgMy4yLTEuOC0xbS44IDMuMi0yLS43bTEuNSAzLTItLjNtMiAyLjUtMiAu'
    b'Mm0yLjUgMi4xLTIgLjdtMjIuMiAxLjUgMS44IDFtLS44LTMuMSAxLjkuNm0tMS41LTIuOSAy'
    b'IC4ybS0yLTIuNSAyLS4ybS0yLjQtMi4xIDItLjZtLTMtMS41IDEuOC0xbS0zLjEtLjkgMS41'
    b'LTEuNG0tMy4yLS4yIDEuMi0xLjZtLTMuMi41LjgtMS45bS0zIDEuMS40LTIiLz4KICAgIDxw'
    b'YXRoIGZpbGw9IiNlNjAwMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlLW1pdGVybGlt'
    b'aXQ9IjIuNiIgZD0iTTMyMi4xIDIzMC4ycy0uNy0uNC0xLS40bC0zIC4xYy0uNS4xLS44LjUt'
    b'LjguNXMuNS41IDEuNC42YzEgMCAxLjcgMCAyLjItLjJsMS4yLS42eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2U2MDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2UtbWl0ZXJsaW1pdD0i'
    b'Mi42IiBkPSJNMzE3LjQgMjI5LjVzLjEtMS40IDEtM2wtLjQuOHMtLjYuMy0uOSAwYy0uMy0u'
    b'NC0uMS0uNS4xLTEgLjItLjQuMi0uOC41LTEgLjItLjMuNC0uMyAxLS4zLjcgMCAxLjIgMCAx'
    b'LjcuOGwxIDEuN2MuNi44LjYgMS45LjYgMS45bC4yLjhzLS43LS40LTEuMS0uNGwtMyAuMS0u'
    b'OC41cy0uMy0uNi4xLTF6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2UtbWl0ZXJs'
    b'aW1pdD0iMi42IiBkPSJNMzE3LjQgMjI5LjVzLjYtLjMgMi4zLS4zYzIgMCAyLjEuMiAyLjMu'
    b'MyIvPgogICAgPHBhdGggZmlsbD0iI2ZjMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMi42IiBkPSJNMzE5LjIgMjM3LjF2LTcuMnMuMi0uMi44IDB2Ny4xcy4y'
    b'IDUuNS0uNCA1LjVjLS43IDAtLjQtMS4zLS40LTUuNHoiLz4KICA8L2c+CiAgPGcgZmlsbD0i'
    b'I2U2MDAwMCI+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Im0zMTEuOCAyMzEg'
    b'LjEuMy0xLjQuNi4yLjVoLS4yYy0uMS0uMi0uMi0uMy0uNi0uM3YtLjJsMS45LS44em0tMS41'
    b'LS41YS42LjYgMCAwIDEtLjMtLjRjMC0uNC4xLS43LjYtLjguMi0uMS43LS4xLjkuNSAwIC4z'
    b'IDAgLjctLjUuOHYtLjJjLjItLjEuMy0uMy4yLS42IDAtLjItLjMtLjMtLjYtLjMtLjMuMS0u'
    b'NC4zLS4zLjZhLjUuNSAwIDAgMCAuMy4zdi4ybC0xLjIuMS0uMi0xaC4zbC4yLjhoLjZ6bS0u'
    b'Ni00Yy0uMyAwLS41LjMtLjUuNiAwIC4yIDAgLjUuMy41cy4zLS4xLjQtLjJsLjItLjZjMC0u'
    b'My4yLS41LjYtLjUuNSAwIC42LjYuNSAxbC0uMi42Yy0uMi4xLS40LjItLjYuMXYtLjJjLjQg'
    b'MCAuNi0uMy42LS42IDAtLjIgMC0uNS0uMy0uNi0uMyAwLS4zIDAtLjQuNGwtLjIuNWMwIC4x'
    b'LS4xLjQtLjUuNHMtLjctLjMtLjYtLjhjMC0uOC41LS44LjctLjh2LjN6bTAtMS4zLjUuMi40'
    b'LTEuMWguM2wtLjQgMS4yLjcuMy40LTEuM2guMmwtLjQgMS42LTIuMS0uNy41LTEuNS4yLjF6'
    b'Ii8+CiAgICA8cGF0aCBkPSJNMzExIDIyMmEuNy43IDAgMCAwLS40LjRsLS41LjggMS45IDEu'
    b'MS4xLS4yLS44LS41LjQtLjZjLjItLjQgMC0uNy0uMi0uOWEuNi42IDAgMCAwLS41IDB6bS4y'
    b'LjRhLjQuNCAwIDAgMSAuMSAwYy4yLjIuMi4zLjEuNmwtLjMuNC0uNi0uMy4zLS41Yy4xLS4y'
    b'LjItLjMuNC0uMnoiLz4KICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTMxMy42'
    b'IDIyMi4xLS4yLjItMS40LTEuMy0uNS41LS4yLS4xIDEuMi0xLjMuMi4yLS41LjV6bS43LS42'
    b'LTEuMy0xLjcuMi0uMiAxLjMgMS43em0wLTIuMy4zLjYgMS0uNS4yLjItMSAuNi4yLjYgMS4y'
    b'LS42LjEuMi0xLjQuOC0xLTIgMS40LS43LjEuMnptNCAuNi0uMy0xLjJ2LS42bC0uMyAyaC0u'
    b'M2wtMS0xLjYuMi41LjIgMS4zaC0uMmwtLjUtMi4xaC40bDEgMS42LjItMmguNGwuNSAyLS4z'
    b'LjF6Ii8+CiAgICA8cGF0aCBkPSJNMzE5IDIxNy42djIuMmguOGMuNSAwIC44LS4yLjgtLjYg'
    b'MC0uMy0uMi0uNC0uNC0uNS4zLS4xLjMtLjMuMy0uNSAwLS4zLS4xLS41LS41LS42aC0xem0u'
    b'My4zaC41Yy4zIDAgLjQuMi40LjRzLS4xLjMtLjQuMmgtLjV2LS42em0wIC45aC41Yy4yIDAg'
    b'LjUuMS41LjQgMCAuMi0uMi40LS41LjRsLS41LS4xdi0uN3ptMi4xLTEtLjUgMi4xLjIuMS4z'
    b'LS45LjcuMmMuMy4xLjMuMy4yLjV2LjVsLjMuMXYtLjdjLjEtLjIgMC0uMyAwLS40IDAgMCAu'
    b'My0uMS4zLS40LjItLjUtLjEtLjctLjUtLjhsLTEtLjN6bS4zLjQuNi4yYy4yIDAgLjQgMCAu'
    b'My40IDAgLjMtLjMuMy0uNS4ybC0uNi0uMS4yLS43eiIvPgogICAgPHBhdGggZmlsbC1ydWxl'
    b'PSJldmVub2RkIiBkPSJtMzI0IDIxOS0uMy42IDEgLjYtLjEuMi0xLS41LS40LjYgMS4xLjYt'
    b'LjEuMi0xLjQtLjggMS0xLjggMS41LjgtLjIuMnoiLz4KICAgIDxwYXRoIGQ9Ik0zMjYuNiAy'
    b'MjAuNyAzMjUgMjIybC42LjdjLjQuNSAxIC4zIDEuNCAwIC41LS40LjYtMSAuMi0xLjRsLS41'
    b'LS43em0wIC40LjMuNGMuMy4zLjMuNi0uMSAxLS40LjMtLjguMy0xIDBsLS4zLS40IDEuMS0x'
    b'eiIvPgogICAgPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtMzI4LjIgMjIzLS43LjQu'
    b'NiAxLS4zLjItLjUtMS4xLS42LjMuNiAxLjJoLS4zbC0uNy0xLjMgMi0xIC43IDEuNC0uMy4x'
    b'em0tLjggNHYtLjNsMS41LS4yLS4xLS41aC4yYzAgLjMuMS40LjUuNXYuMmwtMi4xLjN6Ii8+'
    b'CiAgICA8cGF0aCBkPSJtMzI4IDIyNy42LS40LjJhLjkuOSAwIDAgMC0uMi41YzAgLjUuMy44'
    b'LjYuOC4yIDAgLjQgMCAuNi0uMyAwIDAgLjEuMi40LjIuMyAwIC42IDAgLjYtLjYgMC0uNS0u'
    b'My0uNy0uNi0uNy0uMiAwLS4zLjEtLjQuNCAwLS4zLS4zLS40LS41LS41em0wIC40Yy4yIDAg'
    b'LjQuMS40LjQgMCAuMi0uMS40LS40LjQtLjMgMC0uMy0uMy0uMy0uNSAwLS4zLjItLjMuNC0u'
    b'M3ptMSAwYy4yIDAgLjMuMS4zLjQgMCAuMy0uMi40LS4zLjRhLjQuNCAwIDAgMS0uMy0uNGMw'
    b'LS4yLjEtLjMuMy0uM3oiLz4KICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTMy'
    b'OC43IDIyOS41Yy43LjIuNi43LjYgMS0uMS4zLS40LjUtLjguNC0uNCAwLS41LS4zLS42LS43'
    b'di0uMmMwLS40LS4yLS41LS4zLS41bC0uMyAxLjFoLS4zbC40LTEuNGMuNC4xLjYuMy43Ljd2'
    b'LjNjLjIuMi4yLjQuNS41LjEgMCAuNCAwIC41LS40IDAtLjMtLjMtLjQtLjQtLjV2LS4zem0t'
    b'Mi4xIDIuMS4xLS4zIDEuNC43LjItLjUuMi4xYy0uMS40LS4yLjUuMS43di4ybC0yLS45eiIv'
    b'PgogIDwvZz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1taXRl'
    b'cmxpbWl0PSIyLjYiIHN0cm9rZS13aWR0aD0iLjIiIGQ9Ik0zMTkuMyAyMDIuMyAyODMgMjYz'
    b'aDcyLjd6Ii8+CiAgPGcgZmlsbD0ibm9uZSIgc3Ryb2tlLW1pdGVybGltaXQ9IjIuNiI+CiAg'
    b'ICA8cGF0aCBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iLjEiIGQ9Ik0zMjEuMyAyNTUu'
    b'NWE2LjMgNi4zIDAgMCAwIDMuMiAwYzEuNS0uMyAzLTEuMiA0LjgtMSAxLjQgMCAzLjIgMS4y'
    b'IDUuMyAxLjIgMi4yIDAgMy0uNyA0LjgtMS4xIDEuMy0uMyAyLS4yIDMuNC4yIDEuNi4zIDIu'
    b'NSAxLjIgNS4yIDEiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIu'
    b'NCIgZD0iTTI5My4yIDI1OC4xYzEuMy0xIDMuNC0xLjMgNS0xIDIuMi41IDMuMSAxIDUuNCAx'
    b'IDEuNyAwIDMuMi0xLjEgNS0xLjEgMi44IDAgMi45LjYgNS40IDFhNS42IDUuNiAwIDAgMCAy'
    b'LjIgMCA5LjUgOS41IDAgMCAwIDIuNS0uOGMuOC0uNCAyLjgtLjQgMy44LS4zIDEuOC4yIDIu'
    b'Ni45IDMgMSAxIC4yIDIgLjQgMy4yIDAgMS41LS40IDMtMS40IDQuOS0xLjIgMS4zLjIgMyAx'
    b'LjQgNS4yIDEuNHMzLS44IDQuOC0xLjJjMS40LS4zIDItLjIgMy40LjEgMS42LjQgMi41IDEu'
    b'NSA1LjIgMS4yIi8+CiAgICA8cGF0aCBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0iLjMi'
    b'IGQ9Ik0yODkuMSAyNTZhNy42IDcuNiAwIDAgMSA1LS44YzIuMi40IDMuMSAxIDUuNCAxIDEu'
    b'Ny0uMSAzLjItMS4xIDUtMS4xIDIuOCAwIDIuOS41IDUuNCAxaDIuMmE5LjQgOS40IDAgMCAw'
    b'IDIuNS0uOWMuOC0uMyAyLjgtLjMgMy44LS4yIDEuOC4yIDIuNi44IDMgLjkgMSAuMiAyIC4z'
    b'IDMuMiAwIDEuNS0uNCAzLTEuMiA0LjktMSAxLjMgMCAzLjEgMS4yIDUuMiAxLjIgMi4yIDAg'
    b'My0uOCA0LjgtMS4xIDEuNC0uMyAyLS4xIDMuNC4xIDEuNi40IDIuNSAxLjMgNS4yIDEiLz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTI4NS40IDI2'
    b'MmE2LjMgNi4zIDAgMCAxIDUtMWMyLjEuNSAzIDEuMSA1LjQgMSAxLjcgMCAzLjItMS4zIDQu'
    b'OS0xLjMgMi45IDAgMyAuNyA1LjUgMS4zYTUuOCA1LjggMCAwIDAgMi4yIDAgOC40IDguNCAw'
    b'IDAgMCAyLjUtMWMuOC0uNSAyLjgtLjQgMy44LS4zIDEuOC4yIDIuNSAxIDIuOSAxIDEgLjMg'
    b'MiAuNSAzLjMuMiAxLjUtLjYgMy0xLjYgNC44LTEuNCAxLjMuMSAzLjEgMS42IDUuMyAxLjYg'
    b'Mi4xIDAgMy0xIDQuNy0xLjUgMS40LS4zIDItLjEgMy41LjIgMS42LjQgMi41IDEuNiA1LjIg'
    b'MS4zIi8+CiAgICA8cGF0aCBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik0y'
    b'ODYuNCAyNTguNmMxLjItLjkgMy40LTEuMiA1LS45IDIuMS41IDMgMSA1LjQgMSAuNyAwIDEu'
    b'NC0uMyAyLjItLjUiLz4KICAgIDxwYXRoIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIu'
    b'MiIgZD0iTTI5Ny40IDI1NWMuMyAwIDEuMy0uNSAyLjgtLjUgMi45IDAgMSAwIDMuNi41Ljcg'
    b'MCAyLjUgMCAzLS40bTI1LjQgOC4yYzEtLjIgMS44LS41IDIuNi0uOC43LS4zIDIuNy0uMyAz'
    b'LjgtLjIgMS44LjIgMi41LjggMi45LjhhNi4zIDYuMyAwIDAgMCAzLjIgMGMxLjYtLjMgMy0x'
    b'LjIgNS0xIDEuMi4xIDMgMS4zIDUuMiAxLjMiLz4KICAgIDxwYXRoIHN0cm9rZT0iI2ZmZiIg'
    b'c3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTMzNi43IDI1NC44YzIuMSAwIDIuOS0uOCA0LjgtMS4y'
    b'IDEuMy0uMiAyIDAgMy4zLjIgMS43LjMgMi41IDEuMyA1LjIgMSIvPgogICAgPHBhdGggc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4xIiBkPSJNMjg1LjUgMjYyLjJhNy43IDcuNyAw'
    b'IDAgMSA1LS44YzIuMi40IDMuMS45IDUuNC45IDEuNyAwIDMuMi0xLjEgNS0xLjEgMi44IDAg'
    b'Mi45LjYgNS40IDFhNy41IDcuNSAwIDAgMCAyLjIgMCA5LjggOS44IDAgMCAwIDIuNS0uOGMu'
    b'OC0uNCAyLjgtLjMgMy44LS4yIDEuOC4xIDIuNS43IDMgLjgiLz4KICAgIDxwYXRoIHN0cm9r'
    b'ZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuNSIgZD0iTTI5MCAyNTkuNmMxLjMtLjkgMy41LTEu'
    b'MiA1LjEtLjkgMi4yLjQgMy4xIDEgNS40LjkgMS43IDAgMy4xLTEgNC44LTEgMyAwIDMgLjUg'
    b'NS42IDFhNy40IDcuNCAwIDAgMCAyLjIgMCAxMS4zIDExLjMgMCAwIDAgMi41LS45Yy43LS4z'
    b'IDIuOC0uMyAzLjgtLjIgMS44LjIgMi41LjggMyAuOS45LjIgMiAuMyAzLjIgMCAxLjUtLjQg'
    b'My0xLjMgNC44LTEgMS41IDAgMy4zIDEuMiA1LjMgMS4yIDIuMiAwIDMtLjggNC44LTEuMiAx'
    b'LjMtLjIgMiAwIDMuNC4yIDEuNi4zIDIuNSAxLjMgNS4yIDEiLz4KICA8L2c+CiAgPGcgZmls'
    b'bD0iI2ZjMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS13aWR0'
    b'aD0iLjIiPgogICAgPHBhdGggZD0iTTI5MSAyNDkuNWMuNCAwIDEuMi0uNiAxLjUtLjguMy0u'
    b'Mi41LS43LjgtMWwxLjUtMWExMC44IDEwLjggMCAwIDAgMy41LTMuMSAxNy44IDE3LjggMCAw'
    b'IDEgNS43LTUuMmMuOC0uNCAxLjktLjMgMi43IDBsLjguN2MxIC43IDIuMyAxLjMgMy45IDEu'
    b'OCAxLjUuNCAxLjkgMS40IDMgMi41LjcuNSAxLjMgMSAyIDEuM2wuNC40IDIgMS40YTY3IDY3'
    b'IDAgMCAxIDMuMiAzLjFsLjQuN2MuOC43IDEuNiAxLjUgMi42IDJsMi43IDEuNmMtOS4yLjQt'
    b'MTcuNy0uMi0yNyAwSDI5OWwtMS44LjFoLTguOGwyLjctNC41eiIvPgogICAgPHBhdGggZD0i'
    b'bTMyNy4zIDI1My43LTIuMy0xLjRjLTEtLjUtMS44LTEuMy0yLjYtMmwtLjQtLjdhNjcgNjcg'
    b'MCAwIDAtMy4yLTMuMWwtMi0xLjQtLjMtLjRhOC41IDguNSAwIDAgMS0yLTEuM2wtMS45LTJh'
    b'Ny41IDcuNSAwIDAgMSAxLjMtLjdjLjYtLjQgMS41LS4zIDIuMiAwbC43LjVjLjguNyAxLjkg'
    b'MS4xIDMuMiAxLjUgMS4zLjQgMS42IDEuMiAyLjYgMi4xLjUuNSAxIC44IDEuNiAxLjFsLjMu'
    b'MyAxLjcgMS4zIDIuNyAyLjUuMy42Yy43LjYgMS4zIDEuMyAyLjEgMS42bDIuMyAxLjRoLTYu'
    b'MnoiLz4KICAgIDxwYXRoIGQ9Im0zMTkuMSAyNDIuNC45LjNjMS4zLjQgMS42IDEuMiAyLjYg'
    b'Mi4xLjUuNSAxIC44IDEuNiAxLjFsLjMuMyAxLjcgMS4zYTYzIDYzIDAgMCAxIDIuNyAyLjVs'
    b'LjMuNmMuNy42IDEuMyAxLjMgMi4xIDEuNi43LjMgMS4zLjggMiAxLjJsNS0uMWMtLjYtLjQt'
    b'MS4yLTEtMi0xLjMtLjctLjMtMS4zLTEtMS45LTEuNWwtLjMtLjUtMi40LTIuMy0xLjYtMS4x'
    b'LS4yLS4zYTYuMiA2LjIgMCAwIDEtMS41LTFjLTEtLjgtMS4yLTEuNi0yLjQtMmE5IDkgMCAw'
    b'IDEtMi45LTEuM2MtLjItLjEtLjQtLjQtLjYtLjQtLjYtLjMtMS41LS40LTIgMGE5LjggOS44'
    b'IDAgMCAwLTEuNC44eiIvPgogICAgPHBhdGggZD0ibTMyNy42IDI0NC40LjguOSAxLjUgMSAu'
    b'Mi4zIDEuNiAxIDIuNCAyLjQuMy41Yy42LjYgMS4yIDEuMiAyIDEuNWwxLjMuOGg2Yy0uNi0u'
    b'NC0xLS44LTEuNy0xbC0xLjUtMS4zLS4zLS40YTkzLjggOTMuOCAwIDAgMC0yLTEuOWwtMS4y'
    b'LS45LS4yLS4yYTUgNSAwIDAgMS0xLjItLjhjLS43LS43LTEtMS4zLTEuOS0xLjZhNy4zIDcu'
    b'MyAwIDAgMS0yLjQtMWwtLjQtLjRjLS42LS4yLTEuMi0uMy0xLjcgMGE5LjUgOS41IDAgMCAw'
    b'LTEuNiAxdi4xeiIvPgogICAgPHBhdGggZD0iTTM0My4zIDI1Mi41YTcuNCA3LjQgMCAwIDAt'
    b'MS4zLS44bC0xLjUtMS4yLS4zLS40Yy0uNi0uNy0xLjItMS4zLTItMS45bC0xLjItLjktLjIt'
    b'LjJhNS43IDUuNyAwIDAgMS0xLjItLjhjLS42LS42LS45LTEtMS41LTEuNGE2LjMgNi4zIDAg'
    b'MCAxIDEtLjdjLjUtLjIgMSAwIDEuNSAwbC40LjRjLjUuNCAxLjIuNyAyIDEgLjkuMiAxIC43'
    b'IDEuNyAxLjMuMy4yLjYuNSAxIC42bC4yLjMgMSAuNyAxLjcgMS42LjIuNCAxLjMgMSAxLjUu'
    b'OWgtNC4zeiIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDYzM2Ii'
    b'IHN0cm9rZS13aWR0aD0iLjEiIGQ9Ik0zMDMuMiAyMzljLjQgMCAuMi0uMi42IDBtLTEuNS41'
    b'Yy41IDAgLjctLjQgMSAwbS0xLjQuM2MuMiAwIC4zLS4yIDEgLjJtLTEuNS40aDFtLTEuNi40'
    b'Yy41LS4xLjcuMiAxLjMuMW0tMS45LjVoMS40bS0yIC42aC43Yy41IDAgLjQuMS44IDBtLTEu'
    b'OS41Yy43IDAgMSAwIDEuNC4ybS0yLjMgMS4xaDEuNG0tMTEgMTBjMS44LS40IDQgMCA2LS4z'
    b'bTMuOC0xMC4zYy41LS4yLjQgMCAxIDBoLjdtLTIuNCAxLjFjLjUtLjIgMSAwIDEuNSAwbS0u'
    b'My41Yy0uNS0uMS0xIDAtMS42IDBtMS4yLjZhMi45IDIuOSAwIDAgMC0xLjcgMG0tLjguNGMu'
    b'NyAwIDEuNC0uMiAyLjEgMG0tMi42LjZjLjctLjMgMS40IDAgMi4yIDBtLTMgLjRoMi4zYy4x'
    b'IDAgLjQtLjIuNSAwbS0uMi40Yy0xLjIuMi0yLjMgMC0zLjUuMW0yLjguNWMtLjMgMC0xIC4y'
    b'LTEuNS4xaC0uM2E0LjIgNC4yIDAgMCAwLTEuNy4xbS0uMi40YTEgMSAwIDAgMSAuNyAwaDIu'
    b'MWwuNi4zbS0zLjkgMGgxLjZsMiAuNG0tNCAwYy41IDAgMSAwIDEuNi4ybDIuMS4xbS00LjQg'
    b'MGMuNy4zIDEuNSAwIDIuMi4ybDIuMS4ybS00LjguMmMxLjEgMCAyLjIgMCAzLjQuMi4zIDAg'
    b'LjguMiAxLjIuMW0tNSAuMmMxLjEuMiAyLjIgMCAzLjMuM2wxLjUuMm0tNS4yLjMuMy0uMWgy'
    b'LjZjLjcgMCAxLjUgMCAyLjIuMm0tNS41LjVjMS43LS4yIDMuNSAwIDUuMiAwbS01LjUuNWMx'
    b'LjguMiAzLjcgMCA1LjUuMW0tNS44LjRjLjguMiAxLjYgMCAyLjQuMS42LjEgMS4xLjIgMS43'
    b'LjFoMS41bTcuNC03LjZoLjJtLS40LjJoLjJtLS40LjNoLjRtLS41LjJoLjRtLS44LjMuOC4x'
    b'bS0xIC40IDEtLjFoLS4xbS0xLjMuNWgxLjNtLTEuNi40aDEuNG0tMS42LjRoMS42bS0yIC41'
    b'IDEgLjJjLjMuMS42IDAgLjggMG0tMS44LjIgMS42LjJtLTIgLjJjLjUgMCAxIDAgMS40LjJo'
    b'LjZtLTIuNS40Yy41LS4yIDEuMiAwIDEuOC4xaC42bS0yLjUuNGMuNi0uMiAxLjMtLjIgMiAw'
    b'aC4zbS0yLjcuNWMuOC4xIDEuNy0uMSAyLjYuMW0tMi45LjJjLjcuMyAxLjUgMCAyLjIuMi4z'
    b'LjEuNS4xLjggMG0tMy41LjRjLjMtLjEuNy0uMiAxLS4xLjguMiAxLjYuMSAyLjMuMm0tMy42'
    b'LjRjLjEgMCAuMy4xLjQgMGgzLjJtLTQgLjRjMSAuMyAxLjggMCAyLjcuM2gxLjJtLTQuMS4z'
    b'YzEuMyAwIDIuNSAwIDQgLjJtMy4zLTcuNWguM20tLjUuM2guNW0tLjYuNGguNm0tLjguNWgu'
    b'OG0tMSAuNSAxLS4xbS0xLjEuNGgxbS0xLjIuNmgxLjNtLTEuMy40aDEuNG0tMS42LjZoMS41'
    b'bS0xLjcuNWMuMiAwIC40LS4yLjYtLjFoMW0tMS43LjZjLjYtLjIgMS4yLjIgMS44LS4ybS0y'
    b'IC44aDJtLTIgLjVjLjYtLjIgMS40IDAgMiAwbS0yLjUuNSAyLjgtLjJtLTIuNy43YzEtLjIg'
    b'MiAwIDMuMS0uMW0tMy4zLjdjMSAuMSAxLjMgMCAyLjMtLjFsMS4yLS4yaC42bS00IC42YzEu'
    b'NS0uMiAzIC4xIDQuNi0uM20tMTEuMyAwaDEuMm00LjcuM2MuMiAwIC4zLS4xLjQgMG01LjQt'
    b'LjFjMS4zLS4yIDIuNS4yIDMuOCAwbS00LjQtLjVjLjgtLjIgMS41IDAgMi4zLjFsLjEuMmgy'
    b'bS04LjktLjNoLS44bS00LjEtLjItMS43LjFtMTIuMS0xMS44aC4zbS0uMi4zaC4zbS0uMi42'
    b'LjQtLjFtLS4zLjRoLjZtMCAuNGgtLjVtLjMuNmEuOC44IDAgMCAxIC41LS4xbS4zLjRoLS44'
    b'bS4yLjQuOC0uMW0uMi42aC0uOW0uMi42Yy40IDAgLjcgMCAxLS4ybTAgLjMtLjkuMm0uMi42'
    b'Yy40LS4yLjkgMCAxLjItLjJtLjEuNWgtLjlsLS4zLjFtLjIuOGMuMy0uMS41LS4zLjgtLjNo'
    b'LjZtLjIuNC0xLjQuMm0uMS42IDEuNi0uM20tMS41IDEgMS44LS40bS40LjRjLS43LjEtMS40'
    b'IDAtMiAuM20uMi42cy4xLjEuMiAwYTQgNCAwIDAgMSAyLS4zbTAgLjRjLS41LjQtMS4zLjIt'
    b'MiAuM2gtLjJtLjIuNSAyLjMtLjJtLjUuNWgtMS44Yy0uMyAwLS41LjItLjguM20wIC41aC40'
    b'Yy44LS41IDEuNi0uNCAyLjUtLjRtLjIuNWMtLjcgMC0xLjQtLjItMi4xIDAtLjMuMS0uNS4z'
    b'LS44LjNtLjMuNSAxLS4zaDIuNG0wIC40Yy0uNC0uMS0xLS4yLTEuMyAwLS43LjEtMS4zLjMt'
    b'MiAuM20uNC40Yy41IDAgMS0uMyAxLjYtLjRoMS4zbS0zIC43YzEtLjEgMS43IDAgMi42LS4z'
    b'aC45bTAtLjNjMS40LjEgMi44LS4xIDQuMS4ybS0zLjguMy40LS4xaDMuNG0tLjQtMi45aC4y'
    b'bS0uMS40Yy4xIDAgLjItLjIuNCAwbS0uMy40aC43bS0uNS42Yy4yLS4zLjYgMCAuOC0uMm0t'
    b'LjYuOGMuMy0uMy43IDAgMS0uM20tMSAuN2MuNS0uMiAxIDAgMS40LS4zbS0xLjIuN2MuNy0u'
    b'MyAxLjUuMSAyLjEtLjRtLTIgLjdjLjgtLjIgMS43IDAgMi42IDBtLjYgMGg0LjZtLTUuMy0u'
    b'NmMxLjQuMiAzLjQgMCA1LjEuMm0tMTIuNi0xMC42IDEuMS0uMm0tLjguNCAxLjItLjFtLS43'
    b'LjYuOC0uMmguNG0tLjkuNGgxLjVtLjIuMy0xLjIuMW0uOC41IDEtLjJtLjUuNGgtMS4ybS42'
    b'LjUgMS0uMm0uNi41aC0xbS41LjUgMS4yLS4xbS40LjItMSAuMm0uNS41Yy4zLS4yLjkgMCAx'
    b'LjMtLjJtLjQuNWgtMWwtLjQuMW0yLjYuOC0xLjUuMW0uNS42Yy41LS4yIDEuMS0uMiAxLjYt'
    b'LjNtLS40IDEuN2guOGMuOC0uMiAxLS40IDEuNy0uM20uNS40LTIuMi4yLS40LjFtLjQuNGMu'
    b'OC0uMiAyLS4xIDIuNy0uM20uOC41LTIgLjEtMSAuMW0uNy41aC4zYy42LS40IDEuNy0uNCAy'
    b'LjYtLjRtLjUuNWgtMS45bC0uOS4ybS44LjVjLjgtLjIgMi4zLS4zIDEuNC0uM2gxLjltLjIu'
    b'M2E0LjMgNC4zIDAgMCAwLTEuNSAwYy0uNC4yLS4zLjMtMS40LjNtLjQuMiAxLjItLjEgMS41'
    b'LS4xbS0yLjQuNGgyLjdtLTE2LjItMTFoLjdjMC0uMi4yIDAgLjMtLjJoLjNtLTEuNy0uMmgu'
    b'OGMtLjEtLjIuMiAwIC4yLS4xaC40bTUuNSA2Yy4yLS4xLjItLjIuNi0uMS0uMS0uMi4zIDAg'
    b'LjQtLjFoLjVtMCAxLjVjLjUgMCAxLjIgMCAxLjctLjNtLjguNmMtLjYuMS0xLjYgMC0yLjEu'
    b'M20tOC04LjRjLS42IDAtLjcuMi0xLjEuMm04IDEuNiAxLS4ybS0uNy41Yy40LS4xLjcgMCAx'
    b'LS4ybS0uNy41LjctLjFoLjRtLS43LjRoMS4ybS4zLjJhNCA0IDAgMCAwLTEuMi4ybS40LjQg'
    b'MS4zLS4ybS41LjMtMS4zLjFtLjQuNGMuMyAwIDEuMiAwIDEuMy0uMm0uNS41aC0xLjJtLjQu'
    b'NCAxLjMtLjFtLjQuMmMtLjIuMi0uOS4yLTEuMS4zbS42LjRjLjMtLjIuOCAwIDEuMi0uMm0u'
    b'NC40aC0xYzAgLjEtLjEuMi0uMy4xbTIuNC44LTEuNC4xbS41LjVjLjQtLjIgMS0uMiAxLjUt'
    b'LjNtLS4zIDEuNy42LS4xYy44LS4xLjktLjMgMS42LS4zbS40LjQtMiAuMi0uNC4xbS40LjNj'
    b'LjcgMCAxLjggMCAyLjUtLjJtLjcuNC0xLjcuMS0xIC4ybS42LjRoLjNjLjYtLjQgMS41LS4z'
    b'IDIuNC0uM20uNS40SDMzMmwtLjkuMm0uNi40IDEuNS0uMmgxLjdtLjIuM2gtMS40Yy0uMiAw'
    b'LS4zLjItMS41LjJtLjQuMyAxLjMtLjJoMS40bS0yLjEuNCAxLjctLjFoLjdtLTE1LTEwLjFj'
    b'LjMtLjEuMi0uMi41LS4xbC41LS4xaC4zbS0xLjcgMGMuMi0uMi4yLS4zLjYtLjJsLjQtLjFo'
    b'LjRtNS4yIDUuNWMuMi0uMSAwLS4yLjQtLjEtLjEtLjIuMyAwIC40LS4xaC41bTAgMS41IDEu'
    b'NS0uNG0uOC42Yy0uNi4xLTEuNCAwLTEuOC4ybS03LjUtNy42YTIuMyAyLjMgMCAwIDAtMS40'
    b'LjVtOC42IDIuNS45LS4xbS0uNy4zIDEtLjFtLS43LjQuNy0uMWguM20tLjcuM2gxLjFtLjIu'
    b'MmgtLjltLjUuNC44LS4ybS40LjNoLTFtLjMuNCAxLS4ybS40LjRoLTFtLjQuMyAxLS4xbS4z'
    b'LjItLjkuMm0uMy4zIDEuMS0uMW0uMy4zaC0xbTEuOS43LTEuMi4xbS40LjMgMS4yLS4ybS0u'
    b'MyAxLjJoLjZsMS4yLS4ybS4zLjMtMS41LjJoLS40bS4zLjMgMi0uMm0uNi4zSDMzNmE3LjMg'
    b'Ny4zIDAgMCAxLS45LjJtLjUuNC42LS4yIDEuNi0uMW0uMy4zSDMzN2wtLjkuM20uNi4yIDEu'
    b'Mi0uMmgxLjNtLjIuMmgtMWMtLjMuMS0uNS4yLTEuMy4ybS4zLjIgMS0uMSAxLjEtLjFtLTEu'
    b'Ny40aDEuNGwuNS0uMW0tMTEuNS03LjdjLjIgMCAuMi0uMi41LS4yaC42bS0xLjQgMGMuMi0u'
    b'MS4yLS4yLjUtLjJoLjZtMy44IDQuMi41LS4xaC4zYzAtLjEuMyAwIC40IDBtMCAxYy4zIDAg'
    b'LjggMCAxLjEtLjJtLjYuNGMtLjQuMS0xIDAtMS41LjJtLTUuNi01LjljLS40IDAtLjUuMi0u'
    b'OC40bTcgLjkgMS0uMW0tLjcuMy45LS4xbS0uNi40LjYtLjFoLjNtLS42LjQgMS0uMm0uMi4y'
    b'Yy0uMiAwLTEgMC0xIC4ybS40LjJzLjctLjIuOS0uMW0uNC4yLTEgLjFtLjMuMiAxLS4xbS4z'
    b'LjMtMSAuMW0uNC4zIDEtLjFtLjMuMS0xIC4ybS40LjMgMS0uMW0uMy4zaC0xbTEuOC42LTEg'
    b'LjFtLjIuMyAxLjMtLjJtLS40IDEuMi41LS4xYy42IDAgLjctLjIgMS4yLS4xbS4yLjJhMTIu'
    b'NCAxMi40IDAgMCAxLTEuNy4ybS4yLjNhMzYuMyAzNi4zIDAgMCAxIDEuOS0uMm0uNS4zSDM0'
    b'MmwtLjguMm0uNC4zLjUtLjEgMS41LS4ybS40LjNoLTEuMmwtMSAuMm0uNi4zIDEuMi0uMmgx'
    b'LjJtLjIuMmEzIDMgMCAwIDAtMSAwIDMgMyAwIDAgMS0xLjIuMm0uMy4xIDEtLjFoMW0tMS43'
    b'LjNoMS4zbC41LS4xbS0xMC42LTcuMS40LS4xaC42bS0xLjMtLjFjLjIgMCAuMi0uMi40LS4x'
    b'aC40bC4yLS4xbTMuNiAzLjloLjRjMC0uMi4yIDAgLjMtLjFoLjNtMCAxYy4zIDAgLjggMCAx'
    b'LjEtLjJtLjYuNC0xLjUuMW0tNS01LjRjLS41IDAtLjYuMi0uOS4zIi8+CiAgPGcgZmlsbD0i'
    b'I2ZjMCI+CiAgICA8cGF0aCBkPSJtMjg3LjYgMjk4LjYuNiA0LjVjLTEuMS0uNC0yLjIuMi0y'
    b'LjcgMS4yLS45IDEuNy0uMSAzIDEuNSAzLjdsMi4xIDEuMiA0LTcuOC0xLjYtLjgtMS42IDMu'
    b'MS0uNC00LjEtMS45LTF6bS42IDUuOS45LjNoLjFsLTEgMi4yLS4zLS4xYy0uNy0uNC0xLjIt'
    b'LjktLjgtMS43LjMtLjYuNy0uOCAxLjEtLjd6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2'
    b'ZW5vZGQiIGQ9Im0yODAuNyAzMDIuNyAxLTEuNi0yLjMtMS42LjgtMS4yIDIuMyAxLjYgMS40'
    b'LTItMi41LTEuNi45LTEuMyAzLjggMi43LTQuOCA3LjItMy45LTIuNi44LTEuMnoiLz4KICAg'
    b'IDxwYXRoIGQ9Im0yNzkgMjkyLjUtMiAyLjUtLjctLjZjLTEuNC0xLjItMi44LTEuMi00IC4y'
    b'LTEuMyAxLjUtLjggMi45LjYgNC4xbDEuOSAxLjYgNS42LTYuNy0xLjMtMS4xem0tNC40IDIu'
    b'OGMuMyAwIC43LjMgMSAuNmwuMy4yLTEuNiAxLjgtLjItLjJjLS43LS42LTEtMS0uNC0xLjku'
    b'NC0uNC42LS41IDEtLjV6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Im0y'
    b'NjguNCAyOTQuNi0xLjItMS4zIDMuNi0zLjNjLjgtLjcgMS45LTEuOC45LTMtMS0xLTIuMyAw'
    b'LTMgLjZMMjY1IDI5MWwtMS4yLTEuMyAzLjktMy41YzEuNi0xLjQgMy40LTEuOCA1IDAgMS43'
    b'IDEuOCAxLjEgMy42LS41IDVsLTMuOCAzLjV6Ii8+CiAgICA8cGF0aCBkPSJNMjY1LjEgMjc4'
    b'LjFjLS41IDAtMSAuMS0xLjUuNS0uOC41LTEuNCAxLjUtLjkgMi41LS42LS4zLTEuMyAwLTEu'
    b'OS4zLTEuNCAxLTEuNCAyLjItLjQgMy42bDEuMyAxLjggNy4yLTUtMS42LTIuMmMtLjYtLjgt'
    b'MS4zLTEuNC0yLjItMS41em0wIDEuOWMuNSAwIDEgLjQgMS4zLjlsLjIuMy0xLjggMS4yLS4y'
    b'LS4yYy0uNC0uNi0uOS0xLjQgMC0ybC41LS4yem0tMi41IDIuNWMuMyAwIC42LjIuOC42bC4x'
    b'LjItMS43IDEuMnYtLjJjLS41LS42LS42LTEgLjEtMS41bC43LS4zeiIvPgogICAgPHBhdGgg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtMjY0LjYgMjc1LjMtNy43IDQuMi0uOC0xLjYgNi4z'
    b'LTMuNC0xLjEtMi4yIDEuMi0uN3ptLTExLjQtMy41IDgtMy41LjYgMS42LTggMy41em0tMS05'
    b'LjVhMi43IDIuNyAwIDAgMC0uMyAyLjJjLjYgMS41IDIuMyAyIDMuNyAxLjUgMS40LS40IDIu'
    b'NS0xLjggMi0zLjRhMi44IDIuOCAwIDAgMC0xLjUtMS42bDEuOS0uNmMuNS41IDEgMSAxLjEg'
    b'MS44YTQuNSA0LjUgMCAwIDEtMi45IDUuNmMtMi40LjctNS0uMy01LjgtMi44YTQuNyA0Ljcg'
    b'MCAwIDEtLjItMi4xbDItLjZ6Ii8+CiAgICA8cGF0aCBkPSJtMjU2LjQgMjUwLjYtOC4yIDUg'
    b'LjIgMS4zIDkuNCAyLS4zLTEuOS0yLS40LS41LTMuMSAxLjctMS0uMy0xLjl6bS0yLjcgMy42'
    b'LjQgMi4xLTMuMy0uNCAyLjktMS43em0tMi0xOS45Yy0yLjIgMC00IDEuNi00LjIgNGwtLjIg'
    b'Mi42IDguNy43LjItMi41YTQuMyA0LjMgMCAwIDAtNC00LjhoLS40em0tLjMgMmEzIDMgMCAw'
    b'IDEgLjYgMGMxLjYuMSAyLjYgMSAyLjQgM3YuMmwtNS4yLS40di0uM2MuMS0xLjYuOS0yLjQg'
    b'Mi4yLTIuNXoiLz4KICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTI1MC4yIDIy'
    b'OS41IDEuOS40LjYtMi44IDEuNC4zLS42IDIuOCAyLjMuNS42LTIuOSAxLjUuMy0xIDQuNi04'
    b'LjUtMS44IDEtNC42IDEuNC4zem0zLjMtMTEuNCAxLjguNiAxLTIuNiAxLjQuNi0xIDIuNiAy'
    b'LjIuOCAxLTIuNyAxLjQuNS0xLjcgNC40LTguMS0zLjEgMS43LTQuNCAxLjQuNXptOC45LTIu'
    b'My03LjgtNCAuOC0xLjUgNi40IDMuMyAxLjItMi4yIDEuMy42em0xLjktMTUuOWMtLjYgMC0x'
    b'IC4yLTEuNC43YTEgMSAwIDAgMCAwIDEuNWMxLjMuOCAzLTIuNCA1LjMtLjcgMS40IDEgMS43'
    b'IDIuNy42IDQuMi0uOCAxLTEuOSAxLjMtMyAxLjJsLS4yLTEuNmMuNy4zIDEuNS4xIDItLjUu'
    b'NC0uNi4yLTEuMy0uNC0xLjctLjctLjUtMS40IDAtMiAuNC0xIC43LTIgMS0zLjEuMmEyLjYg'
    b'Mi42IDAgMCAxLS42LTMuNiAzLjkgMy45IDAgMCAxIDIuMy0xLjVsLjUgMS40eiIvPgogICAg'
    b'PHBhdGggZD0ibTI2OC4xIDE5Mi4zLTEgMSA0IDguNyAxLjMtMS40LS43LTEuNyAyLjEtMi4z'
    b'IDEuOC44IDEuMy0xLjQtOC43LTMuOHptMS40IDIuNCAyLjggMS4zLTEuNCAxLjQtMS40LTIu'
    b'N3oiLz4KICAgIDxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0ibTI3OC4zIDE5NS01LjUt'
    b'Ni44IDEuNC0xLjEgNC41IDUuNiAyLTEuNiAxIDEuMnptNC41LTE0IDEuNi0xIDEuOCA5LjUt'
    b'LjguNS03LjgtNS43IDEuNi0xIDUgMy44eiIvPgogICAgPHBhdGggZD0ibTI5MC42IDE3Ni44'
    b'LTEuMy42LjUgOS42IDEuNy0uN3YtMmwyLjgtMS40IDEuNCAxLjQgMS43LS43LTYuOC02Ljh6'
    b'bS4zIDIuOSAyLjIgMi4yLTEuOC44LS4zLTN6bTkuNC02LTEuNC4zLTIuNC43IDIuNSA4LjMg'
    b'Mi40LS42YTQuMyA0LjMgMCAwIDAgMy01LjVjLS42LTEuOS0yLjEtMy4xLTQtMy4xem0wIDEu'
    b'OWMxIDAgMS44LjcgMi4yIDIgLjQgMS40IDAgMi43LTIgMy4ybC0uMi4xLTEuNS01IC4zLS4x'
    b'IDEuMi0uMnptMTAuNS00LjNoLS41YTQuNCA0LjQgMCAwIDAtMy44IDUuMSA0LjQgNC40IDAg'
    b'MCAwIDUgNCA0LjUgNC41IDAgMCAwIDMuOS01LjEgNC41IDQuNSAwIDAgMC00LjYtNHptLS4y'
    b'IDEuOWMxLjQtLjIgMi41IDEgMi43IDIuMy4yIDEuMS0uNyAyLjgtMiAzLTEuNC4xLTIuNi0x'
    b'LjItMi44LTIuNC0uMS0xLjMuNy0yLjcgMi4xLTIuOXptNy40LTIuNHY4LjhoMS43VjE3Nmwy'
    b'LjIgMy41aDIuMWwtMi41LTMuN2MxLjItLjEgMS45LTEuMiAxLjktMi40IDAtMS44LTEuMi0y'
    b'LjYtMy0yLjZIMzE4em0xLjggMS42aC4zYy44IDAgMS41LjIgMS40IDEuMiAwIDEtLjYgMS4y'
    b'LTEuNSAxLjJoLS4ydi0yLjR6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Im0zMzYuNiAxNzQuMy0uNSAyIDIuNy42LS4zIDEuNC0yLjgtLjctLjUgMi4zIDIuOC44LS40'
    b'IDEuNC00LjUtMS4yIDIuMS04LjQgNC41IDEuMS0uMyAxLjV6bTYuNiAwIDEuMi41IDIuMSA3'
    b'LjUgMi4yLTUuNSAxLjcuNy0zLjMgOC4zLTEuMi0uNS0yLjItNy41LTIuMiA1LjUtMS42LS42'
    b'em05LjMgMTQuMyA0LjctNy40IDEuNSAxLTMuOSA2IDIuMSAxLjQtLjggMS4yeiIvPgogICAg'
    b'PHBhdGggZD0ibTM2NS40IDE4Ni42LTguNCA0LjcgMS40IDEuMiAxLjgtMSAyLjQgMi0uNiAy'
    b'IDEuNSAxLjEgMy05LjEtMS4xLS45em0tMS4zIDIuNS0xIDMtMS42LTEuMyAyLjYtMS43em0x'
    b'NC4zIDExLjItOS4yIDIuMyAxIDEuNSAyLS40IDEuOCAyLjUtMSAxLjcgMSAxLjUgNS4zLTgt'
    b'LjktMS4yem0tMS44IDItMS44IDIuNi0xLjEtMS42IDIuOS0xeiIvPgogICAgPHBhdGggZmls'
    b'bC1ydWxlPSJldmVub2RkIiBkPSJtMzc1LjQgMjExLjktLjgtMS42IDguNy0yLjcuNiAxLjEt'
    b'NC4xIDQuNiA2LS42LjYgMS4xLTcuMyA1LjMtLjktMS42IDQuNi0zLjEtNiAuNi0uMi0uNSA0'
    b'LTQuM3ptMTEuNiA4LjMtMS44LjYgMSAyLjctMS41LjUtLjktMi43LTIuMi43IDEgMi44LTEu'
    b'NS41LTEuNS00LjUgOC4zLTIuNyAxLjUgNC40LTEuNC41eiIvPgogICAgPHBhdGggZD0ibTM5'
    b'MC4zIDIyNS43LTguNiAxLjguNCAxLjggMy40LS44LTMgMyAuNiAyIDMtMy4yYTIuMiAyLjIg'
    b'MCAwIDAgMi43IDEuMmMxLjktLjMgMi40LTEuNyAyLTMuNGwtLjUtMi40em0tMS4xIDIuMXYu'
    b'MmMuMi45LjEgMS42LS44IDEuNy0xIC4zLTEuMy0uMy0xLjUtMS4ydi0uMmwyLjMtLjV6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Im0zOTIgMjM2LTguNiAxLS4yLTEu'
    b'NyA4LjctMXptLTEuOCA5LjVhMyAzIDAgMCAwIC44LTJjMC0xLjctMS41LTIuNy0zLTIuNi0x'
    b'LjUgMC0zIDEtMi45IDIuNiAwIC44LjQgMS41IDEgMmgtMmE0LjggNC44IDAgMCAxLS42LTIg'
    b'NC41IDQuNSAwIDAgMSA0LjQtNC41YzIuNSAwIDQuNyAxLjcgNC44IDQuNGE0LjQgNC40IDAg'
    b'MCAxLS41IDJoLTJ6Ii8+CiAgICA8cGF0aCBkPSJtMzgzLjcgMjQ3LjEtLjIgMS45IDEuOC45'
    b'LS40IDMuMS0yIC41LS4yIDEuOCA5LjMtMi4yLjItMS40LTguNS00LjZ6bTMgMy42IDIuNyAx'
    b'LjItMyAuNy4zLTJ6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0zODQg'
    b'MjcyLjFhMi44IDIuOCAwIDAgMCAxLjYtMS41Yy43LTEuNi0uNC0zLTEuOC0zLjYtMS4zLS41'
    b'LTMtLjEtMy43IDEuNGEyLjggMi44IDAgMCAwIC4yIDIuMmwtMi0uN2E0LjkgNC45IDAgMCAx'
    b'IC4zLTIuMSA0LjUgNC41IDAgMCAxIDUuOC0yLjVjMi40LjkgMy43IDMuNCAyLjggNS45YTQu'
    b'NiA0LjYgMCAwIDEtMS4zIDEuN2wtMS45LS44em0tMS40IDQuNy0xLjctLjktMS4zIDIuNS0x'
    b'LjMtLjcgMS4zLTIuNS0yLTEuMS0xLjUgMi42LTEuMy0uNyAyLjMtNC4yIDcuNiA0LjItMi4y'
    b'IDQuMS0xLjMtLjd6bS0xLjcgNi40LS43IDEtNy43LjMgNC43IDMuNS0xIDEuNC03LjMtNS4y'
    b'LjgtMSA3LjctLjMtNC44LTMuNSAxLjEtMS40em0tOSA4LjcgMS4yLTEuMyAxIDEtMy43IDQt'
    b'MS0xIDEuMi0xLjQtNS4yLTUgMS4yLTEuM3oiLz4KICAgIDxwYXRoIGQ9Im0zNjIuOCAyOTAu'
    b'Ny0xLjQgMS4xIDIuMyAyLjgtNC0xLjMtMS42IDEuNCA0LjMgMS4xYy0uOCAxLS42IDIuMi4y'
    b'IDMgMS4xIDEuNSAyLjYgMS4zIDQgLjJsMS44LTEuNi01LjYtNi43em0xLjcgNSAxLjUgMS44'
    b'LS4yLjFjLS42LjUtMS4yLjgtMS44IDAtLjctLjctLjMtMS4zLjQtMS44bC4xLS4yem0tNy4x'
    b'LS40LTEuNiAxIC4zIDEuOS0yLjcgMS42LTEuNS0xLjEtMS42IDEgNy43IDUuNyAxLjEtLjct'
    b'MS43LTkuNXptLTEgNC41LjggM2gtLjFsLTIuNC0yIDEuNy0xeiIvPgogICAgPHBhdGggZmls'
    b'bC1ydWxlPSJldmVub2RkIiBkPSJtMzQ4LjcgMzAwLjMgMy44IDgtMS42LjctMy02LjUtMi40'
    b'IDEtLjYtMS4zeiIvPgogIDwvZz4KPC9zdmc+Cg==', 'SV')

SV = b64_SV
index.append("SV")
index.append("SLV")
index.append("El Salvador")
catalog["SV"] = SV
catalog["SLV"] = SV
catalog["El Salvador"] = SV
country["El Salvador"] = ('SV', 'SLV', 0)
lookup["SV"] = ('SV', 'SLV', 'El Salvador', 0)
lookup["San Salvador El Salvador"] = ('SV', 'SLV', 'El Salvador', 0)
lookup["SLV"] = ('SV', 'SLV', 'El Salvador', 0)
lookup["El Salvador"] = ('SV', 'SLV', 'El Salvador', 0)
details["SV"] = {"continent":"Americas","capital":"San Salvador","currency":"El Salvador Colon | US Dollar","web":".sv","lang":"es-SV","tz":"-06:00","altname":""}
#----------------------------------------------------------------------
b64_SX = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXN4IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InN4LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgY2xpcC1wYXRoPSJ1cmwo'
    b'I3N4LWEpIiB0cmFuc2Zvcm09InNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjZWQy'
    b'OTM5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0wIDBoNzY4djI1NkgzNDEuM0wwIDB6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjMDAyMzk1IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0wIDUx'
    b'Mmg3NjhWMjU2SDM0MS4zTDAgNTEyeiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1y'
    b'dWxlPSJldmVub2RkIiBkPSJtMCAwIDM0MS4zIDI1NkwwIDUxMlYweiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2ZmMCIgZD0ibTE3Mi4zIDE5My4yLjEtNHMtMi4xLTMuNC40LTdjMCAwLTUuMy0y'
    b'LjgtNC03LjIgMCAwLTQuOC0xLjItNC41LTYuNCAwIDAtNS0uMy01LjYtNC43IDAgMC01LjEu'
    b'OC03LjQtMy40IDAgMC01IDEtNi40LTIuNSAwIDAtNC45IDEuNi03LjctMi41IDAgMC01LjIg'
    b'Mi4xLTcuMy0xLjgtMi4xIDMuOS03LjMgMS44LTcuMyAxLjgtMi44IDQuMS03LjcgMi40LTcu'
    b'NyAyLjQtMS40IDMuNS02LjMgMi41LTYuMyAyLjUtMi4zIDQuMy03LjQgMy40LTcuNCAzLjQt'
    b'LjUgNC40LTUuNiA0LjgtNS42IDQuOGE2IDYgMCAwIDEtNC40IDYuNGMxLjMgNC4zLTQgNy4x'
    b'LTQgNy4xIDIuNiAzLjcuNSA3IC41IDdsLS4xIDMuNyA4NC43LjQiLz4KICAgIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTM3Ny4yIDg0'
    b'My4xdi0zLjVzLTEuOC0zIC40LTZjMCAwLTQuNi0yLjUtMy41LTYuMyAwIDAtNC4yLTEtMy45'
    b'LTUuNiAwIDAtNC41LS4zLTUtNC4xIDAgMC00LjQuNy02LjMtMyAwIDAtNC40LjgtNS42LTIu'
    b'MiAwIDAtNC4zIDEuNS02LjgtMi4xIDAgMC00LjUgMS44LTYuMy0xLjYtMS45IDMuNC02LjQg'
    b'MS42LTYuNCAxLjYtMi40IDMuNS02LjcgMi02LjcgMi0xLjIgMy4xLTUuNSAyLjMtNS41IDIu'
    b'My0yIDMuNy02LjUgMy02LjUgMy0uNCAzLjctNC45IDQtNC45IDRhNS4xIDUuMSAwIDAgMS0z'
    b'LjcgNS42YzEgMy44LTMuNSA2LjItMy41IDYuMiAyLjIgMy4yLjMgNi4yLjMgNi4ydjMuMmw3'
    b'My45LjN6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjE0NjQgMCAwIDEuMTQ2MSAtMjYwIC03NzMu'
    b'MSkiLz4KICAgIDxwYXRoIGZpbGw9InJlZCIgZD0iTTE3MC4zIDE4OC4yYy0xMy4zLTEuMy0y'
    b'OC42LTQuNS00MC40IDIuMi04LTQuNy0xOS00LjQtMjguNC0zLjUtNS4xIDEtMTEuMSAxLTE2'
    b'LjUgMS44bC0uOC4xYy05LjcuNy0xOC41LTIuMi0yNy02IDIuOCAxNS4yIDUuNyAzMC43IDcu'
    b'MiA0Ni42QzY3LjYgMjUzIDUzLjMgMjcyLjcgNTkgMjk2YzMuNSAxMS4yIDE1LjggMTcuNyAy'
    b'NyAxOWEyMTQuNyAyMTQuNyAwIDAgMSAzMi4yIDQuNSAzMiAzMiAwIDAgMSA1LjUgMS45IDE5'
    b'LjcgMTkuNyAwIDAgMSA2LjYgNC43YzYtNi4zIDE1LTguMSAyMy43LTkgMTUuOC0xLjkgMzUu'
    b'My0uOSA0NS0xNS4ydi0uOGM1LjMtOCA0LjYtMjAgMi4zLTI5LS4yLTMuMS0xLTUuOS0xLjUt'
    b'OC45LTkuNi0yNS41LTEuMy01NC4yIDIuOC04MGE2MSA2MSAwIDAgMS0xNi40IDUuNWMtNC41'
    b'LjYtOS41LjQtMTQgLjFsLTItLjUiLz4KICAgIDxwYXRoIGZpbGw9IiM4MGNmZTEiIGQ9Ik0x'
    b'OTAuMiAyNjEuNWMwIDEuNi45IDMgMS4yIDQuNSAxLjkgMTEuMiAzLjYgMjYtNy44IDMyLjkt'
    b'MTIuOCA4LTI5LjQgNC42LTQ0LjEgOC45LTMgLjgtNyAzLjUtOSA1LjQtMS40LS45LTIuNy0y'
    b'LjItNC40LTMtMTIuMS02LjQtMjcuOS00LjMtNDEuNS03LjgtNi45LTIuMS0xNC03LjUtMTUu'
    b'OC0xNC41LTQuNC0xOC40IDYuMi0zNC4xIDUtNTIuNC0uOC0xNC0zLjItMjcuMy02LjQtNDAu'
    b'NCAxMC43IDUgMjMgNS44IDM1IDMuNEE1MS42IDUxLjYgMCAwIDEgMTMwIDIwMWM0LjYtMiAx'
    b'MC0yLjkgMTUtMy40IDkuMyAxIDE5LjQgMi42IDI5LjEgMi42IDYuNS0uNCAxMi40LTIuMiAx'
    b'OC00LjctMy4zIDIxLjYtOS44IDQ0LjItMS45IDY2Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZm'
    b'IiBkPSJNMTcxIDI2NS44di0yMC40aDIuNGwtMzEtMjAtLjEtMTAuNWgzbC0xNS42LTExLTE1'
    b'LjQgMTFoM3YxMC41bC0zMC45IDIwaDIuNXYyMC4zSDE3MSIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTM3NiA5MDYuNXYt'
    b'MTcuOGgyLjFsLTI3LTE3LjUtLjEtOWgyLjZsLTEzLjYtOS44LTEzLjUgOS43aDIuNmwuMSA5'
    b'LjEtMjcgMTcuNWgyLjJ2MTcuN0gzNzZ6IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjE0NjQgMCAw'
    b'IDEuMTQ2MSAtMjYwIC03NzMuMSkiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xODAu'
    b'NiAyOTIuNXY2LjNIODAuNXYtNi40aDEwMCIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTM4NC40IDkyOS44djUuNUgyOTd2'
    b'LTUuNmg4Ny40eiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4xNDY0IDAgMCAxLjE0NjEgLTI2MCAt'
    b'NzczLjEpIi8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNODcuMSAyOTIuMXYtMjEuNWg0'
    b'bC0uMiAyMS43LjItMjEuNi01LjgtLjF2LTQuN2w4OS40LjJ2NC41aC01LjR2MjEuOGwtLjEt'
    b'MjEuOGg0bC4yIDIxLjYiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zMDIuOCA5MjkuNHYtMTguOGgzLjVsLS4yIDE5IC4y'
    b'LTE4LjgtNS0uMnYtNGw3OCAuMXY0aC00LjhsLjEgMTktLjItMTloMy42bC4xIDE4LjgiIHRy'
    b'YW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3My4xKSIvPgogICAg'
    b'PHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0i'
    b'TTMxOS42IDkyNC44di0xMy4xSDMwOXYxM2wxMC41LjEiIHRyYW5zZm9ybT0ibWF0cml4KDEu'
    b'MTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3My4xKSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIg'
    b'c3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTMxMiA5MTQuNHY3LjZoNC44'
    b'di03LjZoLTQuOW01OSAxMC40LS4xLTEzaC0xMC40djEzaDEwLjUiIHRyYW5zZm9ybT0ibWF0'
    b'cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3My4xKSIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTM2My4yIDkxNC41'
    b'djcuNmg0Ljh2LTcuNmgtNC44bTcuNi0xMXYtMTNoLTEwLjV2MTNoMTAuNXoiIHRyYW5zZm9y'
    b'bT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3My4xKSIvPgogICAgPHBhdGgg'
    b'ZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTM2My4x'
    b'IDg5My4ydjcuNmg0Ljh2LTcuNmgtNC44bS00My42IDEwLjN2LTEzLjFIMzA5djEzaDEwLjV6'
    b'IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjE0NjQgMCAwIDEuMTQ2MSAtMjYwIC03NzMuMSkiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIi'
    b'IGQ9Ik0zMTEuOSA4OTMuMXY3LjZoNC44di03LjZoLTQuOG0yNi42IDEwLjR2LTEzLjFIMzI4'
    b'djEzaDEwLjUiIHRyYW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3'
    b'My4xKSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lk'
    b'dGg9IjEuMiIgZD0iTTMzMC44IDg5My4xdjcuNmg0Ljh2LTcuNmgtNC44bTIyLjMgMTAuNHYt'
    b'MTNsLTEwLjUtLjF2MTNsMTAuNS4xIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjE0NjQgMCAwIDEu'
    b'MTQ2MSAtMjYwIC03NzMuMSkiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik0zNDUuNCA4OTMuMXY3LjZoNC45di03LjZoLTQu'
    b'OSIgdHJhbnNmb3JtPSJtYXRyaXgoMS4xNDY0IDAgMCAxLjE0NjEgLTI2MCAtNzczLjEpIi8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMTQ3LjcgMjU3LjguMiAzNC42SDExM2wtLjEt'
    b'MzQuNmgzNC43Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAiIHN0cm9r'
    b'ZS13aWR0aD0iMS4yIiBkPSJtMzU1LjcgODk5LjUuMSAzMC4yaC0zMC4zbC0uMS0zMC4yaDMw'
    b'LjN6bS0zMC41IDguNmgzMC42TTMyOSA5MjkuN3YtMjEuNG0yMy4xIDIxLjR2LTIxLjNtMTQu'
    b'Ny0yMS44LTE3LTEyLjRoLTE5LjNsLTE3IDEyLjRoNTMuM00zMzIgODYzLjh2Ny42aDE2LjJ2'
    b'LTcuNkgzMzIiIHRyYW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3'
    b'My4xKSIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lk'
    b'dGg9IjEuMiIgZD0iTTMzNi40IDg2NS43djMuOGg3LjR2LTMuOGgtNy40TTM0MCA4NTVsOSA2'
    b'LjRoLTE3LjlsOS02LjQiIHRyYW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0y'
    b'NjAgLTc3My4xKSIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTE3MS40IDIwMmMyLjkg'
    b'MCAzLjYgMTIgMy42IDE4IDIuNi44IDguMSA0LjMgMTAuNiA3LjRoLTI4LjJjMi40LTMuMSA3'
    b'LjktNi42IDEwLjQtNy4zIDAtNiAuNi0xOC4yIDMuNi0xOCIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMiIgZD0iTTM3Ni4zIDg1MC44'
    b'YzIuNiAwIDMuMiAxMC41IDMuMiAxNS44IDIuMi42IDcuMSAzLjcgOS4yIDYuNGgtMjQuNmMy'
    b'LjEtMi43IDctNS44IDkuMS02LjQgMC01LjMuNi0xNS44IDMuMS0xNS44bS00OS41IDQ5LjVo'
    b'Mi4ybC0uNiAxLjJzMSAxLjQgMCAzbC42IDFoLTIuMmwuNi0xcy0xLTEuOCAwLTNsLS42LTEu'
    b'Mm00LjUgMGgyLjJsLS42IDEuMnMxIDEuNCAwIDNsLjYgMWgtMi4ybC42LTFzLTEtMS44IDAt'
    b'M2wtLjYtMS4ybTUgMGgyLjFsLS42IDEuMnMxIDEuNCAwIDNsLjYgMWgtMi4xbC41LTFzLTEt'
    b'MS44IDAtM2wtLjYtMS4yem01LjUgMGgyLjJsLS43IDEuM3MxLjEgMS4zIDAgMi45bC42IDFo'
    b'LTIuMWwuNi0xcy0xLTEuOCAwLTNsLS42LTEuMXptNC45IDBoMi4ybC0uNyAxLjNzMS4xIDEu'
    b'MyAwIDIuOWwuNiAxaC0ybC41LTFzLTEtMS44IDAtM2wtLjYtMS4xbTQuOSAwaDIuMmwtLjcg'
    b'MS4yczEuMSAxLjMgMCAyLjlsLjYgMWgtMmwuNS0xcy0xLTEuOCAwLTNsLS42LTEuMSIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoMS4xNDY0IDAgMCAxLjE0NjEgLTI2MCAtNzczLjEpIi8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZmYwIiBkPSJNMTMwLjUgMzM2LjhjMTMgMCAyOS0yLjcgMzYuNS02LjVs'
    b'MTYuNS0xLjUuNCAyMC4xYy0xNCA3LjctNDYuMiA5LjQtNTMuMyA5LjMtNy4xIDAtMzkuNy0x'
    b'LjYtNTMuOC05LjNsLjItMjAuMiAxNi41IDEuNWE5OCA5OCAwIDAgMCAzNyA2LjYiLz4KICAg'
    b'IDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIuMyIgZD0i'
    b'TTM0MC43IDk2OC40YzExLjQgMCAyNS4zLTIuMyAzMS45LTUuN2wxNC4zLTEuMi4zIDE3LjVj'
    b'LTEyLjEgNi43LTQwLjMgOC4yLTQ2LjQgOC4xLTYuMiAwLTM0LjctMS40LTQ3LTguMmwuMi0x'
    b'Ny41IDE0LjQgMS4zYzYuNiAzLjQgMjEgNS43IDMyLjMgNS43IiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgxLjE0NjQgMCAwIDEuMTQ2MSAtMjYwIC03NzMuMSkiLz4KICAgIDxwYXRoIGZpbGw9IiNm'
    b'ZjAiIGQ9Im0zNC40IDI1MSAxNC41IDQuNi00LjQgMjMuNS0xMy43IDIuMnMtMi4zLTEyLjQg'
    b'My42LTMwLjMiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tl'
    b'LXdpZHRoPSIuMyIgZD0ibTI1Ni45IDg5My42IDEyLjYgNC0zLjggMjAuNS0xMiAxLjlzLTIt'
    b'MTAuOCAzLjItMjYuNHoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0y'
    b'NjAgLTc3My4xKSIvPgogICAgPHBhdGggZmlsbD0iIzdlN2U3ZSIgZD0ibTQ0LjUgMjc4Ljkt'
    b'MTMuNyAyLjQgOC43LTEyLjQgNSAxMCIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tl'
    b'PSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtMjY1LjcgOTE3LjktMTIgMiA3LjYtMTAu'
    b'NyA0LjQgOC43IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjE0NjQgMCAwIDEuMTQ2MSAtMjYwIC03'
    b'NzMuMSkiLz4KICAgIDxwYXRoIGZpbGw9IiNmZjAiIGQ9Im0yNS43IDI2OCAxNCAxYy4zIDEx'
    b'LjggMS44IDU3IDU1LjggNTkuNUw5My44IDM0NWMtNjUuNy42LTcwLjctNTUuNS02OC03NyIv'
    b'PgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4z'
    b'IiBkPSJtMjQ5LjMgOTA4LjQgMTIuMi44Yy4zIDEwLjQgMS41IDQ5LjggNDguNyA1MmwtMS41'
    b'IDE0LjRjLTU3LjQuNi02MS43LTQ4LjQtNTkuNC02Ny4yem00NC44IDcwLjEgMTQuNC0zLjEi'
    b'IHRyYW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3My4xKSIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZmMCIgZD0ibTIyNS40IDI1MS4yLTE0LjQgNC42IDQuNiAyMy40'
    b'IDEzLjggMi4yczIuMi0xMi4zLTQtMzAuMiIvPgogICAgPHBhdGggZmlsbD0ibm9uZSIgc3Ry'
    b'b2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNDIzLjUgODkzLjctMTIuNiA0IDQg'
    b'MjAuNSAxMiAyczItMTAuOC0zLjQtMjYuNXoiIHRyYW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAw'
    b'IDAgMS4xNDYxIC0yNjAgLTc3My4xKSIvPgogICAgPHBhdGggZmlsbD0iIzdlN2U3ZSIgZD0i'
    b'bTIxNS42IDI3OSAxMy43IDIuNS04LjgtMTIuNC01IDkuOSIvPgogICAgPHBhdGggZmlsbD0i'
    b'bm9uZSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJtNDE0LjkgOTE4IDEy'
    b'IDIuMS03LjctMTAuNy00LjMgOC42IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjE0NjQgMCAwIDEu'
    b'MTQ2MSAtMjYwIC03NzMuMSkiLz4KICAgIDxwYXRoIGZpbGw9IiNmZjAiIGQ9Im0yMzQuMyAy'
    b'NjguMS0xNCAxYy0uMiAxMS44LTEuMyA1Ny01NS4zIDU5LjVsMiAxNi40YzY1LjcuOCA3MC4y'
    b'LTU1LjQgNjcuNC03Ni45Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiMwMDAi'
    b'IHN0cm9rZS13aWR0aD0iLjMiIGQ9Im00MzEuMiA5MDguNS0xMi4yLjhjLS4yIDEwLjQtMSA0'
    b'OS45LTQ4LjIgNTJsMS42IDE0LjNjNTcuNC43IDYxLjMtNDguMyA1OC44LTY3em0tNDQuMiA3'
    b'MC0xNC40LTMiIHRyYW5zZm9ybT0ibWF0cml4KDEuMTQ2NCAwIDAgMS4xNDYxIC0yNjAgLTc3'
    b'My4xKSIvPgogICAgPHBhdGggZmlsbD0iIzAwOWZjNSIgZD0iTTEyMS44IDM0Ni43Yy0uNC4y'
    b'LTEgLjMtMS41LjJsLTIuNi0uMS4yLTMuMyAyLjYuMmMuNSAwIDEgLjEgMS4yLjMuNS4yLjcu'
    b'Ny43IDEuNCAwIC42LS4zIDEtLjcgMS4zbS00LjMgNSAuMi0zLjkgMyAuMmMxIC4xIDEuOC0u'
    b'MiAyLjMtLjcuNS0uNC44LTEgLjgtMS44YTIuNSAyLjUgMCAwIDAtLjYtMiAzLjIgMy4yIDAg'
    b'MCAwLTItLjlsLTQuNC0uMy0uNiA5LjRoMS4zbTkuNC03LjdoMy4ybDEuMS4yYy41LjMuNy43'
    b'LjcgMS40IDAgLjYtLjEgMS0uNSAxLjNhMi42IDIuNiAwIDAgMS0xLjQuM2gtMy4xVjM0NG0w'
    b'IDguMnYtNGwzIC4xYy41IDAgMSAwIDEuMi4yLjQuMi43LjYuNyAxLjJ2Mi4zbC4yLjNoMS42'
    b'di0uMmEuOC44IDAgMCAxLS40LS41IDMuNCAzLjQgMCAwIDEtLjEtLjh2LTEuM2MwLS42LS4y'
    b'LTEtLjQtMS4yYTEuNyAxLjcgMCAwIDAtLjgtLjZjLjQtLjIuOC0uNSAxLS44LjItLjQuNC0u'
    b'OC40LTEuNCAwLTEtLjUtMS44LTEuNC0yLjJhNC43IDQuNyAwIDAgMC0xLjgtLjRoLTQuNXY5'
    b'LjRoMS4zbTEwLTJhNC41IDQuNSAwIDAgMS0xLTIuNmMwLTEuMy4yLTIuMy44LTNhMy4xIDMu'
    b'MSAwIDAgMSAyLjQtMSAzIDMgMCAwIDEgMi40LjhjLjcuNiAxIDEuNSAxLjEgMi42YTUgNSAw'
    b'IDAgMS0uNiAyLjhjLS41LjgtMS4zIDEuMy0yLjUgMS4zcy0yLS4yLTIuNy0uOW0tMS41LTUu'
    b'OWE2IDYgMCAwIDAtLjggMy4zYy4xIDEuNC41IDIuNiAxLjQgMy40YTQuNiA0LjYgMCAwIDAg'
    b'My42IDEuMyA0LjQgNC40IDAgMCAwIDMuNS0xLjggNiA2IDAgMCAwIDEtMy42IDUgNSAwIDAg'
    b'MC0xLjItMy4xYy0uOS0xLTIuMi0xLjUtMy45LTEuNC0xLjYgMC0yLjguNy0zLjYgMS45bTQ0'
    b'LTEzLjVjMS0uMSAxLjgtLjEgMi41LjEgMSAuNCAxLjcgMS4xIDIuMiAyLjNsLTEuMy4yYTIu'
    b'NCAyLjQgMCAwIDAtMS4yLTEuMyAzLjUgMy41IDAgMCAwLTItLjIgMyAzIDAgMCAwLTIgMS4z'
    b'Yy0uNS43LS43IDEuNy0uNSAzYTQuNSA0LjUgMCAwIDAgMS4yIDIuNmMuNi42IDEuNS44IDIu'
    b'Ni43YTMuMiAzLjIgMCAwIDAgMi0xLjFjLjYtLjYuNy0xLjQuNS0yLjVsLTMgLjUtLjEtMSA0'
    b'LjItLjcuOCA1aC0uOWwtLjUtMS0xIDFjLS41LjUtMS4yLjctMiAuOWE0LjMgNC4zIDAgMCAx'
    b'LTMuMi0uNyA1IDUgMCAwIDEtMS45LTMuNCA1LjEgNS4xIDAgMCAxIC43LTQgNC4xIDQuMSAw'
    b'IDAgMSAzLTEuN205LjQtLjcgMy0xLjFjLjQtLjIuOC0uMiAxLjEtLjIuNiAwIDEgLjQgMS4y'
    b'IDEgLjIuNi4yIDEuMSAwIDEuNS0uMy4zLS43LjYtMS4zLjhsLTIuOCAxLTEuMi0zbTMgNy43'
    b'LTEuNC0zLjcgMi44LTFhMyAzIDAgMCAxIDEuMS0uM2MuNS4xLjkuNCAxLjIgMWwuNiAxLjQu'
    b'My43LjIuMyAxLjUtLjZ2LS4yYy0uMyAwLS41LS4xLS42LS40LS4yLS4xLS4zLS40LS40LS43'
    b'bC0uNS0xLjJjLS4yLS41LS41LS44LS43LTFhMi40IDIuNCAwIDAgMC0xLS4ybC42LTEuMmMw'
    b'LS40IDAtLjktLjItMS40LS40LTEtMS0xLjYtMi0xLjZhNC41IDQuNSAwIDAgMC0xLjkuM2wt'
    b'NC4yIDEuNSAzLjQgOC44IDEuMi0uNG0xMS00LjctNS4zLTcuOCA1LjgtMy44LjcgMS00Ljgg'
    b'MyAxLjYgMi40IDQuNS0yLjguNi45LTQuNSAyLjggMS44IDIuNyA1LTMuMi42IDEtNiAzLjht'
    b'NC43LTEzLjggMS41LTEuN2MuOC0uOCAxLjUtMS4xIDIuMy0xIC45IDAgMS43LjUgMi42IDEu'
    b'M2E0LjcgNC43IDAgMCAxIDEuNCAyYy4yLjYuMSAxLjEgMCAxLjZhNCA0IDAgMCAxLS43IDFs'
    b'LTEuNSAxLjYtNS42LTQuOG04LjEgMy42YzEuMS0xLjIgMS4zLTIuNC43LTRhNi43IDYuNyAw'
    b'IDAgMC0xLjctMi4xIDUuMiA1LjIgMCAwIDAtMy4xLTEuNGMtMS4yLS4xLTIuMi4zLTMuMSAx'
    b'LjNsLTIuNiAyLjggNy4yIDYuMyAyLjYtMi44bTUuNi03LjMtOC4zLTUgLjctMSA4LjMgNC45'
    b'LS43IDFtMy4zLTUuNi05LTMuNiAyLjYtNi4zIDEuMS40LTIuMSA1LjIgMi43IDEgMi00Ljcg'
    b'MSAuNC0yIDQuOCAzIDEuMiAyLjMtNS4yIDEgLjQtMi42IDYuNG00LTExLTkuNC0yIC40LTEu'
    b'NSA4LjctMy03LjctMS43LjMtMS4xIDkuNCAyLS4zIDEuNC04LjcgMyA3LjcgMS43LS4zIDEu'
    b'Mm0tLjgtMTIgLjEtMS4yYy42IDAgMSAwIDEuNC0uMi43LS40IDEtMS4xIDEuMi0yLjFhMy43'
    b'IDMuNyAwIDAgMC0uMS0xLjRjLS4yLS43LS42LTEuMi0xLjMtMS4yLS42LS4xLTEgMC0xLjIu'
    b'My0uMy4zLS41LjgtLjcgMS41bC0uNSAxLjJjLS4yLjgtLjUgMS40LS44IDEuNy0uNC42LTEg'
    b'LjgtMS44LjdhMi44IDIuOCAwIDAgMS0yLTFjLS42LS42LS44LTEuNS0uNy0yLjYuMS0xIC40'
    b'LTEuOCAxLTIuNC41LS42IDEuMy0xIDIuNC0uOGwtLjEgMS4yYy0uNSAwLTEgMC0xLjIuMy0u'
    b'Ni4zLS45IDEtMSAxLjkgMCAuNyAwIDEuMi40IDEuNi4zLjQuNi42IDEgLjYuNSAwIC45IDAg'
    b'MS4xLS40bC43LTEuNy40LTEuM2MuMi0uNi41LTEgLjgtMS40LjUtLjUgMS4yLS43IDItLjcg'
    b'MS4xLjEgMS45LjYgMi4yIDEuNC40LjguNiAxLjYuNSAyLjdhMy45IDMuOSAwIDAgMS0xLjIg'
    b'Mi42Yy0uNy42LTEuNS44LTIuNi43bS0xOTUuNi0uNi4zIDEuMmMtLjYuMS0xIC4zLTEuMy42'
    b'LS41LjUtLjcgMS4zLS41IDIuNGE0IDQgMCAwIDAgLjQgMS4yYy40LjcgMSAxIDEuNy45LjUt'
    b'LjEuOC0uMyAxLS43bC4zLTEuNnYtMS4zYzAtLjguMi0xLjUuMy0xLjguMy0uNi45LTEgMS43'
    b'LTEuMi44LS4xIDEuNiAwIDIuMi42LjcuNCAxLjEgMS4yIDEuMyAyLjJhNCA0IDAgMCAxLS4z'
    b'IDIuNmMtLjQuOC0xIDEuMi0yLjEgMS40bC0uMi0xLjFhMyAzIDAgMCAwIDEtLjZjLjUtLjUu'
    b'Ni0xLjIuNS0yLjEtLjItLjgtLjQtMS4zLS44LTEuNWExLjUgMS41IDAgMCAwLTEuMi0uMyAx'
    b'IDEgMCAwIDAtMSAuN2wtLjEgMS44LS4xIDEuM2EzLjUgMy41IDAgMCAxLS40IDEuNiAyLjIg'
    b'Mi4yIDAgMCAxLTEuNyAxLjJjLTEgLjItMi0uMS0yLjUtLjhhNSA1IDAgMCAxLTEuMi0yLjQg'
    b'My44IDMuOCAwIDAgMSAuNS0yLjkgMyAzIDAgMCAxIDIuMi0xLjNtLS42IDEyLjMgOS4zLTIu'
    b'OCAyLjEgNi41LTEuMS40LTEuOC01LjMtMi44LjggMS43IDUtMS4xLjMtMS42LTUtMy4yIDEg'
    b'MS44IDUuNC0xIC4zLTIuMy02LjZtNC4xIDExLjMgOC41LTQuNSAxIDEuNi01LjkgNi4xIDgu'
    b'NS0xLjQuOSAxLjUtOC41IDQuNS0uNi0xIDUtMi43LjktLjQgMS4zLS43LTguNSAxLjUtLjYt'
    b'MS4xIDUuOC02LjItLjMuMi0xIC41YTcgNyAwIDAgMS0uOS41bC01IDIuNi0uNi0xbTE1Ljgg'
    b'MTIuNWMtLjQtLjEtLjgtLjQtMS4yLS44bC0xLjgtMS44IDIuNC0yLjIgMS44IDEuOGEzIDMg'
    b'MCAwIDEgLjcgMWMuMi41IDAgMS0uNSAxLjUtLjUuNC0xIC42LTEuNC41bS02LjguOCAzLTIu'
    b'NyAyIDIuMWMuOC43IDEuNSAxIDIuMiAxYTMgMyAwIDAgMCAyLS44IDMgMyAwIDAgMCAuOC0y'
    b'YzAtLjYtLjMtMS4zLS45LTEuOWwtMy0zLTcgNi40IDEgMW04LjQgNy41IDUuMS04IDYgMy42'
    b'LS42IDEtNS0zLTEuNSAyLjUgNC41IDIuNy0uNSAxLTQuNi0yLjgtMS43IDIuNyA1IDMtLjYg'
    b'MS02LjEtMy43bTE1LTEuNiAzLjEgMSAxIC41Yy40LjQuNS45LjIgMS41LS4yLjYtLjQgMS0u'
    b'OSAxLjFsLTEuNS0uMS0yLjktMSAxLTNtLTIuNiA3LjkgMS4zLTMuOCAyLjguOWMuNS4xIDEg'
    b'LjMgMS4xLjUuMy4zLjQuOC4zIDEuNGwtLjUgMS41LS4xLjd2LjNsMS41LjV2LS4ybC0uMi0u'
    b'Ny4yLS43LjQtMS4yYy4xLS42LjItMSAwLTEuMiAwLS4zLS4zLS42LS42LS45LjUgMCAxLS4y'
    b'IDEuMy0uNS4zLS4zLjYtLjcuNy0xLjIuNC0xIC4yLTEuOS0uNi0yLjVhNS4yIDUuMiAwIDAg'
    b'MC0xLjYtLjlsLTQuMy0xLjMtMyA4LjkgMS4zLjQiLz4KICAgIDxwYXRoIGZpbGw9IiNiYzcx'
    b'NWYiIGQ9Ik03OC41IDE3NS42YzEtMi43IDExLjMtMTAgNDQuOC02LjggMCAwIDUuNyAzLjUg'
    b'OSAzIDItLjItMSAuMi0zLjYtMS45LTIuNS0yLTMtNi4zIDIuNy02LjEgNS44LjEgMjcuMyAx'
    b'LjMgMjcuNyAzLjMuNCAxLjktMTEuNCAyLjctMTUuNyAyLjYtNC40LS4xLTQgMi4xLjQgMiAx'
    b'My43LS42IDI4LjYtNS40IDQ0LjMgNS44IDEuOSAxLjMtNC43IDEuNS05LjgtLjYgMCAwLTE0'
    b'IC43LTIwLS4zIDAgMC00LjUgMy44LTEwLjYgMy40LjggMi0yLjIgOS4yLTIxIDMuNy0zLjIg'
    b'MS0xNC41IDIuOS0xMy4zLS41LTMgMC04LjIgMS05LS43LS44LTEuNyA5LjItNC4yIDExLTYg'
    b'MCAwLTIxLjIuMi0yNS4yLTEuMyAwIDAtMTIuNSAyLjgtMTEuNy40Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjMDA4NzM3IiBkPSJNODUuMyAyMDUuMmMuNC0uNi42LTEuOCAxLjYtMS43IDIgLjUg'
    b'My41IDQuNCA2IDEuOSAxLS4yIDEuMyAxIDIgMS4yLjUgMi4xIDIuMy0uNSAzLjUtLjMgMi44'
    b'LTEuMiA2LjEtMS41IDkuNC0xIDAgMi4yLTEuNiA0LjUtMy42IDUuNyAwIDIgMiAzLjQgMS45'
    b'IDUuNS0uMy44IDAgMi0xLjIgMi4zLTEuNi0uMy0zLS40LTQuMy0xLjMtLjItLjEtLjMtLjQt'
    b'LjYtLjMtLjIuNyAxIDEuNCAxLjQgMi4xLS44IDEuMy0yIC4xLTMuMS4xLS4zLjggMCAxLjct'
    b'LjggMi4yLTEuMyAwLTEuNi0xLjUtMi40LTIuMi0uOS45LjYgMS40LjggMi4xLS42IDIuOC0u'
    b'NSA1LjUtMy4yIDcuM2wtMS45LjljLS41LTEuNC0uMi0zLjUtLjUtNS0xIDEuOC0yIDMuNC0z'
    b'LjUgNC45LTItLjYtMy0yLjgtMy40LTQuN2E1LjggNS44IDAgMCAxIDEuMy02LjJjLS41LTEt'
    b'Mi41LS44LTIuOC0yLjQtMy0yLTQuNSAzLjMtNi40LjZhOC42IDguNiAwIDAgMSAyLTcuNmMt'
    b'LjUtMS0xLjktLjgtMi43LTEuNC0xLjgtMS42LTQuNS0zLjItNC4zLTZhMTQgMTQgMCAwIDEg'
    b'MTQuNyAzLjMiLz4KICAgIDxwYXRoIGZpbGw9IiNmZjAiIGQ9Ik04Ny45IDIwNC45Yy0uMSAy'
    b'LjMgMS41LjYgMi44IDItMS0uNC0xLjcgMS43LTIuNy41bC0uNi42Yy40LjggMSAuOS40IDEu'
    b'OC0xIC40LTEuMy0xLTEuOC0xLjUgMC0uMi4yLS42LS4yLS44LS42LjUtMS4yLjctMiAuNi0u'
    b'Mi0uNC0uNy0xLS4yLTEuNC44LTEgMiAuNCAyLjYtLjMuMS0uNy0uNS0xLjUuMy0yIC41LjEg'
    b'MS4yLS4yIDEuNC41bTYuMiAxLjljLjEuNC0uMiAxIC40IDEuNC44LS40IDEuNi0uMSAyIC42'
    b'IDAgLjQuMSAxLS40IDEuMmwtMS4yLS4zYy4xLS4yLS4zLS4zLS40LS42LS41LS4xLS45LjMt'
    b'MS4yLjYuMy40IDEgLjcuOCAxLjItLjcuNy0xLS42LTEuOC0uMi0uNi0uMi4xLTEuMy0uNy0x'
    b'LjctMSAwLS4zIDEuNi0xLjYgMS0uNC0uNS0uOC0xLjItLjQtMS43YTEuNiAxLjYgMCAwIDEg'
    b'MS45LjJjLjgtLjkuOC00LjEgMi43LTEuN20tNy44IDMuM2MuNS44LS4yIDEuOC41IDIuNiAx'
    b'LTIgMiAuNCAzLjIuMi40LjUuMSAxLjEuMiAxLjYtMS41LjQtMy4zLjktNC42LS4zbC0uNC40'
    b'Yy44LjcgMS41IDEuNi45IDIuOC0xLjEuMi0yLjkuMy0zLjQtLjktLjMtMSAuNy0xLjYtLjQt'
    b'Mi40LS43IDEtLjcgMi4yLTIuMiAxLjNhMS45IDEuOSAwIDAgMS0uOC0yLjVjMS0xLjYgMi44'
    b'IDAgMy44LS43LjItMS40LS4zLTIuNiAxLTMuMyAxLS4yIDEuNS42IDIuMiAxLjIiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik05MC42IDIxMWMtLjUgMi4zLTIuMi0uMS0zLS4yIDEt'
    b'MiAxLjcuNiAzIC4ybTUuNCAyLjVjLTEuMi4zLTEtMS4yLTEuNi0xLjhsLjUtLjRjLjQuNS43'
    b'IDEuNSAxLjEgMi4yIi8+CiAgICA8cGF0aCBmaWxsPSIjZmYwIiBkPSJNOTQuNCAyMTNjLjMu'
    b'OC0uOCAxLjUuMiAybC44LS43Yy45LjIgMS44LjQgMi40IDEuMi42IDEuNy0xLjEgMS43LTIg'
    b'Mi4yaC0xYy4yLS42LS41LS44LS42LTFhMSAxIDAgMCAwLTEuMS4zYy4yIDEgMS41IDIgLjIg'
    b'Mi45LTEuMiAwLTMgLjQtMi45LTEuMi0uNC0xIDEuMi0yLjMtLjUtMi40LS42IDEuMy0xLjIg'
    b'Mi40LTIuNyAxLjNsLjItMS44YzEuNCAwIDMuMS4zIDMuNy0xLjMuNC0xLjEtLjctMi4yLjMt'
    b'MyAxLjUtLjQgMi4zLjYgMyAxLjUiLz4KICAgIDxwYXRoIGQ9Ik05My40IDIxNS42Yy4zLjkt'
    b'LjYgMS0xLjEgMS40LS42IDAtMS0uMi0xLjQtLjYtLjMtMSAuNS0xLjIgMS0xLjYuNy0uMyAx'
    b'IC41IDEuNS44Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNOTIuNSAyMTYuMmMtLjEu'
    b'Mi0uNC4xLS42LjJsLS4yLTFjLjUgMCAxIC4xLjguOCIvPgogIDwvZz4KPC9zdmc+Cg==', 'SX')

SX = b64_SX
index.append("SX")
index.append("SXM")
index.append("Sint Maarten (Dutch part)")
catalog["SX"] = SX
catalog["SXM"] = SX
catalog["Sint Maarten (Dutch part)"] = SX
country["Sint Maarten (Dutch part)"] = ('SX', 'SXM', 0)
lookup["SX"] = ('SX', 'SXM', 'Sint Maarten (Dutch part)', 0)
lookup["Philipsburg Sint Maarten (Dutch part)"] = ('SX', 'SXM', 'Sint Maarten (Dutch part)', 0)
lookup["SXM"] = ('SX', 'SXM', 'Sint Maarten (Dutch part)', 0)
lookup["Sint Maarten (Dutch part)"] = ('SX', 'SXM', 'Sint Maarten (Dutch part)', 0)
details["SX"] = {"continent":"Americas","capital":"Philipsburg","currency":"Netherlands Antillean Guilder","web":".sx","lang":"nl | en","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_SY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXN5IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZD0iTTAgMGg2NDB2NDgwSDBa'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMGg2NDB2MzIwSDBaIi8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2NlMTEyNiIgZD0iTTAgMGg2NDB2MTYwSDBaIi8+CiAgPHBhdGggZmlsbD0iIzAw'
    b'N2EzZCIgZD0ibTE2MSAzMDAgMzktMTIwIDM5IDEyMC0xMDItNzQuMmgxMjZNNDAxIDMwMGwz'
    b'OS0xMjAgMzkgMTIwLTEwMi03NC4yaDEyNiIvPgo8L3N2Zz4K', 'SY')

SY = b64_SY
index.append("SY")
index.append("SYR")
index.append("Syria")
catalog["SY"] = SY
catalog["SYR"] = SY
catalog["Syria"] = SY
country["Syria"] = ('SY', 'SYR', 0)
lookup["SY"] = ('SY', 'SYR', 'Syria', 0)
lookup["Damascus Syria"] = ('SY', 'SYR', 'Syria', 0)
lookup["SYR"] = ('SY', 'SYR', 'Syria', 0)
lookup["Syria"] = ('SY', 'SYR', 'Syria', 0)
details["SY"] = {"continent":"Asia","capital":"Damascus","currency":"Syrian Pound","web":".sy","lang":"ar-SY | ku | hy | arc | fr | en","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_SZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy1zeiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMzZTVlYjkiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgwWiIvPgogIDxwYXRoIGZpbGw9IiNmZmQ5MDAiIGQ9Ik0wIDkwaDY0MHYzMDBIMFoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjYjEwYzBjIiBkPSJNMCAxMjBoNjQwdjI0MEgwWiIvPgogIDxnIGZp'
    b'bGw9IiNmZmQ5MDAiIHN0cm9rZT0iIzAwMCIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTQzLjIp'
    b'IHNjYWxlKDEuMikiPgogICAgPGcgaWQ9InN6LWEiPgogICAgICA8cGF0aCBmaWxsPSIjZmZm'
    b'IiBkPSJtNDkyLjkgMTU0LjMtMjQuMyA4LjYgMjQuMiA4LjUgMjQuMy04LjV6Ii8+CiAgICAg'
    b'IDxyZWN0IHdpZHRoPSIzNTcuMSIgaGVpZ2h0PSI1LjciIHg9IjEyMi44IiB5PSIxNjAiIHJ4'
    b'PSIzLjEiIHJ5PSIyLjkiLz4KICAgICAgPHBhdGggZD0iTTQ3MS40IDE2NS43YTMgMyAwIDAg'
    b'MCAyLjktMi44IDMgMyAwIDAgMC0yLjktMi45bS0yLjggNS43YTMgMyAwIDAgMCAyLjgtMi44'
    b'IDMgMyAwIDAgMC0yLjgtMi45bS0yLjkgNS43YTMgMyAwIDAgMCAyLjktMi44IDMgMyAwIDAg'
    b'MC0yLjktMi45Ii8+CiAgICA8L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNzei1hIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSItMjMuMyIgeT0iMTcuMSIvPgogICAgPHJlY3Qg'
    b'd2lkdGg9IjQ4NS43IiBoZWlnaHQ9IjguNiIgeD0iNTkuOCIgeT0iMTk1LjciIHN0cm9rZS13'
    b'aWR0aD0iMS4xIiByeD0iNC4yIiByeT0iNC4zIi8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiNm'
    b'ZmYiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSIxLjIiIGQ9Ik00ODguMiAyNDBjLTM0'
    b'LjMgMzQuMy04MCAxMDIuOS0xNzEuNCAxMDIuOS04MCAwLTEzNy4xLTY4LjYtMTcxLjQtMTAy'
    b'LjkgMzQuMi0zNC4zIDkxLjQtMTAyLjkgMTcxLjQtMTAyLjkgOTEuNCAwIDEzNy4xIDY4LjYg'
    b'MTcxLjQgMTAyLjl6Ii8+CiAgPHBhdGggZD0iTTMwNC44IDE3M2M5LjIgMTAuMiAxLjUgMTQu'
    b'MyAxMS4yIDE1IDEwLjIuNyA0LjQgMTAuOCAxMyAxMS4yIDYgLjItLjYgMjQuMiA1LjEgMzIg'
    b'NS45IDguMyAxMC44IDIuNSAxMSA4LjQgMCA2LjItMTYgNS41LTE2LjMgMjQuNS0uNSAxMC45'
    b'LTEzLjYgMTEuNi0xNC4yIDE4LjYtLjggNi42IDI1LjggMTAuMyAyNS40IDE2LjItLjMgNi0y'
    b'OC43IDUtMzAgMTEuNy0uNiA2IDM5IDExIDQyLjIgMjguNS02IDItMjIuNyAzLjctMzUuNCAz'
    b'LjgtODAgMC0xMzcuMS02OC42LTE3MS40LTEwMyAzNC4zLTM0LjIgOTEuNC0xMDIuOCAxNzEu'
    b'NC0xMDIuOCAwIDAtMjMuNyAyMS43LTEyIDM1Ljh6Ii8+CiAgPGcgc3Ryb2tlPSIjZmZmIiB0'
    b'cmFuc2Zvcm09InRyYW5zbGF0ZSgtNDMuMikgc2NhbGUoMS4yKSI+CiAgICA8ZyBpZD0ic3ot'
    b'ZCIgc3Ryb2tlLXdpZHRoPSI2LjkiPgogICAgICA8ZyBpZD0ic3otYyI+CiAgICAgICAgPHBh'
    b'dGggaWQ9InN6LWIiIGQ9Ik0yMTQgMTkyLjR2LTIyLjltMTMuOCAwdjIyLjltMTMuOC0yMi45'
    b'djIyLjkiLz4KICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiNzei1iIiB3aWR0aD0iMTAwJSIg'
    b'aGVpZ2h0PSIxMDAlIiB5PSIzOC4xIi8+CiAgICAgIDwvZz4KICAgICAgPHVzZSB4bGluazpo'
    b'cmVmPSIjc3otYyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iNDEuNiIvPgogICAg'
    b'PC9nPgogIDwvZz4KICA8dXNlIHhsaW5rOmhyZWY9IiNzei1kIiB3aWR0aD0iMTAwJSIgaGVp'
    b'Z2h0PSIxMDAlIiB4PSIxMDQuOCIgc3Ryb2tlPSIjMDAwIiB0cmFuc2Zvcm09InRyYW5zbGF0'
    b'ZSgtNDMuMikgc2NhbGUoMS4yKSIvPgogIDxnIGZpbGw9IiNhNzAwMDAiPgogICAgPHBhdGgg'
    b'ZmlsbD0iIzMzMyIgc3Ryb2tlPSIjMDAwIiBkPSJNNTcwLjQgMjM2Yy01LjIgOC45IDQtMyAy'
    b'Ni40IDEyYTIxLjYgMjEuNiAwIDAgMSA3LjggMTUuM2MtMS0uNy0xLjktMi4zLTMtMy4yLTEu'
    b'NiAxLjYgMS42IDkgMiAxMi41LTMuNS0yLTMuMi0yLjgtNC4zLTUuMi4yIDIuOC0uNyAxMC44'
    b'LjggMTQtMi44LS44LTIuNi0zLTQtMy41IDEgMy41LS45IDcuMi0uNCAxMS4yLTEuNi0xLjYt'
    b'My40LTIuOS00LjEtMy41LS4yIDItMy4xIDYuOC0zLjIgOC42YTQuNSA0LjUgMCAwIDEtMi0z'
    b'IDU5LjIgNTkuMiAwIDAgMC04IDEyLjRjLTQuNy00LTE2LjYtMTQtMTguMi0xOS40LTEuNCAz'
    b'LTMuNCA0LTcuMiA2LjItMS42LTguNC03LjUtMTcuOC00LjQtMjUuMWE3NS4yIDc1LjIgMCAw'
    b'IDAtNi4xIDQuMiA0OS42IDQ5LjYgMCAwIDEgMjgtMzMuNnoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNiM2IzYjMiIGQ9Ik01NTEgMjgwLjVjMi4yLTQuMyA0LjItNS43IDUuNi04LjUgMi40LTQu'
    b'OCAyLjgtOC44IDUtOC4yIDIgLjYgMiAyLjYtLjcgNy40LTIuNyA0LjgtNCA1LjgtOS45IDku'
    b'M3ptMTQuNiAxMC4yYy0uMi0zLjIuNy00LjYuNi02LjctLjQtMy44LTEuOS02LjMuMS02LjUg'
    b'Mi0uMSAyLjkgMS4xIDIuOSA0LjggMCAzLjgtLjYgNC44LTMuNiA4LjR6bTExLjEgNi40Yy0u'
    b'OS00LjUtLjItNi41LS44LTkuNS0xLTUuMi0yLjktOC42LTEtOS4xIDEuOC0uNSAzIDEuMiAz'
    b'LjcgNi41LjYgNS4yLjMgNi43LTEuOSAxMi4yem0xMS41LTMyYy0yLjctMi00LjMtMi4yLTYt'
    b'My41LTMtMi40LTQuNi00LjgtNS42LTMuNi0xIDEuMi0uMyAyLjYgMyA0LjdzNC4yIDIuMyA4'
    b'LjYgMi40em0tMS45IDE1LjJjLTEuNC0zLTMtMy43LTMuOC01LjYtMS42LTMuNC0xLjYtNi4z'
    b'LTMuNS01LjYtMS43LjgtMS45IDIuMyAwIDUuNiAyIDMuMiAzIDMuOCA3LjIgNS42eiIvPgog'
    b'ICAgPHBhdGggZmlsbD0iIzMzMyIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjEuMyIg'
    b'ZD0iTTUzLjggMjQ0LjZjLS40LTIuNi4yLTMtMS40LTUgMi40IDEgMi40IDMuNyA1LjMgMS44'
    b'IDEtLjUgMS41LS41LjItMy41IDMgLjIgMTIuNyAzLjUgMTQuMyAzLjYgNC4xLjIgMTEuNi00'
    b'LjMgMTYuOCAxLjIgNSA1IDMuMiAxMC4zIDMuMiAxNy4yLTItMS0xLTEuMy0zLjItMy45IDEu'
    b'NiA2LjIgMCAxNy4xIDAgMjMuNi0uOC0xLjYtLjctLjktMS41LTIuNS0yIDUuOS00LjYgNy00'
    b'LjYgMTQuMS0uOC0yLjggMC0yLjItLjktMy42LTIgNC41LTE2IDguMy0xMC42IDEyLjgtNC44'
    b'LTIuOC03LTIuNi05LTUtMSAuNS0xLjggMS43LTIuNiAzLjItOC41LTMuOC01LjUtMTIuMi0x'
    b'Mi4xLTE3LjktMS4yIDIuNC0uNyAyLjEtMiA1LjktMS4yLTUuMy0xLjYtOC43LTMuMS0xMi42'
    b'LTEuMyAyLjItMS4yIDEuMy0zLjYgNC42LTEtNi40LTIuNS04LTItMTIuMy0yLjQgMS44LS44'
    b'IDEtMy4zIDMuMiAyLjQtMTYuNSAxMi42LTI4LjggMjAtMjV6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjYjNiM2IzIiBkPSJNNDMuNCAyNzEuN2MyLjEtNS40IDQtNyA1LjUtMTAuNCAyLjUtNi4x'
    b'IDIuOS0xMSA1LTEwLjMgMiAuOCAyIDMuMi0uOCA5LjItMi44IDYtNCA3LjItOS43IDExLjV6'
    b'bTguMiAxMy4zYy44LTQuOCAyLjItNi40IDIuOC05LjYgMS01LjQuNS05LjQgMi40LTkuMiAy'
    b'IC4yIDIuNCAyLjMgMS4xIDcuNi0xLjMgNS41LTIuMiA2LjgtNi40IDExLjJ6bTkuOCA5LjRj'
    b'LjMtNC42IDEuNC02LjUgMS42LTkuNS4zLTUuMi0uOC05IDEtOSAyIDAgMi42IDEuOSAyIDcu'
    b'MS0uNiA1LjItMS4yIDYuNi00LjYgMTEuNHpNODIuNiAyNjRjLTQtNC02LjQtNC44LTktNy40'
    b'LTQuNi00LjYtNi45LTguOC04LjYtNy4zLTEuNiAxLjUtLjYgMy43IDQuMyA4IDQuOCA0LjUg'
    b'Ni41IDUuMSAxMy40IDYuN3ptLTIuNCAxNS42Yy0yLjYtNC00LjYtNS4xLTYuMy03LjgtMy00'
    b'LjUtNC04LjQtNS43LTcuNS0xLjcgMS0xLjMgMyAxLjkgNy41IDMuMyA0LjQgNC41IDUuMiAx'
    b'MC4xIDcuOHoiLz4KICAgIDxwYXRoIGZpbGw9IiMzMzMiIHN0cm9rZT0iIzAwMCIgZD0iTTI2'
    b'MS40IDE1NS40Yy00LjggOS4yIDguMy0zIDI4LjggMTIuNGEzNS40IDM1LjQgMCAwIDEgOS4y'
    b'IDE5LjMgNjEuNyA2MS43IDAgMCAxLTEyLTUuM3M5IDkuMiA5IDE5LjZjLTMuMi0yLTQuOC0x'
    b'LjctNi00LjEgMCAzLjMgMyA1LjUgMyAxMC43YTQyLjQgNDIuNCAwIDAgMC02LjMtNC4yYzMg'
    b'NS4zLTUuNSAxNS41LTEuMiAxOC44YTI2LjYgMjYuNiAwIDAgMS0xOC4xLTExYy0xLjYgMS0x'
    b'LjggMi43LTEuOSA0LjYuMy4xLTExLjMtOC43LTEwLjItMTJhMTAuMSAxMC4xIDAgMCAwLTIu'
    b'MiA1LjggMzEuNyAzMS43IDAgMCAxLTkuNi0xMy44Yy0xLjggMi40LTIgMi40LTMuOSA1LTEu'
    b'NC04LjctMS40LTguNCAxLjQtMTUuOGE2OSA2OSAwIDAgMC01LjYgNC4zIDUwIDUwIDAgMCAx'
    b'IDI1LjYtMzQuM3oiLz4KICAgIDxwYXRoIGZpbGw9IiNiM2IzYjMiIGQ9Ik0yNDkuNiAyMDAu'
    b'MmMuOC02LjMgMi40LTguNiAzLTEyLjguOC03LS4yLTEyLjQgMi40LTEyLjIgMi40LjIgMy4y'
    b'IDIuOCAyIDEwLTEuMyA3LjEtMi40IDguOC03LjMgMTUuMXptMTMuMyAxMS42Yy0uNS01LjIu'
    b'NS03LjYuMS0xMS0uNS02LTIuNC0xMC4yLS4yLTEwLjUgMi4yLS40IDMuNCAxLjYgMy42IDcu'
    b'OC4yIDYtLjMgNy43LTMuNSAxMy43em0yMC44IDkuNmMtMi4zLTQuNy00LjMtNi01LjctOS0y'
    b'LjYtNS4zLTMuMi05LjUtNS4xLTguOC0yIC44LTEuOSAzIDEgOC4yIDIuOCA1IDQuMSA2LjEg'
    b'OS43IDkuNnptNy4xLTQxLjVjLTUuOC0zLTguNy0zLTEyLjQtNS02LjUtMy40LTEwLjMtNy4x'
    b'LTExLjYtNS0xLjQgMiAuNCA0LjEgNy4xIDcuMiA2LjcgMy4xIDguOCAzLjIgMTYuOCAyLjh6'
    b'bTIgMTcuM2MtNC0zLjQtNi42LTQtOS4zLTYuMi00LjgtNC03LjEtNy43LTguNi02LjItMS42'
    b'IDEuNi0uNiAzLjYgNC40IDcuMyA1IDMuNyA2LjcgNC4xIDEzLjYgNS4xeiIvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'SZ')

SZ = b64_SZ
index.append("SZ")
index.append("SWZ")
index.append("Eswatini")
catalog["SZ"] = SZ
catalog["SWZ"] = SZ
catalog["Eswatini"] = SZ
country["Eswatini"] = ('SZ', 'SWZ', 0)
lookup["SZ"] = ('SZ', 'SWZ', 'Eswatini', 0)
lookup["Mbabane Eswatini"] = ('SZ', 'SWZ', 'Eswatini', 0)
lookup["SWZ"] = ('SZ', 'SWZ', 'Eswatini', 0)
lookup["Eswatini"] = ('SZ', 'SWZ', 'Eswatini', 0)
details["SZ"] = {"continent":"Africa","capital":"Mbabane","currency":"Lilangeni","web":".sz","lang":"en-SZ | ss-SZ","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_TC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy10YyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwMDI4NjgiIGQ9Ik02NDAgNDgwVjBI'
    b'MHY0ODBoNjQweiIvPgogIDxnIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMCI+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZmNkMTE2IiBzdHJva2Utd2lkdGg9IjgiIGQ9Ik01OTAgMTc0LjZ2OTBjMCA2'
    b'MC0zMCAxMjQuNi0xMDUgMTU5LjYtNzUtMzUtMTA1LTk5LjYtMTA1LTE1OS42di05MHoiLz4K'
    b'ICAgIDxwYXRoIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSI3IiBkPSJNNTkwIDE3NC42'
    b'djkwYzAgNjAtMzAgMTI0LjYtMTA1IDE1OS42LTc1LTM1LTEwNS05OS42LTEwNS0xNTkuNnYt'
    b'OTB6Ii8+CiAgICA8ZyBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS1saW5lam9pbj0i'
    b'cm91bmQiIHN0cm9rZS13aWR0aD0iMi4yIj4KICAgICAgPHBhdGggZmlsbD0iI2ZjYWQ1NiIg'
    b'c3Ryb2tlLXdpZHRoPSIuMyIgZD0iTTQ0Ny4xIDI3My43Yy0yLjcgNC43LTcuNCA1LjctMTEg'
    b'NC4yLTMuNy0xLjUtNy4xLTEwLjMtMTAuOS0xNS0zLjYtNC43LTQuNi0yLjctNy01LjRhMzcu'
    b'NiAzNy42IDAgMCAwLTEyLTcuNGMtMy4zLTEuNS02LjctMi45LTktOC42YTkuOCA5LjggMCAw'
    b'IDEgNS4yLTUuMWMxLjktLjcgMy40LTMuNCAzLjYtNS44LjMtMi4yIDIuMy00LjcgNS02LjYt'
    b'MS4zLjItMy45LS4zLTUuMS0xLjEtMS4xLTEtMy0uOC00LjEgMC0xLjIuOC0yLjYgMS00LjYu'
    b'OC44LS42IDIuMi0yIDIuMy0zLjJzMS42LTEuOSA0LjUtMS45YzIuOCAwIDQuNi0zLjIgNi45'
    b'LTMuMi0xLjYgMC0xLjMtMi44LS40LTMtNC0uNy0zLjUtNC0xLjktNC0uMS0uNC0uNi0xLTIu'
    b'NS0xLjUtMS43LS43LS45LTIuMy41LTMuMy0xLjItMi41LS4xLTQuNCAxLjktNi0yLjgtLjEu'
    b'My00IDEtNi4xLjgtMiAxLjEtMi4zIDItMSAxIDEuMSAzLjMgMy43IDUuOSA0LjUgMi41Ljcg'
    b'NCAyLjEgNC41IDQuMi41IDIuMyAxLjUgMy40IDQuMiA0LjQgMi45LjkgNi44IDMuMyA2LjMg'
    b'OC42YTkgOSAwIDAgMSA1LjIgMS45Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiNmZmExYTEiIHN0'
    b'cm9rZS13aWR0aD0iLjMiIGQ9Ik00NTQgMjA2YTggOCAwIDAgMCAzLjEgNi40YzEuOSAxLjUg'
    b'My41IDIuNyAzLjEgNC42LS4zIDIgLjQgMy4yIDIgNC41IDEuOCAxLjIgMyAyLjcgMi42IDUu'
    b'MnMtLjIgNCAuOCA1LjkgMi44IDMuNCAyIDYuNC0uNCA3IC42IDljMSAxLjkgMCAzLjQtMS43'
    b'IDYuNy0xLjggMy4zLTIuOCA0LjUtNi40IDUuOC0zLjcgMS4xLTQgMy40LTQgNy4yIDAgNC0y'
    b'LjYgNi03LjUgNS4zLTUgNC4xLTguMS0uOC05LjQtNi45cy0xLjQtMTIuOC04LjgtMTguMWMt'
    b'Ny4zLTUuNS00LjQtMTQuOCAxLjctMTguNSA2LjEtMy42IDUuNC0xNC40IDQuNi0yMS0uNi02'
    b'LjYgMy44LTEwLjQgNy4yLTE0IDQuNSAxLjcgMTAuMSA4LjYgMTAuMSAxMS41eiIvPgogICAg'
    b'ICA8cGF0aCBmaWxsPSIjZjFiMmRjIiBzdHJva2Utd2lkdGg9Ii4zIiBkPSJNNDQzLjQgMjQ4'
    b'LjZjLTEuNC0zLjItMi45LTYuNS43LTEzLjUgMy44LTcuMSAxLjQtMTIuNS4zLTE2LjEtMS4x'
    b'LTMuNS0xLjQtNi44IDAtOC4zIDEuNS0xLjMgMi4xLTIuMiAyLjItNC42LjEtMi4yIDItMS41'
    b'IDIuMy0uNHMuNSAzLTEuNSA2LjRjLTIgMy41IDUuNiAxMiAyLjEgMjEuMS0yLjQgNi40Ljgg'
    b'MTQuNSAyIDIwLjJzMiAxOS02LjMgMjFjNS43LTIuNy40LTIwLjUtMS44LTI1LjhaIi8+CiAg'
    b'ICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iLjMiIGQ9Ik00MDYuMyAyNDcuNmMxLjMuMyAyLS41'
    b'IDIuNC0xLjRzLjctMS4zIDItMS41YzEuMiAwIDMuMi0uMyAzLjctMS4zLjQtMSAxLjktLjIg'
    b'My4yLTIuNyAxLjMtMi42IDIuMS01LjYgNS41LTYuN205LjMtMjEuOGMtMS4zIDAtNC45LjIt'
    b'Ni40IDMuNG0tMTAuNC0xOC45YzMgLjkgMS44IDIuOSAzLjMgNCAyLjcgMi4yLjIgNC40IDIu'
    b'NSA1czIuMSAxIDEuNiAzLjVjLS44IDIuOSAyIDMgMSA0LjltLTEzIDkuOWMxLjgtMS42IDYu'
    b'MS0yLjkgNy4xLTQuNm0tNy4yLTRjMi42LS4yIDYuMS44IDYuNi0uMm0tNy0yLjdjMS4zIDAg'
    b'My45LS45IDQuNC0yLjZtLTYuMy0xLjRjMS41IDAgMy40LS4xIDUuMy0xLjVtLTcuMy0zLjRj'
    b'MS4xLS45IDMuMS4xIDUtMS4xbS0zLjEtNC45Yy45IDAgMi44LS4yIDIuOC45Ii8+CiAgICAg'
    b'IDxnIGZpbGw9IiM5ZTU0MGEiIHRyYW5zZm9ybT0ibWF0cml4KC4xMjUgMCAwIC4xMjUgNTM1'
    b'IDI0OS42KSI+CiAgICAgICAgPGcgaWQ9InRjLWIiPgogICAgICAgICAgPHBhdGggZD0iTS01'
    b'NS0yMzNzLTcwLTU5LTEyOC05OS0xMjgtODktMTI4LTk5YzExLTggNzAgMzAgMTUxIDc5IDgy'
    b'IDUwIDEyOCA5OSAxMjggOTl6bS01IDQwcy02OC00MS0xMzUtNzBjLTcwLTI5LTE3NS0yOS0x'
    b'ODYtMzkgMC0xMCAxMjItMTYgMjA5IDE5IDg5IDQxIDEzNSA3MCAxMzUgNzB6bS0xIDY4cy03'
    b'NC0zNC0xNDYtNTBjLTcwLTE2LTE3MC0xMC0xODItMTkgMC0xMCAxMjQtMzAgMjE3IDAgOTQg'
    b'MjkgMTM0IDQ5IDEzNCA0OXptLTQgNjlzLTU2LTM4LTEzMC00NmMtNzAtNy0xNjMgNDYtMTc1'
    b'IDM2IDAtMTAgODEtNjkgMTgyLTU5IDk5IDEwIDE0NiA0OSAxNDYgNDl6bTIzLTIxOHMtNzEt'
    b'NjUtNzEtMTA5YzAtMzkgNDMtOTkgNjItOTktMTAgMjAtNDMgNjAtNDMgOTkgMCA0MCA3NSA4'
    b'OSA3NSA4OXoiLz4KICAgICAgICAgIDxwYXRoIGQ9Ik0tNDItMjc0czE0LTY1IDE0LTEwOWMw'
    b'LTU5LTQyLTExMy0zOC0xMjggMTUgMTUgNTcgNTkgNTcgMTI4IDAgNjAtMTAgODktMTAgODl6'
    b'Ii8+CiAgICAgICAgICA8ZyBzdHJva2U9Im5vbmUiPgogICAgICAgICAgICA8dXNlIHhsaW5r'
    b'OmhyZWY9IiN0Yy1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBzdHJva2U9IiNmY2Qx'
    b'MTYiIHN0cm9rZS13aWR0aD0iMTIiLz4KICAgICAgICAgICAgPHBhdGggaWQ9InRjLWEiIGQ9'
    b'Ik0tMjUtMjk1YzAtMTktNy0zNi0xOS00OS0xNi0xOS00MC0yNS02NS0yMS0zMCA1LTU0IDIz'
    b'LTY5IDUxLTIwIDM3LTIyIDc3LTIzIDExNiAwIDEzNSA1IDE5MCA5IDMyMyAxIDM5IDggMTE5'
    b'LTEwIDE4Mi03IDI3LTE1IDUyLTI3IDc4IDgtMzMgMTItNTAgMTYtNzUgMTEtNjUgOC0xMjYg'
    b'Ni0xODYtNC0xMjMtMTEtMTg2LTE1LTMzNS0xLTQ1IDMtNzkgMjQtMTE1IDIyLTM3IDYwLTY0'
    b'IDEwMy02NCAxOCAwIDMzIDMgNDggMTIgMzAgMTYgNDQgNDkgNDQgODJ6Ii8+CiAgICAgICAg'
    b'ICA8L2c+CiAgICAgICAgICA8cGF0aCBkPSJNLTE5IDE4N3MtMjggNTAtNDkgODYtMzggNDQt'
    b'NTQgMzNjLTE1LTExLTItNDAgMTAtNTRzNzktNzkgNzktNzl6Ii8+CiAgICAgICAgICA8cGF0'
    b'aCBkPSJNLTEyIDE5MXMtMTEgNTctMjAgOThjLTggNDEtMjIgNTUtMzkgNTAtMTgtNC0xNS0z'
    b'Ny04LTU0czQ5LTEwMyA0OS0xMDN6Ii8+CiAgICAgICAgICA8cGF0aCBkPSJNMCAxOTN2MTAw'
    b'YzAgNDItMTAgNTktMjkgNTgtMTgtMS0yMi0zMy0xOC01MiAzLTE4IDI4LTExMSAyOC0xMTF6'
    b'Ii8+CiAgICAgICAgPC9nPgogICAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3RjLWIiIHdpZHRo'
    b'PSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ic2NhbGUoLTEgMSkiLz4KICAgICAg'
    b'ICA8ZyBpZD0idGMtYyI+CiAgICAgICAgICA8cGF0aCBkPSJNMCAxOTJjLTUzLTEtNTgtMjAt'
    b'NTgtMjBzLTctMjQtOC0zOWMtMS0yLTE1LTMyLTExLTQ1LTUtMTItMTctNDEtNi00Ni01LTE0'
    b'LTEzLTMwLTE0LTQ1LTQtMTEtMTQtMzUtNi00MyAwIDAtMTktNDAtMTAtNTAgMCAwLTktMzkg'
    b'MC00OSAwIDAgMC00MCAxMC01MCAwIDAgMC0zOSA5LTQ5IDAgMiAyOC01NSA5NC01NWwtMSA4'
    b'NWgxeiIvPgogICAgICAgICAgPHBhdGggZmlsbD0ibm9uZSIgZD0iTTAtMjZjLTg1LTEtMTAz'
    b'LTIwLTEwMy0yME0wLTc2Yy04NSAwLTExMy0yMC0xMTMtMjBNMC0xMjVjLTg1LTEtMTEzLTIw'
    b'LTExMy0yME0wLTE3NWMtODUtMS0xMDMtMjAtMTAzLTIwbTEwMi0xOWMxIDAtNjQgMC03NC0x'
    b'MGwtMTktMTlNMCAxNTJjLTI1IDAtNTMtNC02Ni0xOW02Ni0yMWMtNDcgMC03NS0xOS03NS0x'
    b'OXMtMS0yLTItNU0wIDYzYy02Mi0xLTc5LTE0LTgzLTIxTTAgMjNDLTg1IDIzLTk0IDMtOTQg'
    b'M2wtMy02Ii8+CiAgICAgICAgPC9nPgogICAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3RjLWMi'
    b'IHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ic2NhbGUoLTEgMSkiLz4K'
    b'ICAgICAgPC9nPgogICAgICA8ZyB0cmFuc2Zvcm09Im1hdHJpeCguMTI1IDAgMCAuMTI1IDQ4'
    b'NSAyOTkuNikiPgogICAgICAgIDxnIGlkPSJ0Yy1kIj4KICAgICAgICAgIDxwYXRoIGZpbGw9'
    b'IiMwMDllNDkiIGQ9Ik0wIDcxMmMtNDMgNDAtMTI2IDE0LTE1Mi00LTI3IDktOTktMTktMTE4'
    b'LTUwLTUyIDctNzAtNjctNjEtODYgMTQtMjgtMTEtNDYgNy02NSAyNS0yNC0xNC00NyAxMC02'
    b'MyAyNC0xNy02LTQ1IDE4LTYzIDI1LTE5LTEzLTQ1IDEzLTU4cy0zLTQ3IDE5LTYwLTEzLTQ2'
    b'IDE3LTYxYzI5LTE1IDMtNDEgMjYtNTIgMjUtMTMgMi00MCAyNS00OSAyNi0xMSA3LTQwIDI5'
    b'LTQ4IDE5LTcgNy0yNSAxOS00MUgwIi8+CiAgICAgICAgICA8cGF0aCBkPSJNLTk5IDE4Yy0y'
    b'MCAyMCA0IDM1LTE2IDU5LTIxIDI1LTIgMzgtMTkgNjBzOCAzMy0xMSA1OGMtMTkgMjQgNCAz'
    b'OS0xNyA1OS0yMCAyMSA0IDM5LTE3IDYxLTIwIDIzIDQgMzgtMTYgNTgtMjEgMjEgMyA0My0x'
    b'NyA2My0yMCAyMSA0IDQ3LTE5IDcxLTIyIDI0IDQgNDMtMTQgNjEtMTkgMTktMiAzOC0xNSA1'
    b'MXMtMTUgMzEtMTAgMzlNLTYwIDI1Yy0xOCAyNSAxMCAzNi03IDU2LTE3IDIxIDcgMjgtNiA1'
    b'MnMxMCAzMC03IDU0IDkgNDMtOSA2N2MtMTkgMjQgOSAzNy04IDYxLTE2IDI1IDggMzgtNyA1'
    b'Ni0xNSAxOSAxMSAzNy04IDYwLTE4IDIyIDggMzktNyA1OS0xNSAyMSA2IDQzLTcgNjAtMTMg'
    b'MTYgOSA0MS0xMCA2My0xOCAyMiA0IDM3LTcgNTJzLTIwIDM3LTkgNDMiLz4KICAgICAgICA8'
    b'L2c+CiAgICAgICAgPHVzZSB4bGluazpocmVmPSIjdGMtZCIgd2lkdGg9IjEwMCUiIGhlaWdo'
    b'dD0iMTAwJSIgdHJhbnNmb3JtPSJzY2FsZSgtMSAxKSIvPgogICAgICAgIDxwYXRoIHN0cm9r'
    b'ZT0iIzAwOWU0OSIgZD0iTTAgNzEyVjEyIi8+CiAgICAgICAgPHBhdGggZD0iTTAgNDhjLTkg'
    b'MzkgMTMgNzMgMCAxMDYtMTMgMzIgOSA0NSAyIDcxLTggMjYgOSA0NS0yIDczczE1IDUwIDAg'
    b'ODdjLTE1IDM2IDEwIDQ1IDAgODItMTEgNDIgMTkgNjQgMCA5NHMxNyAzNyAyIDcxYy0xNSAz'
    b'MyA5IDQ2LTIgODAiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjZmNkMTE2IiBkPSJNMTUgMTc0'
    b'Yy01IDExIDE1IDM3IDQgNTctMTIgMTkgNiA0OS02IDczczE5IDU0IDcgODJjLTEzIDI4IDYg'
    b'NjMgMCA4OS01IDI2IDEzIDc2IDAgOTQtMTMgMTkgMTMgMjQtMiA3MHMtMjUgNy0xNi03YzE5'
    b'LTMxLTIxLTQxLTItNzFzLTExLTUyIDAtOTRjMTAtMzctMTUtNDYgMC04MiAxNS0zNy0xMS01'
    b'OSAwLTg3cy02LTQ3IDItNzNjNy0yNi0xNS0zOS0yLTcxIDEwLTMyIDIwIDkgMTUgMjB6bS04'
    b'NCAzMmMtNyAxMiAxMiAzNS01IDU4LTEyIDE2IDggMzUtOSA1OC0xMSAxNiAxMSAzNi00IDU5'
    b'LTEwIDEzIDcgMzgtNSA1Ny0xMiAyMCA2IDM2LTE1IDYyLTEyIDE0IDkgNDktNCA2MHMtMSA1'
    b'NC0xMCA2MGMtOCA3IDAgMzgtMjIgNDUgMTEtMTUtMTEtMzAgNy01MiAxOS0yMi0zLTQ3IDEw'
    b'LTYzIDEzLTE3LTgtMzkgNy02MCAxNS0yMC0xMS0zNyA3LTU5IDE5LTIzLTctNDEgOC02MCAx'
    b'NS0xOC05LTMxIDctNTYgMTctMjQtMTEtMzcgOC02MSAxOC0yNC04LTQzIDktNjdzLTYtMzAg'
    b'Ny01NGMyNCA5IDEyIDYxIDQgNzN6bS01MC02NWMtMTAgMTYgNCAzNS0xMSA1NS0xNSAyMSAw'
    b'IDQ3LTE1IDY0LTE1IDE2IDQgNDgtMTUgNjFzLTcgNTItMjIgNjUgMCA1MC0xNyA2OS05IDU4'
    b'LTE5IDY3Yy05IDkgMTMgMjgtMyA0MS0xNyAxMy0xNyAzOS0zOSA1NiAxMy0xMy00LTMyIDE1'
    b'LTUxIDE4LTE4LTgtMzcgMTQtNjEgMjMtMjQtMS01MCAxOS03MSAyMC0yMC00LTQyIDE3LTYz'
    b'IDIwLTIwLTQtMzUgMTYtNTggMjEtMjItMy00MCAxNy02MSAyMS0yMC0yLTM1IDE3LTU5IDE5'
    b'LTI1LTYtMzYgMTEtNTggOC0xMCA4LTE5IDgtMjcgMTItMzEgMTIgMjMgNyAzMXoiLz4KICAg'
    b'ICAgICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNLTEzOSAzNWMwLTIxMCAyOS0yODMgMTM5'
    b'LTI4M3MxMzkgNzMgMTM5IDI4M3oiLz4KICAgICAgICA8cGF0aCBmaWxsPSIjMDAwIiBkPSJN'
    b'LTEzOSAzNWMwLTIxMCAyOS0yODMgMTM5LTI4My01MCAwLTgxIDM5LTg5IDY1LTkgMjYtNCAy'
    b'NCA3IDE0czYgMTItNCAyNGMtOSAxMi0xOCA0Ny01IDM2IDEzLTEyIDIzIDEgOSAyMS0xNCAx'
    b'OS0yNiA2NS0xMiA0OXMxNyAxMCA4IDIzYy04IDEzLTcgMjUgMCAxOSA4LTYgNyAyMSAwIDMy'
    b'em0xOTEtNEM1MiAwIDUzLTczIDM2LTk3Yy0xMi0xOS0xMi0zOSAyLTE3czIxIDExIDExLTEx'
    b'Yy0xMi0yOC0yOC01OS0yNC02NSA1LTcgOC00IDE4IDExczEyLTcgMS0yMmMtMTEtMTQtMTAt'
    b'MTcgMTMtNyA0MSAxNyA2MSA2NiA2MSAyMzF6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2Nl'
    b'MTEyNiIgZD0iTTAgNjVjLTQ0IDAtOTItNy0xMjQtMjAtMzgtMTUtNDAtMjgtMjctNDQgMTAt'
    b'MTIgMzAtNSA1MCA0IDE5IDggNzMgMTQgMTAxIDE0czgyLTYgMTAxLTE1YzIwLTggNDAtMTUg'
    b'NTAtMyAxMyAxNiAxMSAyOS0yNyA0NEM5MiA1OCA0NCA2NSAwIDY1WiIvPgogICAgICA8L2c+'
    b'CiAgICA8L2c+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9Ik0wIDBoMzIwdjI0'
    b'MEgwWiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im0zNy41IDAgMTIyIDkwLjVMMjgxIDBo'
    b'Mzl2MzFsLTEyMCA4OS41IDEyMCA4OVYyNDBoLTQwbC0xMjAtODkuNUw0MC41IDI0MEgwdi0z'
    b'MGwxMTkuNS04OUwwIDMyVjBaIi8+CiAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0iTTIxMiAx'
    b'NDAuNSAzMjAgMjIwdjIwbC0xMzUuNS05OS41Wm0tOTIgMTAgMyAxNy41LTk2IDcySDBaTTMy'
    b'MCAwdjEuNWwtMTI0LjUgOTQgMS0yMkwyOTUgMFpNMCAwbDExOS41IDg4aC0zMEwwIDIxWiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xMjAuNSAwdjI0MGg4MFYwWk0wIDgwdjgwaDMy'
    b'MFY4MFoiLz4KICA8cGF0aCBmaWxsPSIjYzgxMDJlIiBkPSJNMCA5Ni41djQ4aDMyMHYtNDh6'
    b'TTEzNi41IDB2MjQwaDQ4VjBaIi8+Cjwvc3ZnPgo=', 'TC')

TC = b64_TC
index.append("TC")
index.append("TCA")
index.append("Turks and Caicos Islands")
catalog["TC"] = TC
catalog["TCA"] = TC
catalog["Turks and Caicos Islands"] = TC
country["Turks and Caicos Islands"] = ('TC', 'TCA', 0)
lookup["TC"] = ('TC', 'TCA', 'Turks and Caicos Islands', 0)
lookup["Cockburn Town Turks and Caicos Islands"] = ('TC', 'TCA', 'Turks and Caicos Islands', 0)
lookup["TCA"] = ('TC', 'TCA', 'Turks and Caicos Islands', 0)
lookup["Turks and Caicos Islands"] = ('TC', 'TCA', 'Turks and Caicos Islands', 0)
details["TC"] = {"continent":"Americas","capital":"Cockburn Town","currency":"US Dollar","web":".tc","lang":"en-TC","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_TD = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRkIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMDI2NjQiIGQ9Ik0wIDBoMjE0djQ4MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2M2MGMzMCIgZD0iTTQyNiAwaDIxNHY0ODBINDI2eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2ZlY2IwMCIgZD0iTTIxNCAwaDIxMnY0ODBIMjE0eiIvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'TD')

TD = b64_TD
index.append("TD")
index.append("TCD")
index.append("Chad")
catalog["TD"] = TD
catalog["TCD"] = TD
catalog["Chad"] = TD
country["Chad"] = ('TD', 'TCD', 0)
lookup["TD"] = ('TD', 'TCD', 'Chad', 0)
lookup["N'Djamena Chad"] = ('TD', 'TCD', 'Chad', 0)
lookup["TCD"] = ('TD', 'TCD', 'Chad', 0)
lookup["Chad"] = ('TD', 'TCD', 'Chad', 0)
details["TD"] = {"continent":"Africa","capital":"N'Djamena","currency":"CFA Franc BEAC","web":".td","lang":"fr-TD | ar-TD | sre","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_TF = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy10ZiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPHBhdGggaWQ9InRmLWEiIGZpbGw9IiNm'
    b'ZmYiIGQ9Im0wLTIxIDEyLjMgMzhMLTIwLTYuNWg0MEwtMTIuMyAxN3oiLz4KICA8L2RlZnM+'
    b'CiAgPHBhdGggZmlsbD0iIzAwMjM5NSIgZD0iTTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZiIgZD0iTTAgMGgyOTIuOHYxOTYuOEgweiIvPgogIDxwYXRoIGZpbGw9IiMw'
    b'MDIzOTUiIGQ9Ik0wIDBoOTZ2MTkySDB6Ii8+CiAgPHBhdGggZmlsbD0iI2VkMjkzOSIgZD0i'
    b'TTE5MiAwaDk2djE5MmgtOTZ6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTQyNiAyMTku'
    b'NiAxNS40IDI0LjZoNDRWMzMwbC0zMy01MS42LTQ0LjQgNzAuOGgyMS42bDIyLjgtNDAuOCA0'
    b'Ni44IDg0IDQ2LjgtODQgMjIuOCA0MC44aDIxLjZMNTQ2IDI3OC40IDUxMyAzMzB2LTQ3LjRo'
    b'MTkuOGwxNC43LTIzLjRINTEzdi0xNWg0NGwxNS40LTI0LjZINDI2em01MS42IDEwNWgtNDh2'
    b'MTYuOGg0OHptOTEuMiAwaC00OHYxNi44aDQ4eiIvPgogIDx1c2UgeGxpbms6aHJlZj0iI3Rm'
    b'LWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjQxNiIgeT0iMzYyIiB0cmFuc2Zv'
    b'cm09InNjYWxlKDEuMikiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiN0Zi1hIiB3aWR0aD0iMTAw'
    b'JSIgaGVpZ2h0PSIxMDAlIiB4PSIzNzEiIHk9IjMyOCIgdHJhbnNmb3JtPSJzY2FsZSgxLjIp'
    b'Ii8+CiAgPHVzZSB4bGluazpocmVmPSIjdGYtYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAw'
    b'JSIgeD0iNDYxIiB5PSIzMjgiIHRyYW5zZm9ybT0ic2NhbGUoMS4yKSIvPgogIDx1c2UgeGxp'
    b'bms6aHJlZj0iI3RmLWEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjMzMyIgeT0i'
    b'MjI3IiB0cmFuc2Zvcm09InNjYWxlKDEuMikiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiN0Zi1h'
    b'IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI0OTkiIHk9IjIyNyIgdHJhbnNmb3Jt'
    b'PSJzY2FsZSgxLjIpIi8+Cjwvc3ZnPgo=', 'TF')

TF = b64_TF
index.append("TF")
index.append("ATF")
index.append("French Southern Territories")
catalog["TF"] = TF
catalog["ATF"] = TF
catalog["French Southern Territories"] = TF
country["French Southern Territories"] = ('TF', 'ATF', 0)
lookup["TF"] = ('TF', 'ATF', 'French Southern Territories', 0)
lookup["Port-aux-Francais French Southern Territories"] = ('TF', 'ATF', 'French Southern Territories', 0)
lookup["Kerguelen Islands | Desolation Islands"] = ('TF', 'ATF', 'French Southern Territories', 0)
lookup["ATF"] = ('TF', 'ATF', 'French Southern Territories', 0)
lookup["French Southern Territories"] = ('TF', 'ATF', 'French Southern Territories', 0)
details["TF"] = {"continent":"Africa","capital":"Port-aux-Francais","currency":"Euro","web":".tf","lang":"fr","tz":"+10:00","altname":"Kerguelen Islands | Desolation Islands"}
#----------------------------------------------------------------------
b64_TG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InRnLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBjbGlwLXBhdGg9InVybCgjdGctYSkiIHRyYW5zZm9ybT0ic2NhbGUoLjkzNzUpIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmZmUzMDAiIGQ9Ik0wIDBoNzY3LjZ2NTEySDB6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjMTE4NjAwIiBkPSJNMCAyMDguMWg3NjcuNlYzMTFIMHpNMCAuMmg3Njcu'
    b'NnYxMDIuOUgweiIvPgogICAgPHBhdGggZmlsbD0iI2Q4MDAwMCIgZD0iTTAgLjNoMzA2LjV2'
    b'MzEwLjZIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xMzQuNCAxMjguNGMwLS44'
    b'IDE4LjktNTMgMTguOS01M2wxNyA1Mi4yczU3LjQgMS43IDU3LjQuOC00NS4zIDM0LjMtNDUu'
    b'MyAzNC4zIDIxLjQgNjAgMjAuNSA1OC4yYy0uOC0xLjctNDkuNi0zNi00OS42LTM2cy00OS43'
    b'IDM0LjMtNDguOCAzNC4zYy44IDAgMTguOC01Ni41IDE4LjgtNTYuNWwtNDQuNS0zMy40IDU1'
    b'LjYtLjl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMTE4NjAwIiBkPSJNMCA0MDkuMmg3NjcuNlY1'
    b'MTJIMHoiLz4KICA8L2c+Cjwvc3ZnPgo=', 'TG')

TG = b64_TG
index.append("TG")
index.append("TGO")
index.append("Togo")
catalog["TG"] = TG
catalog["TGO"] = TG
catalog["Togo"] = TG
country["Togo"] = ('TG', 'TGO', 0)
lookup["TG"] = ('TG', 'TGO', 'Togo', 0)
lookup["Lome Togo"] = ('TG', 'TGO', 'Togo', 0)
lookup["TGO"] = ('TG', 'TGO', 'Togo', 0)
lookup["Togo"] = ('TG', 'TGO', 'Togo', 0)
details["TG"] = {"continent":"Africa","capital":"Lome","currency":"CFA Franc BCEAO","web":".tg","lang":"fr-TG | ee | hna | kbp | dag | ha","tz":"±0:00","altname":""}
#----------------------------------------------------------------------
b64_TH = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRoIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmNGY1ZjgiIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iIzJkMmE0YSIgZD0iTTAgMTYyLjVoNjQwdjE2MEgweiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2E1MTkzMSIgZD0iTTAgMGg2NDB2ODIuNUgwem0wIDQwMGg2NDB2ODBIMHoiLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'TH')

TH = b64_TH
index.append("TH")
index.append("THA")
index.append("Thailand")
catalog["TH"] = TH
catalog["THA"] = TH
catalog["Thailand"] = TH
country["Thailand"] = ('TH', 'THA', 0)
lookup["TH"] = ('TH', 'THA', 'Thailand', 0)
lookup["Bangkok Thailand"] = ('TH', 'THA', 'Thailand', 0)
lookup["THA"] = ('TH', 'THA', 'Thailand', 0)
lookup["Thailand"] = ('TH', 'THA', 'Thailand', 0)
details["TH"] = {"continent":"Asia","capital":"Bangkok","currency":"Baht","web":".th","lang":"th | en","tz":"+07:00","altname":""}
#----------------------------------------------------------------------
b64_TJ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy10aiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMwNjAiIGQ9Ik0wIDBoNjQwdjQ4MEgw'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjM0Mi45SDB6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2MwMCIgZD0iTTAgMGg2NDB2MTM3LjFIMHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'ZjhjMzAwIiBkPSJNMzAwLjggMjMzLjZhOC42IDguNiAwIDAgMSAxNiA0VjI3Mmg2LjR2LTM0'
    b'LjNhOC42IDguNiAwIDAgMSAxNi00IDIwLjIgMjAuMiAwIDEgMC0zOC40IDAiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJNMzA1LjQgMjI0LjdhMTMuNyAxMy43IDAgMCAxIDE0LjYgNi41'
    b'IDEzLjcgMTMuNyAwIDAgMSAxNC42LTYuNSAxNC43IDE0LjcgMCAwIDAtMjkuMiAwIi8+CiAg'
    b'PHBhdGggaWQ9InRqLWEiIGZpbGw9IiNmOGMzMDAiIGQ9Ik0zMTYuOCAyNTguM2EyNiAyNiAw'
    b'IDAgMS00My44IDE2LjYgMjcgMjcgMCAwIDEtNDEgMTJjMi41IDI1IDQwIDE5LjkgNDIuOC00'
    b'LjQgMTEuNyAyMC43IDM3LjYgMTQuNyA0NS4yLTEwLjZ6Ii8+CiAgPHVzZSB4bGluazpocmVm'
    b'PSIjdGotYSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0iI2Y4YzMwMCIgdHJh'
    b'bnNmb3JtPSJtYXRyaXgoLTEgMCAwIDEgNjQwIDApIi8+CiAgPHBhdGggaWQ9InRqLWIiIGZp'
    b'bGw9IiNmOGMzMDAiIGQ9Ik0yOTEuOCAzMDIuNmMtNS4zIDExLjMtMTUuNyAxMy4yLTI0Ljgg'
    b'NC4xIDAgMCAzLjYtMi42IDcuNi0zLjMtLjgtMy4xLjctNy41IDIuOS05LjhhMTUgMTUgMCAw'
    b'IDEgNi4xIDguMWM1LjUtLjcgOC4yIDEgOC4yIDF6Ii8+CiAgPHVzZSB4bGluazpocmVmPSIj'
    b'dGotYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0iI2Y4YzMwMCIgdHJhbnNm'
    b'b3JtPSJyb3RhdGUoOS40IDMyMCA1NTEuMykiLz4KICA8dXNlIHhsaW5rOmhyZWY9IiN0ai1i'
    b'IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSIjZjhjMzAwIiB0cmFuc2Zvcm09'
    b'InJvdGF0ZSgxOC43IDMyMCA1NTEuMykiLz4KICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9'
    b'IiNmOGMzMDAiIHN0cm9rZS13aWR0aD0iMTEiIGQ9Ik0yNTMuNSAzMjcuOGEyMzMuMSAyMzMu'
    b'MSAwIDAgMSAxMzMgMCIvPgogIDxnIGZpbGw9IiNmOGMzMDAiIHRyYW5zZm9ybT0idHJhbnNs'
    b'YXRlKDMyMCAxNjQuNikgc2NhbGUoLjY4NTcxKSI+CiAgICA8cGF0aCBpZD0idGotYyIgZD0i'
    b'bTMwMTkzMCA0MTU1NzEtNzkwNDYzLTU3NDMwNWg5NzcwNjZsLTc5MDQ2MyA1NzQzMDVMMC01'
    b'MTM2NzR6IiB0cmFuc2Zvcm09InNjYWxlKC4wMDAwNSkiLz4KICA8L2c+CiAgPGcgaWQ9InRq'
    b'LWQiIGZpbGw9IiNmOGMzMDAiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDMyMCAyNjAuNikgc2Nh'
    b'bGUoLjY4NTcxKSI+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN0ai1jIiB3aWR0aD0iMTAwJSIg'
    b'aGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtNzAgLTEyMS4yKSIvPgogICAg'
    b'PHVzZSB4bGluazpocmVmPSIjdGotYyIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJh'
    b'bnNmb3JtPSJ0cmFuc2xhdGUoLTEyMS4yIC03MCkiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0i'
    b'I3RqLWMiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0idHJhbnNsYXRl'
    b'KC0xNDApIi8+CiAgPC9nPgogIDx1c2UgeGxpbms6aHJlZj0iI3RqLWQiIHdpZHRoPSIxMDAl'
    b'IiBoZWlnaHQ9IjEwMCUiIGZpbGw9IiNmOGMzMDAiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAg'
    b'MCAxIDY0MCAwKSIvPgo8L3N2Zz4K', 'TJ')

TJ = b64_TJ
index.append("TJ")
index.append("TJK")
index.append("Tajikistan")
catalog["TJ"] = TJ
catalog["TJK"] = TJ
catalog["Tajikistan"] = TJ
country["Tajikistan"] = ('TJ', 'TJK', 0)
lookup["TJ"] = ('TJ', 'TJK', 'Tajikistan', 0)
lookup["Dushanbe Tajikistan"] = ('TJ', 'TJK', 'Tajikistan', 0)
lookup["TJK"] = ('TJ', 'TJK', 'Tajikistan', 0)
lookup["Tajikistan"] = ('TJ', 'TJK', 'Tajikistan', 0)
details["TJ"] = {"continent":"Asia","capital":"Dushanbe","currency":"Somoni","web":".tj","lang":"tg | ru","tz":"+05:00","altname":""}
#----------------------------------------------------------------------
b64_TK = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRrIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwMjQ3ZCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZlZDEwMCIgZD0iTTEwOC4xIDM1'
    b'NC42Yy02LjctLjEgNjIuOC0zNyAxMjAuOS04NC40IDc2LjItNjIuMSAyNDAuMy0xNjEuNCAy'
    b'ODguNi0xNzcuNiA1LTEuNy0xMC4zIDguNi0xMi4zIDExLjktNTEuNSA2MS0xMC40IDE3NiA1'
    b'NCAyMzMuOSAxOS40IDE0LjggMTguNCAxNS42IDU0LjMgMTd2My40bC01MDUuNS00LjJ6bS00'
    b'LjIgNi43cy00LjkgMy41LTQuOSA2LjFjMCAyLjkgNS41IDYuNyA1LjUgNi43bDQ5OC41IDUu'
    b'NSA5LjItNi4xLTEyLjgtNy45LTQ5NS41LTQuM3oiLz4KICA8cGF0aCBmaWxsPSIjZmZmIiBk'
    b'PSJtMTA2LjggMTA5LjEtNCAxMi4yIDEwLjQtNy41IDEwLjMgNy41LTMuOS0xMi4yIDEwLjMt'
    b'Ny41aC0xMi44bC0zLjktMTIuMi00IDEyLjJIOTYuNHptNzguMSA1Ny40IDguNi02LjNoLTEw'
    b'LjdsLTMuMy0xMC4xLTMuMyAxMC4xaC0xMC42bDguNiA2LjMtMy4zIDEwLjEgOC42LTYuMyA4'
    b'LjcgNi4zem0tMTQ1LjIgMTMtNC0xMi4yLTMuOSAxMi4ySDE5bDEwLjMgNy41LTMuOSAxMi4y'
    b'IDEwLjMtNy41IDEwLjQgNy41LTQtMTIuMiAxMC40LTcuNXptNzguMSAxMjIuMy00LjYtMTQu'
    b'Mi00LjYgMTQuMmgtMTVsMTIuMSA4LjctNC42IDE0LjMgMTIuMS04LjggMTIuMSA4LjgtNC43'
    b'LTE0LjMgMTIuMS04Ljd6Ii8+Cjwvc3ZnPgo=', 'TK')

TK = b64_TK
index.append("TK")
index.append("TKL")
index.append("Tokelau")
catalog["TK"] = TK
catalog["TKL"] = TK
catalog["Tokelau"] = TK
country["Tokelau"] = ('TK', 'TKL', 0)
lookup["TK"] = ('TK', 'TKL', 'Tokelau', 0)
lookup["TKL"] = ('TK', 'TKL', 'Tokelau', 0)
lookup["Tokelau"] = ('TK', 'TKL', 'Tokelau', 0)
details["TK"] = {"continent":"Oceania","capital":"","currency":"New Zealand Dollar","web":".tk","lang":"tkl | en-TK","tz":"+13:00","altname":""}
#----------------------------------------------------------------------
b64_TL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRsIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InRsLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMCAwaDY4Mi43djUx'
    b'MkgweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBjbGlwLXBhdGg9InVybCgjdGwtYSkiIHRyYW5zZm9ybT0ic2NhbGUoLjkzNzUpIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNjYjAwMGYiIGQ9Ik0wIDBoMTAzMS4ydjUxMkgweiIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2Y4YzAwYyIgZD0iTTAgMGMzLjIgMCA1MTIgMjU2LjcgNTEyIDI1Ni43'
    b'TDAgNTEyVjB6Ii8+CiAgICA8cGF0aCBkPSJNMCAwYzIuMSAwIDM0MC42IDI1Ni43IDM0MC42'
    b'IDI1Ni43TDAgNTEyVjB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMTg3LjcgMjk4'
    b'LjIgMTI3IDI4NC43bC0zMSA1Mi44LTUtNTkuNy02MC43LTEzLjMgNTQuOS0yNC45LTMuMy01'
    b'OS4zIDQwLjIgNDMuNCA1NS40LTI1LjMtMjguOSA1NCAzOS4yIDQ1Ljh6Ii8+CiAgPC9nPgo8'
    b'L3N2Zz4K', 'TL')

TL = b64_TL
index.append("TL")
index.append("TLS")
index.append("Timor-Leste")
catalog["TL"] = TL
catalog["TLS"] = TL
catalog["Timor-Leste"] = TL
country["Timor-Leste"] = ('TL', 'TLS', 0)
lookup["TL"] = ('TL', 'TLS', 'Timor-Leste', 0)
lookup["Dili Timor-Leste"] = ('TL', 'TLS', 'Timor-Leste', 0)
lookup["TLS"] = ('TL', 'TLS', 'Timor-Leste', 0)
lookup["Timor-Leste"] = ('TL', 'TLS', 'Timor-Leste', 0)
details["TL"] = {"continent":"Asia","capital":"Dili","currency":"US Dollar","web":".tl","lang":"tet | pt-TL | id | en","tz":"+09:00","altname":""}
#----------------------------------------------------------------------
b64_TM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwODQzZCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDBaIi8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTM1Ny42IDUzQTU5'
    b'LjcgNTkuNyAwIDEgMSAyOTUgMTUzLjdhNTkuNyA1OS43IDAgMCAwIDYyLjMtMTAwLjFaTTMw'
    b'MSA5N2w2LjQtMjAuOC0xNy43IDEyLjloMjEuOWwtMTcuOC0xMi45Wm0wLTMwLjYgNi40LTIw'
    b'LjgtMTcuNyAxMi45aDIxLjlsLTE3LjgtMTMuMlpNMzMxLjIgODJsNi40LTIwLjgtMTcuOCAx'
    b'Mi45aDIyTDMyNCA2MS4yWm0tNjEgMzAuMyA2LjktMjAuOC0xNy44IDEyLjhoMjJsLTE3Ljgt'
    b'MTIuOFptMzAuMyAxNS40IDYuOC0yMC43LTE3LjcgMTIuOGgyMS45TDI5My43IDEwN3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJNODYuNiAwaDEyOS42djQ4MEg4Ni42WiIvPgog'
    b'IDxnIGZpbGw9IiMzODM3MzkiPgogICAgPHBhdGggZD0iTTExOCAwaC00LjJsLTguMyA3LjYt'
    b'My0zLjRoM2wtLjgtM2gtNC45bC0xMC4yIDlWMTRoNXYtM2wyLjIgMi4yLTUuMyA0LjZMOTQg'
    b'MjBsLTcuNSA2Ljh2NUw5OSAyMC4zbC0yLjItMi42IDQuOS00LjZMOTcuNSA5bDIuNy0zIDUu'
    b'NiA1LjJaTTg3IDB2OC43TDg5LjUgNlYyLjNoM0w5NS4zIDBabTIyLjYgMGgtM2wuNCAyLjN6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNMTE3LjYgMGgtMy44bC04IDcuNi0z'
    b'LjctMy44aDMuNGwtLjgtMi43aC00LjVsLTkuOSA5LjV2M2gzLjhWOS44bDMuNCAzLjQtNS4z'
    b'IDQuNiAyLjMgMi4yLTcuNiA3LjZ2My44TDk4LjMgMjAgOTYgMTcuOGw1LjMtNC42LTQuNS00'
    b'LjEgMy44LTMuNCA1LjIgNS4zIDExLjQtMTFabS0zMSAwdjguM2wyLjItMi42VjEuOWgzLjRM'
    b'OTQuNSAwWm0yMi42IDBoLTEuOHYxLjV6Ii8+CiAgPC9nPgogIDxnIGZpbGw9IiMzODM3Mzki'
    b'PgogICAgPHBhdGggZD0iTTg2LjYgNTUuNnY0LjlsNy4yIDYuOC0yLjcgMi4yIDUuMyA1LTIu'
    b'MyAxLjh2LTNoLTQuNXYzLjhsMTAuMiA5LjVoNWwuNy0zLjhIMTAybDMtMi43IDguMyA3LjYt'
    b'OC4zIDYuOC0zLTIuN2gzbC0uOC0zLjdoLTQuOWwtOS44IDEwLjJ2My43aDV2LTMuN2wyLjIg'
    b'Mi4yLTUuMyA0LjYgMi42IDIuNi03LjUgNi44djQuNkw5OSAxMDcuN2wtMi4yLTIuNiA0Ljkt'
    b'NC42LTQuMi00LjEgMi43LTIuNyA1LjYgNC42IDEyLjUtMTEuNC0xMi41LTExLjMtNS42IDUu'
    b'My0yLjctMi43IDQuMi00LjEtNS01TDk5IDY3IDg3IDU1LjZ6bTAgMjIuNnYxOC4ybDIuNi0z'
    b'di0zLjhoM2wyLjctMi4zLTIuNy0yLjNoLTN2LTMuN3ptMjAuOCA2LjV2NC45bDIuNi0yLjN6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNODYuNiA1Ni4zdjMuOGw3LjUgNy4y'
    b'LTIuMiAyLjIgNS4zIDUtMy40IDIuNnYtMy40SDkwdjNsOS44IDkuNWg0LjVsLjgtMi43aC0z'
    b'LjhsNC4yLTMuOCA4LjcgNy42LTguNyA3LjYtMy44LTMuOGgzLjRsLS44LTIuM2gtNC41bC05'
    b'LjggOXYzLjFoMy44di0zLjhsMy40IDMuNC01LjMgNC42IDIuMiAyLjYtNy41IDcuMnYzLjhs'
    b'MTEuMy0xMS40LTIuMy0yLjIgNS4zLTQuNi00LjUtNC4xIDMuOC0zLjQgNS42IDUuMyAxMS44'
    b'LTExLTEyLjEtMTEtNS43IDUuMy0zLjQtMyA0LjUtNC4xLTUuMy01IDIuNy0yLjJ6bTAgMjIu'
    b'N3YxNi42bDIuMi0yLjJ2LTMuOGgzLjRsMi4zLTIuMy0yLjMtMS45aC0zLjR2LTMuOHptMjEu'
    b'MSA2LjR2My40bDItMS41WiIvPgogIDwvZz4KICA8ZyBmaWxsPSIjMzgzNzM5Ij4KICAgIDxw'
    b'YXRoIGQ9Ik04Ni42IDE0NS45djUuM2w3LjIgNi44LTIuNyAyLjMgNS4zIDQuNS0yLjMgMi4z'
    b'di0zaC00LjV2My43bDEwLjIgOWg1bC43LTNIMTAybDMtMyA4LjMgNy4yLTguMyA3LjYtMy0z'
    b'LjRoM2wtLjgtMy40aC00LjlsLTEwLjIgOS40djMuOGg1LjN2LTNsMi4zIDEuOS01LjMgNC45'
    b'TDk0IDE5OGwtNy41IDYuOXY0LjlMOTkgMTk4LjRsLTIuMi0yLjYgNC45LTUtNC4yLTMuNyAy'
    b'LjctMyA1LjYgNC45IDEyLjUtMTEuNC0xMi41LTExLjMtNS42IDUuMy0yLjctMyA0LjItMy44'
    b'LTUtNSAyLjMtMi4yLTEyLTExLjN6bTAgMjIuN3YxNy43bDIuNi0yLjZ2LTMuOGgzbDIuNy0y'
    b'LjMtMi43LTIuNmgtM3YtMy40em0yMC44IDYuNHY1bDIuNi0yLjd6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZjNzJjIiBkPSJNODYuNiAxNDYuM3YzLjdsNy41IDcuNkw5MiAxNjBsNS4zIDQu'
    b'NS0zLjQgM3YtMy43SDkwdjMuN2w5LjggOC43aDQuNWwuOC0yLjZoLTMuOGw0LjItMy44IDgu'
    b'NyA3LjYtOC43IDcuOS0zLjgtMy44aDMuNGwtLjgtMi42aC00LjVsLTkuOCA5LjR2M2gzLjh2'
    b'LTMuN2wzLjQgMy01LjMgNC45IDIuMiAyLjMtNy41IDcuNXYzLjhsMTEuMy0xMS4zLTIuMy0y'
    b'LjMgNS4zLTUtNC41LTMuNyAzLjgtMy44IDUuNiA2IDExLjgtMTEuMy0xMi4xLTEwLjUtNS43'
    b'IDUuMi0zLjQtMy40IDQuNS0zLjctNS4zLTUgMi43LTIuMnptMCAyMi42djE3bDIuMi0yLjZ2'
    b'LTMuOGgzLjRsMi4zLTEuOS0yLjMtMi4yaC0zLjR2LTMuOGwtMi4yLTIuM3ptMjEuMSA2Ljh2'
    b'My40bDItMS44WiIvPgogIDwvZz4KICA8ZyBmaWxsPSIjMzgzNzM5Ij4KICAgIDxwYXRoIGQ9'
    b'Ik04Ni42IDIzNi4ydjQuNmw3LjIgNi44LTIuNyAyLjIgNS4zIDUtMi4zIDIuMnYtM2gtNC41'
    b'djMuOGwxMC4yIDloNWwuNy0zLjRIMTAybDMtMi42IDguMyA3LjItOC4zIDcuMS0zLTNoM2wt'
    b'LjgtMy40aC00LjlsLTEwLjIgOS41djMuOGg1LjN2LTNsMi4zIDEuOC01LjMgNUw5NCAyODhs'
    b'LTcuNSA2Ljh2NUw5OSAyODguM2wtMi4yLTIuNyA0LjktNC45LTQuMi0zLjggMi43LTMgNS42'
    b'IDUuMyAxMi41LTExLjMtMTIuNS0xMS40LTUuNiA1LTIuNy0yLjcgNC4yLTMuOC01LTUuMyAy'
    b'LjMtMi4yLTEyLTExLjR6bTAgMjIuN3YxNy44bDIuNi0zdi0zLjVoM0w5NSAyNjhsLTIuNy0y'
    b'LjdoLTNWMjYyem0yMC44IDYuNHY1bDIuNi0yLjd6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZj'
    b'NzJjIiBkPSJNODYuNiAyMzYuNnYzLjhsNy41IDcuNS0yLjIgMiA1LjMgNC44LTMuNCAzVjI1'
    b'NEg5MHYzLjRsOS44IDloNC41bC44LTIuNmgtMy44bDQuMi0zLjggOC43IDcuNi04LjcgOC0z'
    b'LjgtMy45aDMuNGwtLjgtMi42aC00LjVsLTkuOCA5djMuNWgzLjh2LTMuOGwzLjQgMy01LjMg'
    b'NUw5NCAyODhsLTcuNSA3LjZ2My43TDk3LjkgMjg4bC0yLjMtMi4zIDUuMy00LjktNC41LTMu'
    b'OCAzLjgtMy43IDUuNiA1LjYgMTEuOC0xMS4zLTEyLjEtMTAuNi01LjcgNS4zLTMuNC0zLjQg'
    b'NC41LTMuOC01LjMtNS4zIDIuNy0yLjJ6bTAgMjIuN3YxN2wyLjItMi43VjI3MGgzLjRsMi4z'
    b'LTItMi4zLTIuMmgtMy40VjI2MmwtMi4yLTIuMnptMjEuMSA2Ljh2My40bDItMloiLz4KICA8'
    b'L2c+CiAgPGcgZmlsbD0iIzM4MzczOSI+CiAgICA8cGF0aCBkPSJNODYuNiAzMjYuNnY0LjVs'
    b'Ny4yIDYuOC0yLjcgMi4zIDUuMyA0LjktMi4zIDEuOXYtM2gtNC41djMuN2wxMC4yIDkuNWg1'
    b'bC43LTMuNEgxMDJsMy0zIDguMyA3LjUtOC4zIDcuMi0zLTNoM2wtLjgtMy40aC00LjlsLTEw'
    b'LjIgOS40djMuOGg1LjN2LTMuNGwyLjMgMi4yLTUuMyA1IDIuNiAyLjItNy41IDYuOHY0LjZM'
    b'OTkgMzc4LjNsLTIuMi0yLjIgNC45LTUtNC4yLTQuMSAyLjctMi43IDUuNiA1LjMgMTIuNS0x'
    b'MS4zLTEyLjUtMTEuMy01LjYgNC45LTIuNy0yLjcgNC4yLTQuMS01LTVMOTkgMzM4em0wIDIy'
    b'LjZWMzY3bDIuNi0zdi0zLjRoM2wyLjctMi43LTIuNy0yLjJoLTN2LTMuOHptMjAuOCA2LjV2'
    b'NC41bDIuNi0yLjN6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNODYuNiAzMjd2'
    b'My43TDk0IDMzOGwtMi4yIDIuMyA1LjMgNC45LTMuNCAzdi0zLjhIOTB2My40bDkuOCA5aDQu'
    b'NWwuOC0yLjZoLTMuOGw0LjItMy43IDguNyA3LjUtOC43IDgtMy44LTMuOGgzLjRsLS44LTIu'
    b'N2gtNC41bC05LjggOS4xdjMuNGgzLjh2LTMuOGwzLjQgMy01LjMgNSAyLjIgMi4yLTcuNSA3'
    b'LjZ2My40TDk3LjkgMzc4bC0yLjMtMiA1LjMtNC45LTQuNS00LjEgMy44LTMuNCA1LjYgNS4z'
    b'IDExLjgtMTEtMTIuMS0xMS01LjcgNS40LTMuNC0zIDQuNS00LjItNS4zLTUgMi43LTIuMlpt'
    b'MCAyMi42djE3bDIuMi0yLjN2LTMuN2gzLjRsMi4zLTIuMy0yLjMtMS45aC0zLjR2LTMuOGwt'
    b'Mi4yLTIuNnptMjEuMSA2LjR2My44bDItMS45WiIvPgogIDwvZz4KICA8ZyBmaWxsPSIjMzgz'
    b'NzM5Ij4KICAgIDxwYXRoIGQ9Ik0xODQuNSAwaDQuNWw3LjYgNy42IDMuOC0zLjhoLTNsLjct'
    b'M2g0LjlsMTAuMiA5djMuOEgyMDh2LTNsLTIuMyAyLjMgNS4zIDQuNS0yLjYgMi4zIDcuNiA2'
    b'Ljh2NC45TDIwMy40IDIwbDIuMi0yLjYtNC45LTQuNSA0LjItNC4yLTIuNy0zLTUuNiA1LjZa'
    b'bTMxLjcgMHY4LjdsLTMtMi43VjIuM2gtM0wyMDcuNSAwWm0tMjMuOCAwaDNsLS4zIDIuM3oi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiNmZmM3MmMiIGQ9Ik0xODUuMiAwaDNsOC44IDcuNiAzLjct'
    b'My44aC0zLjRsLjgtMi43aDQuNWw5LjkgOS41djNoLTMuOFY5LjhsLTMgMy40IDQuOSA0LjYt'
    b'Mi4zIDIuNiA3LjYgNy4ydjMuOEwyMDQuNSAyMGwyLjMtMi4yLTUuMy00LjYgNC41LTQuMS0z'
    b'LjgtMy40LTQuOSA1LjZMMTg1IDBabTMxIDB2OC4zbC0yLjYtMi42VjEuOWgtMy40bC0yLTEu'
    b'OVptLTIzLjQgMGgyLjN2MS41eiIvPgogICAgPHBhdGggZD0iTTIxNi4yIDU1LjZ2NC45bC03'
    b'LjUgNi44IDIuNiAyLjItNS4zIDUgMi4zIDEuOHYtM2g0LjV2My44bC0xMC4yIDkuNWgtNC45'
    b'bC0uNy0zLjhoM2wtMy0yLjctOCA3LjYgNy42IDYuOCAzLjQtMi43aC0zbC43LTMuN2g1bDEw'
    b'LjEgOS44djMuOEgyMDh2LTMuNGwtMi4zIDIuMiA1LjMgNC42LTIuNiAyLjYgNy42IDYuOHY0'
    b'LjZsLTEyLjUtMTEuNCAyLjItMi42LTQuOS00LjYgNC4yLTQuMS0yLjctMi43LTUuNiA0LjZM'
    b'MTg0IDg2LjlsMTIuNS0xMS4zIDUuNiA1LjMgMi43LTIuNy00LjItNC4xIDUtNS0yLjMtMi4y'
    b'IDEyLjUtMTEuM3ptMCAyMi42djE4LjJsLTMtM3YtMy44aC0zbC0yLjctMi4zIDIuNy0yLjNo'
    b'M3YtMy43em0tMjEuMSA2LjUuMyAyLjYtLjMgMi4zLTIuNy0yLjN6Ii8+CiAgICA8cGF0aCBm'
    b'aWxsPSIjZmZjNzJjIiBkPSJNMjE2LjIgNTYuM3YzLjhsLTguMyA2LjggMi4zIDIuMy01IDQu'
    b'OSAzIDIuNnYtMy40aDMuOXYzbC05LjkgOS41aC00LjVsLS43LTIuN2gzLjdsLTQuMS0zLjct'
    b'OC43IDcuNSA4LjcgNy42IDMuOC0zLjhIMTk3bC43LTIuM2g0LjVsOS45IDkuMXYzaC0zLjh2'
    b'LTMuN2wtMyAzLjQgNC45IDQuNS0yLjMgMi42IDcuNiA3LjJ2My44TDIwNCAxMDdsMi4zLTIu'
    b'My01LjMtNC41IDQuNS00LjItMy43LTMuNC01LjMgNS4zLTEyLjEtMTEgMTItMTEgNS43IDUu'
    b'NCAzLjQtMy00LjUtNC4yIDUuMy01LTIuNi0yLjJ6bTAgMjIuN3YxNi42bC0yLjYtMi4ydi0z'
    b'LjhoLTMuNGwtMi0yLjMgMi0xLjloMy40di0zLjh6bS0yMS41IDYuNC40IDJ2MS40bC0yLjMt'
    b'MS41WiIvPgogICAgPHBhdGggZD0iTTIxNi4yIDE0NS45djUuM2wtNy41IDYuOCAyLjYgMi4z'
    b'LTUuMyA0LjUgMi4zIDIuM3YtM2g0LjV2My43bC0xMC4yIDloLTQuOWwtMS4xLTNoM2wtMy0z'
    b'LTcuNiA2LjggNy42IDcuNiAzLjQtMy40aC0zbC43LTMuNGg1bDEwLjEgOS40djMuOEgyMDh2'
    b'LTNsLTIuMyAxLjkgNS4zIDQuOS0yLjYgMi4zIDcuNiA2Ljh2NC45TDIwMy40IDE5OGwyLjIt'
    b'Mi42LTQuOS01IDQuMi0zLjctMi43LTMtNS42IDUuMy0xMi41LTExLjQgMTIuNS0xMS4zIDUu'
    b'NiA1LjMgMi43LTMtNC4yLTMuOCA1LTUtMi4zLTIuMiAxMi41LTExLjN6bTAgMjIuN3YxNy43'
    b'bC0zLTIuNnYtMy44aC0zbC0yLjctMi4zIDIuNy0yLjZoM3YtMy40em0tMjEuMSA2LjQuMyAy'
    b'LjMtLjMgMi42LTIuNy0yLjZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNMjE2'
    b'LjIgMTQ2LjN2My43bC04IDcuNiAyLjQgMi4zLTUgNC41IDMgM3YtMy43aDMuOXYzLjdsLTku'
    b'OSA4LjdoLTQuNWwtLjgtMi42aDMuOGwtNC41LTMuNC04LjcgNy41IDguNyA4IDMuOC0zLjhI'
    b'MTk3bC43LTIuN2g0LjVsOS45IDkuNXYzaC0zLjh2LTMuOGwtMyAzIDQuOSA1LTIuMyAyLjIg'
    b'Ny42IDcuNnYzLjhMMjA0IDE5OGwyLjMtMi4yLTUuMy01IDQuNS0zLjctMy43LTMuOC01LjMg'
    b'NS43LTEyLjEtMTEuNCAxMi0xMC41IDUuNyA1LjIgMy40LTMuNC00LjUtMy43IDUuMy01LTIu'
    b'Ni0yLjJ6bTAgMjIuNnYxN2wtMi42LTIuNnYtMy44aC0zLjRsLTItMS45IDItMi4yaDMuNHYt'
    b'My44bDIuNi0yLjN6bS0yMS41IDYuOC40IDEuNnYxLjhsLTIuMy0xLjhaIi8+CiAgICA8cGF0'
    b'aCBkPSJNMjE2LjIgMjM2LjJ2NC42bC03LjUgNi44IDIuNiAyLjItNS4zIDUgMi4zIDIuMnYt'
    b'M2g0LjV2My44bC0xMC4yIDloLTQuOWwtLjctMy40aDNsLTMtMi42LTggNy4yIDcuNiA3LjEg'
    b'My40LTNoLTNsLjctMy40aDVsMTAuMSA5LjV2My44SDIwOHYtM2wtMi4zIDEuOCA1LjMgNS0y'
    b'LjYgMi4yIDcuNiA2Ljh2NWwtMTIuNS0xMS40IDIuMi0yLjctNC45LTQuOSA0LjItMy44LTIu'
    b'Ny0zLTUuNiA1LjNMMTg0IDI2OGwxMi41LTExLjQgNS42IDUgMi43LTIuNy00LjItMy44IDUt'
    b'NS4zLTIuMy0yLjIgMTIuNS0xMS40em0wIDIyLjd2MTcuOGwtMy0zdi0zLjVoLTNsLTIuNy0y'
    b'LjIgMi43LTIuN2gzVjI2MnptLTIxLjEgNi40LjMgMi4zLS4zIDIuNi0yLjctMi42eiIvPgog'
    b'ICAgPHBhdGggZmlsbD0iI2ZmYzcyYyIgZD0iTTIxNi4yIDIzNi42djMuOGwtOCA3LjUgMi40'
    b'IDItNSA0LjggMyAzVjI1NGgzLjl2My40bC05LjkgOWgtNC41bC0uOC0yLjZoMy44TDE5NyAy'
    b'NjBsLTguNyA3LjYgOC43IDggMy43LTMuOWgtMy40bC44LTIuNmg0LjVsOS45IDl2My41aC0z'
    b'Ljh2LTMuOGwtMyAzIDQuOSA1LTIuMyAyLjIgNy42IDcuNnYzLjdMMjA0LjUgMjg4bDIuMy0y'
    b'LjMtNS4zLTQuOSA0LjUtMy44LTMuOC0zLjctNS4yIDUuNi0xMi4xLTExLjMgMTItMTAuNiA1'
    b'LjcgNS4zIDMuNC0zLjQtNC41LTMuOCA1LjMtNS4zLTIuNy0yLjJ6bTAgMjIuN3YxN2wtMi42'
    b'LTIuN1YyNzBoLTMuNGwtMi0yIDItMi4yaDMuNFYyNjJsMi42LTIuMnptLTIxLjUgNi44LjQg'
    b'MS41djEuOWwtMi4zLTJaIi8+CiAgICA8cGF0aCBkPSJNMjE2LjIgMzI2LjZ2NC41bC03LjUg'
    b'Ni44IDIuNiAyLjMtNS4zIDQuOSAyLjMgMS45di0zaDQuNXYzLjdsLTEwLjIgOS41aC00Ljls'
    b'LS43LTMuNGgzbC0zLTMtOCA3LjUgNy42IDcuMiAzLjQtM2gtM2wuNy0zLjRoNWwxMC4xIDku'
    b'NHYzLjhIMjA4di0zLjRsLTIuMyAyLjIgNS4zIDUtMi42IDIuMiA3LjYgNi44djQuNmwtMTIu'
    b'NS0xMS40IDIuMi0yLjItNC45LTUgNC4yLTQuMS0yLjctMi43LTUuNiA1LjMtMTIuNS0xMS4z'
    b'IDEyLjUtMTEuMyA1LjYgNC45IDIuNy0yLjctNC4yLTQuMSA1LTUtMi4zLTIuMnptMCAyMi42'
    b'VjM2N2wtMy0zdi0zLjRoLTNsLTIuNy0yLjcgMi43LTIuMmgzdi0zLjh6bS0yMS4xIDYuNS4z'
    b'IDIuMi0uMyAyLjMtMi43LTIuM3oiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmM3MmMiIGQ9Ik0y'
    b'MTYuMiAzMjd2My43TDIwOCAzMzhsMi4zIDIuMy01IDQuOSAzIDN2LTMuOGgzLjl2My40bC05'
    b'LjkgOWgtNC41bC0uNy0yLjZoMy43bC00LjEtMy43LTguNyA3LjUgOC43IDggMy44LTMuOEgx'
    b'OTdsLjctMi43aDQuNWw5LjkgOS4xdjMuNGgtMy44di0zLjhsLTMgMyA0LjkgNS0yLjMgMi4y'
    b'IDcuNiA3LjZ2My40TDIwNCAzNzhsMi4zLTItNS4zLTQuOSA0LjUtNC4xLTMuNy0zLjQtNS4z'
    b'IDUuMy0xMi4xLTExIDEyLTExIDUuNyA1LjQgMy40LTMtNC41LTQuMiA1LjMtNS0yLjYtMi4y'
    b'em0wIDIyLjZ2MTdsLTIuNi0yLjN2LTMuN2gtMy40bC0yLTIuMyAyLTEuOWgzLjR2LTMuOGwy'
    b'LjYtMi42em0tMjEuNSA2LjQuNCAydjEuOGwtMi4zLTEuOVoiLz4KICA8L2c+CiAgPHBhdGgg'
    b'ZmlsbD0iI2ZmYzcyYyIgZD0iTTk2LjggNDI0LjhjLjcgMi43IDMgNC42IDMuOCA3LjYuNy0z'
    b'IDEuNS01LjcgMS04LjctLjctMi4zLTIuNi0zLjgtMi42LTYuNC0yLjIgMS44LTIuNiA0LjUt'
    b'Mi4yIDcuNXptLS40IDExLjRhMTcuOCAxNy44IDAgMCAwIDcuMiA1LjZjLS44LTIuMiAwLTMu'
    b'OCAxLjUtNS42IDEuMS0yIDEuOS0zLjguNy02LjVhMTQuNCAxNC40IDAgMCAxLTEuOCAzLjQg'
    b'MTAgMTAgMCAwIDAtMi4zIDUuM2MtMS41LTEuMS0xLjktMi42LTIuNy00LjFhMTIuOSAxMi45'
    b'IDAgMCAwLTUuMi01LjNjLjcgMi42IDEgNC45IDIuNiA3LjJ6bTEwLjIgNy41LS44IDMuOC00'
    b'LjEtM2MtMS45LTItNC4yLTIuNy01LjctNWE5IDkgMCAwIDAgMy44IDcuMmw4IDVjLS40LTIu'
    b'Ny43LTUgMS40LTcuNmE2LjggNi44IDAgMCAwLTEuNS02YzAgMS44LS43IDMuNy0xLjEgNS4y'
    b'em01LjMgOC43IDMgNS4zYy0yLjYtLjgtNC45LTIuMy03LjUtMy44LTIuNy0xLjUtNS43LTIu'
    b'Mi04LjQtNC41YTEzIDEzIDAgMCAwIDkuMSA5YzMuNC44IDYgLjQgOS44IDJhMjYuNSAyNi41'
    b'IDAgMCAwLTIuNi03LjZsLTIuMy01LjNhNS43IDUuNyAwIDAgMC0xLjEgNXptOS44IDcuMmEx'
    b'Mi4xIDEyIDAgMCAwIDMuOCAzLjhjLTMuOCAwLTYuOC0yLTEwLjYtMi4zLTIuMiAwLTQuNS44'
    b'LTYuOC40IDMgMS45IDUuNyAzLjggOSAzLjggNC4yLjcgOC40IDAgMTMuMyAwYTE3LjIgMTcu'
    b'MiAwIDAgMS00LjktNS43Yy0xLjktMy0zLjgtNS03LjItNS4zbDMuOCA1LjN6bTEzLjMgNmMt'
    b'Ni41IDEuMi0xMi45IDIuNy0xOS43IDIuN2EzMC4zIDMwLjMgMCAwIDAgMjIuMy40YzMuOC0x'
    b'LjIgNy4yLTIuMyAxMC4yLTIgNC41IDAgOS44IDIuMyAxNS45IDguNGwyLjMtMS45YTM2LjMg'
    b'MzYuMyAwIDAgMC0zMS03LjZ6Ii8+CiAgPHBhdGggZmlsbD0iIzM4MzczOSIgZD0iTTEwMi44'
    b'IDU2LjMgOTIuMiA1MFYzNC44bDEwLjYtNi41VjIwbDkuNS01LjZoOGwxNS04LjdoMzEuOGwx'
    b'NS4xIDguN2g3LjZsMTAuNiA1LjZ2OC4zbDEwLjIgNi41djE1bC0xMC4yIDYuNXY4bC05Ljkg'
    b'NmgtOGwtMTUgOC4zaC0zMS44bC0xNS4xLTguM0gxMTNsLTEwLjYtNnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjMDA4NDNkIiBkPSJtMTM1LjMgNi0xNSA4LjdoLTcuNmwtOS45IDUuN3Y4bC0xMC4y'
    b'IDYuNHYxNWwxMC4yIDYuMXY4LjRsOS45IDUuNmg3LjVsMTUuMSA4LjNoMzEuOGwxNS4xLTgu'
    b'M2g3LjZsOS44LTUuNnYtOC40bDEwLjItNlYzNC44bC0xMC4yLTYuNXYtNy45bC05LjgtNS43'
    b'aC03LjZMMTY3LjEgNlptLjggMy40aDMwLjJsMTUuMiA4LjRoNy41bDcuNiA0LjF2OC4zbDEw'
    b'LjIgNi41VjQ4bC0xMC42IDYuNHY4bC03LjIgNC41aC03LjVsLTE1LjIgOC4zaC0zMC4yTDEy'
    b'MSA2N2gtNy42bC03LjYtNC41di04TDk1LjYgNDhWMzYuN2wxMC42LTYuNVYyMmw3LjYtNC4x'
    b'aDcuNXoiLz4KICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNMTUxLjIgNDIuM1Y5LjRoLTE1'
    b'LjFsLTE0LjggOC43aC03LjVsLTcuNiAzLjh2OC4zTDk2IDM2LjdWNDJoNTUuMnYzMi44aDE1'
    b'LjFsMTUuMi04LjNoNy41bDYuOC00LjFWNTRsMTAuNi02LjR2LTUuM3oiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZmZmIiBkPSJNOTYgNDIuM3Y1LjNsMTAuNiA2LjR2OC40bDYuOCAzLjdoOGwxNSA4'
    b'LjdoMTQuOFY0Mmg1NS4ydi01LjNsLTEwLjYtNi41di03LjVMMTg5IDE4aC03LjVsLTE1LjIt'
    b'OC43aC0xNXYzM1oiLz4KICA8ZyBmaWxsPSIjMzgzNzM5Ij4KICAgIDxwYXRoIGQ9Im0xMTgu'
    b'NyAyMS4yLTIuNi0yLjctMi4zIDEuNSAyLjYgMi43LTMuNyAxLjloNy41bDYgNiAyLTIuMy02'
    b'LjEtNS42di0zLjhaIi8+CiAgICA8cGF0aCBkPSJtMTMwLjggMjAtMi42LTIuMi0yLjMgMS41'
    b'IDIuNiAyLjItMy44IDJoNy42bDYgNiAyLTIuMy01LjctNS43di0zLjd6bS0xMi45IDcuNi0y'
    b'LjYtMi4zLTIuNiAyIDIuNiAyLjItMy40IDEuOWg3LjZsNiA2IDEuOS0yLjMtNi01LjZ2LTMu'
    b'OHoiLz4KICAgIDxwYXRoIGQ9Ik0xNTEuMiA5LjRoLTYuNGwtMy40IDNoLTYuOGwtNC42IDIu'
    b'NyAxLjIgMi43IDQuMS0yLjNoMmw2LjcgNy42IDcuMi00LjJaIi8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjZDIyNjMwIiBkPSJtMTE2IDE4LjkgMi4zIDIuMy0xLjkgMS4xLTIuMi0xLjl6bTYuMS44'
    b'djNsNS43IDUuNi0xLjUgMS42LTYtNS43aC02LjFsNy41LTV6bTYtMS42IDIuMyAyLTEuOSAx'
    b'LjQtMi4yLTIuMlptNi4xIDBWMjJsNS43IDUuMy0xLjUgMS45LTYtNi40aC02LjFsNy41LTQu'
    b'NnoiLz4KICAgIDxwYXRoIGZpbGw9IiNkMjI2MzAiIGQ9Im0xMTUuMyAyNiAyLjMgMi0yIDEu'
    b'MS0yLjItMS45Wm01LjcgMHY0bDYgNS4yLTEuNSAxLjYtNi01LjdoLTZabTMwLjItMTYuNmgt'
    b'Ni40bC0zLjQgMy44SDEzNWwtNC42IDIgLjggMi4yTDEzNSAxNWgyLjZsNiA3LjYgNy42LTMu'
    b'OFoiLz4KICAgIDxwYXRoIGQ9Im0xMTguNyA2My41LTIuNiAyLjMtMi4zLTEuNSAyLjYtMi4z'
    b'LTMuNy0yLjNoNy41bDYtNS43IDIgMi4zTDEyMiA2MnYzLjh6Ii8+CiAgICA8cGF0aCBkPSJt'
    b'MTMwLjggNjQuMy0yLjYgMi42LTIuMy0xLjUgMi42LTIuMy0zLjgtMi4yaDcuNmw2LTUuNyAy'
    b'IDEuOS01LjcgNS42djMuOHptLTEyLjktNy42LTIuNiAyLjMtMi42LTEuNiAyLjYtMi4yLTMu'
    b'NC0yLjNoNy42bDYtNS43IDEuOSAyLTYgNS42djMuOHoiLz4KICAgIDxwYXRoIGQ9Ik0xNTEu'
    b'MiA3NS4yaC02LjRsLTMuNC0zLjRoLTYuOGwtNC42LTIuMyAxLjItMyA0LjEgMi4zaDJsNi43'
    b'LTcuNiA3LjYgNC42eiIvPgogICAgPHBhdGggZmlsbD0iI2QyMjYzMCIgZD0ibTExNiA2NS40'
    b'IDIuMy0yLjMtMS45LTEuMS0yLjIgMi4zem02LjEtLjR2LTMuNGw1LjctNS43LTEuNS0xLjUt'
    b'NiA1LjdoLTYuMWw3LjUgNXptNiAxLjUgMi4zLTIuMi0xLjktMS4yLTIuMiAyLjN6bTYuMS0u'
    b'NHYtMy43bDUuNy01LjMtMS41LTEuNS02IDUuNmgtNi4xbDcuNSA1eiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iI2QyMjYzMCIgZD0ibTExNS4zIDU4LjYgMi4zLTIuMy0yLTEuMS0yLjIgMi4yWm01'
    b'LjctLjR2LTMuNGw2LTUuNy0xLjUtMS41LTYgNS43aC02Wm0zMC4yIDE2LjZoLTYuNGwtMy40'
    b'LTMuNEgxMzVsLTQuNi0yLjIuOC0yIDMuOCAyaDIuNmw2LjQtNy42IDcuMiA0LjJ6Ii8+CiAg'
    b'ICA8cGF0aCBkPSJtMTE0LjUgMzEuNy0zLTEtNC4xIDIuNnYuN2wtNi41IDguMyA2LjUgOHYu'
    b'N2wzLjcgMyAzLjQtMS0xLjgtMS42di0yLjNsLjctLjdoMy40VjM2LjNIMTEzbC0uMy0uOFYz'
    b'M1oiLz4KICAgIDxwYXRoIGZpbGw9IiNkMjI2MzAiIGQ9Im0xMDcuNyAzMy42IDMuOC0yLjYg'
    b'Mi4zLjctMS41IDEuMnYyLjZsLjcgMS4yaDMuNFY0OEgxMTNsLS43IDEuMXYyLjdsMS41Ljct'
    b'Mi4zIDEuMi0zLjgtMi43di0uN2wtNi40LTggNi40LTguM1oiLz4KICA8L2c+CiAgPGcgZmls'
    b'bD0iIzM4MzczOSI+CiAgICA8cGF0aCBkPSJtMTgzLjcgMjEuMiAyLjctMi43IDIuMiAxLjUt'
    b'Mi4yIDIuNyAzIDEuOWgtNy4ybC02IDYtMi0yLjMgNi4xLTUuNnYtMy44WiIvPgogICAgPHBh'
    b'dGggZD0ibTE3MS42IDIwIDIuNy0yLjIgMi4yIDEuNS0yLjIgMi4yIDMgMkgxNzBsLTYgNi0y'
    b'LTIuMyA2LjEtNS43di0zLjd6bTEyLjkgNy42IDIuNi0yLjMgMi43IDItMi43IDIuMiAzLjQg'
    b'MS45SDE4M2wtNS43IDYuNC0xLjktMi4zIDYtNS42VjI2eiIvPgogICAgPHBhdGggZD0iTTE1'
    b'MS4yIDkuNGg2LjRsMy44IDNoNi40bDUgMi43LTEuMiAyLjctNC41LTIuM2gtMS45bC02Ljgg'
    b'Ny42LTcuMi00LjJaIi8+CiAgICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJtMTg2LjQgMTgu'
    b'OS0yLjMgMi4zIDEuOSAxLjEgMi4zLTEuOXptLTUuNy44djNsLTYgNS42IDEuNSAxLjYgNi01'
    b'LjdoNmwtNy41LTV6bS02LjgtMS42LTIuMyAyIDIgMS40IDIuMi0yLjJabS01LjcgMFYyMmwt'
    b'NS42IDUuMyAxLjUgMS45IDYtNi40aDZsLTcuNS00LjZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'ZDIyNjMwIiBkPSJtMTg3LjEgMjYtMi4yIDIgMS44IDEuMSAyLjMtMS45Wm0tNS42IDB2NGwt'
    b'Ni4xIDUuMiAxLjUgMS42IDYtNS43aDYuMVpNMTUxLjIgOS41aDYuNGwzLjQgMy44aDYuNWw0'
    b'LjUgMi0uOCAyLjItMy43LTIuM2gtMi4zbC02LjggNy42LTcuMi0zLjhaIi8+CiAgICA8cGF0'
    b'aCBkPSJtMTgzLjcgNjMuNSAyLjcgMi4zIDIuMi0xLjUtMi4yLTIuMyAzLTIuM2gtNy4ybC02'
    b'LTUuNy0yIDIuMyA2LjEgNS43djMuOHoiLz4KICAgIDxwYXRoIGQ9Im0xNzEuNiA2NC4zIDIu'
    b'NyAyLjYgMi4yLTEuNS0yLjItMi4zIDMtMi4ySDE3MGwtNi01LjctMiAxLjkgNi4xIDUuNnYz'
    b'Ljh6bTEyLjktNy42TDE4NyA1OWwyLjctMS42LTIuNy0yLjIgMy40LTIuM0gxODNsLTYtNS43'
    b'LTIgMiA2IDUuNnYzLjh6Ii8+CiAgICA8cGF0aCBkPSJNMTUxLjIgNzUuMmg2LjRsMy44LTMu'
    b'NGg2LjRsNS0yLjMtMS4yLTMtNC41IDIuM2gtMS45bC02LjgtNy42LTcuMiA0LjZ6Ii8+CiAg'
    b'ICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJNMTg2LjQgNjUuNCAxODQgNjNsMi0xIDIuMyAy'
    b'LjN6bS01LjctLjR2LTMuNGwtNi01LjcgMS41LTEuNSA2IDUuN2g2em0tNi40IDEuNS0yLjMt'
    b'Mi4yIDEuOS0xLjIgMi4zIDIuM3ptLTUuNy0uNHYtMy43bC02LTVMMTY0IDU2bDYgNS43aDZs'
    b'LTcuNSA1eiIvPgogICAgPHBhdGggZmlsbD0iI2QyMjYzMCIgZD0ibTE4Ny4xIDU4LjYtMi4y'
    b'LTIuMyAxLjgtMS4xIDIuMyAyLjJ6bS01LjYtLjR2LTMuNGwtNi4xLTUuNyAxLjUtMS41IDYg'
    b'NS43aDYuMVptLTMwLjMgMTYuNmg2LjRsMy40LTMuNGg2LjVsNC41LTIuMi0uOC0yLTMuNyAy'
    b'aC0yLjNsLTYuOC03LjYtNy4yIDQuMnoiLz4KICAgIDxwYXRoIGQ9Im0xODcuOSAzMS43IDMt'
    b'MSA0LjIgMi42di43bDYuNCA4LjMtNi40IDh2LjdsLTMuOCAzLTMuNC0xIDEuOS0xLjZ2LTIu'
    b'M2wtLjgtLjdoLTMuNFYzNi4zaDMuOGwuNC0uOFYzM1oiLz4KICAgIDxwYXRoIGZpbGw9IiNk'
    b'MjI2MzAiIGQ9Im0xOTQuNyAzMy42LTMuOC0yLjYtMi4zLjcgMS41IDEuMnYyLjZsLS43IDEu'
    b'MkgxODZWNDhoMy40bC43IDEuMXYyLjdsLTEuNS43IDIuMyAxLjIgMy44LTIuN3YtLjdsNi40'
    b'LTgtNi40LTguM1oiLz4KICA8L2c+CiAgPHBhdGggZmlsbD0iIzM4MzczOSIgZD0ibTEwOC45'
    b'IDQ5LjEtMS41LTEuNVY0N2wtMy44LTQuNiAzLjgtNC41VjM3bDEuNS0xLjUgMy40IDIuN2gt'
    b'MmwyLjcgMi42aDZsNS0zLjh2LTkuOGgxMS43bDE0LTguN3YtMi4ybC0yLjMtMS4yLTIuNiAy'
    b'djFsLTItMi42IDMuOS0zIDQuMS0yLjdoMS41bDMuOCAyLjdoLjhsMy44IDMtMiAyLjYtLjMt'
    b'MS0yLjctMmgtLjdsLTIuMyAxLjVWMTlsMTQgOC43aDEyLjF2OS44bDQuNSAzLjhoNmwyLjct'
    b'Mi42aC0xLjVsMy0yLjcgMS42IDEuNXYuOGwzLjcgNC41LTMuNyA0LjV2LjhsLTEuNiAxLjUt'
    b'My0yLjZoMS41bC0yLjYtMi43aC02bC00LjYgMy44djkuOGgtMTIuNWwtMTQgOC4zdjIuM2wy'
    b'LjMgMS41aC40bDIuNi0xLjV2LTEuMWwyIDIuNi0zLjUgMi43aC0uNGwtNC4xIDNIMTUwbC0z'
    b'LjgtM2gtLjhsLTMuNy0zIDIuMi0yLjN2MS4xbDIuNyAxLjVoLjRsMi4yLTEuNXYtMi4zbC0x'
    b'NC04LjNoLTExLjdWNDhsLTQuOS0zLjhoLTZMMTEwIDQ3aDEuOXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmZjNzJjIiBkPSJtMTUxLjIgNzAgMS45IDEtMS45IDEuMnptLTQuNSAxLjggMy44IDNo'
    b'Ljd2LTIuMkwxNDkgNzFsMi4zLTEuNlY2NWwtMTUuMS05aC0xMXYtOS4xbC01LjYtNC42aC04'
    b'LjdsLTIgMi43LTIuMi0yLjdIMTA0bDMuNyA0LjJ2LjdsMS4yIDEuNiAyLjItMmgtMXYtLjNs'
    b'Mi42LTNoNi40bDUuMyAzLjd2OS45aDExLjNsMTQuNCA4Ljd2Mi42bC0yLjMgMS41aC0xLjFs'
    b'LTIuMy0xLjV2LS43bC0xLjUgMS41IDMgMi42em0tMzcuOC0zMS43IDEuNSAxLjlIMTA3em00'
    b'Mi4zLTI3LjYtMS41IDEuMSAxLjUgMS4xek0xOTIgNDIuN2wxLjUgMS41IDItMS45em0tMzYu'
    b'My0zMC4yLTMuNy0zaC0uOHYyLjJsMi4zIDItMi4zIDEuNFYxOWwxNS4xIDloMTF2OS45TDE4'
    b'MyA0Mmg4LjdsMS44LTIuMyAyLjMgMi4zaDIuN2wtMy44LTMuOFYzN2wtMS4yLTEtMi4yIDEu'
    b'OGgxLjFsLTIuNiAzLjRoLTYuNWwtNC45LTMuOFYyNy4yaC0xMmwtMTQtOC4zdi0yLjZsMi4y'
    b'LTEuNmgxLjFsMi4zIDEuNnYuN2wxLjUtMS45LTMtMi42eiIvPgogIDxwYXRoIGZpbGw9IiNm'
    b'ZmYiIGQ9Im0xNTEuMiA3Mi4yLTEuNS0xLjEgMS41LTEuMnptLTQwLjgtMjkuOS0xLjUgMi0y'
    b'LTJ6bTQ1LjMgMjkuNS0zLjcgM2gtLjh2LTIuMmwyLjMtMS41LTIuMy0xLjZWNjVsMTUuMS05'
    b'aDExdi05LjFsNS43LTQuNmg4LjdsMS44IDIuNyAyLjMtMi43aDIuN2wtMy44IDQuMnYuN2wt'
    b'MS4yIDEuNi0yLjItMmgxLjF2LS4zbC0yLjYtM2gtNi41bC00LjkgMy43djkuOWgtMTJMMTUy'
    b'IDY1Ljh2Mi42bDIuMiAxLjVoMS4ybDIuMi0xLjV2LS43bDEuNSAxLjUtMyAyLjZ6bTM3Ljgt'
    b'MzEuN0wxOTIgNDJoMy40em0tNDYuOC0yNy42IDMuOC0zaC43djIuMmwtMi4zIDIgMi4zIDEu'
    b'NFYxOWwtMTUuMSA5aC0xMXY5LjlsLTUuNiAzLjhoLTguN2wtMi0yLjMtMi4yIDIuM0gxMDRs'
    b'My43LTMuOHYtMS4xbDEuMi0xLjIgMi4yIDJoLTFsMi42IDMuM2g2LjRsNS4zLTMuOHYtOS44'
    b'aDExLjNsMTQuOC04LjN2LTIuNmwtMi4zLTEuNkgxNDdsLTIuMyAxLjZ2LjdsLTEuNS0xLjkg'
    b'My0yLjZoLjh6bTQuNSAyLjYgMS45LTEuMS0xLjktMS4xeiIvPgogIDxwYXRoIGZpbGw9IiMw'
    b'MDg0M2QiIGQ9Ik0xNTEuMiA0Mi4zVjE5LjdsLTE1LjEgOWgtMTAuNnY5LjFsLTUuMyA0LjJo'
    b'MzF2MjIuNmwxNS4xLTlIMTc3di04LjdsNS4zLTQuNnoiLz4KICA8cGF0aCBmaWxsPSIjZDIy'
    b'NjMwIiBkPSJtMTIwLjIgNDIuMyA1LjMgNC42djguN2gxMC42bDE1LjEgOVY0MmgzMWwtNS4z'
    b'LTQuMnYtOWgtMTAuNmwtMTUtOS4xdjIyLjZ6Ii8+CiAgPHBhdGggZmlsbD0iIzM4MzczOSIg'
    b'ZD0ibTEzNS4zIDMxLjQtMi42LTIuNy0yLjMgMiAyLjMgMi4yLTMgMS45aDcuMWw2IDYgMi0y'
    b'LjItNi01LjdWMjl6bTMxLjggMjEuOSAyLjYgMi4zIDIuNy0xLjYtMi43LTIuMiAzLTIuM2gt'
    b'Ni40bC02LjQtNS43LTEuOSAyIDYgNS42djMuOHptLTMxLjggMC0yLjYgMi4zLTIuMy0xLjYg'
    b'Mi4zLTIuMi0zLTIuM2g3LjFsNi01LjcgMiAyLTYgNS42djMuOHptMzEuOC0yMiAyLjYtMi42'
    b'IDIuNyAyLTIuNyAyLjIgMyAxLjloLTYuNGwtNi40IDYtMS45LTIuMiA2LTUuN1YyOXoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJtMTY5LjcgNTUuMi0yLjItMi4zIDEuOS0xLjEg'
    b'Mi4yIDIuMnptLTUuNi0uNHYtMy40bC02LTUuNyAxLjQtMS41IDYgNS43aDYuMXptLTMxLjgt'
    b'MjUuMyAyLjMgMS45LTIgMS4xLTIuMi0xLjl6bTUuNyAwdjMuOGw2IDUuMy0xLjUgMS41LTYt'
    b'NS43aC02bDcuNS00LjV6Ii8+CiAgPHBhdGggZmlsbD0iIzAwODQzZCIgZD0ibTE2OS43IDI5'
    b'LjUtMi4yIDEuOSAxLjkgMS4xIDIuMi0xLjl6bS01LjYgMHYzLjhsLTYgNS4zIDEuNCAxLjUg'
    b'Ni01LjdoNi4xem0tMzEuOCAyNiAyLjMtMi4yLTItMS4xLTIuMiAyLjJ6bTUuNy0uM3YtMy40'
    b'bDYtNS43LTEuNS0xLjUtNiA1LjdoLTZ6Ii8+CiAgPHBhdGggZmlsbD0iIzM4MzczOSIgZD0i'
    b'TTE2NyA0Mi4zIDE1MS4zIDUzbC0xNS45LTEwLjYgMTYtMTAuNloiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmZmIiBkPSJNMTUxLjIgMzIuMSAxMzYuMSA0MmgzMC4ybC0xNS05Ljl2MjBsMTUtOS44'
    b'aC0zMC4ybDE1LjEgOS45eiIvPgogIDxwYXRoIGZpbGw9IiMzODM3MzkiIGQ9Ik0xNTUuNCA0'
    b'NS43djNoLTh2LTNoLTUuNnYtNy4xaDUuNnYtM2g3LjZ2M2g1LjdWNDZ6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2QyMjYzMCIgZD0iTTE0Ny40IDM2djNoLTUuNnYzaDkuNHYtNnptMy44IDZoOS41'
    b'di0zSDE1NXYtM2gtMy44em0tOS40LjN2My40aDUuNnYyLjdoMy44di02em05LjQgNmgzLjh2'
    b'LTIuNmg1Ljd2LTMuNGgtOS41eiIvPgogIDxwYXRoIGZpbGw9IiMzODM3MzkiIGQ9Ik0xNzgu'
    b'NCAxNjIuOXYtNC41aDEyLjl2LTVoMTIuNXYtNDEuOWgtMTIuNXYtNWgtMTIuOVYxMDJoLTEy'
    b'Ljh2LTQuNWgtMjguOHY0LjVIMTI0djQuNmgtMTN2NC45SDk4Ljd2NDJIMTExdjUuMmgxM3Yz'
    b'LjhoMTIuOHY0LjZoMjguOHYtNC42eiIvPgogIDxwYXRoIGZpbGw9IiNmZmM3MmMiIGQ9Ik0x'
    b'MzcuMiA5Ny45djQuMWgtMTIuNXY0LjZIMTEydjQuOUg5OS40djQxLjZIMTEydjQuNWgxMi44'
    b'djVoMTIuOXY0LjVoMjh2LTQuNmgxMi44VjE1OGgxMi45di01SDIwNHYtNDEuNWgtMTIuOFYx'
    b'MDdoLTEzLjZ2LTQuNmgtMTIuOVY5OHptMy44IDMuNGgyMC44djQuNWgxMi44djQuNmgxMi45'
    b'djQuOWgxMi45djM0LjRoLTEyLjl2NS4zaC0xMi45djMuN2gtMTIuOHY0LjZoLTIxLjJ2LTQu'
    b'NmgtMTIuOFYxNTVoLTEyLjl2LTVoLTEyLjV2LTM0LjNIMTE1di01aDEyLjl2LTQuOWgxMi44'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNkMjI2MzAiIGQ9Ik0xMjguNSAxNTguN3YtNC41aC0xMy4y'
    b'di00LjVoLTEyLjl2LTM0aDEyLjl2LTVoMTMuMnYtNC41aDEyLjl2LTQuNWgyMC40djQuMWgx'
    b'Mi44djQuNmgxMi45djQuOWgxMi45djM0aC0xMi45djQuNWgtMTMuNnY1SDE2MXY0LjloLTIw'
    b'LjR2LTV6Ii8+CiAgPHBhdGggZmlsbD0iIzM4MzczOSIgZD0ibTEzMS4yIDEwOS42LTMuNC0y'
    b'LjZ2NC45bC0zIDEuOXYtM2wtMyAzLTMuMS0zdjNsLTMuOC0ydjQuMmwtMi42IDIuM3YtMi42'
    b'bC0zLjggMi4yLTMtMi4ydjIuNkwxMDIgMTE2djEzLjNoLTMuOHY2LjhoMy44djEzLjJsMy40'
    b'LTIuM3YzbDMuNC0yLjYgMy40IDIuNnYtM2wyLjYgMi4zdjQuNWwzLjgtMi4ydjNsMy0zIDMg'
    b'M3YtMy40bDMgMS45djQuOWwzLjUtMi43djMuNGwzLjQtMyAzIDNWMTU1bDMgMi4ydjUuM2w0'
    b'LjYtNC4xdjQuNWw2LTMuOCA2IDMuOHYtNC4ybDQuNiAzLjh2LTQuOWwzLTIuM3YzLjRsMy0z'
    b'IDMuOCAzVjE1NWwzIDIuNnYtNWwzLTEuOHYzbDMuMS0zIDMgM3YtMi42bDMuOCAyLjJWMTQ5'
    b'bDIuNi0yLjN2M2wzLjgtMi42IDMgMi43di0zbDMuNSAyLjJ2LTEyLjhoMy43di02LjVoLTMu'
    b'N3YtMTMuMmwtMy40IDIuM1YxMTZsLTMuNSAyLjMtMy40LTIuM3YyLjdsLTIuNi0yLjN2LTQu'
    b'MWwtMy44IDEuOHYtM2wtMyAzLTMtM3YzbC0zLTEuOHYtNWwtMy41IDIuN3YtMy40bC0zIDMt'
    b'My44LTN2My40bC0yLjYtMi4zdi00LjlsLTQuNSAzLjhWMTAybC02IDMuOC02LjEtMy44djMu'
    b'OGwtNC42LTMuOHY1bC0zIDIuMnYtMy40bC0zIDMtMy40LTN6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzAwODQzZCIgZD0iTTEwNS44IDExOXYtM2wzIDIuMyAzLjEtMi4zdjNsMy0yLjZ2MzIuMWwt'
    b'My0yLjJ2Mi42bC0zLTIuMy0zIDIuM3YtMi42bC0zLjUgMi4ydi0xMy4yaC0zLjd2LTUuN2gz'
    b'Ljd2LTEzLjJ6bTI1LjgtMTIgMyAyLjYgMi42LTIuNnYzLjRsMy40LTIuN1YxNTdsLTMuNC0y'
    b'LjN2My40bC0yLjYtMi43LTMgMi43di0zLjRsLTMuNCAyLjZ2LTQ5LjFsMy40IDIuM3ptMzku'
    b'MyAwLTIuNyAyLjYtMy0yLjZ2My40bC0zLjQtMi43VjE1N2wzLjQtMi4zdjMuNGwzLTIuNyAy'
    b'LjcgMi43di0zLjRsMy40IDIuNnYtNDkuMWwtMy40IDIuM3ptMjUuNyAxMnYtM2wtMyAyLjMt'
    b'My0yLjN2M2wtMy4xLTIuNnYzMi4xbDMtMi4ydjIuNmwzLTIuMyAzIDIuM3YtMi42bDMuNSAy'
    b'LjJ2LTEzLjJoMy44di01LjdIMjAwdi0xMy4yeiIvPgogIDxwYXRoIGZpbGw9IiNmZmM3MmMi'
    b'IGQ9Im0xMTkgMTExLjkgMi43IDIuMiAyLjctMi4ydjIuNmwzLjgtMi4ydjQwLjRsLTMuOC0y'
    b'LjN2M2wtMi43LTIuNi0yLjYgMi42di0zbC0zLjggMi4zdi00MC40bDMuOCAyLjJ6bTI2LjUt'
    b'NS00LjUtMy43djU5bDQuNS00LjJ2NC41bDUuNy0zLjggNS43IDMuOHYtNC45bDQuNSAzLjh2'
    b'LTU3LjhsLTQuNSAzLjdWMTAybC01LjcgMy44LTUuNy0zLjh6bTM3LjggNS0yLjYgMi4yLTIu'
    b'Ni0yLjJ2Mi42bC0zLjgtMi4ydjQwLjRsMy44LTIuM3YzbDIuNi0yLjYgMyAyLjZ2LTNsMy40'
    b'IDIuM3YtNDAuNGwtMy44IDIuMnoiLz4KICA8ZyBmaWxsPSIjMzgzNzM5Ij4KICAgIDxwYXRo'
    b'IGQ9Im0xMDcuNCAxMjYuNiAxLjUuOGMuMyAwIDEuMSAwIDEuNS0uOCAxLjEtMS4xIDEuMS0z'
    b'LjQgMS4xLTQuOWwtMS45IDEuOS0uNy0xLjktMS4yIDEuOS0xLjUtMS45YzAgMS41IDAgMy44'
    b'IDEuMiA1em0xMy42LTMuNC0xLjItMS4xdi0ybC0yLjIgMi40IDMuNyAzLjcgNC42LTMuNy0y'
    b'LjMtMi4zdjEuOWwtMS4xIDEuMXYtMy44bDEuOS0xLjUtMi43LTIuMi0yLjYgMi4yIDEuOSAy'
    b'em0xMi40LTMuOC0uNy0xLjFWMTE2bC0yLjcgMi4zIDQuNiA0LjIgMy44LTMuOC0yLjMtMi43'
    b'djIuM2wtLjguOHYtMy44bDItMS4yLTIuNy0yLjItMi43IDIuMiAxLjUgMS42eiIvPgogICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0ibTEwOC45IDEyMi41LjcgMS41IDEuNS0xLjVjMCAxLjgt'
    b'LjMgMy40LTEgMy43YTEuNSAxLjUgMCAwIDEtMi40IDBjLS43LS4zLTEuMS0xLjktMS4xLTMu'
    b'N2wxLjUgMS41em0yNi03LjJ2NC45bDEuNi0xLjl2LTEuMWwxLjUgMS41LTMuOCAzLjgtMy44'
    b'LTMuOCAyLTEuNXYxLjVsMS40IDEuOXYtNWwtMS41LTEgMi4zLTIgMS45IDJ6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJNMTIyLjEgMTE5LjR2NC42bDEuOS0xLjV2LTEuNmwx'
    b'LjUgMS42LTMuOCAzLjctMy44LTMuNyAxLjYtMS42djEuNmwxLjUgMS41di00LjZsLTEuNS0x'
    b'LjUgMi4yLTEuNSAyIDEuNXoiLz4KICAgIDxwYXRoIGQ9Im0xOTUgMTI2LjYtMS41LjhjLS4z'
    b'IDAtLjcgMC0xLS44LTEuNi0xLjEtMS42LTMuNC0xLjYtNC45bDEuOSAxLjkuNy0xLjkgMS4y'
    b'IDEuOSAxLjUtMS45YzAgMS41IDAgMy44LTEuMSA1em0tMTMuMi0zLjQuOC0xLjF2LTJsMi4z'
    b'IDIuNC0zLjggMy43LTQuNi0zLjcgMi4zLTIuM3YxLjlsMS4xIDEuMXYtMy44bC0xLjgtMS41'
    b'IDIuNi0yLjIgMi42IDIuMi0xLjUgMnptLTEyLjgtMy44LjctMS4xVjExNmwyLjcgMi4zLTQu'
    b'MiA0LjItNC41LTMuOCAyLjYtMi43djIuM2wuOC44di0zLjhsLTEuNS0xLjIgMi42LTIuMiAy'
    b'LjcgMi4yLTIgMS42eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTE5My41IDEyMi41'
    b'LS43IDEuNS0xLjUtMS41YzAgMS44LjQgMy40IDEuMSAzLjdhMS41IDEuNSAwIDAgMCAyLjMg'
    b'MGMuNy0uMyAxLjEtMS45IDEuMS0zLjdsLTEuMSAxLjV6bS0yNi03LjJ2NC45bC0xLjUtMS45'
    b'di0xLjFsLTEuNiAxLjUgMy44IDMuOCAzLjgtMy44LTEuOS0xLjV2MS41bC0xLjUgMS45di01'
    b'bDEuNS0xLTEuOS0yLTIuMiAyeiIvPgogICAgPHBhdGggZmlsbD0iI2QyMjYzMCIgZD0iTTE4'
    b'MC4zIDExOS40djQuNmwtMS41LTEuNXYtMS42bC0xLjUgMS42IDMuOCAzLjcgMy44LTMuNy0y'
    b'LTEuNnYxLjZsLTEuNCAxLjV2LTQuNmwxLjUtMS41LTIuMy0xLjUtMS45IDEuNXoiLz4KICAg'
    b'IDxwYXRoIGQ9Im0xNTYuMSAxMjEtMS4xLTIuMyAzLjQtMy0zLjQtMi43djEuOWwtMS4xIDEu'
    b'MXYtMy43bDMtMi01LjctNC41LTUuNyAzLjggMyAyLjd2My40bC0xLTEuMnYtMS45bC0zLjUg'
    b'Mi43IDMuOCAzLTEuNSAxLjl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJtMTQ3'
    b'IDEyMC42IDEuMi0yLTMuOC0zIDIuNy0xLjh2MS4xbDEuOCAxLjl2LTQuNWwtMi42LTIgNS0z'
    b'LjcgNC44IDMuOC0yLjYgMS45djQuOWwxLjktMnYtMWwyLjYgMS44LTMuOCAzIDEuNSAyeiIv'
    b'PgogICAgPHBhdGggZD0ibTE0OC42IDExMC40IDIuNiAxLjkgMi43LTItMi43LTEuOFoiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiMwMDg0M2QiIGQ9Im0xNTEuMiAxMDguOSAxLjkgMS41LTEuOSAx'
    b'LjEtMS45LTEuMXoiLz4KICA8L2c+CiAgPGcgZmlsbD0iIzM4MzczOSI+CiAgICA8cGF0aCBk'
    b'PSJNMTA3LjQgMTM4LjNhMS45IDEuOSAwIDAgMSAxLjUtLjdjLjMgMCAxLjEgMCAxLjUuNyAx'
    b'LjEgMS4yIDEuMSAzLjQgMS4xIDVsLTEuOS0xLjYtLjcgMS41LTEuMi0xLjUtMS41IDEuNWMw'
    b'LTEuNSAwLTMuNyAxLjItNC45em0xMy42IDMuNC0xLjIgMS4ydjEuOWwtMi4yLTIuMyAzLjct'
    b'My44IDQuNiAzLjgtMi4zIDIuM3YtMmwtMS4xLTF2My43bDEuOSAxLjUtMi43IDIuMy0yLjYt'
    b'Mi4zIDEuOS0xLjl6bTEyLjQgMy44LS43IDEuMXYyLjNsLTIuNy0yLjMgNC42LTQuMSAzLjgg'
    b'NC4xLTIuMyAyLjN2LTIuM2wtLjgtLjd2My44bDIgMS4xLTIuNyAyLjMtMi43LTIuMyAxLjUt'
    b'MS41eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTEwOC45IDE0Mi41LjctMS41IDEu'
    b'NSAxLjVjMC0xLjktLjMtMy40LTEtMy44YTEuNSAxLjUgMCAwIDAtMi40IDBjLS43LjQtMS4x'
    b'IDEuOS0xLjEgMy44bDEuNS0xLjV6bTI2IDcuMnYtNWwxLjYgMnYxLjVsMS41LTEuNi0zLjgt'
    b'My43LTMuOCAzLjcgMiAxLjZ2LTEuNmwxLjQtMS44djQuOWwtMS41IDEuMSAyLjMgMS45IDEu'
    b'OS0xLjl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJNMTIyLjEgMTQ1LjVWMTQx'
    b'bDEuOSAxLjV2MS41bDEuNS0xLjUtMy44LTMuOC0zLjggMy44IDEuNiAxLjV2LTEuNWwxLjUt'
    b'MS41djQuNWwtMS41IDEuNSAyLjIgMS41IDItMS41eiIvPgogICAgPHBhdGggZD0iTTE5NSAx'
    b'MzguM2ExLjkgMS45IDAgMCAwLTEuNS0uN2MtLjMgMC0uNyAwLTEgLjctMS42IDEuMi0xLjYg'
    b'My40LTEuNiA1bDEuOS0xLjYuNyAxLjUgMS4yLTEuNSAxLjUgMS41YzAtMS41IDAtMy43LTEu'
    b'MS00Ljl6bS0xMy4yIDMuNC44IDEuMnYxLjlsMi4zLTIuMy0zLjgtMy44LTQuNiAzLjggMi4z'
    b'IDIuM3YtMmwxLjEtMXYzLjdsLTEuOCAxLjUgMi42IDIuMyAyLjYtMi4zLTEuNS0xLjl6bS0x'
    b'Mi44IDMuOC43IDEuMXYyLjNsMi43LTIuMy00LjItNC4xLTQuNSA0LjEgMi42IDIuM3YtMi4z'
    b'bC44LS43djMuOGwtMS41IDEuMSAyLjYgMi4zIDIuNy0yLjMtMi0xLjV6Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSIjZmZmIiBkPSJtMTkzLjUgMTQyLjUtLjctMS41LTEuNSAxLjVjMC0xLjkuNC0z'
    b'LjQgMS4xLTMuOGExLjUgMS41IDAgMCAxIDIuMyAwYy43LjQgMS4xIDEuOSAxLjEgMy44bC0x'
    b'LjEtMS41em0tMjYgNy4ydi01bC0xLjUgMnYxLjVsLTEuNi0xLjYgMy44LTMuNyAzLjggMy43'
    b'LTEuOSAxLjZ2LTEuNmwtMS41LTEuOHY0LjlsMS41IDEuMS0xLjkgMS45LTIuMi0xLjl6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJNMTgwLjMgMTQ1LjVWMTQxbC0xLjUgMS41'
    b'djEuNWwtMS41LTEuNSAzLjgtMy44IDMuOCAzLjgtMiAxLjV2LTEuNWwtMS40LTEuNXY0LjVs'
    b'MS41IDEuNS0yLjMgMS41LTEuOS0xLjV6Ii8+CiAgICA8cGF0aCBkPSJtMTU2LjEgMTQ0LjQt'
    b'MS4xIDEuOSAzLjQgMy0zLjQgMi42VjE1MGwtMS4xLTF2My43bDMgMS45LTUuNyA0LjEtNS43'
    b'LTMuNyAzLTIuN1YxNDlsLTEgMS4xdjJsLTMuNS0yLjcgMy44LTMtMS41LTJ6Ii8+CiAgICA8'
    b'cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJtMTQ3IDE0NC44IDEuMiAxLjUtMy44IDMgMi43IDEu'
    b'OVYxNTBsMS44LTEuOHY0LjVsLTIuNiAxLjkgNSAzLjggNC44LTMuOC0yLjYtMnYtNC40bDEu'
    b'OSAxLjh2MS4ybDIuNi0yLTMuOC0zIDEuNS0xLjR6Ii8+CiAgICA8cGF0aCBkPSJtMTQ4LjYg'
    b'MTU1IDIuNi0yLjMgMi43IDEuOS0yLjcgMS45WiIvPgogICAgPHBhdGggZmlsbD0iIzAwODQz'
    b'ZCIgZD0ibTE1MS4yIDE1NiAxLjktMS40LTEuOS0xLjItMS45IDEuMloiLz4KICA8L2c+CiAg'
    b'PHBhdGggZmlsbD0iIzM4MzczOSIgZD0iTTE5Ni42IDEzMC40aC01LjN2LTEuOWgtMTcuNGwt'
    b'MTIuMS03LjZoLTIxLjJsLTEyIDcuNkgxMTF2Mi4zaC01LjN2My44aDUuM3YyLjZoMTcuNGwx'
    b'Mi4xIDcuNmgyMS4ybDEyLTcuNmgxNy41di0yLjNoNS4zeiIvPgogIDxwYXRoIGZpbGw9IiNk'
    b'MjI2MzAiIGQ9Im0xNDAuNiAxMjEtMTIgNy41aC0xN3YyLjNoLTUuNHYzLjRoNS4zdjIuMmgx'
    b'N2wxMi4xIDcuNmgyMS4ybDEyLTcuNkgxOTF2LTIuMmg1Ljd2LTMuNEgxOTF2LTIuM2gtMTds'
    b'LTEyLjEtNy42em0wIDFoMjAuOGwxMS40IDcuM3YxaDEydjQuNmgtMTIuNHYxLjJsLTExIDYu'
    b'OEgxNDFsLTExLjMtNi44di0xLjJoLTEyLjF2LTQuNUgxMzB2LTEuMXoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjZDIyNjMwIiBkPSJtMTYxLjQgMTIyIDEwLjYgNy42di44aDEyLjV2My44SDE3MnYx'
    b'LjVsLTEwLjYgNy4ySDE0MWwtMTAuNi03LjJ2LTEuMUgxMTh2LTMuOGgxMi41di0xLjVMMTQx'
    b'IDEyMnoiLz4KICA8ZyBmaWxsPSIjMzgzNzM5Ij4KICAgIDxwYXRoIGQ9Im0xMzUuNyAxMzYu'
    b'NCA0LjUgMy44IDMtMi42LTEuNC0xLjItMS42LjgtMS0uOCAxNy4zLTEzLjJoLTMuNHptMTAu'
    b'MiA1LjNoMy40bDE3LjQtMTMuMi00LjUtMy44LTMgMi43IDEuOCAxLjEgMS4yLS44IDEuMS44'
    b'em03LjYgMGgzbC0xNy40LTEzLjIgMS4xLS44IDEuNi44IDEuNS0xLjEtMy0yLjMtNC42IDMu'
    b'NFptOS44LTUuMy0xLjEuOC0xLjItLjgtMS45IDEuMiAzIDIuMiA0LjYtMy40LTE3LjQtMTMu'
    b'MmgtMy44em0tMzEtMy43IDMgMS45IDMtMi0zLTIuMnptMTUuOS0uNCAzIDIuMyAzLTItMy0y'
    b'LjJabTIyIDAtMy4xIDIuMy0zLTIgMy0yLjJ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZjNzJj'
    b'IiBkPSJtMTY2LjMgMTM2LjQtNC4xIDMtMi43LTEuOCAxLjUtLjggMS4yLjggMS41LTEuMi0x'
    b'Ny0xMi44aDIuNnptLTEwLjYgNWgtMi42bC0xNy0xMi45IDQuMS0zIDIuNyAxLjktMS4xLjct'
    b'MS42LS43LTEuNSAxLjF6bS02LjQgMGgtMi42bDE3LTEyLjktMS41LTEuMS0xLjIuNy0xLjUt'
    b'LjcgMi43LTIgMy44IDMuMXptMy44LTE3LjhoMi42bC0xNyAxMi44IDEuNSAxLjIgMS42LS44'
    b'IDEgLjgtMi42IDEuOS0zLjctM3oiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDg0M2QiIGQ9Im0x'
    b'MzUuMyAxMzAuOCAyLjMgMS45LTIuMyAxLjUtMi42LTEuNXptMTYgMCAyLjYgMS45LTIuNyAx'
    b'LjUtMi42LTEuNXptMTUuOCAwLTIuMyAxLjkgMi4zIDEuNSAyLjYtMS41eiIvPgogIDwvZz4K'
    b'ICA8cGF0aCBmaWxsPSIjMzgzNzM5IiBkPSJtOTYuNCAyMTkuMi0xLjEgMS45IDIuMiAxLjUt'
    b'Mi4yIDEuOSAxLjEgMS41IDIuNi40IDIuMy0xLjkgNi40IDMuOHYtM2wtMy43LTIuNyAzLjct'
    b'Mi4zVjIxN2wtNi40IDMuOC0yLjMtMS41em0wLTExLjMtMS4xIDEuOSAyLjIgMS41LTIuMiAx'
    b'LjkgMS4xIDEuNSAyLjYuNCAyLjMtMiA2LjQgMy44di0zbC0zLjctMi42IDMuNy0yLjN2LTMu'
    b'NGwtNi40IDMuOC0yLjMtMS41em0wIDI5LjUtMS4xLTEuNiAyLjItMS44LTIuMi0xLjYgMS4x'
    b'LTEuOEg5OWwyLjMgMS41IDYuNC0zLjh2My40TDEwNCAyMzRsMy43IDIuNnYzbC02LjQtMy44'
    b'LTIuMyAyek0yMDYgMjE5LjJsMS4yIDEuOS0yLjMgMS41IDIuMyAxLjktMS4yIDEuNS0yLjYu'
    b'NC0yLjMtMS45LTYuNCAzLjh2LTNsMy44LTIuNy0zLjgtMi4zVjIxN2w2LjQgMy44IDIuMy0x'
    b'LjV6bTAtMTEuMyAxLjIgMS45LTIuMyAxLjUgMi4zIDEuOS0xLjIgMS41LTIuNi40LTIuMy0y'
    b'LTYuNCAzLjh2LTNsMy44LTIuNi0zLjgtMi4zdi0zLjRsNi40IDMuOCAyLjMtMS41em0wIDI5'
    b'LjUgMS4yLTEuNi0yLjMtMS44IDIuMy0xLjYtMS4yLTEuOGgtMi42TDIwMSAyMzJsLTYuNC0z'
    b'Ljh2My40bDMuOCAyLjMtMy44IDIuNnYzbDYuNC0zLjggMi4zIDJ6TTE4MS41IDE4OXY0LjVo'
    b'My40djIuM2gzLjRWMTkyaC0zdi0zWm05LjggNy41djMuOGgzLjh2MS45aDN2LTMuOGgtM3Yt'
    b'MS45Wk0xMjEgMTg5djQuNWgtMy40djIuM2gtMy40VjE5Mmgzdi0zWm02MC41IDY4di00LjVo'
    b'My40di0yaDMuNHYzLjloLTN2M3ptLTYwLjUgMHYtNC41aC0zLjR2LTJoLTMuNHYzLjloM3Yz'
    b'em03MC4zLTcuNlYyNDVoMy44di0yLjNoM3YzLjhoLTN2M1pNMTExIDE5Ni41djMuOGgtMy43'
    b'djEuOWgtM3YtMy44aDN2LTEuOVptMCA1My4zdi00LjVoLTMuN1YyNDNoLTN2My44aDN2M3pt'
    b'NTMtNjAuOC0yLjctMi43LTIuNiAyLjMgMi4yIDIuMy0zIDIuNmg0LjJsMS41LTEuNSAxLjUg'
    b'MS41aDVMMTY3IDE5MWwyLjMtMi4zLTIuNy0yLjN6bS0xMi45IDAtMi42LTIuNy0yLjcgMi4z'
    b'IDIuMyAyLjMtMi43IDIuNmg0LjJsMS41LTEuNSAxLjUgMS41aDQuMmwtMi43LTIuNiAyLjMt'
    b'Mi4zLTIuNi0yLjN6bS0xMi41IDAgMi43LTIuNyAyLjMgMi4zLTIuMyAyLjMgMyAyLjZoLTQu'
    b'MmwtMS41LTEuNS0xLjUgMS41aC00LjlsMy0yLjYtMi4yLTIuMyAyLjYtMi4zIDIuNyAyLjd6'
    b'bTI1IDY4LTIuMyAzLTIuNi0yLjYgMi4yLTEuOS0zLTNoNC4ybDEuNSAxLjUgMS41LTEuNWg1'
    b'bC0zLjEgMyAyLjMgMS45LTIuNyAyLjZ6bS0xMi41IDAtMi42IDMtMi43LTIuNiAyLjMtMS45'
    b'LTIuNy0zaDQuMmwxLjUgMS41IDEuNS0xLjVoNC4ybC0yLjcgMyAyLjMgMS45LTIuNiAyLjZ6'
    b'bS0xMi41IDAgMi43IDMgMi4zLTIuNi0yLjMtMS45IDMtM2gtNC4ybC0xLjUgMS41LTEuNS0x'
    b'LjVoLTQuOWwzIDMtMi4yIDEuOSAyLjYgMi42IDIuNy0yLjZ6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzAwODQzZCIgZD0iTTEwNy40IDIyNS4zdjIuNmwtNi0zLjgtMi40IDJoLTIuMmwtMS4yLTEu'
    b'NiAyLjMtMS45LTIuMy0xLjUgMS4yLTEuNUg5OWwyLjMgMS45IDYtMy44djIuM2wtNC4xIDIu'
    b'NnptMC0xMS40djIuN2wtNi0zLjgtMi40IDEuOWgtMi4ybC0xLjItMS41IDIuMy0yLTIuMy0x'
    b'LjQgMS4yLTEuNUg5OWwyLjMgMS44IDYtMy43djIuMmwtNC4xIDIuN3ptMCAxNy40VjIyOWwt'
    b'NiAzLjgtMi40LTIuMmgtMi4ybC0xLjIgMS41TDk4IDIzNGwtMi4zIDEuOCAxLjIgMS4ySDk5'
    b'bDIuMy0xLjUgNiAzLjd2LTIuNmwtNC4xLTIuNnptODcuNy02djIuNmw2LTMuOCAyLjcgMmgx'
    b'LjhsMS4yLTEuNi0yLjMtMS45IDIuMy0xLjUtMS4yLTEuNWgtMS41bC0yLjYgMS45LTYtMy44'
    b'djIuM2w0LjEgMi42em0wLTExLjR2Mi43bDYtMy44IDIuNyAxLjloMS44bDEuMi0xLjUtMi4z'
    b'LTIgMi4zLTEuNC0xLjItMS41aC0xLjVsLTIuNiAxLjgtNi0zLjd2Mi4ybDQuMSAyLjd6bTAg'
    b'MTcuNFYyMjlsNiAzLjggMi43LTIuMmgxLjhsMS4yIDEuNS0yLjMgMS45IDIuMyAxLjgtMS4y'
    b'IDEuMmgtMS41bC0yLjYtMS41LTYgMy43di0yLjZsNC4xLTIuNnptLTkuOS00Mi4zdjNoM3Yz'
    b'aC0zdi0yLjJoLTMuN1YxODl6bTEwLjIgNy41djIuN2gyLjd2M2gtMi43di0xLjlIMTkydi0z'
    b'Ljh6bS03OC4yLTcuNXYzaC0zdjNoMi42di0yLjJoMy44VjE4OXptNjggNjcuNnYtMy40aDN2'
    b'LTNoLTN2MS45aC0zLjd2My44em0tNjcuMyAwdi0zLjRoLTN2LTNoMi43djEuOWgzLjd2My44'
    b'em03Ny41LTcuNXYtM2gyLjd2LTNoLTIuN3YyLjJIMTkydjMuOHptLTg3LjctNTIuNnYzaC0z'
    b'djNoMi43di0yLjJoMy40di0zLjh6bTAgNTN2LTNoLTN2LTMuMWgyLjd2Mi4zaDMuNHYzLjd6'
    b'bTUzLjctNjIuOCAyLjMgMi43IDIuNi0yLjcgMi4zIDEuOS0yLjMgMi4zIDIuNyAyLjJoLTMu'
    b'OGwtMS41LTEuNS0xLjUgMS41aC0zLjRsMi42LTIuMi0yLjMtMi4zem0tMTIuOCAwIDIuNiAy'
    b'LjcgMi43LTIuNyAxLjggMS45LTIuMiAyLjMgMi42IDIuMmgtMy40bC0xLjUtMS41LTEuNSAx'
    b'LjVoLTMuOGwzLTIuMi0yLjItMi4zem0tNy42IDAtMi4zIDIuNy0yLjYtMi43LTIuMyAxLjkg'
    b'Mi4zIDIuMy0yLjMgMi4yaDNsMi0xLjUgMS40IDEuNWgzLjVMMTQxIDE5MWwyLjMtMi4zem0y'
    b'MC40IDcyLjYgMi4zLTIuMyAyLjYgMi4zIDIuMy0yLTIuMy0xLjggMi43LTIuNmgtMy44bC0x'
    b'LjUgMS41LTEuNS0xLjVoLTMuNGwyLjYgMi42LTIuMyAxLjl6bS0xMi44IDAgMi42LTIuMyAy'
    b'LjcgMi4zIDEuOC0yLTIuMi0xLjggMi42LTIuNmgtMy40bC0xLjUgMS41LTEuNS0xLjVoLTMu'
    b'OGwzIDIuNi0yLjIgMS45em0tNy42IDAtMi4zLTIuMy0yLjYgMi4zLTIuMy0yIDIuMy0xLjgt'
    b'Mi4zLTIuNmgzbDIgMS41IDEuNC0xLjVoMy41bC0yLjcgMi42IDIuMyAxLjl6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzM4MzczOSIgZD0iTTExNy4yIDI0NS4zdjcuNmg2OHYtNy42aDkuOXYtNDVo'
    b'LTkuOXYtNy41aC02OHY3LjVoLTkuOHY0NXoiLz4KICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBk'
    b'PSJNMTE3LjYgMTkzLjF2Ny42aC05Ljl2NDQuMmg5LjV2Ny42aDY4di03LjZoOS45di00NC42'
    b'aC05Ljl2LTcuNWgtNjh6bTQuNSAzaDU4LjJ2Ny4ybDIuNyAxLjZoOXYzNS41aC05bC0yLjcg'
    b'MS45djcuMWgtNTguMlYyNDJsLTIuNi0xLjVoLTkuMVYyMDVoOWwyLjctMS42di03LjV6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2QyMjYzMCIgZD0iTTEyMi41IDE5Ni41djYuNWw4LjctNi41em00'
    b'OS4xIDAgOC4zIDYuNXYtNi41em0tNjAuNSA4Ljd2Ni41bDgtNnptNzIuMiAwIDguNCA2LjV2'
    b'LTYuNXptOC40IDI4LjgtOC40IDZoOC40em0tODEgMHY2aDguNHptMTEuNCA4LjZ2Ni41aDl6'
    b'bTU3LjggMC04LjcgNi41aDguN3oiLz4KICA8cGF0aCBmaWxsPSIjMDA4NDNkIiBkPSJtMTcw'
    b'LjkgMTk2LjUgMjAuOCAxNS4ydjIxLjlsLTIwLjggMTVoLTM5LjNsLTIwLjgtMTV2LTIybDIw'
    b'LjgtMTUuNHoiLz4KICA8cGF0aCBmaWxsPSIjMzgzNzM5IiBkPSJtMTE1LjcgMjM1LjgtMi4z'
    b'LTIuNiAyLjMtMi42LTIuMy0yLjcgMi4zLTIuNi0yLjMtMi43IDIuMy0yLjYtMi4zLTIuNyAy'
    b'LjMtMi42LTIuMy0yLjMgMi4zLTNoNzFsMi4zIDMtMi4zIDIuMyAyLjMgMi42LTIuMyAyLjcg'
    b'Mi4zIDIuNi0yLjMgMi43IDIuMyAyLjYtMi4zIDIuNyAyLjMgMi42LTIuMyAyLjZ6bTQ5LjEt'
    b'MzUuOS0zLTIuNi0yLjcgMi4zLTIuNi0yLjMtMi42IDIuMy0yLjctMi4zLTIuNiAyLjMtMi43'
    b'LTIuMy0yLjYgMi4zLTIuNy0yLjMtMi42IDIuNnY0NS40bDIuNiAyLjYgMi43LTIuMiAyLjYg'
    b'Mi4yIDIuNy0yLjIgMi42IDIuMiAyLjctMi4yIDIuNiAyLjIgMi42LTIuMiAyLjcgMi4yIDIu'
    b'Ni0yLjJ6Ii8+CiAgPGcgZmlsbD0iI2ZmYzcyYyI+CiAgICA8cGF0aCBkPSJtMTU4LjggMjAw'
    b'LjMtMi4zLTIuMy0yLjYgMnY0NS4zbDIuNiAyLjMgMi4zLTIuM3ptLTEwLjIgMC0yLjctMi4z'
    b'LTIuMiAydjQ1LjNsMi4yIDIuMyAyLjctMi4zeiIvPgogICAgPHBhdGggZD0ibTExNiAyMzUu'
    b'OC0yLjItMi42IDIuMy0yLjNoNzAuM2wyLjIgMi4zLTIuMiAyLjZ6bTcwLjQtMTUuNSAyLjIg'
    b'Mi4zLTIuMiAyLjdIMTE2bC0yLjMtMi43IDIuMy0yLjN6bTAtNS42IDIuMi0yLjMtMi4yLTIu'
    b'NkgxMTZsLTIuMyAyLjYgMi4zIDIuM3oiLz4KICA8L2c+CiAgPGcgZmlsbD0iI2QyMjYzMCI+'
    b'CiAgICA8cGF0aCBkPSJtMTY0IDIwMC4zLTIuMi0yLjMtMi43IDJ2NDUuM2wyLjcgMi4zIDIu'
    b'My0yLjN6bS0yMC4zIDBMMTQxIDE5OGwtMi4zIDJ2NDUuM2wyLjMgMi4zIDIuNy0yLjN6Ii8+'
    b'CiAgICA8cGF0aCBkPSJtMTE2IDIzMC42LTIuMi0yLjcgMi4zLTIuM2g3MC4zbDIuMiAyLjMt'
    b'Mi4yIDIuN3ptMC0xMC42LTIuMi0yLjcgMi4zLTIuMmg3MC4zbDIuMiAyLjItMi4yIDIuN3oi'
    b'Lz4KICAgIDxwYXRoIGQ9Im0xNTMuOSAyNDUuNy0yLjcgMS45LTIuMy0yLjN2LTQ1bDIuMy0x'
    b'LjkgMi43IDJaIi8+CiAgPC9nPgogIDxwYXRoIGZpbGw9IiMzODM3MzkiIGQ9Ik0xNzUgMjAw'
    b'LjdoLTQ3LjZ2My44SDEyMXYzNi4zaDZ2My43aDQ3LjZ2LTMuN2g2Ljl2LTM2LjNoLTYuMXYt'
    b'My44eiIvPgogIDxwYXRoIGZpbGw9IiNkMjI2MzAiIGQ9Ik0xMjcuOCAyMDF2My45aC02djM1'
    b'LjVoNnYzLjhoNC41bC05LjgtOC40di0yNi40bDkuOC04LjNoLTQuOXptNDIgMCA5LjggOC44'
    b'djI2LjRsLTkuNSA3LjZoNVYyNDBoNnYtMzUuNWgtNnYtMy44aC01eiIvPgogIDxnIGZpbGw9'
    b'IiMwMDg0M2QiPgogICAgPHBhdGggZD0ibTEzMyAyMDEtOS44IDguOHYyNmw5LjkgOC40aDM2'
    b'LjNsOS44LTguNHYtMjYuNGwtOS44LTguM3ptLjggMS42aDM0LjhsOS41IDcuNXYyNWwtOS41'
    b'IDcuNWgtMzQuOGwtOS40LTcuNXYtMjQuNnoiLz4KICAgIDxwYXRoIGQ9Im0xNDIuOSAyMzUu'
    b'NSAxLjUuNy40IDItMiAxLjQgMy4xIDIuN2gtM2wtMS45LTItMS45IDJoLTNsMi42LTIuNy0x'
    b'LjktMS41di0xLjlsMi0uNyAxLjggMS41em0xMC4yIDAgMS41LjcuNCAyLTEuOSAxLjQgMyAy'
    b'LjdoLTNsLTEuOS0yLTEuOSAyaC0yLjZsMi42LTIuNy0xLjktMS41di0xLjlsMi0uNyAxLjgg'
    b'MS41em02LjQgMC0xLjUuNy0uNCAyIDIgMS40LTIuNyAyLjdoMi42bDItMiAxLjggMmgzbC0z'
    b'LTIuNyAxLjktMS41di0xLjlsLTEuOS0uNy0xLjkgMS41ek0xNDMgMjEwbDEuNS0uNy40LTEu'
    b'OS0yLTEuOSAzLjEtMi42aC0zbC0xLjkgMS45LTEuOS0yaC0zbDIuNiAyLjctMS45IDEuOXYx'
    b'LjlsMiAuNyAxLjgtMS44em0xMC4yIDAgMS41LS43LjQtMS45LTEuOS0xLjkgMy0yLjZoLTNs'
    b'LTEuOSAxLjktMS45LTJoLTIuNmwyLjYgMi43LTEuOSAxLjl2MS45bDIgLjcgMS44LTEuOHpt'
    b'Ni40IDAtMS41LS43LS40LTEuOSAyLTEuOS0yLjctMi42aDIuNmwyIDEuOSAxLjgtMmgzbC0z'
    b'IDIuNyAxLjkgMS45djEuOWwtMS45LjctMS45LTEuOHptMTguMiAyLjctMS41IDEuNSAxLjUg'
    b'MS4xdjIuM2wtMi43LTEuOS0xLjUgMS41aC0xLjlsLS43LTEuNSAxLjUtMS41LTEuNS0xLjUu'
    b'Ny0xLjVoMmwxLjQgMS41IDIuNy0xLjl6bTAgOC43LTEuNSAxLjEgMS41IDEuNXYybC0yLjct'
    b'Mi0xLjUgMS41aC0xLjlsLS43LTEuNSAxLjUtMS41LTEuNS0xLjUuNy0xLjFoMmwxLjQgMS4x'
    b'IDIuNy0xLjlabTAgMTEuMy0xLjUtMS41IDEuNS0xLjV2LTEuOWwtMi43IDEuOS0xLjUtMS41'
    b'aC0xLjlsLS43IDEuNSAxLjUgMS41LTEuNSAxLjUuNyAxLjJoMmwxLjQtMS4yIDIuNyAyem0t'
    b'NTMtMjAgMiAxLjUtMiAxLjF2Mi4zbDIuNy0xLjkgMS41IDEuNWgxLjlsLjgtMS41LTEuNi0x'
    b'LjUgMS42LTEuNS0uOC0xLjVIMTI5bC0xLjUgMS41LTIuNy0xLjlabTAgOC43IDIgMS4xLTIg'
    b'MS41djJsMi43LTIgMS41IDEuNWgxLjlsLjgtMS41LTEuNi0xLjUgMS42LTEuNS0uOC0xLjFI'
    b'MTI5bC0xLjUgMS4xLTIuNy0xLjlabTAgMTEuMyAyLTEuNS0yLTEuNXYtMS45bDIuNyAxLjkg'
    b'MS41LTEuNWgxLjlsLjggMS41LTEuNiAxLjUgMS42IDEuNS0uOCAxLjJIMTI5bC0xLjUtMS4y'
    b'LTIuNyAyWiIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJtMTMzLjggMjAz'
    b'LTguNyA3LjUgMi4zIDIgMS41LTEuNmgyLjNsLjcgMS45LTEuNSAxLjUgMS41IDEuNS0uNyAx'
    b'LjVoLTIuN2wtMS41LTEuMS0yLjYgMS45di43bDIuNiAyIDEuNS0xLjYgMi4zLjQuOCAxLjUt'
    b'MS42IDEuNSAxLjYgMS41LS44IDJoLTIuM2wtMS41LTEuNi0yLjYgMi4zdi4zbDIuNiAyLjMg'
    b'MS41LTEuNWgyLjNsLjggMS45LTEuNiAxLjUgMS42IDEuNS0uOCAxLjVoLTIuM2wtMS41LTEu'
    b'MS0yLjMgMS45IDguNyA3LjVoMmwzLTMtMi0xLjV2LTIuM2wyLjMtLjcgMiAxLjUgMS44LTEu'
    b'NSAyIC43LjMgMi4zLTIgMS41IDMuMSAyLjcgMi43LTIuNy0yLTEuNXYtMi4zbDIuMy0uNyAy'
    b'IDEuNSAxLjgtMS41IDIgLjcuMyAyLjMtMS45IDEuNSAyLjYgMi43IDMtMi43LTEuOC0xLjV2'
    b'LTIuM2wyLjItLjcgMiAxLjUgMS44LTEuNSAyIC43LjMgMi4zLTEuOSAxLjUgMyAyLjdoMmw4'
    b'LjYtNy42LTIuMy0xLjUtMS41IDEuNS0yLjItLjQtLjgtMS41IDEuNS0xLjUtMS41LTEuNS44'
    b'LTEuNSAyLjItLjQgMS41IDEuNSAyLjctMi4zdi0uM2wtMi43LTIuMy0xLjUgMS41SDE3MWwt'
    b'LjgtMS45IDEuNS0xLjUtMS41LTEuNS44LTEuNWgyLjJsMS41IDEuMSAyLjctMS45di0uN2wt'
    b'Mi43LTItMS41IDEuNi0yLjItLjQtLjgtMS41IDEuNS0xLjUtMS41LTEuNS44LTEuNSAyLjIt'
    b'LjQgMS41IDEuNSAyLjMtMS45LTguNy03LjVoLTEuOWwtMyAyLjYgMS45IDEuOXYyLjNsLTIu'
    b'My43LTEuOS0xLjUtMS45IDEuNS0xLjgtLjctLjQtMi4zIDEuOS0xLjktMi43LTIuNi0zIDIu'
    b'NiAxLjkgMS45djIuM2wtMi4zLjctMS45LTEuNS0xLjkgMS41LTEuOC0uNy0uNC0yLjMgMS45'
    b'LTEuOS0yLjctMi42LTMgMi42IDEuOSAxLjl2Mi4zbC0yLjMuNy0xLjktMS41LTEuOSAxLjUt'
    b'MS45LS43LS4zLTIuMyAxLjktMS45LTMtMi42em0tOSAxOC45djEuOGwxLTF6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0ibTE0MSAyNDEuMS0xLjUgMS4yaDN6bTEwLjIgMC0xLjUgMS4y'
    b'aDN6bTEwLjIgMC0xLjUgMS4yaDN6bS0yMi0zNy44IDEuNiAxLjIgMS41LTEuNXptMTAuMyAw'
    b'IDEuNSAxLjIgMS41LTEuNXptMTAuMiAwIDEuNSAxLjIgMS41LTEuNXptMTcuOCAxMC4yLTEu'
    b'Mi44IDEuMi44em0wIDguNC0xLjIuNyAxLjIgMS4xem0wIDguNy0xLjIuNyAxLjIuOHptLTUz'
    b'LTE3LjR2MS45bDEuMi0uOHptMCA4Ljd2MS44bDEuMi0xem0wIDguM3YxLjlsMS4yLS44eiIv'
    b'PgogIDxnIGZpbGw9IiMzODM3MzkiPgogICAgPHBhdGggZD0iTTE2MCAyMjB2LTNoLTMuMXYt'
    b'My41aC0xMS40djMuNGgtM3YzaC00LjF2NS43aDQuMXYzaDN2My41SDE1N3YtMy44aDN2LTIu'
    b'N2g0LjJWMjIweiIvPgogICAgPHBhdGggZmlsbD0iI2ZmYzcyYyIgZD0iTTE1MS4yIDIxNHYz'
    b'LjNsLTQuOSAyLjd2Mi42aC03LjZ2LTIuM2gzLjh2LTNoMy40di0zLjh6bTAgMTcuN3YtMy44'
    b'bDUtMi42VjIyM2g3LjV2Mi4zaC0zLjh2M2gtMy40djMuNHoiLz4KICAgIDxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Ik0xNTYuMSAyMjIuNlYyMjBsLTQuOS0yLjd2LTMuOGg1LjN2My44aDN2M2g0'
    b'LjJ2Mi4zem0tMTcuNCAwaDcuNnYyLjdsNSAzdjMuNGgtNS40di0zLjhoLTN2LTIuNmgtNC4y'
    b'eiIvPgogICAgPHBhdGggZmlsbD0iI2QyMjYzMCIgZD0iTTE0Ni43IDIyM3YyLjNsNC41IDIu'
    b'NnYtNVoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDg0M2QiIGQ9Im0xNTEuMiAyMTcuNy00LjUg'
    b'Mi42djIuM2g0LjVaIi8+CiAgICA8cGF0aCBmaWxsPSIjZDIyNjMwIiBkPSJNMTU1LjcgMjIy'
    b'LjZ2LTIuM2wtNC41LTIuNnY1eiIvPgogICAgPHBhdGggZmlsbD0iIzAwODQzZCIgZD0ibTE1'
    b'MS4yIDIyOCA0LjUtMi43VjIyM2gtNC41WiIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSIjZDIy'
    b'NjMwIiBkPSJNMTEwIDI4M3Y5LjVoLTguN3Y4LjRoLTlWMzI1aDl2OC43aDguM3Y5LjFoMzIu'
    b'NWw1LjcgMy44LTIuNiAxLjVoLTExLjRsLTEuMS0xLjFoMTFsLTMtM2gtMTUuMmw2LjggNy4x'
    b'aDE0bDUtMy40IDQuOCAzaDE0bDYuOC03LjFoLTE1LjFsLTMgM2gxMC42bC0uOCAxLjFoLTEx'
    b'LjdsLTIuNy0xLjkgNS43LTMuNGgzMi41di05aDguN1YzMjVoOXYtMjRoLTl2LTguNGgtOC4z'
    b'di05LjRoLTMyLjVsLTUuNy0zLjggMi43LTEuNWgxMS4zbDEuMSAxLjFoLTExbDMuMSAzaDE1'
    b'LjFsLTYuOC03LjFoLTE0bC00LjkgMy00LjktM2gtMTRsLTYuOCA3LjVoMTUuMWwzLTMuNGgt'
    b'MTAuNWwuNy0xLjFoMTEuN2wyLjcgMS45LTUuNyAzLjR6Ii8+CiAgPHBhdGggZmlsbD0iI2Zm'
    b'YzcyYyIgZD0iTTE2MCAzNDIuNGgzMnYtOWg4LjR2LTguN2g5di0yMy41aC05di04LjdoLTgu'
    b'N3YtOWgtMzIuMkwxNDYgMjc1aC0xMy42bC02IDYuNWgxNGwyLjItMi4zaC0xMC4ybDEuNS0x'
    b'LjloMTEuN2wxNS4yIDkuNUgxODl2OWg5djguN2g5LjJ2MTYuN0gxOTh2OC43aC05djkuNGgt'
    b'MjcuN2wtMTUuMSA5aC0xMi4xbC0xLjUtMS44aDEwLjJsLTIuMy0yLjNoLTE0bDYgNi40aDE0'
    b'em0tMTguNi0zaC0yNy42VjMzMEgxMDV2LTguN2gtOXYtMTYuN2g5VjI5Nmg4LjN2LTguN0gx'
    b'NDFsMTUuMS05LjRoMTIuMWwxLjUgMS45aC0xMC4ybDIuMyAyLjNoMTRMMTcwIDI3NWgtMTRs'
    b'LTEzLjIgOC40aC0zMi41djlIMTAydjguN2gtOXYyMy41aDl2OC43aDguOHY5aDMyLjVsMTMu'
    b'MiA4LjNoMTMuNmw2LTYuNGgtMTRsLTIuMiAyLjNoMTAuMmwtMS41IDEuOWgtMTEuN3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSJub25lIiBkPSJtMTUxLjIgMjgxLjItOS40IDZoLTI3LjZ2OS41aC04'
    b'Ljd2OC43aC05LjF2MTUuOWg5djguN2g4Ljh2OS40aDI3LjZsOS40IDUuNyA5LjUtNS43aDI3'
    b'LjZWMzMwaDl2LTguN2g5LjF2LTE2aC05di04LjZoLTkuMXYtOS41aC0yNy42em0wIDIuMyA5'
    b'IDUuNmgyNi4ydjkuNWg4Ljd2OC4zaDl2MTJoLTl2OC44aC04Ljd2OC43aC0yNi41bC04Ljcg'
    b'Ni05LTZIMTE2di05aC04Ljd2LTguOGgtOS4xdi0xMmg5di04aDguOFYyODloMjYuNHoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjMDA4NDNkIiBkPSJNMTg2IDMyNy4zdjloLTI1LjdsLTkgNS43LTku'
    b'Mi01LjZoLTI1Ljd2LTloLTguN3YtOC44aC05LjR2LTExLjNoOXYtOC43aDguOHYtOWgyNS43'
    b'bDktNS40IDkuMSA1LjNoMjUuN3Y5aDguN3Y4LjhoOS44djExLjNoLTl2OC43eiIvPgogIDxn'
    b'IGZpbGw9IiMzODM3MzkiPgogICAgPHBhdGggZD0iTTExOS44IDMyNHY4LjZoMTQuNGwtMTQu'
    b'NC05LjV6bTAtMjJ2LTloMTQuNGwtMTQuNCA5LjRabTYyLjggMjJ2OC42aC0xNC40bDE0LjQt'
    b'OS41em0wLTIydi05aC0xNC40bDE0LjQgOS40eiIvPgogICAgPHBhdGggZmlsbD0iI2QyMjYz'
    b'MCIgZD0ibTEyMC4yIDMyNC4zIDEyLjkgOC4zaC0xMi45em0wLTIyLjcgMTIuOS04LjNoLTEy'
    b'Ljl6bTYyIDIyLjctMTIuOCA4LjNoMTIuOHptMC0yMi43LTEyLjgtOC4zaDEyLjh6Ii8+CiAg'
    b'PC9nPgogIDxnIGZpbGw9IiMzODM3MzkiPgogICAgPHBhdGggZD0iTTEzOCAzMTAuM3YtNC4y'
    b'aC0xLjVsLTcuNi00LjUtNy42IDQuNWgtMS41djQuNmgtMy43djUuM2gzLjd2NC41aDEuNWw3'
    b'LjYgNC41IDcuNi00LjVoMS41VjMxNmg1LjN2LTZaIi8+CiAgICA8cGF0aCBmaWxsPSIjZDIy'
    b'NjMwIiBkPSJtMTI4LjUgMzAxLjYgNy42IDQuMmgtMTQuNHptNy42IDE4LjUtNy42IDQuMi02'
    b'LjgtNC4yem0tMS45LTkuNHY0LjVoLTguN3YtNC41eiIvPgogICAgPHBhdGggZmlsbD0iI2Zm'
    b'YzcyYyIgZD0iTTEzNy42IDMxNS42djQuMWgtOC43di00LjF6bS05IDB2NC4xaC04Ljh2LTQu'
    b'MXptMTQuMy01djQuNmgtOC4zdi00LjV6bS0xNy44IDB2NC42aC04Ljd2LTQuNVptMTIuNS00'
    b'LjV2NC4yaC04Ljd2LTMuOHptLTkgMHY0LjJoLTguOHYtMy44eiIvPgogICAgPHBhdGggZD0i'
    b'TTEyMi45IDMxMS44djIuM0gxMTl2LTIuM3ptMy40LTQuNXYyLjJoLTMuOHYtMi4yem05IDB2'
    b'Mi4yaC0zLjd2LTIuMnptLTMuNyA0LjV2Mi4zaC0zLjh2LTIuM3ptOSAwdjIuM2gtMy44di0y'
    b'LjN6bS01LjMgNC41djIuM2gtMy43di0yLjN6bS05IDB2Mi4zaC0zLjh2LTIuM3oiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xMjIuNSAzMTIuMkgxMTl2MS41aDMuNHptMy44LTQu'
    b'NWgtMy44djEuNWgzLjh6bTguNyAwaC0zLjR2MS41aDMuNHptLTMuOCA0LjVoLTIuN3YxLjVo'
    b'M3ptOSAwaC0zdjEuNWgzem0tNS4yIDQuNWgtMy40djEuNWgzLjR6bS05LjEgMGgtM3YxLjVo'
    b'M3oiLz4KICA8L2c+CiAgPGcgZmlsbD0iIzM4MzczOSI+CiAgICA8cGF0aCBkPSJNMTY0LjQg'
    b'MzEwLjN2LTQuMmgxLjZsNy41LTQuNSA3LjYgNC41aDEuOXY0LjZoMy40djUuM2gtMy44djQu'
    b'NWgtMS4xbC03LjYgNC41LTcuNi00LjVoLTEuNVYzMTZoLTUuM3YtNloiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiNkMjI2MzAiIGQ9Im0xNzMuOSAzMDEuNi03LjYgNC4yaDE0em0tNy42IDE4LjUg'
    b'Ni44IDQuMiA3LjItNC4yem0xLjUtOS40djQuNWg4Ljd2LTQuNXoiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmM3MmMiIGQ9Ik0xNjQuOCAzMTUuNnY0LjFoOC43di00LjF6bTkgMHY0LjFoOC44'
    b'di00LjF6bS0xNC4zLTV2NC42aDguN3YtNC41em0xNy44IDB2NC42aDguN3YtNC41Wm0tMTIu'
    b'NS00LjV2NC4yaDguN3YtMy44em05IDB2NC4yaDguOHYtMy44eiIvPgogICAgPHBhdGggZD0i'
    b'TTE4MCAzMTEuOHYyLjNoMy43di0yLjN6bS0zLjgtNC41djIuMmgzLjd2LTIuMnptLTkuMSAw'
    b'djIuMmgzLjh2LTIuMnptMy44IDQuNXYyLjNoMy43di0yLjN6bS05LjEgMHYyLjNoMy44di0y'
    b'LjN6bTUuMyA0LjV2Mi4zaDMuOHYtMi4zem05IDB2Mi4zaDMuOHYtMi4zeiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0iTTE4MCAzMTIuMmgzLjN2MS41SDE4MHptLTMuNS00LjVoM3Yx'
    b'LjVoLTN6bS05IDBoMy40djEuNWgtMy40em0zLjcgNC41aDN2MS41aC0zem0tOSAwaDN2MS41'
    b'aC0yLjZabTUuMyA0LjVoMy40djEuNWgtMy40em05IDBoM3YxLjVoLTN6Ii8+CiAgPC9nPgog'
    b'IDxnIGZpbGw9IiMzODM3MzkiPgogICAgPHBhdGggZD0iTTE2MC4zIDMwMi43djQuNmgtMS41'
    b'bC03LjYgNC45LTcuNS01SDE0MnYtNC41aC00LjV2LTQuOWg0LjV2LTQuNWgxLjZsNy41LTUg'
    b'Ny42IDVoMS41djQuNWg0LjV2NC42WiIvPgogICAgPHBhdGggZmlsbD0iI2ZmYzcyYyIgZD0i'
    b'bTE1MS4yIDMxMS44IDYuOC00LjVoLTEzLjZ6TTE1OCAyOTNsLTYuOC0zLjgtNi44IDMuOHoi'
    b'Lz4KICAgIDxwYXRoIGZpbGw9IiNkMjI2MzAiIGQ9Ik0xNjAgMjk3Ljh2LTQuNWgtOC40djQu'
    b'NXptLTguOCAwdi00LjVoLTguN3Y0LjV6bTEzLjIgNC42di0zLjhoLTguN3YzLjh6bS05IDB2'
    b'LTMuOGgtOHYzLjh6bS04LjcgMHYtMy44SDEzOHYzLjh6bTEzLjIgNC41di00LjJoLTguM3Y0'
    b'LjJ6bS04LjcgMHYtNC4yaC04Ljd2NC4yeiIvPgogICAgPHBhdGggZD0iTTE0OC42IDI5NC40'
    b'djIuM2gtMy44di0xLjlabTkgMHYyLjNIMTU0di0xLjlaTTE0NCAyOTl2Mi42aC0zLjh2LTNa'
    b'bTkuMSAwdjIuNmgtMy44di0zWm05IDB2Mi42aC0zLjd2LTNabS0xMy41IDQuOXYyLjJoLTMu'
    b'OFYzMDR6bTkgMHYyLjJIMTU0VjMwNHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0x'
    b'NDguMiAyOTQuOGgtM3YxLjVoM3ptOSAwaC0zdjEuNWgzem0tMTMuNSA0LjVoLTN2MmgzWm05'
    b'IDBoLTN2Mmgzem05LjEgMGgtM3YyaDN6bS0xMy42IDQuNmgtM3YxLjloM3ptOSAwaC0zdjEu'
    b'OWgzeiIvPgogIDwvZz4KICA8ZyBmaWxsPSIjMzgzNzM5Ij4KICAgIDxwYXRoIGQ9Ik0xNjAu'
    b'MyAzMjh2NWgtMS41bC03LjYgNC41LTcuNS00LjVIMTQydi01aC00LjV2LTQuOWg0LjV2LTQu'
    b'NWgxLjZsNy41LTQuOSA3LjYgNWgxLjV2NC40aDQuNXY1eiIvPgogICAgPHBhdGggZmlsbD0i'
    b'I2ZmYzcyYyIgZD0ibTE1MS4yIDMzNy4xIDYuOC00LjFoLTEzLjZ6bTYuOC0xOC45LTYuOC0z'
    b'LjctNi44IDMuN3oiLz4KICAgIDxwYXRoIGZpbGw9IiNkMjI2MzAiIGQ9Ik0xNjAgMzIzLjFW'
    b'MzE5aC04LjR2NC4xem0tOC44IDBWMzE5aC04Ljd2NC4xem0xMy4yIDQuNnYtNC4yaC04Ljd2'
    b'NC4yem0tOSAwdi00LjJoLTh2NC4yem0tOC43IDB2LTQuMkgxMzh2NC4yem0xMy4yIDQuOXYt'
    b'NC41aC04LjN2NC41Wm0tOC43IDB2LTQuNWgtOC43djQuNVoiLz4KICAgIDxwYXRoIGQ9Ik0x'
    b'NDguNiAzMTkuN3YyLjdoLTMuOHYtMi43em05IDB2Mi43SDE1NHYtMi43Wk0xNDQgMzI1djIu'
    b'M2gtMy44VjMyNVptOS4xIDB2Mi4zaC0zLjhWMzI1Wm05IDB2Mi4zaC0zLjdWMzI1Wm0tMTMu'
    b'NSAzLjh2Mi4zaC0zLjh2LTIuM1ptOSAwdjIuM0gxNTR2LTIuM1oiLz4KICAgIDxwYXRoIGZp'
    b'bGw9IiNmZmYiIGQ9Ik0xNDguMiAzMjAuMWgtM3YyaDN6bTkgMGgtM3YyaDN6bS0xMy41IDVo'
    b'LTN2MS41aDNabTkgMGgtM3YxLjVoM3ptOS4xIDBoLTN2MS41aDN6bS0xMy42IDQuNWgtM3Yx'
    b'LjVoM3ptOSAwaC0zdjEuNWgzeiIvPgogIDwvZz4KICA8cGF0aCBmaWxsPSIjMzgzNzM5IiBk'
    b'PSJtMTAyIDM4My42IDM0LTE4LjFoMzAuM2wzNCAxOC4xdjI5LjlsLTM0IDE3LjdoLTMwLjJs'
    b'LTM0LTE3Ljd6Ii8+CiAgPHBhdGggZmlsbD0iIzAwODQzZCIgZD0ibTEzNiAzNjUuOS0zMy42'
    b'IDE3Ljd2MjkuNWwzMy43IDE4LjFoMzAuMmwzMy43LTE4LjF2LTI5LjVMMTY2LjcgMzY2em0u'
    b'NSAyLjJoMjkuOGwzMS44IDE3djI2LjVsLTMxLjggMTdoLTI5LjVsLTMxLjctMTdWMzg1eiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNmZmM3MmMiIGQ9Ik0xNTEuMiAzOTguNHYzMC4yaDE1LjFsMzEu'
    b'NC0xN3YtMTIuOWgtNDYuNXYtMzAuMmgtMTUuMWwtMzEuNCAxNi42djEzLjN6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0iTTE1MS4yIDM5OC40djMwLjJoLTE1LjFsLTMxLjQtMTd2LTEy'
    b'LjloNDYuNXYtMzAuMmgxNS4xbDMxLjQgMTYuNnYxMy4zeiIvPgogIDxwYXRoIGZpbGw9IiMz'
    b'ODM3MzkiIGQ9Ik0xNTMuOSA0MjYuN1Y0MThsLTIuNyAyLTIuNi0ydjguN2gtOS4xbDYtNC41'
    b'di02bC05LTUuN2gtNnYtMjQuMmg1LjZsOS01Ljd2LTZMMTQwIDM3MGg5djguN2wyLjctMS41'
    b'IDIuNiAxLjV2LTguM2g5LjFsLTYgNC41djZsOSA1LjdoNi41djI0LjJoLTYuNWwtOSA1Ljd2'
    b'Nmw2IDQuNnoiLz4KICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNMTU0LjIgMzcwLjR2OWwt'
    b'My0xLjh2Mi42bDE0IDguN2g0LjV2OS41aDIuM1YzODdoLTZsLTkuNS02di02LjhsNS4zLTMu'
    b'OHptLTIzLjQgMjguM3YxMS40aDUuM2w5LjQgNnY2LjVsLTUuMyAzLjdoNy42di05bDMgMS44'
    b'di0yLjZsLTE0LTguN2gtNC41di05eiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im0xNDAu'
    b'NiAzNzAuNCA1LjMgMy44djYuOGwtOS40IDUuNmgtNS43VjM5OGgxLjl2LTguN2g0LjVsMTQt'
    b'OC43VjM3OGwtMyAxLjh2LTkuNHptMjkuMSAyOC4zdjkuMWgtNC41bC0xNCA4Ljd2Mi42bDMt'
    b'MS44djloNy42bC01LjMtMy43di02LjlsOS41LTZoNnYtMTEuM1oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZDIyNjMwIiBkPSJNMTMzIDQwNy40aDQuMmwxNCA5LjEgMTQtOWg0LjJ2LTE4LjJoLTQu'
    b'MmwtMTQtOC43LTE0IDguN2gtMy44eiIvPgogIDxwYXRoIGZpbGw9IiMzODM3MzkiIGQ9Ik0x'
    b'NjAuNyA0MDIuOWgzdi0xLjVoLTIuM3YtMi43aDV2Ni41aC00LjZ2NC41aC05LjV2LTYuNGg0'
    b'LjJ2Mi42SDE1NXYxLjJoMy44di0yLjNsLTE3LjQtMTAuNmgtM3YxLjFoMi4ydjIuN2gtNC41'
    b'di02LjRoNC41VjM4N2g5LjV2Ni40aC0zLjh2LTIuNmgxLjF2LTEuMWgtMy43djIuMnptLTEu'
    b'Ni0xMXYtMi4ySDE1NXYxLjFoMS41djIuNmgtNC4yVjM4N2g5LjV2NC42aDQuNXY2LjRoLTQu'
    b'OXYtMi43aDIuM3YtMS4xaC0zbC0xNyAxMC4ydjIuM2gzLjd2LTEuMkgxNDZWNDAzaDQuMnY2'
    b'LjRoLTkuNXYtNC41aC00LjV2LTYuNGg0Ljl2Mi42aC0yLjN2MS41aDN6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2ZmZiIgZD0iTTE1OS41IDQwNC40djNIMTU1di0xLjloMS41di0xLjhoLTMuNHY1'
    b'LjZoOC43di00LjVoNC41VjM5OWgtMy43djJoMS44djIuMkgxNjFsLTE3LjctMTEuNHYtMi42'
    b'aDQuOXYxLjloLTEuNXYxLjloMy44di01LjdoLTkuMXY0LjVoLTQuNnY1LjdoMy44di0xLjlo'
    b'LTEuOXYtMS45aDMuNHptMS4yLTEwLjZoMy43djJoLTIuNnYxLjhoNC41VjM5MmgtNC41di00'
    b'LjVoLTguN3Y1LjdoMy40di0ySDE1NXYtMS44aDV2M2wtMTcuOSAxMWgtMy40VjQwMWgyLjN2'
    b'LTEuOWgtMy44djUuN2g0LjJ2NC41aDguN3YtNS42aC0zLjR2MS44aDEuNXYyaC01di0zeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiMzODM3MzkiIGQ9Ik0xOTAuNSAzOTkuOXY5LjRoLTMuOFY0MDZo'
    b'LTQuMXYzLjRoLTQuMlY0MDBoMy44djMuNGg0LjJWNDAwem0tMTQuMyAxMi40djkuNWgtMy44'
    b'di0zLjRoLTQuMnYzLjRoLTMuOHYtOS41aDMuOHYzLjRoMy44di0zLjR6bTE0LjMtMTV2LTku'
    b'OWgtMy44djMuNGgtNC4xdi0zLjRoLTQuMnY5LjVoMy44di0zLjVoNC4ydjMuOHptLTc4LjYg'
    b'Mi42djkuNGgzLjhWNDA2aDQuMXYzLjRoNC4yVjQwMGgtMy44djMuNGgtNC4xVjQwMHptMC0z'
    b'di05LjVoMy44djMuNGg0LjF2LTMuNGg0LjJ2OS41aC0zLjh2LTMuNWgtNC4xdjMuOHptNjQu'
    b'My0xMi41di05LjVoLTMuOHYzLjRoLTQuMlYzNzVoLTMuOHY5LjVoMy44VjM4MWgzLjh2My44'
    b'em0tNTAgMjh2OS40aDMuOHYtMy40aDQuMnYzLjRoNC4ydi05LjVoLTMuOHYzLjRoLTQuMnYt'
    b'My40em0wLTI4di05LjVoMy44djMuNGg0LjJWMzc1aDQuMnY5LjVoLTMuOFYzODFoLTQuMnYz'
    b'Ljh6bTUyLjItNi40djcuMWgxMy4zek0xMjQgNDE5di03LjVoLTEzLjJ6bTAtNDEuNXY3LjVo'
    b'LTEzLjJ6bTU0LjQgNDEuNXYtNy41aDEzLjN6Ii8+CiAgPHBhdGggZmlsbD0iI2QyMjYzMCIg'
    b'ZD0iTTE4Ni43IDQwNS41djMuOGgzLjR2LTloLTMuNHYzLjRoLTQuNXYtMy40aC0zLjh2OC42'
    b'aDMuOHYtMy40ek0xNzIuNCA0MTh2My44aDMuNHYtOWgtMy40djMuM2gtNC42di0zLjRoLTMu'
    b'NHY4LjdoMy40VjQxOHptMTQuMy0yNi44di0zLjRoMy40djguN2gtMy40VjM5M2gtNC41djMu'
    b'OGgtMy44di05LjFoMy44djMuNHptLTcxIDE0LjN2My44aC0zLjR2LTloMy40djMuNGg0LjV2'
    b'LTMuNGgzLjh2OC42aC0zLjh2LTMuNHptMC0xNC4zdi0zLjRoLTMuNHY4LjdoMy40VjM5M2g0'
    b'LjV2My44aDMuOHYtOS4xaC0zLjh2My40em01Ni43LTEyLjV2LTMuNGgzLjR2OC43aC0zLjR2'
    b'LTMuNGgtNC42djMuOGgtMy40di05aDMuNHYzLjN6TTEzMCA0MTh2My44aC0zLjR2LTloMy40'
    b'djMuM2g0LjZ2LTMuNGgzLjh2OC43aC0zLjhWNDE4em0wLTM5LjN2LTMuNGgtMy40djguN2gz'
    b'LjR2LTMuNGg0LjZ2My44aDMuOHYtOWgtMy44djMuM3oiLz4KICA8cGF0aCBmaWxsPSIjZmZj'
    b'NzJjIiBkPSJNMTc4LjggMzc4LjN2Ni41aDExLjN6bS02Ni45IDM0IDExLjMgNnYtNnoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMTIzLjYgMzc4LjMtMTEuMyA2LjVoMTEuM3ptNTUu'
    b'MiAzNHY2bDExLjMtNnoiLz4KICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNMjA1LjYgNDI0'
    b'LjhjLS43IDIuNy0zIDQuNi0zLjQgNy42LTEtMy0xLjgtNS43LTEtOC43IDAtMi4zIDIuMi0z'
    b'LjggMi42LTYuNCAxLjggMS44IDIuMiA0LjUgMS44IDcuNXptLjQgMTEuNGExNy44IDE3Ljgg'
    b'MCAwIDEtNi44IDUuNmMuNC0yLjItLjctMy44LTEuOS01LjYtMS4xLTItMS45LTMuOC0uNy02'
    b'LjVhMTQuNCAxNC40IDAgMCAwIDEuOSAzLjRjMS4xIDEuNSAyLjIgMyAyLjIgNS4zIDEuNS0x'
    b'LjEgMi0yLjYgMi43LTQuMWExMi45IDEyLjkgMCAwIDEgNS4zLTUuM2MtLjggMi42LTEuMiA0'
    b'LjktMi43IDcuMnptLTkuOCA3LjUuNCAzLjggNC4xLTNjMi0yIDQuMi0yLjcgNS43LTVhOS41'
    b'IDkuNCAwIDAgMS0zLjggNy4ybC03LjUgNWMwLTIuNy0uOC01LTItNy42YTYuOCA2LjggMCAw'
    b'IDEgMi02YzAgMS44LjMgMy43IDEuMSA1LjJ6bS01LjcgOC43LTMgNS4zYzIuNi0uOCA1LTIu'
    b'MyA3LjYtMy44IDIuNi0xLjUgNS42LTIuMiA4LjMtNC41LTEuMiA0LjktNC42IDcuNS05IDkt'
    b'My4xLjgtNi4xLjQtMTAgMmEyNi41IDI2LjUgMCAwIDEgMi43LTcuNmwyLjctNS4zYy43IDEu'
    b'NSAxLjEgMyAuNyA1em0tOS44IDcuMmExMi4xIDEyIDAgMCAxLTMuOCAzLjhjMy44IDAgNi44'
    b'LTIgMTAuNi0yLjMgMi4zIDAgNC41LjggNi44LjQtMi42IDEuOS01LjcgMy44LTkgMy44LTQu'
    b'Mi43LTguNCAwLTEzIDAgMi4zLTEuNiAzLjUtMy44IDQuNi01LjcgMi0zIDMuOC01IDcuMi01'
    b'LjMtMS41IDEuNS0yLjMgMy44LTMuNCA1LjN6bS0xMy4yIDZjNi40IDEuMiAxMi44IDIuNyAx'
    b'OS42IDIuN2EzMC4zIDMwLjMgMCAwIDEtMjIuMy40Yy0zLjgtMS4yLTcuMi0yLjMtMTAuMi0y'
    b'LTQuMSAwLTkuOCAyLjMtMTUuOSA4LjRsLTIuMi0xLjljOC43LTcuNiAyMC05LjUgMzEtNy42'
    b'eiIvPgo8L3N2Zz4K', 'TM')

TM = b64_TM
index.append("TM")
index.append("TKM")
index.append("Turkmenistan")
catalog["TM"] = TM
catalog["TKM"] = TM
catalog["Turkmenistan"] = TM
country["Turkmenistan"] = ('TM', 'TKM', 0)
lookup["TM"] = ('TM', 'TKM', 'Turkmenistan', 0)
lookup["Ashgabat Turkmenistan"] = ('TM', 'TKM', 'Turkmenistan', 0)
lookup["TKM"] = ('TM', 'TKM', 'Turkmenistan', 0)
lookup["Turkmenistan"] = ('TM', 'TKM', 'Turkmenistan', 0)
details["TM"] = {"continent":"Asia","capital":"Ashgabat","currency":"Turkmenistan New Manat","web":".tm","lang":"tk | ru | uz","tz":"+05:00","altname":""}
#----------------------------------------------------------------------
b64_TN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRuIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2U3MDAxMyIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTMyMCAxMTkuMmEx'
    b'IDEgMCAwIDAtMSAyNDAuMyAxIDEgMCAwIDAgMS0yNDAuM3pNMzkyIDI5M2E5MCA5MCAwIDEg'
    b'MSAwLTEwNyA3MiA3MiAwIDEgMCAwIDEwN3ptLTQuNy0yMS43LTM3LjQtMTIuMS0yMy4xIDMx'
    b'Ljh2LTM5LjNsLTM3LjQtMTIuMiAzNy40LTEyLjJWMTg4bDIzLjEgMzEuOCAzNy40LTEyLjEt'
    b'MjMuMSAzMS44eiIvPgo8L3N2Zz4K', 'TN')

TN = b64_TN
index.append("TN")
index.append("TUN")
index.append("Tunisia")
catalog["TN"] = TN
catalog["TUN"] = TN
catalog["Tunisia"] = TN
country["Tunisia"] = ('TN', 'TUN', 0)
lookup["TN"] = ('TN', 'TUN', 'Tunisia', 0)
lookup["Tunis Tunisia"] = ('TN', 'TUN', 'Tunisia', 0)
lookup["TUN"] = ('TN', 'TUN', 'Tunisia', 0)
lookup["Tunisia"] = ('TN', 'TUN', 'Tunisia', 0)
details["TN"] = {"continent":"Africa","capital":"Tunis","currency":"Tunisian Dinar","web":".tn","lang":"ar-TN | fr","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_TO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRvIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjYzEwMDAwIiBkPSJNMCAwaDY0'
    b'MHY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoMjUwdjIwMC4zSDB6'
    b'Ii8+CiAgICA8ZyBmaWxsPSIjYzEwMDAwIj4KICAgICAgPHBhdGggZD0iTTEwMi44IDMxLjJo'
    b'MzkuOXYxMzkuNmgtMzkuOHoiLz4KICAgICAgPHBhdGggZD0iTTE5Mi42IDgxdjQwSDUzVjgx'
    b'eiIvPgogICAgPC9nPgogIDwvZz4KPC9zdmc+Cg==', 'TO')

TO = b64_TO
index.append("TO")
index.append("TON")
index.append("Tonga")
catalog["TO"] = TO
catalog["TON"] = TO
catalog["Tonga"] = TO
country["Tonga"] = ('TO', 'TON', 0)
lookup["TO"] = ('TO', 'TON', 'Tonga', 0)
lookup["Nuku'alofa Tonga"] = ('TO', 'TON', 'Tonga', 0)
lookup["TON"] = ('TO', 'TON', 'Tonga', 0)
lookup["Tonga"] = ('TO', 'TON', 'Tonga', 0)
details["TO"] = {"continent":"Oceania","capital":"Nuku'alofa","currency":"Pa’anga","web":".to","lang":"to | en-TO","tz":"+13:00","altname":""}
#----------------------------------------------------------------------
b64_TR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXRyIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNlMzBhMTciIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2ZmZiIgZD0iTTQwNyAyNDcuNWMwIDY2LjItNTQuNiAxMTkuOS0xMjIgMTE5'
    b'LjlzLTEyMi01My43LTEyMi0xMjAgNTQuNi0xMTkuOCAxMjItMTE5LjggMTIyIDUzLjcgMTIy'
    b'IDExOS45eiIvPgogICAgPHBhdGggZmlsbD0iI2UzMGExNyIgZD0iTTQxMyAyNDcuNWMwIDUz'
    b'LTQzLjYgOTUuOS05Ny41IDk1LjlzLTk3LjYtNDMtOTcuNi05NiA0My43LTk1LjggOTcuNi05'
    b'NS44IDk3LjYgNDIuOSA5Ny42IDk1Ljl6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJt'
    b'NDMwLjcgMTkxLjUtMSA0NC4zLTQxLjMgMTEuMiA0MC44IDE0LjUtMSA0MC43IDI2LjUtMzEu'
    b'OCA0MC4yIDE0LTIzLjItMzQuMSAyOC4zLTMzLjktNDMuNSAxMi0yNS44LTM3eiIvPgogIDwv'
    b'Zz4KPC9zdmc+Cg==', 'TR')

TR = b64_TR
index.append("TR")
index.append("TUR")
index.append("Turkey")
catalog["TR"] = TR
catalog["TUR"] = TR
catalog["Turkey"] = TR
country["Turkey"] = ('TR', 'TUR', 0)
lookup["TR"] = ('TR', 'TUR', 'Turkey', 0)
lookup["Ankara Turkey"] = ('TR', 'TUR', 'Turkey', 0)
lookup["TUR"] = ('TR', 'TUR', 'Turkey', 0)
lookup["Turkey"] = ('TR', 'TUR', 'Turkey', 0)
details["TR"] = {"continent":"Asia","capital":"Ankara","currency":"Turkish Lira","web":".tr","lang":"tr-TR | ku | diq | az | av","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_TT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXR0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2UwMDAwMCIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNNDYzLjcgNDgwIDAgMXY0NzguOGw0NjMuNy4yek0xNzYuMyAwIDY0MCA0NzlW'
    b'LjJMMTc2LjMgMHoiLz4KICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yNy43LjJo'
    b'MTE4LjZsNDY4LjIgNDc5LjNINDkyLjJMMjcuNy4yeiIvPgo8L3N2Zz4K', 'TT')

TT = b64_TT
index.append("TT")
index.append("TTO")
index.append("Trinidad and Tobago")
catalog["TT"] = TT
catalog["TTO"] = TT
catalog["Trinidad and Tobago"] = TT
country["Trinidad and Tobago"] = ('TT', 'TTO', 0)
lookup["TT"] = ('TT', 'TTO', 'Trinidad and Tobago', 0)
lookup["Port of Spain Trinidad and Tobago"] = ('TT', 'TTO', 'Trinidad and Tobago', 0)
lookup["TTO"] = ('TT', 'TTO', 'Trinidad and Tobago', 0)
lookup["Trinidad and Tobago"] = ('TT', 'TTO', 'Trinidad and Tobago', 0)
details["TT"] = {"continent":"Americas","capital":"Port of Spain","currency":"Trinidad and Tobago Dollar","web":".tt","lang":"en-TT | hns | fr | es | zh","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_TV = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXR2IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwOWZjYSIgZD0i'
    b'TTAgMGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZjQwZCIgZmlsbC1ydWxlPSJl'
    b'dmVub2RkIiBkPSJNNTkzLjMgMTIyLjdINjIxbC0yMi4zIDE1LjIgOC41IDI0LjctMjIuMy0x'
    b'NS4zLTIyLjIgMTUuMyA4LjUtMjQuNy0yMi4zLTE1LjJoMjcuNWw4LjUtMjQuN3ptLTY5LjIg'
    b'MTk2LjhoMjcuNmwtMjIuMyAxNS4yIDguNSAyNC43LTIyLjMtMTUuMy0yMi4zIDE1LjMgOC42'
    b'LTI0LjctMjIuMy0xNS4ySDUwN2w4LjUtMjQuN3ptNjkuMi00NC42SDYyMWwtMjIuMyAxNS4y'
    b'IDguNSAyNC43LTIyLjMtMTUuMy0yMi4yIDE1LjMgOC41LTI0LjctMjIuMy0xNS4yaDI3LjVs'
    b'OC41LTI0Ljd6TTI5NS44IDQxNy43aDI3LjZMMzAxIDQzMi44bDguNiAyNC42LTIyLjMtMTUu'
    b'Mi0yMi4zIDE1LjIgOC42LTI0LjYtMjIuNC0xNS4zaDI3LjZsOC41LTI0LjZ6bTYyLjYtNzYu'
    b'NWgtMjcuNmwyMi4zLTE1LjMtOC41LTI0LjYgMjIuMyAxNS4yIDIyLjMtMTUuMi04LjYgMjQu'
    b'NiAyMi4zIDE1LjNoLTI3LjVsLTguNSAyNC42em04MS4zLTExMi41SDQxMmwyMi4zLTE1LjIt'
    b'OC41LTI0LjcgMjIuMyAxNS4zIDIyLjMtMTUuMy04LjYgMjQuNyAyMi4zIDE1LjJoLTI3LjVs'
    b'LTguNSAyNC43em02OC4zLTIzLjNoLTI3LjZsMjIuNC0xNS4zLTguNi0yNC42IDIyLjMgMTUu'
    b'MiAyMi4zLTE1LjItOC42IDI0LjYgMjIuNCAxNS4zSDUyNWwtOC41IDI0LjZ6TTQzOS43IDQw'
    b'MEg0MTJsMjIuMy0xNS4yTDQyNiAzNjBsMjIuMyAxNS4yIDIyLjMtMTUuMi04LjYgMjQuNyAy'
    b'Mi4zIDE1LjJoLTI3LjVsLTguNSAyNC43em0tODEuMyAxOS45aC0yNy42bDIyLjMtMTUuMi04'
    b'LjUtMjQuNyAyMi4zIDE1LjIgMjIuMy0xNS4yLTguNiAyNC42TDQwMyA0MjBoLTI3LjVsLTgu'
    b'NSAyNC43eiIvPgogIDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9Ik0wIDBoMzIwdjI0MEgweiIv'
    b'PgogIDxwYXRoIGZpbGw9IiNGRkYiIGQ9Im0zNy41IDAgMTIyIDkwLjVMMjgxIDBoMzl2MzFs'
    b'LTEyMCA4OS41IDEyMCA4OVYyNDBoLTQwbC0xMjAtODkuNUw0MC41IDI0MEgwdi0zMGwxMTku'
    b'NS04OUwwIDMyVjB6Ii8+CiAgPHBhdGggZmlsbD0iI0M4MTAyRSIgZD0iTTIxMiAxNDAuNSAz'
    b'MjAgMjIwdjIwbC0xMzUuNS05OS41em0tOTIgMTAgMyAxNy41LTk2IDcySDB6TTMyMCAwdjEu'
    b'NWwtMTI0LjUgOTQgMS0yMkwyOTUgMHpNMCAwbDExOS41IDg4aC0zMEwwIDIxeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiNGRkYiIGQ9Ik0xMjAuNSAwdjI0MGg4MFYwek0wIDgwdjgwaDMyMFY4MHoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjQzgxMDJFIiBkPSJNMCA5Ni41djQ4aDMyMHYtNDh6TTEzNi41'
    b'IDB2MjQwaDQ4VjB6Ii8+Cjwvc3ZnPgo=', 'TV')

TV = b64_TV
index.append("TV")
index.append("TUV")
index.append("Tuvalu")
catalog["TV"] = TV
catalog["TUV"] = TV
catalog["Tuvalu"] = TV
country["Tuvalu"] = ('TV', 'TUV', 0)
lookup["TV"] = ('TV', 'TUV', 'Tuvalu', 0)
lookup["Funafuti Tuvalu"] = ('TV', 'TUV', 'Tuvalu', 0)
lookup["TUV"] = ('TV', 'TUV', 'Tuvalu', 0)
lookup["Tuvalu"] = ('TV', 'TUV', 'Tuvalu', 0)
details["TV"] = {"continent":"Oceania","capital":"Funafuti","currency":"Australian Dollar","web":".tv","lang":"tvl | en | sm | gil","tz":"+12:00","altname":""}
#----------------------------------------------------------------------
b64_TW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXR3IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGNsaXBQYXRoIGlkPSJ0dy1hIj4KICAg'
    b'IDxwYXRoIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogIDwvY2xpcFBhdGg+CiAgPGcgY2xpcC1w'
    b'YXRoPSJ1cmwoI3R3LWEpIj4KICAgIDxwYXRoIGZpbGw9InJlZCIgZD0iTTAgMGg3MjB2NDgw'
    b'SDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDAwMDk1IiBkPSJNMCAwaDM2MHYyNDBIMHoiLz4K'
    b'ICAgIDxnIGZpbGw9IiNmZmYiPgogICAgICA8cGF0aCBkPSJtMTU0IDEyNi45LTIuNSA5LjYg'
    b'OS40IDIuNi0xLjgtNy4xem00Ni45IDUuMS0xLjggNy4xIDkuNC0yLjYtMi41LTkuNnptLTQx'
    b'LjgtMjQtNS4xIDUuMSAxLjkgNi45eiIvPgogICAgICA8cGF0aCBkPSJtMTU1LjkgMTIwLTEu'
    b'OSA2LjkgNS4xIDUuMXoiLz4KICAgICAgPHBhdGggZD0ibTE1NCAxMTMuMS02LjkgNi45IDYu'
    b'OSA2LjkgMS45LTYuOXptMTQgMjcuOCA1LjEgNS4xIDYuOS0xLjl6bTE4LjkgNS4xIDkuNiAy'
    b'LjUgMi42LTkuNC03LjEgMS44eiIvPgogICAgICA8cGF0aCBkPSJtMTkyIDE0MC45IDcuMS0x'
    b'LjggMS44LTcuMXptLTMxLjEtMS44IDIuNiA5LjQgOS42LTIuNS01LjEtNS4xem0xOS4xIDUg'
    b'Ni45IDEuOSA1LjEtNS4xeiIvPgogICAgICA8cGF0aCBkPSJtMTczLjEgMTQ2IDYuOSA2Ljkg'
    b'Ni45LTYuOS02LjktMS45em0tMTIuMi00NS4xLTkuNCAyLjYgMi41IDkuNiA1LjEtNS4xem0t'
    b'MS44IDMxLjEgMS44IDcuMSA3LjEgMS44em00NS0xMiAxLjktNi45LTUuMS01LjF6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Im0xNjggOTkuMS03LjEgMS44LTEuOCA3LjF6bTMyLjkgOC45LTEuOC03'
    b'LjEtNy4xLTEuOHptNS4xIDE4LjkgNi45LTYuOS02LjktNi45LTEuOSA2Ljl6Ii8+CiAgICAg'
    b'IDxwYXRoIGQ9Im0yMDAuOSAxMDgtOC45LTguOS0xMi0zLjItMTIgMy4yLTguOSA4LjktMy4y'
    b'IDEyIDMuMiAxMiA4LjkgOC45IDEyIDMuMiAxMi0zLjIgOC45LTguOSAzLjItMTJ6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Im0yMDAuOSAxMzIgNS4xLTUuMS0xLjktNi45em01LjEtMTguOSAyLjUt'
    b'OS42LTkuNC0yLjYgMS44IDcuMXptLTYuOS0xMi4yLTIuNi05LjQtOS42IDIuNSA1LjEgNS4x'
    b'em0tMjYtNi45LTkuNi0yLjUtMi42IDkuNCA3LjEtMS44em02LjkgMS45LTYuOS0xLjktNS4x'
    b'IDUuMXoiLz4KICAgICAgPHBhdGggZD0ibTE4Ni45IDk0LTYuOS02LjktNi45IDYuOSA2Ljkg'
    b'MS45eiIvPgogICAgICA8cGF0aCBkPSJtMTkyIDk5LjEtNS4xLTUuMS02LjkgMS45ek0xNzMu'
    b'MSAxNDZsLTkuNiAyLjUgNC41IDE2LjYgMTItMTIuMnptLTUuMSAxOS4xIDEyIDQ0LjkgMTIt'
    b'NDQuOS0xMi0xMi4yem0tNy4xLTI2LTkuNC0yLjYtNC40IDE2LjQgMTYuNC00LjR6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Im0xNDcuMSAxNTIuOS0xMiA0NS4xIDMyLjktMzIuOS00LjUtMTYuNnpt'
    b'LTEyLTIwLjlMMTAyIDE2NS4xbDQ1LjEtMTIuMiA0LjQtMTYuNHoiLz4KICAgICAgPHBhdGgg'
    b'ZD0ibTE1NCAxMjYuOS02LjktNi45LTEyIDEyIDE2LjQgNC41em0wLTEzLjgtMi41LTkuNi0x'
    b'Ni40IDQuNSAxMiAxMnoiLz4KICAgICAgPHBhdGggZD0iTTEzNS4xIDEwOCA5MCAxMjBsNDUu'
    b'MSAxMiAxMi0xMnptOTAgMjQtMTYuNiA0LjUgNC40IDE2LjQgNDUuMSAxMi4yeiIvPgogICAg'
    b'ICA8cGF0aCBkPSJtMTk5LjEgMTM5LjEtMi42IDkuNCAxNi40IDQuNC00LjQtMTYuNHptLTEy'
    b'LjIgNi45LTYuOSA2LjkgMTIgMTIuMiA0LjUtMTYuNnptMTkuMS0xOS4xIDIuNSA5LjYgMTYu'
    b'Ni00LjUtMTIuMi0xMnoiLz4KICAgICAgPHBhdGggZD0ibTE5MiAxNjUuMSAzMy4xIDMyLjkt'
    b'MTIuMi00NS4xLTE2LjQtNC40em03LjEtNjQuMiA5LjQgMi42IDQuNC0xNi40LTE2LjQgNC40'
    b'eiIvPgogICAgICA8cGF0aCBkPSJNMjI1LjEgMTA4IDI1OCA3NS4xbC00NS4xIDEyLTQuNCAx'
    b'Ni40em0tMTIuMi0yMC45TDIyNS4xIDQyIDE5MiA3NS4xbDQuNSAxNi40em0xMi4yIDQ0Ljkg'
    b'NDQuOS0xMi00NC45LTEyLTEyLjIgMTJ6Ii8+CiAgICAgIDxwYXRoIGQ9Im0yMDYgMTEzLjEg'
    b'Ni45IDYuOSAxMi4yLTEyLTE2LjYtNC41em0tMzgtMzhMMTM1LjEgNDJsMTIgNDUuMSAxNi40'
    b'IDQuNHoiLz4KICAgICAgPHBhdGggZD0ibTE2MC45IDEwMC45IDIuNi05LjQtMTYuNC00LjQg'
    b'NC40IDE2LjR6Ii8+CiAgICAgIDxwYXRoIGQ9Im0xNDcuMSA4Ny4xLTQ1LjEtMTIgMzMuMSAz'
    b'Mi45IDE2LjQtNC41em0zOS44IDYuOSA5LjYtMi41LTQuNS0xNi40LTEyIDEyeiIvPgogICAg'
    b'ICA8cGF0aCBkPSJNMTkyIDc1LjEgMTgwIDMwbC0xMiA0NS4xIDEyIDEyeiIvPgogICAgICA8'
    b'cGF0aCBkPSJtMTczLjEgOTQgNi45LTYuOS0xMi0xMi00LjUgMTYuNHoiLz4KICAgIDwvZz4K'
    b'ICAgIDxjaXJjbGUgY3g9IjE4MCIgY3k9IjEyMCIgcj0iNTEuMSIgZmlsbD0iIzAwMDA5NSIv'
    b'PgogICAgPGNpcmNsZSBjeD0iMTgwIiBjeT0iMTIwIiByPSI0NS4xIiBmaWxsPSIjZmZmIi8+'
    b'CiAgPC9nPgo8L3N2Zz4K', 'TW')

TW = b64_TW
index.append("TW")
index.append("TWN")
index.append("Taiwan")
catalog["TW"] = TW
catalog["TWN"] = TW
catalog["Taiwan"] = TW
country["Taiwan"] = ('TW', 'TWN', 0)
lookup["TW"] = ('TW', 'TWN', 'Taiwan', 0)
lookup["Taipei Taiwan"] = ('TW', 'TWN', 'Taiwan', 0)
lookup["TWN"] = ('TW', 'TWN', 'Taiwan', 0)
lookup["Taiwan"] = ('TW', 'TWN', 'Taiwan', 0)
details["TW"] = {"continent":"Asia","capital":"Taipei","currency":"","web":".tw","lang":"zh-TW | zh | nan | hak","tz":"+08:00","altname":""}
#----------------------------------------------------------------------
b64_TZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXR6IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InR6LWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNMTAgMGgxNjB2MTIw'
    b'SDEweiIvPgogICAgPC9jbGlwUGF0aD4KICA8L2RlZnM+CiAgPGcgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBzdHJva2Utd2lkdGg9IjFwdCIgY2xpcC1wYXRoPSJ1cmwoI3R6LWEpIiB0cmFuc2Zv'
    b'cm09Im1hdHJpeCg0IDAgMCA0IC00MCAwKSI+CiAgICA8cGF0aCBmaWxsPSIjMDlmIiBkPSJN'
    b'MCAwaDE4MHYxMjBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwOTAiIGQ9Ik0wIDBoMTgwTDAg'
    b'MTIwVjB6Ii8+CiAgICA8cGF0aCBkPSJNMCAxMjBoNDBsMTQwLTk1VjBoLTQwTDAgOTV2MjV6'
    b'Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmYwIiBkPSJNMCA5MS41IDEzNy4yIDBoMTMuNUwwIDEw'
    b'MC41di05ek0yOS4zIDEyMCAxODAgMTkuNXY5TDQyLjggMTIwSDI5LjN6Ii8+CiAgPC9nPgo8'
    b'L3N2Zz4K', 'TZ')

TZ = b64_TZ
index.append("TZ")
index.append("TZA")
index.append("Tanzania")
catalog["TZ"] = TZ
catalog["TZA"] = TZ
catalog["Tanzania"] = TZ
country["Tanzania"] = ('TZ', 'TZA', 0)
lookup["TZ"] = ('TZ', 'TZA', 'Tanzania', 0)
lookup["Dodoma Tanzania"] = ('TZ', 'TZA', 'Tanzania', 0)
lookup["TZA"] = ('TZ', 'TZA', 'Tanzania', 0)
lookup["Tanzania"] = ('TZ', 'TZA', 'Tanzania', 0)
details["TZ"] = {"continent":"Africa","capital":"Dodoma","currency":"Tanzanian Shilling","web":".tz","lang":"sw-TZ | en | ar","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_UA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXVhIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSJnb2xkIiBkPSJNMCAwaDY0MHY0'
    b'ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDU3YjgiIGQ9Ik0wIDBoNjQwdjI0MEgweiIv'
    b'PgogIDwvZz4KPC9zdmc+Cg==', 'UA')

UA = b64_UA
index.append("UA")
index.append("UKR")
index.append("Ukraine")
catalog["UA"] = UA
catalog["UKR"] = UA
catalog["Ukraine"] = UA
country["Ukraine"] = ('UA', 'UKR', 0)
lookup["UA"] = ('UA', 'UKR', 'Ukraine', 0)
lookup["Kyiv Ukraine"] = ('UA', 'UKR', 'Ukraine', 0)
lookup["UKR"] = ('UA', 'UKR', 'Ukraine', 0)
lookup["Ukraine"] = ('UA', 'UKR', 'Ukraine', 0)
details["UA"] = {"continent":"Europe","capital":"Kyiv","currency":"Hryvnia","web":".ua","lang":"uk | ru-UA | rom | pl | hu","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_UG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXVnIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InVnLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1LjMgMGg2ODIu'
    b'NnY1MTJILTg1LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBjbGlwLXBh'
    b'dGg9InVybCgjdWctYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDgwKSBzY2FsZSguOTM3NSki'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZTcwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNLTEy'
    b'OCAzNDEuNGg3Njh2ODUuM2gtNzY4eiIvPgogICAgPHBhdGggZmlsbC1ydWxlPSJldmVub2Rk'
    b'IiBkPSJNLTEyOCAyNTZoNzY4djg1LjNoLTc2OHoiLz4KICAgIDxwYXRoIGZpbGw9IiNkZTM5'
    b'MDgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTS0xMjggMTcwLjdoNzY4VjI1NmgtNzY4eiIv'
    b'PgogICAgPHBhdGggZmlsbD0iI2ZmZTcwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNLTEy'
    b'OCA4NS40aDc2OHY4NS4zaC03Njh6Ii8+CiAgICA8cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQi'
    b'IGQ9Ik0tMTI4IDBoNzY4djg1LjNoLTc2OHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmZkZmYi'
    b'IGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBkPSJNMzM1LjcgMjU2YTc5Ljcg'
    b'NzkuNyAwIDEgMS0xNTkuNCAwIDc5LjcgNzkuNyAwIDAgMSAxNTkuNCAweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iI2RlMzEwOCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIGQ9'
    b'Im0yNDIgMTk0LjktNS4yLTkuNWMyLTIgNS4zLTMuNiAxMC43LTMuNmwtLjYgMTAuNS01IDIu'
    b'NnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmU3MDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ry'
    b'b2tlPSIjMDAwIiBkPSJtMjQ3IDE5Mi4zLjctMTAuNXMxMC43LS42IDE2LjUgNi40bC01Ljcg'
    b'OC4yLTExLjYtNHoiLz4KICAgIDxwYXRoIGZpbGw9IiNkZTMxMDgiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjMDAwIiBkPSJtMjU4LjYgMTk2LjMgNS4zLTguMmMzLjUgMy43IDUg'
    b'Ni4zIDUuNSAxMC4zLjEuMS04LjMgMi4xLTguMyAybC0yLjUtNC4xeiIvPgogICAgPHBhdGgg'
    b'ZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lY2FwPSJyb3Vu'
    b'ZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuOSIgZD0iTTI0NC42'
    b'IDMzMS4xczkuOS0xMS4zIDI5LjEtOC45Yy0yLjktNC43LTEyLjMtNC4xLTEyLjMtNC4xcy0y'
    b'LjgtMjItLjYtMjMuMiAxMiAuMSAxMiAuMWMxLjIgMCAzLjQtMy40IDEuNi01LjYtMS43LTIu'
    b'Mi02LjgtMTAuNS00LjctMTIuMiAyLjEtMS42IDEzLjQgMSAxMy40IDFsLTMyLTQxcy0zLjMt'
    b'MTUuNSAzLjMtMjNjNy45LTYuNSA3LTEzLjYgNi44LTEzLjUtMS4xLTcuMi0xMi0xMi4zLTE5'
    b'LjQtNS43LTQuMyA1LjItMS40IDkuMi0xLjQgOS4ycy0xMS41IDMuMS0xMS45IDUuMWMtLjUg'
    b'MiAxMi45LS4zIDEyLjktLjNsLTEuMyA5LjFzLTI2IDIzLjYtNiA0NGwuNi0uOHM3IDguNiAx'
    b'NC4zIDEwLjVjNyA3IDYuMyA2IDYuMyA2czEuMyAxMS4xIDAgMTMuM2MtMS43LS41LTE5LjMt'
    b'MS4yLTIxLjktLjItMi40LjgtMTEuNC4zLTkuMiAxNS4xbDMuMy03LjVzLS4zIDUuMyAxLjkg'
    b'Ny4yYy0uNC01LjYgMi4xLTkuNCAyLjEtOS40cy40IDYuMiAxLjggN2MxLjQgMSAxLjQtMTAg'
    b'OS05IDcuNC45IDEyLjkuNiAxMi45LjZzMi41IDIxLjQgMS43IDIzLjRjLTUuNC0xLjMtMTgu'
    b'NC41LTE5LjIgMy44IDcuNi0uNSAxMS4xLjQgMTEuMS40cy02LjEgNS41LTQuMiA4LjZ6Ii8+'
    b'CiAgICA8cGF0aCBmaWxsPSIjOWNhNjljIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0i'
    b'IzljYTY5YyIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5k'
    b'IiBzdHJva2Utd2lkdGg9Ii45IiBkPSJNMjQ3LjYgMjE0LjhzLTE4LjkgMjAuOC0xMC43IDM2'
    b'LjdjLjQtMi4yLjItMy42LjUtMy41LS41LS4zIDIuMyAxLjkgMi4xIDEuNSAwLTEuMi0uOC0z'
    b'LjctLjgtMy43bDIuNS43LTEuNS0yLjggMy43LjRzLTEuMy0zLjQtLjktMy40bDMgLjJjLTUu'
    b'NC05LjYtLjMtMTcuNiAyLjEtMjYuMnoiLz4KICAgIDxwYXRoIGZpbGw9IiM5Y2E2OWMiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjOWNhNjljIiBkPSJNMjU0LjIgMTk2LjlzMSA3'
    b'LjItMyA5LjJjLS41LjUtMyAxLjMtMi42IDIuOC40IDIgMS41IDEuNiAzIDEuMiA0LjEtLjcg'
    b'OC45LTkuNCAyLjYtMTMuMnoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZmYiIGZpbGwtcnVsZT0i'
    b'ZXZlbm9kZCIgZD0iTTI0Ny4yIDIwM2ExLjUgMS41IDAgMSAxLTMgMCAxLjUgMS41IDAgMCAx'
    b'IDMgMHoiLz4KICAgIDxwYXRoIGZpbGw9IiNkZTMxMDgiIGZpbGwtcnVsZT0iZXZlbm9kZCIg'
    b'c3Ryb2tlPSIjMDAwIiBkPSJNMjQxLjEgMjA5Yy0xIC45LTYuMiA2LjMtMSA4LjMgNS4zLTEu'
    b'NCAzLjgtMi40IDUtMy42IDAtMi41LTIuNi0zLjEtNC00LjZ6Ii8+CiAgICA8cGF0aCBmaWxs'
    b'PSIjOWNhNjljIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzljYTY5YyIgc3Ryb2tl'
    b'LWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9'
    b'Ii45IiBkPSJNMjUyLjYgMjYwLjVjLS4zIDEuMi0xLjUgNS42LjEgOSA0LjYtMiA2LjctMS40'
    b'IDguMi0uNC0zLjctMy01LjItNC4zLTguMy04LjZ6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZm'
    b'IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLWxpbmVjYXA9InJv'
    b'dW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9Ii45IiBkPSJtMjYw'
    b'LjQgMjgxLjEuMiAxMC4yczMuNi42IDUuMiAwIDAtNy01LjQtMTAuMnoiLz4KICAgIDxwYXRo'
    b'IGZpbGw9IiM5Y2E2OWMiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAwIiBkPSJN'
    b'Mjg2IDI4Mi40cy02LjUtMTUuOC0yMy4yLTE5LjgtMTQuNS0yMS44LTEzLjItMjIuOWMuOC0x'
    b'LjUgMS4zLTMuOSA2LjEtMS42czI3IDEzLjQgMzAuMiAxNCAuNCAzMC43LjIgMzAuM3oiLz4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNkZTMxMDgiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIj'
    b'MDAwIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9Ii45IiBkPSJNMjcw'
    b'LjIgMjYyLjVjLS4zLjIgMjIuMyAxMy40IDE1LjUgMjQuNyA2LjQtNC4zIDQuNC0xMS43IDQu'
    b'NC0xMS43czUuMiAxMy43LTcuNiAyMC40YzEuNCAxLjIgMi4zIDEgMi4zIDFsLTIuMiAyLjFz'
    b'LTEgMS43IDcuNi0yLjVjLTIuMyAxLjktMi41IDMuMy0yLjUgMy4zcy42IDEuOCA2LjItMy4x'
    b'Yy00LjUgNC45LTUuNSA3LjQtNS41IDcuMyAxMi4zLTEgMzktNDEtOC40LTUyLjdsMi4xIDIu'
    b'Mi0xMiA5eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJy'
    b'b3VuZCIgc3Ryb2tlLXdpZHRoPSIuOSIgZD0iTTI3MS4yIDI1OC42YzMgMi4yIDQuMSAzIDQu'
    b'NSA0LTIuOC0uNi01LjMtLjQtNS4zLS40cy02LjEtNS44LTcuMi02LjNjLS44IDAtNS42LTMt'
    b'NS42LTMtMi4zLTEuMi00LjUtOS4zIDQuMi03YTkzIDkzIDAgMCAwIDEwLjMgNC42bDEwLjcg'
    b'My40IDYuMiA2LjlzLTExLTUuNC0xMi40LTUuNWMzIDIuNCA0LjcgNS44IDQuNyA1LjgtMy41'
    b'LTEtNi41LTItMTAuMS0yLjV6Ii8+CiAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJva2U9IiNm'
    b'ZmYiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIuOSIgZD0iTTIyOC40'
    b'IDIwOS45czEwLjUtMi42IDExLjgtMi4yIi8+CiAgICA8cGF0aCBmaWxsPSIjZGUzOTA4IiBm'
    b'aWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0tMTI4IDQyNi43aDc2OFY1MTJoLTc2OHoiLz4KICA8'
    b'L2c+Cjwvc3ZnPgo=', 'UG')

UG = b64_UG
index.append("UG")
index.append("UGA")
index.append("Uganda")
catalog["UG"] = UG
catalog["UGA"] = UG
catalog["Uganda"] = UG
country["Uganda"] = ('UG', 'UGA', 0)
lookup["UG"] = ('UG', 'UGA', 'Uganda', 0)
lookup["Kampala Uganda"] = ('UG', 'UGA', 'Uganda', 0)
lookup["UGA"] = ('UG', 'UGA', 'Uganda', 0)
lookup["Uganda"] = ('UG', 'UGA', 'Uganda', 0)
details["UG"] = {"continent":"Africa","capital":"Kampala","currency":"Uganda Shilling","web":".ug","lang":"en-UG | lg | sw | ar","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_UM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXVtIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2JkM2Q0NCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDAiLz4KICA8cGF0aCBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0i'
    b'MzciIGQ9Ik0wIDU1LjNoNjQwTTAgMTI5aDY0ME0wIDIwM2g2NDBNMCAyNzdoNjQwTTAgMzUx'
    b'aDY0ME0wIDQyNWg2NDAiLz4KICA8cGF0aCBmaWxsPSIjMTkyZjVkIiBkPSJNMCAwaDM2NC44'
    b'djI1OC41SDAiLz4KICA8bWFya2VyIGlkPSJ1bS1hIiBtYXJrZXJIZWlnaHQ9IjMwIiBtYXJr'
    b'ZXJXaWR0aD0iMzAiPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTE0IDAgOSAyN0wwIDEw'
    b'aDI4TDUgMjd6Ii8+CiAgPC9tYXJrZXI+CiAgPHBhdGggZmlsbD0ibm9uZSIgbWFya2VyLW1p'
    b'ZD0idXJsKCN1bS1hKSIgZD0ibTAgMCAxNiAxMWg2MSA2MSA2MSA2MSA2MEw0NyAzN2g2MSA2'
    b'MSA2MCA2MUwxNiA2M2g2MSA2MSA2MSA2MSA2MEw0NyA4OWg2MSA2MSA2MCA2MUwxNiAxMTVo'
    b'NjEgNjEgNjEgNjEgNjBMNDcgMTQxaDYxIDYxIDYwIDYxTDE2IDE2Nmg2MSA2MSA2MSA2MSA2'
    b'MEw0NyAxOTJoNjEgNjEgNjAgNjFMMTYgMjE4aDYxIDYxIDYxIDYxIDYwTDAgMCIvPgo8L3N2'
    b'Zz4K', 'UM')

UM = b64_UM
index.append("UM")
index.append("UMI")
index.append("United States Outlying Islands")
catalog["UM"] = UM
catalog["UMI"] = UM
catalog["United States Outlying Islands"] = UM
country["United States Outlying Islands"] = ('UM', 'UMI', 0)
lookup["UM"] = ('UM', 'UMI', 'United States Outlying Islands', 0)
lookup["UMI"] = ('UM', 'UMI', 'United States Outlying Islands', 0)
lookup["United States Outlying Islands"] = ('UM', 'UMI', 'United States Outlying Islands', 0)
details["UM"] = {"continent":"Oceania","capital":"","currency":"US Dollar","web":".um","lang":"en-UM","tz":"-10:00","altname":""}
#----------------------------------------------------------------------
b64_US = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXVzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2JkM2Q0NCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDAiLz4KICA8cGF0aCBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0i'
    b'MzciIGQ9Ik0wIDU1LjNoNjQwTTAgMTI5aDY0ME0wIDIwM2g2NDBNMCAyNzdoNjQwTTAgMzUx'
    b'aDY0ME0wIDQyNWg2NDAiLz4KICA8cGF0aCBmaWxsPSIjMTkyZjVkIiBkPSJNMCAwaDM2NC44'
    b'djI1OC41SDAiLz4KICA8bWFya2VyIGlkPSJ1cy1hIiBtYXJrZXJIZWlnaHQ9IjMwIiBtYXJr'
    b'ZXJXaWR0aD0iMzAiPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTE0IDAgOSAyN0wwIDEw'
    b'aDI4TDUgMjd6Ii8+CiAgPC9tYXJrZXI+CiAgPHBhdGggZmlsbD0ibm9uZSIgbWFya2VyLW1p'
    b'ZD0idXJsKCN1cy1hKSIgZD0ibTAgMCAxNiAxMWg2MSA2MSA2MSA2MSA2MEw0NyAzN2g2MSA2'
    b'MSA2MCA2MUwxNiA2M2g2MSA2MSA2MSA2MSA2MEw0NyA4OWg2MSA2MSA2MCA2MUwxNiAxMTVo'
    b'NjEgNjEgNjEgNjEgNjBMNDcgMTQxaDYxIDYxIDYwIDYxTDE2IDE2Nmg2MSA2MSA2MSA2MSA2'
    b'MEw0NyAxOTJoNjEgNjEgNjAgNjFMMTYgMjE4aDYxIDYxIDYxIDYxIDYwTDAgMCIvPgo8L3N2'
    b'Zz4K', 'US')

US = b64_US
index.append("US")
index.append("USA")
index.append("United States of America")
catalog["US"] = US
catalog["USA"] = US
catalog["United States of America"] = US
country["United States of America"] = ('US', 'USA', 0)
lookup["US"] = ('US', 'USA', 'United States of America', 0)
lookup["Washington DC United States of America"] = ('US', 'USA', 'United States of America', 0)
lookup["USA"] = ('US', 'USA', 'United States of America', 0)
lookup["United States of America"] = ('US', 'USA', 'United States of America', 0)
details["US"] = {"continent":"Americas","capital":"Washington DC","currency":"US Dollar","web":".us","lang":"en-US | es-US | haw | fr","tz":"-09:00 | -05:00","altname":""}
#----------------------------------------------------------------------
b64_US_AK = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iMTQxNiIgaGVpZ2h0PSIxMDAwIiB4bWxucz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5r'
    b'Ij48cGF0aCBmaWxsPSIjMEYyMDRCIiBkPSJNMCAwaDE0MTZ2MTAwMEgweiIvPjxnIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDU3LjQ4OTc4IDAgMCA1Ny40ODk3OCAxMTU3Ljk5NiAxODcuNDkpIiBm'
    b'aWxsPSIjZmZiNjEyIj48ZyBpZD0iYiI+PHBhdGggaWQ9ImEiIHRyYW5zZm9ybT0icm90YXRl'
    b'KDE4IDMuMTU3IC0uNSkiIGQ9Ik0wIDB2MWguNXoiLz48dXNlIHRyYW5zZm9ybT0ic2NhbGUo'
    b'LTEgMSkiIHhsaW5rOmhyZWY9IiNhIi8+PC9nPjx1c2UgdHJhbnNmb3JtPSJyb3RhdGUoNzIp'
    b'IiB4bGluazpocmVmPSIjYiIvPjx1c2UgdHJhbnNmb3JtPSJyb3RhdGUoLTcyKSIgeGxpbms6'
    b'aHJlZj0iI2IiLz48dXNlIHRyYW5zZm9ybT0icm90YXRlKDE0NCkiIHhsaW5rOmhyZWY9IiNi'
    b'Ii8+PHVzZSB0cmFuc2Zvcm09InJvdGF0ZSgyMTYpIiB4bGluazpocmVmPSIjYiIvPjwvZz48'
    b'ZyBpZD0iYyIgdHJhbnNmb3JtPSJtYXRyaXgoMzQuMjcyNzYgMCAwIDM0LjI3Mjc2IDIyOC45'
    b'OTUgMzk5LjI3MykiIGZpbGw9IiNmZmI2MTIiPjxwYXRoIHRyYW5zZm9ybT0icm90YXRlKDE4'
    b'IDMuMTU3IC0uNSkiIGQ9Ik0wIDB2MWguNXoiLz48dXNlIHRyYW5zZm9ybT0ic2NhbGUoLTEg'
    b'MSkiIHhsaW5rOmhyZWY9IiNhIi8+PHVzZSB0cmFuc2Zvcm09InJvdGF0ZSg3MikiIHhsaW5r'
    b'OmhyZWY9IiNiIi8+PHVzZSB0cmFuc2Zvcm09InJvdGF0ZSgtNzIpIiB4bGluazpocmVmPSIj'
    b'YiIvPjx1c2UgdHJhbnNmb3JtPSJyb3RhdGUoMTQ0KSIgeGxpbms6aHJlZj0iI2IiLz48dXNl'
    b'IHRyYW5zZm9ybT0icm90YXRlKDIxNikiIHhsaW5rOmhyZWY9IiNiIi8+PC9nPjx1c2UgdHJh'
    b'bnNmb3JtPSJ0cmFuc2xhdGUoMTY3IDYyKSIgeGxpbms6aHJlZj0iI2MiLz48dXNlIHRyYW5z'
    b'Zm9ybT0idHJhbnNsYXRlKDI1MCAxNTEpIiB4bGluazpocmVmPSIjYyIvPjx1c2UgdHJhbnNm'
    b'b3JtPSJ0cmFuc2xhdGUoMzM0IDI0NCkiIHhsaW5rOmhyZWY9IiNjIi8+PHVzZSB0cmFuc2Zv'
    b'cm09InRyYW5zbGF0ZSg1ODQgMzMzKSIgeGxpbms6aHJlZj0iI2MiLz48dXNlIHRyYW5zZm9y'
    b'bT0idHJhbnNsYXRlKDMyMyAzNzUpIiB4bGluazpocmVmPSIjYyIvPjx1c2UgdHJhbnNmb3Jt'
    b'PSJ0cmFuc2xhdGUoNTExIDQzNykiIHhsaW5rOmhyZWY9IiNjIi8+PC9zdmc+', 'US_AK')

US_AK = b64_US_AK
index.append("US_AK")
index.append("United States of America Alaska")
catalog["US_AK"] = US_AK
catalog["United States of America Alaska"] = US_AK
country["United States of America Alaska"] = ('US_AK', '', 1)
lookup["US_AK"] = ('US_AK', '', 'United States of America Alaska', 1)
lookup["Juneau United States of America Alaska"] = ('US_AK', '', 'United States of America Alaska', 1)
lookup["United States of America Alaska"] = ('US_AK', '', 'United States of America Alaska', 1)
details["US_AK"] = {"continent":"Americas","capital":"Juneau","currency":"","web":"","lang":"","tz":"-09:00","altname":""}
regional["US_AK"] = ('US_AK', 'United States of America Alaska', 1)
regional["United States of America Alaska"] = ('US_AK', 'United States of America Alaska', 1)
#----------------------------------------------------------------------
b64_US_AL = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI2MDAiIGhl'
    b'aWdodD0iNDAwIj48cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDYwMHY0MDBIMHoiLz48cGF0'
    b'aCBkPSJNMCwwIDYwMCw0MDBNMCw0MDAgNjAwLDAiIHN0cm9rZT0iI2IxMDAyMSIgc3Ryb2tl'
    b'LXdpZHRoPSI2OCIvPjwvc3ZnPg==', 'US_AL')

US_AL = b64_US_AL
index.append("US_AL")
index.append("United States of America Alabama")
catalog["US_AL"] = US_AL
catalog["United States of America Alabama"] = US_AL
country["United States of America Alabama"] = ('US_AL', '', 1)
lookup["US_AL"] = ('US_AL', '', 'United States of America Alabama', 1)
lookup["Montgomery United States of America Alabama"] = ('US_AL', '', 'United States of America Alabama', 1)
lookup["United States of America Alabama"] = ('US_AL', '', 'United States of America Alabama', 1)
details["US_AL"] = {"continent":"Americas","capital":"Montgomery","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_AL"] = ('US_AL', 'United States of America Alabama', 1)
regional["United States of America Alabama"] = ('US_AL', 'United States of America Alabama', 1)
#----------------------------------------------------------------------
b64_US_AR = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB2ZXJzaW9uPSIxLjAiIHdpZHRoPSI0NTAi'
    b'IGhlaWdodD0iMzAwIj48cGF0aCBzdHlsZT0iZmlsbDojYmYwYTMwIiBkPSJNMCAwaDQ1MHYz'
    b'MDBIMHoiLz48cGF0aCBkPSJNMzcuNSAxNDguODQgMjI0LjIyNSAyNzUgNDEyLjUgMTQ4LjU5'
    b'NSAyMjQuMjI1IDI1IDM3LjUgMTQ4Ljg0eiIgc3R5bGU9ImZpbGw6IzAwMjg2OCIvPjxwYXRo'
    b'IGQ9Ik04NCAxNDkuMTI4IDIyNC40MTcgMjQ0IDM2NiAxNDguOTQ0IDIyNC40MTcgNTYgODQg'
    b'MTQ5LjEyOHoiIHN0eWxlPSJmaWxsOiNmZmYiLz48cGF0aCBkPSJNMTQ4LjE3NSAxNDUuMDE0'
    b'aDcuODM1bDEuMzYgNC4zNzZoNC44MmwtNy40OC0yMS4yMjhoLTUuMTE2bC03LjU2OCAyMS4y'
    b'MjhoNC42NzFsMS40NzgtNC4zNzZ6bTMuOTAzLTEyLjA2M2guMDU5bDIuNjMxIDguMzk3aC01'
    b'LjQxbDIuNzItOC4zOTd6bTEyLjk3IDE2LjQzOWg0LjM0NXYtOC4zMDhoNC41ODNjMS41OC0u'
    b'MDE0IDIuNTY2LjI5NCAyLjk2LjkyNC4zOTQuNjMuNTYgMS42NjEuNDk5IDMuMDk3LjAwMSAx'
    b'LjA3My4wNDMgMS45MzUuMTI2IDIuNTg3LjA4Mi42NTEuMTk4IDEuMjE4LjM0NyAxLjdoNC45'
    b'MDh2LS41NjJjLS40NTQtLjEzOC0uNzMtLjQ5OC0uODI4LTEuMDgzLS4wOTktLjU4NS0uMTM4'
    b'LTEuNjMzLS4xMTgtMy4xNDUtLjAwMy0xLjkxLS4yMzQtMy4yMDUtLjY5MS0zLjg4OC0uNDU4'
    b'LS42ODItMS4xMjQtMS4xOC0yLTEuNDkzIDEuMDU1LS4zNzUgMS44NjUtMS4wMTQgMi40Mjgt'
    b'MS45MTguNTY0LS45MDMuODQ4LTEuOTUuODU0LTMuMTM4LjAyMi0uNjUtLjEzNy0xLjQ0LS40'
    b'NzctMi4zNy0uMzQtLjkzLS45OTUtMS43NTctMS45NjMtMi40ODMtLjk2Ny0uNzI1LTIuMzgx'
    b'LTEuMTA4LTQuMjQyLTEuMTQ4aC0xMC43MzJ2MjEuMjI4em00LjM0NS0xMS44ODZ2LTUuNjc2'
    b'aDUuNTI5YzEuMjY4LjA0NSAyLjExLjM2OCAyLjUyOC45NjguNDE3LjYuNjEgMS4yMDQuNTc2'
    b'IDEuODExLjAwMSAxLjA0LS4yODIgMS43ODQtLjg1IDIuMjM2LS41NjguNDUxLTEuNDI4LjY3'
    b'Mi0yLjU4LjY2MWgtNS4yMDN6bTIxLjc4IDQuNzAxIDIuMDctMi4xMjggNi41NjMgOS4zMTNo'
    b'NS43MDZsLTkuMTY1LTEyLjUzNiA4LjY2Mi04LjY5MmgtNS43MzVsLTguMTAxIDguNjMzdi04'
    b'LjYzM2gtNC40MzV2MjEuMjI4aDQuNDM1di03LjE4NXptMjEuMSAyLjgwOWg3LjgzNGwxLjM2'
    b'IDQuMzc2aDQuODJsLTcuNDgtMjEuMjI4aC01LjExNWwtNy41NjkgMjEuMjI4aDQuNjcxbDEu'
    b'NDc5LTQuMzc2em0zLjkwMi0xMi4wNjNoLjA2bDIuNjMgOC4zOTdoLTUuNDFsMi43Mi04LjM5'
    b'N3ptMjUuOTE5IDkuOTkzaC0uMDZsLTguNDI1LTE0Ljc4MmgtNC42NzJ2MjEuMjI4aDQuMTR2'
    b'LTE1LjEzOGguMDU5bDguNjYyIDE1LjEzOGg0LjQzNXYtMjEuMjI4aC00LjE0djE0Ljc4Mnpt'
    b'Ny4zMjItLjA4OGMtLjAzMS45MTYuMTggMS45MTkuNjMyIDMuMDA5LjQ1MyAxLjA5IDEuMzM2'
    b'IDIuMDM0IDIuNjQ5IDIuODMxIDEuMzEzLjc5OCAzLjI0NSAxLjIxNiA1Ljc5NiAxLjI1NS42'
    b'OS4wMzMgMS42ODgtLjA5NSAyLjk5Ny0uMzgyIDEuMzA4LS4yODcgMi41MTMtLjkzIDMuNjE0'
    b'LTEuOTI2IDEuMTAyLS45OTcgMS42ODctMi41NDMgMS43NTYtNC42NC0uMDUtMS44NjItLjYx'
    b'NS0zLjItMS42OTMtNC4wMTctMS4wNzgtLjgxNi0yLjM2Ni0xLjM3OS0zLjg2Ni0xLjY4OWwt'
    b'NS4xNzQtMS4yN2E0LjA4NSA0LjA4NSAwIDAgMS0xLjQ1Ni0uNTY2Yy0uNDg5LS4yOTgtLjc1'
    b'Mi0uODQ4LS43OS0xLjY1Mi4wNDgtLjk0Ny40NTMtMS42MTEgMS4yMTUtMS45OTJhNS4yNzIg'
    b'NS4yNzIgMCAwIDEgMi40OC0uNTVjMS44NjguMDczIDMuMDYyLjQ4NyAzLjU4MSAxLjI0LjUy'
    b'Ljc1NS43NzQgMS40MDUuNzY1IDEuOTUyaDQuMjU4Yy4wMDktLjkwNC0uMjMtMS44ODItLjcx'
    b'NC0yLjkzNC0uNDg1LTEuMDUzLTEuMzMtMS45NjEtMi41MzQtMi43MjUtMS4yMDUtLjc2My0y'
    b'Ljg4MS0xLjE2My01LjAzLTEuMi0yLjI3LjAzNy0zLjk5Ni40MjYtNS4xNzggMS4xNjhzLTEu'
    b'OTgxIDEuNjE2LTIuMzk4IDIuNjJjLS40MTcgMS4wMDYtLjYxMSAxLjkyLS41ODUgMi43NDYu'
    b'MDY3IDIuMjU0Ljc2MiAzLjc3NyAyLjA4NSA0LjU3MSAxLjMyMy43OTQgMi44NzUgMS4zNSA0'
    b'LjY1NiAxLjY2N2wyLjI3Ny41MzJjMS4xNDMuMjQgMi4wNjQuNTM3IDIuNzY0Ljg5NS43LjM1'
    b'NyAxLjA2LjkzNiAxLjA4IDEuNzM3LS4wNTQgMS4wOTctLjUzMSAxLjgzNi0xLjQzMSAyLjIx'
    b'Ny0uOS4zOC0xLjkwMS41NTgtMy4wMDUuNTMyLTEuODgtLjA2OS0zLjEwOS0uNDkzLTMuNjg4'
    b'LTEuMjcxLS41NzktLjc3OS0uODQ3LTEuNDk4LS44MDUtMi4xNThoLTQuMjU4em0yNS4zMzcg'
    b'Mi4xNThoNy44MzVsMS4zNiA0LjM3Nmg0LjgxOWwtNy40OC0yMS4yMjhoLTUuMTE1bC03LjU2'
    b'OSAyMS4yMjhoNC42NzJsMS40NzgtNC4zNzZ6bTMuOTAyLTEyLjA2M2guMDZsMi42MyA4LjM5'
    b'N2gtNS40MWwyLjcyLTguMzk3em0xMS44NzYgOS45MDVjLS4wMzIuOTE2LjE3OSAxLjkxOS42'
    b'MzIgMy4wMDkuNDUyIDEuMDkgMS4zMzUgMi4wMzQgMi42NDggMi44MzEgMS4zMTQuNzk4IDMu'
    b'MjQ2IDEuMjE2IDUuNzk2IDEuMjU1LjY5LjAzMyAxLjY4OS0uMDk1IDIuOTk3LS4zODIgMS4z'
    b'MDktLjI4NyAyLjUxNC0uOTMgMy42MTUtMS45MjYgMS4xMDEtLjk5NyAxLjY4Ni0yLjU0MyAx'
    b'Ljc1NS00LjY0LS4wNS0xLjg2Mi0uNjE1LTMuMi0xLjY5Mi00LjAxNy0xLjA3OC0uODE2LTIu'
    b'MzY3LTEuMzc5LTMuODY2LTEuNjg5bC01LjE3NC0xLjI3YTQuMDg1IDQuMDg1IDAgMCAxLTEu'
    b'NDU2LS41NjZjLS40OS0uMjk4LS43NTMtLjg0OC0uNzktMS42NTIuMDQ4LS45NDcuNDUzLTEu'
    b'NjExIDEuMjE1LTEuOTkyYTUuMjcyIDUuMjcyIDAgMCAxIDIuNDgtLjU1YzEuODY4LjA3MyAz'
    b'LjA2Mi40ODcgMy41OCAxLjI0LjUyLjc1NS43NzUgMS40MDUuNzY2IDEuOTUyaDQuMjU3Yy4w'
    b'MS0uOTA0LS4yMjktMS44ODItLjcxNC0yLjkzNC0uNDg1LTEuMDUzLTEuMzMtMS45NjEtMi41'
    b'MzQtMi43MjUtMS4yMDQtLjc2My0yLjg4LTEuMTYzLTUuMDMtMS4yLTIuMjcuMDM3LTMuOTk1'
    b'LjQyNi01LjE3NyAxLjE2OC0xLjE4Mi43NDItMS45ODIgMS42MTYtMi4zOTggMi42Mi0uNDE3'
    b'IDEuMDA2LS42MTIgMS45Mi0uNTg1IDIuNzQ2LjA2NiAyLjI1NC43NjEgMy43NzcgMi4wODQg'
    b'NC41NzEgMS4zMjMuNzk0IDIuODc2IDEuMzUgNC42NTcgMS42NjdsMi4yNzYuNTMyYzEuMTQ0'
    b'LjI0IDIuMDY1LjUzNyAyLjc2NS44OTUuNy4zNTcgMS4wNi45MzYgMS4wNzkgMS43MzctLjA1'
    b'NCAxLjA5Ny0uNTMgMS44MzYtMS40MyAyLjIxNy0uOS4zOC0xLjkwMi41NTgtMy4wMDUuNTMy'
    b'LTEuODgtLjA2OS0zLjExLS40OTMtMy42ODgtMS4yNzEtLjU4LS43NzktLjg0OC0xLjQ5OC0u'
    b'ODA2LTIuMTU4aC00LjI1N3oiIHN0eWxlPSJmb250LXNpemU6MjhweDtmb250LXN0eWxlOm5v'
    b'cm1hbDtmb250LXZhcmlhbnQ6bm9ybWFsO2ZvbnQtd2VpZ2h0OjcwMDtmb250LXN0cmV0Y2g6'
    b'bm9ybWFsO3RleHQtYWxpZ246c3RhcnQ7bGluZS1oZWlnaHQ6MTI1JTt3cml0aW5nLW1vZGU6'
    b'bHItdGI7dGV4dC1hbmNob3I6c3RhcnQ7ZmlsbDojMDAyODY4O2ZpbGwtb3BhY2l0eToxO3N0'
    b'cm9rZTpub25lO3N0cm9rZS13aWR0aDoxcHg7c3Ryb2tlLWxpbmVjYXA6YnV0dDtzdHJva2Ut'
    b'bGluZWpvaW46bWl0ZXI7c3Ryb2tlLW9wYWNpdHk6MTtmb250LWZhbWlseTpIZWx2ZXRpY2Eg'
    b'TFQgU3RkOy1pbmtzY2FwZS1mb250LXNwZWNpZmljYXRpb246SGVsdmV0aWNhIExUIFN0ZCBC'
    b'b2xkIi8+PHBhdGggZD0ibTIyOS40ODQgNDkuOTgxLTUuNTIxLTRMMjE4LjQ1MiA1MGwyLjA5'
    b'NS02LjQ5MS01LjUyMi00LjAwNCA2LjgxNS0uMDEyTDIyMy45NCAzM2wyLjExOCA2LjQ4NCA2'
    b'LjgxOC0uMDEtNS41MDcgNC4wMiAyLjExNiA2LjQ4N3oiIHN0eWxlPSJmaWxsOiNmZmYiLz48'
    b'cGF0aCBkPSJNMjM0Ljk2NCAxOTAgMjI1IDE5Ny4wODFsLTkuOTc2LTcuMDc1IDMuODEgMTEu'
    b'NDUzLTkuOTY2IDcuMDg4IDEyLjMxOS0uMDAzTDIyNS4wMDQgMjIwbDMuODA0LTExLjQ1NCAx'
    b'Mi4zMjQtLjAwOS05Ljk2OC03LjA3NiAzLjgtMTEuNDYxeiIgc3R5bGU9ImZpbGw6IzAwMjg2'
    b'OCIvPjxwYXRoIGQ9Im0yMDIuNyAxOTAtOS45NjUtNy4wODEtOS45NzYgNy4wNzUgMy44MS0x'
    b'MS40NTMtOS45NjUtNy4wODggMTIuMzE5LjAwM0wxOTIuNzQgMTYwbDMuODAzIDExLjQ1NCAx'
    b'Mi4zMjUuMDA5LTkuOTY4IDcuMDc2TDIwMi43IDE5MHoiIGlkPSJhIiBzdHlsZT0iZmlsbDoj'
    b'MDAyODY4Ii8+PHBhdGggZD0ibTIxNS45ODEgMjQzLjU0MS00IDUuNTIxIDQuMDE5IDUuNTEx'
    b'LTYuNDkxLTIuMDk1LTQuMDA0IDUuNTIyLS4wMTItNi44MTUtNi40OTMtMi4wOTkgNi40ODQt'
    b'Mi4xMTgtLjAxLTYuODE4IDQuMDIgNS41MDcgNi40ODctMi4xMTZ6IiBpZD0iYiIgc3R5bGU9'
    b'ImZpbGw6I2ZmZiIvPjxwYXRoIGQ9Im0yMzMuMDE5IDI0My41NDEgNCA1LjUyMS00LjAxOSA1'
    b'LjUxMSA2LjQ5MS0yLjA5NSA0LjAwNCA1LjUyMi4wMTItNi44MTUgNi40OTMtMi4wOTktNi40'
    b'ODQtMi4xMTguMDEtNi44MTgtNC4wMiA1LjUwNy02LjQ4Ny0yLjExNnoiIGlkPSJjIiBzdHls'
    b'ZT0iZmlsbDojZmZmIi8+PHVzZSB0cmFuc2Zvcm09InRyYW5zbGF0ZSg2NC41MjgpIiB3aWR0'
    b'aD0iNDUwIiBoZWlnaHQ9IjMwMCIgeGxpbms6aHJlZj0iI2EiLz48dXNlIHRyYW5zZm9ybT0i'
    b'dHJhbnNsYXRlKDMyLjI2NCAtODUpIiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCIgeGxpbms6'
    b'aHJlZj0iI2EiLz48dXNlIHRyYW5zZm9ybT0idHJhbnNsYXRlKDE1MS40NzggLTExOSkiIHdp'
    b'ZHRoPSI0NTAiIGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIjYiIvPjx1c2UgdHJhbnNmb3Jt'
    b'PSJ0cmFuc2xhdGUoMTI0LjQ3OCAtMTM3KSIgd2lkdGg9IjQ1MCIgaGVpZ2h0PSIzMDAiIHhs'
    b'aW5rOmhyZWY9IiNiIi8+PHVzZSB0cmFuc2Zvcm09InRyYW5zbGF0ZSg5Ny40NzggLTE1NSki'
    b'IHdpZHRoPSI0NTAiIGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIjYiIvPjx1c2UgdHJhbnNm'
    b'b3JtPSJ0cmFuc2xhdGUoNzAuNDc4IC0xNzIpIiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCIg'
    b'eGxpbms6aHJlZj0iI2IiLz48dXNlIHRyYW5zZm9ybT0idHJhbnNsYXRlKDQzLjQ3OCAtMTkw'
    b'KSIgd2lkdGg9IjQ1MCIgaGVpZ2h0PSIzMDAiIHhsaW5rOmhyZWY9IiNiIi8+PHVzZSB0cmFu'
    b'c2Zvcm09InRyYW5zbGF0ZSgtMTIwIC04MikiIHdpZHRoPSI0NTAiIGhlaWdodD0iMzAwIiB4'
    b'bGluazpocmVmPSIjYiIvPjx1c2UgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTk2IC02NikiIHdp'
    b'ZHRoPSI0NTAiIGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIjYiIvPjx1c2UgdHJhbnNmb3Jt'
    b'PSJ0cmFuc2xhdGUoLTcyIC01MCkiIHdpZHRoPSI0NTAiIGhlaWdodD0iMzAwIiB4bGluazpo'
    b'cmVmPSIjYiIvPjx1c2UgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTQ4IC0zMykiIHdpZHRoPSI0'
    b'NTAiIGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIjYiIvPjx1c2UgdHJhbnNmb3JtPSJ0cmFu'
    b'c2xhdGUoLTI0IC0xNykiIHdpZHRoPSI0NTAiIGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIj'
    b'YiIvPjx1c2UgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoLTE0NCAtOTkuMDc1KSIgd2lkdGg9IjQ1'
    b'MCIgaGVpZ2h0PSIzMDAiIHhsaW5rOmhyZWY9IiNiIi8+PHVzZSB0cmFuc2Zvcm09InRyYW5z'
    b'bGF0ZSgtMTUxIC0xMTkpIiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCIgeGxpbms6aHJlZj0i'
    b'I2MiLz48dXNlIHRyYW5zZm9ybT0idHJhbnNsYXRlKC0xMjQgLTEzNykiIHdpZHRoPSI0NTAi'
    b'IGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIjYyIvPjx1c2UgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoLTk3IC0xNTUpIiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCIgeGxpbms6aHJlZj0iI2Mi'
    b'Lz48dXNlIHRyYW5zZm9ybT0idHJhbnNsYXRlKC03MCAtMTcyKSIgd2lkdGg9IjQ1MCIgaGVp'
    b'Z2h0PSIzMDAiIHhsaW5rOmhyZWY9IiNjIi8+PHVzZSB0cmFuc2Zvcm09InRyYW5zbGF0ZSgt'
    b'NDMgLTE5MCkiIHdpZHRoPSI0NTAiIGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIjYyIvPjx1'
    b'c2UgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTQ0IC05OS4wNzUpIiB3aWR0aD0iNDUwIiBoZWln'
    b'aHQ9IjMwMCIgeGxpbms6aHJlZj0iI2MiLz48dXNlIHRyYW5zZm9ybT0idHJhbnNsYXRlKDEy'
    b'MCAtODIpIiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCIgeGxpbms6aHJlZj0iI2MiLz48dXNl'
    b'IHRyYW5zZm9ybT0idHJhbnNsYXRlKDk2IC02NikiIHdpZHRoPSI0NTAiIGhlaWdodD0iMzAw'
    b'IiB4bGluazpocmVmPSIjYyIvPjx1c2UgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoNzIgLTUwKSIg'
    b'd2lkdGg9IjQ1MCIgaGVpZ2h0PSIzMDAiIHhsaW5rOmhyZWY9IiNjIi8+PHVzZSB0cmFuc2Zv'
    b'cm09InRyYW5zbGF0ZSg0OCAtMzMpIiB3aWR0aD0iNDUwIiBoZWlnaHQ9IjMwMCIgeGxpbms6'
    b'aHJlZj0iI2MiLz48dXNlIHRyYW5zZm9ybT0idHJhbnNsYXRlKDI0IC0xNykiIHdpZHRoPSI0'
    b'NTAiIGhlaWdodD0iMzAwIiB4bGluazpocmVmPSIjYyIvPjwvc3ZnPg==', 'US_AR')

US_AR = b64_US_AR
index.append("US_AR")
index.append("United States of America Arkansas")
catalog["US_AR"] = US_AR
catalog["United States of America Arkansas"] = US_AR
country["United States of America Arkansas"] = ('US_AR', '', 1)
lookup["US_AR"] = ('US_AR', '', 'United States of America Arkansas', 1)
lookup["Little Rock United States of America Arkansas"] = ('US_AR', '', 'United States of America Arkansas', 1)
lookup["United States of America Arkansas"] = ('US_AR', '', 'United States of America Arkansas', 1)
details["US_AR"] = {"continent":"Americas","capital":"Little Rock","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_AR"] = ('US_AR', 'United States of America Arkansas', 1)
regional["United States of America Arkansas"] = ('US_AR', 'United States of America Arkansas', 1)
#----------------------------------------------------------------------
b64_US_AS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWFzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iIzAwNiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDBaIi8+CiAgPHBhdGggZmlsbD0iI2JkMTAyMSIgZD0ibS0uNiAyNDAgNjQw'
    b'LTI0MHY0ODBaIi8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTU5LjcgMjQwIDU4MC0yMTQu'
    b'M3Y0MjguNiIvPgogIDxwYXRoIGQ9Ik00NzQgMjcwLjRjNS4xLjMgNSA1LjQgNSA1LjRsMTgg'
    b'LjRjMi4zLTYuMyA0LjgtNS42IDkuMi0yLjRhMzIuOSAzMi45IDAgMCAwIDguNyA0LjJjMS43'
    b'LTkgMTQuNS03LjIgMTQuNS03LjIgNS42LTEzIDYtMTIuOSAyLjctMTQuNWExMC43IDEwLjcg'
    b'MCAwIDEtNC42LTQuNWMtMy0zLjctNC42LTkuMS01LTEyLjQtLjQtMy4zLTQuMiAxLjYtNSAu'
    b'Ni0uNi0xLTYuMy0uNC02LjMtLjQgMS40IDEuNS0zLjQuNi0zLjQuNi41LjQgMCAxLjcgMCAx'
    b'LjctLjQtLjYtNC4xLTEuMi00LjEtMS4yYTYuMSA2LjEgMCAwIDEtMS4xIDEuNmMtMi0uOC02'
    b'LS43LTYtLjdhMjAgMjAgMCAwIDAtMTAuOSAyLjhjLTEuNi45LTcuNCAzLjgtMTIuMyA4LjUt'
    b'NC43IDQuNi03LjQgNC03LjQgNC0xLjQgNS4yLTEyLjggMTEuNS0xMi44IDExLjUtMS44IDEu'
    b'Ni03LjYgMi40LTEwLjUgMC0yLjktMi40IDAtNi45IDAtNi45IDEuMi0yIDIuMi0xLjkgMi4z'
    b'LTkgLjEtNC43IDUtOC41IDEwLTE0IDYuMy02LjggMTUtMTggMTUtMTggMCAzLjQgMS44IDQg'
    b'MS44IDQgMS43LTMuNSA0LjItNi4zIDQuMi02LjMuMS4zLjUuNC41LjQgMi0yLjYgMy0zLjYg'
    b'My0zLjYtLjUtLjMtNiAwLTExIDQuNHMtOC40IDMtOC40IDNjLTMuNS0xLjItMy44LTQtMy44'
    b'LTQtMi41LTEwLjkgNy40LTE4LjcgNy40LTE4LjctMTMuNC0zLjItMy43LTIwLjMgMTMtMjcu'
    b'NSAxNi42LTcuMiAxNi40LTEwLjUgMTYuNC0xMC41YTEzIDEzIDAgMCAxIDEuOCAzYy4xIDAg'
    b'MS40LTEuOSAxMS02LjEgOS42LTQuMyAxNC4yLTggMTQuMi04IDEuMiAyLjQgMSA0IDEgNCAy'
    b'Ni4zLTkuMSA1Mi0zMC4yIDUyLTMwLjIuOCAxLjcuNSA0LjQuNSA0LjQgNC4yLTQgMTkuNy0x'
    b'My4yIDE5LjctMTMuMmE4LjYgOC42IDAgMCAxLTQuNiA4LjIgNy43IDcuNyAwIDAgMSAuOCAy'
    b'LjMgMzYwIDM2MCAwIDAgMCAxNC40LTkuNWM0LjMgMy43LjQgOS44LjQgOS44IDEuNi0uMyAy'
    b'LjYtMS42IDIuNi0xLjYgMS4yIDYuNC01LjkgMTItNS45IDEyIDEuMyAwIDMuMy0xLjMgMy4z'
    b'LTEuMy0xLjMgNy0xNC40IDE0LjYtMTQuNCAxNC42IDEuOSAxLjggMCA0LTEuNiA1LTEuNSAx'
    b'LTQuMyAzLjMtMy40IDQuMi44IDEgNi43LTMuMiA2LjctMy4yIDEgMi45LTYuNSA4LjYtNi41'
    b'IDguNiA1LjIuNyAxOS42LTUuOSAxOS42LTUuOS0xLjEgNS42LTYuNiAxMC0xMy4zIDEyLjUt'
    b'Ni43IDIuNS02LjQgMy02LjQgMyAxLjIuOCAxMC41LTEuOCAxMC41LTEuOC0yLjggNi4yLTEy'
    b'LjUgMTAuNS0xMi41IDEwLjUgMi43IDIuMyA2LjMtLjQgMTAtMi45YTU4LjIgNTguMiAwIDAg'
    b'MSAxNC02LjRjNS4zLTEuOSA5LjItLjUgOS4yLS41YTEyIDEyIDAgMCAxIDguNC42YzguNy43'
    b'IDkuNiAzLjkgOS42IDMuOSAxIC4yIDEuNy42IDQgMi4zIDIuMSAxLjYgMiA2LjYgMiA5LjIt'
    b'LjIgMi40LS45IDIuNC0xLjMgMy0uNC44LS41IDEuNi0uNSAyLjUgMCAxLTIuMiA2LjktMTUu'
    b'NyA2LjloLTIwLjNjLTEuMiAwLTIuNS43LTIuNS43LTUuNyAyLjgtMi43LTItOS40IDMuNi02'
    b'LjggNS41LTEwLjIgNC42LTEwLjIgNC42QTkwLjEgOTAuMSAwIDAgMSA1NjggMjIxYy00IDIu'
    b'Ni0zLjMgMi4zLjMgMy44czguOCAwIDguOCAwYy0zLjQgMi4zLTEgMy40LTEgMy40IDQuNC0y'
    b'LjcgNy4yLTEuNyA3LjItMS43IDEuNCAzLjktMy44IDEwLTMuOCAxMCAyIC4zIDUuOCAwIDUu'
    b'OCAwLTEgMi43LTQuNiA1LjYtNy40IDYuNC0yLjcgMS0yLjMgMS4zLTEuNCAzIC43IDEuNi4x'
    b'IDMuMy4xIDMuMy00LjgtMy4zLTUtLjQtNS0uNC0uNSA0LS40IDkuNi0uNCA5LjYtMy40LTEu'
    b'Ny0zLjUuNS0zLjUuNS0xIDMuNi01LjEgNy43LTUuMSA3LjctLjItMi4yLTIuMi0yLjgtMi4y'
    b'LTIuOC0yLjIgNC4yLTYuMSA2LjctNi4xIDYuNy0uNSAzLjUuNSA4LjYuNSA4LjYtMi42LS42'
    b'LTMuNS0uNi00IDAtLjMuNy42IDEgLjYgMWwzMy40LjhjLjUgMCAyLjUuMyAyLjUgMy44IDAg'
    b'My43LTMgMy45LTMgMy45bC0zNi40LS45cy4xIDEtMS44IDItMS4yLTEuMS0xLjcgMy40Yy0u'
    b'NiA0LjQtNy44LS40LTcuOC0uNC0xLjIgMS44LTQgNC00IDQtMS43LTUtMy40LTYuNC02LTIu'
    b'Mi0yLjYgNC4zIDQuOCAzLjYgNC44IDMuNnM0Mi44LTYuMyA0NS4xLTYuNWMyLjMtLjMgNC45'
    b'LS4xIDYgMy4xIDEgMy4zLTUuMyAzLjgtNS4zIDMuOGwtNDQgNC44Yy0uOSAyLjYtNC41IDIu'
    b'NC00LjUgMi40LjMgMi41LTIuMyA0LTMuNiA1LTEuNC44LTUuNi41LTUuNi41LTUgMy40LTcu'
    b'Ni43LTcuNi43LTMuMyAxLjQtNS40LjgtOC4xLS40LTIuOC0xLjItMi41LTQuNS0yLjUtNC41'
    b'bC0yNy44IDNhNi43IDYuNyAwIDAgMC0yLjIgMS4yYzEgMS4zLTIgNC4zLTIgNC4zLjkuNSAy'
    b'LjUgMi4xIDIuNyA1LjUuMiAzLjctNC41IDQuMy0yLjIgNyAyLjMgMi41IDYuNy4zIDExLjUt'
    b'MnM5LjUtMiAxMS41LTIgNy44IDEuNiAxMS40IDIuOGMzLjYgMS4yIDQuOC40IDUtMS40LjIt'
    b'MS43IDEuOS0yLjMgMS45LTIuMy0uNSAxLjguNSAyLjYuNSAyLjZhMTEgMTEgMCAwIDAgMy43'
    b'LTEuM2MtLjIgMS40LTIgMi4yLTIgMi4yLTMuNCAyLjMgMS40IDEuNSAxLjQgMS41YTQ0IDQ0'
    b'IDAgMCAxIDE1LjQtMS41IDEyMi41IDEyMi41IDAgMCAxIDE0LjMgNS4yYy40LTEuMi4xLTQg'
    b'LjEtNCAzIC44IDQuMiAyLjUgNC4yIDIuNSAxLjItMS4yLjQtMy40LjQtMy40IDkuNyA1LjUt'
    b'MiA4LTUuMSA5LTMgMS0zIDIuMy0zIDIuM2EyOCAyOCAwIDAgMSA2LjQtMS4zYzIuMi0uMiAx'
    b'LjQgMCA2LjUtMSA1LjItMSA3LjggMS4yIDcuOCAxLjItNC4zLjItNS41IDEuNS01LjUgMS41'
    b'IDIuNiAxLjcgMCAzLjQgMCAzLjQtMy44LTUtNy4yLjEtNy4yLjFhMTUuMyAxNS4zIDAgMCAx'
    b'IDYuNCAxLjRsNS40IDIuN2MzLjYgMS42IDIuOS42IDUuNiAxLjYgMi44IDEgMS43IDMuNyAx'
    b'LjcgMy43YTYuOCA2LjggMCAwIDAtMy43LTNjLS4yIDMtMy4xIDMuNS0zLjEgMy41IDMuNi00'
    b'LTQuMS01LjgtNy44LTUuNy0zLjYgMC02LjMgMi40LTYuMyAyLjQgNy4zIDYuOSAxMi4zIDQu'
    b'NiAxMi4zIDQuNi0uOSAyLjUtNi45IDEuNS02LjkgMS41IDIuOCAyLjIgMi41IDMuNiAyLjUg'
    b'My42LTEuNS0xLjQtNC0uNy05LjItNC01LjItMy41LTkuOS0yLjMtOS45LTIuMyA1LjIgNS4z'
    b'LTEuOCA4LjYtMS44IDguNi0yLjYgMS42IDEgMy41IDEgMy41LTMuMi42LTMuNi0yLjYtMy42'
    b'LTIuNi0xLjctLjQtNC4yIDEuNi00LjIgMS42LjItMy4yIDQuNi0xLjYgNC42LTUgLjItMy41'
    b'LTQtNi4yLTE2LjMtNC41LTEyLjQgMS43LTE2LTIuMi0xNi0yLjItMSAwLTEuMiAxLTEuMiAx'
    b'IDIgMiAyLjkgMi44IDIuNiA0LjItLjQgMS4zLjYgMS44LjYgMS44LTIuMy0uMi0yLjQtMi44'
    b'LTIuNC0yLjggMCAxLjEtLjUgMS4yLTEuMyAyLjNzMCAyLjcgMCAyLjdjLTEtLjgtMi43LTEu'
    b'OC0xLTQuMyAxLjItMS44LTIuNy00LjItMi43LTQuMi0xLjUtMS41LTUuNiAwLTUuNiAwYTE0'
    b'LjkgMTQuOSAwIDAgMS0xMy4zLTMuN2MtMSAwLTIuOS0uNi0yLjktLjYtOC45IDQtMTYuNy00'
    b'LjYtMTYuNy00LjYtNi43IDEuMy05LjgtMi0xMS44LTUuMmExMS41IDExLjUgMCAwIDAtNS4y'
    b'LTVjLTIuNi0xLjYtNS4yLTYuMi0yLjYtOC43IDItMi4xIDEuNS0yLjYgMS41LTIuNi0zLjUt'
    b'NS45IDYuMS03LjcgNi4zLTkuMi4zLTIgMi4zLTMuMyA0LjUtMy40IDIuMi0uMiAyLjIgMCAz'
    b'LjctMS40IDEuMy0xLjUgNCAuMyA0IC4zLjctLjQgNS41LTQuMSA5LjctMi4yIDQuMyAxLjkg'
    b'Ny45LjYgNy45LjYgMy0uNyAyOC00IDI4LTQgMS41LTIuNSAyLjctNS40IDkuNi03czEyLTYg'
    b'MTItNmMtMS4yLTEuMi0zLjItMS4yLTQuMi0xLjMtMS4xIDAtMy4yLTItMy4yLTItMS4zLjYt'
    b'MiAuMy0xMSA1LjgtOC4xIDUtOC4zLTQuOC04LjMtNC44SDQ3OWMtLjMgMy43LTMgNS4yLTMg'
    b'NS4ybC02LjUuM2MtMy42LTEuOC0zLjYtOC4yLTMuNi04LjItMTkuNC4zLTMwLjEgNy4yLTMw'
    b'LjEgNy4yLTIyLTExLjItMzkuMi0xMy44LTM5LjItMTMuOGExMjIuNCAxMjIuNCAwIDAgMCA0'
    b'MC44LTEwLjIgNjMuMyA2My4zIDAgMCAwIDI4LjUgOWMuNS01LjQgNC4xLTYuNyA0LjEtNi43'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik00NDIuMyAzMTQuNmMtNS41IDMuMi00'
    b'LjUgNS00IDZzLjUgMi0xIDMuNmMtMS41IDEuNS0xLjQgMi0xLjQgMiAuMyA1LjQgNCA2LjYg'
    b'NS43IDggMS40IDEgMy42IDQuNSAzLjYgNC41IDIuOSA0LjEgNS45IDQuMiA4LjEgNC4yIDIu'
    b'MyAwIDItLjMgMS0xLjNsLTMuNC0yLjdhMTcuNiAxNy42IDAgMCAxIDUuOSA0LjFjNS42IDYu'
    b'MiAxMC44IDUuNCAxMy4xIDUuMiAyLjMtLjMgMi0xLjcgMi0xLjdhOSA5IDAgMCAwLTIuNC0u'
    b'NGMtOC41LS44LTExLTYuNC0xMS02LjRhMjQuMSAyNC4xIDAgMCAwIDE1LjYgNmMyLjQtLjEg'
    b'Mi4zLjYgMS43LjhsLTIuNC0uMmMtMS4xIDAtMS4xLjMtLjkuOC4zLjQgMS40LjQgMi43LjQg'
    b'MS40IDAgLjMuMSAzLjggMi44IDMuNiAyLjggMTIuMy41IDEyLjMuNS01LjctMS4zLTYuNC00'
    b'LTYuNC00LTcuNyAxLTEwLjgtMy42LTEwLjgtMy42YTMyLjUgMzIuNSAwIDAgMC01LjYtMy41'
    b'IDguOSA4LjkgMCAwIDEtNS01LjhjMS4zIDEuOCAzLjcgMy44IDYuNyA0LjYgMyAuOCAzLjgg'
    b'MS4yIDMuOCAxLjJhMy44IDMuOCAwIDAgMS0yLjMtLjJjLTMtMS0xLjMuMy0xLjMuMyAzLjQg'
    b'Mi43IDQuMyAyLjUgNC4zIDIuNSA4LjYuOSA0LjMtMi42IDQuMy0yLjYgNi4yIDEuNSA3LjIt'
    b'LjggNy4yLS44IDEuMyAyLjcgNiAxLjcgNiAxLjctNi4yIDMtMS41IDIuMS0xLjUgMi4xIDYu'
    b'My0xLjEgNy42LjUgNy42LjUgMS42IDEuNSAzLjQgMS40IDMuNCAxLjRzMS4yIDAgMy41LjRj'
    b'Mi40LjUgNi4yIDIuNSA5LjYgMi4yIDMuNS0uNSA0IC42IDQgLjYtLjYtLjMtMi4yLS41LTQu'
    b'OC43LTIuNyAxLjMtNy40IDEuNi0xNC4yIDBzLTcuNC0xLjMtNy40LTEuM2E4LjcgOC43IDAg'
    b'MCAxIDMuNCA0Yy4zIDEuMiAxLjUgMS4yIDEuNSAxLjIuNS0xLjUgMi41LTIuMSAyLjUtMi4x'
    b'YTI3IDI3IDAgMCAwIDUgMi44Yy40LS43IDAtMS4zIDAtMS4zIDIuNiAyLjUgNS42IDEuNyA1'
    b'LjYgMS43LjgtLjUuNi0yIC42LTIgMSAwIDEuMi42IDIgMS4yLjcuNCAzIC4xIDMgLjEtLjgt'
    b'LjQtMS41LTEuNy0xLjUtMS43IDMuNS0yLjMgMTEtMS4zIDExLTEuMyA1LjMgMSA0LjcgNC41'
    b'IDQuNyA0LjVhMTAgMTAgMCAwIDEgMi41IDIuMWMuNS0xLjIgMC0yLjUgMC0yLjUgMi42IDEu'
    b'MiAzIDQgMyA0IDMtMy4yLTIuNy02LjgtMi43LTYuOCAyLjctLjQgNS43LS4yIDcuNSAwYTEz'
    b'LjggMTMuOCAwIDAgMSA2LjYgMy4xYzIuMSAxLjcgNS45IDIuNSA1LjkgMi41LS4xLS43LTIu'
    b'Mi0yLTIuNy0yLjItLjQtLjItLjYtLjktLjYtLjkgMS45LjQgMy4xLjIgMy4xLjItNi40LTQt'
    b'OC4xLTUuOS04LjEtNS45IDIuNC4zIDMuOC0xLjIgMy44LTEuMi01LjEgMC01LjQtMS4yLTUu'
    b'NC0xLjIuNy4xIDMuMS43IDYuMi4xczcuMiAwIDcuMiAwYy0yLjItMy42LTEwLjctMy0xMy41'
    b'LTIuOC0yLjguMi0zLjgtLjItMy44LS4yLjQtLjIuOS0uNiAzLS43IDIuMiAwIDQuMy4yIDYu'
    b'OC0xLjYgMi4zLTEuNiA1LjctMSA1LjctMS0uOC0xLjYtNC43LTIuMi04IDAtMy41IDIuMS02'
    b'LjUgMS41LTYuNSAxLjUgNS4zLS44IDYuOS0yLjcgNi45LTIuNy0xLjYtLjQtMi41LjEtNS44'
    b'LjgtMy4yLjYtNC0uNS00LS41IDMuNS0yLjEgNi0zIDYtMy0zLS42LTUuOC0yLTUuOC0yLTMu'
    b'MiAzLTUuNiA0LjYtMTEuNyAxLjYtNi0zLjItOS4yLTIuOC05LjItMi44YTE0LjIgMTQuMiAw'
    b'IDAgMSAxNC44LjZjNCAyLjMgNSAuNCA1IC40LTEuMi0uNy0xLTEuNS0xLTEuNSA5LjYgNC45'
    b'IDEzLjggMiAxNS45LjUgMi4xLTEuNS0xLTMuNC0xLTMuNC0uMiAzLTQgNC42LTcuMiAzLjUt'
    b'My0xLTYtMi40LTEwLjQtNC4zLTQuNC0xLjgtMTAtLjgtMTUuMS4yLTUuMiAxLjEtNS45LjYt'
    b'Ni40LjItLjUtLjQtLjctMS43LTMuNC0uNi0yLjYgMS4xLTguOC0xLjgtMTIuNi0yLjctMy44'
    b'LTEtMTAuMS0uNS0xNS41IDIuNS01LjQgMy4xLTguMiAyLjMtOS44IDEuNi0xLjYtLjgtMi43'
    b'LTIuOC0uOS00LjZzMi0yLjMgMS44LTVjLS4yLTIuNi0yLjgtNC4yLTIuOC00LjIgMi40LTIu'
    b'NSAzLTMgMi4yLTQtLjgtMS4yLjQtMS4yIDEuOC0xLjggMS40LS42LjgtLjcuNS0xLjUtLjQt'
    b'LjgtMS4yLS42LTEuMi0uNi0zLjEuMS00LjktLjgtNC45LS44LTUuMi0yLjQtMTAuMSAyLjMt'
    b'MTAuMSAyLjMtMy0yLjMtMy43LS43LTQuMi0uMi0uNS41LTEuNiAxLTMgMS0xLjIuMi0zLjEu'
    b'Ny0zLjggMS45IDAgMC0uNiAxIC4xIDIgMCAwIC44IDEuMi0uNiAyLjctMS41IDEuNS0yIDEu'
    b'OC0xLjUgMy4zLjQgMS4zLjMgMi40LS4zIDMuMyAwIDAtLjctLjctLjUtMS43LjItMSAuMi0x'
    b'LjYgMC0yIDAgMC0xLjUgMS40LTEuOCAyLjQgMCAwLS42LTEuNiAxLjYtMy43IDItMiAzLTMu'
    b'MiAyLjQtNC0uNC0uNi0yIC40LTIuMy42eiIvPgogIDxwYXRoIGQ9Ik00NDguNCAzMzhzLTIu'
    b'Ny0yLTIuNC00LjljLjMtMi43LjMtMyAwLTMuNyAwIDAtLjUuMy0uNCAxLjQgMCAxLS4yIDIu'
    b'MS0uMyAyLjMgMCAwLTEuMy0yLjMtMi0yLjggMCAwIC42LTIuNC0uMi0zLjQtLjctMS4xLTEu'
    b'NS0xLjItMi40LS44LTEuMi40LTIuMSAxLjUgMiA0LjggMCAwIDEuNSAxLjMgMi41IDMuOSAx'
    b'IDIuNiAyLjggMyAzLjEgMy4yem0xMy03LjhzLS4xLTEuNSAxLjMtNC4zYTYuMSA2LjEgMCAw'
    b'IDAgLjMtNS42Yy0uMy0uOC0uNi0uNS45LTEuNyAxLjctMS41LS43LTMuNCAyLjMtNiAwIDAg'
    b'MS44LTEuNiAyLjMtMi4zIDAgMC0zIDEuNi01LjIgMi41LTIgLjgtOS42IDQuNi04IDcuMSAx'
    b'LjggMi41IDEuNiAyLjcgMS4zIDMuOCAwIDAtNC42LTIuNS0zLTYuNCAwIDAgLjgtMS41IDIu'
    b'Ny0zLjQgMS44LTEuNi44LjQgNC4zLTEuNyAwIDAgMi43LTEuNiA0LjMtMy45IDAgMC0yIDEu'
    b'Mi0yLjYgMS40IDAgMC00IC44LTUuOCAyLjUtMS42IDEuNy01LjEgNC43LTQgOCAwIDAtNC0u'
    b'NC01LTQuNyAwIDAtNy42IDkuNCA4LjQgMTMuOCAwIDAgMyAuOCA1LjYgMXoiLz4KICA8cGF0'
    b'aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTMxLjYgMjk5YzYtMSA0MC40LTYuMiA0My42LTYuNSAz'
    b'LjQtLjMgNC43LS44IDUuOSAyIDEuMyAzLTQuOCAzLjEtNC44IDMuMWwtNDEuMSA0LjdjLTIg'
    b'LjItMi41LS42LTIuNS0uNmwtMS41LTJzLS41LS42LjQtLjh6Ii8+CiAgPHBhdGggZmlsbD0i'
    b'IzVhMzcxOSIgZD0iTTQ0Ny4zIDMxNy43cy00LjQgOS4zIDEzIDExLjZjMCAwIC4xLTEgLjgt'
    b'Mi41LjgtMS41IDIuMy00LjUuOC02LjQtMS40LTEuOSAxLjItLjkgMS41LTMuNC41LTIuNS0u'
    b'Mi0yLjIgMS0zLjggMCAwLTUuNCAyLTcuNiA0LjUtMiAyLjQgMi45IDQuMiAwIDYuOSAwIDAt'
    b'Mi41LTEtNC0zLjYgMCAwLTMuMyAwLTUuNS0zLjN6Ii8+CiAgPHBhdGggZD0iTTQ2NC41IDMy'
    b'OS4yczQuMyAzLjcgOS40IDMuNmM1LjEtLjMgNy40LTEuNiA4LjctMy42IDAgMCAxIDEuNSAx'
    b'IDIuNiAwIDAgNC40LTMuNyAxMi0uNXM1LjQgMi4zIDcuMSAyLjVjMCAwLTMuMy0uNS0xMC43'
    b'IDIuOS03LjcgMy41LTI3LjcgMi4zLTI3LjYtNy41eiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3'
    b'MTkiIGQ9Ik00NTcuMyAzMTIuNnMxLjkuMyAzLjgtMS45YzAgMC0yLjYuNS0zLjggMnpNNDQy'
    b'LjYgMzMwcy0zLjYtMi44LTEuMy0zLjRjMCAwIDEuNy0uMyAxLjMgMy40eiIvPgogIDxwYXRo'
    b'IGQ9Ik01MjEuMiAzNDcuOHMyLTMuNSA3LjUtMy41IDYuMSAyLjYgMTMuMSAzYzAgMC04LjQg'
    b'Mi40LTE0LjIuMy0zLTEuMS01LjgtLjItNi40LjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcx'
    b'OSIgZD0iTTQ2Ni4zIDMzMS43czguNCA1IDE1LjctLjVjMCAwIC42LjYgMS4yIDIgMCAwIDUu'
    b'Ni01LjQgMTUuNS40IDAgMC0xLjItLjEtNS45IDEuOC02LjEgMi43LTIxLjQgNC41LTI2LjUt'
    b'My44eiIvPgogIDxwYXRoIGQ9Ik00OTguMyAzMzYuN3M4IDEgMTQuNy42YzQuMS0uMiA4LjYt'
    b'MSA2LjQuNC0yLjMgMS4zLTEuMSAxLjUgOC40LjcgOS40LTEtLjEgMS43IDYuNCAyLjYgMCAw'
    b'LTE1LjkgOC0zNS45LTQuM3oiLz4KICA8cGF0aCBmaWxsPSIjNWEzNzE5IiBkPSJNNTE5LjIg'
    b'MzMxLjdzNC42LTEuNyA5IC4zYzQuMyAyIDMuNiAyLjIgNi41IDIuNSAwIDAtMiAyLjktNi43'
    b'LjYtNC44LTIuMy02LTIuOC04LjgtMy40em01LjIgMTQuM3M0LjYtMi4zIDkuNiAwYy42LjQg'
    b'MiAxIDMuMyAxLjIgMCAwLTMuOCAxLjMtNy44IDAtMS43LS41LTMtLjktNS4xLTEuMnptLTIy'
    b'LjctOC4yczEwLjMgMSAxNS44LS4xYzAgMC02LjQgMyA5LjcgMS43IDAgMCAzLjUtLjQgMyAu'
    b'MS0uMy41LS42IDEgMS4yIDEuNSAwIDAtMTIgNS40LTI5LjctMy4yeiIvPgogIDxwYXRoIGQ9'
    b'Ik00NTAuNyAzMjkuMnMuMi43IDIuNCAxLjdhOC43IDguNyAwIDAgMSA0IDMuOSA1LjYgNS42'
    b'IDAgMCAwIDMuNSAyLjlzLTggMS43LTExLjYtMi42YzAgMC0yLjctMyAxLjYtNiIvPgogIDxw'
    b'YXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik01MTMuNyAzNDcuNnMtMy4xLS4yLTcuNS0xLjdjLTQu'
    b'My0xLjUtNS40LS4yLTcuOS0yLTIuNC0xLjktNy4zLS43LTguMi0uNi0xIC4xLTMuNiAwLS4z'
    b'LTIuMSAwIDAtMi42IDAtMy42LTEuNCAwIDAtMS4yIDEuMi01LjYuOCAwIDAgMiAzLTYgMi4x'
    b'YTEwLjMgMTAuMyAwIDAgMCAxMS4xIDNjMCAuMi0uNSAyLjUgMyAzLjUgMy44LjkgNC41IDEu'
    b'NiA2LjQgMi4zIDAgMCAuMy0xLjUtNC42LTUgMCAwIDIuNi0uMiA2LjQuN3MxMi4yIDMuMSAx'
    b'Ni44LjR6bTIgMy43cy44IDEuOCAzLjIgMS40YTE3IDE3IDAgMCAxIDEwLjIuOHMuNy0zLjIt'
    b'Ny0zLjRjMCAwLTQuOC4yLTYuNCAxLjJ6bS02NS4yLTIxcy0zIDIuNS0uMyA1YzIuNCAyLjMg'
    b'Ni4yIDIuMSA4IDIgMCAwLTEtLjYtMi0yLTEtMS41LTEtMi41LTMtMy40LTIuMS0uOS0yLjMt'
    b'MS4xLTIuNy0xLjZ6bS0zLTEyLjZzLTQuNiA5LjMgMTMgMTEuNmMwIDAgMC0xIC43LTIuNS42'
    b'LTEuNSAyLjEtNC41LjgtNi40LTEuNi0xLjkgMS4xLS45IDEuNS0zLjQuNC0yLjUtLjMtMi4y'
    b'IDEtMy44IDAgMC01LjUgMi03LjcgNC41LTIgMi40IDIuOSA0LjIgMCA2LjkgMCAwLTIuNS0x'
    b'LTQtMy42IDAgMC0zLjMgMC01LjUtMy4zeiIvPgogIDxwYXRoIGQ9Ik00OTMuMyAzMzkuM3Mz'
    b'LjctLjYgMTMgMi45YzkuNCAzLjQgMTMuMyAyLjYgMTQuNiAyLjUgMCAwLTUuMiAyLjgtMTMu'
    b'NC0uOC03LjItMy4yLTcuNi0yLTE0LjItNC42eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEi'
    b'IGQ9Ik01NTEuOCAzMzcuMnMyIDAgMy40LjVjMCAwIC43LS43IDIuNy0xIDAgMC0xLjMtMS4y'
    b'LTYuMS41em0tNi40LTUuMnMyLjEgMCAyLjgtMS4yYzAgMC0xLjEtMS4zLTIuOC0yIDAgMCAu'
    b'NCAxLjYgMCAzLjJ6bS03MS43LTIzLjhzLS41LTEgMS44LTEuNGwzMS4zLTQuNXMxLjUgMCAx'
    b'LjcgMWMuMyAxLjEtLjEgMS45LTcuMiAyLjdsLTI1LjYgMy4ycy0xLjkuMy0yLTF6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmYzIyMSIgZD0iTTUwMiAzMDYuOXMwIDQuMSA0LjIgNC43YzQgLjYg'
    b'NS41LS4yIDYuNS0yLjMuMy0uNyAxLjYtNS0uMi01LjMtLjgtLjEtMiAwLTIuOS4zLTEuNC43'
    b'LTIuNyAxLjQtMi4zIDIgMSAxLjYgMS4yIDIgMSAyLTEuMi4zLTEuOC0uNi0yLTEuMi0uMy0u'
    b'OC41LTEuMi0yLjItLjgtMS4yLjEtMiAuMS0yIC42em0xNy41LTMuMmMyIC4zIDEuOSA0Ljgt'
    b'LjYgNi45LTIuOCAyLjItNS40IDEuMy01LjQgMS4zLTEuNC0uNS0xLjItLjQtLjEtMiAxLTEu'
    b'NSAxLjUtMy42LjktNS0uMi0uNS4zLS45IDEtMSAwIDAgMi0uNCA0LjItLjJ6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iI2ZmYzIyMSIgZD0iTTUyMS4zIDMwNC4xczEuNiAyLS40IDUuNWMwIDAtLjgg'
    b'MSAxLjEuOSAxLjgtLjIgNi4xLTIuMiA1LjctNC44IDAgMC0uMi0uNi0xLjMtLjZzLS4yLS41'
    b'LjMtLjhjLjQgMCAxLjktLjYtMS45LTMgMCAwLS42LS42LTEuMy0uMy0uNi4yLTIuNiAxLTIu'
    b'NiAyLjIgMCAuNS40IDEgLjQgMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTI1'
    b'LjQgMzAwLjlzMyAyLjEgMyAyLjhjMCAuNi0uMyAxLjUuNSAxLjMuOCAwIDQtLjcgMy0yLjgt'
    b'LjgtMi4xLTEuNy0zLTMuMi0zLjQtMS41LS42LTEuOS4xLTMuMiAxLjEgMCAwLS45LjYtLjEg'
    b'MXptLTE2LjEgM3MuNS0xLjUtMi4yLTIuMmMwIDAgMS4xLTEgMy40LS40IDIuMi40IDIgMiAy'
    b'IDIuMSAwIDAtMS44IDAtMy4yLjV6bTUuOC0uNHMzLS41IDQuNS0uNGMwIDAtMS42LTMuMy01'
    b'LjctMi4zIDAgMCAxLjUgMS44IDEuMiAyLjd6bTUuMy0uOHMwLTEuMSAyLjYtMi4xYzAgMC0x'
    b'LjItMS4yLTMtMS0yIDAtMi41LjctMi41LjdzMi4zLjggMi45IDIuNHptMS0zLjZzMS43LjQg'
    b'Mi43IDEuM2MwIDAgMS41LTEuNyAyLjgtMiAwIDAtMi41LTEuNC01LjUuN3oiLz4KICA8cGF0'
    b'aCBmaWxsPSIjNWEzNzE5IiBkPSJNNDM1LjggMjkwLjlzNy4yLTYuMiAxMS4yLTUuNGM0IC44'
    b'IDIgLjIgNi40LS41IDQuNC0uNiA5LTEuMSAxMC44LS45IDAgMC01LjQtMy44LTE0LjktMy43'
    b'IDAgMC02LjYgMi4zLTExLjMgNS4zIDAgMC04LjktNC45LTE4LTIgMCAwIDkuOSAzLjcgMTUu'
    b'OCA3LjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmYzIyMSIgZD0ibTUxMi4yIDMwMS40IDEuMi0u'
    b'MnMyIDIuNS42IDIuNWMtMS4yIDAtLjgtLjMtMS0xYTIuMyAyLjMgMCAwIDAtLjgtMS4zem0t'
    b'OSAuMnMtLjggMSAuNi44YzEuNy0uMyAxLjQgMCAzLjEtMS4zIDAgMCAxLjItMS4xIDMuMi0u'
    b'NCAwIDAgMS44LjYgMy4yLS4xIDEuNC0uOCAxLjctLjcgMi41LS42LjggMCAuOC4yIDEuNy0u'
    b'NiAxLS43IDIuOC0uMSAzLjktMSAxLjEtMSAyLjUtLjIgMC0yIDAgMC0uNS0uNS0uNS0xIDAg'
    b'MCAxIC40IDEuOCAxIC44LjggMiAuNSAyLjIuNCAwIDAgLjItMi4zIDIuMy00LjMgMi4zLTIg'
    b'Mi4zLTIuMiAxLTIuMnMtMy41LS42LTQuMyAwLTcuMiA0LjgtMTEgNS41Yy0zLjguNy03LjMg'
    b'MS44LTkuNyA1Ljh6bS0xMDEuMy0yMy40czExLjcgMyAxNC4zIDQuMmMwIDAgLjYtMS45LTQu'
    b'Ny0zLjQgMCAwIDEyLjktLjQgMjYuNCA1LjggMCAwIDYuNi01LjYgMjcuNy0zLjkgMCAwIDAt'
    b'MS44LjItMy4zIDAgMC0xNC44LS40LTI4LjQtOC43IDAgMC0xMi4zIDYtMzUuNSA5LjN6bTY0'
    b'LjcgNS42Yy0uNy0xMS44IDMuOC0xMyAzLjgtMTNzMi4xIDAgNC40LjVjMCAwLTMuNiA0LjMt'
    b'Mi42IDEyLjggMCAwIC40IDEuMy0yLjcgMS4zcy0yLjktMS41LTIuOS0xLjV6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzVhMzcxOSIgZD0iTTQ2OS44IDI5MS43cy0yLjMtMi4zLTIuNS00LjljMCAw'
    b'IDAtLjYgMi4yLS42IDIuMyAwIDIuNS0uMiAzIDEuMS42IDEuMyAyIDQgMi4zIDQuM3oiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNDc0LjUgMjg1LjdhMjguMyAyOC4zIDAgMCAx'
    b'LS4yLTQuNWMuMS02LjYgMS4yLTYgMS43LTUuMmgyLjNzLTEuNy03LjQtMy43LTNhMTkgMTkg'
    b'MCAwIDAtMS41IDEwLjRjLjEgMiAuMyAzLjMuNiA0eiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3'
    b'MTkiIGQ9Ik01MDAuMiAyODUuN3M0LjMuOC0yLjMgMi4zYzAgMCAuMyA4LjIgOC4yIDIuNSAw'
    b'IDAgNC43LTMgOC00LjIgMCAwIDEuNi0uNiAxLjQtMS44IDAgMCAuMi0xLjUtMS41LTEuMSAw'
    b'IDAtMS40IDAtMi4zLS4zIDAgMC0xLTEuMi0xLjYtLjgtLjYuNS0yLjEuMi0uOSAxLjcgMS4y'
    b'IDEuNCAxLjUgMSAyIC42LjYtLjQgMy4xLTEuNC45LjdzLTQuMi0xLjItNS0xLjh6bS0yMiAx'
    b'aC0ycy0xIDEuNi0xLjctMWwtLjcgMS42czIuMyA4LjggNC40LS42eiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNmZmMyMjEiIGQ9Ik00NzUuNCAyNzYuNnMtMSA1LjguMyA5LjJsMjEuMS41cy0uMi00'
    b'IDAtOS43SDQ5NHMtLjUgNC42IDAgNy41aC0uNXMtLjQtNCAwLTcuNUg0OTFzLS40IDQuMyAw'
    b'IDcuNWgtLjVzLS40LTMuNyAwLTcuNUg0ODhzLS41IDMuOSAwIDcuNWgtLjZzLS41LTMuOSAw'
    b'LTcuNWgtMi43cy0uNiAzLjYgMCA3LjVoLS41cy0uNi0zLjYgMC03LjVoLTIuN3MtLjYgNC4y'
    b'IDAgNy41aC0uNnMtLjQtNCAuMS03LjVoLTIuNXMtLjcgMy41IDAgNy41aC0uN3MtLjQtMyAu'
    b'Mi03LjVoLTIuNnptMjIuMyAxMC40cy0uNS0xMC4yIDEuNC0xM2MyLTIuNiAyLjUtMiA1Ljgg'
    b'MCAzLjQgMi4yIDcuNyA0LjUgOC41IDQuOC42LjMgMS42LjUgMS42IDIuNHMuMyAyLjQtMi42'
    b'IDBhOSA5IDAgMCAwLTIuNy0xLjhjLTIuNi0uOS42LjUgMS41IDEuOS44IDEgMS41IDEtLjYg'
    b'MS41YTIxOSAyMTkgMCAwIDAtMTIuOSA0LjJ6Ii8+CiAgPHBhdGggZD0iTTUwNSAyNzkuNnMt'
    b'MS41LTEuOC41LTIuM2MyLS40IDIuMSAzIDIuNSA1LjEuMyAyLjItMi41LTIuMS0yLjgtMi43'
    b'em0tMi43IDlzLTIuMy45LS43IDEuNmMxLjQuNyA1LjUtMi43IDQuMi0yLjUtMS42LjMtMy41'
    b'IDEtMy41IDF6bTMtM3MyLS4zIDEuNi41Yy0uMyAxLTEgLjQtMS40LjItLjMtLjItMS42LS43'
    b'LS4xLS44eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik01MTYgMjgyLjhzLjYgNCA0'
    b'IDVjMCAwIDIgLjQgMS41LTEuMyAwIDAtLjMtMS41LS42LTItLjMtLjctMS42LTEtMS44LTEu'
    b'MS0uMiAwLS4zLS41LjYtLjIgMSAuMyAxIC40IDEtLjNzLS42LS40LTEuNC0uOGMtLjQtLjIg'
    b'MC0uNC4zLS4zLjQgMCAxLjMuMyAxLjMtMSAwIDAgLjEtLjgtLjktLjgtMS4xIDAtMS0uNi0u'
    b'Ny0uNy4zIDAgMS41LjggMS45LS42LjMtMS4zLTEuNi0uNS0xLjQtMS4yLjMtLjggMS43LjMg'
    b'MS43LS41LjItLjggMS4zLTEuMS0uNi0xLjQtLjktLjEgMC0uNiAxLS40IDEgLjEgMS42LTEu'
    b'MiAyLjMtMS42LjYtLjUgNC4yLTIuNi0uNi0xLjktNC43LjctNi4xIDMtNi4zIDMuNWExMyAx'
    b'MyAwIDAgMC0xLjMgNy42eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik01MjcgMjg1'
    b'LjhjLjcgMCAxLjIgMCAxLjQuNS44IDEuNi0xIDEtMiAyLjJzLTEgMS0yLjQuNWMtMS40LS40'
    b'LTItMi41LTItMi41IDAtLjcuNS0uOCAxLjItLjYgMCAwIDIuMy4yIDMuOSAwem0tNS0uOHMw'
    b'IC40LjkuNWMuNyAwIDMgLjMgNC41LS4xIDAgMCAuNC0uMS4yLTEgMCAwIDAtLjctMS4yLS40'
    b'LTEuMy4yLTMgMC0zLjctLjEtLjYtLjItMSAwLS44IDF6bS0uMi0yLjlzLS4xIDEuMyAxLjEg'
    b'MS40YzEuMy4yIDIuOS4yIDMuNSAwIC41IDAgMS40LS4yIDEuNS0xIDAtLjcuMi0xLjItMS4z'
    b'LS44cy0zLjQgMC0zLjYgMGMtLjEgMC0xLjItLjMtMS4yLjR6bS41LTIuNXMtLjMuNi0uMiAx'
    b'LjJjMCAuNS45LjcgMi41LjdzMy0uMiAzLjItLjdjLjEtLjcuNS0xLjMtLjctMS0xLjMuMS0z'
    b'IC4yLTMuNiAwLS42LS4zLTEuMS0uNC0xLjItLjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcx'
    b'OSIgZD0iTTU4Mi4xIDI4NnMwIDEgLjkgMi4ybC00NS4yLTEuM3MuNi0uNC44LTIuMnoiLz4K'
    b'ICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTIyLjcgMjc3LjhzLS40IDEuMS40IDEuNGMu'
    b'Ny4yIDIuMi40IDQgLjEgMCAwIDEgMCAxLjMtMSAuMy0xIC4zLS40LTIuMy0uOCAwIDAtLjgt'
    b'LjMgMS41LS4zIDAgMCAxLjQgMCAxLjUtLjIuMy0uMiAyLTEuNy0uMy0xLjUtMi4zIDAtMS4x'
    b'LS41IDAtLjUgMS4yIDAgMS42LjMgMiAwczAtLjItLjctLjgtLjEtLjUuMy0uMWMuNS4zLjgu'
    b'NSAxLjMgMHMtLjQtMS4yIDAtMWMuMyAwIC42LjggMiAwIDEuNi0uNyAzLjUtLjMgNCAwIC42'
    b'LjUgMi4yIDEgMy4xIDAgMS0uOC0xLjEtMS43LS4zLTEuOCAxLS4xIDEuNi4yIDEuOS0uNS40'
    b'LS44LTEuNC0xLjQuMy0xLjggMS42LS41LjItNS0uMy01LjUgMCAwLTEuOSAxLjEtMy44IDQu'
    b'My0yLjEgMy4zLTMuMyA1LjItNiA0LjItMy45LTEuNS02IC42LTYuNSAxLTEgLjYgMiAuOC4y'
    b'LjktMS43IDAtMS43LjItMS44LjQtLjIuMyAwIC41LjMuNi4zIDAgLjkuNi0uMS42cy0xLjgt'
    b'LjMtMS41LjljMCAwIDAgLjIuNi4zLjYgMCAuOC44LS4zLjgtLjggMC0uOC4yLS44LjN6bTQu'
    b'MSAxMS4zcy0uNy41LjMuNmMxLjIgMCAxLjcuMyAyLjEtLjNzMS44LS40LjgtMS4yYy0xLS44'
    b'LTEuNi0uMy0zLjIgMXoiLz4KICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTMxLjUgMjc1'
    b'LjVzMy44LTMuNSA2LjktMS4yYzMuMiAyLjUgMy40IDIuOCAzLjUgMi45IDAgMCAuNC4zLS40'
    b'IDEtLjkuOCAwIC44LjkuM3MxIDAgMS40LjVjLjUuNSAxLjEuOC0uMy44aC00LjZzLTIuMS4y'
    b'LTEtLjdjMS0uOS44LTEuOS4zLTItLjYgMCAwIC42LS4zIDEtLjQuNC0xLjEuNy0xLjkuN3Mt'
    b'MS40LjYtLjIgMWMxLjEuNC0uMi43LS44LjdzLTMuNS4yLS41LjZjMyAuMy0uMy4zIDIgMS41'
    b'IDIuNCAxLjQuNiA0LjMtLjMgNC42IDAgMC0xIC41LjIuNCAxLjMtLjIgMi0uMyAxIC40LS44'
    b'LjYtMi42IDIuOS01IDEuMiAwIDAtMS4yLS42LjgtLjcgMiAwLTEuNi0uNS0yLjMtMS0uNS0u'
    b'My0zLTIuNy0xLjUtMi41IDEuNi40IDEtLjUuMS0uOC0uOC0uMy0xLTEuNiAwLTEuNCAxIC4z'
    b'IDIgLjkgMyAuOC43IDAgLjUtLjMtMS4yLS44LTEuNy0uNi0yLjQtLjctMi0yIC40LTEuNSAy'
    b'LjMuNSAxLjgtLjYtLjQtMS0yLS41LTEuMi0xLjlzMS0uOCAxLjUtLjZjLjMuMSAxIDAtLjEt'
    b'LjgtLjgtLjUgMC0xLjMuMi0xLjR6Ii8+CiAgPHBhdGggZD0iTTUzNC4yIDI3Ni41czAtLjUu'
    b'OC0uNGMuNiAwIC40LS4yLjYtLjQuMiAwIDEuOS41LjMgMS0uNi4zLTEuNi4yLTEuNi0uMnoi'
    b'Lz4KICA8cGF0aCBmaWxsPSIjZmZjMjIxIiBkPSJNNTM3LjkgMjgwLjVzLTEuMy42LS4yIDJj'
    b'MSAxIDEgMS41IDEgMi4yLS4xLjggNDMuNCAxLjMgNDMuNCAxLjNzMC0yLjkgMS44LTQuNWwt'
    b'NDYtMXoiLz4KICA8cGF0aCBmaWxsPSIjNWEzNzE5IiBkPSJNNTgyLjggMjg1LjJzLjItMi40'
    b'IDEuNi0zLjFjLjctLjUgMS42LS4zIDIgMS42LjYgMi43LTEuNyA1LjEtMi43IDQtMS0xLS44'
    b'LTIuNS0uOC0yLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzdiM2MyMCIgZD0iTTUzMi45IDI5NS40'
    b'czIuOS0yLjUgMy40LTMuNmMwIDAgNy44IDUuNiA3LjMuNGwuMi0yLjZzMi45LjMgMy4zLTJs'
    b'LTcuMy0uM3MtLjgtLjEtMiAxLjFjLTEgMS4yLTMuNCAyLjUtNS41IDEuNCAwIDAtMS0uOC0x'
    b'LjkgMC0xIC41LTEgLjctLjIgMS41czIuNCAyLjkgMi43IDR6bTE2LjgtMTUuNC00LjMtLjJz'
    b'LTEuNS0yLjItNC42LTQuNmMwIDAtLjktLjQuOC0xLjggMS44LTEuNCAyLjMtMi44IDIuMy0z'
    b'LjUgMC0uNiAwLTEuNy42LTEgLjYuOCA1IDQuOSA1LjggMy43LjYtMS4yLjctMS43LjctMi4x'
    b'LjItLjQuMy0xLjUgMS0uMy42IDEuMSAxIC44IDEuMSAzLjggMCAwIDAgMyAuNSA0IDAgMC01'
    b'LjYtMS43LTMuOCAyem0tMTguNi05LjJzMy4zIDIgNS0uNmMxLjUtMi41IDIuNi0yLjggMS40'
    b'LTUuMy0xLjItMi4zIDAtMy40LjktNC40IDEtMSAxLjgtLjggMS44LTQuNi4yLTMuOSAyLjgt'
    b'NSA0LTYuMyAxLjItMS4yIDQuMi0zLS40LTMuNy00LjQtLjgtMTMuNC0zLTE1LjctNi41LTIu'
    b'My0zLjUtMy4zLTEuNS0zLjMtMS4zIDAgLjItLjggMi43IDEuNSA3LjNzNC4yIDcuNiA2LjUg'
    b'OWMyLjIgMS41IDQuMiAyLjMgMyA1LjRzLTMgOC42LTQuNyAxMXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjNWEzNzE5IiBkPSJNNTQzLjIgMjYxcy42IDggNi4zIDEwLjhjMCAwIDEuMy0zIC44LTYu'
    b'MSAwIDAgMS45LjEgMi40IDEgMCAwIDAtMi4zLTIuNi0zLjItMi43LS43LTEuNC02LS40LTYu'
    b'NS45LS42LjYtMS43IDAtMi42LS43LTEtLjgtMi4zIDEuNC0xLjcgMi4zLjYgMi0uNi41LTEu'
    b'Ny0xLjMtMS4xLTEuMy0yLjUuNy0yLjVzNS0xLjkgMy4yLTIuNGMtMi0uNi0yLjUtMS4zIDAt'
    b'MiAyLjctLjggNC0xLjcgMi0yLTItLjItMy4zLS45LTEuNC0xLjIgMS45LS4zLS4zLTIuMy0y'
    b'LjUtMi4zLTIuMy0uMi03IC43LTMuMy0yLjMgMy44LTMtNS40LS44LTEuNi0yLjggMy44LTIt'
    b'MS4zLTEuMS0yLTEuMXMtLjcgMC0uNC0xYy4yLTEtLjUtMS42LTEuNy0uOS0xIC42LTEgLjYt'
    b'MS0uNyAwLTEuNS0xLjMtLjQtMi4xIDAtLjkuMy0zIDEuOS0zLjkgMS0uNy0uOS0xLjItMS43'
    b'LTMuOC0uMi0yLjYgMS41LTIgLjItMi0uNXMxLTMuNC0yLjQtLjUtLjctMy0zLjUtMWMtMi43'
    b'IDItMyAyLjQtMy41IDEuNS0uNS0xLTEtMS43LTQgLjMtMy4xIDEuOS0uOC0xLjMtLjUtMiAu'
    b'NS0uNiAxLjgtNS0uOS0xLjYgMCAwLTEuMyAyLjQtNC4yLTEuOSAwIDAtMyA0LjMtMy45IDIu'
    b'NC0uOC0yLTEuNS0yLTIuNi0uOC0xIDEuMi0uMi0uMS0uNy0xLjItLjQtMS0uNy0yLjktNS44'
    b'LjgtNS4xIDMuOCAxLjggMS0yLjEgMi43cy0xMy41IDctNC44IDUuOWM4LjctMS4zLTQuMiAz'
    b'LjMtMS4yIDQuMiAzIC44IDIgMy41IDEzLjQuMyAxMS4yLTMgOS40LS40IDE1LjItMyA1Ljgt'
    b'Mi40LTEuNC45IDYuNC44IDcuNy0uMiAxLjMgMCAyLjggMS42IDEuNSAxLjYgOCA1LjMgMTQu'
    b'MSA2IDYuMS42IDcuNy0xLjcgNS45IDEtMS44IDIuNi0yLjQgMy42LTMuNCA0LjYtMSAuOC00'
    b'IDMtNCA2LjYgMCAzLjctNC44IDQuMy0zIDguM2w0LjEtNHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'NWEzNzE5IiBkPSJNNTUzLjMgMjY5LjlzLTEuNC0xLTEuNC0yLjhjMCAwIDEgLjIgMS40Ljgg'
    b'MCAwIDMuNS00LS44LTUuNC00LjEtMS40LTItNS4zLS42LTUuM3MxLjctLjMuNC0yYy0xLjIt'
    b'MS41LTEtMS42IDEuMy0yIDIuMy0uNCAyLjEtMSAxLTEuNWE3LjcgNy43IDAgMCAxLTEuOS0x'
    b'LjZzNi44LTIuOSA0LjYtNC4zYy0yLjItMS4zIDAtMSAyLTIuMyAyLTEuNCAyLjItMS43IDIu'
    b'NS0yLjMgMCAwLTIgLjMtMy40IDAgMCAwIDEuNy0uOSAwLTIuM3MtMi4zLTIuNi01LTJjLTIu'
    b'Ny43LTEuOC0uMi0uOC0xLjNzLjYtMS43LTEuMy0yYzAgMCAuMi0xLjIgMS43LTIuNSAwIDAt'
    b'My43LjItNS0uNCAwIDAgMS42LTEgMS42LTIuMyAwIDAtMiAuNy00LjUuNSAwIDAgMS41LTEu'
    b'MyAxLjUtMi40IDAgMC00LjQgMS02LjQgMi41IDAgMC0uNSAwLS44LS42LS40LS40LS42LTEt'
    b'NS41LjYgMCAwIC41LTIuMiAxLjctMyAxLjItLjggMS0yLjYtNi41IDIuMSAwIDAtMS0uNi0x'
    b'LjktMi45IDAgMC0xLjcgMi4zLTIuOSAzLjEgMCAwLTEgLjUtMS0xIC4yLTEuNS0uNy0uNS0x'
    b'LjQgMC0uOC40LTEuMyAxLjUtMS0xLjVzLTEtMy42LTEtMy42LTIuMyAzLjMtMy43IDMuN2Mw'
    b'IDAtMi41LTIuNC0zLjQtNC0uOC0xLjYtLjgtMi4yLTEuNy42LS45IDIuNy0yIDMtMiAzcy0x'
    b'LjUtMS4zLTEuNi0yYzAgMC0uMy43LS44IDEgMCAwLTEuMy0xLjUtMS4yLTMuNyAwIDAtOC4y'
    b'IDQuNS05LjIgNy4yIDAgMC03LjctLjUtMTAuOC4xIDAgMCAuNy0yLjQgMi43LTMuNyAwIDAt'
    b'Mi0uMi0yLTIuMyAwIDAgMS42LjIgMi42IDBzLTEuNC0zLjEgMS4xLTMuMmMyLjUtLjEgNC4y'
    b'IDEuMiAzLTIuMi0xLTMuMy0uNi0zLjMtLjYtMy4zczQuNCAyLjYgNS4xIDEuOWMuOC0uNi0u'
    b'NS0yIDMuNC0xLjQgMy45LjcgMi44LTEuNSA0LjQtMS43IDEuNSAwIDIuMyAxIDEuMy02LjFz'
    b'NC44IDMuNS45LTcuMmMwIDAtMS0zLjMtMy4zLTQuNyAwIDAtLjYgMi4zLTMuMi4zLTIuNi0y'
    b'LTcuOC0yLjgtNS42LTQuNCAyLjItMS43IDMuMi0zLjkgMi42LTUuMiAwIDAtMi42IDIuNi03'
    b'IC43LTMuNi0xLjUtNC40IDEuMy04IC41IDAgMCAwLTEgMy4xLTMuNCAzLTIuMy0xLjguOC0z'
    b'LjYgMS4zLTEuOS40LTIuNCAwIDEuNS0zLjEgNC0zIDEyLTguNSAxMS0xMyAwIDAgMS44IDIu'
    b'MyA2LjcuNiA1LTEuNyA4LjYtMi4zIDEwLTVhMjMgMjMgMCAwIDEgNi40LTUuNmMxLjEtLjUg'
    b'Mi40LTEgLjkgMS41LTEuNiAyLjQtNCA2LjYtMTAuOCA5LjQtNi44IDIuOC05LjUgNC44LTEw'
    b'LjcgNi4zLTEuMiAxLjUtNy40IDQuOC0zLjMgNC4zIDQtLjcgMTAuOSAwIDcuNi0xLTMuMi0u'
    b'OS02LjkuNi0zLjktMi4xIDMtMi43IDMuNS0zLjYgNy45LTUuNCA0LjQtMS45IDkuMi02LjEg'
    b'OC43LTEuNi0uNSA0LjQtOC42IDkuMS0xMC42IDEwLjYtMiAxLjQtMS4yIDEuMi0xLjIgMS44'
    b'IDAgLjYtLjQgMS44LTEuMiAyLjMtLjguNi0uNSAxLjItLjMgMi40LjIgMS4zLS4yIDEuOC40'
    b'IDIgLjYuMSAxLjIuMiAxLjQgMS4xLjIgMSAuNiAxIDEuOCAxIDEuMS0uMiAyIDAgMiAuNiAw'
    b'IC43IDEuMiAxLjcgMS4zLS40LjEtMi4yIDEtMi41LTEuMi0xLjUtMi4yLjktMi42LjYtMi42'
    b'LS40cy0uMi0uOC0xLS45Yy0xIDAtMS4zLTEuMy4zLTIuMiAxLjYtLjggMS42IDAgMy42LTEu'
    b'NiAyLTEuNyAyLTIgMi4zLTMgLjMtLjctMi45IDIuNC00LjQgMy0xLjUuOC0xLS41LS44LTIu'
    b'MS4zLTEuNyA0LTQgNS43LTQgMS44IDAgNS42IDEgNCAzLjMtMS43IDIuMy02LjQgNS4yLTQu'
    b'NSA1LjQgMi4xLjIgMi40LS42IDMuNi40IDEuMiAxIDAgMy4yLS40IDQuNGE4LjQgOC40IDAg'
    b'MCAxLTIuMiAyLjdzLTIuMi0zLjgtMi4xLS44YzAgMy4xLS41IDQuMiAwIDQuMy41LjEgMi44'
    b'IDEuNyAzLjYgMS43cy00LjEgMi4zLTIgMi41YzIgLjEgNS4zLTEgNi40LTMgMCAwLTQuMi0x'
    b'LTUuOS0yLjYgMCAwIDQuOS0xLjIgMy41LTUuOCAwIDAgNC45IDEuMyAyLjcgMy41LTIgMi4x'
    b'LTMuMyAxLjgtMS41IDIuNCAxLjkuNiAyLjcgMS4yIDIuNyAxLjJzMS4zLjYuNSAxLjZjLS43'
    b'IDEtLjcgMi42IDAgMi41LjUgMCAyLjYtMSAuOS0yLTEuOC0xIDEuOS0uOC40LTEuNy0xLjYt'
    b'MS0yLTEuMS0yLjQtMS42LS41LS4zIDE5LjctMTIuMiA5LjUtNy44IDAgMCAyLjEtNC42IDUu'
    b'MS00LjYgMyAwIDMuMiAyLjMgMS41IDQuMi0xLjcgMS43LTIuOCA0LjYtNi43IDUuMiAwIDAg'
    b'NS42IDIuNy0xIDcuMiAwIDAtMS41LjctMSAxLjJzNC41LTEuNyA1LTNhNS41IDUuNSAwIDAg'
    b'MSAzLTMgMzggMzggMCAwIDAgMTEuMi05LjZjMi4zLTMuOSAyLjgtNCA3LjItNy41czMuNi0y'
    b'LjggNC4yLTMuNmMuNS0uOS43LTIuMyAyLjctMy40IDItMS4yIDkuOC01LjQgMTIuMy03LjIg'
    b'Mi40LTEuOCA3LjQtNSA5LjYtNy44IDIuMS0yLjcgOC02LjIgOS40LTUuNiAxLjQuNy0uMiAy'
    b'LjgtMy41IDUuNC0zLjUgMi41LTEyIDkuMy0xMy4zIDEwLjRhNDQuNyA0NC43IDAgMCAxLTEx'
    b'LjIgNi42Yy0yLjcuMy0yLjQgMS4zLTQgM3MtNS4zIDUuNC02LjUgNi40Yy0xLjMgMS00LjMg'
    b'My00LjQgNC41LS4yIDEuNS41IDEuNi0xLjkgMy44YTUwIDUwIDAgMCAxLTExLjkgOC4xczQu'
    b'NSAxLjYgMS44IDQuNmMtMi42IDMtMi41IDIuNi0yLjYgMi44IDAgMCA2LjctMSAyIDQuMyAw'
    b'IDAtMSAxLjUgMS4xIDAgMi4zLTEuOSAxLjQtNC4xIDEtNC41IDAgMCAzLjctMi4zIDcuOS0y'
    b'LjMgNC4xIDAgNC0uMy4yLTEuNCAwIDAgMi43LTMuMiA1LTEuNiAyLjIgMS41IDEuNCAyLjUt'
    b'LjkgMy44LTIuNCAxLjItNS44IDEuNy04LjUgMy4yIDAgMCA1IDEgNy42LTEuMSAyLjYtMiAy'
    b'LjgtMSAzLS42LjUuNC44IDEtLjQgMi42LTEuMiAxLjctMS4zIDEuOC0xLjIgMi4yIDAgLjQt'
    b'LjEgMS41LTIuNSAyLTIuMy4zLTMuNSAxLjMtMi42IDIuNC43IDEuMi43IDQtMS4yIDMuNy0y'
    b'LS4zLTEuNi0xLjktMi4zLTIuNS0uOC0uNi0xLjktMS41LTUuNC4yLTMuNiAxLjktMy44LS4z'
    b'LTMuNy0xLjUgMCAwLTIuMyAyLTQuMi4yLTItMS45LS4yLTIuNiAxLTMuNSAxLTEgNS41LTMg'
    b'Mi44LTIuNS0yLjcuMy02LjcuNC03LjYtMS42LTEtMi4xIDItMS45IDIuNC0xLjcuNS4yIDIu'
    b'MyAxLjcgMi41LS4zIDAtMiAzLTIuMyAyLTIuNi0xLS40LTIuNS45LTIuOSAxLjMgMCAwLTIt'
    b'Mi45LTUuNC0yLTMuNCAxIDEgLjcgMiAuOC44LjIuMyAxLjgtMi43IDQuNi0zIDIuNy0xLjcg'
    b'MS44LjUgMS44IDIuMyAwIDcuOSAwIDQuNiAyLjYtMy4yIDIuNy00LjUgNC02IDMuNi0xLjgt'
    b'LjUgMC0xLjYuOC0yLjFzMS4yLTEuMi0uNC0uNmMtMS42LjUtMi4xLjctMy40LTEuNS0xLjIt'
    b'Mi4zLS44LTEuNi0uMi0zLjEuNi0xLjUgMS44LTMgLjQtMi41LTEuNi42LTEuNC43LTEuMy0x'
    b'IC4xLTEuNy0xLjctMi4xLTEuNy0yLjFzLjggMS43LjEgMi44Yy0uNiAxLS43IDEuNC40IDEu'
    b'NiAxIC40IDIgMS4zLjYgMi4zLTEuNC45LTEuMi43LS40IDEuMyAxIC43IDIuMyAxLjMuOSAy'
    b'LjctMS40IDEuNC0uMyAxIC40IDEgLjggMCAyLjMuNiAyLjMgMiAwIDEuMiAwIDEuNSAyLjMu'
    b'MyAyLjMtMS4zIDYuNy0xLjEgNi43LjYgMCAxLjgtLjYgMi4zIDEuOC44IDIuNC0xLjUgMy41'
    b'IDEuNCA1LjIgMCAxLjYtMS41IDIuNi0yLjggNC42LS40IDEuOSAyLjQgMS4zIDMtMSA0Ljgt'
    b'Mi4zIDEuNyAxLjEuNCAyLjktLjVzNi43LTEuNSA5LjUtLjJjMi45IDEuMiAzLjcgMSA1Ljgg'
    b'MCAyLjEtLjggMy4yLTEgNi4zIDEuMSAzLjMgMi4yIDUuNyAyLjYgNy40IDIuNSAwIDAtMy41'
    b'IDEuNC03LjUgMS42LTQgLjMtNiAxLTYuNyAxLjYgMCAwIDIuMyAxLjUgMi44IDMuMiAwIDAg'
    b'Mi42LS4zIDMuOC4yIDAgMC0uNiAxLjkgMSAyLjlzMi43IDEuNCAxLjUgMi43Yy0xLjIgMS40'
    b'IDEuOS44LjEgMi43LTEuNyAyLTIuMSAzLTIuMiA0LjUgMCAxLjYuNCAxLjgtMS4xIDItMS42'
    b'LjEuMiAxLjktLjUgNC0uNyAyLTUgMS43LTQuOCA3LjIgMCAwIDEuMi0yLjcgMy44LTUgMi41'
    b'LTIuNCAyLjYtMi42IDIuNS00IDAtMS40LS4xLTEuMSAxLjItMi4yIDEuNC0xLS42LTIgLjgt'
    b'My42IDEuMy0xLjUuMi0xLjIgMS44LTIuNyAxLjUtMS42LTEuNS0xLjcuMi0zLjMgMS41LTEu'
    b'Ni00LTMuNS0yLjMtNC41IDEuNS0xIDQuMy0yLjQtNS0yLjMgMCAwIDIuMy0zLjYgMTAtMi45'
    b'IDAgMC0yIDEuNi0yLjIgM2wxLjYuNXMtLjQgMS4xLTEuOSAyLjNjMCAwIDQuMiAyLjMgNC45'
    b'IDMuOCAwIDAtMi42LjgtMy4zIDEuOCAwIDAgMS4yIDEuMyAxLjYgMyAwIDAtMi45LS40LTMu'
    b'MiAxLjctLjQgMi4xLTEuMy43LTEuMyAycy4xIDEuNy0uOSAyYy0xIDAtLjEgMS4xIDAgMS44'
    b'LjIuNy42IDIuMy40IDIuOCAwIDAtMS41IDAtMi4xLjIgMCAwIC40IDMtMS4zIDMuNS0xLjcu'
    b'NCAxIDEtLjkgMS4zLTEuOC4zLTEuNS41LTMuNyA0LjUgMCAwIDEuOS0xIDMuOC0yLjQgMi0x'
    b'LjMtLjItMSAzLTQgMy4zLTMuMyAyLjctMy41IDIuNC01LjEtLjItMS42LS4zLTMgLjktNC41'
    b'czEuNS0zLjIgNS43LTNjMCAwLTEuMi0yLjgtMi43LTMuNSAwIDAgMi0xLjMgNC0xLjUgMCAw'
    b'LTEuOC0yLjMtNS42LTQuNCAwIDAgMy0yLjYgMy45LTMuOSAwIDAtMS41LjMtMi43IDAgMCAw'
    b'IC42LTEuMyAzLjQtMy4xIDAgMCAxLjUgMS40IDEuNCAyLjkgMCAwIDQuOC0yLjcgNy41LTIu'
    b'NCAwIDAgMS40IDMuNC01LjMgMTAgMCAwIDQuMi4zIDYgMCAwIDAtMSAzLjItNiA1LTUgMiAx'
    b'IDQuMi00LjEgMy44LTUtLjQtMy41IDEuMy0zLjQgMy45LjIgMi42LjMgNS4zLjIgNiAwIDAt'
    b'NC0xLjMtNCAyLjYuMSA0LTIgNC44LTIuNSA1LjEgMCAwLTEuMi0xLTMtMS43IDAgMC0yLjUg'
    b'NC45LTYuNSA3Ljd6Ii8+CiAgPHBhdGggZmlsbD0iIzdiM2MyMCIgZD0iTTU0Ny40IDIyMC41'
    b'czEuNC0uMiAzLjggMS4yYzIuMyAxLjUgNC42LTEuNSAyLTIuMy0yLjYtLjggMC0xLjggMi40'
    b'LjIgMi40IDEuOSAzLjMuOSA0LjIuMy44LS43IDEuOS0xLjEuMy0yLjItMS42LTEuMSAxLS42'
    b'IDIuMy4zIDEuMi43LjcgMS41LjYgMS43LS4yLjItLjMgMi45IDIgLjUgMi40LTIuNSAzLjct'
    b'NC44IDMuNi02IDAgMCAxLjMuOCAxLjUgMi4zLjIgMS41IDItLjggMi42LTEuNi42LS44IDEu'
    b'Ni0zIDEuNS00LjQgMCAwIDEuNiAyLjUgNCAwczEuNC0xIDQuMi0xLjdhMTcuNiAxNy42IDAg'
    b'MCAwIDguNS01LjJjMi0yLjUgMi4xLS44IDQuNi0xLjRzNy43LTQuMiA4LjItNi4xYy40LTEu'
    b'OS4zLTMuMS0uNC0yLjQtLjcuNi0uNCAwLTEuNS0uNi0xLjEtLjctMi43LjktMi43LjlzMS42'
    b'IDEuMi4zIDEuN2MtMS4yLjYtMi4zIDIuMy00LjYgMS42LTIuMy0uNi00LjggMi4yLTQuOCAy'
    b'LjJzMiAxLjYtLjcgMi43Yy0yLjcgMS0yLjMgMS40LTMuOS4yIDAgMC0yLjkgMy43LTQuNiA0'
    b'LjUgMCAwLS43IDAtMS4yLS44IDAgMC0yIDIuMS0yLjggMi41IDAgMC0xLjMtMS0yLjMtMS41'
    b'IDAgMC0yLjMgMi45LTQuMiAzLjcgMCAwLS42LTEtMS44LTEuNyAwIDAtLjYgMy42LTQuNiA1'
    b'LjggMCAwIC4yLTEtMS44LTIuMyAwIDAtNSA0LjMtNi45IDQuNy0yIC40LS4yLS45IDAtMS41'
    b'LjQtLjUgMS42LTIuMy0uOC0zcy0yIC41LTIuNS43Yy0uNi4yLS42LS40LTIuMi0uMnMtMS4z'
    b'LjktMiAxLjJjLS44LjItMy42LS41LTMuNCAxLjQuMSAxLjggMS41IDMuMS0xIDQuMi0yLjUg'
    b'MSAxIC44IDQuMS40eiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik01NTcuNSAyMTUu'
    b'M3MuNi0yLjUtMS41LTMuNWMwIDAgMTMuMi0yLjEgMy4yLTcuMiAwIDAgMTEuOS0yLjMgOS02'
    b'LjEtMi43LTMuOC01LjQtMy01LjgtMy0uNCAwIDIuNS0yLjEgMy4zLTEuOC43LjMgMTAuMiAz'
    b'LjkgNy44LjctMi40LTMtMi4yLTIuOS0yLjYtMy44IDAgMCAzLjEgMCA3LjkgNC42IDAgMCAx'
    b'LTEgLjktMi45IDAgMCAzLjMgMSA0LjQgMiAwIDAgLjYtMS4yLjMtMS44IDAgMCAzIDEuNSA0'
    b'IDMuMiAwIDAgMS4zLTEuMiAxLjUtMi42IDAgMCAzIDEuMyAzLjcgMi4yIDAgMCAxLTEuMy42'
    b'LTMgMCAwIDQuOSAxLjMgNS41LTEuNiAwIDAgNC45IDEgMS43IDIuOS00IDIuNS0uNC0uNi00'
    b'LjYgMi4zLTMuMiAyLjMtNSA0LjktNi42IDQuNC0xLjEtLjUtMi41IDIuOS00IDEuMy0xLjUt'
    b'MS43LTEuNS0xLTIuNy43YTI0LjUgMjQuNSAwIDAgMS0yLjggMy41cy0uOC0uNS0xLjYtMS4y'
    b'YzAgMC0uOCAxLjYtMiAyLjggMCAwLTEtMS4zLTIuNi0yIDAgMC0yLjMgMi43LTMuOCAzLjcg'
    b'MCAwLTEuNC0xLjQtMi45LTEuOSAwIDAtLjIgMy44LTMuMSA1LjcgMCAwLS42LTEuMi0yLjYt'
    b'MiAwIDAtMS40IDIuMy00LjYgNC4zeiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik01'
    b'NTAuNiAyMDkuNXMtMS42IDEuMi0uNiAyLjVjMSAxLjQgMS4xLS4yIDIuNC0uMyAxLjMtLjIg'
    b'MTcuNS0zIDIuOC03LjMgMCAwIC43LS42IDMuMS0uOCAyLjYtLjMgMTEuOC0yLjcgNy41LTYt'
    b'NC4zLTMuMi03LjkgMS4xLTQuMy0yLjggMy0zLjEuNi00LjYuNi00LjZzLTguNSA1LjYtMTAu'
    b'NCA2LjdjLTEuOCAxLTQuNiAzLTEuNCA0IDMuMyAxIDUuNC0zLjQgNS43LTIuNC4zIDEtNi40'
    b'IDQuOC01LjQgNi40LjkgMS44LjcgMy4zIDIuNCAyLjkgMS42LS4zIDYgLjggMi41LjctMy43'
    b'LS4xLTUgMS01IDF6Ii8+CiAgPHBhdGggZD0iTTU1Ni40IDIwMS4zcy0xLjUgMS4xLjUuNiA1'
    b'LjktMS40IDUuMi0yLjRjLS44LTEtMy40LjItNS43IDEuOHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'N2IzYzIwIiBkPSJNNTgyLjQgMTg0LjVzNy41LS4yIDEwLjUgMS45YzMgMiA0LjYgMy40IDUu'
    b'NSAzLjggMCAwLS4xIDIuOC01IC43IDAgMCAuNCAxLjQtLjIgMi44IDAgMC0xLjctMS4yLTMu'
    b'OC0xLjcgMCAwLS40IDEtMSAxLjcgMCAwLTIuMS0yLjItNC42LTIuOSAwIDAtLjQgMS4xLS44'
    b'IDEuNiAwIDAtMi42LTEuNi00LjYtMS42IDAgMCAuNCAxLjcgMCAyLjMgMCAwLTUuNC00LjMt'
    b'MTAuMy0zLjggMCAwIDIuMyAzLjUgMy44IDUuMSAwIDAtOS44LS43LTgtNiAxLjUtNS4zLS4y'
    b'LTQgNi4yLTRoMTIuM3oiLz4KICA8cGF0aCBmaWxsPSIjNWEzNzE5IiBkPSJNNTM2LjMgMTk5'
    b'LjFzLTEuMSAxIDAgMS43YzEuMS44IDUtMiA1LjUtMi40LjYtLjQgMi0uNCAwIDEuMXMtMy44'
    b'IDMtNSA0LjZjMCAwIDYuNC0xLjggMTAuNi01LjQgNC4zLTMuNy0uMS0xLjMgNy00LjggNy4z'
    b'LTMuNSAxMS4xLTkuMSA3LjItOC41LTMuOC42LTcuMyA1LTEwLjQgNi43LTMgMS43LTQuNyAy'
    b'LTQuMiAxIC40LTEgMi43LS42IDYuOS00IDQuMS0zLjMgMy4yLTMgMy4yLTQuMiAwLTEuMi0x'
    b'LjUtNCA0LjctNy40IDYuMi0zLjMgMjUuNi0xNC41IDI3LjMtMTguNSAwIDAtNS43LjYtMTMu'
    b'MiA2LjFhNjkuNyA2OS43IDAgMCAxLTEzLjQgOC44Yy0yIC44LTEuOC4yLTMuMSAxLjlhMTcx'
    b'LjggMTcxLjggMCAwIDEtMTAuMSA5LjhjLTEuMyAxLTEuOCAxLjYtMS45IDMuOCAwIDEtOC40'
    b'IDcuMy0xMSA5Ljd6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcxOSIgZD0iTTU2MiAxODQuM3Mt'
    b'MS41LjYtMyAwYy0xLjMtLjctLjgtMy42IDIuNS01LjVhNTAgNTAgMCAwIDEgMTIuNi00Ljhz'
    b'LS41IDMuOC0xMC4xIDcuMWMwIDAgLjYgMi0yIDMuMnoiLz4KICA8cGF0aCBmaWxsPSIjYWE1'
    b'MzIzIiBkPSJNNTY1LjQgMTgxLjhzLjMgMSAwIDEuOGMwIDAgMTcuOSAxLjcgMjcuMS05LjIg'
    b'MCAwLTEyLjcgMS4yLTE3LjcgNC4zIDAgMCAzLjItNCAxMi43LTcuM3MxMy40LTcuNCAxNC4y'
    b'LTkuN2MwIDAtMTIgNC4zLTE3LjcgNC4zIDAgMC0xLjIgMC0yLjMuNS0xLjEuNy04LjggNi4y'
    b'LTEwLjggNy4yIDAgMCA0LjMtLjQgNS45LTEuOCAwIDAtMyA4LTExLjQgMTB6Ii8+CiAgPHBh'
    b'dGggZmlsbD0iIzVhMzcxOSIgZD0iTTUzMSAxOTJzLTIuMyAxLjctMS4zIDIuNGMxIC45IDIu'
    b'NiAxIDYtMS45IDMuNi0zIDEyLjEtMTAuMiA2LjgtMTAuNSAwIDAtNy0uNC02LjcgMy44LjIg'
    b'NC4yLTQuNCA2LTQuOCA2LjJ6bS0xNS45LTIuNXM0LjYgMi43IDIuOCA0LjljMCAwIDE0LTEx'
    b'LjggMTAtMTQuNC0zLjgtMi42LTYuOSAyLjMtNiAyLjcgMSAuNiAzLS40IDIuMy42YTc3LjQg'
    b'NzcuNCAwIDAgMS05IDYuMnptLTMuNi0zLjhzMyAxIDMuMiAyLjNjLjEgMS4yIDkuMi02LjQg'
    b'Ni44LTkuNy0xLjEtMS41LTYtMi02LjQuOC0uMiAzIDQuNi0uMyAzIDEuOC0yLjIgMi43LTUu'
    b'OSA0LjQtNi42IDQuOHptMzIuNi02LjRzLTEuOSAxLjQtLjEgMi4zYzEuOC43IDIuOC0uNiAz'
    b'LjctMS4zLjktLjggNS4zLTQgNi4yLTYgMS0yIDIuNS0yLjcgNC4xLTMuNyAxLjUtMSAxMi42'
    b'LTYuNiAxOS41LTEyLjcgNi44LTYuMSA0LTQuNSAxMS04LjRzMTEuNy03LjUgMTMuMi0xMS44'
    b'YzAgMC0zLjMgMS02LjIgM2EyNDMgMjQzIDAgMCAxLTEwLjcgNi41Yy0xLjMuNS0zIC42LTQg'
    b'MS42cy0xIDIuMy00LjMgNWMtMy41IDIuOS0yMSAxNS4zLTIzLjIgMTdhMzM0LjcgMzM0Ljcg'
    b'MCAwIDAtOS4yIDguNXoiLz4KICA8cGF0aCBmaWxsPSIjYWE1MzIzIiBkPSJNNTMwIDE4My40'
    b'czItMSA1LjYtLjhjMy42LjIgMTcuOC0xMy42IDIyLTE2LjNhMzQxLjYgMzQxLjYgMCAwIDAg'
    b'MTguNy0xMy44YzEuOC0xLjggMi0zLjYgMy42LTQuNiAxLjUtMSAzLS45IDYuNC0yLjkgMy41'
    b'LTIgMjAuMy0xMiAxOS4zLTE3LjggMCAwLTI1IDE1LTMwLjcgMTkuOGEzNzUgMzc1IDAgMCAx'
    b'LTI0LjcgMTcuN2MtMi44IDEuOS01IDUtOS45IDguOC00LjcgMy45LTkuNSA3LjItMTAuMyAx'
    b'MHoiLz4KICA8cGF0aCBmaWxsPSIjYWE1MzIzIiBkPSJNNTI0LjggMTc4czQuNi0uNCA1LjIg'
    b'MS45YzAgMCAxMC02LjggMTIuMi05LjYgMi4yLTIuOC0uOC0xLjIgNC45LTQuOWE1OTQuMyA1'
    b'OTQuMyAwIDAgMCAyNy0xOS4xYzIuNy0yLjMgNy44LTUuNSAxMS45LTguMiA0LTIuOCAxOS45'
    b'LTEwLjYgMTguMS0xN2wtMTQuMiA5LjVjLTIuNyAxLjgtMy45LjgtNi41IDIuOS0yLjYgMi4x'
    b'LTguNSA2LjMtOS41IDcuNmExNjEuMyAxNjEuMyAwIDAgMS0xNC40IDExYy00LjQgMy0xNC4x'
    b'IDguNi0xOC45IDEyLjhhNjAyLjggNjAyLjggMCAwIDEtMTUuOCAxMy4yeiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNhYTUzMjMiIGQ9Ik01MTAuNCAxNzYuOHMyLjMgMCAzLjEuOWMwIDAgNC4zLTMu'
    b'OSA4LjkgMCAwIDAgMTYuOC0xMS41IDE4LjUtMTQuNCAxLjctMi44IDQuNS0yLjkgMTEtNy42'
    b'IDYuNi00LjggMTAuNy02LjkgMTUtMTAuMiA0LjQtMy40IDguMS03LjMgMTEuMi05LjMgMy4x'
    b'LTIgMTEtNy4yIDkuOC0xMS43IDAgMC02LjUgMy42LTEwLjYgOC4yLTQuMiA0LjYtMy44Ljct'
    b'OC4xIDQuNWE4Mi43IDgyLjcgMCAwIDEtMTYuMyAxMS43Yy01LjUgMi43LTIuMiAyLjQtNi4y'
    b'IDUtMy45IDIuNS0zLjYgMi01IDIuNWExMCAxMCAwIDAgMC01LjEgM2MtMS42IDEuNy01LjQg'
    b'NC05LjYgNi41YTEwNi41IDEwNi41IDAgMCAwLTE2LjYgMTAuOXoiLz4KICA8cGF0aCBmaWxs'
    b'PSIjYWE1MzIzIiBkPSJNNTE1LjUgMTY4cy0xLTEuOS43LTMuM2MxLjYtMS4zIDQuNi00Ljgg'
    b'NS03IC41LTIuMy4xLTEuOSA0LjgtMy44YTE4OC4yIDE4OC4yIDAgMCAwIDM4LjItMjEuNmMx'
    b'LjgtMS41IDYuNC00LjYgOC4zLTYuMiAwIDAgLjggMi41LTEuMiA0LjJhMjIyLjEgMjIyLjEg'
    b'MCAwIDEtMjEuNSAxNC45IDc2LjYgNzYuNiAwIDAgMC05LjYgNS41Yy0xLjkgMS42LTEuNiAy'
    b'LTEwLjIgNi4zLTguNSA0LjEtOSA0LjYtOC43IDQuOS4zLjQgNC4yLTEuMyA2LTIuNCAxLjgt'
    b'MSA4LjgtNC4zIDExLTZhNjkgNjkgMCAwIDEgNy01IDI5NiAyOTYgMCAwIDAgMTgtMTEuMmMz'
    b'LjUtMi43IDQuNS0zLjUgNS4zLTMgLjcuNCAyIC40LjQgMnMtNi43IDYtOC43IDcuM2MtMiAx'
    b'LjMtOC4xIDUtOS44IDUuOC0xLjcgMS0yLjQgMi41LTMuNCAzLjItLjkuOC0zLjcgMi43LTcg'
    b'My41cy00IDMuMy02LjMgNC44Yy0yLjMgMS40LTE4IDEwLTE4LjUgMTAuMyAwIDAgLjktMSAu'
    b'Mi0zLjJ6Ii8+CiAgPHBhdGggZmlsbD0iI2FhNTMyMyIgZD0iTTU3MC4zIDEzMi40cy0uOS44'
    b'LS40IDEuMmMuNi42IDIuOCAyLjIgNS42LS42YTEwNi41IDEwNi41IDAgMCAxIDEyLjUtMTBj'
    b'Mi4zLTEuNSAzLjYtMi44IDMuNS00LjcgMCAwLTExLjQgNi0yMS4yIDE0LjF6bTE1LjYtMXMx'
    b'LjctMi45IDYtNS43YzQuMy0yLjcgMTAuOC02LjcgMTEuNS03LjYgMCAwIDEuNiAxLjctMS43'
    b'IDMuOGEzMTEuNyAzMTEuNyAwIDAgMC0xMC44IDdjLS43LjctMiAxLjYtNSAyLjV6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iIzdiM2MyMCIgZD0iTTQ5OSAxNjNzLTQuOCAyLjYtMy4xIDQuMmMxLjcg'
    b'MS41IDQuMiAxIDUuNC42bDMuMi0xYy40IDAgNC41LTEuMyA1LjYtMy4yIDEtMiAzLjgtNC4y'
    b'IDYtNS44IDIuMi0xLjUgMy0zLjIgMi43LTQuM0w0OTkgMTYzem0tMjguNCAyMnMzLjQtMiA4'
    b'LS43YzAgMC0uMi0xLjEtMS0xLjcgMCAwIDUuNy0xLjUgNi45LTQgMS4yLTIuNSAxLjUtMiAy'
    b'LjUtMi42IDEuMi0uOCA4LjctNi44IDcuOC04LjEtLjktMS4zLTEtMy4xLTEuNy0zLjcgMCAw'
    b'LTEuNSAyLjEtOSA1LjctNy4yIDMuNi0xNS40IDYuMi0yMS40IDE0LjItNS45IDgtNS4zIDEy'
    b'LjYgMiAxNC43IDAgMCA1LTMuMiAxNy42LTIuMSAxMi40IDEuMSAxNi42IDUuOCAxNy40IDYu'
    b'Ni44LjkgMy4zIDQgLjkgOS4xIDAgMCAyLjUgMS4xIDIuNi0xLjMuMy0yLjMuNC0xLjggMS0x'
    b'LjUuNi40IDEuMy41IDEtMS40YTE4IDE4IDAgMCAwLTIuMy03LjJjLTEuMS0xLjUuMi0uOC45'
    b'LS42LjcuMyAzLjMgMi41IDEuOC0xLjUtMS41LTMuOC0yLTItMi0xLjggMCAuMy0uNCAxLjIt'
    b'My44LTEuNGEyNi44IDI2LjggMCAwIDAtOC44LTQuNGMtMi4zLS42LS43LS42LjctMSAxLjQt'
    b'LjYgMy4xLS44IDMuOC0yLjQgMCAwLTEuNC4zLTMuOC0uNmExMy4yIDEzLjIgMCAwIDAtMTEu'
    b'NSAyczEuMi00LjUtMi41LTQuM2MtMy42LjMtNi4yLjItMTAgMy4yIDAgMC0uMy00LjYgMy40'
    b'LTcgMy43LTIuNSAzLjItMSA1LjItMS42IDItLjYgMi4zLTIuNyAxLjQtMy40IDAgMCA0Ljgu'
    b'OSAxMi44LTUuOCAwIDAtNC4zIDUuNy05LjUgNi44IDAgMC0uOSAzLTUuNyAzLjctNC44Ljct'
    b'NC42IDMuNC00LjYgNC4xeiIvPgogIDxwYXRoIGZpbGw9IiM1YTM3MTkiIGQ9Ik00NTcgMjEy'
    b'LjdzMi4yLTE0LjEgMTUuNS0xNS4xYzExLjQtMSAxNS4xLjUgMTcuNCAxLjNzOCAyLjQgNS44'
    b'IDQuMmMtMi4yIDEuOC0zLjUgMS41LTMuNSAxLjVzMi41LTIuOS4yLTMuM2MtMi4zLS41LTIu'
    b'NC45LTIuNyAyLS40IDEuMy0uNSAyLjYtMS42IDMuNiAwIDAtMS4yLTEuNC0yLjktLjJzLS4y'
    b'IDEuMi41IDFjLjYtLjIgMS41LS41IDEuMy41LS4xIDEtMSAyLjgtMy44IDQuMi0yLjcgMS40'
    b'LTIuNiAxLjMtNS44IDEuOS0zLjMuNS02LjMgMS44LTEwLjUgNS4zLTQuMiAzLjYtOC43IDIu'
    b'NC05LjYtMS41LS44LTMuNC0uNC01LjQtLjQtNS40eiIvPgogIDxwYXRoIGQ9Ik00NzIgMjEy'
    b'LjJzMS4yLTIuNy0xLTRjMCAwLTYuOSAxLjItOS0uOSAwIDAgNy41LS40IDEyLjItMi4zIDQu'
    b'Ni0xLjcgMy4zLTMgMS43LTMuNC0xLjYtLjMtNC42LjUtNC45IDIgMCAwLTEtMS42LjItMi42'
    b'YTUgNSAwIDAgMSA0LjctLjhjMS43LjQgMy4xIDEuMiA4LjYtMS42IDAgMCAzLjEuNyAzLjMg'
    b'Mi44IDAgMi4yLS4zIDMtLjYgMy4zLS4yLjQtLjYgMS0xLjMgMS0uNi0uMi0xLjUtLjMtMi4z'
    b'IDEuMmE4LjkgOC45IDAgMCAxLTIuNiAzLjdzMS41LTQuNi0yLjUtNS43YzAgMC0zLjMgMi01'
    b'LjggMi4xIDAgMCAzLjIgMy0uOCA1LjJ6Ii8+CiAgPHBhdGggZmlsbD0iIzVhMzcxOSIgZD0i'
    b'TTQ3OS4zIDIwMy44cy0xLjYtMS42LjQtMS45YzItLjEgNC42IDEuNCA0LjIgMi43LS42IDEu'
    b'Mi0zIDEuMS00LjYtLjh6Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTU5Mi42IDE4MS42'
    b'cy0zLjcgMS0uMiAzLjNjMy40IDIuMyA1IDQuMiA3LjUgNC44IDIuNS43IDUgMS41IDUgNHMt'
    b'LjUgMy41LTEuOSA1LjJjLTEuMyAxLjcuOCAyLjQgMi42IDEuNSAxLjgtMSAzLjMtMS41IDQu'
    b'NS0yLjIgMS4xLS43IDMtLjYgMS40LjMtMS45IDEtMy43IDEuNS0xLjQgMS41IDIuMy4xIDE2'
    b'LjIuNCAxOS4xLS42IDMtLjkgNi44LTEuMiA3LTUgMCAwIC4yLTEuNiAxLjMtMi40IDEtLjcg'
    b'MS44LTIuMy4yLTEuMi0xLjUgMS4xLTIuNyAxLjctMyAxLjMtLjMtLjMtLjUtLjYuNy0xLjEg'
    b'MS4yLS41IDEuOCAwIDIuOS0xLjUgMS0xLjYgMS0xLjQuNC0yLS42LS42LTEuOC0xLTEuMi0x'
    b'LjguNi0uOCAxLjItMy0xLjQtMS43LTIuNSAxLjMtNy42IDQuOC0xMCA1LjMtMi4yLjUtNCAx'
    b'LjItNy4xIDEuOC0zIC43LTUgMS40LTguNSAzLjMtMy4zIDEuOC0zLTEuMS0yLjUtMS41IDAg'
    b'MCAxLjMgMi4zIDQuNy0uNyAzLjQtMi45IDIuMy0uMSAxMC42LTIuOSA4LjMtMi43IDYuMy0z'
    b'LjEgOS41LTQuOCAzLjMtMS43IDYuNC0xLjggNC00LTIuMi0yLjQtMi40LTIuNS01LjMgMGEz'
    b'NC41IDM0LjUgMCAwIDEtMTYgNi40czE4LjgtOCAxNi45LTkuMmEyMC44IDIwLjggMCAwIDAt'
    b'NS4zLTIuNWMtMS4zLS4zLTEuNy0uNi00LjcuOC0zIDEuMy0zLjUgMS42LTQuMyAxLjctMSAw'
    b'LTMuNS42LTcgMi40LTMuNiAxLjktNS41IDIuNi04IDQgMCAwIDEuNy0zLjMgOS4xLTUuNSA3'
    b'LjQtMi4yIDExLjEtNC4yIDEwLjQtNC42cy0yLjctLjgtNC0uNWMtMS41LjMtMS0uMS01LjYg'
    b'MS43LTQuNSAxLjgtMi42IDEuNC02LjIgMi4yLTMuNy43LTUuMSAxLjUtNi45IDIuMyAwIDAg'
    b'LjgtMSAzLjEtMS45IDEuMy0uNC0xLjMtLjkgMi4yLTFoMWEzMi4yIDMyLjIgMCAwIDAgOC42'
    b'LTMuM2MtLjctLjEtNS4xLS42LTkuNSAxLjYtNC41IDItMi41IDEuMy00IDEuNS0xLjYuNC01'
    b'IDIuNC02IDMuNC0xLjEuOS0yLjcgMS41LTIuNyAxLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzVh'
    b'MzcxOSIgZD0iTTQ4Mi43IDIwMS44czEuOC41IDIuMiAxLjhjLjUgMS4yIDEuNi0uNiAxLjYt'
    b'MS4xLS4xLS42LTEuMi0zLTMtMS45LTIgMS4xLTEgMS4xLS44IDEuMnoiLz4KICA8cGF0aCBm'
    b'aWxsPSIjN2IzYzIwIiBkPSJNNDc3LjkgMjI2czMuNy0xLjggNi45LTEuNWMwIDAtMS4zLTQu'
    b'NC45LTMuNyAyLjEuOCAxLjUuNCAyIC40IDAgMCAuMS0yLjktLjUtNCAwIDAgMi4zLjUgNC42'
    b'LjUgMCAwLTIuMi00LjEuMi03YTYuOSA2LjkgMCAwIDAgNC4yIDMuNHYtMi4zczEuNy0uMyAz'
    b'IC40YzEuNC44IDIuNS03LjYtMS41LTkuMyAwIDAtMSAxLjUtNC43IDIuM3MtMy43IDEuNS01'
    b'LjIgNC4zLTMgMi45LTYuMiA1Yy0zIDItNSA2LTUgNi40IDAgMCAxLjUgMiAxLjMgNS4xeiIv'
    b'PgogIDxwYXRoIGZpbGw9IiM5OTkiIGQ9Ik02MDMuMSAxNzcuOGMxLjMtLjItMS40LS45IDIt'
    b'MWgxYTMyLjIgMzIuMiAwIDAgMCA4LjctMy4zYy0uNy0uMS01LjEtLjYtOS41IDEuNXMtMi41'
    b'IDEuNC00IDEuN2MtMS42LjMtNSAyLjMtNiAzLjMtMS4xLjktMi43IDEuNS0yLjcgMS41cy0z'
    b'LjcgMS0uMiAzLjRjMy40IDIuMyA1IDQuMiA3LjUgNC44IDIuNS43IDUgMS41IDUgNGE3IDcg'
    b'MCAwIDEtMS45IDUuMmMtMS4zIDEuNy44IDIuNCAyLjYgMS41IDEuOC0xIDMuMy0xLjUgNC41'
    b'LTIuMiAxLjEtLjcgMy0uNiAxLjMuMy0xLjggMS0zLjYgMS41LTEuMyAxLjUgMi4zLjEgMTYu'
    b'Mi40IDE5LjEtLjYgMy0uOSA2LjgtMS4yIDctNSAwIDAgLjItMS42IDEuMy0yLjQgMS0uNyAx'
    b'LjgtMi4zLjItMS4yLTEuNSAxLjEtMi44IDEuNy0zIDEuMy0uMy0uMy0uNS0uNi43LTEuMSAx'
    b'LjItLjUgMS44IDAgMi45LTEuNSAxLTEuNiAxLTEuNC40LTJsLTEtLjlzLS45LS43LTEuOS0u'
    b'MWEyNy42IDI3LjYgMCAwIDEtNyAyLjdjLTEuNi4xLTMuNS45LTYuNSAyLjRzLTguMiA0LjYt'
    b'OSAxLjdsLTIuOCAxYy0zLjQgMS44LTMtLjctMi41LTEuNCAwIDAtMS44IDItMS43LjIgMC0x'
    b'LjggMS4yLTEuNSAzLjMtMi4xIDItLjYgNS0yIDMuOC0zLTEuMy0xLTIuNyAxLTQuMiAxLjgt'
    b'MS40LjctNC4zIDEuMi00LjgtLjktLjQtMi4xLS40LTMuNi00LjMtMy44LTQtLjItMy45LTIu'
    b'Ny0yLjgtMy44IDEuMS0xIDItMi44IDUuNy0zLjV6Ii8+CiAgPHBhdGggZD0iTTYxNS42IDE5'
    b'Ni45czYuMS0yLjggMTEuNy00LjFjNS43LTEuMyAxLjIuMi4zLjQtMSAuMy05LjcgMy4yLTEx'
    b'LjggNC4yLTIgMS0xLjcuMi0uMi0uNHptMS40IDEuM3M2LjktMi4zIDguMi0xLjRjMS4zIDEg'
    b'LjIuNi0xLjMuOC0xLjYuMS01LjcuOC02LjguOC0xLjEgMC0uMS0uMi0uMS0uMnptMTEtMi41'
    b'czEuNC0uMiAxLjUuNGMuMS40LS42LjUtMS4zLjQtLjctLjEtMS4zLS41LS4xLS44eiIvPgog'
    b'IDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik00NDYgMjU1LjlzLS4zLTYuMiAyLjgtOS4yIDE3Ljgt'
    b'MTguNSAyMC4xLTIyLjhjMCAwIDIgMS4zIDIgMy44IDAgMCAyLjUtNC4zIDQuNS02IDAgMCAx'
    b'LjcgMS44IDEuNSA1LjQgMCAwIDMuNS0xLjkgOS0xLjkgMCAwLTIgMi40LTIuMSAzLjkgMCAw'
    b'IDcuNi0xIDExLjctLjMgMCAwLTEwLjYgNi03LjcgNi41IDMuMS41IDYuMiAwIDYuMiAwcy0z'
    b'LjQgMy4zLTguOCA0YzAgMCA2LjkgMCA4LjIgMS41IDAgMC02LjYgMS0xMiA1IDAgMC0uNC0u'
    b'Mi0uNC0xLjcgMCAwLS4zIDEuNC0xLjggMi43LTEuNSAxLjItNS4xIDQtNi41IDUuMy0xLjQg'
    b'MS4zLTMuOCA0LTYuNiA0IDAgMCAuNi0yLjEtMS40LTIuOGE1LjcgNS43IDAgMCAwLTYgMS41'
    b'cy03IC4xLTkuNC41YzAgMCAxLjYtMi42IDMtMi42IDEuNiAwIDcuNiAxIDguMS0zLjIuNi00'
    b'LTMuOC0zLTIuMi01LjQgMS43LTIuNCAxLjMtMi4yIDEuNC0yLjYgMCAwLTEuNC44LTIuMiAz'
    b'YTEwLjcgMTAuNyAwIDAgMS00LjIgNiAxNSAxNSAwIDAgMC00LjggNXMtMS4zIDAtMi40LjR6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTQ1Mi44IDI1Mi4ycy4zLS44IDIuMy0xLjJj'
    b'Mi4yLS4zIDIuMy0xLjMgMi0xLjgtLjMtLjQtMS41LS40LjUtMi44IDAgMCAuOC4zIDEuMi44'
    b'LjYuNiAyLjkgNS41LTYgNXoiLz4KICA8cGF0aCBmaWxsPSIjOTk5IiBkPSJNNDQ3LjkgMjQ3'
    b'LjljMCA0IDUuMyAyLjUgNS4zIDIuNWEyMS40IDIxLjQgMCAwIDAtMy44IDMuNmMuNC0yLTMt'
    b'Mi41LTMtMi41YTEyLjMgMTIuMyAwIDAgMSAxLjUtMy42em0xOS4zLTIxLjUgMS43LTIuNXMy'
    b'IDEuMyAyIDMuOGMwIDAgMi41LTQuMyA0LjUtNiAwIDAgMS43IDEuOCAxLjUgNS40IDAgMCAz'
    b'LjUtMS45IDktMS45IDAgMC0yIDIuNC0yLjEgMy45IDAgMCA3LjYtMSAxMS43LS4zIDAgMC0x'
    b'MC42IDYtNy43IDYuNSAzLjEuNSA2LjIgMCA2LjIgMHMtMy40IDMuMy04LjggNGMwIDAgNi45'
    b'IDAgOC4yIDEuNSAwIDAtMiAuMy00LjYgMS4yIDAgMC0xLjktMS44LTcuNi0xLjUgMCAwIDQu'
    b'NC0yLjYgOC0zLjQgMCAwLTEuNi0yLTQtLjEgMCAwLTQuOS0zLjMtLjgtNi4yIDAgMC0yLjgt'
    b'LjUtNC43LjggMCAwIDAtMi4zIDIuMS0zLjMgMCAwLTUuNC0xLTYuNyAzIDAgMC0xLTEuNS0u'
    b'NS0zLjQgMCAwLTMuMyAxLjktNC44IDQgMCAwLS41LTQtMi42LTUuNU00NTYuOCAyNTJjLS45'
    b'LjItMi4zLjMtNCAuMiAwIDAgLjItLjUgMS4zLTEgMCAwIC40LjggMi43LjgiLz4KICA8cGF0'
    b'aCBkPSJNNDY2LjYgMjM2LjdzMi41IDIgMy4zIDNjMCAwIDIuMy0xLjQgMy0yLjcgMCAwIDEu'
    b'OSAxLjEgMi40IDIuOCAwIDAgMS4zLS44IDEuNS0yIDAgMCAzIC42IDQuMiAxLjYgMCAwIC40'
    b'LTMgMC00LjggMCAwIDIuMS4yIDMuNC43IDAgMC0xLjItMiA1LTQuNSAwIDAtNC43IDEuMS02'
    b'LjUgMyAwIDAtMiAuMi0yLjktLjR2NC41cy0xLjItLjYtMy41LTEuMWMwIDAtLjYgMS0xIDEu'
    b'MiAwIDAtMS41LTEuMi0yLjEtMi43IDAgMC0yLjMgMi4xLTMgMyAwIDAtMi4zLTEuNi0zLjgt'
    b'MS42eiIvPgogIDxwYXRoIGZpbGw9IiNmZmMyMjEiIGQ9Ik00NTIuNSAyNjcuM3MxIC40IDMu'
    b'My0xLjQgOC43LTUuOSA5LjItOS4yYy43LTMuMy0yLTMuNC00LTIuNS0yLjIgMS0xLjMgMi43'
    b'LTEuMiAzLjQgMCAuNi4yIDIuOS0zLjMgNmwtNCAzLjd6Ii8+CiAgPHBhdGggZmlsbD0iI2Zm'
    b'YzIyMSIgZD0iTTQ1MS45IDI2OC4zcy01LjItMi4yLS42LTQuNSA2LjctMi45IDcuMi00Ljlj'
    b'LjYtMS45LjItMS41LTEuNS0uNy0xLjcuNy04LjIgMy44LTkuMiAxIDAgMCAyLjcgMSA2LS42'
    b'IDMuNC0xLjcgNi4yLTIuMSA0LTIuOGEzNyAzNyAwIDAgMC0xMSAuNWMtMS40LjQtMSAuMy0x'
    b'LjMgMS42LS4yIDEuMy0xLjYgNC0yLjIgNC43LS41LjgtMS44IDQgLjYgNS41YTguNiA4LjYg'
    b'MCAwIDAgOCAuMnoiLz4KICA8cGF0aCBkPSJNNDQ5LjkgMjU3cy0xLjMuMi0xIC43Yy4yLjUu'
    b'NS40IDEgLjQuMyAwIDEtLjIgMS4xLS41IDAtLjMtLjgtLjctMS4xLS41eiIvPgogIDxwYXRo'
    b'IGZpbGw9IiNmZmYiIGQ9Ik00NTEuNSAyNjcuMXMtMi40LTEuMS40LTIuNmMyLjctMS41IDUu'
    b'Ni0zIDYtMy42IDAgMC0xLjMgMS45LTYuNCA2LjJ6Ii8+Cjwvc3ZnPgo=', 'US_AS')

US_AS = b64_US_AS
index.append("US_AS")
index.append("United States of America American Samoa")
catalog["US_AS"] = US_AS
catalog["United States of America American Samoa"] = US_AS
country["United States of America American Samoa"] = ('US_AS', '', 1)
lookup["US_AS"] = ('US_AS', '', 'United States of America American Samoa', 1)
lookup["Pago Pago United States of America American Samoa"] = ('US_AS', '', 'United States of America American Samoa', 1)
lookup["United States of America American Samoa"] = ('US_AS', '', 'United States of America American Samoa', 1)
details["US_AS"] = {"continent":"Americas","capital":"Pago Pago","currency":"","web":"","lang":"","tz":"-11:00","altname":""}
regional["US_AS"] = ('US_AS', 'United States of America American Samoa', 1)
regional["United States of America American Samoa"] = ('US_AS', 'United States of America American Samoa', 1)
#----------------------------------------------------------------------
b64_US_AZ = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iOTAwIiBoZWlnaHQ9IjYwMCIgdmlld0JveD0iLTI4OCAtMTkyIDU3NiAz'
    b'ODQiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiPjxwYXRoIGQ9Ik0tMjg4LTE5Mmg1NzZ2Mzg0'
    b'aC01NzZ6IiBmaWxsPSIjMDAyODY4IiBzdHlsZT0iZmlsbDojMDAyNjY0Ii8+PHBhdGggZD0i'
    b'TS0yODgtMTkyaDU3NlYwaC01NzZ6IiBmaWxsPSIjYmYwYTMwIiBzdHlsZT0iZmlsbDojYmIx'
    b'MzNlIi8+PHBhdGggaWQ9ImEiIGQ9Ik0yODgtMTQ3djgwTDAgMHptLTE0OS00NWg4M0wwIDB6'
    b'bS0xMTIgMGg0OEwwIDB6IiBmaWxsPSIjZmVkNzAwIi8+PHVzZSB0cmFuc2Zvcm09InNjYWxl'
    b'KC0xIDEpIiB4bGluazpocmVmPSIjYSIvPjxwYXRoIGQ9Ik0wLTk2IDYyLjM4NSA5NmwtMTYz'
    b'LjA3LTExOS40MmgyMDEuMzhMLTYyLjM3NSA5NnoiIGZpbGw9IiNjZTVjMTciLz48L3N2Zz4=', 'US_AZ')

US_AZ = b64_US_AZ
index.append("US_AZ")
index.append("United States of America Arizona")
catalog["US_AZ"] = US_AZ
catalog["United States of America Arizona"] = US_AZ
country["United States of America Arizona"] = ('US_AZ', '', 1)
lookup["US_AZ"] = ('US_AZ', '', 'United States of America Arizona', 1)
lookup["Phoenix United States of America Arizona"] = ('US_AZ', '', 'United States of America Arizona', 1)
lookup["United States of America Arizona"] = ('US_AZ', '', 'United States of America Arizona', 1)
details["US_AZ"] = {"continent":"Americas","capital":"Phoenix","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["US_AZ"] = ('US_AZ', 'United States of America Arizona', 1)
regional["United States of America Arizona"] = ('US_AZ', 'United States of America Arizona', 1)
#----------------------------------------------------------------------
b64_US_CA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc1NTgyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQ2FsaWZvcm5pYS5zdmcucG5nIgogICB4bWxuczppbmtz'
    b'Y2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAg'
    b'eG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3Nv'
    b'ZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94'
    b'bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpz'
    b'dmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZz'
    b'NTU4NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzU1ODQi'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNTU4OCI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQWIKS1VsRVFWUjQy'
    b'dTE5ZDN3YzFiWC91ZE4yZDdacWQ3V3JWUytXYk1zVk42ckJCbU13b1R5YXdTK1laZ0xoMFo5'
    b'RGk0bmovQklTYWdqdApCVWdnTDdUUUhEQTlGR09xQzY2eVpVbVdaSFh0YWxmYnA1Yzc3NCtS'
    b'WmRuWUp2d2VFT3N4MzQvK2tHNmJPK2M3NTl4enp5MUNobUdBCmhkRU13aEtCUmFFRmkwSUxG'
    b'b1VXaFJZc0NpMVlGRnF3S0xRb3RHQlJhTUdpME1KaFFLRXVTcm9vV1FJZHhSUW0zdjk4OElN'
    b'dkxJR08KWWdvSDNsZ2RlMk8xSmREdkg5UzMwZ3FXbGNUN240TmhZRmtoYkl3bDF0R25oWU1m'
    b'cmRmeXZNWUp5VFhyTFptT0FpMDBNRTY4OXptVwo1ZUdVdnVmZk1IL3BmdW9WWGRxYlR0aHNo'
    b'Zk9QUllUbDkzNkhRUDkvcS9aY1M4ZTJueXpMTjdZZW9veXJybXJLbis1MFQ2eTFwSHc0ClVt'
    b'aU9meTBySHU1NjRvVUQ1aFl2UEczQy9iZVJyTU1TOGVGTDRiQWp1djI2LzZmbCtiMm0yZTJj'
    b'OVBEeThCa25Xc0lkSGU1TTZMUTUKaE0yMlQ0c01IVnB3Z2lYWlVVTmhldDBXWlRBRkFJZ2tF'
    b'RWtBZ0pMTXBOZHZ0U1E3YWlpTXJmb1FBT3dsNFptdlBYYmtPMCt5bFNVQQpFSHZkbXVPUGty'
    b'SFF3SGpOcE5OOTB5Wk1mT2dYZElFSEFMUWMxN2owZDZuUE5zMXBmTnVhUzR3Q0NuTU56ZW0x'
    b'V3l1dXVuQy85TDRYCjMvSk1ySE5Qc0tZVGg3OUhhaGlBMERmTytnN0E1YlBSbmc2YXNlbTY2'
    b'dlVGZytGaWk4TFJnV2h2NTd1dlBiTjk4eGNEL1QwWTZ3Q0EKRUJnR2pCazNlZGJzK2ZOK2RJ'
    b'R0RkWDF0STZMSTg3a3NRUklGZ1RENkhqKzdIenFGdXFhOS9QUkRiNi84cTZvcUFNRGFhQnRO'
    b'dSt5TQowMDRuTW55NHdOMHhrS1Fjcm91dXZPM29PUXRvZW0va1hlRHpYZTNOWGJ1Yk85dWEy'
    b'bHNhWW4zZG1xYWFXYXpMSFNtcENrZEtweDl6CjBveWpUMlJzZG92Qzd3cmJONi85NjMvZDJk'
    b'ZmRQdVJWRStpSXFwS0FtNlZKZ3JYUkdCdFpVZDRkUzViNHZXdGJ1aEJKQlVJUkIrdlMKTkpY'
    b'UDUxS0RNWVMrL3EzdER2YUUrV2ZQUC9QZmk4dXFMUXEvTlJpR3NXUEwyamRlZW5MNzVxRzFa'
    b'WVNBSnFtcVVFRnAwQnQwc3dEQQoyaGdBMERFbVNVSld0VmZYTnRJMG1ST2tnSWZGR0FnRVlh'
    b'K3IwT3ZhM2hYTmk3S3E0NjgreFVaVHNxcnQrVGpJR2NlY2VNRmxOeDdPClJJNE9DblZkMy9E'
    b'WmUzOS85dEhlcm5ZQUJERFU1eUtmcTZZb1dCWDJHd1oyTU16d1FNWkxpcDJoRUVJN3VtSmVw'
    b'eU9aNDZ1Sy9BeEYKcXBydVllMEFLTVVKZmNuc2p1NllJS3Y3UGFzeVZCQndzU3JHVFQwREJF'
    b'SFlhRW8zNE5Sekx6L3Y0dXNPVCtGUWh6OS9IVzA3bi9qOQpIZjJkcllxbUZUZ2RQcGVqTDVs'
    b'VE5NMUdVL1ZsWVE5ckg4amt5d3Q5SXgwUnA1M3BHRWhWaGYyMUpVRlIxc3FDUHNMTTNSTUtE'
    b'THBaCkwydG5iY3puVFIwamRaRkF5RVpUazZzaVdVRks1dmhDcjZzbTdOY3gvdnpOWndTQlcz'
    b'elZyUWdSRm9YL0ZHUlordS83bGtiS3gvcUwKSzU5NFlMbXF5S1ZCWDZHSHJTOE43K2lPZFdp'
    b'YWpTS1BHVnRCRXNTR1hUMUJMK3QzT1R6c1h1OUR4emlhenBjWCtqUk45emhzeElIYwpUSm9r'
    b'YkJRNWMweloybDNkdzZZSUd3Wk5raFJCT0dqYXpkckRYcGZMd1RBVU5XL3FtRTgrZWYwNWdy'
    b'em95bHYrcndYWXZsMTg4ZEZiCkwvN2xEN0lzdmY3c0k1MDdOL010SHovMzhDOVZSZlk1SFpN'
    b'cmltYlVsTm9aT3BrWEFFRFZzZC9OQnR5T2lwQXZtc3FuT0JGalE5dWoKVHpyR3NVeGVWclZF'
    b'VHNpTHlnR2ZoUTNENTdRSHZjNzYwdERlY1FXQlNXY3NrNDluT1U1V0dJb0NBQWROejZndGZl'
    b'KzFwLy94MnJPVwpGaDRLYnp6eklJdmtLMTkrc2l6b1RYTFM2b1kyMDhxNUhVeUozd01BQklK'
    b'cDFjVzl5U3cyREVYVC9DNTNiWEVoU1JDU29yVVBKRGxKCm5sUVJvUWhDVXJUYVNGRFQ4ZTVZ'
    b'Y25MRmdmZnlFQWdSQkNFcjJtQ09IeG1RQ0hoWUhXT0VVS0hiNlJ2U2JNTXdVSm9Ud2w3WDA0'
    b'L2QKVlJncG5YYmtIRXNMRHp6VjY0MUdNVGFtVlJmN1hlejBtaEpSMFV6bjBNSFFncXdZQnNp'
    b'YXZuNVhqMWsreTBzQVlLUEl5cEMvT3V5bgpTWEl3SitRRlJkWDAzUU9wdmxRdUx5b01UZVVr'
    b'NldBZW04dk91QjFNV2hDSFZkRG5kTkFrR2N0d1B0WXhycVF3NEdZeE5xSnBMaXRLCmdxVEdN'
    b'eHpHK3NPL1hScnI2enA4NUVhdVdMSGlNT25LczQvZm5ZKzJ6YW9yTC9LNVNnTGVuQ2k3Yk14'
    b'QWxnT0FGQ2M0YmJhTUlINjgKdlQzSkRVazhLOGdZRzREQWFhTmxUYU5Kb3F5d1lDQ2JkekIw'
    b'VTIrY29jamVaSmFYVlpKQUFROUxrK1RJWjJrNkpnakVTMG84eC9VbgpjNllGZHRtWmFUVWxu'
    b'Q2k3SFRhR29UeXNuYUVJVGxaNFNXbnNHVWp6WWtZUUFVRFQxRVNzOTlnVFQ3ZTBjQjgwTlh6'
    b'NXpxdFB6Nnd0CjYwMWthSklDZ0p3b05mY25JZ1Z1aEpCaHdOcGQzVnM3b25sNTc4Q1c0Y1ZO'
    b'N2IwZmJHdnRUV1ZGUmZPd2RyZmRsc3FMbnpWMXFockcKQnFRNGdaY1VpaURJZlY4enc0dUpI'
    b'QzhwYW9vVE43VDJpc3JRTExDdU9PaGxIUlJCS3BwR0ltUTZRWnFPT1ZucFNxUmxUVGNNS0hD'
    b'eApBTEJsdzhlSmdUNXJMTnhuenY3Y24rNXowSFRBeGU3b0hoaFhXb2dBVGFtSTFJUUNPaGlw'
    b'SFA5QlF6dUFrUk1raE1EQlVNTkNWM1dzCjZyaTVOekdycm93aUNjTXdDQUo2azltUXoxVmM0'
    b'T1lsT1ZMZ0tRdjRHSHF2Q21vWWR5Y3lyYkZrVmNnZnozSzhOUFJOMkJtNm9yQWcKSjhxSlBD'
    b'K3FTa2FRNmt0Q25LeTI5Zzh5TktucE9KbmpDMXgyQjAzWmZLNnNBZzZIMDZKd0x3YjZ1enZi'
    b'ZCtxYTl1cW1WcitkZkhOagpjOWpuT3FxdTNPVmdBTURyc0UycDRMZDFSVzBVZWN5NGlzcXdm'
    b'OVg2eHRRZWN3b0EwWFErblJjREx0YWMxSnRUL3RwSTBPV3dzWHYyCkpSc0dBQmdJSVU1U2R2'
    b'WW04cUtrYUpxK3g0TWxDV0xXbURJQWlHYzVYZGZkZG5kRjJFZFRCS0ZDejJBbUw4b0FnQTJZ'
    b'V0JZcDlEcTcKRXBtQjNmMW1iTll5cEVNSUY1ZUhBLzZJMzFNNVpxSXpWR2tZc0t0L2NITjcz'
    b'M0RvWkV3a1FKTkVzZDh6SmhMRXVrSHVHZGhvaW5RNQptRWlCTytCaEFZQ1gxYzU0QmdCSy9G'
    b'NmFJa3Y5WGdkTm1ZRTNoRURWY0VjOHZXVjNuNktxQU1DSnlyQTJWNFFLQWg1V1ZMVkVYaWp5'
    b'CmVXcUsvQURBUytxSERlMGFOa3l2MkVhUjJNQ0FvRCtkTXd6Y3NPbHppOEs5ZUcvbGs0ckFK'
    b'Zk84T3RDR3N2MHBUdEIxM0ozTWlPb1EKaFg0M083YTBzQ3VSK2JLdDUvbFB0eVN5M0I2dlJC'
    b'OWZHanFpdXFUQTZkQXc3b2luekJpTm91bG0rTnRwM3p1alVIVjlVM3RmVnBEdApOcG9kY1dx'
    b'QVFLaWt3Q1BLU2w2UVFoNjJLbHhBRUNnbnlGKzBkQ1Z5M0hDWnFWV1JzTmZkMmpjWXozQUE4'
    b'UG5xTnl4RE9vVHRtOWUrCnUvTFBzK3VyWkUxMzJSZ0RqSlpvSXVoMm1yRktzMHhlbEFSSnhZ'
    b'YXh0U002WE5GQjB4N1dWbHNVTkhtU0ZZMFRGUjNqUFdaemZ6QVUKT2JFc2pNRW85bnUyZDhX'
    b'YWUrTm1lc0RqTFBRNVUza2htczZQTHdzNTdZeW00N3dnZHlYU0FKQVRKSW9nNmtxQ2RodE5F'
    b'SkRtUmZNUgo3UzA3TU5ZSmd2eWhhMkZ2Vi9zamQ5NDRxN3FZSklrU3Y4Zk4ycmQxUmhFaUps'
    b'VVVsUVI5dzZHVzNmRjBmem8vSW9hQ0FJQ215ZWxqClNrMytOQjIzeDVMeGJONGtyeitkTzBC'
    b'RWpTSnJJb0hxa0YrVTFWaHFiNEd5Z0NlZEYrSlovcWl4NVVVK3Q0NXhmeXFuNkxwaGdJMm0K'
    b'QWg2MnJqZzRxYnlJWmVqZVpLNHZsVFZyQ1h4Kzk2N0dIN29XOXZkMlBQQ0xLemd1OTlZbXpz'
    b'UGFDejJzeWltNXBDQXoydGFPYUcwawo2QzB0VkRUdGs1MmQvYW1jYnFEcFI1ODRlZnF4NHlm'
    b'TmNIdjlWMTg0MjBGVElhOExBQ1JGMjlEYWsrRkZPME9iL3FvZ0thS2lrUWdaCllGQWtBUUFJ'
    b'RVp3b2JldUtDYktTeUhJalE5dnQwV1NoengxMHN5ekRBQUF2S3h2YXVtbUtJaEJNS0F1RnZL'
    b'Nnd6d1VBWFlsTVExZDAKcEg1M3REYU9HVGY1QjAxaHBLUnl6dWtYdmZ6WGgxUlZrWFJVZnNS'
    b'SnpudmZhQTZoVElnSWUxMFpRZHpjM3RlZnlldUV2YngyNGhYWApyeWl2SG10VzNQRForMjZI'
    b'YlVwVk1VMFNwaHVaRXlXQ1FCUExpOTdaM0FJQXZhbnM2b2EyZ0llbFNZSzFNNktzS1pyV2w4'
    b'eW1PTkhjCm1URVNuS3hTbkhCVVhUbENNSkRKeDdKY1RsQUlwTlJHQ3V1S2c2eU53UVlrODBK'
    b'blBMM2Z5cFFvOEQ5MExVUUluYkZ3eWJ3ekx1elkKMVZnUUNLMWN2aXhUU1hUNURGM0IyN3Fp'
    b'Ym9lTmsrUmdxT1NHT3g2b0hGTlBqZ2l2YkY3N2dkUEdsUGc5T3NieExOL1lNMkFZeHBGMQpG'
    b'ZXRhdXN3Z05jWkdmem9YeStTd2dSaVNJRWtrcWJxWnRSOS9ERVVWZXRpNmtxQ0RvWFNNdXhL'
    b'WnJrUkd4N2dpN0o5Vlc0b1FFbVIxClIvZEFScEJpbVNGTFhsVGd6dkNpcEdpcHdaamx6Z0FB'
    b'T0J6TytpbXpQbnJubGJYOTIyZ1BZSU9jYzhvNXdYREpaeCsremlqeTFUZi8Kcm1ic3BQMnF0'
    b'TzdjTXFVeVFwRUVMeWxyR3R0dEpEVzVNaktZNHdheS9MNXJFUUJnS0xvT09nREFoWmZmUkpB'
    b'a1E5dlNxWGhINjA1dgpRV0Q3NXJVMlhReDRuRlVodjRaeGZ6TFhrOHhLcWxZWktwaGVVNUlY'
    b'NWFhK2VNRGw3RXRsMHB4a0J0a3J3NEhTZ0Nma2RXM3ZqQ1VUCkZvVWpNR3YyZkZIa1JaNmJQ'
    b'ZS9NVUtRTUFFNDZiV0U2RmE4YVU3OWZ5WGkwaDFHNXNtQ2tlekR6WlZ1dm5hSm0xWlVuc2x4'
    b'anp3Q0EKTWVPWWt6YXRYVDF5S3dKRFVkakFtbzV0ZHNlcC83WjRaRWpvSitjZVZWWG9yU3NP'
    b'WUFOeW9yUjJWemNuU3RPcVMyME10YW05TDU3bApPRWxCYU5Cc0RDRlVYUlNvTHkzMHU1MEFF'
    b'TXZtdWQ1T2ExNjRGMDZYNTdSekxqbDM4VFVtZndEZzh3ZS95aDhBZlBqMlMrVkJYMnQwCmNI'
    b'VkRXMDZRNnN2RHV3ZVN6WDJEZ3F4T25uN3NmLzd5NFIrZGQ5bHc0ZUlDejl4SjFiUEhWd0hB'
    b'VzYvOHhkeW9PSXlBeXo2bEttSzMKMGFrOFA1RG03RFE1c1NKU0d3a21zdm4rZEk2VEZBQkFh'
    b'TWlBSXpDT3FDNE8rOXcwU2RBa01iV3l1TDluZDJwd3dLTHdteUdiVG43MAo3c29VSi9ZbGMy'
    b'R2ZtNkhJcHQ1RWMyOGlMMHFzMDMzMXpYY2hoUDc5aXA5ZGVQbE5abm0zdzFZZTlKa0wrb1B4'
    b'Nk9aMWEwWm9JU1lBCks2cVd5WXZSVEo2WEZUdE4rVmo3TzF0YTJtSXBTZEZJa3J6OHV1V1hY'
    b'ck5zMkN6M0pES0tOaFRRQ2JwWmlrRGJObjVtVWZnTm9DcnkKZzcrOXlVUHFOb3BFQ01hWGhn'
    b'UlpOU00xRG9melo3OTYxT2NQbWhidnJBdXZQTy9pNjBpUzdFL2wwcHdVOGpxcml3SUE4Tjdy'
    b'eis5OQpjNElrYlM0TVJtdHNzSE1nbzJwNndNMDI5Y1l6dklpeFVUV20vaGYzUFgzeUdZdm1M'
    b'aml2cktyT3JMS3RzLytMNXU2TjdiM1JkTjR3CklPUjEvZTNKKzNQWjFMOVdMSWZSZXVIWHJt'
    b'WThkczh0VWwvVGpKclNvZ0lQeHNiR3RsNHprT2J5K0g1eDcxOXJ4MDhaV2I1KzhzenkKNnJH'
    b'ZnJubUhFNlZpdjlmdmNqVDNKUVF1ZDhiQ0pjTmJ0dGQ5c2RvRGdxaW9iZEZraGhkVkhTZHlQ'
    b'QURVMWsvOStlK2VqSlJXbWt3ZgpQZWUwZERMZTI5V21hbnFLRTJMcC9LNyt3UlFuSUlTU21X'
    b'd3VrNXg1N0x4L3BXTS9XdmFScm56bTBlWlBYcTR2Q1dNd2VoS1poczZZCkdVR3RHbE4velcz'
    b'M2xKVFhITERXcHJXcjcvdmxOVUdQazVOa1NkSG1uSExPVlV2dkhNNzl3Njl2NExzYWRJeWI5'
    b'Z1RiQUdEdWd2TXUKdStZT21ySHQxMVFtTmZqcGg2dWFHemJ5WEs2dHBVSGZZMUZKa3Z6akM1'
    b'KzZ2UVUvZEkvMDBJaEhlMTc3MitNTWlib0dNalJGU0twdQo4bGMvWlZidHVDbFBQcmppdEhN'
    b'djVibGM2ODZ0amMxYmp6OStnYXJJd1ZCeDg0Nk5nL0VvQUppN1kwaUs4bmo5cWlJUDArTXRD'
    b'SFkwCjVHbHE3NHl6ZHZ6VVVGSHBCMis5S0FyOHNYTi9GT3ZyS2ltdjhRVUtLWXIyK1lObm5M'
    b'L2tqUE9YQU1DVzlSL2Y4NHVmRHNYL2RMMm4KczdWK3lpeExDdzhBalBWWWYzY3FNZkRDVXcr'
    b'MHR6VHNHY09RR2NydUQ5amJpMW5lVG1KQXdieUNERWk1NmJ5RDh2R3FQNmNlMFo1RgorNzVa'
    b'emtsM2hld1graWZxc2lMd25LSklnL0YrQjBYeWtvd05Bd0FFRzlsWTRYYUxXdHBGNndRYWs5'
    b'S3lGTFpqVktSUnRjSHlTZU9uCmxWU002ZG5kMHQvVDBkdmRsb3p2RGJoZmVkT3ZqenorRkRD'
    b'QWRibC8wQlFxc2tTU0ZEYXdlWXBsODdvMVR6eHdSemFkL0dwSmpVUnIKNnd2NkFnYzl0akty'
    b'T1JOSlNRaUF0NU1HUW9RQmFTZTF2Y296TFFrTGk0NW8yUFNad09YM3E4TGJ5ZmVtRjhyMFFm'
    b'MDd0NmlkM0FkMQo5a0JuVzlQZUVacEFPYmNOVTlUOGNVY0pQTGZ3MHV2THF1cnNkc2YzdVdQ'
    b'NFgweGhhbkNncDdNMVhGeSs2bTlQZkxEdEl3bHdYbGVPCks1MG95eUtwYU4zdExZYXh6N0VI'
    b'QTZIT3NHTnJqY2VVdFVQQmxURkJzSk9ESG9hMzc3V0hwRzdvNUZmMi94cFFuSkxINW1FTXVM'
    b'bXUKYnNQQW1BQ0pKalVTeVRUUlhPYnFDeDdnbTZCMVRHQ1FhWUxFeHRpWVZFZjVVRjljMUJV'
    b'Q0c1eUQybGpuRld3a0FxTW9KUWZ5YXRtZwpOQzVVUFdQYWNTZWZ1Y2hYRVB6cWdQcC9nVUpa'
    b'RXJkKytVbE4zYVJzWmxEVHREZGZmZnE1M1o4amdLNlFJK21oaHlmUlBrNHIwMnpqCmRTYzFt'
    b'TTZsa3lrM28xRUlER2dwZFdaYzlIQnJyS3lEQVFnTWhTSlVhb2hVa2RsSEF4eXk3cFIxUnNY'
    b'OWU3UVdHWVpEd1JwSjZBaEcKTXMzS2VuRlNFaGt5R3JCaGhBQ0EwbzNhWHQ2aDZDazMweGwy'
    b'd0lGMmhST0dnZmM5bFZnVEZmdzVwUnE1YnJ6ODlqRmpKMy9YNTFXLwpQd3JUeVhocjA3Ym5u'
    b'bjkwcmRERFlNUXhpTGVUQXo1Ym5xVVFHR1Z4cVhSUUVteGtSNFROc2hRQU1KcWhVUHZMckRn'
    b'cGhkUHlRSUd0Ci95dFcxS2JpdWw2dUppWmtXV3JRYTJ1c2NKbVNqYVFrcDZqckJNcTRtYlNM'
    b'R3BaN3lhRGs1VFdaSm5wQ2Rva21rV0dVSlNSVzFobk4KU0xubzNzS3ZQMXdZekNvVHVqaUhv'
    b'dStPc0szRnJJRVFBQkFZRUJnNmdVamRxSWlMUnd2c25jc2VyYWdlTjRvcE5BeThzK0hMRDk5'
    b'ZAp1Ykx4bzVpTDZDeHltc1RRT3E2TWlZTWVKdTJtVGNKVUVnQ1pTZ1dWY2NFaDRjNElPMUts'
    b'U0d4NGVVMmxrRVlnMFVaKzFVNENBZ0liCkZEYVFBWWNZMWI1VGxDZEVSc1c3aTV5WUFQTzlw'
    b'clJuTDU0MC82TExsNXFSaDFGRDRVQi85MGZ2dnRLNGRYMS9mMWNySTdkSG5EbDIKU09nU1Ey'
    b'b2p6SmROeFl5S0djMWdOSjNXREFNQkFHQ0VOQktwSk5KSlFpZEFvUW1kUURyeERVNVJrN3JC'
    b'YUpqUkRXYW9mY3hvQnFQcQpqR1l3R3JZYmhJZHhlRzF1djh2cm9td09oeE1ScEdGZ1VlQUFn'
    b'Rk5sU1pWNFhSWmtTVkJrVGhOMUJDcUpNSUUwRWdFQ2hTUUFRQ1dSCnNhZExqSW9wYkZBYVpu'
    b'U0RCY29CcE1mR21yY05ZQU5UV2Y3b0kyWmZlOXU5bzRuQ3BvWXYrM3M3aGpnVGVDNmZIUTR4'
    b'OC9sY2JEREsKaVhtV3R2dmNCUzZQeitYMnVUeGV0NmVBWmhpS29qVk5sVVJlbGlSWkVnVStK'
    b'L0Njcm1zQ2x4ZDFPUzF6YVlsUENKbTBtQmRncUVGRwpNd0NBeG9iWDV2TGEyQUs3Sit3SitI'
    b'MEJ0NmZBNWZFNTNSNm5hKytQeStPek81d2srYzMydkNpeVpPNDY1TG1jZ2JIQTV6VlZsU1RS'
    b'CjFIM0dabU1ZRzBsU0xvL1g1Zlo5enllOFIvRjFDVHlYNC9OWjF1bEdCTUV3dHUvSC9Uc01n'
    b'YXgvUVRuYVlWM1FaRkZvd2FMUXd2OFMKMytaS3hlUDNMOXZaOENVQWVIMytwU3NlOVJZRUFP'
    b'RCtGZGVLQW4vSFBYOEJBRjNUYnJucXJBVm5MNTUzK3RDMWJTdWYvYStHalovOQo2Zy9QcjNy'
    b'aGlVL2VYMlVtanBzMGZkR1NwZmN0LzQ5MEtnRUFnV0Q0bHQ4OC9zVkhiNjE2OFU4QVFKSFUr'
    b'WmRlZitUcytUZGVldW81ClA3NzZoUGxuUDNMWHpZek5mdVZOdjM3aHFRZmFtcmJkY2U5L0Ew'
    b'QnZWOXU5eS8vanJBdCtjdUpwNXgrc3czKzg5L2JtSFpzQXdPbDAKWC9meis3bGM1ckg3bHcz'
    b'bjN2Zm5ONTU5L0o2TmExY0RBRW1TQ3krNXZycHU0cDIzTFZsODFhM1RqcHB6MDJVTEZweTll'
    b'UEtNNCs1ZQpkcFZaZnZyUmN5Lys2ZTJQM2ZkelhkT3V1ZTBlTTdGeDY3cW5IdjcxVGNzZmNu'
    b'dDg5Nis0SnB0SkFVRDk1SmtqMTd3T0l5MWM4NCsvCkV3UlJHQzVwYmRyVzBkWUlBSklvYk5u'
    b'd2NlUFdkZWxrSEFBTU1QcDdkdWR6NmVFcW1WUWkydGNKQUpuVVlDTFdPK09ZRTJjY2MyTHQK'
    b'K0tsZHU1dGJHamNIQ29zS0FxR203UnY3dXR0NFBoZVA5bFJVajgxbWtwdStXQTBBOFdqUG15'
    b'OC9hUmhHSnBrd28rSHBaRHk2NS96dApqaTFyNDlHZXpldlhIS0xEbWZTZ3dPWEtxK282Mm5h'
    b'Mk5HNlNKS0cvWjNkMTdRU3pHd0FvbDBubHMrbEpSeHlkU1ExdVdyZEcwN1Y0CnRFY1NlZlBw'
    b'ZkQ2bnEybzgyaE9PbEhxOEJaKyt2d29BQmdmNlJ4NDlGQVcrdjJlM3FrZ2RiWTJ0VGR2OGdS'
    b'RERNR3YrOGZmRDE1Qk8KblhuOEpWZmZYbFU3Z1hXNkFhQjV4MFpkMHhCQ1RRMWZmcjFCb0ps'
    b'RlM1WXVXckowemlubm1Dbm5McjdtekF1dUdGbm02bHZ1R3Q0ZgpCUUM5WGUwN0d6WWNzTFdk'
    b'MnpZZ2hKcTJmN25mbHFmOVVGUlM4ZE9mL1haa3lrbW5YMkIydzF6YzkvajhWOXo0cTBPdjZK'
    b'NjQ0UHhaCng4My9aK1J6MXFJclR6bnJvcXJhQ1llcElUVlJWbFgzMjBkZkdaTGoxZzJoU0Ju'
    b'cmRPM2N0dUdZdVQ4NmRFVmQxejU2ZHlVQWZLUEwKQ0VadWh4a1oxV3Zhdm5IbWNTZHYrUFM5'
    b'cnZibWJ5U3lMZXZYUkhzN0s2ckhWdGROQkFBRFkzTTZmNGdxTzdhc3krZlMvK1NNZnQ3cApG'
    b'dzZQSTRjcGhTUFJ1RzM5aEtsSHNrNzNwclZmZjArd0lrdFAvUDRPQUZqeCs0TmVESEx0aitk'
    b'S2dqRHoySlBNUDJ2cnAyNzY0c1BDCmNFbnh2aHN2dXRwYnVGem05UE11Yjl5eXJuSHIra05R'
    b'Mk5IYWVQM0Y4d0NncEt4R2tnUUFlUDNGUHdQQW1SZGNZVklZai9WZWNjNlIKQURCNXhuRUhh'
    b'K1REdDE4Q2dLT09QM1hVdXpNbVZFVk9KK05lZjZHdXFaMXRUVlcxRXd5TVkzMWRxY0dZeHhj'
    b'NFJFVUg2L3JqQzU4QQpBR096N1R5STRUMy80dXZlZXVVdjhlalFZRFA3cERNVHNiNVlmL2Qr'
    b'Rk81czJFQ1NaR0tnTHhDS05HNWJmL3I1bHgvc29mNWcwWUt6CkwzNzZzZC9GWTcwZW54OEFm'
    b'bjdYazNYMVIxRFUwSktXeCt0ZmVOa05CRUZPTzNJT3orY08yTWhWUys5TXhxUHZydnFucnFR'
    b'eGcwb2oKaDRQRGF5eFVGYmxwKzhZYkxwbmYxTENoZWNjbWpQVjFINy96OFh1dklvUjJiaHNh'
    b'dExDT05VM1ZOUFdyZ1NHYjNXRTc1SkwzQ2FlYwo0L2I2dFQySHBHbUdPZVdzSHg5QSs3ZXVK'
    b'd2p5cVlkK0ZZLzJ0T3pZck9zSEhRNDl2c0R4OC84TkFGUlYzdE9teldaM2tOVFF4KzF3CnVr'
    b'NDZiZUhjVTg4MUhld0R3bTUzTURiNzhIRU53ekQydk9EKzVsY1NoVlYvZStLR1MrWWZwbHBJ'
    b'MDh5SGI3OWtXaFdhc1cxWnQ2YTAKb3ViZVA3MEpBTXR2WExSejI0YWpUbGdBQUs4ODg4Z3J6'
    b'endDQUhjKzh2SWhtZ0tBMzl4ODZiQ25NekpMMDdYaFAwOCtZOUdxRjU0WQpXUmRqdlhuSHhr'
    b'VkxsaTQ0NStLZWpsMjNYSFZXWjF0anpkaURuaUlqU1FvaFlwam11NWRkU1pBa0FEeiswdWNI'
    b'N05XamQ5LzY2TjIzCm11OW9wajkyL3pMRE1Fd1BEZ0IyN2R5eStMVEpBTER3MHV2TEt1dEcx'
    b'bjN3TnpjTi8zNDRVbmpqOGdkN085c0F3TUU2eDAyWW5rMG4KaC9kMW5iZjQya3dxUVpMa2VZ'
    b'dXZIV0hFd3RPUG1odU9sQUhBMUZuSEZ3VDJYcVExWnR6a0syNVl3WE41QUhCN2ZPVlZZelZW'
    b'V2JSawpLVTB6RjE5OWUzdkxkbDNIaTVZc3JhNmQ2SFI1cnI3NUxsTURaaDQ3cjdKbXZDUUla'
    b'MTF3NWN6alRnYUEwc3JhSC8va1pvbzZzTWptCm5uS09vaWgyQjN2OXN2c3BpZzVIeWtaMmp5'
    b'Q0lvK2NzR0RkcCtuQktZYmprNnB2dnlxUVNBRUJTMU94NVp3TEFvaVZMelZ4enhEMSsKL3Ru'
    b'ako4ODBVOFpQbnVYeCtjOWJmRzFCSUZSZU5mYnk2NWFiNTlsS0s4ZDhpMkszd3R4V2dNMkNS'
    b'YUVGaTBLTFFndWpIR2pMcGJkYQpVaGpkRkw3am4yRkp3VEtrRml3S0xWZ1VXaFJhc0NpMFlG'
    b'Rm93YUxRb3RDQ1JhRUZpMElMRm9VV2hSWXNDaTFZRkZxd0tQeGg0bjhBCkRjcHBZaUJNR2Fn'
    b'QUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURJdE1qRlVNRFE2TURZNk5UY3JN'
    b'REE2TURCNzVPWXUKQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEF5TFRJeFZE'
    b'QTBPakEyT2pVM0t6QXdPakF3Q3JsZWtnQUFBQUJKUlU1RQpya0pnZ2c9PQoiCiAgICAgICBp'
    b'ZD0iaW1hZ2U1NTkwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_CA')

US_CA = b64_US_CA
index.append("US_CA")
index.append("United States of America California")
catalog["US_CA"] = US_CA
catalog["United States of America California"] = US_CA
country["United States of America California"] = ('US_CA', '', 1)
lookup["US_CA"] = ('US_CA', '', 'United States of America California', 1)
lookup["Sacramento United States of America California"] = ('US_CA', '', 'United States of America California', 1)
lookup["United States of America California"] = ('US_CA', '', 'United States of America California', 1)
details["US_CA"] = {"continent":"Americas","capital":"Sacramento","currency":"","web":"","lang":"","tz":"-08:00","altname":""}
regional["US_CA"] = ('US_CA', 'United States of America California', 1)
regional["United States of America California"] = ('US_CA', 'United States of America California', 1)
#----------------------------------------------------------------------
b64_US_CO = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxODAwIiBo'
    b'ZWlnaHQ9IjEyMDAiPjxwYXRoIGZpbGw9IiMwMDI4NjgiIGQ9Ik0wIDBoMTgwMHYxMjAwSDAi'
    b'Lz48cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCA0MDBoMTgwMHY0MDBIMCIvPjxwYXRoIGQ9Ik0x'
    b'MTMwLjgxLDc1MEE0MDAsNDAwIDAgMSwxIDExMzAuODEsNDUwTDc2MCw2MDAiIGZpbGw9IiNC'
    b'RjBBMzAiLz48Y2lyY2xlIGN4PSI3NjAiIGN5PSI2MDAiIHI9IjIwMCIgZmlsbD0iZ29sZCIv'
    b'Pjwvc3ZnPg==', 'US_CO')

US_CO = b64_US_CO
index.append("US_CO")
index.append("United States of America Colorado")
catalog["US_CO"] = US_CO
catalog["United States of America Colorado"] = US_CO
country["United States of America Colorado"] = ('US_CO', '', 1)
lookup["US_CO"] = ('US_CO', '', 'United States of America Colorado', 1)
lookup["Denver United States of America Colorado"] = ('US_CO', '', 'United States of America Colorado', 1)
lookup["United States of America Colorado"] = ('US_CO', '', 'United States of America Colorado', 1)
details["US_CO"] = {"continent":"Americas","capital":"Denver","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["US_CO"] = ('US_CO', 'United States of America Colorado', 1)
regional["United States of America Colorado"] = ('US_CO', 'United States of America Colorado', 1)
#----------------------------------------------------------------------
b64_US_CT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc2NjYyIgogICB3aWR0aD0i'
    b'MTI3IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDEyNyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfQ29ubmVjdGljdXQuc3ZnLnBuZyIKICAgeG1sbnM6aW5r'
    b'c2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAg'
    b'IHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9z'
    b'b2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkv'
    b'eGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6'
    b'c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVm'
    b'czY2NjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc2NjY0'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzY2NjgiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMTI3IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUg4QUFBQmtDQUlBQUFBZ3puZ2NBQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFqClJVbEVRVlI0'
    b'MnUyZGQyQlV4ZGJBejl5MlBidlozVlRTRTFJSkxTU1VRQ0FVQVVNVnBBcytFYkdBUEJIRlo4'
    b'RUdOcXpZUVBFSmlIU1EKSWlDOWx3QUpwSkN5NmRuVXpXWjd2Zlg3QXhUMGdRLzBNL0F3NTcv'
    b'ZE8zTm03dS9PblRublRMbEludndtdE1zZEVxd2RRVHY5ZHZydAowazYvblg2N3ROTnZwOTh1'
    b'N2ZUYjZiZExPLzEyK25lUmNPSWFRTjUyK25jQ3ZVOCtINytYaWRvTWlQc2Z2UVhpZjZpdVBO'
    b'bkNCMTdFCjFGYmdRYkRMQVhOUm9WNkJwaGxoTTRiSmtjd0JDT2ViVkhoTFQ4VDV0Tk8vRGNF'
    b'eEZLQ1ZHTTBlbXVGdjBNemxaUkJ4VGhCYnlBQVcKS0VId1lnSW5nQmNoQWdBRUxNQ0FSQVpN'
    b'em1NVWNLcEdMa1FITmorc3VqOUdCL3luS29TQXdCRERDZTMwcjhxcjA0MURlOUNNNHVGVwpp'
    b'LzNwZC9Mcm1wM1gwZUxZNkIxa2ZEMFNjV3dyaGlqRU5LRW9INURLaENJT2dCQjRLOExsQXU5'
    b'R1RCTk9LSGpjVnhDQXc4TWFoUEN0ClhIRWNYamZvK29LeStuVjRhbklzaHVENDJVdnZyREh6'
    b'ZC9vUjNQbCsvNVVuMGg0YldxYnlrZmhpeDFLMUg0NGJFbjc5VlVaMW1valYKSXlrbk1JREVB'
    b'bWNWT2ljSytkTzU3SEZDRndVNzBrNC9LUGFLM1B6N2c3a1ZrMWxjS1hCMmhFZ0FBRXhKUTBR'
    b'eEo2bTVYdHMveGtaRgpTTDRYWTQwUER6aTcvZjFBa2tCL2EvcjlVNE9mZVRTVEluRUtOZk5B'
    b'SWNRNzNld3ZWd1hjZ1VWVUlGTGc3U0RRR01JRlJJSlp4aGU1CmNJUWdpV09YanllV1poRmp0'
    b'UFJqc1RBakNBTERCSUVEVENUd1ZpUXdRUGh4UXZnWmdHdGpzcGpDZlluelVxeVd3SnpkRS8y'
    b'MkxCdU4Kb2I4cmZha0UvMnJKU0pJa0tVV2lMNUZqNDFNYTNYMS9QS2EvUnArMDhYWEIzc3R5'
    b'UkdDWWpNY1Z3SHVSbWNHcjZVY0J3Q0xBd2JPcwpTQVFlRGp3c0txZm5BSzhHRUhBbDRHcEJj'
    b'R0hlZklYUXFnYlM4WXRDbTROMWNIRU9MbHFKRnhBaS84ejBwT1d2RDd5REQrQ08wWmVJCjhV'
    b'T3JwZ1FIK2dFQXBocEJJWU12T2xqcjZPK2xyelZWekJNTXloWkpONmZBQ0t3UjV6MUFxdUNO'
    b'NFBkUzVJMDhpSmZNT3RVcWYzVDkKcFlrdnpGZ3RJd1EzRS9wRzJMdUVFbmhhWUpvUUVJSTR4'
    b'UVlTR3pES1h4UytzYUtnenZ1Z2tyaU1JVmFxVGtVSVRSelZhOFhyQS9FNwo5QVJ3S21CZzI1'
    b'YzZ1SGZvN3E4blJVVUVYLzFOaFlMOUp4OWhQMDMyR3RLdmEwbVZwY25vQmdCT1drNm01Z01D'
    b'Z1FmZUtVcUJJWjhPCmY2dTdYMzBZOWJWSFBqc3dZbEwzYmtOVFVrYjRheExjeG9PKytIRWFE'
    b'ZS9uTytMdzJXS2FzbU5TRGpnQTBndU5zWWdYQXdDT293VXoKRWp0b3VUanB1MjdSY0xIZlNB'
    b'QkFDQ1hGaFdTbStwKzVXR2V5dHJYamh0cDRWcjFqdU05SEx3N3VteGFINC9pdkxuZ3VROFVR'
    b'anNjcQo2ZWRzMExkU2I5Kzh2eUxYdHQ0aGNpVnFvekxDKzJRa2RWSEtLVDlzZXlpNWtzVkN5'
    b'ZmpqZ0VtdnVRS2VhcjRzaythVk92ZDhCeHRkClZtLys4ZEt4ay9wamRuQndSbEVzek1qSzZI'
    b'QmY3MENWdUNGQnRvUkFiaXd1RzZmVTE1ZnY5ZEw1UlZYTFZwL2JlYlNXYnl0anFPM28KQjJ1'
    b'cDkxOFlQSFJBSjRxaWJwekNjUXhxSHdMZWFXRlREUHhZTzk4VjBOV1VTSEFwMGVsQVlxc01y'
    b'K0R3TUR4NkIxQmh2L1hGM0VWYwo1UVJDYURZeUdVMzBjQnNiRDRBRWdDdDlDb0VjUWRTUEhV'
    b'UmJCUkJ4WVZ0Rnl1NDM5cDg1YnYreC9La0w5akNzY0kvUUp3bTBaQmIzClNQcDN0QkJJaXdh'
    b'SWd4NldLYU52bk5SYnpqZThpRGtQQVFBblNMeENBQ09vQ0xCSzhUb0VEQTh5WGpXTkNINFJN'
    b'UGxOdkdHN3UzcVIKeUxVQkE1cm1WWFl1d2N2N0kyQ2t1TjZIS0VIQXVQQytvc2hQY1hIWTcz'
    b'blVQSitUVnpiODBhM2VHL2w5LzN2MEh4a1RQV0ZvR0FKTwpUWjd2SVBwQmp1c3NNRndTOGFa'
    b'WWZoTUtYcDNic0oxelhBTE9naUdHeC93d2NUaWxTaWVVbVlESi9udDVyTkZyMk1EYkRwSmND'
    b'UzVZCmVaQXdLSkFUOVJRRlBrVEl1OThrajhDWWZxUU5Hd2ltQUFjTEw1REhkQmtQdkJGOUw5'
    b'RC83TVhVSVIzWGE4Z3pWcTZyM3ZPZ0FpK0oKbHF3UWdMU3JQdkFOSFh2SDNUM0JVOFpVUGNy'
    b'UXJtWjZpSXNQd3hBanhwcFV4SVhoaTlLTHF2OWFtN0F0TEU1ZHRVMkVHUUN3WmtmMAozS1cx'
    b'aTllRlhMQXM1WUZVV1I4MzFXejR6L1JueXM1ZEMwSnNmUHZUUTh0bmJYNmlxcW5tMWt0Y2RX'
    b'cnRQOWJPUGxaOGF0bmU1Yi8wCkorY3FjbTZBM25sT0tCL1U2T3gyb3ZtOXhSdmo1MzRrbE9w'
    b'RkpMTG9QVk1va2VaZXNEalBGN2FlcSs1K29Lai80aldzdnNsYlVtVXIKcm9FdVhVY0dpQTZK'
    b'dmZzYytHQ1I5R280ak9WWWhtTW4vdnVoaDN0UFk3eDByVTczeXVuRlpkYXlRNWVQRmVxTHB2'
    b'V2FkQ3ZGMVJzYgp4NjZjbE45WVVHN1hjVHlmaElmNyt2dnZ5dG03NnRLYWtVbFpHSFpkZzJQ'
    b'MGZQbjlqZDVocDJ2R3pIOC85L3hsVTBPTHU3d2V2NitICnU4NG8rbnE3bmZ1TGpaKzJvQzhB'
    b'Nkp0Y3BkVTJMMzExSEd0b2NRY0dCQVlGaHZ0Ukp6eTJVcEgvbExMbWlpYzMvblB4Z2JmMVRR'
    b'MC8KMWZ5VW9FNmdhODFGeDQ5NGd4WEh5MC8xamVrOUwyTk9URURVclJUbkkxVlFuQ2pQbXR0'
    b'UTEvSk14bFBuVm0vdU5XejQ2d2NXWjlkZQp1RlJkOFBHeHo0b2FTZ2ZGRFVBSTBSVlRPTVo5'
    b'MGZUc3N4L2tHMHllSzlrTkp1ODNlOFJiajNyWnZ6NE9lbWU4TFFBb3E3Vm45azNYClVMaytl'
    b'TDRWQnV3dHVsVGpxWEtDWTEvVFhoRXR2YzhidjNmZDkySVBJL0tJeHNXTnFPRmFwcVJNVXNt'
    b'VnQ2ajhRbFZ1akc5TWo5WlEKYVpPejVIeE93YWxEaXBqd0EvcWpUWHk5VENFSkZuWHdsd1FF'
    b'VWpxaTlmMWF6OVF2ZDRxejg0MS9JMThYQUp4dVZxTVN4WVJyTk9RWgpwMWZXTiszWnNaMUc1'
    b'K1pmTHJFVUpZczdoVjYyWmYzamNTa3BldVM1bDA4Zk9majJZKzlybEw2M3JyeG5kQTllWity'
    b'ZW84L3c4Vk9MClRwMGU5K3lDM2F1K1lrTVVCRWJPN1R4M1lkYjhJSFVBclgrVllNdDBybm52'
    b'ZkZ2cDhkNloyYkU3R2Q4L2ZLNTVUUDhlQW1BRWt3OEEKR0liTkdEaDVHaitCeWEveEJsdHhB'
    b'aGM0cnVWeUMreVdyMXF6S3VQVmpMZ3hjYmVvZWM5amU0ck82Ym9OVTlKSk5BaDhaRXg4Sk5J'
    b'dQpYN0IzYzg0UDl5VmVpZmdMaFB1SW13K3BiNlhNTnZydkdPT3MxRHRZUWVIbC9VbG91dkpQ'
    b'cjZqVTlKaGVKOHhGelRWVmdEQ0I0OHArCktNUE5JdGJONnJicGJsRXR4M0xscDhxVnZLYnVX'
    b'SjJ0d1FZQ2VMd2VPK002VjVVek9lMUJqVndOQUVCWDQrQnc4OEZtRy9NM2pURFQKRE1jTHdB'
    b'aStHRnh0ZlM2VDY3c3Z2NDlKVERhMkdBeU45UnpIQldVRWtWNlNWSkJwQzlKdXRUTWw4SlRK'
    b'S1R6SEl6SHlEZlBsZVg3dgp0eXNHRGgrM2FkOVczU0dkd0FzQXdOUE5BTUR3S3V5T0J2anZK'
    b'UDFBclFSREFNQUxtQndBR2k0MDdKMjIxL3hSSy9HeE1IYmVndVByClY5dnR0c2lNU0hWbnRY'
    b'OVgvNERPQWJldXVkZnp2VEFLNjc2Z08wN2lacE94dWpDLzc3RHhNWitIblg3MjlJNUhkd0FB'
    b'enpGWGpMRUEKamZodlNyOVRSeFVBaUxCV0Znc0ZBS2ZKNlRRNU9lQndCbytNVFVpZk1PMVNR'
    b'UzdMc2NPL0hKNzB6MDc3OGcvZnV1WXRGM1ptcmM3cQpsTldwcHF6RVpqTS8vTWE3YnBPYnhF'
    b'aU80SXc2SXdCZ2xCOEFrTWltbEpPaGdkSy9JLzJNRkQ4UlpxU1FVWkNrQWtETTRCaXY0SlZJ'
    b'CkpmM2U2Z2NBSGNJaS9Dbkp1dmNXMXpqMVM4OTljcmoweU5yVEd4dGJtMzlmNTZIQ1l6azFG'
    b'Nzg0c1dKZHpUYXIxYnpwN2RjMXZscGYKdFZZVHJZbWJITWM2Mk9qTWFBREF4TkU4VUJLOEVR'
    b'Q0dwUWYvTGVnandaTVdkREF0OEFBU1hER2hpcFFFalpZOEFZQkpBeWNCQU1KUQorci9TVlVF'
    b'cXYzZy9BRUFJUlNkMDRsa21lOCtQNjh2V0Y3WVdQckhsNmVuclpnckNUWjJna2liZHBQVVBU'
    b'Vno1a0pVd2J5blpzdmExCkY0Zk9uaU1WUzY1YzdUYXpHNmtpTXhabEFBQWcwb04xa1dDMUJI'
    b'SU9TdytTU1loN24vN1EySjkrV0Z6d3pKaEx3K1AyUHpteEk0NjgKd2RRT0YrcENTRUt2SkVn'
    b'Y2t6aHA3NlJmUEdTQjU4Yk1mVFovNTA2SlY1NXJ6TDIveTMwdE5tT3J6WFF6L1FjS2owUm93'
    b'aExENGl1YQpLeWtEenpnZG5YdW1DejlIQzVTQnlrZk9Qb0tUVjJkMUJPVkVCTHlXUENHVEVI'
    b'TW14NHFnZFhEMDdtR3h1NlNvOGQ2a2I1S1pNcmRoCkc2MlVRbXRmbnZQaHg0Zm5IeWsxSS85'
    b'bmIvS21JSUhsTUJ5WDhXajdreHQ3K0tkaWJ1TFNTMmNyakZYNzhnNVpuYmFMMWZtL3lURjMK'
    b'OE96ZGoyeXZhYXlibGZiSWMzMW1xNlVLQUJENEc0ZnBwVUZUdkVLUWx0eXk4TkRMbXkzdnFQ'
    b'dHQxQXdvRHg1VThjQ1FuU0N3OTVxMwp4U3VyYzBKY0hBK2xCYmkwU2VicVhGaGN4WmZWK1p3'
    b'ZmQ5OU5zM0RjNFRYZmlvUDl1b1FtNzNwc0N3QWNMVDc1MkpZbmpBN2orS1R4ClBTUFN1b1lu'
    b'STRSMjUrMnJORmZPSGZBRUFQaXJ0SG1MemdMQTRZS2pPWjlkckM0ckVmZ2IrN0VJRXpHYVJW'
    b'L3VmL0tTeVVoMjRERS8KdFA0eUpvb1NVdFVlWUMxQWF1K3B0bzlzSFppVGc0V3FhS1R5Yy9n'
    b'NU1ZdUVza3U2eEEzQU1mdzNLVDgvOFBYcGtuT0FRRjlhVkgzbQpsRi9YSWQvTlgydXFNZ0ZB'
    b'cERvOFhCSEJLOWt0cFZ2a01zbWF0OThHZ005UHJyaFlrL2Zac2VWcnN0ZFZHS29BUUxkWGQz'
    b'VHgwY3c1CkN6Yzk5NHpINVFLQWYyMTR6V1EzLzZZZ2VmQUVuRWdWcklnMVlIUTFvcUo1eEFO'
    b'bkVDT3g0cDZMTkdncXNYQWQ0RzdPSUtNNHo3WXgKOW9ISnd2T2ZubUJabGlBSUFQamkwTW9k'
    b'QmJzaS9jTmR0SXVqR01lZUVpbEpUdi9vaTgzM2JVRmU5RlBSVDZNMmp3b1BDSTFSUndNbQpS'
    b'SHJWK2gybkswN25oQ2ZFRUJLMHMvekhmZnI5VHN6V0ZVOTl5MmRSNWZvS1paM0NMUmVQZkgz'
    b'SkovT2VLcnQ4NlpUaFpGeHU3UGY1CjYwUkk5TzZZSlVraDhRRGdjTmhsTlEyTmM3aWxSN0Js'
    b'elRodjR6Z3ZuRk80VWRZcS91UndaQXE3UjlvK2p4dXhIcWM1YVJXSG1ubXMKWHNTeEE1TUZR'
    b'WUFRamNGZ01GeEpreEFVaDVUYzdxcmRlL1M3S3kvbmM2VzZRUDhncFZLRkVSZ3BJczFXczh4'
    b'WEJnQnZqbm5sK2VoSApKdllhdCtDTkQ2Tmo0cXN2NVFwVmJnYno5dW5RKyt1Qks0OHUzQ3RU'
    b'U1QxdWp3Z1hVZjVVZk9kdVNvbjhoOFd2bWQzbVY4NjhWT29xClRveUlreEJYUGF3TDJRY2Z6'
    b'S2oxRWNHYnczaUZpZVNkR051TUFZMEV6b04xUDRKdzc3M1M4d1NWSXJHRERCSnd5ZysxUkZn'
    b'Rlp1TGIKOE9NeHBzR1JGQlFVZENWSlptSy8rd05ISm1qaVBTWTJJTThjbnA3QnVGMDRoUS83'
    b'ZEJqSGMxM3U3NEl3QkFEbGE4c0sxeFozaStzSApBQmhDWTU5OUliMU9zV0xFbDA2WDIwK3VC'
    b'WUNrY1VsaXVWalpRWm01Sk5QbGNpa3h5dGRIRmQ2a3Rua2NENFNQNng4NElDb3c0dXJ6ClRr'
    b'cmJ1RjkySm85ZGQ1UjFpbmp3S0JESWNMV0FnUThZSWdSTXVFZDZIbFRYZ3pOMEZGU05QTmNz'
    b'dXIrRXFZWGRBclh2b0RydjgwMEkKWFl1MDlFM29XV2d1bURCNmd1SDVqeFNaSXczWk9RQVFr'
    b'aGFpaWxHbHZaUUdBSzFWcmZsZjVpc2dZTk8wVGJOUHpnWUJKR0lwamFGSgpxZU1ucFk2L2Vr'
    b'c1UwZTJKYnFaaUU4S1F2cUpDU1JCK0hXUDdWZEwzWmJ4UjJWSTFzSFBHTDhVRkJIWkl1My9s'
    b'M0hXUEY1TXV4c2FLCjRxMFlpOWpkRDRKREEyeGJSQ0RhcU8wakVDSGFIek4wUWI0TTF5b0lW'
    b'a3hMYzQrbHVlMHRwZGNuNng3Ujlhc3BuMFVZU1ovbVZ1QTUKdTE0dkNBTEMwUGl0NHlreEJR'
    b'QStRVDRjd1NFTXlSUXloQ0dCNHc1dFdLMU9qSDVoMDZ2WDYwbWFrTlR2MVg0QTBGSldobGdH'
    b'RUNhNgpWUFp3NnBTUEo3NG5vWDZGMVZyLzR6T1pEaEFMVkN4SDF5Sk14UW1rbzIzUXQzVjhQ'
    b'eUhTcDhBdThFNDhQVUN6ZG14VGdJLzdTRTAyCmRMMjZ4UDZVN214Mnc3bFNVNm11NFhMbERK'
    b'NHVlMFUrakR5MmNxeFNwZW9mMk4vclpUSmkwanRISk4zL3lmMjdaKy91OVVndlFSQmMKZG12'
    b'QjhXT1B2UExSOW9kM2JQaDZROXByYVZIcFVWdlA3RFI2amEyMDhXTHJ4YWJhMnRxVWVzWmRJ'
    b'QnVFenV4OFBOZ25KRm1iUERobQpZSmhmeU0vdXR5T1dZMmFvaVkxbFlnaW1nVUZCb1hSVFMx'
    b'dlpnVzIybHExSG9uckozT1E0MGJ5dnppajdkcDlIMTN6S0kwVnkvMDhDCmc4TUI0SHpaeFRw'
    b'Ym5ZazJFUmlobFdoNWprOEtUT1FFN25KemtjMWprNUNTbm1HcEFiNytJcEpxYkdpNi9ISGg0'
    b'UGNHRzF1YVg1M3cKd0lJVks2Mm52ZG52Wm51UUp5SWhZdlRXMFhhWG83eTU4a0pEamxhaXBU'
    b'Q3FaMlJxVlV0MXZhMEJRMWlUcTBsQktZQkd3N3NPVWNtVQpBTkJRVjVaMzhpM0F0VDM3RG56'
    b'MDM5Tk5STFJFQ0QrNUx2bGVvLy9jd3dsajAwM0pzaGRzUHUvNWhNMzhBeHBZanNVUU51cUR5'
    b'Vi9NCitEREkxKytUT1k4NjNmeXJhOWE2cks2ZEQreHNxbXRLbVpqUzc0MStmOXd3SytuZTdF'
    b'bytiUno5NWllMUZYckhQZVZ0SlVRcFpWZ0YKQUloVXZmOUE5aUo5YVpkM2VyMjA4N1VLV2pk'
    b'bnd6UGZ2Zk5HOHVCaGFwRVlBS1JLYWRMTUpGSkNkbis2KzU5aTRUUEFWMVFWS0F0SQpqRksy'
    b'RFpPMm82K1FFaVJtQndDUjlJODQ4Y3VPZjE3dnJWMmJ0MDV2cnRjNnhGNmpvZWVRKzdHcmEy'
    b'UWhja2prQTk4K0lOUEsvbFFWCnFRZ0tHYUFOcDF6YWpyNkg1bGxlQ2dEQW1mOUE5cWN5Wm44'
    b'NDZBTzFWTjA1TkZIYnlrUjA2c3B4SEE1WFRYSzVuenlvVzlEL2gyM0cKQUlDN3JaWTR0SjNO'
    b'VTlQb2lOTEdBd0M0Y2tFVWQ3dlprME9UcEtRMFhCTXlJREhqMEk1TmRmc1BNbGxqZnJVdzdj'
    b'K0x0NHJEUXdHZwpyTVorcjdYOUM1ZE5EcTRqS3lqQXN2NlBhWWdPakJ6VUtSTjQyRlJ4MHVw'
    b'MjdmanFzeXNSdXExbmQvMC8xRTlnd0hISXppV3huRkJTCmJidlg2Tzg5MldCeDhQWGVzZUE4'
    b'QmM0VGYweEoxWUdxTDN0K21icW1TOS9COCt0cXErb3RMUUN3N09qbkZZYXFyMDU4ZTZENDhC'
    b'K3YKbjJVOU1BMVZ0c3p6aGEwMlJ4c3RNMm03dFd3Y0p5QUVzUjFUL1VXbkNPZHU4SjE0L2Rh'
    b'Zlc1UkxYMXhxMWJWaUhGSUhxZE5tREx5OAo5MGQ5UzkwcVp0djU4dHpWSmF1THluV1pVZjE5'
    b'RmFyYnJoelRLTlRPYXFhSEdPaU1MemVWTlJyZDkxcmJCNEN0Qi9YbmloeEZ6aGQ1CnhpSlVU'
    b'd0hPZXJzYUFnY0VFZ3hCK1ZGZEh1L2lzVmxESW1PcWp4d0pZU0l2Mm5JVzkxbjh3K3lOVWNF'
    b'UnQyL24yN25LaVE1YVhlbDYKNk1EWnB0eGlVNXNCYWROMW5JSUFPVVdtdEM0eElFcldvbTJD'
    b'ZFErbUhBTDRWZU02UC9kdzl2NFhDdkxPeGlVUHZ0bHc2aGZucHordQpEK3dWR0pjVlYxMVk2'
    b'S3FwcFFETXZBQktlWEc1THF2clVMWGlwc3M5ODNJUG56dnlvZE9OQlhXSXVmWkd1blJzMlVn'
    b'M0xTcHlMcXFvClo5OWFlWmxoK1h1VFBnQjRhZjdJdWVib3lJNmtJbDJON2NmTXkybEJTOGc3'
    b'QTZBZk5rMUxqRHIvZzY0QVRFb3ZqY1JpbVZoOEE3czcKZWxSMGFIb29UdURGeDQ2NkRTMjRo'
    b'SXJEdForL3Z1VWYvYWRwZlg1dnY4T1BHOFozaVQ1NTh2eHBxeVF4d2orTXBlMk82aVdVWVY0'
    b'cgpuYUp6UFh1eDFMM284d0tIaTIxTEdyY2RhWWdLdENJUUtwcFVmNlpVa2tCVDdvOThjSWhm'
    b'bkdKTklQVlRvU2xtN2lGcHJqdGZJQUZSCmtGU2hXRGZOVWxRYkhObnJtNFJPUGY4eis5bUs4'
    b'MVdXcXQxclZ0YURBUk40YVNzOWRlN2lTRTFFYW5UMy8zeHBlSjdmOXQyekpGZjIKWm5aK2c4'
    b'eE5ZS1RMSStvb0ZoOTd5QU1JcS9ROFVXTk5YYldqY3MrSityWS9OT08yNllkcGJlZmVXMk56'
    b'VXllS1E0djAyc29tWmExUgoyV29YTXl6T2NKaFU5RnRyd2VJVVdadzNkaDBETk9KeGcwUHZU'
    b'M1BQTy9CYUJlYWtLM0FxZ3VOZGFIbG5mbG9mNFhJRmQ5azBYUk9jCm5wSTJ5RmV0QlFBMzdW'
    b'bXhiMVd0cmJiQ3EvTlgrWWt4Y2JodldFV2R6c3hZWkFxZlJudGpCeUc4UjNES3pNSFRDUHlh'
    b'SDNQa3dKWVEKWnBiZHlYK2FHN1RaYlJJYUtBaWdDWTJ3SXFtWHYvckpYU2NzV3c3b0xmYXJD'
    b'MG45Zk53Sm9hMEloTUphYmF0ZGNqZEcyVWIzYWxqMQpNa2t3K2VBcHVwWEZGeGFuT0tjaUlL'
    b'ODZvTjRrcjJ0VnVMMVgwZFNiNUxvR05ZWWhMSEVYRTF3aDBNQzJZT0pvWVZDejlQbE1jMjBE'
    b'ClpuQUd6eHpSdU9OVTVQQVpoNVRLMjM3YmVKN2Z2VzZXcy9XQ3hkVFFJNUYrK25od1NiekJr'
    b'NjBob2t5OEV5bnFlN0FWR1ZkVzdxc1YKN2tjSDUwL3VWeHdUcGdKeE1naHV4bm9pY2U3MEp2'
    b'T3ZRaGNVd2ZXTWJld1YyeEFUWkZKS2FSd0pyUTV4a1Y1N3FUcWdXSzlwc1VuYQpnajRBekor'
    b'RXY3YndLWVNKZ0drQXBnNVlFd0FIdlBjR1JpUm5BYm9hM0xuZ0tmaFBJK2RRZnZpRFMwZDdm'
    b'VXFwa1Fmb2FreWN4QUtBCnA1QlVZeEtQVTBqU3VMYVBaeXVxZVRwa1krLzBvYmR0bnVhZWlL'
    b'UkhMODNEdjc1QVlLVFVLamdJRFE4T0RYYzVBYkV5OE1xUUl4UUEKUnFXVnIzajhzRHhvTEdq'
    b'bmdpZ0dRSURtdDhEMDdZTFZnMWJzQ1FVQU1jV043RkUyTWIyMFg2SmVLbUlBRTRNb0ZzaFFR'
    b'QVR3WG1BYgp3Vk5rc2hIVGwyVWR1eHphUmhIbXJENzQybytuRWVMYktZOTNBbE1QdlBzWFU0'
    b'OXZXaEkydFlmRkt5Q1JYWWpJSWJ1WGN6YU9iVVZrCkI1NHpZa0FJWTd6NGdJaTBHVTl2SlVu'
    b'eWRtdm9jTmkzZjVmNXBxMjZwZ2dqTkFqaE9HZGpjYVhBWHhpS0dlT3ZwT2tWMTdEdjFWMVkK'
    b'NURxUTlRWGVCWmdNdkNWUU94M0NONVVXSDMvMGxRc1BEU2lja0Y2cWtubEFGQTgrdzBFK0FL'
    b'U3BnRVMvTWlVY3VpRVBmMzlSZDlzMQovSU54bnZFRHhXODgzWU1RZDdobFk5TUxEYytEVndl'
    b'WUZJZ0FvRUtCREFHQnlkWnByUzRSQWdDWEdPeGE5bkE0SDNXVTBYTzRqOEE3CkFUQWtTMUJN'
    b'SEdnRmdRVzR2WHZ6dXByWXFxZVBPbXd0VWtGd1lVZ2w1VXBpaUc1NXZBdVE1MW9BT1Rtc0Ja'
    b'T2xnUE1NTkN3QXVocGkKam9Fb0hrUngwTGl3STNIK3hGdFd3SDFBT1JGOHA0SWs1WVlGR1J2'
    b'TzlKdHh0SzZaL0FNWWI1ditpRjZPWll1eS9FSnVjeExEZmhnRQpENGdUQUZNQWF3REhjZUFk'
    b'UUVYOWVQN2FOa1NrN3dFQUtPb1U0YzlnUHBoZ0owQk1WN29JQlZab0xSa1BIWllwTmJlMGVa'
    b'eGx2RmI5CldybnpBeFZxRVNCU1VvU3pDUzFzcVM5ZWw4RUJUdmJPWTlockUvbmZIMHQ2Y2RK'
    b'UFduUWV0UE1BRTRGMU8vaS9BSDd6b2ZGRnpHY1EKS080RG41R0EzVHpnekpxK1hQMWpRNHY0'
    b'NS9NZy9qSjdIeUhocWVFWFh4bS9QeERmQXM0endOUURid1VRQUZjQXd2OUxadHNPWU9xZwp3'
    b'ekpRREFhZkVlQTdEZFNQQ0xMTWgvNlZRLy9hU2hMc0lqeStDb3hCZVA0Z1AzK1BtNmRHeG1m'
    b'NWtRZEZqbTlOellVdVdpcVNSOXpNCkYzTll5dTFWUzhubWVYSjJsNVh0VXVwNnJtUEFoRXNY'
    b'aE1ZV04xWXlIQVFNMmNLNE9uL00yZUVYV0F5SGRlN2NNeWw5S2ZCMmFIZ2UKSkYxQWtnS3VN'
    b'eER3S3FnZUFIRVNvTjl0b0ppa2Y3K0JUNDNsYmRhbTNGSytMVWJkeUFCTHY4UzZmZ2wxQ1NH'
    b'dE1ZRm1tWmdCSkFMcwo1eEdmczhMUFlYZEFGRkNoUUVWQjBMdFFQUTZRQ1B6bWdjK0lLNE56'
    b'd2NWZGZXYmszV0IwaUR5T0NUNVEzUlVBa3JzeS81cWNHYWkwCkJZbjJCbEQ3U0dSMTh0RXU4'
    b'U1Nmc0ZtaW45Zjc4VHh2YmRpTHpOOG8wU2xXa0RmVFE1cm9ZUTVhdS85MDAxZGJkRjZHdXhx'
    b'NnY0bUUKK3psemw1ZFIzcVBnTXdKQ1YwRGpLNlVGUC9qSHYrSWJQdjBtRVNzenVQT0JMZ2Rh'
    b'RDB3dGNCYmdMQUN3OWFqd3pEZnBab2U0TFViZAphMmE3eWlXaEdCK3BGMGZnOUJJMGUvVTlz'
    b'THNwcFl6dW9MWS9PVjQrWXZ6N3dKbkE4Q0ZZTmdEdkJGRkhFTVh1TytNNGxlZG1PY3poCm9U'
    b'd000ZlNTZGhkbGNZcHRicXJlcFBEUTE5Nm45SzUrMDBkRlJ3UVJXdkpra0dpUEFpOTE4ZUVl'
    b'N2NmcTRBeW51WURYUDYzQThoMWMKZElOM2xKSHBhM1dpN1lmck51K3YvdjFUWGdpTXowaXFt'
    b'OWIvOHVpME1rcVpCdHA1ZXkvRUlnUzk0NnREaHg0ZjJKM2QvdThYZng1ZApCZkNXZ3VNa09F'
    b'K0MreEl3Vjg4dU16dkVqUmE1M3Fnd1dLUm1wNWpqc2JwV3hUY0hramtCYXp2Ni8xWE9mWmVZ'
    b'ME9VQkFEQ2EzQlFCClBxUU9QSVhBMUFOckFNNTYxVlFWM01CN1FQQUFad1hPeXRDMjgrV0JT'
    b'My9vZVRELzJoR0Z2Z3BxMXZpTzZWMjFmcExpQ01rcUNWWm4KcHViNDBsOXdncVRLTTlOSTk2'
    b'cXNkMzJ6cmZ6M3cyUUV4dmZ2cEIrVFZqWXl0VnlqRW9OUEZ2aE9PVjhXMFNYUjcrUzUrcklx'
    b'Nit5cAo4YjNIdmx0WUtleGZrdDI3aXhwNEc3Z0xnRE16SEg2cHl2OThlV0J4bmFha1hsT3Mx'
    b'MWhkb2p2Z2JkMWVFQlVUVEdlbTRwS29uNDdXCjVPUWJtbHBjNzc2WVRwSVlTZnh1QTZHcndI'
    b'R01hVmdjTld2U2IxeGxIRU9QVDR3YjJjOC9Rcks2ZzJpN2lVblR1WjRwcU9UZldWbGcKTUh0'
    b'L1o5REs3S1FmMTZ0MFJJOEt0WW9FeFRCUWpnWDVnT3hMcGtBLzJlc2ZaOCtmMWExVG5PYWw5'
    b'ODRzZWI3M1Y4dGZlUFlMZVZ3SAowOHhCK1hJeFhkNmt5dFlGNTFZRXVwbi81Nm5BdjN4bXNV'
    b'ZDBFOTc4QW9SL2R5YW5LVDAxYU8rUmFwNFh2dDFZTkxSLytJWmR1b1ZQCnBIeXhKdi9KNlow'
    b'QkFKeW53WGtDY0JYZ0dpQ0RRTkt0bGMzdzByK3RJY2NMbjY4dnVWRFk4dXJqRHpPQ3VzNlR0'
    b'WFIxK2VIc3BwdFYKUUVLeWt6T0tuaHArTVRhVUI1OHM4SGtaNVAyTHloMzFsWTdzUzNrU01U'
    b'RjVkQ3lCWTJhckZ3QVcvVE1ON1B0ODhWTUFRMHZyMWMrdgpHZkNYd3ZuTDZTc2tOR3M3UXRS'
    b'TW1mUFE1d3ZmTFh4c2FpZTVqS3pTMnl4MmIyU0lqOG5pY1hzNEFBQkdYMVI0aUJHMENGeTBw'
    b'NEhDClRnZ0MrOXEvVlRkcmJ0a0ZyUjkrVnpwLytwajNWeFVmUG5kVDlLUFR5dDZkZnJSRFVD'
    b'Qm8vZ1dxU2JXTjNNY2ZYVnI0Skx0Mlc4bEwKYzFQM0hLa0dnRzE3SzU2Y25teXgwOEMxaWt5'
    b'ZnVocS9XdjVURzUwYTFCYjkvb2dlRmQvTzJTMldCVVBnSWtFeEdtSDQxcjBWTFViWApZMU03'
    b'RmVwYWFacnYwZGtmRE8rWDJiSTZ4aVQ4a3V0eW1hSDMrSytFMzQwN3FwV1V5WHJqZmY2aFd2'
    b'c25NdzhPU1hGQXdLdmdPN200CjNKeVRiNWc0S3ZhelZYbVRSOGNkUFZPWEdLdStXTmd5WTN5'
    b'QzBlVFdLb3pRdWhKTTN4NHY4SDF1ZFdaUm5mYmVvUThBbmNKYVBuN2sKY00vWUJpQ0RRSEUv'
    b'eVB1QktCNm84Ri9PdlFQN0FWcS9xRW0rSml5czQ1VS81cnkyZS9XMmkzK3N1SEc5U3orWmVW'
    b'Z1pNaEVDRnJrWgorWUVUK2c0QnNuWGJTd2YzQyt1YXBOMTNySGJDaUk0dU42UDFjWUIxQjFp'
    b'M2NjNExCL1BDM3QrUmRyYTBUWGVQdHVtSmtMM2o2c2YzCkxoM1FTUjhiYkFJQVFEaVFvU0Fm'
    b'Q01GTEFRQmFWNEpoaVkwTzF6dDdPYm1vQTBjT3RGalFsUUMxeFNrMk84VldKMlZ5aUFYaDk3'
    b'eEsKbVpqNTRPSERVd2Nhb01NeU56bm83TVVtZ1JjT250Uy9Oci9Ycm9OVnhsYjM3R21kZ0cw'
    b'QzIyNnc3aFNjWnkrVSsyMDVIYmN0Ty9ZMwo0Y3g3a1A3MWpLSUR6VkVCMXVoQXkwdlB2VVQ2'
    b'cEZsczNtZmZQUG4raXoxOGlXendGQUhiREp3Rk9OdFZYNGF6QUc4QjNzTnd1TUVxCnFXOVYx'
    b'TFVxaXVzMHhYV2EweVVoMTRkMi9YemNwYXNyeWZCUE51MjEwZ3czYVhUc0MyK2YxdmlLcDQ2'
    b'SkN3dVdndjBuTUgzRDIwNmUKTHcvWWVUNW14N21ZbWhZbDNEbEJkL1liby84WVVydnNuZGVB'
    b'REY2OXBUZ2tVTjZuUjlERnl5MGlFay9wN0grakVLa0gyQVpnbW9DcApCN29jUEtYZ3ZzaDc2'
    b'eTlXQld3N0c3djVkSHlqV1FZQStadTdSY1psMVRVNU51MHE0emhoOXRST05mWFc1TUNqWUhp'
    b'cm9jbTgra2pTCm1xT2Q2bG9WY0JmSUhUc2Q2WW84T3VoY1YvOGR2SEppZm9sbDdMQm9RWUNG'
    b'YjUwcUxEV05IQkpaWG0xNWVlblpyRUVSZWNYR1hRZXIKYkE1YUpwUFF2UEticmZha3p2M2Nl'
    b'QzlhTWtvVVBBZXBSZ1g3S3dZbG5Idnl2b045NHVzeEJNVzExS0NNUGo1eXl0RHFqbzFTZFF6'
    b'UwpCemhuMXBkdnJEWDZQcmx5d3JwallUYTNDTzRPdWNNbndNLy9kdURaU3dhcy92RVo0NklC'
    b'NEllOTVRRHc3b3ZwUEM4c1dYYit5b204CjJibE54V1dtbmZzcnRiN2lzN2xOSGk4cms1SUdv'
    b'M3ZtYzRjTXJlNGp1WEx3bXc4ZHorQXhCelA3WnkyZmsvZEsxdEx5Q3d1TmRmdEcKRGRUMGpW'
    b'alA2SVo5K1FOVzA2SXVkaTA4WFhoM2ZXZm1EdGVHWnZHcEg0K3MxQjJIcWxIZ0tabzRLdmFE'
    b'UmYxRUZINVpaNW81T1NrNgpYQWtBUEMrOE1pL05iUFZpR0xMWXZBM05UZ0RJTFRBcyttZWF3'
    b'ZWlxYjNRc1dYYWU0d1NES3hhQ0ZrTmN2cVRqcHBoZ1R1dDUwMU9RClVIVGhxN1BGZmc4UE5V'
    b'ZjArUFJRRGc1M21hQzc0ZHZTL2tyWEY3UDNEKzFhRGJJK0lPOFBvbzZBYTREUUFxNEJSQUFt'
    b'K1dVdXlXejEKU2lXRWlNS1BuSzdMN0JPeWVrdHhWSmp5VEU3amd0bmRYMTU2NXEyRmZlcWFI'
    b'QnFWV0NJbXJrN3BNTTBBTEZBUkRxYzdhc0NuYmkvYgpUdi9HMGpPMllYenYwdFNZeGlDMVV5'
    b'UDNpTWhmazBJRTRMNkFxNEhRZ0NnQkpOMUFtdUxrSW5mc3J4dzdMUHA0ZGoxRjRwbDlRbDc5'
    b'CklQdmxlYW52ZnBHVDBGRTlidmkxMlppVkcwNCs4OWJSdTYzdDMwVmZmTXJXQldmcnJqazdD'
    b'aW10a2JzQmdNUjV1WmloU0ZZdGQ2dmwKM2hDTlBTWDZhUGVvOVFFcWwwd1VPeVY5RWhCVGdn'
    b'SmsxWHE3bCtZd0RFZ0M4OUxjQThPdW53Z1RQbHViRDNlZjNMM2YyN0s3S0x1TAorcDBFQ1NH'
    b'dFV6T0tKdlY5UDhEM25jNCtJenVuejNMem9iT21kQUlBWDZYb3VsM0EwRkI3cnFMV2RCZmU0'
    b'eDIyT1ArTUdHM1N3d1hoClgrenRubGV0OVJQbFJKQmZrTzc5Q29rYk1KL2VQYS9iZE1qVWYv'
    b'cnRucE41N0YxNEMzZFJ2LzhuSlRIRStJOUJCVmtwRmFGYU94QmEKSUlNQkVOQzFaWFdRdW1E'
    b'NnJjODN0ZFAvVTVJYzN0STV2TVZmNld3MHkvT3IvWFFOYXBhL1N6OG5lUS9TL3grUzl1L3J0'
    b'dE52cDk4dQo3ZlRiNmJkTE8vMTIrdTNTVHIrZGZydTAwNy9YNVA4QW82RkpSaW9uWUg0QUFB'
    b'QWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10Ck1ESXRNakZVTURRNk16STZNamtyTURB'
    b'Nk1EQ3hGMUlSQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEF5TFRJeFZEQTAK'
    b'T2pNeU9qSTVLekF3T2pBd3dFcnFyUUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBpZD0i'
    b'aW1hZ2U2NjcwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_CT')

US_CT = b64_US_CT
index.append("US_CT")
index.append("United States of America Connecticut")
catalog["US_CT"] = US_CT
catalog["United States of America Connecticut"] = US_CT
country["United States of America Connecticut"] = ('US_CT', '', 1)
lookup["US_CT"] = ('US_CT', '', 'United States of America Connecticut', 1)
lookup["Hartford United States of America Connecticut"] = ('US_CT', '', 'United States of America Connecticut', 1)
lookup["United States of America Connecticut"] = ('US_CT', '', 'United States of America Connecticut', 1)
details["US_CT"] = {"continent":"Americas","capital":"Hartford","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_CT"] = ('US_CT', 'United States of America Connecticut', 1)
regional["United States of America Connecticut"] = ('US_CT', 'United States of America Connecticut', 1)
#----------------------------------------------------------------------
b64_US_DC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTAwMiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9EaXN0cmljdF9vZl9Db2x1bWJpYS5zdmcucG5n'
    b'IgogICB4bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNl'
    b'cy9pbmtzY2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vm'
    b'b3JnZS5uZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3'
    b'dy53My5vcmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAv'
    b'c3ZnIgogICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVm'
    b'cwogICAgIGlkPSJkZWZzMTUwMDYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlk'
    b'PSJuYW1lZHZpZXcxNTAwNCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVy'
    b'Y29sb3I9IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBl'
    b'OnBhZ2VzaGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBp'
    b'bmtzY2FwZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3Jv'
    b'dXBtb2RlPSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imcx'
    b'NTAwOCI+CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIyMDAiCiAgICAgICBoZWlnaHQ9IjEw'
    b'MCIKICAgICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1h'
    b'Z2UtcmVuZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6'
    b'aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBTWdBQUFCa0NBTUFB'
    b'QUQwV0k4NUFBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQ'
    b'b0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUEwbEJNVkVYLy8vLys4Zkww'
    b'bktuMW5hcnUKVVdqdVVtaisrZnJwSWovcElUNysrUG40dWNMb0d6bjR1c1B3YjRMeGNJUC8r'
    b'L3ZxS2ticEtVWCsrdnI1djhmNXdzcjFrNkgxbEtMNgowdG5xTkUvcEhUdnBIanZyTUV2NXk5'
    b'SHllSXJvSERyeGQ0ajV3Y25xTDB2cUxFajk2dTN1VzNIdVZXdjk1K3IvL1B6cEtFVHBKVVAv'
    b'Cit2djZ5OUw2ek5QeWdaTHlncExyTlZEbkd6bjFuS24zcTdicEprTHJORTcvL3Y3NjBkZnNQ'
    b'MW43Mk4zNzNPSHNSVjN5ZG9qeGNZWCsKOS9qemdaSHhkb2pzUUZuM3NyMzR1c0xzUWx2KzlQ'
    b'WDgzdUwyMlYrUkFBQUFBV0pMUjBRQWlBVWRTQUFBQUFkMFNVMUZCK2NJR1FNTQpEK1M0UG9v'
    b'QUFBRVhTVVJCVkhqYTdkakhUc05RR0VSaGh4Yk1iMnJveGFIM1hrTHZ5ZnUvRWhCa0JWaWdX'
    b'WTZUODYzdVpxNTB2TEp1CmtnREFYNVZLQ1dhS3Z2NFN6QlFEZ3lXWUNZYXF3Nm45VERFU2tk'
    b'blBGS01SWS9ZendmaEV4T1NVK2V4ZldXMzZ5MHg4bW0wZmE1bmQKVERFM3Z4Qy9MQzR0Mjgw'
    b'azZVcis4K2E4bmhyT05LdHJuWnZYTTlPWlpHT3p1SGxyMjNZbTJkbjl2bmx2MzNpbU9DaSsw'
    b'YUh4VEhGVQpYSDFzUEZPY3hHbjE3UHdpNHZMS2R5Wm9SRnpmSk1udFhVVERkcWE0eng4ZTIv'
    b'K2tUL216N1V6eDhscWMzdDV0WjRKbXEzTnVOVTFuCkFIcENkQWxDQ0NHRUVFSUlJWVFRUWdn'
    b'aGhCQkNDT20yRUFBQXdHczgvMXFFRUVJSUlZUVFRZ2doaEJCQ0NDR0VFTUpyUEFBQUFBQUEK'
    b'UGVrRGptNkZHN0FBVnlVQUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURndE1q'
    b'VlVNRE02TVRJNk1UVXJNREE2TURCMApBOWZzQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFB'
    b'eU1ESXpMVEE0TFRJMVZEQXpPakV5T2pFMUt6QXdPakF3QlY1dlVBQUFBQUJKClJVNUVya0pn'
    b'Z2c9PQoiCiAgICAgICBpZD0iaW1hZ2UxNTAxMCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_DC')

US_DC = b64_US_DC
index.append("US_DC")
index.append("United States of America District of Columbia")
catalog["US_DC"] = US_DC
catalog["United States of America District of Columbia"] = US_DC
country["United States of America District of Columbia"] = ('US_DC', '', 1)
lookup["US_DC"] = ('US_DC', '', 'United States of America District of Columbia', 1)
lookup["Washington DC United States of America District of Columbia"] = ('US_DC', '', 'United States of America District of Columbia', 1)
lookup["United States of America District of Columbia"] = ('US_DC', '', 'United States of America District of Columbia', 1)
details["US_DC"] = {"continent":"Americas","capital":"Washington DC","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_DC"] = ('US_DC', 'United States of America District of Columbia', 1)
regional["United States of America District of Columbia"] = ('US_DC', 'United States of America District of Columbia', 1)
#----------------------------------------------------------------------
b64_US_DE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc2ODU3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRGVsYXdhcmUuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczY4'
    b'NjEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc2ODU5Igog'
    b'ICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAg'
    b'ICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2Vy'
    b'Ym9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAg'
    b'IGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzY4NjMiPgogICAgPGltYWdlCiAg'
    b'ICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6'
    b'ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZC'
    b'T1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFEck9WNm5BQUFBQkdkQlRVRUFB'
    b'TEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FB'
    b'QTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFjCmtVbEVRVlI0MnUx'
    b'OWFYQmMxNVhldWZlK3ZmZTkwUUFhT3dpUUJBa1FDd2xTK3hySmttWExsbDNXT09YSmVPTEVx'
    b'V1FxcWRURUtZOVQKU1NWVlU1UE12K1JIbHJKck1oTlBaV0xYUkxabFNiRkdzaXhMSkVXSk8w'
    b'aGlCOUhvUnFQMzllMXJmb0NpS0lvU0tRb2tRYm0vd2crOAo3dHYzdmZ1K2U4ODk1OXh6ejBY'
    b'ZitlR1BvWVc3R2JqMUNsb1V0dENpc0lVV2hTMEtXMmhSMkVLTHdoWmFGTFlvYktGRllRc3RD'
    b'bHRvClVkaWlzSVVXaFMyMEtHeWhSZUUxMFVsSm5aVDArVzRqOVhsdEdJK3NDYmJVVHpjQUlH'
    b'MjZqcW9SeWFGYkZONGRRT0QwVXVKK3JzZ2kKNi9KWWpMblUwM3J3Z3U1ekFMVW8zTllJWU8w'
    b'UVY0d1E1YXJQR1dSTnNjVSt1bkZFalpZc3JrWGhkZ1FCZXc5YkcyRXFCSnlQS3hQQwoybE44'
    b'WnRid25kQkRwb05iRkc0anhJbHlpQ3Q0c1g1OU1ZdWNuVXl0azVLT2FwRjEwOVdpOE02RFJk'
    b'WTRVeDVrNnA5cWl2Tmc0ekUrCnUycDZqbW9SMVNZdEN1K2syakxGRmJuMzFaWXJNYjh1ZVZs'
    b'VE5Xa0tXWjB4ajJYWmhGd3RPYnVwWm9KSXAvWFFCZDN2dENpOHpmQmkKNHlCWGFDUHl4eFhv'
    b'N2h1cWltWUVWWXRWZVhsRHBrRlB0dmsvV294QjloUmI3S0xFSTJxMFpqTXRDbStQTThMWnhW'
    b'VDNNUldNUG1uawpXSlRYSGFCRC92N0VrS3VZVCtzMkJuSG00d3JIaVBLTWErMjhIamlsQmEy'
    b'N3plcTR5eWlNRTJXYUsvaXZwN2FvdXRHVzdHY1lOcE5PCkVRUExtc1c3UFdiRHBqRCtoSjR4'
    b'd2xTNnFPWlJOWnExaEJhRld3OEdXUk0zcHJZNGpyT1F4ejdEenVVelhsK3dYQ3hFMnBJMHpT'
    b'amwKNjFzUlhtdzhMcXl2bXA2amFsaDE3bzZYUThhLytPejJmOHB1cXZrWW40MVRDZ0xRZE5P'
    b'eG5ZL3FKcGNoa3JnbmtyejNnY2NRSmp0Mwo3bllRU2JSM1VEU3p1TGlJTFltbXJxOS8rckUr'
    b'U0RkMXdCV0xoVzB2VjdkN1IvTmdZNW90dGxQU1JxRitZVzRqdlY2dlZwVll6UDM4ClZ5YXVX'
    b'VjRDL3oxZitOYUxQL21MbFpXVlZDcEZDTWxrMWxZWFRqUlVldkxCNTFiZi91SEgzV2cxWGNv'
    b'Vm03cG1lcjFjTk9RbURPVmsKVng3cTZ6L3VKT29XMDZMd3Btd0c1T3lrNjJOc21RWWJBRjUv'
    b'Y3lHOVhyTXR1NjRxbk5mN1gvN0hteHhIL2Y3ekI2NGNWYmJqS0xweAo3TGUvOGpGcWJXTlJy'
    b'aFRFSXE2c0wyamxwWXpvN29qNWl4Sk8rSzdGMzNyNVp5K2VWM1FkQWJJY3EyN3JWWXJEZ3Fm'
    b'amJQYjd6eCtjCjBZTm5kTCs5WGIwNTI1VENLRkVQY2ZuTGFzdVI0eXVWcW5SeFkyTXB1LzRI'
    b'My9qYVAvajd6Ly9xeGI4WjdndGNKUlV4UW1GV0VqZmUKL2Rrcko2cVZueU1FR0NITGNpemJG'
    b'amo2K0J1dlAzcmZVTUxYZmcxQjNSNTYrc21kcWF3VURNVisvTUxMemFiWUZZN0ZCSHRxc3B1'
    b'QQpNOHFVZTZqR1VUVzZzUzNWbkcxSElZT3NNYVl5ek5RS0lscVNUY1NITU0xdUZFNzcvTno4'
    b'ZWpvUkRYcDhRckt6WTJSa01PSXhybG1EClcyQVA3T3UxTEtzcHFSUkZlSWErbUMyRi9PNkFW'
    b'eEM0anhXSmZkMlIzc0hSQS91bWpwOWYrSnNYZjlYWEVWZWJkaUhiZ0lFRUFQaXcKOGJpd3Zt'
    b'eDQzOVhDbWtOYUZINHNPaWx4bWkyNnNGbXFxNjRkVHpmV3M1b3FEdzZOTUZxKzNZZEVVeXpV'
    b'ak8vK3dSOWlqRzFiLzZpaQpjVDZ2SEZkRHBGaytNRFNkV3A3UGVIMnNXRDdZdXhlWk03Tjhn'
    b'R3NXRC9ic1d3T2c2dk1KM3pXVUZFbHNJb1NlZlBqZW4venkxWERZCnRhT3JiV1JuK3hYT0lP'
    b'aW5HKzJVOUo0YVdUWTlMWTMwYWdqSXZKZlA3Mk1yRExJM0owS1pUZmlENGJkZWZTWG9JY1Nv'
    b'NmNXS2Q2azYKT0RrMXZuL3F2LytqZjhMYk9oLzIwc3lIQmtSZHRTb21EWnlnRmRaMkR1NHM1'
    b'MUtPTzJDVzBzTURRK1ZjeW5hSHJQSjZLQkNrallxTAp2UWFGcVkwOEx3U245NDEydDNrZlB0'
    b'Q1RiQSt5ek5WZG5FWk9GeTFHaUZhd09CMjJ4WEJFZDN5ajlpVzFoU25UeUw3eTgzVEZZSkU1'
    b'CnZ5cU5Ec2V6cjUrUVRxWWppREpjakR5Y2pKNWNhWmltNHFhRWZaMTlEd3gvakhXdmFmcWFh'
    b'ZGQxWGFTcEhwYnhlWVJyT05oS05mSFgKcHk5UUhDcFhSSWxvWThtOVlNSEp0VE05L3NoNGIz'
    b'ZG5QUFJ4ajIwNjZKd1JQS3NGN3JnMzV3NlB3aURSSHVFMkJ1Z0crWWkzek1jVAozU0pQZi9u'
    b'MzA3bVMrSXZETVljcTZGckl3UmZtVjlwWnZtWWFNWWZDNlpvWTVqMFI3K1pQRmxQWnRld0dP'
    b'RWkzbG5sK3puSlNmVjBhCklVb2tYQkQ0ZktYYUtKU281WFJHbEl5US81SWszQ2pYamkwdWlZ'
    b'Nm1xU2JtVUwxUVdhdXNZeDVMRGZWc1BwM0wxWWU3RXRmMjVpQ0kKRTZXVGxpb1dLOTlSSjhB'
    b'ZHV6ZUZuRkdtc3B1cG9vOWZvVFVkdHRGczVKY1hBZ1l5SFNmR3NCbE5pVEhzdXFhNENOVXdU'
    b'UzlGbFkrdQpKSWJiRGNNOE5mZm0xS2djQzVOQ1lYWjJRZTNxRUJDd05JVUNQb3Fta0t4cXVy'
    b'M2MyWjZhR0dOeUpmdllHV0hmMEgwMFJjMmswNVNYCmdBZ2NSNXVpUlhpRW1naHNzQ3liWjVt'
    b'R0xGK25DMkx0QzY3MGd1NTdUd3NiZHlpVzdNNVEyRWxKMDJ6QmhjMVBMbmIyN1hPWnRlYlMK'
    b'TzhmdkIyaWFSb0JtT2xpK29HdFJoZ1dBdW1tb3R1WEx5ZmxVTVMyZVBiQlBPbnUyVWFSTUtp'
    b'STBtNnBjcDExKzV1UjVzVkt6SHIzSApYMnRZaThzeTZ1S0tDN1c4U1UyUDJlK2UvcTJKazZ1'
    b'TmttR1lQTThRZzFBYzFzRWlidXhJUUJ4a3EwNkppSVpwZmJKREJ3SHNZT3FkCmxIUk1qNndh'
    b'N3MrL0lCV3dlWUF0VHJBbDVzTXozeldoSDU3WGoxNVlWcFFkRHFYYU5rOElBRWlXNVNJVUFI'
    b'Q1lWQXpEUTZoNXZYem8KMGVZN1I2dGZhRE9UTHJTVXBaT3NFYlMxeGFwellKL1BkbUE5cDNy'
    b'cVNnSTBwZDdzN0tuMW1zeHY1dlQ5RS9qLy9HYUQ4SXlxR0JSUApUTm95Skl0aUNBQVl4Q0lP'
    b'YnRnS29mRGVqaVRMWEQvMGpVWjJEeVdHaVphM2VlUDJPZ0Z1MzgwMmUrdXpydFJtWU9DTmdH'
    b'N3pkTklNCmx2V1NvVy95ZHhVc2NBREFwaXIxaHRuTEdnU1Q1dkRUMDg5K3ZjUU9kUEJPdnlx'
    b'LzgyWkJ6b3ErZ25pdWdCR2o5VTZXS2RacTgrSVIKanluSlZrZkFjUnpvOUlRY3l3RUFUQkE0'
    b'WUpnV1VwSEJtd0JBSE93V3VFOGxYYjdzU28wd2xVK1lIZTVXQ29OWWUxSklIMlFMbTk2eQpH'
    b'elh6dThJT0FFdlJHQ0huSSs5RXRXMnR3d3NBWHBmTk1qaEVRdzJIbWliN3c3OCtTdnVDdWdX'
    b'ZFBuZ29aQjN5bVcrdHc0ekU1b1JtClBHNHZudmNCQU8vWUZJWENBUUsyTXowODRDRWNBSmlz'
    b'alZSazZCWmd3QmdEZ0lmbE1QcDBDaWNOOWdSYi9xSXJFOGJhNTRSQ0F2WVkKVzNuS2xZNFM5'
    b'ZFArdG4yd3JlSWhQQ2I2dFRvMWh6SGQ3cXVCYlJTQW90QWFZbXJWVXZuMDRkRis3MXhhZW1r'
    b'OW9Wa0lBRTVrN1djRwprT0tRcFRYaFQzL1VmYlFaWHF6WWE0aWhLRlN1MjRpZ1Y4K2ZkVXdI'
    b'QU9vTml5SUVkSVJkU0ZOTm1pV21iZG0yYzFOZFZuMUtTTzluCml4U3liL2tidnFWellSdVJI'
    b'eEd5M1pSNGN6MEZJY1FPUnF1T0pYZDRoWUxJQTc1eUxtemFaazFSL2JwVHoxbk1FTzRhNU02'
    b'Y2F6emUKSldPNXZHYkU0c2wyVnNyN0dEUGhSUXlHTjdNVXo3cS9tZFFGc0JieStxNEQ0VklS'
    b'SDE3Z0VJUDBCamVic1JzS0pjbFVtSE44YnQ0bgpDQW0zWDlRMWs5Z0NZdU1CMzAwOVBFU0ky'
    b'a3VKRFp0dU9NemRSeUdQekdtdU9NV1Z1TS9XRFZtZWNRWDRRazBCQ3VwK2ZqWkFyY2M5Cllu'
    b'OTByVHVROHRKN016SUxHRGlLRzJNeUdlV0pEcE1oNEdkTW5iaERadFgyZHMraDhSUWVMcVBF'
    b'dmpDK1A0NzlqTlBuMVRzQy9Ja00KY0lLL0k3Z3JWU3hUZGpEZDBBbnJEdkhpYUc5QzA4eHZQ'
    b'SGhnUjBkYnBsaHBHSXFtR3J1U0hUZi8vTWp1bzV1M1ZNM1plcVBpby9IdwpueEd4c084M3Rj'
    b'WGcxQ0RqOXZncmRUOUFLT2dEQUZWU1JDUkFwbUFkYWpmaHpNQUEvWjlPN01mOVg4UGdWQVVm'
    b'QUlENTRZYStmOG11Ci9zVTNKK2ZXOHhVUHl6dzdNZm1mZi9KM3lhamZkZ3JCSURtL25BRVdW'
    b'ak1sbHFWY3dBQkFWcXd1WlFxblU3WEovbWhYekgvVFJsU00KcEc1UnFOd1dVK2pGK2pSYlNG'
    b'REsxbFpyTzllWWtqZ1huNGx3VXcvdGQzbjRiTkZiYTh4SGhmS3k0NzF1YlVsUHJ0b0lFTFFq'
    b'RVkwQQp3RE1Qakw2VFdRWWd0bUZ6SEUzelZMcFNjUXRzeE9kYkZjc0JqMjhoV3p1N1V2cnFv'
    b'Y0hQMG9UTlVMbHVTanlpUnFvMnV4MHBKT0RzCllhdDc2T3NFbHQwYzNEeGZieWljNStyMUFT'
    b'cmtjWG40Y3ExYXFhVjJEK2xVSlhoRGNvTDFlTHoxalZ5S3BabVFQMUNXTHUxZWMxTzgKWkt1'
    b'T2hrNFdMZ0xBY0NneGt1ZzRzTy9ocG16UjlJa3RhVWlVS0Y5MHBlZDAzMGt0dEZYZW5LMnBK'
    b'VWFVWjRTMVVhWjhLL2dEZ0xhNApWOVZOQVBEN1BMcHVYaUcwRVFEa3l5dVRvM2xWa3hiRTNW'
    b'ZTVFWHhFOXhJRGYxaWhYWlIybVVaamNqUmZLRjhFZ0kxNmJmTnpReldCCkFkdStOSGt2RmZJ'
    b'SGh2b2I1VFhITUI3Y3QyUHJiQUJuSjFON3hwVnVKL0syR0lVM0hsajJXVUF6VkNOYmh4NGdC'
    b'TlAwQnpZK1RjQzIKbmJxb09UWTBqZEFUK3lkWXIxdXNWQVJzbzNyMTZkLzcxbVl4eDNIS3RX'
    b'cW1VTjZvVkJWTlo1SUh6UElaeDg2THFyMVdLTlZVbVdJdwp3Q2JQSDdURElOYmNXbloycmVs'
    b'aVZoNmQ2Z0d5bGNxSUIrdVBiVkdvM04wUlo4Y0tYTG15dHZtL3BuMWdNbHQ2OGMzMzV1K2ZM'
    b'alprCnVwaExkNGFyajk3ejdQbVR4Ly8yQi8vY0lxUzBNT3VQUkJMREk1ekhZK3U2S2piRExE'
    b'djU0S092dmZ5ajFOb1MxK3NmSDhtKzlwWWMKUjFCWGllTTRsbVhMb2haZ1hLeEZhYXJwcGps'
    b'ZHQwNHRGLzd0Tnc5UlpQdHVnL3FzRk9vT09hSkZsMDNQd1J1STBMMXBxTllWb3RENAo0QzdK'
    b'bU5veFVzcVhqS0w1cUxjak1uSHdXUUI0N1gvOWlLY1FoYUYyNW1nTllQVzFYMXd1TCtxbXl4'
    b'Y1luMzYyVWkwdkZFdFIrcVhICjdxdWVPT2Q5ZS8zOU9wdWdFc094SGVMQ2c0bjRtVlRqMEs1'
    b'Mmh0bjZqdDYwbVNOYUpHdHVRVERPMXRpRmtrTXZHRDRUVUp5bzZCYUkKMU5XaVhLdEl2cURI'
    b'c1N3ZkE1aTkxSEs1c1RxMXh5NVdUWGY0MEplLy9zYzh6d1BBM3ZzZjdybm40ZHhHVnMxbnI2'
    b'cEg1RDJCYU52dQp5ZjI3OWh6S1o4OWk3ZlJRbjVCYTV4WUtHaVlJQUdpZElBNHd3UUNnTksy'
    b'RnRQeUhUKzdGZUN1YlpBTTZwd2ZmVU9LTkxkckNnYmZ3CnlXYjA0QXR5TW12eVc4dGZYVlFJ'
    b'eHdhRDNuS2hSbGw2d1AyQjN4azVTcUZzTUJTeTFMVVB2QW84bit6dGUrQ2IzOUVBNjlZbDNh'
    b'U2kKNkpwcHhXUHhqWTJOUzROWnVzalF1RkEyR2swUjNnK2tHdXZ2WnV4TFkyNXVYYmxuVjN4'
    b'clJXakI0bjhoZFI3WFFsdTQxci9GSXI1aApNNjhxN2I5VjRsc1k1bVhiRGtaSThISmlRMlpw'
    b'RkFtNFJmR1NMbGVxaGd6TDZlL21Vb3R2VnN1NUszL1ZQVGk0NDRsblMwRGQ5eS8rCjNmUS8r'
    b'MEgzK0g3M3lJUlkyRmhMWFZ5Wm42dVdjK21MYnc5MGM0WUZYbGMvejE4YUVER3ZyOTBmQklC'
    b'bVEyOUs1aVBqdlZ2VkN0M0IKNzJxUmwrV09yVFVLYjRtYjJ3RzBiSHBla0pKTGhuZExLZ3g0'
    b'QlZWUm92RlF1VnhYVFlkbmFXSmZzaXM4N3NBYlIyeUd4bnNHNFMvLwo2eitVbWxWVFZ6Yi9k'
    b'RVZjbnJ2QVJ4TzdKaWNJZG1SVi9mSS8vcU02NGI3M1ozOGVDQWYrNnI5OVo2VGZZV2o4eGhF'
    b'N0VneXhtTDRrClNRQk13d2FBUXBtTWRRZHVKSHIvUnBBMlhTOUlYZWR2elM3R1c2V1JLZzcx'
    b'bGhwYk1qelRYTUdIamMvcWNTV0lwb2hwV3FyaEFBQWgKbDZTUVEvR1JVQ1NicThRakRMOHk5'
    b'eWQvUENHN3ZaeVgyK3hLTXRGUkVMNzNadzhaRGtadStJOS8rWHN3QlAvMEIvZndZbjFYa3NU'
    b'QwovbXpPaUlUQ1BvOTN1cmRmZDh5b3o0Y2RHRW0ya3hTOTVsUWVHKy9iQ3JXRlBxcEYxODFi'
    b'R0VOOGE0MktEVXY0dVpTOGJoYUQ2MEpnCmtBa2c4S3lzbXJKbVhKNUdIRXdOZFIyYVc1cGxo'
    b'WE1Nalo5OTBKVXRHSE1aclNnN2NaL0RlVW5FVCtJQmZQS2l0VkJFSHNyeU0rWjAKa2twRXZT'
    b'dHJ5dGw1V1ZkR2hycUdBTUR2RnRvaS9tS2xHZkM3TE50WktwZ0hoK0lVL2t4RDBISFE3Y25M'
    b'Y012dFFndndLUzJZTWx6VApYT0ZUTFJucWhybVNMcmJIQWg0WDU2Snh6UUYvd0tQS2Vya3Fj'
    b'dVNTQjEzWGJRRG9TdzZmT0orcmk3S2I1eXBWWWFpOTFxUFZSM1lJCnFhd1dDMkdHd1UrTTR5'
    b'Y0JuWm5WS01wZHE0WXBKR2NMdE4vakdoOGVBZ0R6ZlpXSFkybFZNOTZlU2RWTHRVaFAyT3Ur'
    b'cEpkZE4zem0KbzZqWTNHRWxXdHJxYWU4V0doVTNJbGVYREs4TVZKeFNibVE0T280enMvREdB'
    b'OVBadFkwMVRRdUYvTzVVVWJSc0VPdFNOT3htS2FSagpCZ0NLK1JrS3oxcW14ekNaamxoQ00r'
    b'cnh3TTVFWkU5RHJCTktyemVjNVRYSk5CMktvRVNFeWF3bitqb2VZaWgzVThuSHc0UEk0Unh3'
    b'Ck5rcnZGQ29TeC9nOExzNHdMY08wenB6TWVEQzFjMGU0TGVwWE5YMHU5YnBxbkhsdkp0UFhl'
    b'VU55MVFCOFNndStwY1p1VzJUaTdYTTYKT0lEbWRkLy9sYnB1Uk0wcDE4VGRROGJSMC9YRjFj'
    b'THFlbzZoYWRzMG83RkF1VlRYVFdkVGtKcW1OYis0T05pai9yL0Ryd3oyenVwbQprNmIwczB2'
    b'dkZpc2JiZUhKcFl0dEZ6UE0vRVdsV0RFSW9vNmRpZ2Q5UThWcWRtYnhNRU1ibHRYczY1bjcx'
    b'ZUZmRHZWTGgwK2NRZ2pwCmh0a1FsWmtMNjNMVDZ1a0sranc4QUdpR1htdVVMNmFsaGRWbHc3'
    b'aitqSjQyWFMrSXlSazllRHR6VE4zdUNEYkR3V3VtdTJ4ek1hSjgKUWhBYnh6R1pYTHJlYktU'
    b'V1kvZU9qYzY4dDV4K2I2bFdxbWRMOVo1a1NCQlkwVVJpZFhZbzJlaG9ZNkloakFubE9GYXh3'
    b'clRIWll4TApwMmJYZkY3UzExWFowY3ZyT3F0cW84bjQwRHRuM3dvRmN3R2ZVYTE3QTc1R1E1'
    b'WU9qcmtJUVN5REdrMGpGdTRvMTV0SGo2VXR5N2wzCnVvK21NVU5UQXM5WlZnU1QzTHRubWcv'
    b'dW44SWZ2ODliZHFpM3RkaEpMV1RjOWlqOU94UE4zYkNaZWRPUEFhSkV2V1ozUlFncENqMHgK'
    b'MHZDNnJaLysxVUlnYit6Zk0vbjBsNzYrTDl5MmV1clV3RmozYS8velZacmJpTGNobjRmcTZl'
    b'RFdjeFpGSWNNcWxhdnl6a0dxVk1aKwpUeWlkeFlVU240enRKNFRVeEJWVnJ3MzE2ZStlcmZa'
    b'MVd4eERJMlFtMjVsTVRuZnhLRmZVQTk2T1k4ZFMwLzc0dDcvMTdZUzd3OGlsCmk1YWF6dVVr'
    b'NVV3c29qZWF3WUZrenpVOWJRN0FndTU3WFVsVWJzdk10MTBvM0xUQnNwYXdacm5DV0JNK0Vo'
    b'T2NLeFk5M25PU0lzdXEKTmpybGRQYTRZc0h4M3E4KzEzSGZvUjBESStMWmkzMjdWL3IzT0I0'
    b'WDFSNWpUTXY1MVZ2aXpuNTBkczRLQlhEUVQyamFrQlRkdy9lMAp4MklVb1J0U3c3QlNiVkZa'
    b'VWEyZ2p6azNid3owT0llUHl5TkRYTUJMRmNyR3hCNUtuWmZ2My9mMSsvL1Y5L3k3aGhtdkwz'
    b'djBqVFh6CjdiR1JZckxkam9TWWh3L1NQMzV4cGlQU3c3SDBoOVVXOXRkeVl0NzAyWGR1WjhV'
    b'MjNSYXprRHAxNzlUR2I5OXJ6TXlHY3FWeXRTNkcKZzl6WHUwZEhIdnEycDdkSHI5VUJ3ZHhM'
    b'UDcwZ3pSZHRKUkRJZTkweHl6SlZUUWRrVDR4bzc1N214bmMrdnJKK0xCeW9scXBBY0tLcgpi'
    b'Yy9KdVZjbTkrZ25aaGpicGx3Q0laaFVHeVZaYkV2cXZyRzlqNGYzVFRBZWo3ZS9OL1h6Rjll'
    b'V2ZyZ2g1SmRYTEVreHdISFZtdUs5CmswYTFiaHI2eU9USW5zMG4zTndXYzBZTDJIZDZXd3ph'
    b'SmtkUUNzZzh3Qlc3S0hIemNtMGpHdzZkcXRZVjVCeEtSTnZBaERpenQxU3IKMVBPWnFPRDE5'
    b'dzJ5d1NBWGpVanBUT0hjZXl2VnM0Ryt6bHFqVGdnMXMvUmF2VW02RTdHK3p1RnkvV1NwbG1N'
    b'WVZDeHgzZTFqVFhrOQpsYzE3WGM3SXdDT1diZmtJWTZ5cC9TUDNSeVltTFUzall0SGF6UG4x'
    b'ZDM1amhlTnNJQklNQk9SQ3Frb3VBc0RaaFZPQWxzNHQwTTg5Cjl2VG1hbVhHZEIxVkkrTDJT'
    b'SENLdHRVcG9wZTNpQUpBcGRFMExUTWFDSURrUkR5N0djWkZDWUphS2xYTmxMcWVEUVYzaGlj'
    b'bnRXS1oKOXJwcHQzdmo4RnVWM0N6RUdCTGdkZDJVVkJHQmthK3MxSnVzcGhzaFA3aUZMby9B'
    b'dUhnM3BWdjJ1aHdJRDhZbURqREJnRm9zWTRyUQpQbS9oOEpGOC9pVHA5Q2E4azhqQ1lOdW1v'
    b'ZVMwczVpbEFPQnkvaS9GSWEwdG90ZFJjeFpOTHdWT21HZ0N5N2g0SGdBOFZtemdLODluCjMz'
    b'bXplUDU0YUdRVXdGSTlrc0xVeTZmTzhLdy91SGVQdUpwS1B2MVVaT2U0MzkrSE1wcWRiWkNh'
    b'U3FsT2tJMjJ1WUtkcmxCQTl3Vk0KdDk4S1IvM0RuWHNmSHZqeTg1NzJaR054U1N1VmZZUDk5'
    b'ZG5aNWQvOHJSb1djWWgzMmFIMmZmYzNDMnVJSmJHcDZkcnNuTVdaQUlBeApjZ0NXRGUvclNx'
    b'Sm9iNjkwcG1oN251VWJKdXBCcmhEQ0dyS0lTd3NadHFSeElsQ0lyM3FRbDVKSjliSUhBRGJV'
    b'VUhobmJPS2duTTBpCmpObGd3SlFrTGg3akl1SDZoWG5HNzlPcU5UWWN0RFhka2hWZGxNQXlI'
    b'ZHVtM1c1REZPWDhSaUYxR25XeDZIMVZzeTA4Z1J5Y3piMEwKWUlkY1E2cGVrYUFFQURXYk9h'
    b'ekdDdHN5RnkzYXRzY3hYNVcwNUpJZXE1bWJrdTFxelY0MlNJWDRBdDJ1V0x1UWlOTnVqNmUv'
    b'Ti90MwpiL0R4cUpUTzhQRzRLY3RzTU9BYjdNKy9mVVFwRkN0cnM3SlRvanQ5OE9IbFhLcE9t'
    b'eTROS0F3QVlOb0F5S0xJakI3WURydDU3ejRLCk4zRTVkZENOK29BczI4cUx0TWJSakp0bUJJ'
    b'cHpZNFF0WGJNc1RSVnJtbDZCQUVPRlhYQmpDL0U1U3ppaVJWcXBnejRUbWpiOXFwTG8KcHBy'
    b'VGJKSEQxdzhQUndSVENhOERvSU91Z3c1USsrQzdDRkFRdk1IN2FnNDVvWWNXZEsvVFN1QzFK'
    b'VmcxUFZuTE5jYVVoNW5hclg2agptMnJMZTFwWWRlNk9iTUYzVFNaRTNjSEh0RWpLZEUvZnls'
    b'QzVoazIza2xuZVd1UXMvdWRTOGtaU3l0NkV3NitWVXZiMk9WZG45R0RLCjlFeHpoY1FXeGJU'
    b'bkxiNlYyUG4yT3dIb1YrWEVKNlJYdjNINTNFcXZmc2V3R1NxWGtZVHhtOTNVMFRya1lGdEFj'
    b'OGdSTGJwaXVnOXgKUmU4TnF6bE5tMjRkTmJMZDFCemhaMUxuallUSzNiYkFzaGFGbnhxYm9Y'
    b'S3JodXVheDI1dG9teXpyV08zdGp1cU52dVMzUDdSemY2NgpRMXFIMzkxbGFrNVdFbHBIVU43'
    b'ZFVCenlsaHBiTmQyYkZNTG5GeFI4cnZINUptOFRyUk8xV3hTMjBCS2tkMW1YeDJoL1h3OUNx'
    b'TmhvCkx1WUtyVkY0SGRCazI3bStEdlQzY2pSOWRHSDVxMVA3dHNrajNiRUl0b2QzRGYzUjR3'
    b'OVdKZm54dmJ0U3BVcHZOUHo5THo1aFd2YkIKd2Q2bXFzYjl2dTg4ZEk5cDJVL3UzYjJjTDMz'
    b'M2tmdjJkU2M1aHA3cTdUWnQrMCsrOUdSVmt0ZXJ0WC81aFVmM2RuWGthdlh2UC9ORQoyT1Ar'
    b'd3RoSVZaTGJBcjUvL2ZUZk15enIwSTcrcWlRL05yTHpHd2NuWFN6ejdOVFlpWXRybTF2Uk1F'
    b'WmZHaC9kMmQ0MjNONm1HRVpOCi9wQXJvRE1VZUdUM01NRzQwR2h5TlAzRjhiM0Q3VzNEN1cy'
    b'eWJ0QVlQM2RnSDBmVDJWcDlNVmVZNk9rNk1OQTczTjdXSGd5c0ZFcS8KVzZNd1hha0tMUFB1'
    b'OHFxaTYxK1pHa3VWS2dMTHFJWnhmQ1cxVWEwL3QzLzgxR3I2OE1MeXowNmNFVlcxcnFpNmFU'
    b'b092SHptM0ZxcApraTVYSHRrOTNCMEpZWVRLVFNsVHFkbU9VNWNWMVRBd1FwdFZhWVo1Yk9s'
    b'aXZ0NWNyOVl3UWhmV040SXUxK1h6QzVPaG9JdGxKVTJMCis3MTErV3BYVHJwY0hZaEhPME5C'
    b'QUVpR2d3TERTSm9XOTNrYmlqS2J6UzNtQ3RNRHZiczdFaGloWFowSlJkYzEwM1J6N08rd0lI'
    b'WEEKelY1cVAwTlJwbTBUZ25tR05pd0xBRlREb0FnQkFJcVF5K2xRamkydlJyenV5ZDd1YkxW'
    b'MnVScUJaV3F5RW5CZlduQ25LV0phbDg2YwpaQ2pxcWJHUjA2bE1VNzJVZHFpaHFIOTkrTml2'
    b'ejg4WEc4MnFKRk1Zcy9TSDFBTHIvVFJlNWFhNFdiTFFhRllsK1N0VFkyL05MZjJiCm4vNkNw'
    b'YW1BUy9qbHliT3ZuRG12R2NiaGhhWGZPUW9ETGdFQWRuVWtrdUhneTZmUGJWNDY0SVRkcnFu'
    b'ZTdqY3V6RThQOVBiSElzL3QKSHcrNkJSL1B1VGsyVTY1OVkzb3k3dmNHWGNLUmhlV0xoVkxB'
    b'SmZnRTNzVXlIRTBEZ01EUXlWQndzeXJiZG1JKzczaFAwaThJQ0tILwpmZlM5MGE2Tys0WUdO'
    b'dTllRVNVSDRKSGR3K2x5RFFDZW1Sajk3aVAzWDM0MnY4RDdCRDdxZGRPRWxOOHZtYWxVQVNC'
    b'VnF2VEZJa0czCksxMnVWaVM1TEVwZW5odnQ2aXcyeER2MUp1OVlFR0xVNjdFZGh5YWsyR3lh'
    b'bGgxMHV6YXpZRE1VYVNwcVU5WGlmcStMWmRjck5ZeVIKbTJWdHg4RUlVUVFydXNIU1ZGV1VI'
    b'WUN3eHdVQXFtRnVmbVZhZHFrcFhsbFZRMUY5UEcvYXRxSWJ0bVBUaEZRbCtmS28vZE92ZmVr'
    b'Lwp2UEJTV1pSNGhuNXc1NDZYVDU5N24wS0JJaGdqMUZCVTFUQTJTLzc3RjE2cWlCSUFoTnd1'
    b'RDgrdGxTdWJDVGEvZG1BY0FIN3l6b2s3ClJlRWRNeW9LamVhVmw1dHY1MHJrYWg4azBwZTFh'
    b'eThFWnF2MWozNTRWVldpZXUwMDUwT0p1S3pyWlZFQ2dMREgvZHE1dWN0ZjFUNTgKd3NobXlj'
    b'dlZsa1dwZk1VdHhybzZmM0xzeEIyY2lMWjdLUEN0QTB0UmZwZVFyemMrWThtT29EOWJxOTlj'
    b'RnZhV2FmK1pvSm5tamZCMwozWktaU3ExbDJyZlFvckJGWVF0M05mNC9Dak00LzFqc01QQUFB'
    b'QUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpNdE1ESXRNakZVCk1EUTZNams2TlRZck1E'
    b'QTZNREIwOUEvV0FBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl6TFRBeUxUSXhWREEw'
    b'T2pJNU9qVTIKS3pBd09qQXdCYW0zYWdBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9'
    b'ImltYWdlNjg2NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_DE')

US_DE = b64_US_DE
index.append("US_DE")
index.append("United States of America Delaware")
catalog["US_DE"] = US_DE
catalog["United States of America Delaware"] = US_DE
country["United States of America Delaware"] = ('US_DE', '', 1)
lookup["US_DE"] = ('US_DE', '', 'United States of America Delaware', 1)
lookup["Dover United States of America Delaware"] = ('US_DE', '', 'United States of America Delaware', 1)
lookup["United States of America Delaware"] = ('US_DE', '', 'United States of America Delaware', 1)
details["US_DE"] = {"continent":"Americas","capital":"Dover","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_DE"] = ('US_DE', 'United States of America Delaware', 1)
regional["United States of America Delaware"] = ('US_DE', 'United States of America Delaware', 1)
#----------------------------------------------------------------------
b64_US_FL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc3NDEyIgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfRmxvcmlkYS5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzNzQx'
    b'NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzc0MTQiCiAg'
    b'ICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAg'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAg'
    b'IGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJi'
    b'b2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAg'
    b'aW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnNzQxOCI+CiAgICA8aW1hZ2UKICAg'
    b'ICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZlQXNw'
    b'ZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXpl'
    b'UXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJP'
    b'UncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RCVFVFQUFM'
    b'R1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFB'
    b'Nm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQWEKLzBsRVFWUjQydTNk'
    b'ZDNoYzVaMHY4TlByekprK0dzMUlvekxxdG16TGt0eU53ZGdzTFdDS01XbDc3M05UOWlZTHVm'
    b'RHNKbXpqQ1U5MgpVOWduMlpTYkFObnNUZUZDZ0EwR1REUFlHQnVNSGN1MmJGbXllcC9SOUhy'
    b'T21UbTkzRC9JaGV4bVE3RlZSckhlUC9YTW5IazEzL21jCm4rYm92TDhYZkJydEFqNytxTHho'
    b'YS9lamYwLzZQY0RLbUk4aEpYTzk5MzVuN29XamwvQmMrRTdZZndsUEswNUVwbjc1SXVaZ25P'
    b'dGIKVndLNHpCSFovOGJ4VysvTG54dTV0S2VEbDZad2hlT1M0N3RjaFNzY2x4emZ2Q2xjNGJo'
    b'VStPWk40UXJIcGNJMy93cFhPQzR5dnZsWAp1TUp4a2ZFdG9NTDNSdUNXcTd0Ky9EZUV6M1ds'
    b'NDB0a3o5N3puZWlMeHhibytQT3Y4TDNCajg1TS9lTEFGYzR4c3YrTjQzdnV6NThmCldiaVhX'
    b'RUNGVjNoMVhLREt0NmdLcitUcXVIQ1Y3NzlRR0g3MmNPKzlEOHVad2lLODJKWEFjZEh3QVFD'
    b'QTJxMXJ2M1V2YUpxbWxNcjEKM3Z2dzNQTnZMdHFyaGo1LzI1OHF2a1h6NEw5eFc5Y2pmMGY2'
    b'UGFCcG1vdi84bjk2SEJjZjMzc00zbzhRQUlBVmpzc0kzL3UxOFBjagpYT0c0alBCOVVJUXJI'
    b'SmNGdmcrSmNJVmorZVA3U0JHdWNDeG5mQjgxd2hXT1pZdnY0MFc0d3JFTThYM3NDSzlranVX'
    b'Sjd4SWp2QUk1CmxpMitTNC93eXVGWTV2Z3VOOEx5NUZnYU81dC84MmVsOFVFaFZuRFVwYktE'
    b'dEpoSGdsZmxvcWNjcEZ0M05xbkZmQVBUMXViYy9YbXEKWWYxeXh6Y1BFWllQeDlKSVQvclpm'
    b'OGljblFaQjFka2dpSGtVdDJvZ0JKQXVSZVlRQUFCc1FWSG1FU21IeWh6Q1JVajNLcDZMV0tt'
    b'Rwp0ZjVQUDBBM2IxNm0rT1l0d3FYbFdEanh6TXhqMzdlNHBtVU93VzBxem1pa1U3MzRwSC9M'
    b'MzB5ZStsNzkrcjhJano3bkMyeksrOVp6CllnNmRQdXltS3hUU3BjZ0ZSRk5nZHBxRUVKUHlr'
    b'KzdiSHJadnZXM1o0WHR2UUpjL0ZjTHIzUHJNdzF1ZStqYnV0aS8wcjYwVytMTmYKL3RiYnQ5'
    b'N0huanMxK2NEcTBYLzhXd3lPT0VMRnBrOGtTYWNhT2U1d05wU1lLaWsxd09neUJJS0F6Q0VJ'
    b'Ym1naWpHQUdPMFBDdU9GdQpMVTRkOWhCMmRkM25Jcjd1QXFDeTRVZnU3Zi92bmR6NW5oTjNm'
    b'ZTNrSi85MkVmSkQ3ZGF1Ui81dSt3dmZuNWNDRDgzWHRLcnYySFY5CjN6TlZ0KzFjaE0rdk52'
    b'dDY3dWxQbENJRjN6cVdxcFFORlVacFBiQ3hvQ3VRYVlDa1V6VjF3TmxRRWpPb1p4VXY1akVB'
    b'QUZLRDF0YTcKRW1vUkZuTVk1VllxMTdQaDQ4NTBQMU94am5NMkM0Q2Ftdm51blVEeXVjWEJk'
    b'MFBmTS9QNFovWThuRWdYc3pwQ2lCbllsSGUzbFZDTApqdEVhVXkyZC9YRk42SVowY0hzT0FJ'
    b'RFpZeTZFTkZRQmtndW9WRUNrUEFwQUFHRlRJY1FBQUJER0RjcWxnS2lKa2JvbXc0WUtDbG0w'
    b'CmVVL3l6QTlyUGUwOFN1cHNoRlE0ZFBJMXQ2R0J5K2c3MHZ4SHVIRFZFU0dNNE5VNTJpdjcx'
    b'ck1LajJnU0hEMWx4eXlhZHczdmJpbk8KSG5VcUpRU21rWkxGMzJzNndoWlB4bXJMZ0k2Yk50'
    b'M3FwanpxOURuL3pPdVcrSkFSalFLNlpLMldTSnNxRlZES0s4ZE8yMXYzeG1NOQpEcFRTaXds'
    b'TVNPTXpSMTJhQ00wN3ZubXBmSXNVNFVKd1JBaTkvczh5R0tVMzNaYVU4dWpGSi8yYnZ6WjE4'
    b'ZGYrNm0zNTZFbUhLaUJZClMrMmJvVS85OEVLUG9Vb1BiT3ZTRGMxRzZBSnVPenFlKythbnZx'
    b'VEhCOFpTd2h6b0k0V1lpdy83K3c0QWtXSEtJOHQ1dFA2R2xKUkgKZXgrcFdmOC93MUllWVdk'
    b'SmZvNmNPK2xRNXluRmhiNUFBVC8wMEVNTGRHaGJXMzN0WjI4dVRjZTRrZW5MUDM4MjNaYUVZ'
    b'Yk4xWHdJaApESnpScEJ6S3psQ0VRNHVmdFdFMVB2SGF2YjVkRGVmeTJVT0Rzd0hHQm5FWkxE'
    b'b2lzT3hMYzF4M0tKU1Y5SXFLMmxyMVZiL0RBOUdWCjN0cTJOWGQ4bGx6ZGtEa3pBTWdsMERR'
    b'bkQzb2JQNUd5Vk1yMk90SFZMSlFTT0dyVitUbkNOTURMeDdmanBSOTVkM1F1WEhGZFFJWHoK'
    b'eUxGMWI5dzBRSlRTcTdmbHJRR3BtTURwQ25uNG1Vb1R3SXZYL1lWWXM3R2pvZTdad1l0dkRW'
    b'MWdZUDJtYWpvbVEvdUhwcTBJZFAzcQorb0Y0ampjcy9lSEpsejl6clZnWWdWREc3ZDhRQzBm'
    b'ai9ZZnlKUjBkZmpPZzZEZ2pZUmJOdDQ1RFNHUDJxSXQwS255TVNGMjBSbjlyCkwxdDhpNkZ3'
    b'dmpqV1hKMHpBYkQ1MXBRdEtKNzljYTJ6VVNoTVV1RzNuS2lIR2JybEJ6bDdpMHBYelFyNjMv'
    b'LzZSeG11MEtCekdSTnAKdHJCT3J1UUNETDBrQmZ5ZXgzdDZONFJhcjYycEdRbkxFbHdobVZq'
    b'YzNtMEV0OG9sVm5RM1pQS2pWcDRHVmNXenV0ai9pMnJNcWxXcwo1WFVWb2oyeVZNREVERmFl'
    b'K0JaVjRlVndKRjFxWUdQQjI4NVJIdFZlTDZnQ05QUzBuM0lyT2w2VnV1VnJGZHEwSm1RQ3JT'
    b'MlpZbUh2Ci9zRnVRcmZRdHNwU1RBNzNtNUx3U3ZEYTY2VlpDc04rS3RsM3QzYy9jc2U2NU5o'
    b'SjNFYmFhL2RkZUdPL09QRzJGajZUNTB2akdRRUcKd0YzT2VoUmc3ZldseWs2dTcvOVVWMi9K'
    b'QzFrTWhNMXpqd2JmdmNSVGJ2aVdKa0xnNDY4UnFkbVJ0VlpMYmZ2aUYzNWV6WVpKeXEwNApH'
    b'MHA4c2ZyTTUzNWpOM2tYcVR1QUtBUUE5ZDdhbjV3K2YyamdmTDNCQjNwKzZkNTZsNkZyVDR0'
    b'MDBPWlE1ZEk0TDM1ajN4ZTcwVmh1CjhnMU5LRm05NnpMOXg0Qm83M0NxaU1HZ3BCbmhnZ1FC'
    b'NEYxMTlVWlJRQWdkcFhXWU1IS2p0S0VEaEYwYmZPcWozdkMrSkN1QkZ1TkUKK2gvK3NMUlF3'
    b'YnV1czdYVnA5N3ExUVhwZ3gvTVZFbUJ6YXd0S0tHazdtb3VPZW9GMml1emM3YUpXeC9jN0Jo'
    b'REJsK3lpV0dYa2lJWgp4OG5SRElOUk9tNzU5NEZ6N2Y3QU9GRlpWUjNxc0pFRVFmUWtjanRY'
    b'dFg3aDJsdkVmQzRmbndKTlZGS1FtVmgwSXBHSjVRcUNZcWdHCmdKSjJVMWZHUzFLemxXVDhZ'
    b'dVM0c3hqRkcyNUtZN1NSSGFWQkNKRHk2SWZpVy84dmY3M3VPMTlCTEJTd3VHT3hJL3hZMWJI'
    b'MXpnUmcKZ0JhZlhFcmlBQUNJZVRRM1ppbmU4bFZIcUNrSlZmMzJpVyt3bkpCTVpSdWJJZzVF'
    b'YVBSSW9ZQzdkeXBlY3RWcGlpZ1Vpem1PVlFscgp5VFIrdEp1aEthL2R5dEpBeWVOMzEyKzdz'
    b'NjZ0MG1lemJyeHFselBZNkhONFBZanN3clJjU2RCc2JqSUt0ZHlXck94aWFZOWlyeFBGClBH'
    b'cnFJRHREbFVubEs1Y0lBUUJBYURLNGQvY0hjTFQ0Wk15cVYzUnd3NytwTE1WeGkxOFcwN2pF'
    b'dE5MWGR1dEZ2UVQ3bFVLeXF5blUKNkhXOVpudWdCTmZsRkg4dU52MTQzeUFPUVZzWm5Cdys3'
    b'REpFTjAxK2JsY0hWQ3loWklDd212SEppS3hiTVZ0Z3ZPZGdpbGNrMUVxNQpXM2o3YXRqcW54'
    b'aDh4NmpzVkQydDlYU0JuekFER3dzd1pob2FwRXN3NVZHeUk3UW13bjhVM3ovZmgxcHBZSW5H'
    b'a2tYNG9SeDlIUnpoCjFIQ2IxblpYSE1hTllwUVFjcmp0Z1NlYldxNXprcE82aWN3TTlOUzdi'
    b'UW1xUGtVM0lETEhHd1Jya01QSmFHZHpkelBBb3lwZlNzNXMKdnU3ejdWMS9saEc1SW9nN1hH'
    b'c1FPYUtLWXlacWR6cTlDdU5UcXpvNjI5c1JUMk1TOTltMy9qZFAweGF3L1M2aDVtcW01emtJ'
    b'TlVhZgo4NDIrVUVGNWxNSVV6VlJKdVRHNnJQQ1ZTNFFmd0xGbVo1YXBrbUhVN0gwMGlPQUc0'
    b'ZEJLVk5PVE90VmNZWE42dHhpRmJNOVRENTAvCi9VWnkvUFMrblF6Z2JKK1ZiQ1NPM3RCYXQ2'
    b'ZHB2TkZSekUvT1ZXNjZkc2VPclpTbENoVENoV0lCSml3WW1CazRPK0txMmFTV1R0a0kKcGFu'
    b'NWRsbk13c1VCZzR1WUFHQkUraWh2YUU2bGFqT3ZTN095WnhWdnFWUmd6S1E4YW1HYVltZklz'
    b'c0pYUmhIK2x4d3BqK0pxS1FXdgp5bkVSc25wYkhpR04zQmg5Y04wZGJSMjNVRUxTb1F6eHNY'
    b'Q05Ibzd4S2wvSXhHYlo2MjYvMXdYd0JrcVJhczZVQUFxM0YyYkdPMXNiClFJMUhFYzFTc1VV'
    b'Y09lejJkWXlNekV5ZFBwcWU2aS9hTjRHK3JWYUtHTC93MjlsWmpuVjA1d1JjQ0Yrdzl2d2dl'
    b'T0VISTBuQlk0QTEKVitkb3J5em1NUkEwUWRqazVzaDN6NlZsZ3Evc0l2eFBIRjMxR1VNSC9W'
    b'MnNvMTZnM0tvdXdJV1lQZEc5aFNzcGdveVBtU0Z1NERjNgp6ZGpkQVppeStxc3E3ZTdxMnNZ'
    b'T1A5am5JelU0SDhiMFNHb202cStyeVplS0VLNlJqSTkydU1KakY2TjloN0tKV09QR1hSczdv'
    b'aDVICmpaUWJKS1FSRDJNTElvTDh6cVBVK0l1RE03TUZRWXR6Zkl1TnlZMFRNMis2Y0VhejFZ'
    b'aWxKQTVqcGxEd2xnKys5OTgzb014RzlSMjcKUE52WGo5Ni9sWEpJTTBkZDlkZGxBQk1vekJK'
    b'S2hTT2lZSnNxcFdvc2NWRU5PdG1NdTZvcVIzajhFRzVJMkxPdnZPS05qdC9kR1pSbwpOTkQ1'
    b'R1UySjhxLzNhU0RsWmlCSUcrSlNIbEVMTVpWdG5iZDNqVHg0czhYVkZJN2libnc4bm93d29h'
    b'MHpMLzV3N3NJSlJkTkcweVVJCkJEQUV0bmZjcVJiR2FDalN0aS9PVkVrQUFNUk8yMUdHdUtI'
    b'dm1USzhSN25zSWdRQWdQQTY3Ylc4THVuSkMwejBsTjAwUVU4YjMrdXcKUFhiNElMbTFhLzNx'
    b'aW12a2czSnRQVjVLQzJvdDkvWERaaVh1c3VqVzJhamszdlNOWHZidTZndDFxOVpvc2tnRWR1'
    b'T3VZR251ZEc2cwp2N3E5U1FWdGZTLytDeXBsZTEvOFFlZU5uMVFzdXJ2KzVuTy8rcXR3Smgv'
    b'TENCMVg3V1RPbmQrKzU0c3lnSlpxZHhaN25rVUhuaW9tCjhQQmJUa2RJb0N0a0V6Yks4eDd6'
    b'Y293UUFJRHNNTzV0RjFydVNEaENncERHWm82NDN0Wm9PNDNrV083VjArbHREbFhFSzJ5aVlM'
    b'SHcKOHYrK0RVbEhMYUdRTlQxMnBtKzhlMHliZkNQMnlwNW9qWkRUY3M5UHoxWlRycWJRanZz'
    b'RUxoc2ZPRmE1OXNZemJ6NjcvY1o3L0syYgpNV2ppN0N1L1hMdjNKc2RRcXBQYzZiUTVjSHRU'
    b'eU0rTWprOVhaNCt6SnFkd2lKRENLdGJ3cWdoRGlHSHhac3Z6dllLQU1wMlhSbm9VCm1VVjZ2'
    b'bGMzK2tLRnJrSm5aY05IVzNZSGtIN05laVFEbm8vRUQ1VHFMN0IwVnFXZXdMZmt1WVRtclJw'
    b'MytsVFNLRG5nS2xXVWlnV1YKQXloakhPVlBuanZ3TFVoT1ZYZGM1NnRmRTJ6c3NGanRxRktZ'
    b'T25rK01ueEJ5RG1TbzBPd1p1V2lXYnZWb3FoRnQ4OURraUJSNVZVRgpHR2MwWFFVTDB5Uktt'
    b'c2srYTNtK1ZXV3EwTjFTTkhVZ1AwbjUxbk9CemZtTFQvcGxHQ3VxV2o4SHlLYWgyUU1hQm4x'
    b'dnRDTUQyQ0VRCndCSElMWXgwNXVLcjJtc2pESU04MmFkY0YwUUJvSDhpSnVtR0hWZThIbTMy'
    b'NGpGZTBoQVNSd2c4T25VYVp1VnprWktkUUNlR0w3QzUKV0JyZUhMMDRxRUZJTkdxTkFaWXFD'
    b'MUx5QnB0UjAxWWp4cy9hdk8wOFRCZ2dhS3hFK0RGRzdJeXRiVis4ZFc5Q3pLSEpQa1lUWVJ3'
    b'aAp0amF1TTR6Y21zWk9LenVYTEtnRWhsb1UyWVF4RWpFVVYvZW9jajR5WjZ4cmJ1Ry9YcFhV'
    b'Y0p6Tkg0bnBXMXViRURuSkplRDAyY2NvCmR6V0dVN3JBY2pQOXZWR0xtWTJwaEd2bTdKR0dw'
    b'dFg4MEJtVHo2SVlrY3RGQVQ0L0tmTEIzVjlDQ0gzbWlEczdTaWY3bWVxdE9WOEgKdHhMaHg1'
    b'a1dhZVRHYVNHRmdSQUFRb0JwZ0FLWEhVdk9mR3IzZGFpaE80S05Cd1l5UVIyVHM2SUhVeFdJ'
    b'bUpVeFhqRktYTHJPaDZLOApYS1BMSlF3aUNmcVhmUk12M05ncUEwamN2b2ZsVEVuS0doWmFn'
    b'MGlLUXV6T1ZvS1U3SUd0M3NacTFYbXpNRHVnWkFZQVZhYXNPT1gwCkd4QU52V05TYmprN1Nu'
    b'dmFlSlF5NG1mdHdaVUlQL3J3ZGZDYUFISVJNak5NRXc0TnMycjMxUGdNcjJjdVBKbWY3TFcx'
    b'Ykk0VWNBSTIKV2NqYVNrc0Zuak0wSkpWTjJ6SGNhdWFreDN2MEVKRXRTWFlwLzZtMjVrTkpi'
    b'WUxqdnJJcE1qWGhMYXBWQUFBVFRnWkNhWXpFeHdXZwp3NWZnV0lZdlRCUXdQK3drV3l3Y2lB'
    b'Q3lhcFpTUmNnQTZRcGx4eitPcFFjdHBnWWl0TG1pOEdPTTNKVFg0czZRYm1YVkp6bXBnT1Fu'
    b'CjZlN1UrZDZoVjgyR2RZQW9HV2ZtRlB1dFJVVFNORmlFR1VETGNvcm5xK0FzQXRHcDFJYmdR'
    b'NTlORjB1aGFYY0ZYL0NxYWduMWhIVGoKNWFQVjlSYWx5cTB4VGk5SklOTW9kVHlLdm43K1RJ'
    b'L1Q4VUJyemdEbHNKS2Z2bkFNdjM1ZlgwcXhNQ1E5OXpJRUc0TlArUjBOSmRxcgpZRmJOMmFp'
    b'dlJQaFJoNVRNR1JvZzVqREtYVXdQV3FLL2RkUmNrNjJVb05VNzlvem1XVUlPMDVvQW8xaEdn'
    b'dXlvb21xd0J1SUZCYWhyCkRFbWFGckprZEZDbTNaNmswT3JaME5FUHQ2L0JJcDNhSUExNUNK'
    b'TW5QSmJSaVVSenBmMm5iNHpKbW56NDRvalIxbnpmQ2ZObk43dFcKNFRhKzdab01YYWRvVTFH'
    b'anBqMCtqSkRtaHZ1blRSM01UVkJTSGkybUdHOHNYWVpmRGN2b0F0dTc0OTN1WlpRdFRYc1Zo'
    b'RFFVRGdWTQpFRUpOU0ZlZnFycnBySVJ0dkdhdm82MnpKNEVuVlFxRllRVFFZSXpTWmZhRzdS'
    b'WkhiZWhRQXNJVE9zS2xSRVZ3WWJKR09pcWtvZk1aClRuT3VveGduaUEwcVZHVmZmdlNwaThK'
    b'TGd5TzZhYktTS2hoZ1JNVkNGVFlSRDZweUNUV0tqWFpJUC9oclM0VXdmZGdkT2Vsa3FxVDgK'
    b'T0MzbHpBdmZQRlNHbmVUS0tFSXBtZXY1SDE4Zi9PYS82WUlrYzZnMUlFRVF3TTBSM2pXOE15'
    b'UndzOWhwZ3h6aStNUERBd2lnSnBWYQpqcytqT0FsQUdJQ1JsTVk2SVBaa1dHbXZDa2cvZVU1'
    b'akdMV2hRN1NGT01UeDRFdlA5TWFUQVFiZXVVcEhvY0twT2ZTZjNwaWJ5aFNLCmtnQUFnTjlL'
    b'cFhoeGpTK1lNb05XblYxUDVPTndmVHljY0F3ZXhCbXRZaTFmdXpNTDZBQk1tTFBIWEVwQmk3'
    b'MXlQSGQyeUx1anMzd3UKazVaTGhQK3BkYUFtd3RhQWJBdEszalU4akpqVFI5eUVUVjJOeTZK'
    b'dXlqWWZUcUlwSlpCUkVCZ2pUQmcxWVl5R3RFaml3bHFmRFNaTQpxcnV1dGNIUTAzT0RKdkJL'
    b'ejBGQkZuRVl4akIxbzUzOTl3R3oyZzMxVEF1U3JHUkxQQUFBZVZHcTgzaHBEUGp4a2NQN2gw'
    b'WTgvcnJyCmJYbmswSzlvTWs1NWxQaFplekZHb0pSUm1DVVM1Mnp2enEzY0dqc3VmWVMvaisv'
    b'M2YrNWR3MHNzYXZYSm5sVkZKaWdwUEtwR2xMU1UKRDZuWkRWYmpCZlBxa2dxQWhBMkVFQjJB'
    b'VFJDNlFUNE5UcDFlalFNQm1sRkZXem94a1dYTk5ubHV2Wm9NNWlkYVllV0pCUDJ6TTFNegpP'
    b'V1cxMzNweUtpSElFZ0FBRG92VlN0bU9qbzVzYXQyb0s3d3BTenZkcVBEMjY1VmRuSzZDbGVz'
    b'NS84YkMxT3NlTVkyeDRmZi9YMmhJClN2bHdYT3c3MlA0UTN4KzdMWkZ5SysxL0hxVXJsUERi'
    b'RGo1S2JQcXI2ZWtqTHRQbTZiT0dxcHJXaHFlUngrM2I0enE1Q2NvMVN2RU4KMmttUHM0THN2'
    b'bFpnMDdNdkh5cTlNdHo4ODM4STFyU1FWdWV4M3VQUERBMisySHRTVkdSSlZkNDllSjNUSVdw'
    b'YXlPVThNVDM3dXl0NgpJR2luNmJaQXpUL256N2pOcWV5WVJaY2hoTlNiOXlSbmpyakM3emlF'
    b'RlA2SGt5eUhiZ0JMRnVGSFdVeGJlMjNXWGlzMDM1Wjg3K3c2CitMU2Z1dk1lWjlmVnlaODht'
    b'RDNCNFM1UTVRQ3lDamVxblkzLzYyR1JjRDUyK0hsdk1VM0k3SW0wVk9QeEJIVjR4dWM3M0g5'
    b'bWNHNm0KTFZBTEFYcnY3QlFHbzNzNlFtK09SZ3Nsb1NSTGJpdlQ0UFdVWkxYV1JYY3F3dTJU'
    b'aDF0dWp5UEU3eTZualIybzBHV28vL0hBQjh4egphWnR6TEUyRXMwKy9kdTcrN3lwWjlvTWY1'
    b'bXdxV2YxUys1L0hhSy84N2s4U3ZVeDJ3bDY4NFNzdG03ZkVEajhycFZLaXpjS3lHVUpoCmVW'
    b'bjlWOHVHVCt1cThkUnhhcy9hNG9IejlNYVF5Q0pmSUhQdjRTTXdGQVpoU1ZVcWJEWUloSE1s'
    b'M2tYVGtWd09BQUFMUWRwTTVTQXcKNW00cHZIY3RyWmpBcHcrNUkrODQrQmp4d1ZQRlhMYjEz'
    b'Ly9ybXJ1di85T3ZoZTlXdnFGdi8xd1g1UTk5c0pqRmdsZmxrNzFNWlRkYgpTdUVUTDN1cnR4'
    b'WHk0eVNaSEIzbWpKSFIwMEVQbFl0UERWMDhrMWN3bXhrS3JGK0hmLzhBMGxsbC9Ib2tjYysy'
    b'YzM3L043UFRvaUxiCktCb0VRTGZGZXQrV0RockRnamE2TDVyZ1JFSFZkVTRVZnlmSmF2Mk5Q'
    b'TUU0ZUg4M083TGZSN3BWektLUDdQZEpMSnJzWXo1MHFyb28KenoxL2RFbXFZN25ma0k4eld1'
    b'ZVh3Z0JzK3Rad0U2OTZXKytLbXlZdzlMUmZoZDB2UklkTTBIVFpuYmJHVFJaUGwvSDZxVGQz'
    b'cmE5MQpleGdVclFGa3pGSnhwQ0NlbVIxVkZYNkR2K0xBNE9nMW9mcVIrRnhYbGUvMTZYaTFn'
    b'NW5Kc3BLcXpHYlNBQUFnZ0huQ21tV2dWUE9lCkpBQUNJL3Q5ZGJzeTZVRnJkcFNlT2V5V1Zt'
    b'N0lCeTZ2allTN3RWaHpUYmF5azZNcmZnZFhsNkhKMXp4Q3lYV0d3clo5NXVzU1NzcTYKN3FW'
    b'dDhkbUI4UlA3RmN3SnVlbzJiS3lMcERoV0FhT2l0bjkwTnNIbTU3SnA0Ly8vc2phS1lnV0JJ'
    b'YW1nbmNsbDB3ZXBHVWdzdGU1TgpRSWo1L2luMHNKc05rNWUydUdreHErUHlXSnhXdlMzdmFD'
    b'ZzEzSmhHS2QzVXdkN0hncXMrR1l1ZHRvdDVtcnJqYXdPVDUyMmU2dWpZCjJXUXU3OXIreGRa'
    b'cWQ0Q1NHQ2gzbWk4QklINzN6MThsTURUTnNZcW12WHUwQ3BzOXlSWUFBT2l1cTY5T2puekRE'
    b'RU9JNmxuRmF6SlUKc1pZSEFFQXR3dU92ZUNVV0dYK3g0cExudkdnY0Z6YkMrZXJoQWlGbXpj'
    b'NHM3VkVhYjA3MS95cFF0eXM3OGFxbjg4dXptV0ZMWnRpcQpNNVZETlJ2Qmx0MktiMzBEMndO'
    b'YlhKbDg0U3AvTEU5NkgzNXI5c2pJNkZoMDhyMURCZDJWcmRVdHZSUDlIa0Q1S1RscVRRcSt0'
    b'U3hxCjFia3drUm0yZFAzbHJLNUNveTlVU0RsMDhqWFA1Uys2WHdTT3kyYWhOa29hTmRka2Ni'
    b'dnE3MkkxQ1VwZVlDcldjcllhRWNhTTJXT3UKVW9vQUt1dk4zWitEU2NOS0tsYkhxSzZ1K3Vs'
    b'RjZkakk2R1FtSjh0c2lpL0NFT3hqN0IyMW9TNlR1eVo1ekpyZ01ZdGF0UzNIemxDNgpCSG5h'
    b'K2ZTZ0ZjRjBOa3dXNDBUNGJhY21MWStGMmd2VExtRmhHaWdoaEJHNk1RMmpSdkNxZkxMUFd0'
    b'bk5ZclEyZWREajM4RGlqSmJzClk5Z3dBY0FFRW5DcmdYWXUySFpHVnY3MVRQOFh0bTk5Njl6'
    b'WnRiQzVDWlU4cVVtcm1EUVZCV2UwcXEyRnhEbkd1NVl2SmJCaW5EQlUKc0dJZEZ6MWx6MDlT'
    b'c1o1NVcyaS9DQnlYWDlPU3BqMUpRd1U5cTRwVlcvSmpCeXBjelVYY3JpazhvdkF3VXkxcEVw'
    b'UWR0WWhaVkZjZwpFRFIxRFZKTE1BZ0NDS0hqTm8xeXE3WmFBVUxOekpDbG1NQmgxS2pzWWlI'
    b'VVZEaWtHTWNCRUlqMjJPSm43RmR1MDVKRjYxNVd2VDFICnVWUUlOU3E3T1VBSGtnUFdVaHp2'
    b'dW1kMjRJa0FqQm51dHFLalhqQk5RQk5oWFFWeHF5NW1VUkEyY2JzbUpMREpRNTVWZDhjRy9t'
    b'OEEKUXN5MnUrT3gwelpua3hBKzZ2U3M0Y2NPZUxNamxvV2UvTHh6aE9ZUjMyc2QreGFuKzV4'
    b'dXZTWDA0SE80TDVUdXQ2UUhMVFZYNXdLYgpDNWxoQzBaclVnSEZhQzE2eWc3QjVzeFIxL0F6'
    b'bFFvUEo4NHp1WEVhb3pSWFd4Rm5OTXlxdWR1S3dhdHk3QXdKbytia1FiZXQyV3JmCit4clpl'
    b'c3NpVEQ1KzhNVEJkZnNtLyszNU1sSzRoSzBEQzZkZXpSMjRueDJYSU1Sd3RaUmN6Y1hJQ1Fk'
    b'S0daVmRCY0t1OVQ0YWREWUsKZElVc3BEQUlNVW1YNmxuTnB5OWFRY2dVc2xodWxIWTBsQXFS'
    b'MnRvdmY5VzIrZTVGcUFJTHhIRTVOYlA4WXcyVVNxTW5ZMDk4VjRuMgo0bFlwUDBreDFTSmgw'
    b'ekJHZzNFRHBYUVFOc1VNTG5Pd29ZTmlHb013MDlUQVlwcjJicTd6M3ZYdFAyeE11dXphSGw5'
    b'R1M5bnk2OXNwClRKN1BIdjVGY2FTZnNrN21SbEJWTUgwZFhPS2N6VFNCeWs2ZWkza1FtOWZh'
    b'MnVUWTlaZFUvZHJ5K1doZUpzZGwwTmg1NGJxWGZjaG4KZEpsdy9QanQxWmRiMDl4eS9vNDBM'
    b'eHpMZDVPRHBjSzM3RGgrNUsxR3JqQjh5NGhqMlczNFV6NzRsZ3ZIRDl0MjY0ckhWLzRjeTJY'
    b'egp1M0xHVitZYy84Z1dsQ3Y0bGcvSEpkNElkbm5oSzArTy8zRTc1aFY4eTVEajBteUt2dHp4'
    b'bFJWSDBEVE5GWHpMbWlNWWZ2YndDcjVsCnpSRjhHdTFhd2Jlc09jSjN3djVGd0ZkV3JRTVhZ'
    b'Y3pqSGgwZmZuVm1RUlZlYWZpV2hPTUNLZ3pjY3ZXT2wzN2t2V285Y0FVUFcxdDkKN2Fkdktr'
    b'N084YU16eTBuaENyN0Y1RGovQ3EvQXlyZTAxWEUrRmE3Z1d4S084Nlp3QmQ5U2Nad0hoU3Y0'
    b'bHBiajVTcGN3YmZrSEM5ZAo0UXErTXVGNGlRcFg4SlVQeC84SGZtNG0zSXJMazZ3QUFBQWxk'
    b'RVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURJdE1qWlVNVGM2Ck1qRTZOVE1yTURBNk1E'
    b'RG9KeFZJQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEF5TFRJMlZERTNPakl4'
    b'T2pVekt6QXcKT2pBd21YcXQ5QUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAgICBpZD0iaW1h'
    b'Z2U3NDIwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_FL')

US_FL = b64_US_FL
index.append("US_FL")
index.append("United States of America Florida")
catalog["US_FL"] = US_FL
catalog["United States of America Florida"] = US_FL
country["United States of America Florida"] = ('US_FL', '', 1)
lookup["US_FL"] = ('US_FL', '', 'United States of America Florida', 1)
lookup["Tallahassee United States of America Florida"] = ('US_FL', '', 'United States of America Florida', 1)
lookup["United States of America Florida"] = ('US_FL', '', 'United States of America Florida', 1)
details["US_FL"] = {"continent":"Americas","capital":"Tallahassee","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_FL"] = ('US_FL', 'United States of America Florida', 1)
regional["United States of America Florida"] = ('US_FL', 'United States of America Florida', 1)
#----------------------------------------------------------------------
b64_US_GA = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iOTYwIiBoZWlnaHQ9IjYwMCIgdmlld0JveD0iMCAwIDY5MTIgNDMyMCIg'
    b'eG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8cGF0aCBkPSJNMCAwaDY5'
    b'MTJ2NDMyMEgweiIgZmlsbD0iI2I1MDAyNyIvPgogIDxwYXRoIGQ9Ik0wIDE0NDBoNjkxMnYx'
    b'NDQwSDI4ODB6IiBmaWxsPSIjZmZmIi8+CiAgPHBhdGggZD0iTTAgMGgyODgwdjI4ODBIMHoi'
    b'IGZpbGw9IiMwMDJkNTYiLz4KICA8cGF0aCBkPSJtMTUwNC40NjUgMzkzLjc4NyAxMDIuNTkt'
    b'NzIuMzQ0LTEyNS41NjQtMS44MDUtMzcuMTU5LTExOS45NjQtNDAuNDM5IDExOC44NTctMTI1'
    b'LjU1Ni0xLjgwMiAxMDAuNTYyIDc1LjI2MS00MC40MjYgMTE4Ljg1OCAxMDIuNTg5LTcyLjM0'
    b'NyAxMDAuNTYzIDc1LjI1NXptLTQ5My4zNzcgODguMjg3IDU3LjIyMS0xMTEuNzI2LTExMi4w'
    b'MTcgNTYuNzQ2LTg4LjY0NS04OC45NTQgMTkuNDIyIDEyNC4wMzEtMTEyLjAwOSA1Ni43NDYg'
    b'MTI0LjAxMiAxOS45MTEgMTkuNDMzIDEyNC4wMjYgNTcuMjItMTExLjcyOCAxMjQuMDEgMTku'
    b'OTA2ek02MTMuNzE1IDc5MS45NjhsLTEuMjUtMTI1LjUxNS03Mi44MTYgMTAyLjI5Ni0xMTku'
    b'ODIyLTM3LjU3NCA3NC44MjkgMTAwLjc5OC03Mi44MSAxMDIuMjkgMTE5LjA1Ny0zOS45OTMg'
    b'NzQuODM3IDEwMC43ODctMS4yNTEtMTI1LjUxNiAxMTkuMDUzLTM5Ljk5N3ptLTIwNC43NTQg'
    b'NDU4LjEzNS01OS40MjgtMTEwLjU1NC0xNi45NDEgMTI0LjQxMS0xMjMuNTU0IDIyLjQwNyAx'
    b'MTMuMDkyIDU0LjQ4LTE2LjkzOCAxMjQuNDAzIDg2LjgzNS05MC43MzIgMTEzLjA5NSA1NC40'
    b'NjctNTkuNDMtMTEwLjU1NSA4Ni44MjktOTAuNzM0em0yOC45MjEgNDk5LjY0NC0xMDMuOTkt'
    b'NzAuMjc1IDQyLjgwOCAxMTguMDMtOTguOTg3IDc3LjI1MSAxMjUuNDUtNC4zMTIgNDIuODA4'
    b'IDExOC4wMjMgMzQuNzI3LTEyMC42ODcgMTI1LjQ0Ny00LjMyNC0xMDMuOTkyLTcwLjI3NCAz'
    b'NC43MjEtMTIwLjY4NnptMjU4LjkzMSA0MzEuODIxLTEyNC43MzEtMTMuOTA1IDkyLjc0OCA4'
    b'NC42MTgtNTEuNzUxIDExNC4zOTYgMTA5LjA3NS02Mi4xMSA5Mi43NDQgODQuNjEtMjUuMzMt'
    b'MTIyLjk5NyAxMDkuMDY2LTYyLjExOC0xMjQuNzMyLTEzLjkwMy0yNS4zMzUtMTIyLjk5M3pt'
    b'NDMwLjcyMSAyNTkuMjczLTExNi45MDIgNDUuNjQ2IDEyMS40NDEgMzEuODI3IDcuMzMyIDEy'
    b'NS4zMzggNjcuNzItMTA1LjY3OCAxMjEuNDM0IDMxLjgyMy03OS41OC05Ny4xMzYgNjcuNzA4'
    b'LTEwNS42ODItMTE2LjkwMyA0NS42NDgtNzkuNTgyLTk3LjEzem00OTkuMjM5IDMwLjg1Mi04'
    b'Mi4zIDk0LjczNiAxMjIuMzE3LTI4LjI0OCA2NC43MzIgMTA3LjU3MSAxMC44NTgtMTI1LjAz'
    b'NyAxMjIuMzA4LTI4LjI0OC0xMTUuNTk4LTQ5LjAzIDEwLjg0NS0xMjUuMDM1LTgyLjI5OSA5'
    b'NC43MzgtMTE1LjU5Ny00OS4wMjN6bTQ1OS4yNDMtMjA0LjE5OC0yOC44NSAxMjIuMTI0IDk1'
    b'LjE3Ny04MS44NDcgMTA3LjMwMSA2NS4xNjktNDguNDg2LTExNS43NTggOTUuMTctODEuODQ0'
    b'LTEyNS4xMzcgMTAuMzAxLTQ4LjQ5Ny0xMTUuNzUtMjguODQ5IDEyMi4xMjYtMTI1LjEzNCAx'
    b'MC4zMDd6bTMxMC4wNjEtMzk2LjU2MyAzMS4yMDIgMTIxLjUzOSA0Ni4yNDItMTE2LjY5NiAx'
    b'MjUuMjkgNy44NDQtOTYuNzItNzkuOTY2IDQ2LjIzOC0xMTYuNjktMTA2LjAxNSA2Ny4yNjct'
    b'OTYuNzI1LTc5Ljk1NSAzMS4yMDMgMTIxLjU0LTEwNi4wMDkgNjcuMjd6bS01Ni42MjItOTcx'
    b'Ljk0MiAxMTcuNzM1IDQzLjM3MS02OS43NTQtMTA0LjM0NSA3Ny42My05OC42MzktMTIwLjc0'
    b'NiAzNC4xNTktNjkuNzUyLTEwNC4zMzgtNC44NzUgMTI1LjQ0OS0xMjAuNzM5IDM0LjE2OSAx'
    b'MTcuNzM2IDQzLjM3LTQuODY5IDEyNS40NDZ6bS0zNTUuOTA5LTM1Ni4zMDUgMTI0LjM5OS0x'
    b'Ni4zMDQtMTEwLjI0OC01OS45NzkgMjIuOTA0LTEyMy40MS05MS4wNDEgODYuMzUxLTExMC4y'
    b'NDMtNTkuOTczIDUzLjk3NSAxMTMuMzQyLTkxLjAzIDg2LjM1OCAxMjQuNC0xNi4zMDZMMTk2'
    b'MC42NCA2NjYuMXptNTAyLjY4OCA4MzYuMDAxIDg0LjEwMSA5My4xMTctMTMuMjc5LTEyNC44'
    b'MTQgMTE0LjU4MS01MS4yNzEtMTIyLjc5Ni0yNS44NjQtMTMuMjgxLTEyNC44MDYtNjIuNjEz'
    b'IDEwOC44MjItMTIyLjc5Ni0yNS44NTEgODQuMTA0IDkzLjExNy02Mi42MDcgMTA4LjgyMnoi'
    b'IGZpbGw9IiNmZmYiLz4KICA8cGF0aCBkPSJNOTE4LjY3MyAyMDkwLjAxOGgtMzYuMzU3di00'
    b'LjA0NGMxLjAyNC0uMDggMi41MDMtLjE4OSA0LjQzOC0uMzQyIDEuOTM0LS4xNTEgMy4zLS4z'
    b'NzkgNC4wOTctLjY4NCAxLjI1Mi0uNDkzIDIuMTYyLTEuMTU3IDIuNzMxLTEuOTkzLjU2OS0u'
    b'ODczLjg1NC0yLjA2OS44NTQtMy41ODl2LTU4LjU2MmMwLTEuMzI4LS4yMS0yLjQzLS42MjYt'
    b'My4zMDQtLjQxOC0uOTEyLTEuNDA1LTEuNjY5LTIuOTU5LTIuMjc5LTEuMTM4LS40NTYtMi41'
    b'OC0uODcyLTQuMzI0LTEuMjUzLTEuNzA3LS40MTctMy4xMTItLjY2NC00LjIxLS43NDF2LTQu'
    b'MDQ0aDM2LjM1N3Y0LjA0NGMtMS4xNzcuMDQtMi41OC4xOTEtNC4yMS40NTYtMS42MzIuMjI4'
    b'LTMuMDU1LjUzMi00LjI2Ny45MTItMS40NDIuNDU2LTIuNDA5IDEuMTk2LTIuOTAyIDIuMjIy'
    b'LS40OTUgMS4wMjUtLjc0IDIuMTY1LS43NCAzLjQxOHY1OC41MDRjMCAxLjI1My4yNjUgMi4z'
    b'NzUuNzk3IDMuMzYxLjU2OS45NSAxLjUxNyAxLjcwOSAyLjg0NSAyLjI3OC43OTcuMzA1IDIu'
    b'MDg2LjY0NiAzLjg2OSAxLjAyNSAxLjgyMS4zNDIgMy4zNTcuNTMyIDQuNjA5LjU3djQuMDQ1'
    b'em05OS42MTktNzYuNzkxYy0xLjA2My4wNC0yLjY5NC4zNDItNC44OTMuOTEyLTIuMjAxLjU2'
    b'OS0zLjc3NSAxLjE1OS00LjcyMiAxLjc2Ni0xLjM2Ni45NTEtMi4yOTYgMi43NzMtMi43ODgg'
    b'NS40NjktLjQ1NSAyLjY5Ny0uNjgzIDYuMTE1LS42ODMgMTAuMjU0djU5LjE4OGgtNC45NWwt'
    b'NDguOTMyLTY2LjEzOHY0MS43YzAgNC42NzEuMjg1IDguMjYuODU0IDEwLjc2Ny42MDYgMi41'
    b'MDYgMS41MTYgNC4yOTIgMi43MzEgNS4zNTQuODcxLjgzNyAyLjY3MiAxLjYxNSA1LjQwNSAy'
    b'LjMzNiAyLjczMS43MjMgNC41MzIgMS4xMDIgNS40MDUgMS4xMzl2NC4wNDRoLTMzLjExNHYt'
    b'NC4wNDRjMS4wMjQtLjA4IDIuNzQ5LS40MzYgNS4xNzgtMS4wODMgMi40MjctLjY4NCAzLjk0'
    b'NC0xLjI5MSA0LjU1Mi0xLjgyMyAxLjMyNi0xLjA2MyAyLjIzNy0yLjY3NSAyLjczMS00Ljg0'
    b'Mi40OTMtMi4yMDIuNzM4LTUuOTQyLjc0LTExLjIyMnYtMzkuODJjMC0xLjc0Ni0uMzA0LTMu'
    b'NDkzLS45MS01LjI0MS0uNjA4LTEuNzQ3LTEuNDIzLTMuMDk0LTIuNDQ3LTQuMDQ0LTEuMzY1'
    b'LTEuMjU0LTMuMjI1LTIuMzE2LTUuNTc2LTMuMTktMi4zMTUtLjkxMS00LjE5My0xLjQwNC01'
    b'LjYzMy0xLjQ4MXYtNC4wNDRoMjMuMDQ0bDQ1LjQwNCA2MS42Mzh2LTM4LjQ1M2MwLTQuNzA4'
    b'LS4zMDQtOC4zMTUtLjkxLTEwLjgyNC0uNjA4LTIuNTQ0LTEuNDc5LTQuMjMzLTIuNjE3LTUu'
    b'MDctMS4wNjMtLjcyMS0yLjgwNy0xLjQyMi01LjIzNC0yLjEwOC0yLjM5LS42ODQtNC4yMS0x'
    b'LjA2My01LjQ2Mi0xLjE0di00LjA0NGgzMi44M3Y0LjA0NHptMTE5LjA3NyA0NC40OTFjLS45'
    b'MTEuMTE0LTIuMTQ0LjMwNS0zLjY5OC41NjktMS41MTguMjI5LTIuNzUxLjU3LTMuNjk4IDEu'
    b'MDI1LTEuMTM4LjU3LTEuOTU0IDEuMzg3LTIuNDQ3IDIuNDUtLjQ1NSAxLjAyNS0uNjgzIDIu'
    b'MjQxLS42ODMgMy42NDZ2Ni4yNjdjMCA0LjU1Ny4wMTggNy42MzMuMDU3IDkuMjI4LjA3NSAx'
    b'LjU5NS4xNTEgMi45MDYuMjI4IDMuOTMxLTUuMDQ2IDIuMjc4LTEwLjA3MSA0LjAyNi0xNS4w'
    b'NzggNS4yNDEtNS4wMDcgMS4yMTQtOS45MiAxLjgyMS0xNC43MzcgMS44MjMtNS4xNiAwLTEw'
    b'LjEyOC0uOTY4LTE0LjkwNy0yLjkwNS00Ljc4LTEuOTM3LTguOTUzLTQuNjg5LTEyLjUxOC04'
    b'LjI2LTMuNjA0LTMuNjA3LTYuNDY5LTcuOTkzLTguNTkyLTEzLjE1OS0yLjEyNS01LjE2NS0z'
    b'LjE4Ni0xMC45MzYtMy4xODYtMTcuMzE4IDAtNi4xNTMgMS4wMDQtMTEuODQ5IDMuMDE1LTE3'
    b'LjA5IDIuMDQ4LTUuMjc4IDQuOTMtOS44NTQgOC42NDgtMTMuNzI5IDMuNjAyLTMuNzk3IDcu'
    b'ODg5LTYuNzQgMTIuODU5LTguODMgNS4wMDctMi4xMjUgMTAuMzU1LTMuMTg4IDE2LjA0NS0z'
    b'LjE5IDQuNTUyIDAgOC41MTUuNTUyIDExLjg5MSAxLjY1MiAzLjM3NSAxLjEwMiA2LjM1MyAy'
    b'LjQzMiA4LjkzMyAzLjk4OGwyLjMzMy0zLjg3NGg0LjU1MmwuNTEyIDI4LjI1NWgtNC42NjZh'
    b'NzguNjg0IDc4LjY4NCAwIDAgMC0yLjk1OC05LjE3MmMtMS4xNzctMy4wMzYtMi42OTQtNS43'
    b'NTEtNC41NTItOC4xNDZhMjAuNjc0IDIwLjY3NCAwIDAgMC02LjgyOC01LjY5N2MtMi42NTYt'
    b'MS40NDItNS44NDMtMi4xNjMtOS41NTktMi4xNjUtNC4wNTkgMC03LjY4MS44MzctMTAuODY3'
    b'IDIuNTA2LTMuMTg2IDEuNjM0LTUuOTU3IDQuMDgzLTguMzA3IDcuMzQ5LTIuMzE1IDMuMTUz'
    b'LTQuMDk3IDcuMDgzLTUuMzQ5IDExLjc5Mi0xLjI1MiA0LjcxLTEuODc4IDkuOTY5LTEuODc4'
    b'IDE1Ljc4IDAgNS4xMjcuNjA2IDkuOTY5IDEuODIxIDE0LjUyNiAxLjI1MiA0LjUyIDMuMDUz'
    b'IDguNDMxIDUuNDA1IDExLjczNSAyLjM1IDMuMzgxIDUuMjkgNi4wMzkgOC44MTkgNy45NzUg'
    b'My41MjggMS45MzggNy41MjggMi45MDYgMTIuMDA2IDIuOTA2IDMuMzM3IDAgNi4zNzEtLjUx'
    b'MyA5LjEwNC0xLjUzOCAyLjc2OC0xLjAyNiA0LjcyMS0yLjEwOCA1Ljg2LTMuMjQ3LjMwMi0x'
    b'Ljk3NC40NTMtMy45NjguNDU1LTUuOTgxLjAzNy0yLjAxMi4wNTUtMy43Mi4wNTctNS4xMjd2'
    b'LTQuNDQzYzAtMS41OTUtLjIyOC0zLS42ODMtNC4yMTYtLjQxOC0xLjI1My0xLjMwOS0yLjE2'
    b'NS0yLjY3NC0yLjczNC0xLjI1Mi0uNTctMi45NTktLjk4Ni01LjEyMS0xLjI1NC0yLjEyNS0u'
    b'MzAyLTMuNzk0LS40OTMtNS4wMDctLjU2OXYtNC4xNThoMzUuMzkxdjQuMTU4em03OS4zODkt'
    b'MzguOTY1YzMuNTY1IDMuNzIzIDYuMzUzIDguMjIzIDguMzY0IDEzLjUwMSAyLjAwOSA1LjI0'
    b'MSAzLjAxNCAxMS4wNTEgMy4wMTYgMTcuNDMyIDAgNi40MTktMS4wMjQgMTIuMjQ4LTMuMDcz'
    b'IDE3LjQ4OXMtNC44OTMgOS43MDQtOC41MzUgMTMuMzg3YTM2Ljk4OCAzNi45ODggMCAwIDEt'
    b'MTIuMjkgOC40MzFjLTQuNjY2IDEuOTc1LTkuNjM2IDIuOTYtMTQuOTA3IDIuOTYyLTUuNjE1'
    b'IDAtMTAuODEtMS4wNDQtMTUuNTktMy4xMzMtNC43NDItMi4xMjUtOC44MTktNS4wNjgtMTIu'
    b'MjMzLTguODMtMy40MTQtMy42ODMtNi4xMDgtOC4xNDUtOC4wOC0xMy4zODctMS45MzQtNS4y'
    b'NzgtMi45MDItMTAuOTE4LTIuOTAyLTE2LjkxOSAwLTYuNTY5IDEuMDI0LTEyLjQxNyAzLjA3'
    b'My0xNy41NDYgMi4wNDgtNS4xNjQgNC44NzQtOS42MjUgOC40NzgtMTMuMzg3IDMuNTY1LTMu'
    b'NzIxIDcuNjk5LTYuNTY5IDEyLjQwNC04LjU0NWEzOC4yNzEgMzguMjcxIDAgMCAxIDE0Ljg1'
    b'LTIuOTYyYzUuMzQ4IDAgMTAuMzkzIDEuMDA4IDE1LjEzNSAzLjAxOSA0Ljc0MSAyLjAxNCA4'
    b'LjgzNyA0Ljg0MiAxMi4yOSA4LjQ4OHptLTguNDc3IDU3LjMwOGMyLjEyMy0zLjQ1NiAzLjY1'
    b'OS03LjM2NyA0LjYwOS0xMS43MzUuOTg1LTQuMzY3IDEuNDc3LTkuMjQ3IDEuNDc5LTE0LjY0'
    b'MSAwLTUuNTQ0LS41NTEtMTAuNjMzLTEuNjUtMTUuMjY3LTEuMDYzLTQuNjMyLTIuNjM3LTgu'
    b'NTgzLTQuNzIzLTExLjg0OS0yLjA4Ny0zLjIyOC00LjcwNS01LjczMy03Ljg1Mi03LjUyLTMu'
    b'MTQ5LTEuODIzLTYuNzUzLTIuNzM0LTEwLjgxMS0yLjczNC00LjU1MiAwLTguNDIxIDEuMDQ1'
    b'LTExLjYwNyAzLjEzMy0zLjE4NiAyLjA5LTUuNzg2IDQuODgxLTcuNzk1IDguMzc0LTEuODk3'
    b'IDMuMzQzLTMuMzIgNy4yNTQtNC4yNjcgMTEuNzM1LS45MSA0LjQ4Mi0xLjM2NiA5LjE5MS0x'
    b'LjM2NiAxNC4xMjggMCA1LjQ2OS40OTIgMTAuNDA3IDEuNDc5IDE0LjgxMi45ODUgNC40MDYg'
    b'Mi41NDEgOC4zMTcgNC42NjYgMTEuNzM1IDIuMDQ4IDMuMzQzIDQuNjI2IDUuOTYzIDcuNzM4'
    b'IDcuODYxIDMuMTEgMS44NjIgNi44MjYgMi43OTIgMTEuMTUyIDIuNzkyIDQuMDU3IDAgNy43'
    b'MTktLjk0OSAxMC45ODEtMi44NDkgMy4yNjItMS44OTcgNS45MTYtNC41NTUgNy45NjctNy45'
    b'NzV6bTEwOS4yOTctMjUuOTc2YzAgNi44NzUtMS4yOTEgMTIuODM2LTMuODY5IDE3Ljg4Ny0y'
    b'LjU4IDUuMDUyLTUuOTM3IDkuMTkxLTEwLjA3MSAxMi40MTktNC4xNzMgMy4yMjktOC44NTgg'
    b'NS42NC0xNC4wNTQgNy4yMzQtNS4xOTcgMS41OTUtMTAuNTY1IDIuMzkzLTE2LjEwMiAyLjM5'
    b'M2gtMzMuNDU2di00LjA0NGMxLjA5OSAwIDIuNTIxLS4wOSA0LjI2Ny0uMjg1IDEuNzgxLS4y'
    b'MjggMi45NTctLjQ3NCAzLjUyOC0uNzQxIDEuMTM4LS40OTMgMS45NTItMS4yMTQgMi40NDct'
    b'Mi4xNjQuNTMtLjk4Ni43OTUtMi4xNjMuNzk2LTMuNTMydi01OC4zMzNjMC0xLjI5MS0uMjI4'
    b'LTIuNDQ4LS42ODMtMy40NzUtLjQxOC0xLjAyNS0xLjI3MS0xLjg0MS0yLjU2LTIuNDQ5YTE1'
    b'LjU0OCAxNS41NDggMCAwIDAtMy44MTItMS4yNTNjLTEuMzY1LS4yNjYtMi41NDItLjQzNy0z'
    b'LjUyOC0uNTE0di00LjA0NGgzNS4yNzdjNC44NTQgMCA5LjYzMy43NiAxNC4zMzggMi4yNzgg'
    b'NC43MDMgMS40ODEgOC43OTkgMy40OTUgMTIuMjkgNi4wMzkgNC43NCAzLjM4IDguNDU4IDcu'
    b'ODA0IDExLjE1MiAxMy4yNzMgMi42OTEgNS40NjggNC4wMzggMTEuOTA1IDQuMDQgMTkuMzEx'
    b'em0tMTMuOTQxLS4wNmMwLTUuNDMtLjcyMi0xMC4zMjktMi4xNjItMTQuNjk3LTEuNDQyLTQu'
    b'NDA0LTMuNTQ3LTguMjQtNi4zMTYtMTEuNTA3LTIuNjE3LTMuMTE0LTUuODQzLTUuNTYzLTku'
    b'NjcyLTcuMzQ5LTMuNzk0LTEuNzg0LTguMDIyLTIuNjc1LTEyLjY4OC0yLjY3Ny0xLjU1NiAw'
    b'LTMuMzE5LjA0LTUuMjkxLjExNC0xLjkzNC4wNC0zLjM3Ni4wOC00LjMyNC4xMTR2NjIuMTVj'
    b'MCAzLjQ1NyAxLjAwNSA1Ljg1IDMuMDE2IDcuMTc4IDIuMDA5IDEuMzMgNS4xMDEgMS45OTQg'
    b'OS4yNzQgMS45OTQgNC44MTcgMCA5LjAyNy0uODU0IDEyLjYzMS0yLjU2MyAzLjYwMy0xLjcw'
    b'OSA2LjUyNC00LjA4MiA4Ljc2Mi03LjEyMSAyLjM1MS0zLjE5IDQuMDU4LTYuODczIDUuMTIx'
    b'LTExLjA1MiAxLjA5OC00LjIxNiAxLjY0OC05LjA3NiAxLjY0OS0xNC41ODR6bTE2OC4xMjIt'
    b'MzYuNzk4Yy0uOTQ5LjA0LTIuMDQ4LjI2OC0zLjMuNjg0YTE1LjE5MyAxNS4xOTMgMCAwIDAt'
    b'My40NzEgMS41MzhjLTEuMzI4LjgzNi0yLjQwOSAxLjgwNS0zLjI0MyAyLjkwNS0uNzk3IDEu'
    b'MDY0LTEuNDk5IDIuNTYzLTIuMTA1IDQuNS0yLjY5NCA4Ljc3Mi01LjgyMyAxOS4wMjYtOS4z'
    b'ODggMzAuNzYyYTYwOTEuMzAzIDYwOTEuMzAzIDAgMCAxLTExLjU1MSAzNy40MjdoLTUuMjM0'
    b'bC0yMC4zNjktNjIuMjA3LTIxLjIyMyA2Mi4yMDdoLTUuMDA3YTQ1ODkzLjk1IDQ1ODkzLjk1'
    b'IDAgMCAxLTExLjY2NC00MS4zNTdjLTQuMDIyLTE0LjMxNi02LjcxNC0yMy45MDYtOC4wOC0y'
    b'OC43NjhhOS42ODQgOS42ODQgMCAwIDAtMS41MzYtMy4xMzNjLS42NDYtLjkxMS0xLjUzNi0x'
    b'Ljc0Ni0yLjY3NC0yLjUwNi0uOTQ5LS42NDUtMi4wNjgtMS4xMi0zLjM1Ny0xLjQyNC0xLjI1'
    b'Mi0uMzQyLTIuMzktLjU1LTMuNDE0LS42Mjd2LTQuMDQ0aDMyLjk0NHY0LjA0NGMtMi44ODQu'
    b'MTU0LTUuMzQ4LjQzOC03LjM5Ni44NTUtMi4wMTEuNDE4LTMuMDE2IDEuMTIyLTMuMDE2IDIu'
    b'MTA4IDAgLjM4MS4wNTcuODk0LjE3MSAxLjUzOC4xMTQuNjA5LjIwOCAxLjEwMi4yODQgMS40'
    b'ODEuODcxIDMuMzQzIDIuNDA4IDguODY5IDQuNjA5IDE2LjU3NyAyLjIzNyA3LjY3MiA1LjUz'
    b'NyAxOS4xOCA5LjkgMzQuNTIybDIwLjE0MS01OS45ODZoNS41NzZsMjAuMzEyIDYxLjI5NmEz'
    b'MDk1LjA3IDMwOTUuMDcgMCAwIDAgNy4wNTYtMjQuNjY3YzEuOTcyLTcuMDYzIDMuNjAyLTEz'
    b'LjEwMyA0Ljg5My0xOC4xMTUuOTEtMy41MzIgMS40NzktNS45NDIgMS43MDctNy4yMzUuMjI4'
    b'LTEuMzI4LjM0Mi0yLjQ0OC4zNDItMy4zNjEgMC0xLjI5MS0uODkzLTIuMzczLTIuNjc0LTMu'
    b'MjQ3LTEuNzQ2LS44NzMtNC41OTEtMS40NjEtOC41MzUtMS43Njd2LTQuMDQ0aDI5LjMwMnpt'
    b'NzguMzk2IDUyLjk3OS0xLjUzNiAyMy44MTJoLTY3LjAyNXYtNC4wNDRhOTMuMjkgOTMuMjkg'
    b'MCAwIDAgNC41NTItLjQ1NmMxLjg5Ni0uMjY2IDMuMTI3LS41MzEgMy42OTgtLjc5OCAxLjIx'
    b'My0uNTY5IDIuMDQ3LTEuMzExIDIuNTA0LTIuMjIyLjQ5Mi0uOTExLjczOC0yLjA2OC43NC0z'
    b'LjQ3NXYtNTguMTA2YzAtMS4yNTMtLjIxLTIuMzU0LS42MjYtMy4zMDQtLjQxOC0uOTg2LTEu'
    b'MjkxLTEuNzgzLTIuNjE3LTIuMzkzLTEuMDI0LS40OTMtMi40MDktLjkyOS00LjE1My0xLjMx'
    b'LTEuNzA3LS4zNzktMy4wNzItLjYwNy00LjA5Ny0uNjg0di00LjA0NGg2Mi40NzR2MTkuNDgy'
    b'aC00LjI2N2MtLjc2LTIuODg2LTIuNDA5LTUuOTQyLTQuOTUtOS4xNzItMi41MDQtMy4yNjUt'
    b'NC44OTMtNS4wNS03LjE2OS01LjM1NGE1My4wNDUgNTMuMDQ1IDAgMCAwLTQuMjExLS4zNDJj'
    b'LTEuNjMyLS4wOC0zLjQ5LS4xMTItNS41NzYtLjExNGgtMTIuNjg4djMyLjEyOWg5LjEwNGMy'
    b'LjkxOSAwIDUuMDQ0LS4yNjUgNi4zNzMtLjc5NyAxLjM2NS0uNTcgMi41NjEtMS41IDMuNTg0'
    b'LTIuNzkyLjgzNC0xLjEgMS41MzQtMi41NjIgMi4xMDUtNC4zODYuNjA2LTEuODYgMS4wMDUt'
    b'My42MDcgMS4xOTUtNS4yNDFoNC4yNjh2MzEuNjE2aC00LjI2OGMtLjE1My0xLjgyMy0uNTY5'
    b'LTMuNzQtMS4yNTEtNS43NTQtLjY0Ni0yLjA1LTEuMzI4LTMuNTMxLTIuMDQ4LTQuNDQzLTEu'
    b'MTc3LTEuNDgxLTIuNTIzLTIuNDQ5LTQuMDQtMi45MDUtMS40OC0uNDU2LTMuNDUzLS42ODQt'
    b'NS45MTctLjY4NGgtOS4xMDR2MjQuMjY4YzAgMi40MzIuMTcxIDQuMzUuNTEyIDUuNzU0LjM0'
    b'MiAxLjQwNiAxLjAwNSAyLjQ2OSAxLjk5MSAzLjE5Ljk4NS43MjMgMi4zMzEgMS4xOTYgNC4w'
    b'NCAxLjQyNCAxLjcwNy4xOSA0LjEzNC4yODUgNy4yODMuMjg1aDQuOTVjMi4wNDggMCAzLjc3'
    b'My0uMDcgNS4xNzctLjIyOGEzMS45MzkgMzEuOTM5IDAgMCAwIDQuNDM4LS43OThjMS41NTQt'
    b'LjQxNyAyLjY1NS0uOTY2IDMuMy0xLjY1MiAxLjc0NC0xLjgyMyAzLjU2NS00LjU3NSA1LjQ2'
    b'Mi04LjI2IDEuOTM1LTMuNzIxIDMuMTY3LTYuNDU1IDMuNjk4LTguMjAzaDQuMDk1em0xMTgu'
    b'NzUzLTM1LjA5MWgtMy45MjZjLS4zNDEtMS4zNjctLjk2Ny0yLjk4LTEuODc3LTQuODQyYTQw'
    b'LjYxNiA0MC42MTYgMCAwIDAtMi45NTktNS4zNTVjLTEuMTM4LTEuNzQ3LTIuMzg5LTMuMjY1'
    b'LTMuNzU1LTQuNTU3LTEuMzI5LTEuMzI4LTIuNjE4LTIuMDg4LTMuODY5LTIuMjc5LTEuMTc3'
    b'LS4xNTEtMi42NTctLjI2NS00LjQzOC0uMzQxLTEuNzgzLS4wOC0zLjQzNC0uMTEyLTQuOTUt'
    b'LjExNGgtMy4zdjY0LjY1NmMwIDEuMjU0LjI2NSAyLjQxMy43OTcgMy40NzYuNTMgMS4wMjUg'
    b'MS40NiAxLjgyMiAyLjc4OCAyLjM5My42ODMuMjY3IDIuMTA1LjYyNiA0LjI2OCAxLjA4MiAy'
    b'LjE5OS40NTYgMy45MDYuNzAzIDUuMTIxLjc0MXY0LjA0NGgtMzguMTIydi00LjA0NGMxLjA2'
    b'Mi0uMDggMi42NzMtLjIyNiA0LjgzNi0uNDU2IDIuMi0uMjI4IDMuNzE3LS41MTMgNC41NTIt'
    b'Ljg1NCAxLjI1Mi0uNDkzIDIuMTYyLTEuMTk1IDIuNzMxLTIuMTA4LjYwNi0uOTQ4LjkwOS0y'
    b'LjIwMi45MS0zLjc2di02NS4xNjloLTMuM2MtMS4xNzcgMC0yLjYzNy4wNC00LjM4MS4xMTRh'
    b'NTIuNzkgNTIuNzkgMCAwIDAtNS4wMDcuMzQxYy0xLjI1Mi4xNTMtMi41NjEuOTEyLTMuOTI2'
    b'IDIuMjc5LTEuMzI4IDEuMzMtMi41NiAyLjg0OC0zLjY5OCA0LjU1N3MtMi4xNDQgMy41MzIt'
    b'My4wMTUgNS40NjljLS44NzMgMS44OTktMS40NzkgMy40NzUtMS44MjEgNC43MjhoLTMuOTgz'
    b'di0yMS45MzJoNzAuMzI1djIxLjkzMXptOTEuNzY3IDU4LjkwM2gtMjEuNzM1Yy00LjgxOC03'
    b'LjU1Ny05LjE4LTE0LjA4OC0xMy4wODYtMTkuNTk2YTQzNi45MjEgNDM2LjkyMSAwIDAgMC0x'
    b'Mi42MzEtMTcuMDMzaC04LjI1djI1LjYzNWMwIDEuMzI5LjIwOCAyLjUwNi42MjYgMy41MzEu'
    b'NDE2Ljk4OCAxLjMwNyAxLjc0OSAyLjY3NCAyLjI3OS42ODMuMjY3IDEuODc4LjUxMyAzLjU4'
    b'NS43NCAxLjcwNy4yMjggMy4xNDcuMzYxIDQuMzI0LjM5OXY0LjA0NGgtMzQuMTM5di00LjA0'
    b'NGMuOTEtLjA4IDIuMjE5LS4yMDggMy45MjYtLjM5OSAxLjc0NC0uMTg4IDIuOTU3LS40MzYg'
    b'My42NDItLjc0IDEuMTM4LS40OTMgMS45NTItMS4yMTQgMi40NDYtMi4xNjUuNTMtLjk0OS43'
    b'OTUtMi4xNjMuNzk3LTMuNjQ2di01OC40NDhjMC0xLjMyOC0uMTktMi41MDUtLjU2OS0zLjUz'
    b'Mi0uMzgxLTEuMDI1LTEuMjcxLTEuODA0LTIuNjc0LTIuMzM2LS45NS0uMzQyLTIuMTgyLS42'
    b'NDUtMy42OTgtLjkxMS0xLjUxOS0uMzAzLTIuODA4LS40OTMtMy44NjktLjU3di00LjA0NGgz'
    b'Ny4yNjhjMy40MTQgMCA2LjYxOC4zNjEgOS42MTYgMS4wODIgMi45OTYuNjg0IDUuNzA3IDEu'
    b'ODA2IDguMTM2IDMuMzYxIDIuMzUxIDEuNTIxIDQuMjI4IDMuNTE0IDUuNjMzIDUuOTgxIDEu'
    b'NDAzIDIuNDMyIDIuMTA0IDUuMzc0IDIuMTA1IDguODMgMCAzLjExNi0uNDc1IDUuODY4LTEu'
    b'NDIyIDguMjZhMTcuMDI2IDE3LjAyNiAwIDAgMS00LjIxIDYuMjA5Yy0xLjcwNyAxLjYzNS0z'
    b'Ljc1NSAzLjA1OS02LjE0NSA0LjI3Mi0yLjM4OSAxLjE3OS01LjAyNiAyLjE4NS03LjkwOCAz'
    b'LjAyIDMuOTgyIDUuMjggNy4yODIgOS43MjQgOS45IDEzLjMzIDIuNjU1IDMuNjA4IDUuODk3'
    b'IDcuOTk1IDkuNzI5IDEzLjE1OSAxLjY2OCAyLjI3OCAzLjE2NyAzLjk3IDQuNDk1IDUuMDcg'
    b'MS4zNjYgMS4wNjQgMi43MTIgMS45MzcgNC4wNCAyLjYyLjk4NS40OTUgMi4yMTcuODc0IDMu'
    b'Njk4IDEuMTQgMS40NzkuMjY3IDIuNzExLjQxOCAzLjY5OC40NTZ2NC4wNDZ6bS0yOS45Mjgt'
    b'NjAuMjcxYzAtNC44OTktMS40MDQtOC43NzItNC4yMS0xMS42MjEtMi44MDgtMi44ODYtNi43'
    b'NzEtNC4zMjctMTEuODkyLTQuMzI5aC05LjY3MnYzNC42OTJoNy40NTRjNS4yMzUgMCA5LjU5'
    b'Ni0xLjY3IDEzLjA4Ni01LjAxMyAzLjQ4Ny0zLjM3OCA1LjIzMi03Ljk1NSA1LjIzNC0xMy43'
    b'Mjl6bTExNC4zNjQtMTYuNTJjLTEuMDYzLjA0LTIuNjE3LjI2OC00LjY2Ni42ODQtMi4wNDgu'
    b'NDE4LTMuNzE4IDEuMDQ1LTUuMDA3IDEuODgtMS4yOTEuODc1LTIuMTgyIDIuNjc3LTIuNjc0'
    b'IDUuNDEyLS40OTQgMi43MzQtLjc0IDYuMDc4LS43NCAxMC4wMjZ2MzUuMTQ4YzAgNC40ODIt'
    b'LjkzIDguMzc0LTIuNzg4IDExLjY3OC0xLjg2IDMuMzA0LTQuMzA2IDYuMDIxLTcuMzQgOC4x'
    b'NDYtMi45OTggMi4wNS02LjE2NCAzLjUxNC05LjUwMiA0LjM4Ni0zLjMuOTExLTYuNDY5IDEu'
    b'MzY3LTkuNTAyIDEuMzY3LTQuODU2IDAtOS4xOC0uNjQ2LTEyLjk3My0xLjkzNy0zLjc5NC0x'
    b'LjI1My02Ljk4MS0yLjk2Mi05LjU1OS01LjEyNy0yLjU0Mi0yLjE2NS00LjQ1OC00LjYzMi01'
    b'Ljc0Ny03LjQwNi0xLjI5MS0yLjgwOS0xLjkzNS01LjczNC0xLjkzNS04Ljc3M3YtNDcuNzk0'
    b'YzAtMS4zMjgtLjIyNy0yLjQzLS42ODMtMy4zMDQtLjQxOC0uOTExLTEuMjkxLTEuNzQ2LTIu'
    b'NjE3LTIuNTA2LS45NDktLjUzMS0yLjE2Mi0uOTQ5LTMuNjQyLTEuMjUzLTEuNDc5LS4zNDIt'
    b'Mi42OTQtLjU1LTMuNjQyLS42Mjd2LTQuMDQ0aDMzLjYyN3Y0LjA0NGMtMS4wNjMuMDQtMi40'
    b'MDkuMjExLTQuMDQuNTE0LTEuNTkzLjMwNC0yLjc3LjU4OS0zLjUyOC44NTQtMS4yOTEuNDU2'
    b'LTIuMTYyIDEuMjE2LTIuNjE3IDIuMjc5LS40MTggMS4wNjQtLjYyNiAyLjIyMi0uNjI2IDMu'
    b'NDc1djQ0LjY2MmMwIDIuMTY1LjIyOCA0LjQ0My42ODMgNi44MzYuNDkzIDIuMzU1IDEuNDQg'
    b'NC41NTcgMi44NDUgNi42MDcgMS40NzkgMi4wOSAzLjQ4OSAzLjc5OSA2LjAzMSA1LjEyNyAy'
    b'LjU0MSAxLjMzIDYuMDI5IDEuOTk0IDEwLjQ2OSAxLjk5NCA0LjE3MSAwIDcuNjYyLS42NjQg'
    b'MTAuNDY5LTEuOTk0IDIuODQ1LTEuMzI4IDUuMDgyLTMuMDc0IDYuNzE0LTUuMjQgMS41NTQt'
    b'Mi4wNTEgMi42NTUtNC4xOTYgMy4zLTYuNDM4LjY0NC0yLjIzOS45NjYtNC40OTkuOTY3LTYu'
    b'Nzc5di0zMy4xNTVjMC00LjIxNS0uMzA0LTcuNjUxLS45MS0xMC4zMTEtLjYwOC0yLjY5NS0x'
    b'LjQ5OS00LjQ2MS0yLjY3NC01LjI5OC0xLjMyOC0uOTQ5LTMuMTQ5LTEuNjg5LTUuNDYyLTIu'
    b'MjIyLTIuMjc2LS41MzEtNC4wMjItLjgzNS01LjIzNS0uOTEydi00LjA0NGgzMy4wMDF2NC4w'
    b'NDV6bTU5Ljg3OSAzOS43MDZjMS43MDcgMS44OTkgMi45NTkgMy45ODggMy43NTUgNi4yNjcu'
    b'ODM0IDIuMjQxIDEuMjUgNC44NjEgMS4yNTIgNy44NjEgMCA3LjE0LTIuNjM3IDEzLjAyNy03'
    b'LjkwOSAxNy42NTktNS4yNzMgNC42MzQtMTEuODE3IDYuOTQ4LTE5LjYyOSA2Ljk1LTMuNjA0'
    b'IDAtNy4yMDgtLjU1Mi0xMC44MTEtMS42NTItMy42MDQtMS4xNC02LjcxNC0yLjUwNy05LjMz'
    b'MS00LjEwMmwtMi40NDcgNC4xNTloLTQuNTUybC0uNzk3LTI3LjY4Nmg0LjYwOWMuOTQ4IDMu'
    b'NDE4IDIuMDQ2IDYuNTE0IDMuMyA5LjI4NiAxLjI4OSAyLjczNCAyLjk3NiA1LjI5OCA1LjA2'
    b'NCA3LjY5YTIyLjg3OSAyMi44NzkgMCAwIDAgNi44ODUgNS4zNTRjMi42NTUgMS4zMyA1Ljcy'
    b'NyAxLjk5NCA5LjIxOCAxLjk5NCAyLjYxNyAwIDQuODkzLS4zNDIgNi44MjctMS4wMjUgMS45'
    b'NzItLjY4NCAzLjU2NS0xLjY1MiA0Ljc4LTIuOTA1YTExLjYyNiAxMS42MjYgMCAwIDAgMi42'
    b'NzQtNC4zODdjLjYwNi0xLjcwOS45MDgtMy42NjQuOTEtNS44NjggMC0zLjIyNy0uOTEtNi4y'
    b'MjctMi43MzEtOS0xLjgyMS0yLjgwOS00LjUzNC00LjkzNy04LjEzNi02LjM4YTM0OS45NTYg'
    b'MzQ5Ljk1NiAwIDAgMC04LjQ3OC0zLjI0N2MtMy4xODYtMS4yMTUtNS45MzctMi4zNTQtOC4y'
    b'NS0zLjQxOC00LjU1Mi0yLjA1LTguMDk5LTQuNzI4LTEwLjY0LTguMDMyLTIuNTAzLTMuMzQx'
    b'LTMuNzU1LTcuNjg5LTMuNzU1LTEzLjA0NSAwLTMuMDc2LjYyNi01Ljk0MiAxLjg3OC04LjYw'
    b'MiAxLjI1Mi0yLjY1OCAzLjAzMy01LjAzMSA1LjM0OC03LjEyMSAyLjE5OS0xLjk3NCA0Ljc5'
    b'Ny0zLjUxMiA3Ljc5NS00LjYxNGEyNi4xOTYgMjYuMTk2IDAgMCAxIDkuMzg4LTEuNzA5YzMu'
    b'NzE2IDAgNy4wMzYuNTcgOS45NTcgMS43MDkgMi45NTkgMS4xNCA1LjY1MSAyLjQ2OSA4LjA3'
    b'OSAzLjk4OGwyLjMzMy0zLjg3NGg0LjU1MmwuNDU1IDI2LjgzMWgtNC42MDlhOTYuODI4IDk2'
    b'LjgyOCAwIDAgMC0yLjg0NS04LjgzYy0xLjAyNC0yLjgwOS0yLjM3Mi01LjM1My00LjA0LTcu'
    b'NjMzLTEuNjMyLTIuMjAyLTMuNjI0LTMuOTQ5LTUuOTc0LTUuMjQxLTIuMzUzLTEuMzI4LTUu'
    b'MjM1LTEuOTkyLTguNjQ4LTEuOTk0LTMuNjA0IDAtNi42NzcgMS4xNTktOS4yMTggMy40NzUt'
    b'Mi41NDIgMi4zMTgtMy44MTIgNS4xNDYtMy44MTIgOC40ODggMCAzLjQ5NS44MTQgNi40IDIu'
    b'NDQ3IDguNzE2IDEuNjMxIDIuMjc5IDQuMDAxIDQuMTU5IDcuMTEyIDUuNjRhOTUuODIgOTUu'
    b'ODIgMCAwIDAgOC4xMzcgMy40NzVjMi42OTIuOTUxIDUuMjkgMS45NzYgNy43OTUgMy4wNzdh'
    b'NTUuODk3IDU1Ljg5NyAwIDAgMSA2LjU0MyAzLjM2YzIuMTIzIDEuMjUzIDMuOTY0IDIuNzE2'
    b'IDUuNTE5IDQuMzg2em04Ny4zODYtMjEuODE4aC0zLjkyNmMtLjM0MS0xLjM2Ny0uOTY3LTIu'
    b'OTgtMS44NzctNC44NDJhNDAuNjE2IDQwLjYxNiAwIDAgMC0yLjk1OS01LjM1NWMtMS4xMzgt'
    b'MS43NDctMi4zOS0zLjI2NS0zLjc1NS00LjU1Ny0xLjMyOC0xLjMyOC0yLjYxNy0yLjA4OC0z'
    b'Ljg2OS0yLjI3OS0xLjE3Ny0uMTUxLTIuNjU2LS4yNjUtNC40MzgtLjM0MS0xLjc4My0uMDgt'
    b'My40MzMtLjExMi00Ljk1LS4xMTRoLTMuM3Y2NC42NTZjMCAxLjI1NC4yNjUgMi40MTMuNzk2'
    b'IDMuNDc2LjUzIDEuMDI1IDEuNDYgMS44MjIgMi43ODggMi4zOTMuNjgzLjI2NyAyLjEwNS42'
    b'MjYgNC4yNjcgMS4wODIgMi4xOTkuNDU2IDMuOTA2LjcwMyA1LjEyMS43NDF2NC4wNDRoLTM4'
    b'LjEyMnYtNC4wNDRjMS4wNjItLjA4IDIuNjcyLS4yMjYgNC44MzYtLjQ1NiAyLjE5OS0uMjI4'
    b'IDMuNzE2LS41MTMgNC41NTItLjg1NCAxLjI1MS0uNDkzIDIuMTYyLTEuMTk1IDIuNzMxLTIu'
    b'MTA4LjYwNi0uOTQ4LjkwOS0yLjIwMi45MTEtMy43NnYtNjUuMTY5aC0zLjNjLTEuMTc3IDAt'
    b'Mi42MzcuMDQtNC4zODEuMTE0YTUyLjc5IDUyLjc5IDAgMCAwLTUuMDA3LjM0MWMtMS4yNTEu'
    b'MTUzLTIuNTYuOTEyLTMuOTI2IDIuMjc5LTEuMzI4IDEuMzMtMi41NiAyLjg0OC0zLjY5OCA0'
    b'LjU1N3MtMi4xNDUgMy41MzItMy4wMTYgNS40NjljLS44NzMgMS44OTktMS40NzkgMy40NzUt'
    b'MS44MjEgNC43MjhoLTMuOTgzdi0yMS45MzJoNzAuMzI2eiIgZmlsbD0iI2VlZDAwMCIgZmls'
    b'bC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiNlZWQwMDAiIHN0cm9rZS1taXRlcmxpbWl0PSIz'
    b'Ljg2NCIgc3Ryb2tlLXdpZHRoPSIxLjYzMyIvPgogIDxwYXRoIGQ9Ik0xNDQyLjg4NiAxMDY2'
    b'LjE4OWMuMTY0LS4wNy4yNTctLjA5LjI2My0uMDkuMDY0LS4wMiAxMC4wNDEgMy41NjkgMTAu'
    b'MTI2IDE5LjE5NyA4LjgyOS0xLjY1NCAxMi4zOTMgMy4wMDkgMTAuNjkxIDEzLjk4NyAwIDAt'
    b'MTAuNDgyLTIuODM0LTEyLjE5MyAzLjE0My0yLjU3IDYuOTEtLjYxIDEyLjUzOSA1Ljg3OSAx'
    b'Ni44ODggMCAwIDEwLjkgOC42MzggMTcuNzU5LTcuNzM1czkuMzI4LTIxLjk0MiA5LjMyOC0y'
    b'MS45NDJjMS45MDgtNi4wMzIgMTMuMjY1LTIwLjE2OCAyMy41NzgtMjIuMTQ5IDMuOTI5LTEu'
    b'NTc1IDcuNjktMS4yNjQgMTEuODg2LS4yNjEgMCAwIDkuMDI0IDEuOTUzIDkuMjggOS40OTQu'
    b'MjU3IDcuNTQtMi44MjIgMTAuODIyLTcuOTExIDEzLjAxLTUuNjI2IDIuNDE5LTEyLjU3My0y'
    b'Ljc3My0xMi41NzMtMi43NzMtMi40MjItLjQ1My0zLjE5NS4zODUtNC42ODMgMS40MTctLjY4'
    b'NS40NzUtMy41NDEgMy42MS01LjE5NiA3LjEzOSAwIDAtNS4wMDkgMTAuNTg4LTcuMzk4IDE4'
    b'LjY3NS0xLjg4MiA2LjM2OC02LjAzIDI1LjYyOS0yNS41MzEgMjguNTJoLTQ2LjAyMmMtMTku'
    b'NTAxLTIuODkxLTIzLjY0OS0yMi4xNTItMjUuNTMxLTI4LjUyLTIuMzktOC4wODctNy4zOTgt'
    b'MTguNjc1LTcuMzk4LTE4LjY3NS0xLjY1NS0zLjUyOS00LjUxMS02LjY2NC01LjE5Ni03LjEz'
    b'OS0xLjQ4Ny0xLjAzMS0yLjI2MS0xLjg2OS00LjY4My0xLjQxNyAwIDAtNi45NDggNS4xOTIt'
    b'MTIuNTc0IDIuNzczLTUuMDg5LTIuMTg4LTguMTY4LTUuNDY5LTcuOTExLTEzLjAxczkuMjgx'
    b'LTkuNDk0IDkuMjgxLTkuNDk0YzQuMTk2LTEuMDAyIDcuOTU3LTEuMzE0IDExLjg4Ni4yNjEg'
    b'MTAuMzEzIDEuOTgxIDIxLjY3IDE2LjExNyAyMy41NzcgMjIuMTQ5IDAgMCAyLjQ2OSA1LjU2'
    b'OSA5LjMyOCAyMS45NDIgNi44NTggMTYuMzczIDE3Ljc1OSA3LjczNSAxNy43NTkgNy43MzUg'
    b'Ni40ODktNC4zNDkgOC40NDgtOS45NzkgNS44NzktMTYuODg4LTEuNzEtNS45NzgtMTIuMTkz'
    b'LTMuMTQzLTEyLjE5My0zLjE0My0xLjcwMS0xMC45NzggMS44NjItMTUuNjQgMTAuNjkxLTEz'
    b'Ljk4Ny4wODUtMTUuNjI4IDEwLjA2Mi0xOS4yMjIgMTAuMTI3LTE5LjE5Ny4wMSAwIC4wOTku'
    b'MDMuMjYzLjA5eiIgZmlsbD0iI2VlZDAwMCIvPgogIDxwYXRoIGQ9Ik0xNTAwLjE1NiAxNTkx'
    b'Ljk2aC0xMTEuNDA3bDEzLjE0OC00MzQuNjc3aDg1LjYyOXptLS40NzcgMjQxLjcxNmgtMTE4'
    b'LjMwNGwtLjAwNS0xOTcuMzkyIDExOC4zMDktLjAzN3oiIGZpbGw9IiNlZWQwMDAiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1pdD0iMy44'
    b'NjQiIHN0cm9rZS13aWR0aD0iOC40ODkiLz4KICA8cGF0aCBkPSJNMTM3OS40MzggMTYxMy43'
    b'NzRoMTE5LjkyNmM4LjM1NCAwIDE1LjEyNSA1LjA5MSAxNS4xMjUgMTEuMzcycy02Ljc3MiAx'
    b'MS4zNzItMTUuMTI1IDExLjM3MmgtMTE5LjkyNmMtOC4zNTQgMC0xNS4xMjUtNS4wOTEtMTUu'
    b'MTI1LTExLjM3MnM2Ljc3MS0xMS4zNzIgMTUuMTI1LTExLjM3MnoiIGZpbGw9IiNlZWQwMDAi'
    b'IHN0cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lk'
    b'dGg9IjguNDg5Ii8+CiAgPHBhdGggZD0iTTEzODguMzMgMTU5Mi40MzhoMTA0LjY4OGM3LjQz'
    b'OCAwIDEzLjQ2OCA0Ljc3NiAxMy40NjggMTAuNjY4IDAgNS44OTItNi4wMyAxMC42NjgtMTMu'
    b'NDY4IDEwLjY2OEgxMzg4LjMzYy03LjQzOCAwLTEzLjQ2OC00Ljc3Ni0xMy40NjgtMTAuNjY4'
    b'IDAtNS44OTIgNi4wMy0xMC42NjggMTMuNDY4LTEwLjY2OHoiIGZpbGw9IiNlZWQwMDAiIGZp'
    b'bGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1pdD0i'
    b'My44NjQiIHN0cm9rZS13aWR0aD0iOC40ODkiLz4KICA8cGF0aCBkPSJNMTQwOC4wNzMgMTY3'
    b'My4yNThoNjMuMjA0djEzMC4xMzhoLTYzLjIwNHoiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9IjguNDg5Ii8+'
    b'CiAgPHBhdGggZD0iTTE0MDYuNzU2IDExNDIuMTIxaDcyLjYwNGM1Ljk2NyAwIDEwLjgwNCAz'
    b'LjUxNSAxMC44MDQgNy44NTIgMCA0LjMzNi00LjgzNyA3Ljg1MS0xMC44MDQgNy44NTFoLTcy'
    b'LjYwNGMtNS45NjcgMC0xMC44MDQtMy41MTUtMTAuODA0LTcuODUxLjAwMS00LjMzNiA0Ljgz'
    b'OC03Ljg1MiAxMC44MDQtNy44NTJ6IiBmaWxsPSIjZWVkMDAwIiBzdHJva2U9IiMwMDJkNTYi'
    b'IHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI0LjkiLz4KICA8cGF0'
    b'aCBkPSJNODQ3LjcxNiAxODU3LjI5NmgxMjA1LjczOXY0MC42NTdIODQ3LjcxNnoiIGZpbGw9'
    b'IiNlZWQwMDAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9rZS13aWR0aD0iMTAiLz4KICA8cGF0aCBkPSJNNzk2'
    b'LjI3NSAxODk3LjYwOEgyMTA1LjczdjQzLjA1SDc5Ni4yNzV6IiBmaWxsPSIjZWVkMDAwIiBz'
    b'dHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRo'
    b'PSI2Ii8+CiAgPHBhdGggZD0iTTg4My4zNjkgOTc0LjQ2aDExMjUuNzg3djI0LjkwOUg4ODMu'
    b'MzY5eiIgZmlsbD0iI2VlZDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDJk'
    b'NTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI5LjU1Ii8+CiAg'
    b'PHBhdGggZD0iTTE3OTcuMTAxIDk3My42OThjLTU4LjMyNy0xMzkuNzMxLTE5My42OTYtMjM3'
    b'LjM2NC0zNTEuMzgtMjM3LjM2NC0xNTcuNTg5IDAtMjkyLjg4NiA5Ny43NjktMzUxLjI3MiAy'
    b'MzcuMzY0SDk1NC41MTNjNjQuNzI0LTIxNC43NzEgMjYwLjM4MS0zNzIuMjIyIDQ5MS4yMDkt'
    b'MzcyLjIyMiAyMzAuOTg1IDAgNDI2Ljc1NiAxNTcuMTU3IDQ5MS40MTQgMzcyLjE1M3oiIHN0'
    b'eWxlPSJmaWxsOiNlZWQwMDA7ZmlsbC1ydWxlOmV2ZW5vZGQ7c3Ryb2tlOiMwMDJkNTY7c3Ry'
    b'b2tlLXdpZHRoOjQuODk5ODk5OTY7c3Ryb2tlLWxpbmVqb2luOnJvdW5kO3N0cm9rZS1taXRl'
    b'cmxpbWl0OjMuODYzNjk5OTEiLz4KICA8cGF0aCBkPSJNOTEzLjYyMSA5OTkuNjgyczE5LjQ1'
    b'OSAxMS42NCAzNS42NjUgNDYuMjk3bDEwMDEuNTI3LS4wNHMxNi40NzEtMzguNzUxIDM5LjE1'
    b'OS00Ni4zMzJ6IiBmaWxsPSIjZWVkMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0i'
    b'IzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9IjYiLz4K'
    b'ICA8cGF0aCBkPSJNMTE2Mi4wOTMgMTA1NC45ODFzOTIuNzggMTU5LjIzMiAyODEuNDQ2IDE1'
    b'Ny4wMzljMTg2LjM3LTIuMTY2IDI4MS40NDctMTUxLjYyNCAyODEuNDQ3LTE1MS42MjRsNDku'
    b'Njk5IDczLjY0NnMxOC4zNjcgMjQuOTA5LTE3LjI4NiA1Ni4zMTdjLTEyNS45NTcgMTEwLjk1'
    b'Ny0yMjUuNzMxIDEzMi43NjQtMzEzLjg1OSAxMzIuMTI5LTEzMC4xNTUtNy4xMjMtMjM1LjEz'
    b'Ny01MS4xNjgtMzE0LjkzOS0xMzIuMTI5LTE0LjM1NC0xMS45MzUtMTcuMjg3LTI3LjYxNy0x'
    b'Mi45NjUtNDAuNjE0eiIgc3R5bGU9ImZpbGw6I2VlZDAwMDtmaWxsLXJ1bGU6ZXZlbm9kZDtz'
    b'dHJva2U6IzAwMmQ1NjtzdHJva2Utd2lkdGg6NC44OTk4OTk5NjtzdHJva2UtbGluZWpvaW46'
    b'cm91bmQ7c3Ryb2tlLW1pdGVybGltaXQ6My44NjM2OTk5MSIvPgogIDxwYXRoIGQ9Ik0xMTEz'
    b'Ljc0NSAxMTY2LjI2MnMtNS42NzItMzIuMjE5IDQ1LjEwNy02LjIyNmwzLjc4MS0xMDQuNTE0'
    b'bTYxNS41NjMgODguODA5Yy0xNi4yMDYtMzQuOTI3LTQ1LjkxOCA3Ljg1MS00NS45MTggNy44'
    b'NTFsLTcuNDgxLTkxLjI0NCIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9rZS13aWR0aD0iNi4zNjciLz4KICA8cGF0aCBkPSJN'
    b'OTQzLjg2OSAxMDQ3Ljg1NmgxMDA2Ljk0NGMzLjU4IDAgNi40ODIgMy4wMjcgNi40ODIgNi43'
    b'NjF2Mi4yNTJjMCAzLjczNC0yLjkwMiA2Ljc2MS02LjQ4MiA2Ljc2MUg5NDMuODY5Yy0zLjU4'
    b'IDAtNi40ODItMy4wMjctNi40ODItNi43NjF2LTIuMjUyYy0uMDAxLTMuNzM0IDIuOTAyLTYu'
    b'NzYxIDYuNDgyLTYuNzYxeiIgZmlsbD0iI2VlZDAwMCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJv'
    b'a2UtbWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9rZS13aWR0aD0iNSIvPgogIDxwYXRoIGQ9Ik0x'
    b'MDMyLjg3NCAxMDY0LjkzOWMuMTY0LS4wNy4yNTctLjA5LjI2My0uMDkuMDY1LS4wMiAxMC4w'
    b'NDEgMy41NjkgMTAuMTI2IDE5LjE5NyA4LjgyOS0xLjY1NCAxMi4zOTMgMy4wMDkgMTAuNjky'
    b'IDEzLjk4NyAwIDAtMTAuNDgyLTIuODM0LTEyLjE5MyAzLjE0My0yLjU3IDYuOTEtLjYxIDEy'
    b'LjUzOSA1Ljg3OSAxNi44ODggMCAwIDEwLjkgOC42MzggMTcuNzU5LTcuNzM1czkuMzI4LTIx'
    b'Ljk0MiA5LjMyOC0yMS45NDJjMS45MDctNi4wMzIgMTMuMjY0LTIwLjE2OCAyMy41NzgtMjIu'
    b'MTQ5IDMuOTI5LTEuNTc1IDcuNjktMS4yNjQgMTEuODg2LS4yNjEgMCAwIDkuMDI0IDEuOTUz'
    b'IDkuMjggOS40OTRzLTIuODIzIDEwLjgyMi03LjkxMSAxMy4wMWMtNS42MjYgMi40MTktMTIu'
    b'NTczLTIuNzczLTEyLjU3My0yLjc3My0yLjQyMi0uNDUzLTMuMTk2LjM4NS00LjY4MyAxLjQx'
    b'Ny0uNjg1LjQ3NS0zLjU0MSAzLjYxLTUuMTk2IDcuMTM5IDAgMC01LjAwOSAxMC41ODgtNy4z'
    b'OTggMTguNjc1LTEuODgyIDYuMzY4LTYuMDMgMjUuNjI5LTI1LjUzMSAyOC41MmgtNDYuMDIy'
    b'Yy0xOS41MDEtMi44OTEtMjMuNjQ5LTIyLjE1Mi0yNS41MzEtMjguNTItMi4zODktOC4wODct'
    b'Ny4zOTgtMTguNjc1LTcuMzk4LTE4LjY3NS0xLjY1NS0zLjUyOS00LjUxMS02LjY2NC01LjE5'
    b'Ni03LjEzOS0xLjQ4Ny0xLjAzMS0yLjI2MS0xLjg2OS00LjY4My0xLjQxNyAwIDAtNi45NDgg'
    b'NS4xOTItMTIuNTczIDIuNzczLTUuMDg5LTIuMTg4LTguMTY4LTUuNDY5LTcuOTEyLTEzLjAx'
    b'LjI1Ny03LjU0IDkuMjgxLTkuNDk0IDkuMjgxLTkuNDk0IDQuMTk2LTEuMDAyIDcuOTU3LTEu'
    b'MzE0IDExLjg4Ni4yNjEgMTAuMzEzIDEuOTgxIDIxLjY3IDE2LjExNyAyMy41NzcgMjIuMTQ5'
    b'IDAgMCAyLjQ2OSA1LjU2OSA5LjMyOCAyMS45NDJzMTcuNzU5IDcuNzM1IDE3Ljc1OSA3Ljcz'
    b'NWM2LjQ4OS00LjM0OSA4LjQ0OC05Ljk3OSA1Ljg3OS0xNi44ODgtMS43MTEtNS45NzgtMTIu'
    b'MTkzLTMuMTQzLTEyLjE5My0zLjE0My0xLjcwMS0xMC45NzggMS44NjMtMTUuNjQgMTAuNjkx'
    b'LTEzLjk4Ny4wODYtMTUuNjI4IDEwLjA2Mi0xOS4yMjIgMTAuMTI3LTE5LjE5Ny4wMSAwIC4w'
    b'OTkuMDMuMjYzLjA5eiIgZmlsbD0iI2VlZDAwMCIvPgogIDxwYXRoIGQ9Ik0xMDg4Ljg3MSAx'
    b'NTkxLjk2SDk3Ny40NjRsMTQuODE2LTQzNC42NzdoODIuMjk1em0zLjQ0OSAyNDEuNzE2SDk3'
    b'NC4wMTZsLS4wMDEtMTk3LjM5MiAxMTguMzA1LS4wMzd6IiBmaWxsPSIjZWVkMDAwIiBmaWxs'
    b'LXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMu'
    b'ODY0IiBzdHJva2Utd2lkdGg9IjguNDg5Ii8+CiAgPHBhdGggZD0iTTk3My4yMDUgMTYxMy43'
    b'NzRoMTE5LjkyNmM4LjM1NCAwIDE1LjEyNSA1LjA5MSAxNS4xMjUgMTEuMzcycy02Ljc3MiAx'
    b'MS4zNzItMTUuMTI1IDExLjM3Mkg5NzMuMjA1Yy04LjM1MyAwLTE1LjEyNS01LjA5MS0xNS4x'
    b'MjUtMTEuMzcyLS4wMDEtNi4yODEgNi43NzEtMTEuMzcyIDE1LjEyNS0xMS4zNzJ6bTcuNjE5'
    b'LTIxLjMzNmgxMDQuNjg4YzcuNDM4IDAgMTMuNDY4IDQuNzc2IDEzLjQ2OCAxMC42NjggMCA1'
    b'Ljg5Mi02LjAzIDEwLjY2OC0xMy40NjggMTAuNjY4SDk4MC44MjRjLTcuNDM4IDAtMTMuNDY4'
    b'LTQuNzc2LTEzLjQ2OC0xMC42NjggMC01Ljg5MiA2LjAzLTEwLjY2OCAxMy40NjgtMTAuNjY4'
    b'eiIgZmlsbD0iI2VlZDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDJkNTYi'
    b'IHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI4LjQ4OSIvPgogIDxw'
    b'YXRoIGQ9Ik0xMDAxLjU2NiAxNjczLjI1OGg2My4yMDR2MTMwLjEzOGgtNjMuMjA0eiIgZmls'
    b'bD0ibm9uZSIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1pdD0iMy44NjQiIHN0'
    b'cm9rZS13aWR0aD0iOC40ODkiLz4KICA8cGF0aCBkPSJNOTk2Ljg2NiAxMTQzLjc4Nmg3Mi42'
    b'MDRjNS45NjcgMCAxMC44MDQgMy41MTUgMTAuODA0IDcuODUyIDAgNC4zMzYtNC44MzcgNy44'
    b'NTItMTAuODA0IDcuODUyaC03Mi42MDRjLTUuOTY3IDAtMTAuODA0LTMuNTE1LTEwLjgwNC03'
    b'Ljg1MiAwLTQuMzM2IDQuODM3LTcuODUyIDEwLjgwNC03Ljg1MnoiIGZpbGw9IiNlZWQwMDAi'
    b'IHN0cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lk'
    b'dGg9IjQuOSIvPgogIDxwYXRoIGQ9Ik05NDguODk2IDE4MzQuMTc3aDE2OC41NDR2MjIuNzQ0'
    b'SDk0OC44OTZ6IiBmaWxsPSIjZWVkMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIHN0cm9rZT0i'
    b'IzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9IjQuMDgz'
    b'Ii8+CiAgPHBhdGggZD0iTTE4NTguOTkxIDEwNjYuMTg5Yy4xNjQtLjA3LjI1Ny0uMDkuMjYz'
    b'LS4wOS4wNjUtLjAyIDEwLjA0MiAzLjU2OSAxMC4xMjcgMTkuMTk3IDguODI5LTEuNjU0IDEy'
    b'LjM5MyAzLjAwOSAxMC42OTEgMTMuOTg3IDAgMC0xMC40ODItMi44MzQtMTIuMTkzIDMuMTQz'
    b'LTIuNTcgNi45MS0uNjEgMTIuNTM5IDUuODc5IDE2Ljg4OCAwIDAgMTAuOSA4LjYzOCAxNy43'
    b'NTktNy43MzVzOS4zMjgtMjEuOTQyIDkuMzI4LTIxLjk0MmMxLjkwOC02LjAzMiAxMy4yNjQt'
    b'MjAuMTY4IDIzLjU3OC0yMi4xNDkgMy45MjktMS41NzUgNy42OS0xLjI2NCAxMS44ODYtLjI2'
    b'MSAwIDAgOS4wMjQgMS45NTMgOS4yOCA5LjQ5NC4yNTcgNy41NC0yLjgyMiAxMC44MjItNy45'
    b'MTIgMTMuMDEtNS42MjUgMi40MTktMTIuNTczLTIuNzczLTEyLjU3My0yLjc3My0yLjQyMi0u'
    b'NDUzLTMuMTk1LjM4NS00LjY4MyAxLjQxNy0uNjg1LjQ3NS0zLjU0MSAzLjYxLTUuMTk2IDcu'
    b'MTM5IDAgMC01LjAwOSAxMC41ODgtNy4zOTggMTguNjc1LTEuODgyIDYuMzY4LTYuMDMgMjUu'
    b'NjI5LTI1LjUzMSAyOC41MmgtNDYuMDIyYy0xOS41MDEtMi44OTEtMjMuNjQ5LTIyLjE1Mi0y'
    b'NS41MzEtMjguNTItMi4zOS04LjA4Ny03LjM5OS0xOC42NzUtNy4zOTktMTguNjc1LTEuNjU1'
    b'LTMuNTI5LTQuNTEtNi42NjQtNS4xOTYtNy4xMzktMS40ODctMS4wMzEtMi4yNjEtMS44Njkt'
    b'NC42ODMtMS40MTcgMCAwLTYuOTQ4IDUuMTkyLTEyLjU3NCAyLjc3My01LjA4OS0yLjE4OC04'
    b'LjE2OC01LjQ2OS03LjkxMS0xMy4wMXM5LjI4MS05LjQ5NCA5LjI4MS05LjQ5NGM0LjE5Ni0x'
    b'LjAwMiA3Ljk1Ny0xLjMxNCAxMS44ODYuMjYxIDEwLjMxMyAxLjk4MSAyMS42NyAxNi4xMTcg'
    b'MjMuNTc4IDIyLjE0OSAwIDAgMi40NjkgNS41NjkgOS4zMjggMjEuOTQyIDYuODU4IDE2LjM3'
    b'MyAxNy43NTkgNy43MzUgMTcuNzU5IDcuNzM1IDYuNDg4LTQuMzQ5IDguNDQ4LTkuOTc5IDUu'
    b'ODc4LTE2Ljg4OC0xLjcxLTUuOTc4LTEyLjE5My0zLjE0My0xMi4xOTMtMy4xNDMtMS43MDEt'
    b'MTAuOTc4IDEuODYyLTE1LjY0IDEwLjY5MS0xMy45ODcuMDg1LTE1LjYyOCAxMC4wNjItMTku'
    b'MjIyIDEwLjEyNi0xOS4xOTcuMDEgMCAuMDk5LjAzLjI2My4wOXoiIGZpbGw9IiNlZWQwMDAi'
    b'Lz4KICA8cGF0aCBkPSJNMTkxNy4xMDIgMTU5MS45NmgtMTExLjQwN2wxNC44MTUtNDM0LjY3'
    b'N2g4Mi4yOTZ6bTYuMTUyIDI0MS43MTZoLTExOC4zMDVsLTEuMjQ4LTE5Ny4zOTIgMTE5LjU1'
    b'My0uMDM3eiIgZmlsbD0iI2VlZDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMw'
    b'MDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI4LjQ4OSIv'
    b'PgogIDxwYXRoIGQ9Ik0xODAzLjg1NiAxNjEzLjc3NGgxMTkuOTI2YzguMzU0IDAgMTUuMTI1'
    b'IDUuMDkxIDE1LjEyNSAxMS4zNzJzLTYuNzcyIDExLjM3Mi0xNS4xMjUgMTEuMzcyaC0xMTku'
    b'OTI2Yy04LjM1NCAwLTE1LjEyNS01LjA5MS0xNS4xMjUtMTEuMzcyczYuNzcxLTExLjM3MiAx'
    b'NS4xMjUtMTEuMzcyeiIgZmlsbD0iI2VlZDAwMCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2Ut'
    b'bWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9rZS13aWR0aD0iOC40ODkiLz4KICA8cGF0aCBkPSJN'
    b'MTgwOS45NDggMTU5Mi40MzhoMTA0LjY4OGM3LjQzOCAwIDEzLjQ2OCA0Ljc3NiAxMy40Njgg'
    b'MTAuNjY4IDAgNS44OTItNi4wMyAxMC42NjgtMTMuNDY4IDEwLjY2OGgtMTA0LjY4OGMtNy40'
    b'MzggMC0xMy40NjgtNC43NzYtMTMuNDY4LTEwLjY2OCAwLTUuODkyIDYuMDI5LTEwLjY2OCAx'
    b'My40NjgtMTAuNjY4eiIgZmlsbD0iI2VlZDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJv'
    b'a2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI4'
    b'LjQ4OSIvPgogIDxwYXRoIGQ9Ik0xODMxLjQwOCAxNjczLjI1OGg2My4yMDR2MTMwLjEzOGgt'
    b'NjMuMjA0eiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1p'
    b'dD0iMy44NjQiIHN0cm9rZS13aWR0aD0iOC40ODkiLz4KICA8cGF0aCBkPSJNMTgyNC41Mzgg'
    b'MTE0Mi4xMjFoNzIuNjA0YzUuOTY3IDAgMTAuODA0IDMuNTE1IDEwLjgwNCA3Ljg1MiAwIDQu'
    b'MzM2LTQuODM3IDcuODUxLTEwLjgwNCA3Ljg1MWgtNzIuNjA0Yy01Ljk2NyAwLTEwLjgwNC0z'
    b'LjUxNS0xMC44MDQtNy44NTFzNC44MzctNy44NTIgMTAuODA0LTcuODUyeiIgZmlsbD0iI2Vl'
    b'ZDAwMCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9r'
    b'ZS13aWR0aD0iNC45Ii8+CiAgPHBhdGggZD0iTTEzNTMuNTA1IDE4MzQuMTc3aDE2OC41NDR2'
    b'MjIuNzQ0aC0xNjguNTQ0eiIgZmlsbD0iI2VlZDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRo'
    b'PSI0LjA4MyIvPgogIDxwYXRoIGQ9Ik03MjcuNzkgMTUyNS45NzRjLTI4LjYzMS0yMC41Nzgt'
    b'NTguODgyLTE1LjE2Mi01OC44ODItMTUuMTYyczIxLjg2MS0yOS4xMSA1Ni43MjEtMTQuNjIx'
    b'YzIyLjE0OCA5LjIwNiA0MS4wNTYgNDMuMzIxIDk3LjIzNyA3LjU4MXM3Ny45ODYtNTMuNzk4'
    b'IDEyNy40ODgtNzAuMzk3YzUwLjg2MS0xNy4wNTQgOTAuNzU0LTIwLjU3NyAxMDIuNjM5LTI0'
    b'LjkwOSAxMS44ODQtNC4zMzIgMzAuNDgtMTEuMTIxIDM5Ljk3NS02OC4yMzEgMi4xNjEtMTIu'
    b'OTk3IDU0LjAyIDEwOC4zMDMgNTQuMDIgMTA4LjMwM3MtNy41NjMgNDAuMDcyLTU3LjI2MiA2'
    b'Mi44MTYtMTM1LjgxMSAzNi4zNDktMTgzLjY2OSA3NC43MjljLTE2LjIwNiAxMi45OTYtNDcu'
    b'MzQ3IDM1LjQ2Ny02Ni4xNzUgNjMuMDg3LTQ0LjI5NyA2NC45ODEtOTAuNDg0IDcyLjI5Mi05'
    b'MC40ODQgNzIuMjkyczQxLjg4LTM2LjY3OCA1My40OC04Ni4xMDFjMi4xNjEtOS4yMDYtMS4z'
    b'NzEtNTAuNjEyIDE1LjEyNi02Ny4xNDgtMTcuNTE3IDE3LjU2LTYxLjg2OC0xNy4wMzgtNTYu'
    b'MTgxLTEyLjQ1NSAwIDAtNS40MDItOS4yMDctMzQuMDMzLTI5Ljc4NHptMTA3Mi4zMDYtMTg0'
    b'LjY5OHM4LjY0MyA0OS4yNzggMTA1LjM0IDc0LjE4OCAxMTEuODIzIDU2LjMxOCAxMjcuNDg5'
    b'IDYzLjg5OSA1Ni4zNzEgMzYuNzcxIDk5LjkzOCAyMi4yMDJjMTcuMTY0LTUuNzQgNjUuMTI2'
    b'LTE4Ljk1NCA2OS4wNDEtMTYuMDE3IDEuNDY4IDIuNDQ3LTEzLjcwMyAyNy44OTYtMTUuNTYx'
    b'IDMwLjA5Ny0zMi4wODMgMzguMDE2LTQ0LjI5NyA0My44NjMtNTYuMTgxIDQ5LjgxOS0yNS45'
    b'NTYgMTMuMDEtMjcuOTYyIDE0LjU4OS00Ni40NTcgMTUuNzA0IDAgMCAxNy4yODYgMjEuNjYx'
    b'IDE5Ljk4NyA1Ni44NTlzNDkuNjk5IDcwLjkzOCA0OS42OTkgNzAuOTM4LTYyLjY2NC0xNi4y'
    b'NDUtOTAuMjE0LTUzLjYxYy0yNy41NTEtMzcuMzY1LTcyLjkyNy02OS4zMTQtODkuNjc0LTc3'
    b'LjQzNy0xNi43NDYtOC4xMjMtMTAyLjA5OC0zNy4zNjUtMTE5LjkyNS00NC40MDQtMTcuODI3'
    b'LTcuMDQtNzMuNDY4LTM2LjI4MS04MS4wMzEtODMuMzkzLTcuNTY1LTQ3LjExMiAyNy41NDkt'
    b'MTA4Ljg0NSAyNy41NDktMTA4Ljg0NXoiIGZpbGw9IiNlZWQwMDAiIGZpbGwtcnVsZT0iZXZl'
    b'bm9kZCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9r'
    b'ZS13aWR0aD0iNy40MjgiLz4KICA8cGF0aCBkPSJNODgzLjMwNyAxMzc5LjE3MmMtNjUuNjM1'
    b'LTI1LjcyMi00NS4zNjctNDMuMDgzLTQ1LjM2Ny00My4wODMgMTYuMTUtMjguODc1IDM3LjMw'
    b'Ny02NS4xNDQgMTE3LjI3Ny05NS45MTMgMTA2Ljk2LTQxLjE1NSAyMTYuMDgyLTIyLjc0MyAx'
    b'ODYuOTExIDI0LjkxLTE3LjczNCAyOC45NjktNDguMzQ4IDc5LjYwMy00OC4zNDggNzkuNjAz'
    b'cy0xMi42OTUtMzQuMTE1LTcxLjAzNy0xMi40NTVjLTU4LjM0MiAyMS42NjEtNzYuMzUyIDMw'
    b'LjgzOS03OS44MTMgNDIuMjg4LTUuNDAyIDE3Ljg3LTMuMjQxIDI5LjI0MiAzOC44OTUgMjIu'
    b'NzQ0LTI3LjU1MSA5LjIwNi01OC4yNDQtLjM5OS05Mi43MDQtMTUuNzMyeiIgZmlsbD0iI2Vl'
    b'ZDAwMCIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9r'
    b'ZS13aWR0aD0iNy40MjgiLz4KICA8cGF0aCBkPSJNMTg4My41NTcgMTMzMC42MDhjMTIuMTMg'
    b'My4xMjUgMzIuODM1IDEzLjE3NCA0NS4wNCAyMS45MzkgNTkuNDY0IDQyLjcwNSA0OC41MTYg'
    b'NzkuOTYgMzIuMDMxIDgwLjkzMy0xOC4zNjcgMS4wODMgMTE2LjU5My0yLjY5MSAxMzIuNzk5'
    b'LTExLjM1NXMyMS42MDgtMTguNDEyIDExLjg4NS0zOC45ODktODMuMTkxLTE0Ni4yMDktMjAz'
    b'LjExNy0xNzAuMDM2Yy0xMTkuOTI2LTIzLjgyNi0xNjcuNDQ5IDI2LjczOS0xNTcuMTk5IDQz'
    b'Ljg2MyA5LjcyMyAxNi4yNDUgNTQuMDIgNzAuMzk2IDU1LjY0IDkyLjU5OCAxMi4zMDEtMjMu'
    b'MjM0IDM5Ljk3Mi0yOS44NTMgODIuOTIxLTE4Ljk1M3oiIGZpbGw9IiNlZWQwMDAiIHN0cm9r'
    b'ZT0iIzAwMmQ1NiIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLW1pdGVybGltaXQ9'
    b'IjMuODY0IiBzdHJva2Utd2lkdGg9IjYuMzY3Ii8+CiAgPGcgZmlsbC1ydWxlPSJldmVub2Rk'
    b'Ij4KICAgIDxwYXRoIGQ9Im0xODI2LjA3NiAxMzA3LjM0LTIzLjE0Ny0zMy4yNTcgNi4wMjkg'
    b'MzYuMTI5LTkuMjkxIDEuNTU5LTEwLjUwNS02Mi45NTYgOS45NjMtMS42NzEgMzAuMDY2IDQy'
    b'LjA5IDE1LjEyLTQ5LjY3IDguODE2LTEuNDc5IDEwLjUwNSA2Mi45NTUtMTIuMjk1IDIuMDYz'
    b'LTYuMDI4LTM2LjEzLTEyLjI3NiAzOS4yem05NS41NjctMjQuMTI2Yy0yLjAwMiA5Ljg2NS01'
    b'Ljc1OCAxNi45NDItMTEuMjYyIDIxLjIyOS01LjUwMSA0LjI2LTExLjkwMyA1LjY0My0xOS4y'
    b'MDkgNC4xNTQtNy4yMjctMS40NzQtMTIuNTU1LTUuMjUxLTE1Ljk4NC0xMS4zMzItMy40MjMt'
    b'Ni4xMDgtNC4xNDctMTQuMDI1LTIuMTczLTIzLjc1M2wuNzI0LTMuNTY1YzEuODQtOS4wNjMg'
    b'NS40MjItMTYuMDMgMTAuNzQ2LTIwLjkwMiA1LjM1LTQuODY1IDEyLjA1OC02LjQ3NiAyMC4x'
    b'MjQtNC44MzEgNy44ODEgMS42MDggMTMuMjQ5IDUuNzI0IDE2LjEwNCAxMi4zNSAyLjg4IDYu'
    b'NjMxIDMuNDE3IDE0LjM5NiAxLjYxMiAyMy4yOTN6bS0xMy4yNjQtMy41NjkuMzQ1LTEuNjk5'
    b'YzEuNTY1LTcuNzEgMi4wOTctMTMuNTU4IDEuNTk4LTE3LjU0NS0uNS0zLjk4Ny0zLjExOS02'
    b'LjQ2NC03Ljg1OC03LjQzLTQuMzczLS44OTItNy42MTYuMTczLTkuNzI5IDMuMTk1LTIuMDg3'
    b'IDMuMDI4LTMuOTk3IDguODExLTUuNzMgMTcuMzVsLS4zMTIgMS41MzRjLTEuNzQ1IDguNTk0'
    b'LTIuMzAyIDE0LjYyNS0xLjY2OCAxOC4wOTIuNjMyIDMuNDY4IDMuMjc4IDUuNjc2IDcuOTQg'
    b'Ni42MjcgMy44MjIuNzggNi45MzYtLjM4NCA5LjMzOS0zLjQ5MSAyLjQyOC0zLjEwMiA0LjQ1'
    b'NC04LjY0NiA2LjA3NS0xNi42MzN6bTY0LjQyOSAzMS4xODRjLTQuOTI3IDkuMDk2LTEwLjMg'
    b'MTQuOTE2LTE2LjExNiAxNy40Ni01Ljc5NiAyLjU1OC0xMi4wMzggMi4wMTUtMTguNzMxLTEu'
    b'NjI4bC0xOS40OC0xMC42MDQgMzAuMzg0LTU2LjA5NyAxNy40NzIgOS41MTFjNy45ODQgNC4z'
    b'NDYgMTIuMzgyIDkuODY5IDEzLjE5MyAxNi41NjkuODQ4IDYuNjg4LS45ODMgMTQuMTk0LTUu'
    b'NDk0IDIyLjUyMnptLTExLjg0Ni02LjkzLjgyNi0xLjUyNGMzLjMyOS02LjE0NiA0Ljg2Mi0x'
    b'MS4zOTMgNC42MDItMTUuNzM5LS4yNjItNC4zNDUtMi4xMzEtNy40NjQtNS42MDUtOS4zNTds'
    b'LTQuNDc0LTIuNDM1LTIxLjMyMyAzOS4zNjggNS40OTUgMi45OTFjMy40MDUgMS44NTQgNi42'
    b'NjkgMS45NDYgOS43OTMuMjc3IDMuMTM3LTEuNjkzIDYuNjk4LTYuMjIgMTAuNjg2LTEzLjU4'
    b'MXptNDYuNTM3IDkuNTYyLTExLjk3OSAxMi4yMjEgMTIuODM3IDEyLjY0OC02Ljc0NCA2Ljg4'
    b'LTEyLjgzOC0xMi42NDgtMTIuNiAxMi44NTQgMTcuNjk4IDE3LjQzOC02LjY1NSA2Ljc4OS0y'
    b'Ny40Mi0yNy4wMTYgNDQuNjM1LTQ1LjUzMyAyNi4yNDcgMjUuODYtNi42NTUgNi43ODl6bTYu'
    b'MzY1IDEwMC45MjQtNi44MzUtMTEuNjM1YzguNzkyLTUuMzE3IDE0LjYzMS05Ljg1MyAxNy41'
    b'MTktMTMuNjEgMi45MjMtMy43NDggMy40MjItNy4yNiAxLjQ5Ny0xMC41MzlsLTEuNjI4LTIu'
    b'NzctMjQuNjUxIDE0LjU1Ni02LjkxNy0xMS43NzMgNTQuODY0LTMyLjM5OCAxMi4wODQgMjAu'
    b'NTY4YzIuOTQzIDUuMDA5IDMuODg0IDkuMjI1IDIuODI3IDEyLjY0OS0xLjA0NSAzLjQ0Ni0z'
    b'LjIyOCA2LjE0OS02LjU0NyA4LjExMWwtMi45ODIgMS43NmMtMy4xMjcgMS44NDYtNi4xNzEg'
    b'Mi40MTYtOS4xMzMgMS43MDktMi45NjItLjcwOC01LjY4NS0yLjc4NC04LjE2Ni02LjIzMSAx'
    b'LjEyOSA0Ljg2Ny4wNzkgOS42MzgtMy4xNDkgMTQuMzEyLTMuMTkgNC42ODQtOS40NTEgOS43'
    b'ODEtMTguNzgzIDE1LjI5MXptMzEuMjkxLTM2LjAxNCAxLjQ5LS44OGMyLjM3NS0xLjQwMiAz'
    b'LjcxOC0zLjAwNCA0LjAzMi00LjgwNi4zMTMtMS44MDItLjIyMi0zLjg4LTEuNjA2LTYuMjM0'
    b'bC0yLjI1OC0zLjg0NC0xNC41MDcgOC41NjcgMS44NzEgMy4xODZjMS42NDEgMi43OTMgMy4z'
    b'NDYgNC40NzUgNS4xMTkgNS4wNDYgMS43NzIuNTY5IDMuNzI0LjIyNCA1Ljg1OS0xLjAzNXpt'
    b'LTIwMy41NTEgMTE0Ljc5Ny0xMS4yODUtOC4yMiA1LjM3OC0xNS4wMS0xNi4xNDktMTEuNzYz'
    b'LTEyLjY3NSA5LjY5Ni04Ljk4My02LjU0MyA1My44OTgtMzkuNjQzIDEwLjI4IDcuNDg4em0t'
    b'Mi44MzQtMzIuMzkyIDcuNzMzLTIzLjM4Ny0xOS40MDcgMTQuODg0em03My43MSA1Ljg4MS0x'
    b'MS44MTYtNS43NzktMjMuNzUgNDguODE4LTEyLjI0OS01Ljk5IDIzLjc1LTQ4LjgxNy0xMi4x'
    b'MDUtNS45MiA0LjE2MS04LjU1NCAzNi4xNzIgMTcuNjg3em0yOS4yMzggMS4yNS0yNC44Nzgg'
    b'NTguNzU4LTEyLjU0NS01LjMzOSAyNC44NzgtNTguNzU4em00OC4yNTUgNTguMzQ4Yy00LjA4'
    b'NSA5LjE5OC05LjI3OSAxNS4yOTItMTUuNTc5IDE4LjI4Mi02LjI5MSAyLjk2Ni0xMi44Mzkg'
    b'Mi45MjctMTkuNjUxLS4xMTMtNi43MzgtMy4wMDgtMTEuMTI0LTcuODUxLTEzLjE1OS0xNC41'
    b'MzMtMi4wMjQtNi43MDYtMS4wMjItMTQuNTk0IDMuMDA1LTIzLjY2M2wxLjQ3Ni0zLjMyM2Mz'
    b'Ljc1Mi04LjQ1IDguNzUzLTE0LjQ3NCAxNS4wMDQtMTguMDc2IDYuMjc0LTMuNTkgMTMuMTcx'
    b'LTMuNzA2IDIwLjY5LS4zNSA3LjM0OCAzLjI4IDExLjcgOC40NjQgMTMuMDU3IDE1LjU1MyAx'
    b'LjM4IDcuMDk5LjIyOSAxNC43OTctMy40NTQgMjMuMDkyem0tMTIuMTgxLTYuMzYzLjcwNC0x'
    b'LjU4NGMzLjE5Mi03LjE4OCA0Ljk3NS0xMi43ODIgNS4zNDgtMTYuNzgzcy0xLjY1MS02Ljk4'
    b'OC02LjA2OS04Ljk2Yy00LjA3Ny0xLjgyLTcuNDc0LTEuNDg0LTEwLjE4OSAxLjAwOS0yLjY5'
    b'MSAyLjUwMy01LjgwNSA3LjczNS05LjM0IDE1LjY5NmwtLjYzNSAxLjQzYy0zLjU1OSA4LjAx'
    b'My01LjQwNCAxMy43OC01LjUzNCAxNy4zMDItLjEzMiAzLjUyMyAxLjk3NSA2LjI1MyA2LjMy'
    b'MiA4LjE5MyAzLjU2MyAxLjU5MSA2Ljg1NCAxLjEzMSA5Ljg3Mi0xLjM4MSAzLjA0MS0yLjUw'
    b'MiA2LjIxNS03LjQ3NSA5LjUyMS0xNC45MjJ6bTU0LjcyMiAzMy4yNTEgMTguODQtMzIuNzE1'
    b'IDguNCA0Ljg2My0zMS44MzUgNTUuMjgxLTUuMDY4LTIuOTM0LTYuMjA5LTQ5Ljg5OS0yMC4w'
    b'MDEgMzQuNzI5LTguNC00Ljg2MyAzMS44MzUtNTUuMjgxIDYuMzE4IDMuNjU3ek05NDQuODc3'
    b'IDEzNDEuNzI2bC04LjQ1MiA1LjA5MS00Ny4xMjEtNDYuMDg0IDExLjgxOS03LjEyIDI5Ljc3'
    b'OCAyOS4yNDEtMTAuNTAzLTQwLjg1MiA4LjI4MS00Ljk4OCAzMS4xMTcgMjguNDMzLTEyLjMy'
    b'My0zOS43NTUgOS40NDktNS42OTIgMTguNDMxIDYzLjM2Ny04LjQ1MiA1LjA5Mi0zMi4yNTQt'
    b'MjkuMDgyem00Ny4xNS05MC4zNzUgMTguNjE2IDYxLjA0My0xMy4wMzMgMy45OTUtMTguNjE2'
    b'LTYxLjA0M3ptNzMuMjE3IDMyLjU3OGMuOTQgNi43MDMtLjQ4MyAxMS45NTgtNC4yNjYgMTUu'
    b'NzY2LTMuNzg5IDMuNzgxLTkuNDUzIDYuMjAyLTE2Ljk5NSA3LjI2NC00LjMxNC42MDgtNy45'
    b'OS44NTQtMTEuMDI4Ljc0Mi0zLjAzOS0uMTEzLTUuNTgtLjQzOC03LjYyNS0uOTc2bC0xLjUy'
    b'Ny0xMC44OTJjMS42NDYuNzY1IDQuMTQxIDEuMzM5IDcuNDg3IDEuNzIyIDMuMzQxLjM1NSA2'
    b'LjU3My4zMTMgOS42OTctLjEyOCA0LjM5My0uNjE4IDcuMzIzLTEuNjU3IDguNzkyLTMuMTE4'
    b'IDEuNDk1LTEuNDYzIDIuMDQzLTMuNjE5IDEuNjQzLTYuNDY5LS4yNTgtMS44NDMtMS4wODMt'
    b'My4zOTMtMi40NzMtNC42NDktMS4zOTEtMS4yNTctNS4wNDMtMi42NjQtMTAuOTU1LTQuMjI0'
    b'LTQuNzEyLTEuMjcyLTguNDkyLTMuMjAyLTExLjMzNy01Ljc5My0yLjg1LTIuNjE2LTQuNjMx'
    b'LTYuNDY3LTUuMzQzLTExLjU1LS42ODEtNC44NTkuNzAxLTkuMjQgNC4xNDgtMTMuMTQzIDMu'
    b'NDcyLTMuOTA3IDguNjc2LTYuMzQ4IDE1LjYxLTcuMzI2IDMuMzYtLjQ3MyA2LjQxOC0uNjA1'
    b'IDkuMTc0LS4zOTUgMi43NzguMTc5IDQuNzQuNDE1IDUuODg4LjcwOGwxLjM1MSA5LjYzNWEx'
    b'MjYuMjE1IDEyNi4yMTUgMCAwIDAtNy4wMDUtLjU5NGMtMi4zMTMtLjEyOS00LjczOC0uMDEt'
    b'Ny4yNzkuMzQyLTMuNi41MDctNi4xMSAxLjQ1OS03LjUzNCAyLjg1NS0xLjQyMyAxLjM5Ny0y'
    b'LjAxMiAyLjk3NS0xLjc2NSA0LjczNC4zMTMgMi4yMzUgMS4xNDYgMy44NDEgMi40OTcgNC44'
    b'MTcgMS4zNTIuOTc4IDUuMDgyIDIuMTc2IDExLjE5IDMuNTkyIDUuNjg4IDEuMzA3IDkuODkz'
    b'IDMuMzkxIDEyLjYxNiA2LjI1MyAyLjc0NCAyLjgzNSA0LjQyNCA2LjQ0MyA1LjAzOSAxMC44'
    b'Mjd6bTE5Ny4wNjUtNDMuMzk4Yy0xLjk1NCAzLjg0NS00LjgyMyA2LjQ3OS04LjYwNSA3Ljkw'
    b'Mi0zLjc0NyAxLjQxLTguMDgzLjg1Ni0xMy4wMTMtMS42NjEtMi44ODItMS40NzItNS4xMDEt'
    b'Mi44Ni02LjY1OC00LjE2MS0xLjUzNS0xLjI5LTIuNjg5LTIuNTU5LTMuNDYyLTMuODFsNC40'
    b'MjUtOC43MDdjLjcyNC44NzcgMS43NTIgMS44OTIgMy4wODUgMy4wNDhhMjMuNDUgMjMuNDUg'
    b'MCAwIDAgNC4zNzUgMi45YzEuNDc2Ljc1NCAyLjk2Ni45NzggNC40NzMuNjcxIDEuNTA2LS4z'
    b'MDcgMi43Ny0xLjQ2NiAzLjc5Mi0zLjQ3NmwyMS42NDktNDIuNTk0IDEyLjE0NCA2LjIwM3pt'
    b'NjkuMTgyIDI1LjUxYy0yLjE0OCA1LjYwOC01LjQ2OCA5LjM3Ny05Ljk1NSAxMS4zMDYtNC40'
    b'NzkgMS45MDItMTAuMTQ5IDEuNTM0LTE3LjAwOC0xLjEwNS03LjM2LTIuODMxLTExLjk5Ny02'
    b'LjU2My0xMy45MTQtMTEuMTk4cy0xLjU5NS0xMC4yOTUuOTY3LTE2Ljk4M2wxNS4zNTYtNDAu'
    b'MDg3IDEyLjcyMyA0Ljg5NC0xNS45NzcgNDEuNzA3Yy0xLjI0IDMuMjM5LTEuNDg5IDUuOTM4'
    b'LS43NDEgOC4wOTguNzgxIDIuMTQ0IDIuODgxIDMuODczIDYuMjk5IDUuMTg4IDMuMTY4IDEu'
    b'MjE5IDUuNzkgMS4zOTcgNy44NjcuNTM0IDIuMTAxLS44NTMgMy44NjctMy4xNDkgNS4zMDEt'
    b'Ni44ODhsMTUuODg2LTQxLjQ3IDkuNDMgMy42Mjd6bTY3LjM1NCAxMy43NjNjLS44MjMgNi43'
    b'MTgtMy41NTQgMTEuNDI1LTguMTkxIDE0LjEyMi00LjYzNiAyLjY2OC0xMC43MzIgMy41Mzgt'
    b'MTguMjkyIDIuNjA3LTQuMzI0LS41MzItNy45MzgtMS4yNDgtMTAuODQ0LTIuMTQ1cy01LjI3'
    b'Ny0xLjg3MS03LjExNC0yLjkyMmwxLjMzNy0xMC45MTdjMS4zOTIgMS4xNjYgMy42NTQgMi4z'
    b'NjggNi43ODcgMy42MDYgMy4xMzYgMS4yMSA2LjI2OSAyLjAwOCA5LjQgMi4zOTMgNC40MDMu'
    b'NTQyIDcuNTAyLjI5OSA5LjI5OC0uNzMxIDEuODIyLTEuMDI1IDIuOTA3LTIuOTY1IDMuMjU4'
    b'LTUuODIyLjIyNi0xLjg0OC0uMTctMy41NTktMS4xODktNS4xMzNzLTQuMTgzLTMuODgyLTku'
    b'NDkxLTYuOTIyYy00LjIyMy0yLjQ1MS03LjM3NS01LjI5Ni05LjQ1NS04LjUzNy0yLjA3Ny0z'
    b'LjI2Ny0yLjgwNC03LjQ0OC0yLjE4LTEyLjU0My41OTctNC44NzEgMy4wNjMtOC43NDQgNy40'
    b'LTExLjYxOSA0LjM2My0yLjg3MyAxMC4wMTktMy44ODEgMTYuOTctMy4wMjYgMy4zNjguNDE1'
    b'IDYuMzU2IDEuMDgxIDguOTYzIDEuOTk5IDIuNjM3Ljg5MyA0LjQ3MSAxLjYzMSA1LjUwNCAy'
    b'LjIxMmwtMS4xODMgOS42NTdhMTI2LjY3NSAxMjYuNjc1IDAgMCAwLTYuNjEzLTIuMzkxYy0y'
    b'LjItLjcyNS00LjU3My0xLjI0My03LjExOS0xLjU1OC0zLjYwOC0uNDQ0LTYuMjc5LS4xNzYt'
    b'OC4wMTQuODAzLTEuNzM1Ljk4LTIuNzExIDIuMzUyLTIuOTI3IDQuMTE1LS4yNzQgMi4yNC4x'
    b'MTUgNC4wMDcgMS4xNjggNS4zMDEgMS4wNTMgMS4yOTUgNC4zNDcgMy40MiA5Ljg4MSA2LjM3'
    b'NCA1LjE1NyAyLjczOCA4LjY4MSA1Ljg0MiAxMC41NzIgOS4zMTQgMS45MjEgMy40NDcgMi42'
    b'MTIgNy4zNjggMi4wNzQgMTEuNzYzem02Mi43NzYtMzEuNzA1LTEzLjE0Ni0uMjI5LS45NDcg'
    b'NTQuMzA2LTEzLjYyNi0uMjM4Ljk0Ny01NC4zMDYtMTMuNDY2LS4yMzYuMTY2LTkuNTE2IDQw'
    b'LjIzOC43MDN6bTM3LjE4MS0xMy4wNjYgNy43NTggNjMuMzU4LTEzLjUyNyAxLjY2NS03Ljc1'
    b'OC02My4zNTd6bTc2LjIwMyA0NC4zNzNjLS43MDYuODk1LTIuMTQ4IDEuOTg1LTQuMzI1IDMu'
    b'MjcyLTIuMTcxIDEuMzEzLTQuODAyIDIuNDQzLTcuODkzIDMuMzkyLTcuNzk1IDIuMzg5LTE0'
    b'LjkzMiAxLjgwNC0yMS40MS0xLjc1Ni02LjQ2MS0zLjU5NC0xMS4xOTMtMTAuMzEzLTE0LjE5'
    b'Ni0yMC4xNTdsLS43NTMtMi40NjhjLTIuNzk3LTkuMTctMi41NTEtMTcuMjk2LjczOC0yNC4z'
    b'NzkgMy4zMTQtNy4wOSA4Ljc0MS0xMS43OSAxNi4yOC0xNC4xMDIgMy4yNDUtLjk5NCA2LjAx'
    b'NS0xLjYyMiA4LjMxMi0xLjg4NCAyLjI4Ny0uMjg4IDQuMTMtLjI5MiA1LjUyOS0uMDFsMi45'
    b'NjEgOS43MDljLTEuMjg5LS4yODItMi45NTItLjM3Ny00Ljk5MS0uMjg0LTIuMDE1LjA5LTQu'
    b'Mjg2LjUxNy02LjgxNiAxLjI5Mi00LjcwMyAxLjQ0MS03Ljc5NSA0LjQ5OC05LjI3NiA5LjE2'
    b'OC0xLjQ1NyA0LjY2NC0xLjE0NyAxMC4zOTMuOTI2IDE3LjE5bC4yNTkuODVjMi4yMjEgNy4y'
    b'ODIgNS4wODkgMTIuMjg3IDguNjAzIDE1LjAxNCAzLjU0IDIuNzIgNy40NDQgMy40MjYgMTEu'
    b'NzEyIDIuMTE4IDIuODg3LS44ODUgNS4yNjMtMS45MzYgNy4xMjctMy4xNTcgMS44NTUtMS4y'
    b'NDYgMy4zMDEtMi4zMjMgNC4zMzgtMy4yMzF6bTE4Ljg3NS02Ny42MzUgNy43NTggMTUuMjY1'
    b'IDE2LjAzNi04LjE5MiA0LjM2OCA4LjU5NC0xNi4wMzcgOC4xOTEgOC4xNjEgMTYuMDU3IDIy'
    b'LjEwNy0xMS4yOTMgNC4zMSA4LjQ4LTM0LjI1IDE3LjQ5Ni0yOC45MDctNTYuODc1IDMyLjc4'
    b'Ny0xNi43NDggNC4zMSA4LjQ4em0tNjcxLjMxNCAzMDMuOTMxYzUuMDA4IDkuMDU1IDcuMDE5'
    b'IDE2LjcyNSA2LjAzNyAyMy4wMS0uOTYgNi4yNzUtNC43NyAxMS4yNi0xMS40MyAxNC45Nmwt'
    b'MTkuMzg1IDEwLjc2OS0zMC44ODUtNTUuODM5IDE3LjM4Ny05LjY1OGM3Ljk0NS00LjQxNCAx'
    b'NC45NTQtNS4xNjMgMjEuMDI4LTIuMjQ4IDYuMDgzIDIuODc4IDExLjQxNiA4LjQ2MSAxNi4w'
    b'MDEgMTYuNzV6bS0xMi4xOTMgNi4yOS0uODM5LTEuNTE3Yy0zLjM4My02LjExNy02Ljk3NS0x'
    b'MC4yMzQtMTAuNzcyLTEyLjM1LTMuNzk3LTIuMTE0LTcuNDI1LTIuMjExLTEwLjg4NC0uMjkx'
    b'bC00LjQ1MiAyLjQ3MyAyMS42NzUgMzkuMTg4IDUuNDY5LTMuMDM4YzMuMzg4LTEuODgyIDUu'
    b'MjE5LTQuNTkyIDUuNDkzLTguMTMxLjI1OS0zLjU2Mi0xLjYzOC05LjAwNS01LjY5LTE2LjMz'
    b'NHptNjkuNjU2LTMwLjI5MWMzLjkyNCA5LjI2OSA0LjgyOCAxNy4yMzQgMi43MTMgMjMuODk0'
    b'LTIuMTI3IDYuNjM2LTYuNjIyIDExLjQxMS0xMy40ODUgMTQuMzMzLTYuNzkgMi44OS0xMy4z'
    b'MTYgMi44MDMtMTkuNTc4LS4yNjMtNi4yNzMtMy4wOS0xMS4zNDQtOS4yMDUtMTUuMjE0LTE4'
    b'LjM0NGwtMS40MTgtMy4zNDljLTMuNjA1LTguNTE1LTQuNTktMTYuMjkyLTIuOTU0LTIzLjMz'
    b'MiAxLjY2LTcuMDQ5IDYuMjc5LTEyLjE4NiAxMy44NTctMTUuNDEgNy40MDUtMy4xNTEgMTQu'
    b'MTU1LTIuODA3IDIwLjI1MyAxLjAzMyA2LjEyMSAzLjgzIDEwLjk1MSA5LjkyNSAxNC40OTIg'
    b'MTguMjg0em0tMTIuOTUgNC41OTItLjY3Ni0xLjU5N2MtMy4wNjctNy4yNDQtNS45MzMtMTIu'
    b'MzY2LTguNTk4LTE1LjM2OS0yLjY2NS0zLjAwMi02LjIyNC0zLjU1Ni0xMC42NzYtMS42NjEt'
    b'NC4xMDkgMS43NDgtNi4xOCA0LjQ2OC02LjIxNCA4LjE1OS0uMDA5IDMuNjgxIDEuNjg0IDku'
    b'NTMyIDUuMDgxIDE3LjU1NWwuNjEgMS40NDFjMy40MTkgOC4wNzQgNi4zNjggMTMuMzYyIDgu'
    b'ODQ5IDE1Ljg1OSAyLjQ4IDIuNDk5IDUuOTEgMi44MTcgMTAuMjg5Ljk1MyAzLjU5MS0xLjUy'
    b'OCA1LjUtNC4yNTUgNS43MjUtOC4xODEuMjUxLTMuOTM1LTEuMjEzLTkuNjU1LTQuMzktMTcu'
    b'MTU5em02My4xMTggMTEuNTY5LTI4LjgwNy0yOC40NzMgMTIuNDk4IDM0LjQyNC04Ljg1MiAz'
    b'LjIzLTIxLjc3Ny01OS45ODMgOS40OTItMy40NjQgMzcuMjE3IDM1Ljg5MyA1LjgzNi01MS42'
    b'MDMgOC40LTMuMDY1IDIxLjc3NyA1OS45ODQtMTEuNzE1IDQuMjc0LTEyLjQ5Ny0zNC40MjQt'
    b'NC45NDIgNDAuNzg4em04My45NDgtNjMxLjc3NWMtLjAzOCAxLjMxMS0uNjE1IDMuMzM0LTEu'
    b'NzI4IDYuMDY4LTEuMDg4IDIuNzU0LTIuNzE5IDUuNjgxLTQuODg5IDguNzgzLTUuNDc1IDcu'
    b'ODItMTIuMzU0IDEyLjUxNi0yMC42MzkgMTQuMDg5LTguMjkyIDEuNTI5LTE3LjExNi0uOTgy'
    b'LTI2LjQ3NC03LjUzNGwtMi4zNDYtMS42NDJjLTguNzE2LTYuMTAzLTEzLjk2NC0xMy41MDMt'
    b'MTUuNzQ1LTIyLjItMS43NjItOC43MjIgMC0xNi44NjQgNS4yOTktMjQuNDI4IDIuMjgtMy4y'
    b'NTUgNC4zNzQtNS44MzggNi4yODUtNy43NDggMS44ODUtMS45MjcgMy41NTYtMy4yNzkgNS4w'
    b'MTYtNC4wNTNsOS4yMjkgNi40NjJjLTEuMzYxLjY5MS0yLjkzNyAxLjgyMy00LjcyNyAzLjM5'
    b'NS0xLjc3MiAxLjU0OS0zLjU0NiAzLjU5Mi01LjMyMyA2LjEzLTMuMzAzIDQuNzE4LTQuMDU1'
    b'IDkuNjkzLTIuMjU2IDE0LjkyNSAxLjgxNyA1LjIwOSA1Ljk1NiAxMC4wNzMgMTIuNDE2IDE0'
    b'LjU5N2wuODA4LjU2NWM2LjkyMiA0Ljg0NyAxMi44OTggNy4xOTcgMTcuOTI4IDcuMDUyIDUu'
    b'MDQ4LS4xNzEgOS4wNzEtMi4zOTcgMTIuMDY5LTYuNjc4IDIuMDI4LTIuODk2IDMuNDc5LTUu'
    b'NTY3IDQuMzUxLTguMDE0Ljg0Ny0yLjQ2MiAxLjQzNS00LjQ3NyAxLjc2Ni02LjA0MnptMzQu'
    b'NTYyLTg1LjI0YzguMDM3IDcuNzYxIDEyLjMyNCAxNS42IDEyLjg2IDIzLjUxMy41MTQgNy44'
    b'OTQtMi4yNjMgMTQuOTc4LTguMzI3IDIxLjI2LTYgNi4yMTMtMTIuOTYzIDkuMjEzLTIwLjg5'
    b'MSA4Ljk5Ny03Ljk0OS0uMjM3LTE1Ljg4Ni00LjE4Mi0yMy44MTItMTEuODM1bC0yLjkwNC0y'
    b'LjgwNGMtNy4zODQtNy4xMy0xMS42NzctMTQuNzM1LTEyLjg4Mi0yMi44MTUtMS4xODItOC4x'
    b'MDIgMS41NzUtMTUuNjIgOC4yNzEtMjIuNTU0IDYuNTQzLTYuNzc2IDEzLjg1My05LjYxNSAy'
    b'MS45MjktOC41MTcgOC4wOTcgMS4wNzcgMTUuNzcgNS4xMTUgMjMuMDIgMTIuMTE0em0tMTEu'
    b'ODI4IDEwLjg5Ny0xLjM4NS0xLjMzN2MtNi4yODEtNi4wNjYtMTEuNDYzLTEwLjAyNS0xNS41'
    b'NDYtMTEuODgtNC4wODMtMS44NTQtOC4wOTItLjc0NC0xMi4wMjcgMy4zMzEtMy42MzEgMy43'
    b'Ni00LjY5MyA3LjU2My0zLjE4NyAxMS40MSAxLjUyNyAzLjgyNCA1Ljc2OSA5LjA5NSAxMi43'
    b'MjYgMTUuODEzbDEuMjQ5IDEuMjA3YzcuMDAyIDYuNzYxIDEyLjM0MSAxMC44NTMgMTYuMDE3'
    b'IDEyLjI3IDMuNjc3IDEuNDE5IDcuNDQ5LjEyNSAxMS4zMi0zLjg4MyAzLjE3My0zLjI4NiA0'
    b'LjA2MS03LjAyIDIuNjYtMTEuMjAxLTEuMzc4LTQuMjAzLTUuMzItOS40NDctMTEuODI3LTE1'
    b'Ljczem03NC45Ny01NC40MzgtMjQuNjQxLTMzLjkxNSA5LjE5MS02LjY3OCA0MS42MzggNTcu'
    b'MzEtNS41NDUgNC4wMjktNTQuODMyLTE1LjE3MiAyNi4xNTggMzYuMDA0LTkuMTkxIDYuNjc4'
    b'LTQxLjYzNy01Ny4zMSA2LjkxMi01LjAyMnptODguMjMzLTM1Ljg5NWMzLjE3NSA2LjgwNyAz'
    b'LjI1MyAxMi45LjIzNiAxOC4yNzgtMy4wMzEgNS4zNS04LjU4NyA5LjkwOS0xNi42NzEgMTMu'
    b'Njc5LTQuNjI0IDIuMTU2LTguNjQ5IDMuNzA1LTEyLjA3NyA0LjY0Ny0zLjQyOS45NDMtNi4z'
    b'NjkgMS40ODYtOC44MjMgMS42MjhsLTUuMTU4LTExLjA2MmMyLjA4LjIzOSA1LjA0OC0uMDIg'
    b'OC45MDUtLjc4NiAzLjg0My0uNzkxIDcuNDM5LTEuOTY3IDEwLjc4Ny0zLjUyOCA0LjcwOC0y'
    b'LjE5NSA3LjY1LTQuMzI3IDguODI3LTYuMzk2IDEuMjA1LTIuMDggMS4xMzQtNC41NjctLjIx'
    b'Ni03LjQ2MS0uODczLTEuODcyLTIuMjg1LTMuMjM0LTQuMjM2LTQuMDg1LTEuOTUxLS44NTIt'
    b'Ni40NzUtMS4wNzMtMTMuNTctLjY2NS01LjY2NC4yOTQtMTAuNDk2LS40MzktMTQuNDk0LTIu'
    b'MjAyLTQuMDEyLTEuNzg5LTcuMjIxLTUuMjY1LTkuNjI4LTEwLjQyOC0yLjMwMi00LjkzNS0y'
    b'LjE0OC0xMC4wODMuNDY0LTE1LjQ0NSAyLjYzOC01LjM3NCA3LjY3My05Ljc5NCAxNS4xMDUt'
    b'MTMuMjYgMy42MDItMS42NzkgNi45NzQtMi44ODkgMTAuMTE3LTMuNjMgMy4xNTgtLjc4MSA1'
    b'LjQyNC0xLjIxNiA2Ljc5OC0xLjMwNWw0LjU2MyA5Ljc4NmExNTUuMjQ2IDE1NS4yNDYgMCAw'
    b'IDAtOC4wMSAxLjgxOGMtMi42MjMuNjcxLTUuMjk1IDEuNjQyLTguMDE4IDIuOTEtMy44NTgg'
    b'MS43OTktNi4zNTkgMy42OTEtNy41MDYgNS42NzZzLTEuMzAzIDMuODcxLS40NyA1LjY1OGMx'
    b'LjA1OSAyLjI3IDIuNDk3IDMuNjg4IDQuMzE1IDQuMjU1IDEuODE5LjU2OCA2LjM2NC41Mzkg'
    b'MTMuNjMzLS4wOSA2Ljc2NS0uNTk5IDEyLjEyMS4xNDkgMTYuMDY4IDIuMjQ1IDMuOTYzIDIu'
    b'MDU2IDYuOTgyIDUuMzEgOS4wNTkgOS43NjN6bTYxLjI5MS01OC42ODQtMTQuODczIDMuOTg1'
    b'IDE1LjYgNTguMjIzLTE1LjQxNyA0LjEzMS0xNS42LTU4LjIyMy0xNS4yMzYgNC4wODMtMi43'
    b'MzQtMTAuMjAzIDQ1LjUyNi0xMi4xOTh6bTQxLjM3Ny0xNS43NiAxNS45MjMtMS4xMTQgNC45'
    b'NDUgNzAuNjY4LTE1LjkyMyAxLjExNHptMTAxLjI0NyAxMi40MTMtMTUuMzYxLTEuMDc0LTQu'
    b'MjA1IDYwLjEyOS0xNS45MjItMS4xMTMgNC4yMDUtNjAuMTMtMTUuNzM0LTEuMS43MzctMTAu'
    b'NTM2IDQ3LjAxNiAzLjI4OHptNzcuNDk5IDYwLjY1MmMtMS45NDkgNi4zNzUtNS40MzggMTAu'
    b'NzczLTEwLjQ2NSAxMy4xOTYtNS4wMTkgMi4zOTMtMTEuNjQ0IDIuMzMxLTE5Ljg3NC0uMTg1'
    b'LTguODMtMi43LTE0LjU4My02LjU3LTE3LjI2NC0xMS42MTEtMi42OC01LjA0MS0yLjg1OS0x'
    b'MS4zNjItLjUzNC0xOC45NjVsMTMuOTMxLTQ1LjU2NiAxNS4yNjMgNC42NjctMTQuNDk0IDQ3'
    b'LjQwNmMtMS4xMjUgMy42ODEtMS4xNSA2LjcwMi0uMDcgOS4wNiAxLjExNyAyLjMzOSAzLjcy'
    b'NyA0LjEzNCA3LjgyNyA1LjM4NyAzLjgwMSAxLjE2MiA2Ljg2NSAxLjIgOS4xOTUuMTExIDIu'
    b'MzU4LTEuMDc5IDQuMTg2LTMuNzQyIDUuNDg3LTcuOTkzbDE0LjQxMS00Ny4xMzcgMTEuMzEz'
    b'IDMuNDU5em04OC45NzctNC40NDctMTMuNzItNi45OTEtMjcuMzY1IDUzLjcwNy0xNC4yMjEt'
    b'Ny4yNDYgMjcuMzY1LTUzLjcwNy0xNC4wNTQtNy4xNjEgNC43OTUtOS40MTEgNDEuOTk1IDIx'
    b'LjM5OHptMzkuMTQxIDEyLjYyOSAxMi45MTIgOS4zODItNDEuNjM5IDU3LjMwOS0xMi45MTIt'
    b'OS4zODJ6bTYyLjEyNiAxMDMuNjI0Yy03LjkgNy45LTE1LjgxMyAxMi4wNS0yMy43MzQgMTIu'
    b'NDQ4LTcuOTAxLjM3Ni0xNC45MzYtMi41MjQtMjEuMTEyLTguNjk3LTYuMTA4LTYuMTA4LTgu'
    b'OTg1LTEzLjEyMi04LjYzMS0yMS4wNDUuMzc1LTcuOTQ0IDQuNDU4LTE1LjgxMSAxMi4yNDkt'
    b'MjMuNjAxbDIuODU0LTIuODU1YzcuMjU4LTcuMjU4IDE0LjkzNy0xMS40MTggMjMuMDM3LTEy'
    b'LjQ4MSA4LjEyMS0xLjA0MSAxNS41OSAxLjg0NyAyMi40MDYgOC42NjQgNi42NjEgNi42NjEg'
    b'OS4zNzEgMTQuMDE5IDguMTMzIDIyLjA3NC0xLjIxOCA4LjA3Ny01LjM5IDE1LjY3OC0xMi41'
    b'MTQgMjIuODA1em0tMTAuNjg4LTEyLjAxNyAxLjM2MS0xLjM2MWM2LjE3NC02LjE3NCAxMC4y'
    b'MjQtMTEuMjg2IDEyLjE0OS0xNS4zMzZzLjg4NS04LjA3Ny0zLjEyLTEyLjA4M2MtMy42OTYt'
    b'My42OTYtNy40OC00LjgyNC0xMS4zNTItMy4zODUtMy44NTEgMS40NjEtOS4xOTUgNS42MS0x'
    b'Ni4wMzMgMTIuNDQ4bC0xLjIyOSAxLjIyOGMtNi44ODMgNi44ODItMTEuMDY2IDEyLjE0OS0x'
    b'Mi41NDcgMTUuODAxLTEuNDgzIDMuNjUxLS4yNTUgNy40NDYgMy42ODUgMTEuMzg2IDMuMjMg'
    b'My4yMyA2Ljk0OCA0LjE4MiAxMS4xNTMgMi44NTUgNC4yMjUtMS4zMDYgOS41MzYtNS4xNTcg'
    b'MTUuOTMzLTExLjU1M3ptNTQuNjQ3IDczLjcwMSAzMy45MTUtMjQuNjQgNi42NzggOS4xOTEt'
    b'NTcuMzExIDQxLjYzNy00LjAyOC01LjU0NSAxNS4xNzEtNTQuODMyLTM2LjAwNCAyNi4xNTgt'
    b'Ni42NzctOS4xOSA1Ny4zMS00MS42MzggNS4wMjEgNi45MTJ6IiBmaWxsPSIjMDAyZDU2Ii8+'
    b'CiAgICA8cGF0aCBkPSJNMTY3My4wOTggMTM5OC45NTFzMy45MDYtNC4yOTQgNS4xNzMtMS4x'
    b'NiAxLjUzNiA1LjgwNi40NTIgNi45NzctLjk1NSAxLjkxMS0yLjQ5IDMuODc2Yy0xLjUzNCAx'
    b'Ljk2NS0uODU0IDMuMDg4LTIuMzM1IDQuMDMzcy0yLjE2MS41MTktMy43OTMuNDMzbC0uNjY0'
    b'IDQuODczLTEuMDYyIDQuMDczLjYxMiAzLjkxOCAyLjc4NCA2LjIzLTIuMTIzLTQuNjY5IDIu'
    b'OTcyIDUuMDk0YzIuMjUgNS45MzUgMjMuNjM4IDExLjg5NyAzMS4zODcgMTUuMzY0IDE2LjEz'
    b'MSA3LjIxNiAxMy42MDggNDEuNTE3IDE1LjMwNyA0NC45MTMgMS42OTggMy4zOTYgOC40ODkg'
    b'NDguODE2IDguNDg5IDU2LjQ1N3MtOC40ODkgNDguODE2LTkuMzM4IDU3LjMwNmMtLjQyMyA0'
    b'LjIzLTEuNDc5IDE0LjM2My0yLjUzNiAyNC42MjEtLjIwOSAyLjAyNy0zLjExOS0uNjM4LTQu'
    b'MDM5IDEuMTg2LTEuMjE5IDIuNDE4LTEuMDQyIDkuMzc1LS43NTMgMTEuNjc3LS41MDcgNS4w'
    b'MDgtMS45MzIgOC45MDItMi4xNjMgMTEuNDQ4LS44NDkgOS4zMzktOS40NTUgMTAuMjExLTku'
    b'NDU1IDEwLjIxMXMtLjMwNiAzMS45NC0yLjAwNCAzOS41OGMtMS42OTggNy42NDEtMi44NTMg'
    b'OS4wOTYtLjMwNiAzMC4zMjFzLTMuMzk2IDQ3LjU0My0zLjM5NiA0Ny41NDMtOC43NjcgMzgu'
    b'Njk0LTEwLjQ2NSA0NC42MzcgMS4xMjYgMTEuMzk2IDEuOTc1IDE1LjY0Yy44NDkgNC4yNDUu'
    b'ODQ5IDExLjAzNy44NDkgMTEuMDM3aC03NC42NDdjLTEuODk4IDAgMS4zMTEtNi43MTUgMy44'
    b'Mi0xMS40NjEgMS4xNjItMi4xOTggNC42NjktNS41MTggOS43NjMtNi4zNjdzNS41MTgtNi4z'
    b'NjcgOC40OS0xMy4xNTljMi45NzEtNi43OTIgMS42OTgtMjEuMjI0LS44NDktMzAuMTM5cy01'
    b'Ljk0My0zMC41NjMtNS45NDMtMzguMjA0LTQuMjEzLTI1LjA0NS04LjQ1OC0zNi45MzFjLTQu'
    b'MjQ1LTExLjg4NS02LjM2Ny0zNy43NzktNi4zNjctNDAuMzI2IDAtMS4xMTEtLjQ4NS0yLjU0'
    b'NS0xLjM4NC00Ljc5Ni0xLjE2Mi0yLjkwOC0xLjM0OS03LjE4MS0zLjc0MS0xMy44ODItNC4y'
    b'NDUtMTEuODg1LTMuODUyLTI2LjMxOC00LjI3Ni0zOC42MjhzLTUuMDk0LTI1Ljg5NC03LjI0'
    b'NS0yOC45MDRsLTEuMzEzLTUuMzE4LTEzLjA5MiA0LjA4My0xMi42NTcgOS45MTFjLTIuNzg3'
    b'IDIuNTE5LTUuODI2IDIuOTM5LTEwLjk0NCAzLjM5Ni05LjkwOS44ODUtMTkuODE3LTEwLjc0'
    b'My0yMi4xNDItMjcuNTUtMi41NjktMTguNTc4IDEuMTAxLTI2LjU0IDIxLjc3NS0yNi40NzZs'
    b'OS4xODcuMDIgNy45ODQuMjY2SDE1NzhzMi4zMTggNC41MjMtMS4yODggNi4xMTljLTMuNjA1'
    b'IDEuNTk2LTQuNjM1IDEuODYyLTQuNjM1IDEuODYybDQuNjEzIDUuMjgyYy0uMDg2LjAxIDIu'
    b'NDk5LTEuNzM4IDEwLjE4OC01Ljk0M2wyLjg2NS02LjY4NmMuMjEyLTQuMjQ1LjUzMS01LjIt'
    b'LjMxOC05Ljg2OXMtMi40OTctMzEuNTEzLTIuNDk3LTM3Ljg4LjE4NS0xMy45LjgzMy0yMS4y'
    b'NWMuNTktNi42ODYuNS0yMS41ODcgMy43NS0yNy45MTcgNC4wMzItNy44NTMgMjUuODMzLTEx'
    b'LjI1IDI1LjgzMy0xMS4yNXM5LjQzNS0xLjAzMyAxMC43MDgtMy41ODFjLjQ3NS0uOTQ5IDIu'
    b'ODQ1LTUuMDIxIDMuODUzLTYuNjExLTYuMDY4LTIuMTU0LTguMDU5LTkuNjEzLTguOTQ3LTEx'
    b'LjQyOS0uOTI0LTEuODg5LTIuNTQ3LTEwLjYxMy0yLjc1OS0xMS40NjEtLjMxMy0xLjI1My0y'
    b'LjIxNC05LjEzOC0zLjI3OC0xMi4yNjEtMS4wNjMtMy4xMjMtLjE2LTguODE0LS4xNi04Ljgx'
    b'NGwtNi45MDUtLjc1OS04LjM1MS0uNjQycy00LjY2OS0uNjU0LTUuODcxLTEuMTI1Yy0xLjIw'
    b'Mi0uNDcyLTUuMjQ5LTEuMjk4LTUuMjQ5LTEuMjk4cy02LjYzNC01LjY4Mi0uMDU1LTEwLjI0'
    b'NSAxNC4zMTMtOC43OTMgMTUuNTc5LTkuNTQ1IDEuNzczLTIuMDAyIDEuNzczLTIuMDAybC0u'
    b'MTE4LTEuNjQyYy0xLjUxNC0yLjMyOS0yLjk4NS01LjQ3NC00Ljg3Ni0xMi4zMjEtMS44OS02'
    b'Ljg0NyAxNi4wNzktOS43MDUgMTYuMDc5LTkuNzA1IDUuMTk4LS40NDYgMjIuNjI3IDEuODYx'
    b'IDIwLjgzMyAxLjQ2NSAzLjYzOS44MDQgNi4wMTkuNjc0IDEyLjk3NC42MyA2Ljk1NS0uMDQg'
    b'MTYuMDI1IDIuNDc2IDIxLjA4MSAzLjU1OXMxMC4yMTEgNS43NjMgMTIuODIgMTAuNjA0YzIu'
    b'NjA5IDQuODQgMTMuMTcyIDEwLjk2MyAxNi4yODYgMTMuOTg5IDQuNzExIDQuNTc5IDEwLjMx'
    b'IDE0LjE3NCAxMi40NjUgMTcuNjc4IDMuNzY5IDYuMTI4LS4yOTYgNC42NjUtMS41NjIgNS40'
    b'MTctNS44OSAzLjQ5Ni0zOC42ODctMy45LTM1LjgyOC0zLjU0NSAyLjM0OC4yOTIgMS43OTct'
    b'LjU0NC0uNzQtMS45MTNsLS4wMTcgMi4zMTMtMS45MSA3LjIxNnoiIGZpbGw9IiNlZWQwMDAi'
    b'IHN0cm9rZT0iI2VlZDAwMCIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lk'
    b'dGg9IjEuNjMzIi8+CiAgPC9nPgogIDxwYXRoIGQ9Ik0xNjM4LjI0MiAxNDkwLjc4MmMxLjA0'
    b'MS0xNy4zODggMi40NjktMzEuNzE5IDUuMDk0LTQyLjg3NC44NDktMy42MDggMC01LjMwNiAw'
    b'LTUuMzA2LTQuNTItLjEwOC03LjU2Mi0uNDUxLTEyLjI0LTUuODYxIiBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRo'
    b'PSI0LjA4MyIvPgogIDxwYXRoIGQ9Im0xNjA5LjYwNCAxNjgwLjM5MS45OTktNy4yMDVzMi4y'
    b'MzMtNC4xMTkgMS4zODQtMTIuMTg0IDAtMzAuNTYzIDIuMTIzLTQyLjAyNGMyLjAwOS0xMC44'
    b'NTIgMTkuMDM5LTQ0LjU3MSAyMC43MzctNTMuNDg2IDEuNDY1LTcuNjg5IDEuNjk4LTMzLjUz'
    b'NSAxLjY5OC0zNS42NTcgMC0uNzA0LS44NDEtMy4xNTktLjQyNS0xMi43MzUiIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Ut'
    b'd2lkdGg9IjQuOSIvPgogIDxwYXRoIGQ9Ik0xNTk1LjM0MSAxNTkxLjc3MWMyLjE1MSAzLjAx'
    b'IDYuODIgMTYuNTk0IDcuMjQ1IDI4LjkwNHMtMS42MzUgMjYuNzQzIDIuNjEgMzguNjI4YzIu'
    b'MzkzIDYuNzAxIDQuMjQ2IDEwLjk3MyA1LjQwOCAxMy44ODIuODk5IDIuMjUgNC43MTcgMy42'
    b'ODUgNC43MTcgNC43OTYgMCAyLjU0NyAyLjEyMiAyOC40NDEgNi4zNjcgNDAuMzI2IDQuMjQ1'
    b'IDExLjg4NiA2Ljc5MiAyOS4yOSA2Ljc5MiAzNi45MzFzMy4zOTYgMjkuMjkgNS45NDMgMzgu'
    b'MjA0IDMuODIgMjMuMzQ3Ljg0OSAzMC4xMzljLTIuOTcyIDYuNzkyLTMuODA1IDEwLjk4Ny04'
    b'LjQ5IDEzLjE1OS0zLjYwMiAxLjY3LTUuMzU2IDIuMzg5LTguMTg1IDUuODM2LTMuNDA1IDQu'
    b'MTUxLTcuMjk3IDExLjk5Mi01LjM5OSAxMS45OTJoNzEuMzE0czAtNi43OTItLjg0OS0xMS4w'
    b'MzctNS45NDMtMTAuMTg4LTQuMjQ1LTE2LjEzMSAxMi43MzUtNDQuMTQ3IDEyLjczNS00NC4x'
    b'NDcgNS45NDMtMjYuMzE4IDMuMzk2LTQ3LjU0My0zLjM5Ni0yMS4yMjUtMS42OTgtMjguODY1'
    b'YzEuNjk4LTcuNjQxIDMuNTQyLTM4LjExMiAzLjU0Mi0zOC4xMTJzMTMuMzE4LTMuNTc4IDE0'
    b'LjE2Ny0xMi45MTcgNi4wNjItNDAuNjYxIDYuOTExLTQ5LjE1MSA5LjMzOC00OS42NjUgOS4z'
    b'MzgtNTcuMzA2LTYuNzkyLTUzLjA2MS04LjQ4OS01Ni40NTdjLTEuNjk4LTMuMzk2IDAtMjku'
    b'NzE0LTE2LjEzMS0zNi45My03Ljc1LTMuNDY3LTI4LjMxMy0xNy40MTItMzAuNTYzLTIzLjM0'
    b'N2wtMi45NzItNS4wOTQiIGZpbGw9Im5vbmUiLz4KICA8cGF0aCBkPSJtMTYzMS45MDggMTQz'
    b'Mi4zODMtMy44NTMgNi42MDhzLTMyLjUwOSA2Ljk4LTM2LjU0MiAxNC44MzNjLTMuMjUgNi4z'
    b'My00LjU4MyA0Mi44LTQuNTgzIDQ5LjE2N3MxLjY0NyAzMy4yMTEgMi40OTcgMzcuODhjLjg0'
    b'OSA0LjY2OS41MzEgNS42MjQuMzE4IDkuODY5IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDJk'
    b'NTYiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIg'
    b'c3Ryb2tlLXdpZHRoPSI1LjQyMSIvPgogIDxwYXRoIGQ9Ik0xNjUwLjU1MyAxNTM4Ljc0OWMu'
    b'NDI0IDMuMzk2LS40NTEgMjUuMTQ1IDguNDkgMzkuMDUzIDMuODIxIDUuOTQzIDIwLjUxOSAz'
    b'OC4zMTIgMjQuMTk2IDQyLjQ0OSAyLjIgMi40NzUgNy44NTcgMy40MzcgOS4yODMgNi44MDYg'
    b'Ny4zNzUgMTcuNDMtLjQxNyAzNC41ODMgMTAgMzcuMDgzbDIuOTE3IDEwIiBmaWxsPSJub25l'
    b'IiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdp'
    b'ZHRoPSI0LjkiLz4KICA8cGF0aCBkPSJNMTY3My43NzEgMTQzMi4wNTdjLTEuNzcyIDIuNDUz'
    b'LTEzLjYzNSA5LjU4My0yMC42MjUgOS41ODMtMi41NDcgMC0xLjA0MiA1LjIwOC0yLjE2OSAx'
    b'MS4zNjItMS4xODcgNi40ODItMS4yNzMgNDMuMjk4LS40MjQgNDcuOTY4LjM0NCAxLjg5Ni0u'
    b'MzI1IDIuODY0LS40MjUgOC45MTQiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAwMmQ1NiIgc3Ry'
    b'b2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9IjQuMDgzIi8+CiAgPHBhdGgg'
    b'ZD0ibTE2ODQuODQ3IDE0NzcuNTc1IDQuMzM0IDE3LjAyNyA1Ljk0MyAzMS40MTIgMi4xMjIg'
    b'MTkuMTAyLjQyNSAxNi45NzktLjQyNSAxNC40MzMtMS42OTggMTAuMTg4LTIuMTIyIDkuMzM5'
    b'LTMuODIxIDMwLjU2M2MxMi4zMS0yLjk3MSAyMC40MDktLjA5IDI2LjMxOCA0LjY2OSIgc3R5'
    b'bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMmQ1NjtzdHJva2Utd2lkdGg6NC44OTk4OTk5Njtz'
    b'dHJva2UtbGluZWNhcDpyb3VuZDtzdHJva2UtbGluZWpvaW46cm91bmQ7c3Ryb2tlLW1pdGVy'
    b'bGltaXQ6My44NjM2OTk5MSIvPgogIDxwYXRoIGQ9Im0xNjAzLjU5NiAxNDQ2LjMyNS44MzMg'
    b'Mi45MTdjLTEuMTU4LTYuMzk4IDE5LjM4IDg0LjQxNCA4OS40MjEgMTI2Ljg2M2wzLjM5NiAy'
    b'LjEyNCIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbWl0ZXJsaW1pdD0i'
    b'My44NjQiIHN0cm9rZS13aWR0aD0iNC45Ii8+CiAgPHBhdGggZD0iTTE2MTcuMzQ2IDE0NDIu'
    b'NTc1YzcuMzU2IDIzLjM4IDI5LjM4MSA4MS44MTYgNzkuNjg4IDExMi4zMDVsLjYzNyA0LjI0'
    b'NW0tNjkuNzMzIDIyLjUxOGMxMi45MTcgMi43MDcgMjEuMjQ5IDIuNzA1IDMyLjkxNi0uNDJt'
    b'LTEyLjcwMiA2Ni41NjZjMi41NDMgMTcuNjM5IDUuNjg0IDM4LjcxMiA2LjY0NiA0Mi4wNzgg'
    b'MS42OTggNS45NDMgMy4zOTYgMzUuNjU3IDMuMzk2IDM1LjY1N2wuODQ5IDI4Ljg2NS44NDkg'
    b'MzYuNTA2djQyLjQ0OWMtNi45NzIgNC44NzctMTAuNjMyIDEyLjE1Ni0xMC45ODIgMjEuODM2'
    b'IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2'
    b'NCIgc3Ryb2tlLXdpZHRoPSI0LjkiLz4KICA8cGF0aCBkPSJNMTU3OC4zMjIgMTU1Ni45NjJj'
    b'LTQuMzMzIDYuNTE1LTI1LjcyNi01Ljg1My0yNi44MSAxMi42MDYtLjgzMyAxNC4xODYgMS45'
    b'MTMgMzAuMjE3IDE1LjYzMSAzMS45NzlsMTAuMDk2LTYuNjc4IDIuNzAzLTIuNzA5IiBmaWxs'
    b'PSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9r'
    b'ZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI0LjUxNyIvPgogIDxwYXRoIGQ9'
    b'Ik0xNTY1LjU5NSAxNTQ5LjM5N2MtNS44ODMtOTIuMTUtMy4xNDgtMTcyLjg4MSAxMi4xMzQt'
    b'MjM0LjAwOC00MS4xNDkgNTkuNzQzLTI0LjIyNSAyMzQuMDcyLTI0LjIyNSAyMzQuMDcyeiIg'
    b'ZmlsbD0iI2VlZDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIi8+CiAgPHBhdGggZD0ibTE1ODku'
    b'ODUxIDE1NDkuMzYxLTIuOTcxIDguMDY1Yy03LjY4OSA0LjIwNS0xMC4wNyA0LjQyNy05Ljk4'
    b'NCA0LjQyMiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAyZDU2IiBzdHJva2UtbGluZWpvaW49'
    b'InJvdW5kIiBzdHJva2UtbWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9rZS13aWR0aD0iNS40MjEi'
    b'Lz4KICA8cGF0aCBkPSJNMTU3NS44NjggMTU1OS44NTdzNy41NDUgMjAuMDU0IDEuMzcgMzUu'
    b'MDExIiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1saW5lam9pbj0icm91'
    b'bmQiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI0LjUxNyIvPgog'
    b'IDxwYXRoIGQ9Im0xNTY1LjgwMiAxNTQ5LjkyMiA4LjMzNy4xODRoMy44NjNzMi4zMTggNC41'
    b'MjMtMS4yODggNi4xMTljLTMuNjA1IDEuNTk2LTYuMDY5IDEuNTYxLTYuMDY5IDEuNTYxIiBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0'
    b'cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSIzLjQ4OCIvPgogIDxwYXRo'
    b'IGQ9Ik0xNTY4LjI4IDE2MDAuNDQ4Yy0yLjc4NyAyLjUxOS01LjgyNiAyLjkzOS0xMC45NDQg'
    b'My4zOTYtOS45MDkuODg1LTE5LjgxNy0xMC43NDMtMjIuMTQyLTI3LjU1LTIuNTY5LTE4LjU3'
    b'OC0uMDk0LTI2LjMwOSAxOC4zMTEtMjYuODMyIiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDJk'
    b'NTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSIzLjQ4OCIvPgog'
    b'IDxwYXRoIGQ9Ik0xNTcxLjQ4MSAxNTU3LjYxNWgtMTMuMjExcy03LjAyNiAxLjg3LTcuMzQg'
    b'Ny41ODNjLS41IDkuMDk5LS42NjUgMjEuOTY0IDMuMjUgMjcuMDE5bDMuOTE1IDQuMDQ0IiBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIg'
    b'c3Ryb2tlLXdpZHRoPSIzLjQ4OCIvPgogIDxwYXRoIGQ9Im0xNjE2Ljc5MiAxMzgwLjE4MiAx'
    b'LjE0NiA2Ljg3NS0xLjYyOCAyLjk1LTcuMTQyLS40NzEtOC4zNjgtLjI3N3MtNC42OTItLjQ0'
    b'OS01LjkxNC0uODY4LTUuMjk5LTEuMDY3LTUuMjk5LTEuMDY3LTYuMDU1LTguMDE1LjMxNi0x'
    b'Mi44NmM2LjM3MS00Ljg0NCAxMi45MzQtOC4yNTggMTQuMTY3LTkuMDY0IDEuMjMyLS44MDYg'
    b'MS44NDMtLjU5NiAxLjg0My0uNTk2IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0'
    b'cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI0LjA4MyIvPgogIDxwYXRo'
    b'IGNsaXAtcnVsZT0iZXZlbm9kZCIgZD0ibTE2MTYuNzE3IDEzODEuNjc5LjAwMSA3Ljc3IiBm'
    b'aWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIg'
    b'c3Ryb2tlLXdpZHRoPSIxLjYzMyIvPgogIDxwYXRoIGQ9Ik0xNjE3Ljg0NSAxMzg3LjQ2NHMt'
    b'MS45ODQgNi42NDQtLjkyMSA5Ljc2NyAyLjk2NSAxMS4wMDkgMy4yNzggMTIuMjYxYy4yMTIu'
    b'ODQ5IDEuODM2IDkuNTczIDIuNzU5IDExLjQ2MS45MjMgMS44ODkgMy4wNCA5Ljg4MSA5LjY5'
    b'NSAxMS42NjJzMTQuMDgyLjUzNCAxOC4zMjEtMi4zMTIiIGZpbGw9Im5vbmUiIHN0cm9rZT0i'
    b'IzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9IjMuMjY3'
    b'Ii8+CiAgPHBhdGggZD0iTTE2MzAuNzI2IDE0MTcuMDY3czMuMjM5LTEuMTgxIDQuMzM5LS43'
    b'MTQgNC4yNS44MzYgNC4yNS44MzYgMy45MjMtLjcxNSA1LjIzMi0uMzM5YzEuMzEuMzc1IDMu'
    b'Mzk3LjM4MSA0LjAxNS4zMTFtLTE0Ljk4OSA0LjExMXM3LjczMSAxLjUwOCAxMC45NzIuMTQ1'
    b'bS0uMjU2LTMzLjMyM3M2Ljk3My0yLjg2NyAxMy4wNzUgMS42NDUiIGZpbGw9Im5vbmUiIHN0'
    b'cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9'
    b'IjIuNDUiLz4KICA8cGF0aCBkPSJNMTYzNS40MiAxMzg3LjY2OWMuNTM3IDEuNDYtLjUwMyA1'
    b'LjctMS40MSA3LjM5LS45MDYgMS42OS0xLjE2OSA0Ljc0NC0xLjc0OCA2LjA0My0uNTggMS4y'
    b'OTktMS4zMDkgMy41MS0xLjI3MSA0LjczOXMuMDQzIDEuMTI3IDEuOTMzIDIuMTQ2IDMuMjIy'
    b'LjEzOSA0LjY3Ni0uMjk2YzEuNDU1LS40MzUgMi43NDYtLjg0OSA0LjA1NS0uNDc0IDEuMzEu'
    b'Mzc1IDMuMjA0LS42NSAzLjE3Mi0xLjk4MS0uMDMzLTEuMzMxLS40NDEtMy4yOTUtMS4zMjEt'
    b'NC4wNTdzLTIuNzU5LTEuOTg1LTIuNzU5LTEuOTg1IiBmaWxsPSJub25lIiBzdHJva2U9IiMw'
    b'MDJkNTYiIHN0cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSIxLjk2Ii8+'
    b'CiAgPHBhdGggZD0iTTE2MjIuMzkxIDEzODguNTJjMS4wNTQtLjE1NCA3Ljc0Ny0zLjkwNiAx'
    b'My4zMDUtLjA0IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRlcmxp'
    b'bWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSIyLjQ1Ii8+CiAgPGVsbGlwc2UgY3g9Ii0xNjUy'
    b'LjMzMyIgY3k9Ii0xMzY0LjM1MiIgZmlsbD0iIzAwMmQ1NiIgcng9IjQuNTc0IiByeT0iMS4x'
    b'MzYiIHN0cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Ut'
    b'd2lkdGg9IjEuNjMzIiB0cmFuc2Zvcm09InJvdGF0ZSgtMTc4Ljk5NykiLz4KICA8cGF0aCBk'
    b'PSJNMTYzMS45MDggMTQzMi4zODNjLjI0My4wOS40OTIuMTY0Ljc0OC4yMzIgNi42NTUgMS43'
    b'OCAxNC4wODIuNTM0IDE4LjMyMS0yLjMxMiIgZmlsbD0ibm9uZSIgc3Ryb2tlPSIjMDAyZDU2'
    b'IiBzdHJva2UtbWl0ZXJsaW1pdD0iMy44NjQiIHN0cm9rZS13aWR0aD0iMy4yNjciLz4KICA8'
    b'cGF0aCBkPSJNMTYxNS41MjggMTMzOS4xNjFzLTE3LjM5OSA1LjE1Ny0xNS4yMTIgMTEuOTEz'
    b'YzIuMTg3IDYuNzU3IDMuNzk0IDkuODMzIDUuNDA3IDEyLjA5MyAxLjYxNCAyLjI2IDQuODAz'
    b'IDExLjA2NyA1LjgwMyAxMy41MjYgMSAyLjQ1OC4zOTQgNi45MzQgNC40NDkgNC45MzkgMjMu'
    b'MDI2LTExLjMzMSA3Mi41OTEgOC4yNzggNjEuOTI5IDcuNDIzLTIuODcyLS4yMyAzMi4wODYg'
    b'Ni45OTUgMzcuODE2IDMuMjQ3IDEuMjMyLS44MDYgMy42OTYtMi40MTgtLjMzNS04LjM3NC0y'
    b'LjMwNS0zLjQwNi05LjMxNi0xMi4zMzUtMTQuMjIxLTE2LjcwMy0zLjI0Mi0yLjg4Ny0xMi42'
    b'NTEtOS4wNDctMTUuNDY5LTEzLjc2OC0yLjgxNy00LjcyLTkuNTc4LTguNjY0LTE0LjY3NC05'
    b'LjUyNS01LjA5Ny0uODYxLTE0LjI2Ni0yLjk4My0yMS4yMTEtMi42MzVzLTguOTgtLjI4Mi0x'
    b'Mi42NS0uOTI3YzEuODA3LjMxOS0xNi40Ni0xLjg4LTIxLjYzMi0xLjIwOXoiIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Ut'
    b'd2lkdGg9IjMuMjY1Ii8+CiAgPHBhdGggZD0iTTE2NTcuNTIxIDE3MDUuODFzMTguMzMzIDEx'
    b'LjI0OCA0MC0uNDE5YzIwLjE4Ny0xMC44NjkgMy43NS0yLjA4NCAzLjc1LTIuMDg0bS04Ny4w'
    b'ODUgNXMyMC4yOSA5LjU5NSA0MS4xMjMtMS4yMzkiIGZpbGw9Im5vbmUiIHN0cm9rZT0iIzAw'
    b'MmQ1NiIgc3Ryb2tlLW1pdGVybGltaXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9IjQuOSIvPgog'
    b'IDxlbGxpcHNlIGN4PSItMTc4Ny4xMzQiIGN5PSItMTIxMy4zOCIgZmlsbD0iIzAwMmQ1NiIg'
    b'cng9IjQuODA4IiByeT0iMS4xOTUiIHN0cm9rZT0iIzAwMmQ1NiIgc3Ryb2tlLW1pdGVybGlt'
    b'aXQ9IjMuODY0IiBzdHJva2Utd2lkdGg9IjEuNjMzIiB0cmFuc2Zvcm09InJvdGF0ZSgtMTcz'
    b'Ljk5NikiLz4KICA8cGF0aCBkPSJNMTYyMy43NzIgMTU5My4zMDljMTIuMjkyIDQuNTgyIDMx'
    b'LjI1IDMuMzMyIDQzLjEyNC0uNDE4IiBmaWxsPSJub25lIiBzdHJva2U9IiMwMDJkNTYiIHN0'
    b'cm9rZS1taXRlcmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSI0LjkiLz4KICA8cGF0aCBk'
    b'PSJNMTc3OS44MyAxODM0LjE3N2gxNjguNTQzdjIyLjc0NEgxNzc5LjgzeiIgZmlsbD0iI2Vl'
    b'ZDAwMCIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9IiMwMDJkNTYiIHN0cm9rZS1taXRl'
    b'cmxpbWl0PSIzLjg2NCIgc3Ryb2tlLXdpZHRoPSIuNjgiLz4KICA8cGF0aCBkPSJNMCAyODgw'
    b'aDY5MTJ2MTQ0MEgweiIgZmlsbD0iI2I1MDAyNyIvPgo8L3N2Zz4K', 'US_GA')

US_GA = b64_US_GA
index.append("US_GA")
index.append("United States of America Georgia")
catalog["US_GA"] = US_GA
catalog["United States of America Georgia"] = US_GA
country["United States of America Georgia"] = ('US_GA', '', 1)
lookup["US_GA"] = ('US_GA', '', 'United States of America Georgia', 1)
lookup["Atlanta United States of America Georgia"] = ('US_GA', '', 'United States of America Georgia', 1)
lookup["United States of America Georgia"] = ('US_GA', '', 'United States of America Georgia', 1)
details["US_GA"] = {"continent":"Americas","capital":"Atlanta","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_GA"] = ('US_GA', 'United States of America Georgia', 1)
regional["United States of America Georgia"] = ('US_GA', 'United States of America Georgia', 1)
#----------------------------------------------------------------------
b64_US_GU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LWd1IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2JlMDAyNyIgZmls'
    b'bC1ydWxlPSJldmVub2RkIiBkPSJNMCAwaDY0MHY0ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIj'
    b'M2I1YWEzIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yNS42IDI3LjNoNTg5LjV2NDI4LjRI'
    b'MjUuNnoiLz4KICA8cGF0aCBmaWxsPSIjY2JlMGU1IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0zMTQuNCA0MTMuMmExMCAxMCAwIDAgMCA4LjQuMWMxMzcuOC03My4zIDEzNy44LTI3NC4z'
    b'LjEtMzQ2LjZhMTAgMTAgMCAwIDAtOC43LjJjLTEzNC4zIDczLjQtMTM0LjcgMjcyLjEuMSAz'
    b'NDYuM3oiLz4KICA8cGF0aCBmaWxsPSIjYWRkMmQ5IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9'
    b'Ik0zMTQuNCA0MTYuOWMyIDEuNyA2LjQgMS41IDguNCAwIDEwMS41LTc2IDEwMi0xMjMuMyA5'
    b'Ny42LTEyMy4zaC0yMDFjLTMgMCAxLjggNDguMiA5NSAxMjMuM3oiLz4KICA8cGF0aCBmaWxs'
    b'PSIjZmRmOWExIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yMzUuMyAzMzEuMmEzOS4yIDM5'
    b'LjIgMCAwIDEgMjcuOSAxLjdjNy42IDQgMTIgNCAyMC4yIDQgOC42LjIgMTUuMyA2LjUgMjQu'
    b'NiA2LjggMTcuMS40IDI0LjMgOC45IDExIDktNi4yIDAtMTkuNy00LjMtMjYuMi0zLjQtMTMu'
    b'NiAxLjQtMjIuMiA0LjQtMzUgMTguN2wxNC44IDEwYzEyLjgtNS4xIDE0LjktMTEgMjItMTEu'
    b'MiA4LS4zIDEwLjctNS4yIDIwLTUuMmE5Mi42IDkyLjYgMCAwIDAgMzMtMy4yYzE0LjgtMy40'
    b'IDcuOC0xMy44LTEuMi0xNy41LTcuMy0zLjEtMjAuOC0uMS0yOS4yLTMuMi02LjQtMi41LTEu'
    b'Mi02LjUgMi4zLTcuMyAzLjQtLjcgNy4xLjUgMTEuNCAxLjIgNy43LjYgMTcuNC0uMSAyNC4x'
    b'LTEuMiAxNC0yLjEgMTMuNC02LjIgMjAtNi4zIDUtLjMgOC43LTEuNyAxMi00LjEgNC0yLjcg'
    b'OC4xLTggMTIuOS03LjhsMTIuNy41LTE4IDQwLjQtNTAuNyA1MS43LTI2LjMgMTAtNTcuOC0z'
    b'Ny43LTI5LjEtNDQuNyA0LjctMS4yeiIvPgogIDxwYXRoIGZpbGw9IiMxNzlhM2IiIGZpbGwt'
    b'cnVsZT0iZXZlbm9kZCIgZD0ibTMwMS44IDI5MiAxMTYtLjYgMi0xMC4zcy00LjEtLjYtNy41'
    b'LS44Yy00LjEtLjMtMTEuMyA0LjQtMTYgNC4zLTMuNSAwLTcuMy02LTEwLjctNi02IDAtNi40'
    b'IDUuMy0xMiA1LjUtNC41LS4yLTYuNC0zLjYtMTIuMy0zLjItNiAuMy01LjYgMy43LTEzLjMg'
    b'My41LTEwLjItLjMtMTQuMy05LjEtMjIuNS05LjItMTMuNi0uMi0xNCAxMy0yMy44IDE2Ljd6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZkZjlhMSIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJtMzAx'
    b'LjggMjk0LjQgMTE5LjQtLjZ2LTMuMmwtMTIyLjIuNiAyLjcgMy4yeiIvPgogIDxwYXRoIGZp'
    b'bGw9IiNhNzkyNzAiIGZpbGwtcnVsZT0iZXZlbm9kZCIgZD0iTTM1MC44IDMzMC4zYzEuOSA3'
    b'IDMuOCA5LjQgMTEuMiAxMS4zIDcuMyAxLjcgMTguNS01LjQgMTEuNi0xMi4zLTYuNi02LjQt'
    b'MTMuNi04LTE5LjUtMTMuOC0xMi41LTEyLjMtMzEuMy00Mi41LTMxLjMtNjMuOCAwLTE4LjMt'
    b'MS44LTU1LjgtMS44LTkxLjMgMC0yLjMtNyA2LjQtNyA4LjguNCAzMS4zLjQgNTUgMS42IDg2'
    b'LjYgMiAyMy4xIDEzIDM4LjcgMjIuNyA1Mi43IDQuMyA2LjggMTAuNiAxNCAxMi41IDIxLjh6'
    b'Ii8+CiAgPHRleHQgeD0iNDY1LjEiIHk9IjI2OS41IiBmaWxsPSIjYmQwNzI4IiBzdHJva2U9'
    b'IiNmZmYiIHN0cm9rZS13aWR0aD0iMS42IiBmb250LWZhbWlseT0iaGVsdmV0aWNhIiBmb250'
    b'LXNpemU9IjI1LjYiIHRyYW5zZm9ybT0ibWF0cml4KDEuMzMgMCAwIDEuMzMgLTM2MyAtMTA4'
    b'KSI+PHRzcGFuPkc8L3RzcGFuPjwvdGV4dD4KICA8dGV4dCB4PSI0ODguMSIgeT0iMjY5LjYi'
    b'IGZpbGw9IiNiZDA3MjgiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIxLjYiIGZvbnQt'
    b'ZmFtaWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIgdHJhbnNmb3JtPSJtYXRyaXgo'
    b'MS4zMyAwIDAgMS4zMyAtMzYzIC0xMDgpIj48dHNwYW4+VTwvdHNwYW4+PC90ZXh0PgogIDx0'
    b'ZXh0IHg9IjUxNiIgeT0iMjY5LjYiIGZpbGw9IiNiZDA3MjgiIHN0cm9rZT0iI2ZmZiIgc3Ry'
    b'b2tlLXdpZHRoPSIxLjYiIGZvbnQtZmFtaWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUu'
    b'NiIgdHJhbnNmb3JtPSJtYXRyaXgoMS4zMyAwIDAgMS4zMyAtMzYzIC0xMDgpIj48dHNwYW4+'
    b'QTwvdHNwYW4+PC90ZXh0PgogIDx0ZXh0IHg9IjUzOS41IiB5PSIyNjkuNSIgZmlsbD0iI2Jk'
    b'MDcyOCIgc3Ryb2tlPSIjZmZmIiBzdHJva2Utd2lkdGg9IjEuNiIgZm9udC1mYW1pbHk9Imhl'
    b'bHZldGljYSIgZm9udC1zaXplPSIyNS42IiB0cmFuc2Zvcm09Im1hdHJpeCgxLjMzIDAgMCAx'
    b'LjMzIC0zNjMgLTEwOCkiPjx0c3Bhbj5NPC90c3Bhbj48L3RleHQ+CiAgPHBhdGggZmlsbD0i'
    b'IzIzOWU0NiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjU5LjYgMTYwLjljLTEuNSAzIDMu'
    b'Ni0uOSA0LjgtMS4zIDYuNy0yLjQgOS4zLTEwLjggMjAuOC01LjcgOSAzLjkgMjEuMSAxLjYg'
    b'MTQuOCA1LjYtNy44IDQuNy0yMy41IDkuOS0yMy44IDMzLjIgMS4zIDIuMiAxLjQgMS45IDIu'
    b'NS0uNiAyLjQtNS40IDEzLjctMjAuMSAxOS4zLTE4LjkgMi4zLjYgOC45LTYuNyA5LTQuNi43'
    b'IDUuOC05IDE3LjYtOC44IDMzLjMgMCAzLjcgNC41IDQuOSA2LjYgMi4zIDIuMi0yLjMgMy40'
    b'LTQuNiA3LjItNy42IDYuNi01LjQgNC44LTI4LjYgNS42LTI3LjUgNC43IDYgNS40IDIzLjMg'
    b'MTIuNCAzMC4zIDUuOSA1LjkgMTAuNiAzIDkuMy01LTIuNS0xNi40LTEwLjItMTEuNy0xMy45'
    b'LTI4LjYtLjgtMy4zLTEtNi4yIDMuNC00LjkgNS4zIDEuNiA4LjUgNCAxMi40IDEwIDQgNS44'
    b'IDExLjQgMTEuMyAxNS43IDE0LjYgNy41IDUuOCAxMC4yLjggNi42LTYuNmEzOS42IDM5LjYg'
    b'MCAwIDAtMjEtMTguMmMtNi4yLTIuMi04LjQtMi40LTEzLjgtMy40LTEuNS0uMy0zLTMuNC0u'
    b'NC01LjFhNDIuNSA0Mi41IDAgMCAxIDE5LjYtNy43YzYuNy0uMiAxMiA1LjIgMTYuNyA2LjYg'
    b'OS40IDIuNCA5LjQtMy41IDUuMi04LTMuNC0zLjctMTAuNi0xMC0xNy4zLTkuMS0xMy41IDEu'
    b'Ny0xMi42IDEuMy0yMSA2LjgtMyAxLjgtNi40IDMuOC01LjEgMS42IDMtNS41LjItNC41IDQu'
    b'OS0xMC4xIDMuNi00IDYuMy03IDEwLTggMy40LS45IDgtNC41IDkuMy02LjQgMy40LTQuNi41'
    b'LTcuMy00LjctNS43LTQuNiAxLjItNyA0LjItMTAgNS03LjQgMi40LTEzLjMgMTktMTQuMiAy'
    b'MS40LTEuMSAyLjgtMi40IDEuNC0yLjItMSAxLTExLjcgMi0zMS41LTItMzkuNi02LjQtMTIt'
    b'NS44LTYuNC04LjItLjctMy42IDktMi4zIDE3LjUgMCAyNi4zIDEgNC40IDQuNiA5LjQgNS4z'
    b'IDEyLjkuNSAyLjctMS42LS44LTIuOC0yLjUtMy45LTYtNi44LTEwLTEzLjItMTMuM2EzNS4z'
    b'IDM1LjMgMCAwIDAtMjAuMi0yYy0xLjguNiAyIDMuMiAzLjUgNC40IDQuMyAzLjQgMTIuNCA0'
    b'LjUgMTggNy45IDQuNiAyLjkgOC4yIDQuNyA5LjggOC43LjYgMyAxLjYgNy40LS40IDcuMy01'
    b'LjEtLjMtMTMtNC44LTI5LjQtMy04LjQgMS4yLTE1LjYgOC4zLTIwLjMgMTYuOXoiLz4KICA8'
    b'cGF0aCBmaWxsLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0yOTUuMyAzMTAuNmg0Ljd2Ny45aC00Ljd6'
    b'Ii8+CiAgPHBhdGggZmlsbD0iI2ZkZjlmZiIgZmlsbC1ydWxlPSJldmVub2RkIiBkPSJNMjcx'
    b'LjcgMjU3LjljMTguOCAyNiA0OSA0MS4yIDQ5LjYgNTNoLTU4LjhjMTMuNS0xNi4yIDIxLjgt'
    b'MjcuMiA5LjItNTN6Ii8+CiAgPHBhdGggZmlsbD0iI2E2ODg2MSIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNMjU0LjYgMzExLjVjMjUuNiA1LjcgNTYuMSA4LjkgNzUuNi0uOC4yIDUuNy02'
    b'LjMgMTQtMTEuNyAxNGgtNDljNS43LS45IDktMi42IDE4LjItM2wtMjYgLjJjLTMgLjEtOC03'
    b'LjYtNy4xLTEwLjR6Ii8+CiAgPHBhdGggZmlsbD0iI2JlMDAyNyIgZmlsbC1ydWxlPSJldmVu'
    b'b2RkIiBkPSJNMzEyLjYgNDI1YzIuNiAxLjUgNi43IDEuNCA5IC4yIDE0Ny44LTc4LjcgMTQ3'
    b'LjktMjk0LjQuMi0zNzJhMTAuNyAxMC43IDAgMCAwLTkuNC4yYy0xNDQgNzguOC0xNDQuNCAy'
    b'OTIgLjIgMzcxLjd6bS43LTE3LjdhOS4zIDkuMyAwIDAgMCA4IC4xYzEyMy42LTcyLjggMTI1'
    b'LjEtMjY1LjEuMS0zMzQtMi40LTEuOC01LjktMS4yLTguMyAwLTExOC40IDcwLjEtMTI1IDI1'
    b'NC41LjIgMzMzLjl6Ii8+CiAgPHBhdGggZmlsbD0iI2JkMDcyOCIgZD0iTTI2OC44IDIyNS40'
    b'cTMuNCAwIDYgMS40IDMuNSAxLjggNC4zIDYuNkgyNzZxLS42LTIuNi0yLjYtNC0xLjgtMS4y'
    b'LTQuNy0xLjItMy4zIDAtNS43IDIuNy0yLjMgMi41LTIuMyA3LjYgMCA0LjIgMS45IDcgMiAy'
    b'LjcgNi4zIDIuNyAzLjMgMCA1LjQtMS45IDIuMy0xLjkgMi4zLTYuMkgyNjl2LTIuN2gxMC42'
    b'djEzaC0yLjFsLS44LTMuMnEtMS42IDEuOS0zIDIuNy0yLjIgMS4yLTUuNSAxLjItNC4zIDAt'
    b'Ny41LTIuOC0zLjQtMy42LTMuNC05Ljd0My4zLTkuN3EzLjItMy41IDguMi0zLjV6bS0uNiAw'
    b'eiIgYXJpYS1sYWJlbD0iRyIgZm9udC1mYW1pbHk9ImhlbHZldGljYSIgZm9udC1zaXplPSIy'
    b'NS42Ii8+CiAgPHBhdGggZmlsbD0iI2JkMDcyOCIgZD0iTTI5Mi40IDIyNi4xdjE1LjJxMCAy'
    b'LjYgMSA0LjMgMS40IDIuNyA1IDIuNyA0LjEgMCA1LjctMi44LjgtMS42LjgtNC4yVjIyNmgz'
    b'LjR2MTMuOHEwIDQuNC0xLjQgNy0yLjEgNC4zLTguMiA0LjMtNi4zIDAtOC41LTQuNC0xLjIt'
    b'Mi41LTEuMi02LjlWMjI2em02LjMgMHoiIGFyaWEtbGFiZWw9IlUiIGZvbnQtZmFtaWx5PSJo'
    b'ZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIvPgogIDxwYXRoIGZpbGw9IiNiZDA3MjgiIGQ9'
    b'Im0zMzguNCAyNDAuNS0zLjctMTAuNy00IDEwLjd6TTMzMyAyMjZoMy43bDkgMjQuNWgtMy44'
    b'bC0yLjQtNy4zaC05LjdsLTIuNyA3LjNoLTMuM3oiIGFyaWEtbGFiZWw9IkEiIGZvbnQtZmFt'
    b'aWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIvPgogIDxwYXRoIGZpbGw9IiNiZDA3'
    b'MjgiIGQ9Ik0zNTcgMjI2aDQuOWw2LjkgMjAuNyA3LTIwLjdoNC43djI0LjRoLTMuMnYtMjAu'
    b'NmwtNyAyMC42aC0zLjFsLTctMjAuNnYyMC42SDM1N3oiIGFyaWEtbGFiZWw9Ik0iIGZvbnQt'
    b'ZmFtaWx5PSJoZWx2ZXRpY2EiIGZvbnQtc2l6ZT0iMjUuNiIvPgo8L3N2Zz4K', 'US_GU')

US_GU = b64_US_GU
index.append("US_GU")
index.append("United States of America Guam")
catalog["US_GU"] = US_GU
catalog["United States of America Guam"] = US_GU
country["United States of America Guam"] = ('US_GU', '', 1)
lookup["US_GU"] = ('US_GU', '', 'United States of America Guam', 1)
lookup["Hagåtña United States of America Guam"] = ('US_GU', '', 'United States of America Guam', 1)
lookup["United States of America Guam"] = ('US_GU', '', 'United States of America Guam', 1)
details["US_GU"] = {"continent":"Americas","capital":"Hagåtña","currency":"","web":"","lang":"","tz":"+10:00","altname":""}
regional["US_GU"] = ('US_GU', 'United States of America Guam', 1)
regional["United States of America Guam"] = ('US_GU', 'United States of America Guam', 1)
#----------------------------------------------------------------------
b64_US_HI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMjAwIiBo'
    b'ZWlnaHQ9IjYwMCIgdmlld0JveD0iMCAwIDQ4IDI0IiBmaWxsPSIjMDEyMTY5Ij4NCjxjbGlw'
    b'UGF0aCBpZD0iYzEiPjxwYXRoIGQ9Ik0wIDBIMjRWMTRIMHoiLz48L2NsaXBQYXRoPg0KPGNs'
    b'aXBQYXRoIGlkPSJjMiI+PHBhdGggZD0iTTAgMFY2SDIyVjEySDIxek0yMSAwSDEwLjVWMTNI'
    b'MFYxMnoiLz48L2NsaXBQYXRoPg0KPHBhdGggZD0iTTAgMEg0OFYyNEgweiIvPg0KPHBhdGgg'
    b'ZD0iTTAgMCAyOCAxNk0yMSAwIDAgMTIiIHN0cm9rZT0iI2ZmZiIgc3Ryb2tlLXdpZHRoPSIy'
    b'LjQiIGNsaXAtcGF0aD0idXJsKCNjMSkiLz4NCjxwYXRoIGQ9Ik0wIDAgMjggMTZNMjEgMCAw'
    b'IDEyIiBzdHJva2U9IiNjODEwMmUiIHN0cm9rZS13aWR0aD0iMS42IiBjbGlwLXBhdGg9InVy'
    b'bCgjYzIpIi8+DQo8cGF0aCBkPSJNMTAuNSAwVjE0TTAgNkgyNCIgc3Ryb2tlPSIjZmZmIiBz'
    b'dHJva2Utd2lkdGg9IjQiLz4NCjxwYXRoIGQ9Ik00OCAwdjRIMjJsLTEtMVYwem0wIDl2NEgy'
    b'MVY5em0wIDl2Nkgwdi02eiIgZmlsbD0iI2ZmZiIvPg0KPHBhdGggZD0iTTQ4IDN2NC4ySDB2'
    b'LTIuNGgyMVYzem0wIDl2M0gwdi0zem0wIDl2M0gwdi0zek05LjMgMGgyLjR2MTNIOS4zeiIg'
    b'ZmlsbD0iI2M4MTAyZSIvPg0KPHBhdGggZD0iTTQ4IDZ2Mi41SDIxVjZ6Ii8+DQo8L3N2Zz4=', 'US_HI')

US_HI = b64_US_HI
index.append("US_HI")
index.append("United States of America Hawaii")
catalog["US_HI"] = US_HI
catalog["United States of America Hawaii"] = US_HI
country["United States of America Hawaii"] = ('US_HI', '', 1)
lookup["US_HI"] = ('US_HI', '', 'United States of America Hawaii', 1)
lookup["Honolulu United States of America Hawaii"] = ('US_HI', '', 'United States of America Hawaii', 1)
lookup["United States of America Hawaii"] = ('US_HI', '', 'United States of America Hawaii', 1)
details["US_HI"] = {"continent":"Americas","capital":"Honolulu","currency":"","web":"","lang":"","tz":"-10:00","altname":""}
regional["US_HI"] = ('US_HI', 'United States of America Hawaii', 1)
regional["United States of America Hawaii"] = ('US_HI', 'United States of America Hawaii', 1)
#----------------------------------------------------------------------
b64_US_IA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4Mzg3IgogICB3aWR0aD0i'
    b'MTUwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSW93YS5zdmcucG5nIgogICB4bWxuczppbmtzY2FwZT0i'
    b'aHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1sbnM6'
    b'c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlwb2Rp'
    b'LTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIK'
    b'ICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9Imh0'
    b'dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzODM5MSIg'
    b'Lz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzgzODkiCiAgICAg'
    b'cGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAgIGJv'
    b'cmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAgIGlu'
    b'a3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2Fy'
    b'ZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAgaW5r'
    b'c2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnODM5MyI+CiAgICA8aW1hZ2UKICAgICAg'
    b'IHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZlQXNwZWN0'
    b'UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGltaXplUXVh'
    b'bGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxpVkJPUncw'
    b'S0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RCVFVFQUFMR1BD'
    b'L3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3BnQUFBNm1B'
    b'QUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQWEKNGtsRVFWUjQydTJjWjBB'
    b'VTE5N3d6OHoyd3U2eTdNSlNscVV1eUVwSHFnZ0dzR0RYR0RYMkdFdU1KVEdKcG1paUpqSEd4'
    b'TVFZZTRrYQpZNnlJRlZGRVJVQUJCZW05TGt2YjN1dnM3dk5oYjdqR21QdSs5M21lOTRxdjgv'
    b'dkFCL2JNbnRuem0vT2ZjLzduekVCazNsdmdQMHZSCjFjOGpRM25nLzBlTTViVmRNZFAvdzVY'
    b'Q0FPVWxCMVdJS2tSQkZhS2dDbEdGS0toQ0ZGUWhDcW9RVllpQ0trUkJGYUtnQ2xHRktLaEMK'
    b'RkZRaENxcncxUVg3NnZ6VTdzWXFzOUVBUWNDS0lJNy9ZSEE0R01hNCtmQkpWQnFxY0VoanQ5'
    b'dXI3MTN6ajBpZ09yUCsrcWxFMUNIdgpFeUpta3hPVHpYVDNSaFgrdjZXMk1OZGlOakhkdVZR'
    b'NkU3RllERnFsVHFYQVlIRVlMSTRuaU1JVHljODlxakwvY2toaUJvRk1RU3htCnRXekFaa1dJ'
    b'WktldStnb3NEazhnVTAwR0hRVEJHQ3hPSmUxWERQUmk4WGk2aXh2RHpSTlYrRDlGSmVrVEM5'
    b'dkV3bGFwcUVNcTZqRG8KTkFHUkNSeS9ZQmlHdmZpaG91WWFzMEh2eFErdHZwOFROaXFUUUth'
    b'MGxCZEJNQ1l3ZWlRRVFVOS9qMFl1WVhwNEU4Z1V1ODFXbkgyYwo3TVJndW5PeEhvVFdpbUtK'
    b'cUIyQ1lBd1dpeWRTN01BZUVKbUltRTBjM3lCWm4xQXA2WVV4V0RjZW4wQ21vQXIvRFhwYjZ5'
    b'WGRiVGFiCjdlejJkVmdjM2lNZ2hPYmlwbEZJVFhvTjFablZYbDNXWGxXS0l4QWZYdm1OVEhm'
    b'RzRRaEduUm94bThUZGJReFhqNkRZVklOV1haeDkKYk9UMFArM0pFd3ZiL01KaUFRQTlyWFZl'
    b'L0ZBYWl5TnNlTkphVVd5eldiRTRBb3pGbW5RYXJVS0dKUkNMc280aVpqUEhMeGdBNE9FLwpq'
    b'QmNTWFpaek9uN1NYQnlCaENyOFZ5QVdjLzJEdk1vN1Z6cHF5dWdzRHBGQzR3YUhCOFdtY0lN'
    b'amZFTkgzRDkvbUJjU3FaYUxSWTNWCkdCek9ZakxackFpUlFqWHFOVFlFNld0dndPSUpCbzBx'
    b'ZGZhS3p0ckhQc05qL01NVFJNMDFYdnpRd2UvSFlMRUlZc2JoaVZiRUloYTIKWHRyOU9ZWE9K'
    b'Tk1ZYXBrWWl5Y2daaE9lU0tJd21FYXRCb3NqRUVoVWswNXJzMWxwTEk2b3BVYlJMOXI5em1R'
    b'bkpqdml0Y2xoS1JPSQpGQ2RVNFo5UXl3WnlEbS92YWE1bHNOMnRDRUpsdUxSVmxqQTVYamFi'
    b'Rll2RFYrWmZGbmUxUWhBc0VYWDRESStKU3A5ZWtaZUZ3ZUdGCjlVK3NpSVZJb2ZXSkdta3Vy'
    b'bmdpdWFIMERoWlA0QWFIeTNvNjNmMkgxVCs4RGNBL0ZSSXBUanFsbk9yTWtvbzZsT0plQW9s'
    b'Q290SzYKRzZ2Y2ZBS3hPTHhjSldkeXVKTHV0cURZRkFpQ1hiMERZQXhHM2k5cXJTaFdTZnU3'
    b'R3lwZFBIbkFEc3B2WmwzWStiRmZXRnhVeHJTaAo1aEtEWTBUK2g2dDg2ODBVZHpjR0FJQkFw'
    b'ZzRmT1M0a0liMjJNQmVEeFE1TFRQY1JSS3RsWWtsM081dnJqOFVUdWhzcmNYaUNGVUZxCkMy'
    b'K0ltcXBkdlFQeEJHTGNoRG5TM2k0OGtVUWdrblZxQlk1QVZJcDdsWkkrT3R2ZHFGVnpmSU1r'
    b'b25ZMjEyK3dPclBKWU5Db0VZdkoKb0ZVL3ljdEdMQ1lzSG0vUzZ6d0RCQU9kemRQV2ZxbVc5'
    b'cWZQWDZNVTk0VWtwbmZWVlhUVVBOSW9wSXAra1VtdnhaUElWSVlMWWpGMwoxWmQ3OFVOeEJL'
    b'S3cva25XRDU5MDFEekNFNGhzYjM4SSt0UEVHdWtUcXc2ZGZZVVVEdmFTNkxFem9qS21jWHlE'
    b'elNaOTNNUTNwNjdaCnFwYUplWUlvblZJdTdlbGtzRGtFRWtVcDZRVjJ1Nk0xRTZZc01HalZX'
    b'RHdoWThGN1BjMDFXRHlobzdyTW9GVkZqSjVrMEtqMGFpV2IKNno4NHFGRkorakU0dkU0cDB5'
    b'aWs5US95Y0VTU2NxQjM1a2M3ZENxNWl3ZFByMUhwVlBJcmV6WmpjZmhITjg1aWNUaVRYanZR'
    b'MlVJawpVKzAyRzVubWpNWGl1cHVxWEhrQlJJcVQyYWp2YnF6MEQwL0FZTEIxRC9MdS9QWXpq'
    b'Y1hoK0FZTjF2V0tLaHdFaHlkd2ZJTm9McTRBCkFKNGd5c00vWkhqeTJORnozbUc0ZVlTbFRx'
    b'UXlYR3J1NXppN2VWb1JwT2IrRFVWL040bEtrNHJhVStlc01PcTBlQks1dDYzZTB6OEUKZzhO'
    b'emZQbjlIVTNPYnA1V3hHTFVhcG9lRmZoSHhFdEVIWVhuajdoNDhHUTlYU05udkdYUUtBdk9I'
    b'VEpvVkpWM3JpQm1ZMUJzYW4xSgp2bWVBUU5qd2hFU2wyV3cyRXBYVzAxTEg1SGlaalFZaXhZ'
    b'bmg2cUZUeXp1cXkzeERZM0VFb2tHcmt2VUtPYjU4YVUvSGs5dlpkQmFICnllRytLSVZET3NI'
    b'bW1PZjVoc1p5ZlBncGJ5emJuRjBaRUpub3hnc01pRXpVS0NSS1NTL2J5Ky9lMllNRUV0bHV0'
    b'M2tGRG04b3ZXUFUKcWhpdW5uVkZ0ejRaRzdnMm5yVnRUcUpScisyc0sxZExCd0FFOWJVM0pr'
    b'eWVwMWNyTHV6Y3dBMEtiMzVjU0tFNzh3VFJuYldQbG4vLwpPNEZFbWI5NXY5bG9HREZ1Sm9K'
    b'WUZtODc1aEVnY09YNnpmbHNONTVJTm1oVXI4MWRGUkNWS0JWMTlMVFV6dnQ4Yi9MTXQ0Tkdw'
    b'THkxCjdSak54ZTBGdGhMME1qNFcwOXRhcjljb245ek9wckU0TEUrZmdyTUgvY0xqQjdwYXpB'
    b'WmR4c0wzaVJScVoxM0YxYjFiN0hiNzJNVWYKK0liRmFSU1NlNmYzRVVoVUdzc3RQSFhpeFYy'
    b'ZnNiMzgycW9lY255RFpiMWQ3KzdPNGdtaW44bm1QRE81QkFDWURUcHBUNmViRHgrRAp4Vm5N'
    b'Umd3R0MyT2VIUXlpajhYODMrSVJFTkpWVjI3VWFibkI0VDB0dFZOV2I3VWlGZy8vRUF3Vzkr'
    b'akdPYTFTTGhHMnJ0bC85YXZyCkRla0wxbXJrNHNlNTU5bGNmN05SSDVZNm9mVGE2Y0RvNUw3'
    b'MlJwYW5iMTk3WThhQ3RjLzRBd0Q4MVI4QUFFK2llQVFJTUZnY0FBQ0gKSi83VjM0dmlaVjJw'
    b'Nkd0ck1CdjFkMy9meDQ4WmRYemprcjYyQnExQ0dwczUyM0UzRFlnYXlSTkVrMmtNREJibjZ1'
    b'MVBZN3JxVklxTQpSZTkzMVpiamlNU2EremwrNFhIeS91NllNVE15RnI3L3NtZUFYMWFGYWZO'
    b'V0F3Q3NpS1U0Kzdpc3Q4c083RDB0dFErdm5Ld3V1Slp6CmFEdGlOZzJXOU9LSGNmeUN3MU1u'
    b'U0VXZGFwbjRTZjdscEdtTHJZaGw2cHF0Y3pmdEFTOC9RMXFoeVl3VWxqUmZ2RjZlZDY5T3Fk'
    b'SS8KL1pHNy96QVNsVzQyNkYwOGVLbXpsbk44K0U0dXJvakZqQ09RTURpY0k5ejlJeXJDTUpY'
    b'aHduVDNWdlIzUDhtL2xENS9yVkxja3pyNwpuYXdmUGozMTVTcXpVZit5S3h4Q2s0cG5LSy9x'
    b'L0dKSE5neERqeXM3WGRtMC9jZnZwQ1FHRVFuL2RPUEpIMTVibUNzV3RqV1gzNDk0CmJZcC9S'
    b'SUlUMDlValFNQmd1eU1XQzA4UWhaaE5kY1czQmpxYSt0b2JGUDBpclZMbUZUZzhmdExjMEZI'
    b'akxTYWpoMytJUXRKNys5ZWYKQkVsai9yZXlMYS82dlBDWk1lR2VvL25qMDhKeThxcE9aNWY0'
    b'Y0ZreXVkYmJpK1h0NVRKWWhrU2xFeWxPR3JuWXFOUDJ0VFhvMVlycQplOWQ2Vyt0YnlvdTR3'
    b'ZUhjWWVHMWhUZkRVaVp3ZklQNE1ja2FoU1JoOHJ5Z0VTa2QxYVgxRDI0UGRMWXczRHlTWnl3'
    b'aFUrbTNqdi9BCkU4UlE2RXhVNGYrbVFnaUNxdXFFRmRXZHpXMEROcHU5b3JxcnRrSDA4ZG9K'
    b'ZE5xZlZnUTV2a0U4UWZTam5MT2VnUUt6VWQ5V1dRSUEKc0pnTVVsR0hrek03TW0wS0RHUCtL'
    b'TW12ekw4c2JLaGtlZnJ3UWlKOWhzZVlEYnFxdTFjZjM4cnlqMGhvS3IzTEUwVC96OWVWMEtu'
    b'OQpueGlWRVBTa1JoZ2I2ZXZLb2ltVU9zUnE0N2pTLzFyTTJjMXJ4YTd6U2RNVzk3YlZCNDFJ'
    b'TVJ0MFJDcE4wdDFlZWVmeW9EOEFRSDk3ClU5ekVOOWxjUDVxTEc5UGR1N0hzYmxuT21ZR3VG'
    b'a0ZTUmxQWlBaL1FHTXZmM0JRUnhLWlU2YzBXWk1nMjFOQmQ4bzBLODNGM294LzUKN2I2aita'
    b'ak9GRHp1K1dmTDl2SmxlL2x1K0xWQXA1YWYyTFJNMHQwR1krQW50eStWMzhxS0hqUERVY1pt'
    b'cytZYzNqNzJyUThmM1RnNwowTmxNSkR0eC9JTGRmUGhVT2pOKzBsdzYyeDJMd3p0S3RuYUk4'
    b'd3ZyaWt0YmFocEVQWDBLQkxHT1NnelM2ODJOclgyVHhrUkFFUFQ5Cmx0bFAzNUpSaGM4bi8z'
    b'NzlaOXN1MEp4STMyK1ozU1dTN3R5WFN5VVQvdlVoSkNjNnlZbit3Uzk1aU1YY1hsVjY1OVNl'
    b'ckI4KzBhc1YKQ1pQblkzQjRMMzRvc050THI1N3FxSDJjdWV4alIwcnphVlJxL1ltenhXY3Zs'
    b'Y3JrMnZnWS82czNLOGVuaFVVTTkrNGJVSTZJOE50MQo4R1pzbEIrRlREaDY2ajdYazdsaDlR'
    b'UlU0ZC9TME55N2Z1dTV3b2ROTXlhTjBPbU5QbHlXRTVVSUFQRHpjWDJtcE0xbWIyenBMUzVy'
    b'CkxTbHY2KzZSN2Q0Mkx6alFIUUNBeGVINU1jbjhtT1R1eHNycmg3YjN0dFl6M2IzOUl4UDh3'
    b'dUpjUEgwNGZzRU5EL09qTXFZUDdscVQKeWpRNzl1UTB0UFRWTllyaW92d3BaRUxmZ0hMeitx'
    b'bVZ0VUtaUWh2b3g2bHI3Q0dUQ2M1MHlzaDQvdDVmOG4vWWYzUEptNk5ZTGtObAp5WEFJNVVn'
    b'dGlQWHJINi9tM0s1cWJ1MWZPaitsczFzcTdKR1BUZ3ErZGEvTzA5MTUzNDRGWEk5L0RCb2ZW'
    b'M2FjdlZSNjRlcmpBRjlYCnZqL24rSmtpQUlDWEJ6UDM3QWUrM3V4bnU1ZWtyNjJ5cEtlbEZv'
    b'dkgwOW51N1ZXbENaUG5BMkQzajBnd21pd0hqdC81OXVlY0FGL1gKa1hGOFBCNTd0NmlCUWla'
    b'TXk0eEdyTFlkUDE4M1c2eFdxdzFCckdZTGdzZGhRME84SGozcEFBQjhzbmJpeG5XVC8vb1RY'
    b'a2lPZEtqMApRb1BSTW1IT1RxWXpOU2JjZDBKR3VLaFhNU0xDcjdOYmxwMVQ4YzNHbWRNblJE'
    b'dGkzZkV6UmNkT0Yvcjd1SVlMdkJWSzNZNHZacDIvCjhnaUdJWnZOTHVxVlo3eiszWWs5UzVO'
    b'aUE1LytaanJiUFNwaldsVEdOQUNBM1daamVmb1czeXRtRFVzNTlmM2xVMWtQUmIxeUFFQmwK'
    b'cmZDN3piTnJHMFI5QThxVXhPQ3RPeThUOE5qa2VIN2FLRUZDalA4UEIyNENBTmd1VGt3R1JS'
    b'RGtlZWxHaFZpcVJnUHBzMnpla1YxYQowUzRJOXJRZ1ZrR3c1NDZmYzF4WnRKV0xYM3QzU1Rx'
    b'WmhGZXA5VDhjdUhucXdnTUNIc2YxWkk1UEN5TVNjRmdzL043RzM5Y3N6ZUI1CnNUcUVFZ0JB'
    b'MzRCeStxTGREY1hibWM3UG54NUFNSHkzSHJsZWptazluOVVsa2owZGszODhjUE51VVlNemc1'
    b'SjdwMmJGd3RGdnowdmgKdU5KMWV0T0dyZWVLU3BwaEdOTHFUQUcrcmo3ZTdIVXJ4czJhR210'
    b'QnJEZ3NCZzJrL3h4SzhDSS9zQ0JXQU1Ea3NaSGR2Zks0S0w5UAoxazUwM0c5T1h5ejU5T3NM'
    b'U2JHQjd5MGZNMm5lcmcyck0rdWFlbE1UZ3g4OGFpa3VhN0ZhYmUxZEVqcU56UE55Y1hkallM'
    b'SHdxUU1yCi9xNXhUMThzV2Y3aDhjS3Jud1lGdUo4NFczU3ZxRkVzVlp2TUNBREFqVTNqKzNO'
    b'R1JQcWxKZ1kvZk55YVYxQmJXdDdlSlpLNXNtZ2EKclFFQWdNVmliRFpiYjcrU1RNTERNS3pW'
    b'R2Jlc24vYmh1K1BSUUFvQUFGMGltY01mQUtCREtEbTViM21nbjV1alY2MWMveXVKaUY4OApK'
    b'M25IbnB4cEU2TFZHb1BGWXIyZVY5WGFQbEQycEoxSXdJMk01NDlKSGU3dXh1Z1hxMjdrVjhm'
    b'SEJNeGNzc2RzdHU3WlB0K1B4MzY2Cm4zMjNOK2ZMblZjbWo0ME1GM2dEQUpZdkdMMTh3ZWlu'
    b'VDZQc1NmdngwMFdiZDJTck5BYXBUQU1BV0R3bk9UN2FQeXFNTi9lZGd3a3gKQVZhYjdiZnpE'
    b'd0w5T0RhYnJhWkJkTGU0NFJtRnIyNGdIWnhtc1YyY2JwejV3SmxCQVFDY3YvTG82S2tDdVZL'
    b'M2VrbTZNNE9DeDJGSwpIcmRTS1lTdmZyeUNJTFpIbFIxOGYwN0VjTzloZ1I1Nm8zbjNrVHla'
    b'WERzeUxoQ0NRRkZKczhGb3lYaDl4OFhqcXgyMlpITHQrcTNuCnJ0MTZRaVJndjlrMDg2OGoy'
    b'K3ljOHQySDh6cTdwVzVzMnNKWkk3L2NlZG54MGUyQ3VxOC9uYUhUbXp1RjBqR3B3LzE5WEFj'
    b'a0tyc2QKc0poT2JaM2k0dElXaFZMbk9OdFhYU0dQeTJJNlUrUUtYWmlBNjh5Z05MZjFmL3ps'
    b'K1R1RjlVWFhQcHUzOHFESmpPajBKaThQNXI1agpkNUxqZ3pMVHd3UkJudndBam1PQVdsalMv'
    b'TTVISjVMaitONWVMdFgxM1o3dXpnYWpCUURRTDFhbFRmLzIrdWtQMkM1T2M1YnZqNC8yClg3'
    b'NXdOQmFENFQyVlpYWE1ZUmFzT3R6ZUtVNU5DaDRSNFhzanYzcENSdmoyM2RjY1VhRzdWNzUw'
    b'M2JFT29kUnNRYTdrUG5GbVVQUUcKczFLbG16Z21Za1NrWDhHRHhxcTY3dFNrWUZRaElPQ3hl'
    b'ZWZYZjdqNVRHbDVlM2pxUmljcWNjUHFpVFVOM1RLRk5zRFg3ZEtOaXNwYQpZV1FvNzVlZmxz'
    b'UkUrQTRlWlRJam4yKy9lRHE3UktjekVRaFlIcGRWVk5xY1Brcnd4cFRZYzVmTEFBQXdERy9l'
    b'a1MwVXlmeDhYQlZLClhVVjFaKzdaRDUrcCt2dDl1ZlZOUGRNeW94TmpBNmVNaTJ4dTcyOXU3'
    b'Ly9xMHhtZmZYM0JjU25rM3FuQjR6Q1JvVHhuQnFWdlFEa2kKMGxjcTA5UTBpSlFxblRPRGdz'
    b'TmgwRUQ2RDRJRDNSZlBTYjViMUFCQmpOU2tZWUYrYnBzK21ISzN1REVtd3ZmVWhRY0h2bHM0'
    b'Y1V6RQowK1ZiMnZzWHJqcGl0OXVKQk55RTlQQmZ6eFYvdkdiaStMU3dRNy9la3l0MUZESmg4'
    b'cmpJNXJiK3hwWStCcDA4Yy9LSUFiRnFhbVkwCmhVeFFhd3dQSDdlT2pPTlR5QVFBd0R1TFJw'
    b'L0pMcm1jVzdGOFllcEhtOCthVEpZNXkvWlRLWVR4YVdHWjZlR0pzWUY3anVUUm5FaGgKQWk2'
    b'RFJyNVQxQkFaeXROcWpYVk5QYTBkQXlQaitNOU1ZRjVwaGZlS0cxZXVQd0VBZUdmeDZPenI1'
    b'Y254ZkR3Tzg5MmVuSGt6RTR1dgpiNlE1L2VtcGhwUG5pai9jZkdidHNqRlVDdkgrd3lZQ0FZ'
    b'dkJ3SGNLNnl0cmhBdG1KWldVdDRVTzR4SUoyUE5YeWphc25rQnpJbTNhCmZqRXpMZXlqVlpr'
    b'QWdMV2ZuVHAzdWN5SlNwdzlMVzdsNHJTWUNOKzRLTC9TaXZZNXl3OW90QVlpQVpjUUU3Qitk'
    b'ZWFZMU9HT3VyNzYKOVBVRHgrOFVsN2E0TUttbDVXMEtwWTd2ejVrN0kyRVkzd09ER1JLTEJF'
    b'TkNZZG1UOXRmZitubitHMGxYY3ArVVBHNmowOGlkM2RKTgozMXlNaS9KYk5IdmswLzVFdmZK'
    b'MW41KzJXbTJMWmllM2RVcmVuamVLeGFTdSsvdzBsVUlNRG5UL2FkdGNIQll6NGMwZnRUcmpn'
    b'ZU1QCkVNUW02bFVreERDOTNKMi8zekliQUZCZDMzM2g2cU10NjZkOXQvZkc0Wk1GUjAvZG56'
    b'dzIwb1ZKQlFEQU1EUStMV3pxK0tpYWhwN2oKcDRzR3hLcjVieVE1Z3Z6cXR6UHVGTllMZTJT'
    b'LzdsM215aHB5RDVNT0NZWHJ0NXcxR0MxMWpUMnpwOFhmSzI3Z2ViRTJic3NhT3pvMApLSUJ6'
    b'S2FjaUlTWUFBS0RWbVhZZHZMbjdjQjRHQSsvNjZrMnR6blRvMXpOZUhzNUhUOTMzOW5JNThm'
    b'UFNZWHdQUjIvdTZwWTJ0dlFhClRSWUF3Sy9uaWd0TG1xNmVldDhSTnIvNE50dG1zMDhlRjBr'
    b'azR2eDQ3SmxMOXQ0dmFaSXJkREFNcFNRRXViSHBaeStWRVFrNGZnQ24KdXI1NzhQUmdHRXBQ'
    b'RVlDaHlwQlFTQ1lSQUFBbDVXMm5EcXpvRjZ0eWJsZDkvZW5ycFJYdFp5K1ZyVmcwV204d0gv'
    b'bXRZTmZCbXdPUwpmNlMxdW52a1IzNHJNRnVRbnc3ZXlrd1BINVVZVkZ6V3N2ZVgvSHZGalIx'
    b'Q0NSNkhYYjg2aytsTVdiZnBOQXhEUDMwOTE0Zkxjb3hSCmI5K3ZBd0NjeW5vNExUTzZiMEJK'
    b'SnVIenN6Wk1XN2diaHFIN0pjMXloUmFMd1RDZEtYVk5QVzVzMm1mYnN0Z3VWRTkzSnBtRTkv'
    b'WnkKR1Jib2djVU94ZVhWSVpHZE9YYTZjTlhISndFQVVXRThtODFPcDVITlpvUk14b2NPNDlZ'
    b'MmlxcHFoUUcrYm5IUi9yc08zblNVcDFLSQpZU0ZlTlEyaUJXOGtpYVZxUVpCblZWMzNvOG9P'
    b'bVZ5VG1SNE9RWkFneUJPQ3dPYnZMbTNmOU1icXQ5TUhLL3I4MjRzNzkrVTZacUxMCkY0NjIy'
    b'KzFSWVQ0UEhyVm90TWJLV3VIeUJhTVBuYnlYRkJ0Z3R6dHV6dzBERXJWR2EvempPc05IRFBm'
    b'T1RBOWZ0aUNWOGpjclg2L3UKVm1CSHV3TUFTRVE4blVZZUZ1ak85V1EydC9idlA1Wi91NkNP'
    b'UWFjc25aOVMxeVFhTEsvVkdTRUlLcjM1aGQxdWIyenAyN2svTnp1bgpmT3pvNFZnczVzMFpD'
    b'WE5mVDhpOVU5M2VKWGwveGRpbi9RRUFObjgwN2J2TnN5ZU5qU0FTY1Q4ZHVwVmZXUC9nVVlz'
    b'bnh4bUx4VmdzCkNKbUVQL2JUa2hFUmZsblhIaStlazJ5M2c2Tzdsa3djRTVFMkttVEt1S2hQ'
    b'MzV1azFocUZQYkpGcXcramdmUlozTmkwQUY4M0VoRTMKZG5Ub25xTzNDeDQwQWdCaUkvMDRi'
    b'dlNSY1h3cWhYanNkSkVneUFPWGpzbTVYVTJsRUQ1Wk8zSDEyeGtZRER6MzljUUxWeDg3T29v'
    b'cgppN1p4M2VTc2E0OGR0ekVYSnZXclQyWThlOEhDMEp2VDQxbE1hbFNvejQ4SGI5cnQ0SmZm'
    b'N3lPSWplL1BHWkNvNjVwNkNoNDJUaDBmCnBWRHFxdXU3Mjdza3pnektxaVZwRzdhZUR3dmh3'
    b'akIwYU9laXRrN0ppZytQVzYyMklUSWNCVU5uK3hQTmllanV4c0RqTUtsSncyNFgKMU5udEFJ'
    b'L0hIdjV4Y2Vnd3JrNXYybmNzUHlyYzUyNVJ3NFNNOEhOSFZtV2tEb2RoQ0FEQWNhVy9QaWtt'
    b'djdCZUt0TXNuSlUwSUZFZgpPVm1nMWhqV0xodno4WnJuTDZ3VGlUaWR3WFRrdDRLMDVCQXZE'
    b'K2VKR1JGQkFlNTNpeG9NUmt0cGVWdE52ZWpoNHphMXhvQWdOcmxTCjYweW5tRXhJU1hsYnVJ'
    b'RGJLWlNlUFBkQUVPeVpuVk0rYVd6RWN6Znl2SkR0VDBQeHNaZ2ZEOXpjK0UwV0FHREQ2Z24z'
    b'aWh0WUxrN1gKODZvaVEzbmZiNWtkSCszLzEvSXl1WGJpM0IvRlVyWFJaRm0ySUhYbDRqVDIv'
    b'MmxKM1dSRzh1L1hpYVdhdkh1MVhFL211bmZHMFduawpscmIrbG82QjlrNUpXNmU0dlV2YzFT'
    b'MFQ5c2d3R05odXR3TUEyV3kyd2NOM2ZESHIzYmZTaHNpOWNDZ3F0TnZ0YzFjY3ZKeGJBY01R'
    b'CkJvWkhKUWE5UFM5bFlrYUVvK2M5RjYzT1dGYlJuaGdiK085dVROTHFURlRLYzhZbTNiM3k5'
    b'emYrTGxkb0FRQVR4MFRBTUZUd29NbUMKV0NVeVRXMkQ2SU9WNDdadW1ENUVGQTdGN1U4UUJP'
    b'MzlkcjRIaCtIanpabzBOdktaeFBSem9WS0lyeVdIL0RmcWVxNC9yYzU0NnNMRApoSmlBNnZw'
    b'dUdJWVVLbjFNaEErTDZWVFgxT05FSlZKSStHZXlmZWh3NWprNE15aU9mTW9MZ1VvaFpxUUlO'
    b'bjZURlJQaHk2Q1JJUWhVCjFncnRkbUEwV1l3bXkzc3J4c1pHK3FFS2h6cHViTnIxMzlmOWk5'
    b'Q05LaHpxZUhrd1g1WlRSVjltK2RLREtrUVZvcUFLVVZDRnFFSVUKVkNFS3FoQUZWWWdxUkht'
    b'cGVWa1RiTnJzUEVRaWh5Q0l0bUFxUk1DYmFwcU5wVlYybXcwQWdQZjNKcWNsSUwxaVEzRTVB'
    b'SUFRR1lJUAo0Q0dpZnF3WEJ3Q2d2WHdieTNVblJna0FBTUJxdGVtTnNCTUY3WVV2QUt0TU9i'
    b'QjhrK1pDTGtUQTZ3dktPaU9uOUMvOVRMSHpxSGpWCmx1NzBoZklkaDdIdWJObld2YjF2ckxY'
    b'MlNRQUFQVE5XV2RxRXdHYnJYN29SNlJVN3ZrVDkrMVg1OW9Ob0lIMUI1MDJuQWdCZ0doVUEK'
    b'b0x0K0QxaXRqSlZ6Zlp0dWNZNS9Dd0RRWHM0SEVFUk9Td0FBR0NzYmREa0Z4ckpxMWRIemhy'
    b'SnFtMFpIZmkwZUFHQzNJTkl0ZXhRLwpuVUQ2SmFqQ0Y0d2RzVHJpSndBQUg4QURBTmd0RmdB'
    b'QU9TVVdBR0FvTHBkdDJ3OEFVUDJTcGMzT0k2Zkd3V1FTQUVEMXl3VkxtOUNtCk04aTNIVUFW'
    b'RGxGSUtiRUFocldYYmxzNlJQZ0FIaklnVmZ4OGtqSXVHUUJnTjVwa1grMWpmcndjQUtBOGVN'
    b'YlMyWU1xSElwZ21IVEMKOEVDN3ljeFlOb3V4WmdFQXdHNHdVakpUQUFESy9iOFRvNGV6dDYw'
    b'alJnbnNab3RzODI1VTRSQUlwNDQ5Mkk2L2YwQk9qUU13VEZzMApuVFozTWtRazRQeTQrRUFm'
    b'bTg0ZzMzR0V0V1VOZ0NEbWhxVUFBTlZ2VjB4MUxlaWs0c1ZkaGpRcUFFQjdLWStTa2FRNmtR'
    b'MEF3REJvCmc3SFUzQ2JFOFR3QkFOU3A2VmhYRndDQVl0ZHhxMHpSTS8xZEFBRGtlTEdDMVNy'
    b'ZHRNdno0bDVVNFg4T1JOUVBBRUI2eGNCdVp5eWIKcGIyUWF5Z3E3d3lmQkFEQXNKeGROcTRj'
    b'N0lYUUgyOXVveStlQVd3MnExeWwrT0VYN3UwVHBGRWpIUC9YbkwvUis4WmE3YVhidXJ4aQpT'
    b'a2JTUzljVUwrVWI4Z0VBaHVJS3U4RUlBQ0FseDBBRXZFT24zV2dDR0JqbnhRRVl6Tk1SRmpo'
    b'ZWwyNnoyUzJJM1dxMW04d3dsVEtvCjFxWXoyTTFtQUFDRXdUZzY5SDhiZEIvcHZ6UGFUSXA2'
    b'OXBkNHVQN05WZnJITGpRWWhnaDRDQUJBL3RNend6Q0ZCQ2drOE5LQzVraGYKL3FFQTJnU29R'
    b'aFJVSVFxcUVGV0lnaXBFUVJXaW9BcFJoU2lvUWhSVUlRcXFFRldJZ2lwRWVXSDhGeW5rTEJX'
    b'a01mYndBQUFBSlhSRgpXSFJrWVhSbE9tTnlaV0YwWlFBeU1ESXpMVEExTFRJelZERTJPakl6'
    b'T2pFeUt6QXdPakF3SXg1UDR3QUFBQ1YwUlZoMFpHRjBaVHB0CmIyUnBabmtBTWpBeU15MHdO'
    b'UzB5TTFReE5qb3lNem94TWlzd01Eb3dNRkpEOTE4QUFBQUFTVVZPUks1Q1lJST0KIgogICAg'
    b'ICAgaWQ9ImltYWdlODM5NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_IA')

US_IA = b64_US_IA
index.append("US_IA")
index.append("United States of America Iowa")
catalog["US_IA"] = US_IA
catalog["United States of America Iowa"] = US_IA
country["United States of America Iowa"] = ('US_IA', '', 1)
lookup["US_IA"] = ('US_IA', '', 'United States of America Iowa', 1)
lookup["Des Moines United States of America Iowa"] = ('US_IA', '', 'United States of America Iowa', 1)
lookup["United States of America Iowa"] = ('US_IA', '', 'United States of America Iowa', 1)
details["US_IA"] = {"continent":"Americas","capital":"Des Moines","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_IA"] = ('US_IA', 'United States of America Iowa', 1)
regional["United States of America Iowa"] = ('US_IA', 'United States of America Iowa', 1)
#----------------------------------------------------------------------
b64_US_ID = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4MzEyIgogICB3aWR0aD0i'
    b'MTI3IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDEyNyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSWRhaG8uc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2NhcGU9'
    b'Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHhtbG5z'
    b'OnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9k'
    b'aS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsi'
    b'CiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3ZnPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczgzMTYi'
    b'IC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc4MzE0IgogICAg'
    b'IHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBi'
    b'b3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAgICBp'
    b'bmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9h'
    b'cmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlu'
    b'a3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzgzMTgiPgogICAgPGltYWdlCiAgICAg'
    b'ICB3aWR0aD0iMTI3IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFzcGVj'
    b'dFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1'
    b'YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3'
    b'MEtHZ29BQUFBTlNVaEVVZ0FBQUg4QUFBQmtDQUlBQUFBZ3puZ2NBQUFBQkdkQlRVRUFBTEdQ'
    b'Qy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZt'
    b'QUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFXCk9FbEVRVlI0MnUyZGQz'
    b'UWMxYm5BdjZtN005dDN0VnFWWFhWWjFiYUtMZmR1c0kwYkJBTjJNREVsSk9TRUVITHlYZ2lC'
    b'QkVKSlNCNEIKUWdpRVI3RHA0QUNKd1JTYlptT1FteXhMc2lTclcyVzEydDdiOVB2K3NKT2M5'
    b'ODU3THlIdkhWczQ4L3RyOXB6WnMzTi9lK2U3TTkvOQo3Z3dHODM0QUtoY0lYRldnMmxmdHE2'
    b'ajJWZnNxcW4zVnZvcHFYN1d2b3RwWDdhdW85bFg3S3FwOTFiNkthbCsxcjZMYVYrMnJxUFpW'
    b'Cit5cXFmZFcraW1wZnRhL3lKYmV2eUNCeG9NaGYzaGFRWDZKajFRaFRMWTZ1WnFlNzNKRWlj'
    b'Rm1Ta0lZR1VRU0t3bEljNFlrYWpvNDYKVDBZYU9ETC95OUlpN0V0UXg2bUlMY1lEVnpXZE51'
    b'dkZSSnBJSk9XWmxXaitiTENhNEkwUEFEQm9tUWt2N0FHYkZjTXdYTThxc1RUMQplbnR0VzJJ'
    b'bDROTzlieEhnWERSOWp3NmhadDJIZDY5NHU2NGc0TXlWcmw0RC9XZVUvYTN3OVMzZ2RFQXdD'
    b'cmYrRE94bTJMUUN2blUvCk9IUGhoemNoUllGNFFxN09EVjVlZlRUb1QzbjRNc0F3MWY0WHhx'
    b'aE0zYnRzVjVQTDExaWoyTTNvenNlZ3FnU3V2QVIyNzROVjh5REgKRE4yRFVPaUFxUUFJSXJo'
    b'OThPMnRrR3VGajQvQm56Nkd4KzVBQTJkUWRYNXdZWDdiaVhFbmp4bFYrMStBZW0zcmd4dmZF'
    b'eVRFYy9MUwpPZURLZzJBWW5uZ05GalZBVVQ3NGd2RGhSN1MvWDVmMjZSdzBIVTZpdWxwWlE4'
    b'UHJId0NHd2VBWVhMc0I3bmtTV3VvUURtaDliZmZ3CkJCYVVYR3JjLzd0WWJONTM0NUtlaWtK'
    b'bDd5SG82SWU3YmdhRVFKTGh6QWpWMzVtYndBdkFXa1BuVitJbUM0OVJBc0t0R0s2TUh1ZDgK'
    b'blRySlhWRWZORmpGVkJZK1B3a3YvaHdBb1BVa2pFeGlPMXZyUDQrdVUvdiszMkMrOGNPYmxu'
    b'VGptSUlUOE0ycllOY2VzQnBCeUJENwozaXJ3NmE5elhuYXJLYWZnM250LzdCMGZ0R3Vob2Ro'
    b'ZTdkRHhmRkp4MWVzV1gwYzJiblVQNjkxdFhxY3pYVmFrYURWZ3QwQ09CYnhoCnFNb0orZjFa'
    b'RDErbTJ2OGZLYVZPL3V1bFJ6SlpOT3FCZzhkaFlCeHV2dzRPN3M5eHk5c01HMzZ3ZEhZRnc4'
    b'ZFlEUVVBQ0NHWHk1WE4KWnBPSlJESWNLTFZvTkptQWIzeFlnL0hodkFWUnZ5c3k2TjZ3THBO'
    b'SXdkSWRZTllCbzBVTEtudzlvN3Fva3FmYS8yK2c1ZGpERzk3RQpNTmkwQW5idUFVWURheGJD'
    b'S3k4VjBhc2VvdXFYTE1rbko0YjY3STdjaU1LMitmbitzTmpyaTA4bFJiM0pPcTlwVnNqdk51'
    b'djBwWFpUClpXbkovTnJTSVcwSnlsLzJ3WlB0NXZ4RVVUNHNhWVo5bjhPc0dkamNvdEg5QXpV'
    b'U3hxajIveXUzTmJ3Z1MwSTByb3hOd1k1TndHamgKNDcwVnVkc2YxNVRVYWRQKytFaFhXVm5a'
    b'c1VGUE9uK1dRclBaMElUSldhVnpGR2UwMXZiQlVTRVZ5Yy9MUjVJWWk4VVVSZkh5bEw2cwpq'
    b'cWhhM2YzeVlic3JzdmNnL09obU9Ib0tFaW1peWp4OExOQ3MydjlQT0xHZUxVMjlOcU5DVTRB'
    b'UWVBTFFlZEJodlBMWHV1anByTUhKCkk4eGwwbG9NakluVmpnWGpxWkNINU1MaE01M20wbG54'
    b'b0pkUWVKUU45dzMwa1lVelRRYmRsRCtZWW15WjdqZEVSV0Vicnc1K2VQRDIKYjZWdWZ3aUdK'
    b'cUNtVENuTUVUcEdERWx3cVBiL3l1MHR1eTFHZWVNeWROZmprT1ZBaXBpVStmZm9hdVlpZ3FR'
    b'R1AvRzFQcE10di9STQpJRGthVHBuS1pnWVB2MlkwbS9IOFdhdzVSd2lPOHQ1KzBsNU9GODVV'
    b'akhsaDNKUUFUZi9lM3l3cTBQWWUvdGd3ZTQxaXFodytjSFRyCkZWeHpMVFRYZ1RlSXpiQk5I'
    b'cHljcDJiWnptR0ZrZko4ZnR0YXhXeUFBenZodTlzaHFzd3hOcTRDQUlYVXJtMnVEOFl4Z21i'
    b'WTRqcHIKZFF1RzRYbHpONDRPRGFIZ1lLSnJyNi9yb0xWcUx1dXNZNjE1QUJEb1BCVHZQR0J2'
    b'dmd3aGFsYlRITmFhYTJwZUhjdzBPR3l3ZmluVQpsc0cyZFVxaGhiZWdNMnJmUDhlV3NuZU5t'
    b'c3lpQm5UMjQyTy90Tk9iZmtYcGpZb3M2NE45QXhPK0RTdFhUTXBHWEtzN3V3TmxzSEhoCjRQ'
    b'dS8vNVZ2c0pkbFRJVUxONTlOSjhTbnhvejVKVUxXNzM3bEY3Rk1RT2NkU29nSmpiTUpkelow'
    b'dmJydmtsVVpBQ0FKK093a2JxYWkKblpGWmF0OEhBRmcwdzcrazRWeWkrUFFaU0RDTlRKNFRB'
    b'S3hDc0Z3dnNqVEJVN3JsdEZ0SXh2OTZnWVJqRFU2N2pZUnNKdjJYVEk2cApvSVRTbTNUaEkr'
    b'dXZ1TndLY2xHWk9USHdZWHkwblhFVXB1aUd2ajkzOS9rejVaWXlueHA1QUFCWWNVcVdVV1B0'
    b'dVkvdjdkRnBHalphCndxZWxaTGhZdy90REVYdE9UbVY1aFM4Y1k2V0VMSW1IMzN4MnZLY3R0'
    b'M2wxQUdrblkrbmdtVjR4bmVnOTlONkpkMTlWWkRuakc2a3AKcWdrbm9yS1o1a3hhR1hUOGVE'
    b'Y0FwTTAxNzcxOTd0U1pVdzg0amhqUnE5cUhhc3RBVmlEK2tvZ2M5MWxqc2ZHMjBkSEV5UEh4'
    b'aE5RNQo3azJuMDQ4OC9nU3JOeUloYy96dEY1dlhYVU9RVk1jbmI1VmVldTNhbit3c1gzOWp6'
    b'MmY3bkRXTjlTdld0NysvbTBCbzJaekZwMGNICk1SekRNVXd3MTdlVTVBTkFaS1I5Yk14Nkxy'
    b'dUNRU3FMMTlzR0xuamJMM3dHdk1vZXdQK3NYbEVnSVpvOGc2ZHh4aXNhNkx5eVdlc3UKWFRl'
    b'cnNsS0hzbjZGT2ZESnh3dXZ2RkVSZUVkQm9iTzY0ZHlJWFZCOGRzTS8ydEY0NlZmYTNubmx1'
    b'ZHpyZ0xWT2VFZDdoa0wxMTkxcwpNdkN4OFg1V1NnZFRsS3dBZ1FNQUlNQktMSUcyeEQrOWZi'
    b'cytSUkdTSUVMUEVFUVNJR2t0V0h3cTRSMmxacS8wQlVLWFZUZzFRb0xRCkdrN0ZLWXJXWk5y'
    b'L1NDWW0xeXh0N2g2VjRwUmRzWllCWXhRaUhrV2o5d3djemJQWUdLTkZRZGlTV2NZOGZUVko0'
    b'dnNuMmtKTnE0cXkKcDFOYW1oUFpFejF3eDZQQWFHRFRDaW5mbUZUN1BoZ1ljZElQTGR0QXg4'
    b'QTFhMERCQ1lMQVU1eHN6VVFZbG1HMWxIZXl4MXpnSk4zSQpXZE9vakx5bjFiSGhjR1JoYWQ2'
    b'WWUwVEQrVDg5MUR1ekxGZG50blRHUEs3bzBVamRnbFJvTW9maFdqdThzNnZzdVZaTmZ6RGxH'
    b'NW1rCkZZWEFxUThPdzBzUFFUd0pUKzJHSEllbzJnY01RODQ4T1B3U2RQWER1QmRvbWlKSmdp'
    b'THh1dm82amM3RWV6NERRU0tTSXdiclJrV1IKTFhpOGdKR0hPenMrL0RSYk02UGNZc3pXRmVk'
    b'RTB0a0poZUFFYWREdGhSa1lvWEFXazJiTXl6ZlZZdTRKUDFqSFRRWlRtQmRsVVhiWQo0SWE3'
    b'SVoyRlRTdUJSNkRhaHd4SEtqcG83WUJKUHdDQ1pDTEppekpyTktSTkJWYVRTUklpRlkxYk0w'
    b'ZGVwd2pFeDhNRFBWNmxNcmV5Ckx0ZnNwd0pESTUwOEw1bDFqdm5GMFdCQWxpUVJKMUlocjlW'
    b'dThZY3lFeEU4bHVUVFBHSVZ4ZHZiVnUyd2pVNzRsczJCdFlzQngrR1QKWTlBOVFhcjJJWmpT'
    b'V2JTSkoxNlJMVWJZc1Jsb1hOSWJEWjR4UDZXeEM2RHRsUlpxSTl6eGNWT0VtZUJpZ1VTRzIz'
    b'OWsrR0JQTkJTSgo1T1lZSzJ4NlUxaVlQQ1hnZWg0QUJtTVJBeDNIa0NtVEZTMTVyczYrQ1NX'
    b'bkRpY0lMdVJ4YTNCZTR0NzhFRTROUVhFK09PeEVKTXVxCjk3cGd3cWJxOG9ObWczSnFFQUpo'
    b'ME1RMUlra1VhOU0zTWZ2bkJQOFFTT0hoTERyWjFWc2QyVjhSM0o5b2J0QzRUQXFsNUJaWWpU'
    b'WFcKQ0xpeWRwZkp5VWdTbDBtSUdoMnhPZno2WEtrMXJqVVpnLzJNeld5ZE9sRVlQUm1Ja3dn'
    b'QkkwVFdyay9UTkFBR2pJWm9QVlBpNXNyLwoyYS8zZTBQbExLUGtXdUVYMzRPdmJZSWlKbXcw'
    b'MHU0TW9rbXAxaXJnR1ovZkg1Zy9iNzQzUTMrbEZzbStxVURYeUl4NlIrWDZXa3JMCkdseGt3'
    b'YXlWNmJBcGMyWWl4eUJ3ZzZjdXJ3WTlKWnpvOXVPS0dBOG5DdlhTZUJnejZSaEZGRXNjNG4y'
    b'L2d5ZGVoaXdIQktIMHhjclUKeUFNUnJBekhVSFVadUgzd3lBdXdaVlVTdVhIU2JMMjdSeW1h'
    b'WkhncGJyV09OanRLT0VQSmQ5c0QzYU5UTmF0bWo3cGp4YlJGYXpPbQpZMlVFcWVIYlB6Qksy'
    b'VkJxeXN1bGIydlA0emdwR1V1RldVc2d3dHRYZjkwenNWK0xCTDBnTEwweWR1OThrQlhZZXhB'
    b'U0dSUkI1WUQ5CjA5c0hEQi93bW9QUitORk9wYUVLQUVjYVBpa0FIUk9Bc2xnY0prZWczeDhL'
    b'aGJTc3FjRTVsYzVnM29tUW83eGtLbURPY2M1MjFSWkYKSm9lOWJyZkpyRXNhcWNKY3NraDNa'
    b'akNZcjhFSU9ZdHdtVWhGdzFPQmdOTmlvR2l4YnhUOTZEY2d5YkI1QlI0VFROT2h6bWRhNURo'
    b'OQpJVmhkTzE1YmlyNnpIY3Bkd0JyQ2lVeGQvZFh6cmZrV28wd0tHWjVtOVJPVDQxTXg0aHZ6'
    b'eHJQNU5RZGVQaDZZREVTbUpsMjF6ZVBkCmJVSnFMQ2dLbDJ4dnVNYlJPVHhXeU1uMHFDZFdh'
    b'TFRFMDBrc0VYWmFqV0kwdm0ySFc4c29lWFpZdHhoWUJ0OTVmRUZNS1ZBakR3REEKbU5Ta29J'
    b'TjVkakRwd2FTSEhJdjAwZjdUWEtCSTc3UmhGWmd4TjQ5UGpzdzIrb1NoNFR3TGxqb3lxS01v'
    b'WElwUzRkU1JaKzhnQlM2ZAp6b29jcnd4MWxkU0J3ZXdUSk4zYUJsc3F6ZUlZcGlDa2lLTFJr'
    b'aWt2bGV3V29FZzRNd2trRGFOaUUweURFcmZwVWNPTVljKzJOcCtaCklsSVplTzE5V0hjTFZN'
    b'OTJwL2NjRnJOODI1blRiNzcyWHZzYmZaOTFoNmpSd2s2ZnE5eVMwaGVZRVFJZHE1VlRDUURn'
    b'QlVHU1pRdWUKN2dzYXMwYW5TS0xoY1BDb05JSmhXRENSVHFlanF6WjYzL2tVMXQ0Q3M2b0FK'
    b'L0RuajgyWkp1V0YwMlZtMFNjVXJ5eHFPOUtCV0MwNgpjQncyTElPbW1lRmpmNVNQZXlidFNW'
    b'YzJ4bzVZQW41M3dUaU5FWGk2Y01XU1JDQVo5a2FEb1JpT1k0eUpYWHJMeXFtT3ZqMjlWVGds'
    b'CkxsdThxbU5zUENzck5ZWThoY3RzdTNiNGdXZFFmU1dzbWdjbmVuR1NvcDRmdkJwZ1d0aWZO'
    b'dlg3R1Badmg5YTdISWdrWWNkbVdORUMKcis1WHFrcmFHendZSGZDc2dkQy9YeUpjdGIwZlMz'
    b'T2VvTm1NSmF2WHpjSXdyS3JDeGZIQ2pPVzFmaTYrVDhQNG1PRkpBdFBLNHJkWApGMElFSC9Q'
    b'N0d4Y01Kam5sMFBQUTNndGpIckJiMFFPZmJKb202bUZhVlpSa3dCb09KcXB5UTFlc1JIcy9o'
    b'YlllS0hXaDZ6YUhvNzFXCk81S1ZQdW1kVC9qeVFtbjl4blIzWWtac09GeHV0V2swTkVMSVlq'
    b'Y0ZVZG85NFMyMkdmOWx4VHBDVGlYRFJ6R1A1cmJiaGhoV3VmY3AKYUtxQnRZc2hGTWRmUGxy'
    b'Zno4MkZhY1AwcW1XYjRDcHpZRGdVekFiQzZQczc0TktGOE9pTDRLcU9wR253Qk0wRE1lejRp'
    b'Q0JiSFVuWgo0RDR4eXVBa1JaRXNveDBmbWNxdEtJaW00MXVKWEZraER4OGZscEsrcTdaN1ox'
    b'ZER1UXVhYXVDeEZ5QXJFQ2ZIN0h1OVcyQTZNZTNxCk9Mc2lzMHFaUG1lT1lER2lYNzhFR0Fa'
    b'YUxUUTNadjBReW1XcEhLdkRaQ2hpWFdaSHZUUFhhclphRElSQlU5QlN5cEtrMUIyd3hiUFoK'
    b'Yk5mY3VmMnRwemxHQzAwMVoyTWFKRkw0a04reWEvajY2VmJMUC8xV2QyRFkwd00zWHAzZHJX'
    b'Y25MMStoUFBNbUxHbUd1Zlh3MkV1dwo1WkpnUVNvWWpwL1NIVGRFMCtha291VkVURXNpelFC'
    b'WGFJbVh6RTVJTW9RaXNPVVMrT1ZPV0RVZkFPQmdHd3hQNEVkR1hXOU9YZ1BUCmJ4WEY5RjA1'
    b'Vk04ZXZtMTVheXhKYkY0dS9lUUpXRFVmYnJ3QzF0MENWU1d3Y2ZrNXVaamxlaFI5N3V6K2M3'
    b'ZkM0WmRnNDYzdzhQZWgKdFJOU0dVQVlrV05TSGoyd3VEZXpZSHEyY2ZxdVhRbUlydjBEOVU3'
    b'TkdScm5yQ2Fpc1JvbDB2Q2JsK0grNzBCVExWQVVoZWM5aU9mZApnK0ZHbEQ0RW9IVDFRMnNI'
    b'a0FRc213dERia0xQd3VsSjY0T0hyL1ZKbFRCZG1kYnJ0bVJNZXpMUzlGR1BLNCtaMHVMYzRB'
    b'U3hxQUU4CkFaaFRCd1N1QUtZQkpZSFNCNEh2RnlVb3lBVi9HTXQzRUtFSW5KcXdQdno1NWlQ'
    b'UjVmSzBLVmUrOEpGSFE4b1BmT1hRSzBkck95YSsKY0JFcnJtUm42bzZzcUR4VG5odERpa0xS'
    b'dUt4UWtpamhCRW1Ub2l3ckJFSDBlWXlIUmlxNzB2T1VMeTY5cWRqMzFaYlRkLzFwR1M4UgpG'
    b'K2VvdTdwMmJHWFYrSmFtL2lTbnNlcXlDVTd6NnJIYWg5NmZMOHAvKzZaUHdabXU3TXF1VXlz'
    b'QkFHU2VWZndtT3E0bEJFR21JcHdwClMrWUJvZmxMai9wN29FbjVoK3VPYnB0MzJxZ1Z3aW5H'
    b'eVBEaEZMT3FadXk5N3ZLTDAvNG5mY1YzckR0YWt4OCtQT0xzY3VkYVdPN1cKbGUwRjV1UzNY'
    b'bHJ6QmVPbEprTVVaUkNBZFBhYytrY081dkZ0SDEzUk9QanM1N01pYWFheHlIOTU0K0JFeEhp'
    b'Z3YvaWlqVHlQYnYzNApHMHM3Vi85cTYzaklaRE5rTVF3Skl0Rnh6NjdHbjk3UTc3T2R6MmJY'
    b'NW9mYmY3S3I0YWMzYWlrSkFZU1RiTEV0L3RIM1gzdjZVTVAzClhsdDFFZVo1V0ZyODJvS2Vu'
    b'Wi9QT2pKUzJGVHM2L2pKcnFldS9hRGZaeHNKV2hhVVQ1M240VzVCdVdjb1lCbndXWi9hdnYv'
    b'a2o1OXIKTFBJZEhpbmMxVHJ6YXd0NkdFcTZDTzAzbC9oTURIOW93QVVBRlk3WVo0T3VSUTl0'
    b'TjdOOG5qSFY3N09lWi9zRGZtdStLVzFtK1lVLwp2NjUxMkZtYUV3ZUFUd2VLVEF6ZlhITCt5'
    b'cHZQWDl3dnNpUUFRRVBKQVBESGt6UHVXbi80OEowdkZwaFRUeHhvUGpKU2VKN3RmejdrCmZQ'
    b'SkFZK2M5TzcxeGZiazl1cWR6SXdCb0tBa0FpcTN4ejhGNXNmWDlKRThEd05JWmJnQ1lDQnRi'
    b'SHRpaEllWDc5aTY2OTYzRmoxenoKOGZVTHUzV2E4MUhhcDljSU55enFmdVNhais5NWE4bDll'
    b'eGVSdU5MeXdBNTN4QUFBeTJhNEFTREJhYzZiay9NMzZocTF3dkRQZjhmUQowcHo3cngvd1dR'
    b'RUF4NUdPRm8xYVllaG5UNU14Z2pPZ2Q3ckxkN2ZWN09zdSszKy82TlpTMHRyNjBXdGEramJV'
    b'RDlQRGpGeVZxYmp6Cm13bU96b2lVb21BQVVKTWZQbjczOHhtZXF2alJONU1jZmJIZDYvSVMw'
    b'ZSt6WFR1dmQwUERjTjlVem5qSVJPQ29wWFRxOXp2ZWQ1bVQKM01QbFpKeXNEZ3RiNS9WOTUr'
    b'cWpqY1VCcTQ2TFpiVFJqUGIvOHFQbDl0aVdPUU0vV0hQc3Q5cyt1cFoxVng0bnNWTkc4YUNO'
    b'eXVPVwpMeGsrN2MyWmpCb3hnTlcxNDY5KzQyMmJMcnZ0bWMwOUh2dEZtMlY3Ly9ZL1hGSTdk'
    b'blpia0FpYWxBRkEyT1VpV21MU1NSTlJuUUlGClF4RUtzZ1JtRS9DWnlRQkJ0WS9udFkvbjlY'
    b'anNveUhUV01qMHYvd2ZGcFlyeVltWDJXTjFCYUU1SmI3bVlwODlJY3M5UnZtVVVlblgKRTQx'
    b'eGZFWUtlUmh5U1ZqWWswL2ZOSUZiQlVuQlNWdzUrL1VQZWtzdisvVlZGKzMxUGdBUUdOb3lw'
    b'Ly9PUzQ5ViswVDV1QmtsU0dWRQpwOFJKY2tHVTN1TE4zbCtKR1NUTmprbGhyd05Fbk43bTRS'
    b'NnFvQzRMQUMzamRoRjNjRmdlbjZUeFVKTE5DRlJHSUpNY2JkQUtMQzJ4CnRHZzNaUFFjUWo2'
    b'TjR0TW93enA1V0ljNEhDL2dwRTl6MktlN01qZlBacC92UUI2R2Y4NkY1UWpFN0RqL1pDbGVs'
    b'c2F0SWpFdk9saUoKLyt6UTNEZmJxMlIwWHRQUTV6dS9MeU5zZDF2TjdyYWFWVFhqRHk0Nk9y'
    b'Tk5WQUkwWHBhaE4vaFJuQ1JLTTFoSlZqeG9rNDlabUYrZQpCaEVEQ1VNQ1JsMGFsZzdaZ0ZE'
    b'UWlJNDZhSE80R1N4SHdJcXpLRXdEc0JnQ2xDU1JXOHZWSlRHelJDNk1ZT1VaWlg4dWVibVhX'
    b'aHBSCmZGb1VwcG1IVHdNSmlsZWp1ZDR0anpFb29BRU1FUlhwM25uSy9SMkwzbjJuQWwySWd2'
    b'SUxuTjlmT3NQOTNRVWRheU14TktCREtVSnEKdGVvZTc4aytNSVBhNUNOYllrQXAyZnRtNFBr'
    b'ODBSQVhkaGF4ejNabWYxb0ZJUnFsU09hcFUvSUpNKzdNZ29pREF1SytYUG1raVgybQpTenBo'
    b'VnZvTWVCNEhaZ21qRmVUVkVKY0U1WS9zU01JZ1MwQ09vQXpwY0x1QWJPSitwK0d4WXcyZkRW'
    b'N0k1L1pjNExtdFE0T3VRNE91CkFsUHFoc1hkMnd1SGkyYWt1VjFGU29oR0lwNjlvMFo3eHpC'
    b'bUVmR0t0REtpdzV3Y0NMam1xaW4rcVJLOFBJMjhXdjYzSmZvL3Rja2QKSnNUalNNU1JnQU9G'
    b'bEZFV3orT2tQZ085eVFjWUFJR1FUd3NtRVh4YWFaUWhIZnprK3VRTFV4WFB0ZFo3RCtqaFFq'
    b'TXRaaGFuNHZvSAozMTN3SUN5WTdRcHNXZDUvMlZjbmEwSTh1U1RDdjFLb2pETzRSWlQ3REho'
    b'cEdqQlF2RnFVSUVHcjREWUJyMHFoSklrRVhPNDFvREVHCkFDQkJvaGhGWGoxRkxvM3d6eFRo'
    b'eFJtcHgwaldwckRxVkYrRitGNlo4WTMydWFjTzVNSzBZWnJPTE9ib3M4dXJKNXFMZkhNZC90'
    b'bVEKMUVjeHhhT0ZJSTBVVEI3V1FZb2c1OGZ3cXBTd0o0K3NUc21qTEFyUXdNcGtjeHc0SEMv'
    b'TmdrRktXbENYWW13TDVKNFl5LzkwMEJWTwpUY2RwRnV4TDhXWnZoekZkYUVrV21sUEYxb1RO'
    b'a05HUXNwRVJDRXl4c0Z3MG81VVJuc2pTdkVTRVV1eEUyRGdaTlhpaWhrQ1NuZjd0Cnd0VDNx'
    b'bDlBMU9jd3EvWlYreXFxZmRXK2ltcGZ0YStpMmxmdHE2ajJWZnNxcW4zVnZvcHFYN1d2OG8v'
    b'eEgwbjFjb2NXN3YxdEFBQUEKSlhSRldIUmtZWFJsT21OeVpXRjBaUUF5TURJekxUQXlMVEky'
    b'VkRFNE9qRXdPak13S3pBd09qQXdUdkRlV0FBQUFDVjBSVmgwWkdGMApaVHB0YjJScFpua0FN'
    b'akF5TXkwd01pMHlObFF4T0RveE1Eb3pNQ3N3TURvd01EK3RadVFBQUFBQVNVVk9SSzVDWUlJ'
    b'PQoiCiAgICAgICBpZD0iaW1hZ2U4MzIwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_ID')

US_ID = b64_US_ID
index.append("US_ID")
index.append("United States of America Idaho")
catalog["US_ID"] = US_ID
catalog["United States of America Idaho"] = US_ID
country["United States of America Idaho"] = ('US_ID', '', 1)
lookup["US_ID"] = ('US_ID', '', 'United States of America Idaho', 1)
lookup["Boise United States of America Idaho"] = ('US_ID', '', 'United States of America Idaho', 1)
lookup["United States of America Idaho"] = ('US_ID', '', 'United States of America Idaho', 1)
details["US_ID"] = {"continent":"Americas","capital":"Boise","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["US_ID"] = ('US_ID', 'United States of America Idaho', 1)
regional["United States of America Idaho"] = ('US_ID', 'United States of America Idaho', 1)
#----------------------------------------------------------------------
b64_US_IL = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4MzI3IgogICB3aWR0aD0i'
    b'MTY3IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE2NyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfSWxsaW5vaXMuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczgz'
    b'MzEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc4MzI5Igog'
    b'ICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAg'
    b'ICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2Vy'
    b'Ym9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAg'
    b'IGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzgzMzMiPgogICAgPGltYWdlCiAg'
    b'ICAgICB3aWR0aD0iMTY3IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6'
    b'ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZC'
    b'T1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtjQUFBQmtDQUlBQUFCc0NMZWhBQUFBQkdkQlRVRUFB'
    b'TEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FB'
    b'QTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFuCnVVbEVRVlI0MnUy'
    b'ZGQzaGI5YjMvUDJkcTcyRU5EMW5lZGp4aU80bXpJUU95S1FrWmJFb0xCQXEzWlpRdTJsSkdh'
    b'Y3N1dEt3Q3Q0eVMKTUVvZ1FNZ0NNcDBFSjNZY2ozaEt0aVhMMmtmNzZNemZIeVlwcGIxUGYv'
    b'VDIzc2E1ZWo5Ky9PZzVQdWNyV1M5OVArdDg5UDBpb2loQwpUdi9IaE9iZWdoejFuSExVYzhw'
    b'Unp5bEhQYWNjOVp4eTFIUEtVYzhwUnoybmMwRDRlZjhmaGtLaGFEUTZNZVJTYURWRlphVUdn'
    b'eUZICi9ieWx6akRNeU1oSUloS2xQajJhK3ZpUXBPMTBzTlNtMlBwNGp2cDVTSjJtYWEvWEt3'
    b'aUN0KzBrdCs5NGV2cytCWldpUkNZZmtXZ0gKeHNmYVRsWlVWT1NvbnlmVXg4YkdzdGxzUEJJ'
    b'TkgrMUF1MTJ4ZzhmVnJnbWZ5S2dCMzhQSGVSQnRPSWtDUWdhaTQrUGpOcHN0UjMxcQp5KzEy'
    b'aDMwVDlKSE8yS2ZIdU5hVHFqUUxBREdCVnFLU29NQU9BMTJMS1RTQUpZcXR1aHZXV1JmT29t'
    b'azZOOWVuTnZWQUlKRDFoN3pYCjNhUDBoR2lSODRuWnBDZzBZY3F3eURwQWlnQTRFS2xPb1pS'
    b'ZWY0bjJzb3VwWkFMWHFQTHk4bncrbjlWcXpWR2Zxa29taytHZEJ5V2UKWUR1Zk1pR0VGaUY0'
    b'WUgwaVU0aEtzeUJVU1RXd2NwN2g2dFVxUno3RE1IcFNId3FGa3Nra0FPU29UMkdKb3FpcXIw'
    b'eWpLTUlEQjZJWgpJUXdJenNsSVpFYU5hbjR6MUpXWnlwMTJ1MTJoVVBUMDlNaGtNa0VRY0J3'
    b'dktpcjZQMjdoa1NuZFM4UHpmSDkvLzhoelc0Z1h0cVdyCml0U0xXdENLSW5sTnFkWmt4RERN'
    b'NFhEa1hQaDVTQjBBVXFuVTZPaW9iKzloeDdJTFlvbTR3K0hRNlhRQUVJdkY3cmh0Y3pyc2xj'
    b'bGsKbHZ5aUdYTVdybG0zQ2NPd0hQSXBTVjBVUmJmYkxRZ0NnaUJuRDNvOEhvMUdZN0ZZYUpx'
    b'ZU5PRDMvZXpIMU9uOVBDN1RhUFg1WlhYdQpqczlZaExDVjFzOWZ1cnA1MXB3elY0MisvYWRY'
    b'MDFRZ0hQREdZekZFWURtZXoyUTVyY2xxem5kZXNtNVRZMU56enEvLysyTzM4Zkh4Ck5CWGpC'
    b'OGVTSjdwVFBjTmNKTVpTTVpRa01ibVVMclR4eStacEw1ZzFlYktRVFVvSUpNVmt0Q2FibUkz'
    b'elBJdkpsRnE5NGUxbkgzejcKSllXbHVEcEpoU2VHVHFwSUVRRFNTVHFSb0xNc0p5WHhGTTNH'
    b'b3FISVdMKzMrMkJoZVgxWjNheTFHNjZVU0NRNTZ2OEdEUXdNSkR5KwoyUHVmSnQvZXJZd2tn'
    b'eUlyQlpSRWtJakFGS0hTZ01pb1Rya29nMWF6Y09iaytSS0pKSTNMSmNDcWRLYXhuaU04TDZo'
    b'VjJyNGp1NExoCk1KWElUSXowV3cwcWdhWDdBeWxlRUhWS3FjT2lFVERTRStFdVdyckExWGZL'
    b'TithS01sSWRGV24vNktVamU3WlZUSiszL3Nwdm1reW0KSFBYL1BjL3RjcmxDNys1SlAvV0dO'
    b'SlVkRTlJaGtiVWlaSi9JVktMeURpR3BSd2lmeUpnUlV0VlFlZGJzS3pXR3VKQXRicGhuejdj'
    b'UApkb3FXOGhrWExMdDA2OVAzQktMSnlrSWppaUk5STBHbGxLeXVMRS9Gd21ablE3SFRhUzJ1'
    b'MnZIU2d3T2RSNnVhNXM5WnZrbHZNTHorCjh2TnlobFdnMGJIUHQvL2k2RjU3eGZSMVYxeGZY'
    b'bDQrMWFsajk5NTc3em1PZkd4MDFQWHI1OFVYdHNVWnVsZElwMEVnQUpVaHFCMlYKWkVXK0Js'
    b'WEVnUmNCQkFETndtWkZoWE15bWtOUTlNamU3WFRFTTNyNkJNTUpDclg2Nks2dG83NXdxVjJQ'
    b'WStpeDAxNkgxVkEyclduZQppaXRHT2c5bVkwR2VWQSsyN3cvRUdYTnhyY2l6ZlNlUGVYMEJN'
    b'UlhLcHVLaFdDcVpZWXdLTkJzWk83QjNSMGZuS1pQRmJqU1pjM1A5CmYwU0NJSXlPanJvZmYx'
    b'bit6cjVEZk55SnlxUUlXbzNLR1F3UkdzcGxwWVc0V29WSUNIazB3VkZ4RUVWOWJlWFphNXRt'
    b'ekhxTzBHQXEKYlRvV3NwWFhOYzVkOHZITHA5STBpMk9vSnhndks3UW9wVGpQQ3p0ZmYxeEE1'
    b'YzY2Rm8xV2U3QzdyZEJSRm5DMUMwYUxYSzJYeVJWSApYWjRMTDFnWTlneWtvLzVEWGFPT0Fu'
    b'dWVVa2dNSDMzbUY4ZnpxNXBYcmIrMnFtWmFqdnEvV1AzOS9ZbldEdUpQdTQ3emllbW95aVZt'
    b'CktnbUZzSDZwYWYweVhXa1JnaUJmRHVNQmdPTzRzems2aG1IV0FpY2JjYTI0K25zN1hubGsx'
    b'N2diUVZHRmxBQ0FUSmJOejVNWlNwcEkKRExLSnNBZ2lJWkYxN1h0WFN3QndkTXV5VFJnaENm'
    b'czkxcUtLOFpPN3FMSHU4dnI1R1I2ZHMxcERVZkU5MjE3bGVhSElvbzBNSEhudQpnZU9XOHVh'
    b'cmJyZ3RQNzhnUi8xZkk1cW1VVUgwUGZJU0xnaFNCQjBRMCtWS3ZlbzN0MnRiR213Mm0wYWor'
    b'WWNqNUJXVVJQaUV1NmNOClJBRVZoUmtycngxKy9qRUFrSkE0SnlJa0JscWQzaitjdHRYTTh3'
    b'OTFwbmhTWTNYS05hcmplLytjVHFjeU1tdG0xd2NzRUEybFpTTUQKM1lIeEVabzBodjNqVHBO'
    b'YUxpRmNFOUZZTW12U3ltV0RyWS84cU5QWnNQQ21XKytZUW5IK3VVdmQ0L0dFZHg5T3U3MWRm'
    b'TXFJRUJXRQpRbm52WnVPODVyS3lzaSs3Z1BiMmRwN25aVEpaYlczdFYwWll0dm9iai81d2V6'
    b'Sk95WFJXdmNucU9uVkVRbURwTEt0WHllTHBMSWtqCmc3MmQ5dExhQlV0Vy9QRzNiUksxTWVu'
    b'dDRST20vT3BaUUNyZHJxR01mNmpVUklaR2U4ekZ0YXVXcmhNNC90TS92K0QzKzJtR2t4QjQK'
    b'ZldtZVA1SnE3UjdETWRRLzd2VjR2TDk1L09tcFF2M2M3WnREVVRUNjRUNFVFQWNxcmNlVXlO'
    b'cEY4U0t6UXFHWS9HdEg2d2V0VzI5Nwo2cjdyZUo0M21VeVZsWldIRHgrT3hXSmZIcUdzckJ4'
    b'VFdRU09uWDNSMm9tUkFRNlQxVXlyRDBSVFNoa1ppVVJIdWxyWlpJZ1JzQmNmCnU1ZE5oakEr'
    b'WTZtYVV6dDdDUUZjYVducFFQdEJSMUdodEdCNlZmTkNBbGlaaEh6cmo3OGJHZk5LQ0t5eTBH'
    b'alJLenVIL0tkSFExYUQKcXRTdTd4c0xGemxMY3pIOHYwQ1JTRVNhWjVCVk9uR1ZNb2xEMmYz'
    b'ZkxhdXBUaWFUTkUzMzl2WjA3SGpBSWUyOTJObE5sdDhjamlhMgpidDI2ZHUzYXZyNCtpcUsr'
    b'bkZXZk9ORU95WWxVZ29wSGcxcHpRV0ZKUlZkSG0wRXREOGZUT3FPbHRHRnVZOHRDejFCWEVq'
    b'UUZwZFhoCmNkZmdxYU9obE9nZGM0ZkdSeUtSQ0V2NU1wbVUzbVE5ZEdCZkxEQldhdGNEQWk0'
    b'ZkZVdlJaZmtHdTFIdFp4V05DMVlVNU9lM3RSMWYKdDJFVGlrNk43dE56dHlMTDgvekl5TWlr'
    b'R1VjUWhPZDVsVXFWU0NSSWtrd2tFa1ZGUmVQRDdjcXVhK1AyTzRqODVRY1BIdXpxNnJyawpr'
    b'a3RLU2twNmUzdm56NTgvNldYM2ZmYnBsaWQvWWl0eUpnTWp1Tm9pWktnQnQ3Y3MzekEwSGky'
    b'eDZRQWw1SGxsNHg2WDJlWUkrVno1ClpkTU4xa0tiemJMcnZUY1ZXUjhBaE9QcGNDeERFbGlC'
    b'V2MxeXd1ZUQ0ZW4xZGFsNEpKbWdDcXBiVEhwTktCajZ4YStmT0d1QmNuNzkKdjIyRk1NenBk'
    b'SDdsb05WcWpVYWpEb2RqOS9aWEE0ZmZEdmhzOHkvNHNIN2V6WUlnWEhQTk5ZY1BINzcvL3Zz'
    b'dnZ2aml6WnMzYjl5NApjZG15WmQ2eEVWSWlyV2xlNkRwOWNtSjBjTW42emNPUC9Sd0FNQlJo'
    b'RVltOXRGNnBWSTBOZGlKc2NzSEtLeVpjUFcvODRiZVZEUzJlCjB5ZEZVWlJMQ1lkRmExRExC'
    b'MzBKdVhPdTJhaGZzTDdnMGcxWFR0YUdsVXJsMU0zWHA4RGRsMkF3U0ZGVU1wSFFhTFdUOHg1'
    b'QmtFUWkKNFQveW9KWnRyN01uZS9OZW1ENW4xZWpvNk1NUFA3eDU4K2FhbXBxT2pvNlBQdnln'
    b'NjlpK1NEaElpaG1TbENHSVVGUmFiZEtyT2o0LwpVbWpXakFaaU5wTzJ2SG1SNitSQldrQjE5'
    b'ckpVMkZQZHZORHVyRG5XZXNEMStRNlRWa0V6M05IKzROckxOZ29vY2VjUGYzbyszYTg3CmQr'
    b'YzZ4M0U5M2Qzam54M0JYTDdNcVQ1c3hUemxtb3N3REp2OG1NcGtza1hmK3ROZzE0RzJuaTNE'
    b'UjdaYm5jMWJ0bXlwcmEydHFhazUKZE9pUVFxR3dXaXpId2g2emdzUlF1VTRwaTZlemZuZHY2'
    b'K0ZvclROdmFEeHF0eHFMNnVlemRJSktwSzNGRlFsUGo2TnhzVXdxZmVlMQo1OVVhSFlGakxo'
    b'L0ZjcnhCTGIzbXB1K2F6V1k0djNUdXp2V0JnWUh1N3o2ZzJOY0JBRGdnd29zL1hieHAzZDg5'
    b'Yyt2V3JXTmpZOVhWCjFTdFdyTmk1YzZmZGJnOEZBeS8vK3M1VUpsdGkxNDlGV0t0V3F0RG54'
    b'ZnlqQVNwbDFNZ2pDYnBwN3VMQzB1cnRXMTQwcVFpRjFxd3AKcU9IU1VkZDQyS1JWREEzMENl'
    b'bElVWjUyeEUrbHMremFxMis1OXFiL09NK29uN3N4cHlpSzNMSHVRM3o4RkovS2dzQjh1UDk0'
    b'Vzl2ZgpQWFBqeG8wMm0yM0ZpaFY3OSs3VjYvVXhpbnJ2VDM4WUhvL3FWREpTWTd2ODI5OURW'
    b'SmJaRjYwWFNZM0RvbzBrTWhLWmNueWdmZHZyCno1dE5Sa1JiSkZHYlRoL2RPZXFuM01OREtV'
    b'OVhvVnJJMHlrUG5ocHgrU2lUUnRGeDRBUC94TVI1UnYzY3pkd29pZ3J2UFN3Snh0UEEKY3lC'
    b'cVRudWluWDFlS1hCU1VxRlE0UGhmK2FhU2twSjkrL2JaN2ZheGtlR2Q3Ny9WYytLdzA2WVRS'
    b'U0NsU205Zkd5K0lxVmhJNE5qUwpoZ1VzTlpaTVp4M1RGNkdaaU5wZWdmSzBpSURSMmRqVVBE'
    b'TXgwbkY2eEI5TDBhSW9ZaWd5bzlKK2F0anZNTW05NGVTTTJmTnpjLzEvCnhmY2dpSGJsUWdj'
    b'cU1hQ0VWMlFHaFl4NHZJZmIvR0QvWGI4KytOcGJmWDE5ZnIvLzdNbHl1UnpEc1BmZjJmTGlN'
    b'MDk2ZW82VzJIUW8KZ2xpS3lqZmVlQ2VISytjdFdaUEpNR3BUL3FWWDN5Z1NDbEJhQmpvT1Qx'
    b'dDR5ZWpwZGxKblJ3blptS3YvdWFjZlV4RGk5REtMUmlHeApHVlVzSjRnaTZGV3lYbThpR3ZE'
    b'K3ZiaWpMemZYLy9YUzZYUmhHUjd1NkRiN0V5SUFDa2dVV0VyZ2hHR3Y0dU9qdm1NZENaRlB5'
    b'QW1hCnByVmFMUURrNStlLy9QenZtUEJJaVYwZnBOSVpocFBMWldrcUdQWlAwQXlEQ1dsTW92'
    b'am9qZWRGZ2MreldBcXJtMDhlMmpsL3hZWUoKenhpUEVOT2JtaE9lN3Y2eGdFYWxTR1d5RE1m'
    b'YmpLcWg4VWg1dnNIWnVIakR0VGNhRE1hdnZyN3djcEN1QVZTWm8vNHZsbGF2UzVYYgpJd051'
    b'c3k4R0FGa1FFNkpnUlBDRGZFempwL0M5YmFIZGgyaU9DZUtBa1lSR281RklKUEhSRG44MG1X'
    b'RTRaMW1WcmJnaUdBeExDY3hZClVNN3hzSGo1SmRGd2lKQ3BuTldOcnQ2MjZmTlhibi96UDNV'
    b'bTJ5Yzd0ME80WHlQRE5RcEp5YXpWU3krOWNuREVKK0hpWTZHa1FxR1UKeU9UcnJyaitxNjhz'
    b'c3hVeWJ3QnpBT1RYZmlVYW1iUlRPZXIvdkFpQ01OdnQzSXdxMm00VWVvY3RHVUdLb0R5QUFK'
    b'QVJCWmRJYStPWgorS0YyOW9NRElUYVROcWptemw5NDhQQmhuM2ZVYWRXaHdEWE1YcEtLeCtS'
    b'eWliM1EyZDEyUUFTRVNZYlRDV3J0dGQ4NXNYZmJ5S2g3CjRmTExaREtwbHZWNVF2SHhjTkpx'
    b'VUU1TVRGeC8ydzlYcjkwUVNvbDVGdXNsVjk4aUFsYmYrRGM5aytIRkFDaUlDY0RzUU5SOGNU'
    b'RDcKTVNRZkJlbXFjNS82MU9pUmRidmR3VEVQL2NubmthMDcxQ01CQUtCRUxpeXlFeUxqUkdV'
    b'U1FQVUlIbHRRVi96UUhWSXArZXlEdDJPNApSQlJGcVVRS0tGWllOcTIvNDVCY2dwYzFMVHB4'
    b'Y0NjR29sS3JUNGRHRStuc2NJaHhXclE2bVFnQW5tRDhjUGRZZlVuZS9EWFgzWDdYCkQ3NVVH'
    b'WGFCeUFFZ2dKKzV2MEp2QitvV0VOTUFBTkpsb0gwV0VCV3dweUIwSVpETm9IMFpNR3R1cnY4'
    b'clRMMVdheXNzWVBOTm1rc1gKMDVVRmlVeEc1Z2thZ1ZBZ1dFb1Voc1ZNSVNxVmp2Z1RLbW5K'
    b'a2dVS3ZkWGRjN3lxYWFIWmFrc240eTJMVnAwNjhvbWhxTHFzdWo3cQo5MXFLSzB0clp3NTN0'
    b'eVhTVEtsZGJ5aHJqcVY1a1k3cFZUSkNybTJvTHZHTVQ2ejR4dm92MmV3RWhDOEVlaHVRQ3dB'
    b'emc1aUV4TDBnCkJFR2tBVVRnaGdBdkJWUVBpWHVBNndjeENaS0ZnQlhscVAvTFFucTlYbTgy'
    b'bTJWRmR0V2lXZHo4aGtRaW9YUk5xQkZzVE14R1JZNUEKRUl3Z1ZFdG1OODlza2FxTUJ6NTh3'
    b'Ky91NFhtQkN2c1p5bU1ycVR1eDYvVk1QQnlub2pXTnMwYjd1eVFxSGM1bG1LaW51S3BCWFZo'
    b'SApKZEtwTEw5NnczV3VFN3M1VWx0ZVdYM21tYk5BYndQZURkbmRnT1lCZXh3eWZ3WXhBOEFC'
    b'QUlBQTdDbGdQb1hzQVVCSVFBaFEvUndRCmFZNzZmMHNzeTQ2TmpVVWlFWXFpSXBFSWdpQkdv'
    b'OUZnTU9qeWJjU3Mya3hWVWVab3B5VERob0dWSVppcXV0UncwVHlkVGxkVVhGTFIKTUx1bnI4'
    b'OWFXTDcycWh1UEhHbGR2ZUZhLzRTSHcrUXlsUjRFbHFKaXhkVXphWWtCeDRtdzYyU2NvaGFz'
    b'dnVyR1cyL2Y4c2JyWW56Ywo2dzh0WHZHTk00SGJOc2p1QVRFSlloeTRidUFHZ1I4QUJEOURY'
    b'UVFFZ0hNQkNJQklBSkVDS2dWeTFqbE8vZHl0dzJjeW1lNzJqc2luClIrRzBtL0g2RVFRaHJH'
    b'WlhaWkZpZG9PeE1OOXF0VTZ1T3VIK1VkWis5MU50WEVJbkV0cVZDODdlNFhZVU8zL3g4TFBm'
    b'dWVHNnZkL2EKYUZIQzFtZC94YVFpcVZSNjNxcXJMWVdsbm9IT2hVdVh2L1hLOHlCVFdSb3VS'
    b'cG1VdzFHMDhkS1ZwVHJCUFJHMVpLVjc5dXhac21RSgpnQWhDRU1Ua21SeDlDTkMvYVlrWEJR'
    b'QUJBQVVRUUFnRFZnWUFrSDRacEtzQk5aeWJrZDA1WFlmdnV2N0hjTHlYQm9FU09RMkNXeEFT'
    b'CkFHZ1NReTVvSkJZMjYrYzJhUTM2ZUR3K3ZPRU9qVGZDWEwzTWR2UEd5c3BLaVVSMmRwQllM'
    b'SGJ2clplSEErTjlZNkZwRG5PS1pndnoKTkRURHlTVUVKeUxlQUdVektnWEF6YzQ2dmMzWjlz'
    b'azdJNTRKVEdsKzlqKzN0TGEycmwrL0hzTUFrbzlCNGlFQTRVeFpTdzlDQkJBcAppQXlBZU9Z'
    b'QkQ0Z1VSQnFBQVBWOUlHWWgvUUlRMDBIM1dtNnVmMjNiTG5ZTlVTS1hCSjRYeFZLVU9Na24x'
    b'UWllb25uOXpvTjV1NDZOCms1akxwTlY5YTYwd3V4YWZXVWZVNkdqL3plMnhqUzBMYmo4N2lF'
    b'YWowVm9jZkRwUzU4d0x4ek4yb3lxV29obVc1M2todzNBb0NqVEQKaFdNSlgvQXprL2J6dnVF'
    b'SnFjYjhnNS8vY21Sa1pNV0tGYnQyN1ZxK2ZBbGs5NTlKd2NVdkhQbGY4bkw0MHBFemhjN01t'
    b'OEQxQWdESQpyOHBWWkwrMnBGS3BtS2VUSXFnRklYVUl6b0dvUmZDNHlER2lrSWVRSDNPUmRE'
    b'YXI4MGIwRlNVMVA5eXNucVZUaXZlOXVNTkk4bHRqCnNmQ1h4eWtxcVpCSmNJV1VOR25sUTk2'
    b'SWhNRFZDb2xhSWRHcHBCSUNIL1hIcVdTR0Y1Qmpyc1NHYjk3MnV4Zi9sRXFsZFRwZE1CaGsK'
    b'R0laaEJKQXMrYXZDaTVBQ1JBWWduZ0UvK1lBQWtRRkFBVUdBNndXUkEwUU5uQ3RIL1o4S05X'
    b'MW0vZklGbHU5Y1lWdTltTldwSEtpMApBVk1Xb0pLUXlHb1IzSVFRaVpacTFHazM2SEFrK2NC'
    b'MXY2eDRZWnYyVUsrbDQ5QnRxVlRxN0NDMWpTMFp3QUJFSEVVbE1qbXFLZUI0CklaUGxBRUN2'
    b'a3FVUWxkcG9LMnBjL05xYjd5MWZmV2xiVzV0V3EzM25uWGU2dXJxV0xWdTJhOWR1NE4xbjNx'
    b'Vko4Q3dBQ245eGkrSmsKZ25IMkpZUElBWUlCN2dERkRia3F6ZGZXNE9DZ3QvMlVxYVppY28y'
    b'SlJKUktIV3FQYlA5VWNyU2JFSUFITVZYcjFOOXo0NnlMRmgvWgpzL3lGRHd5djdTQUJBTWV3'
    b'bDM3cUxUSkxMY1cvS0s5c0FvQklKTkwzV3N1SG5ZNXdNS3JVbWEvODduMnZQUEtEVklKU3lj'
    b'aFlLbXV0Cm1qMTN5ZXJpNHVLaG9hRjMzMzIzc2JIUjdYYlBtVE5uOGVMRmZyOS9lSGg0L3J6'
    b'cGtzUUs0UG9BMEM5bU5pSURrUWJBQURoQXlDOXEKT0lBQWdvUElBWUlDSUlBNVFQOGVZSmFj'
    b'WC85NmNqZ2M2WFRhWkRMRllySFMwbElBR0RXYjhsWmU0T3NkU0hjUElnWjE2ZXltWXFlegov'
    b'Y2hqYVY3NjJnN3k1OTlkKyt6cmU2ZFY1TC9iT2wxUFBWT3BYV3kyV21UT0szRlU0OFJwWThV'
    b'RkUrR2RGdWUwaHVsTmg1b1dEYlorCkVFdGxOUXBwUEI1cmFHall1blhyME5EUTk3Ly9mWXFp'
    b'cXF1ckd4c2J1N3E2WkRMWi9QbnpqN1crTmIrK0JDQUQzTmhmTzNJUkFFRGsKdjRqZUFRV1Iv'
    b'd0sveUFKZUFvZ3NOOWYvR1ltaU9EQXdRQkNFdytINHlwZWJKcFZLaHJ0YkYxMTBSM1VzaWNs'
    b'bFpEckRBQUNLSWtLVwphaWtZdi9FQ2YxTUJiVklqdnJpTXFYcWlkdWJGazgyczJXejJXNWRm'
    b'WWlWVE9BWVplZUVUTDd4KzdOaXh5c3JLam80T2tpUnJhbXBPCm5Ub1ZqOGZuenAzYjBkRWhD'
    b'TnpDK3JjZyt6R2d5alBnUlVCSUVObS85cElvZ0FnSStzWG5nQ2dINDJjQVJNNnZmMjBORFEx'
    b'WkxCYUcKWWY0dWNnQTQxZlpFU2RXbWNtY1pBTmp6OUtzWE55SUk4dUJkR3lRS1E5YXcvQUQv'
    b'c3lmMldFNjRpWkY0MWpsK3k4cy9xWC8vOVY4RApnRVFpdVhHVnVyalNMQ2p0ZGtjcEFNeWNP'
    b'WE5nWUVDbFVobU54ZzgvL0ZBaWtWUlZWVDMxMUZNOVBUM1pMT3VtN2diWlJoQnB3T3hmCnl0'
    b'RW40emdFUVBqTGI1R2Z6T3NCcndCUnlOWG0vaGxSRkJXUHg3MWhiNzRsLzI5YlZEbU85UjIv'
    b'cGJqcXlldXZYc2x5L0o1RFhka3MKRzZHU0o3cmN5WFIySWtnTmp3WTIxdlFjSGRIdEMxZVNC'
    b'ckNVYjA3NzIvMmUweko5U2VyVW80VTFTNjYrL2JkekYxdzRPUnBCRUdOagpZNisrK2lyRE1C'
    b'YUw1ZGxubitWNXZxU2t4R0t4MU5UVUlKQ0U5Sll6NXAzLzY4d05PWU4vOHZ2VUFxQTYwRHdN'
    b'V0dIT3duOXR1ZDN1CnlZNkpxMzU3bFY2dS8vYWliMTgwNXlJQXlESlpDU2tCZ0xaOXI5cE8v'
    b'MXkvNGpCcDFLRXl5YWV0UGRmYzhheG5Jb0poYUYxbFlYdTMKdTY2eWNJbm10VmU3WnRZM05K'
    b'ZFpQcXRDdXpRb3VubzZjMlJJc3F5V2JodFYwWXc0RUZCSTdRdUxwbTlpR0NhVlNsVlhWNU1r'
    b'U1JDRQowV2dVUlJGSDR5Q21BWkZEOUVvUVFzQzV6aFJpLzlaa2luLzVLQ0JxTUd3SG9qNlh1'
    b'WDA5cFZLcHlWRE9ZckVZbGNZUmF1U2h2US85Ci9xM2ZNd3l6NmQ1TnV3L3ZCb0RNNkh1S2l1'
    b'c0p2ZWJ6dVpzOHYzdjl3dG5WSjNmOGN0M3lHWElwV1Z1Ump5Q0kzYUw3MkZXZjV1UloKaG4z'
    b'bUhlT2hTS1dwZ2ZodDV5d0d0K3djY0xUeDE3dTRGa1JSTURRMEhJdkZNcGtNQU96ZnYvL1Vx'
    b'Vk41ZVhrWWh1RTRCb0lQNGorRQp3RFFRNHNENy9vSThna0lmQVgwa1JMRXpCdUJMazRlb0Ji'
    b'enluRTZKejAwTFQ1S2t5V1NTeStVQTBEdlVPOGFOcFVLcGdjeUF0OWZiCnpYVDN1SHRXTmEr'
    b'SytwOXdMbjIyLzN1UFVQcy9MNzduRmdEQWs2a3JyN3JJWkZBLy91SU9odVVHM2Y0NHE4d3dQ'
    b'SjFsTVF5TnBndE8KREJmVjVMVzFHRHo5VVJyWHFFMmxteFRXR1liOCtrbjNnU0NJVkNvZEh4'
    b'OGZIQngwdTkweUdhbVJ0Z1BUQVFJRllnVEV4QmN2TG83QwpFQUVNQWd3Q1VSU1VDRWhKQUE0'
    b'UUJhQXFRTFdBTzBDNkJoQWlSLzJmbDRwVTdlbmVnMGdSSnNFRXc4RzBrR2FsTEJJVTZvcjdt'
    b'RmJuCjhNOS9XM0xmZjVpK3NianI4anM5VDcyYWY5T21wanJudXVVelc5c0hRNUhFUTNkdjJu'
    b'T29hODNTcGxBMGlTQWdrK2xmMlMyYlpSL0wKYW5XRTNEbnV4eEtKUkRRYXhUQk1LcFVDQUlx'
    b'aWFyV2FKRWtFUVRvN3U0RlFrZWhBbGhIVDZWaVdsU1V6cWdDbGk3cklLSVZIYWVLTApuNVE4'
    b'aXNpakNXazBiWTJtekZHNk9jcHVpQ1lOMFZncW5zeG8xZktjWC8vYXl0Q1pkVDlaUjhySmJE'
    b'b2JFMk55UWM2YTJHd3NPMGRiCjlQQjE1T0ZtdDJwNmRmMzJaOGFlK09QUVQ1K3NlZlZodzdM'
    b'NTdnZWZLZnJCRFlKTWVzOGpiejMrMGc2T0UxQVVBUUJCRUcxNXVuRi8KTkYvdWZlVkI3NUhl'
    b'YStycXBwOEpETG12dEZwekhEYytQajRSaksrNzdES3BUSDc4bE10czBCUVhtRktaN0lnM3BK'
    b'UkpDdTNHOW02MwozYUkzRzlTVGwzVDNlNlJTd21FekFrQWtuZzZFWW5WVmhVVjJZNDc2LzY4'
    b'T3RmVm5zc3prNCtkMi9tcGNkUEVNcnlKVmFYY2FMOGZwCkdEMVBqMzlmQjRNUEVUT092cFVk'
    b'RDV4WWZLM2xpdFdWdi85NTMyMzMrMTU5cjNIdkgxWFRxeEFVL2VSd3p6VjNQaU9LY1AzNmhR'
    b'LysKN3IwZmJGNzF4RXNmLys0dXIwRExaTG9OV3EyMnRiVzFzTEJ3ZUhoWUVBU3RWanMyTnVa'
    b'd09BS0J3UFRwMHlkWE5Zckg0NWRkZGhsQgpFQm1hU2FSb3JWcE94ZE15S2VueFJjcUxMWU1q'
    b'L2p5ajVtakhZSUhWVUYxbTkwNUVSOGRERXBJZ1NielNhY1Z4TEdmaHY0WUtiUVlxCm5zNHkz'
    b'SUpabFhaZDNyNkIvYWdFVGNWVFJCNGhpVW80R1RkTkRSVUQ4ZnpiSDFhVUY1MWNzNW5RYVd1'
    b'M1BCN2VzWC9vbmllY1A3c2wKYjkzRnB5NzdqNnd2MkxCKzZiWHJGaHp2Y3IzMDVuNUJFQTYy'
    b'OWMrcDQ1WTNEbnFpYSt6MmZBUkJCZ2NIVVJSdGJXM3Q3T3djSFIyVgpTcVdSU09UdzRjTlZW'
    b'VlY2dlg0eXVSOGVIaTRyS3pzOU5KNUtaM2xlNk9yelNFbENRdUlSS3FuVEt0cTdSK3FyaS9L'
    b'TW12MUhUeU1vCk5OYzZ1d2M4RlU2clFuN3VMbGh5N3ZwMXExbGJYR0E2MWpHVXBTVWxXbnZI'
    b'UUFkQjRueUdsNnZrbk1oVnFJWFo1YldtZGQvcnUvWCsKZUd0SDNiYmZJUmphZWVtdG1wbDFG'
    b'VS8velBQMDY5N250bHF2dmtSV1hJREY0bGRkdVRUUHFQbWt0ZHRpNUY2OHU5Mlh1RTZyYzRU'
    b'RApZWlZLNWZWNmNSeTNXcTBsSlNVTkRRMkNJRGdjRHFmVFdWaFlPT25wQWNEbjh4VVZsL2U3'
    b'SnF3bWJaSGQ2Q3cwYTlVS0twNGVHZzNrClcvUVZUbXRIejBnaVJjK3NkNG9pSEQwNVZPYXcr'
    b'RU54czBIOVh4V1hjaGIrdjFRb21tanZIZ0ZFNURrUlJaSEgzcmtuTGd0eVdVN0cKeUVSS1hO'
    b'bVF2ZnZHMndNZmEzcSsrYVBTaCs3TS84NlZIU3R2U0hVUHpqanlKaE9Nbkxqd0d2UDZaVlhQ'
    b'Mzk5MzYzM0I3Wi9PN3Y0QQpVeXI2QjArblBaZjNqRnlFeTVyQzRUQk4weVJKb2loYVdQaDN5'
    b'aW5oY0pobFdSekhXWmFOUmltdHVhaklXVGxaSko2TTlnVkJSRkVFClFSQlJGRkVVb1JKcGpV'
    b'TEdzRHlPb3hpR2xoVG1GUmVjdXd0Um5ydDNYNHc2MWRKNTAwYkNJemF0TFphT3ZWTDl3aU52'
    b'UHJKL2FIOGEKU3lNbUJKRklPU3JVLzkybjlVdm1GTngyMWNqREwxSUhqazk3NHpGY3ErNVll'
    b'Wk9rd0ZMKzJBK0QyL2FNdi94bjV5OXVRK1V5NzdPLwpKV2E4MWpOeUlSRDFvVkRvN0JMeERN'
    b'UDRmRDZMeGVMMWVnT0JnRXdtQ3dhRDFkWFZKMDZjbUROblRsdGJtOVZxcmE2dWlrUWlDMmVX'
    b'CnV5S3VTbXRsNzNodmxhMHFrb3JvRlhvcVRXbmxXaEhFUkNhaGxxa0ZVUmdOanpxTWpuTThM'
    b'VHJYMTFGUlM5VVpKdE0zMFdmVUd6ZGYKdHZtZVZmZlVGdFJLMUpKQWxBdHUzNEpLeUtybjc0'
    b'dC9mc3IxNERPMmIxMW1Xck5vNFB1L3liZzkxUy8vaXFNU2ZiZmVyMXN3by9DTwpiNDY5Y2Vl'
    b'RTVkRlhkaFNwOUJkR0lwRXY3d3BBa3FUVmFrVVFSSzFXZDNWMURRd01mUGpoaDVsTXByKy9u'
    b'NktvM2J0M2QzVjFBWUJlCnIzLzc3YmRKakF6RlEwcXBFZ0M2UEYzajFIaVhweXZEWkVLSlVD'
    b'Z1pvbG02YjZJUFJhYkEwalRuK2pxeU9vVU9BRXJOcFNPaEVVRVEKNXMrYVgyd3ZmdVhqVnlq'
    b'dk1id3dXdm5jMDZoYzFuUDlqK1dsUmFXL3Vpdnc1OTIrUDc1YjhzRDNWQTFWSFN0dkFBU3FY'
    b'dnhCMi82RgpKOExEYjNaWVVZUWFPL1plaWJ6azd6NVJKQkpScTlWT3AxT24wMDEyWWZNOHYz'
    b'TGxTcFZLZGZiekljU0YwZlNvUXFKSTBJbTZncnJPCnNjN2EvTnFUb3lkbk9HZmdHTjQ3M3B2'
    b'bHNsWFdxbk9mK3BSWkgzNS8zLzVxVzNVZ0h2am9zNC9lN1g0WGdzbTNibFRaWmh6c3VmN0gK'
    b'd2ZmMk5uMzJLcTVWZjk2eVFkVlFWYi85bVpHSFh4eDk5R25IYTFXOXlYMWJPeFJIK2toY2dV'
    b'dGtFbFNHenJQTm0xYzhMeGFMb1NqSwo4M3cybTFVcWxaTkoycGVUZGIvZlA3bWVFY2R4Q29X'
    b'Q1lSaXoyYnhvNlNJcVRla1ZlbzduWXBtWUtJcG10WmtYZUVFVVl1bVlYcW5ICjBhbXhCdmZV'
    b'b0M2SWdpQUsrL3YyTnhZMThnSy8rK0R1N1IzYmI2azdWUko3c1BmYlB5MTcrRzc3VFpzNmxu'
    b'ODdkWHA0eHRHM29zUHYKTWUyLzZkWkYzKzlXdElWMUhBSzRGRWRRUkdBRmlWWUNIRHg1eFpQ'
    b'TnRjMFRvUWtCRTdSeXJXZlVFd3dFYVpwT3A5TTRnY3VrTWtKTwp6R3FjUmRFVWlaRUNMOFFq'
    b'Y2JWR25jV3lPSW9mOHh5Ym5UOGJSZEREQTRlbk82YnpQRTl6dEUxcjYvWjJOem1hWUlwb0t1'
    b'MEY0WS83CkEvR0FRV0ZRU0JVRVJ2VHN1eHgrNmlWdExYVnZQK3g5N3VINGtWZnhhd3p1cFBl'
    b'MFJ6emtWdzFGNUtSR0t2QUNvU0NpL1ZGOWhUNFQKeVFpY1FDaUlhNXF2K2VhYWJ3NzZCd3NN'
    b'QlFnZzhVdzhYNStmeXFZVUVvVTc1TFpvTEoxam5TWG1rdVB1NDQxRmpTaUs2aFY2ZDhoTgpr'
    b'aVNPNGZGTVhPQUZobVVLREFYSGhvN05MWitib0JNWkpuUHVSM0JUbFRvQXhES3hVQ0tra3Fw'
    b'R3dpT2M2MTE1Wmlzdk1ZbVlaTlFkCk8rSkw5RkRTb0tCQWNFemtSWjdsRVF5UmFxWFplQllC'
    b'SkJWSTZVdjFYSmJEWmJnZHR6OTV3NU1tdmVuSTBKRVp4VE5PanAxc0xHcHMKYzdVNXpjNXdN'
    b'bHlnTDVBU1VnRHdScjF5aWR3YjhWYlpxdHdoZDRtNXhCLzNKK21rdytSZ09YYkFQMkRUMmlh'
    b'b0NiVmNyWlFxZFhKZApqdnIvY0NxZkNMRThxeVNWRWx3U1RvZXRXbXNrR1RsOC9QQ3g0V1BE'
    b'Z1dFLzVVZFloQlpwWHNZekNRWUFVQkdsd3pUTHNlYUdMMWFUCjBndjYrU1h6QzgyRjRVUzR6'
    b'bEhYVXQ4U1RvV0hBOFBOeGMzSGhvN1YyR3RTMlpRbjZxRlp1cjZ3bnNDSVBsK2ZRV2tnY1pK'
    b'bTZVUW0KWVZBWklzbUlScVlCQkNTNHhLQ2NZanYrVGtucTQ5UzRUV3M3N2o1ZWxsZldPOTQ3'
    b'czJUbTBhR2orYnA4RVVTYXBaT1I1RjJ2MzVWaQp2bWlPNXRJY1R1S2tsdVF5SEtFa2tEUmlW'
    b'OXNOQ2dQTHM3NllqOElwSklqODhhNC9odGhRdGIxYVNraWpxZWlnZjdDcHVBbEZVQi9sCmsw'
    b'dmtWSnBpT1paS1U2VjVwUWlDa0RqNStmRG5MU1V0SjBaT3RKUzB3QlRVVk4zWlN3UnhPREFz'
    b'SmFSMm5UMFlEMklZUm1BRWp1STkKM2g0dXhYMTA3S1BlaWQ1RUtwR2trcnlLRndRQkpWQ2xW'
    b'SGxwMWFWWFhueGxrazlpQ0phbnlVdG4weTl2ZTNuTFIxdGVlZUNWUW50aAorMGk3dytUd1JE'
    b'dzE5aG9NeFlLSklBSUlnaUNwYkNyRFpLcHNWUXpQZEl4MEdKUUdpOFlDQUNST0VoaVJvLzYv'
    b'clM1UDE3VDhhWWNHCkRqVVVObmlqM2pKTDJaQi9xQ1N2SkphT2FlWGFWRHAxcVAyUXkrOXlo'
    b'VjE2bVg3bHJKVTFaVFUwU3djVFFWZlExVkxTMHVYcGFuUTAKY2dLSG8vamtVQ3pQZG85M0V5'
    b'aVJyODlQWjlQQlJMREtWaVdJd3U2dTNhc2FWZzBIaHd2MEJhMkRyUXNxRnNCVTFwVGZ4WS9s'
    b'MlI1dgpqMEZwaUdWaUVsekNDN3hPcVlza0l5cXB5cUEwZEl4Mk5CYzM0eWllNWJKcEpxMlQ2'
    b'L2IzN1o5Yk5sY1FoWk9qSjV1TG02azBGVTFGCjlVcTlJQWl4VEV5djBDZm94R1RjVG1CRU9C'
    b'a21jWExRUDFodUtTZHg4dE9lVDVmVkxXTjVkb3BPOFNsVGtmMkhJakNpdnJBK1g1K3YKbHFs'
    b'UkJDMnpsQ1V6U1lmUjBUL1JUN04wWFVGZG42OFBBQVltQm5xOFBiekFsK1dWRGZvSENZeW9z'
    b'RmF3QWh2UHhQTTBlUUFnSVNUQgplSkFUT0kxTVF6TjBKQmtaRFkzNktCL0xzMmFWdVhPc2sy'
    b'YnB4VFdMSjU5eHFyOXBVNTc2WDJxM2NsMkJvV0NDbXVBRUxwS01MS3hjCm1HYlNjbEt1bENw'
    b'cGxzN1Q1czBxbWNYeXJGd2lsNUpTVHVDR0FrT0pUS0xRVUhoNi9MUkdwaGtManpVN20wZkRv'
    b'emlHRXhpUm9CTTYKcFM1Zm4zOTYvSFMrSWIrbHBFVWowNXdIdk04MzZrcXBrc0FJbTg1V2JD'
    b'cG1lQ2JEWkh5VUw1cUtScElSQ1NISlpET2lLREk4TStnZgpOS3ZNV1RaYlpDaWkwbFE4RTNl'
    b'WUhMRk1MTVdrUEdGUFhVRmRnazdrNi9NblloTU14d2lpTUx0MHRpaUtHSHBlYmZDS3dua25B'
    b'aU1jClJvZENvbWh5Tktsa0tyMVNuNlNUc1V3c2tvd0U0b0VLUzhWcDMybUZST0dOZXAwbUo4'
    b'dXpXcm5XSFhRM0ZEYTR3MjZHWTRMeElBRE0KS1p0alVwbU1TaU9HWWxQaU50clhFZzdudFhB'
    b'VUx6SVVBVUJ0Zm0wMEhiWEpiSEpTam1NNEFHU1lEQUNFazJGZTRHMDZHeS93czB0bgo0eWhl'
    b'YmErZXZQQThmbHVtZkF5ZlU4N0M1L1Ivd01LZjZISS85UHYzdFdyNWpWY3NldVdkQTU2SnlG'
    b'MDNySnpiWEE0QW5hZEhIM2pxClBaMUc4Y09iVjArMnNPM2MzL25vQ3g4MVZCZHRYTlh5NkI4'
    b'K1FoRGsxY2R1SGgwUFBmTENSeXpMLy9MN0crTEp6T012N3NpMzZ1UEoKak1Xa3ZmV2FwWjhj'
    b'N25ua2hROHJTMncvK2M0bGovN2hJd3hGTVF6MVRrVHV2R0ZGWllrdE45Zi9QV3FjNXFnb3NW'
    b'NjBvSFpHblhQTgowcVl5aDJVU09RRFVWUlpXbDlsWFhGaC90bXZ4NGdWMWNwbmsyblh6bTJx'
    b'TG02WVZLMlNTeDE3OHlKRnZ1bVJwMC9JTDZqVXEyVlczCi8vNG50MTV5OTAyckhyaHp2V3Nz'
    b'c0dWNzY2STUxUWF0OHZJMXMyT0pkREFjdi8vT3krNzkzbHE5VnNtd1hNN0MvMXYvZ1RPN3RT'
    b'SUkKZkdVN05RU0JyL1FtVDNhMUFnQ0NJRCs2WmMyT3owNTI5SXdnQ0tBbzBqM2dOV2hWZWNZ'
    b'dk5nTGR1S3BseS9Zalp5OHBzQmtHUi96TApyL3ZOdzg5L3VIckpkR2VoT1VmOW5OT0J6L3Yr'
    b'NFJFTVEvL3dxeHR1dnVkbE9zdkNseGNVK252eWgySlAvZUxheDM5NmxVeEszdnlUCmw0OTFE'
    b'T2VvL3pzbGlPSmtHdkxsWEdUYnJyYXZISGx2OTNFQUVJU3pKNHVDSUJRWG1HNithc2s5ajd3'
    b'RkFOV2w5bEEwNFF0UWsrZS8KOFg3cnB0VXRaeS94QmFnSG50cFdXV0s3OVpxbFAvN09KVDJE'
    b'M2x3MDkyL1Q4Vk91MDBQajQvNm9QVS8vL3U3amFacDUvbzFQQXVINAowWTZoenp1SFcwOE1C'
    b'TUx4bmdIdjZhRnhBUGg0WDJjNmszMWh5NmVYcjVsenZNc1ZqYWZ1dm1uVk5Xdm43VHZhcTVC'
    b'SmNCeDcvWWxiCjduOXFteTFQRzA5a1NvcnlOcTJlL2NuaG5qQ1ZmT1dkQSt1V3p5d3Z0dHo1'
    b'NE9zRWpvZWlpY2Z1dVRLWHIrZVVzL0E1NWFqbmxLT2UKVTQ1NlRqbnFPZVdvNTVTam5sT09l'
    b'azQ1NmpsOWJmMC8vSjkycTRuRWxRTUFBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmxBREl3TWpN'
    b'dApNREl0TWpaVU1UZzZNRFk2TkRnck1EQTZNREM3U2phaEFBQUFKWFJGV0hSa1lYUmxPbTF2'
    b'WkdsbWVRQXlNREl6TFRBeUxUSTJWREU0Ck9qQTJPalE0S3pBd09qQXd5aGVPSFFBQUFBQkpS'
    b'VTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlODMzNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_IL')

US_IL = b64_US_IL
index.append("US_IL")
index.append("United States of America Illinois")
catalog["US_IL"] = US_IL
catalog["United States of America Illinois"] = US_IL
country["United States of America Illinois"] = ('US_IL', '', 1)
lookup["US_IL"] = ('US_IL', '', 'United States of America Illinois', 1)
lookup["SpringField United States of America Illinois"] = ('US_IL', '', 'United States of America Illinois', 1)
lookup["United States of America Illinois"] = ('US_IL', '', 'United States of America Illinois', 1)
details["US_IL"] = {"continent":"Americas","capital":"SpringField","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_IL"] = ('US_IL', 'United States of America Illinois', 1)
regional["United States of America Illinois"] = ('US_IL', 'United States of America Illinois', 1)
#----------------------------------------------------------------------
b64_US_IN = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iNjAwIiBoZWlnaHQ9IjQwMCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3Jn'
    b'LzIwMDAvc3ZnIj4KICA8cGF0aCBmaWxsPSIjMDAwZjVkIiBkPSJNMCAwaDYwMHY0MDBIMFoi'
    b'Lz4KICA8cGF0aCBkPSJNMzYwIDU1LjU0aDEyLjc2bDQuMjEtMTIuNDcgMy45IDEyLjUxaDEy'
    b'Ljg1bC0xMCA4LjA5IDMuNjEgMTEuODUtMTAuNTMtNy4xMy0xMC40NCA3LjE3IDMuNTYtMTJ6'
    b'bTU2IDUwLjFoMTIuOGw0LjItMTIuNDggMy45IDEyLjVoMTIuODVsLTEwIDguMSAzLjYxIDEx'
    b'Ljg0LTEwLjUzLTcuMTItMTAuNDMgNy4xOCAzLjU1LTEyem0yOS44MSA3Mi4xaDEyLjc3bDQu'
    b'Mi0xMi40NyAzLjkgMTIuNWgxMi44NWwtMTAgOC4xIDMuNjEgMTEuODQtMTAuNTMtNy4xMi0x'
    b'MC40MyA3LjE4IDMuNTUtMTJ6bS02MC43IDI0LjJoMTIuNzdsNC4yLTEyLjQ2TDQwNiAyMDJo'
    b'MTIuODVsLTEwIDguMSAzLjYxIDExLjg0LTEwLjQ2LTcuMTUtMTAuNDggNy4yMSAzLjU1LTEy'
    b'em00OS4xNCA1NS41OUg0NDdsNC4yMS0xMi40NyAzLjkgMTIuNTFINDY4bC0xMCA4LjA5IDMu'
    b'NjEgMTEuODUtMTAuNTMtNy4xMi0xMC40MyA3LjE3IDMuNTUtMTJ6bS00NC45NiA2MS42OWgx'
    b'Mi43Nmw0LjIxLTEyLjQ2IDMuODkgMTIuNUg0MjNsLTEwIDguMSAzLjYyIDExLjg0LTEwLjUz'
    b'LTcuMTItMTAuNDQgNy4xNyAzLjU2LTEyem0tMzQuMzUtNDcuODFoMTIuNzZsNC4yMS0xMi40'
    b'NyAzLjkgMTIuNTFoMTIuODVsLTEwIDguMDkgMy42MSAxMS44NC0xMC41My03LjExLTEwLjQz'
    b'IDcuMTcgMy41NS0xMnptLTMyLjYgODYuMTJoMTIuNzdsNC4yLTEyLjQ3IDMuOSAxMi41MWgx'
    b'Mi44NmwtMTAgOC4wOSAzLjYxIDExLjg0LTEwLjUzLTcuMTEtMTAuNDMgNy4xNyAzLjU1LTEy'
    b'em0tODAuNzMgMGgxMi43Nmw0LjIxLTEyLjQ3IDMuODkgMTIuNTFoMTIuODZsLTEwIDguMDkg'
    b'My42NyAxMS44My0xMC41My03LjExLTEwLjQ3IDcuMTcgMy41Ni0xMnptLTI4LjgtODYuMTJo'
    b'MTIuNzZsNC4yMS0xMi40NyAzLjkgMTIuNTFoMTIuODVsLTEwIDguMDkgMy42MSAxMS44NC0x'
    b'MC41My03LjExLTEwLjQ0IDcuMTcgMy41Ni0xMnptLTM4LjI4IDQ3LjgxaDEyLjc2bDQuMjEt'
    b'MTIuNDYgMy44OSAxMi41aDEyLjg2bC0xMCA4LjEgMy42MSAxMS44NC0xMC41My03LjEyLTEw'
    b'LjQ0IDcuMTcgMy41Ni0xMnptLTQ0LjEyLTYxLjY5aDEyLjc2bDQuMjEtMTIuNDcgMy45IDEy'
    b'LjUxaDEyLjg1bC0xMCA4LjA5IDMuNjEgMTEuODUtMTAuNTMtNy4xMi0xMC40NCA3LjE3IDMu'
    b'NTYtMTJ6bS05Ljk0LTc5Ljc5aDEyLjc2bDQuMjEtMTIuNDcgMy44OSAxMi41aDEyLjg2bC0x'
    b'MCA4LjEgMy42MSAxMS44NC0xMC41Mi03LjEyLTEwLjQ0IDcuMTggMy41NS0xMnptNjEuODUg'
    b'MjQuMmgxMi43Nmw0LjIxLTEyLjQ2IDMuOSAxMi41SDIxNmwtMTAgOC4xIDMuNjEgMTEuODQt'
    b'MTAuNTMtNy4xMi0xMC4zNiA3LjIgMy41Ni0xMnptLTMxLjQzLTk2LjNoMTIuNzZsNC4yMS0x'
    b'Mi40NyAzLjkgMTIuNWgxMi44NWwtMTAgOC4xIDMuNjEgMTEuODQtMTAuNTMtNy4xMi0xMC40'
    b'MyA3LjE4IDMuNTUtMTJ6bTU2LjQzLTUwLjFoMTIuNzZsNC4yMS0xMi40NyAzLjg5IDEyLjUx'
    b'SDI0MWwtMTAgOC4wOSAzLjYxIDExLjg1LTEwLjUzLTcuMTItMTAuNDQgNy4xNyAzLjU2LTEy'
    b'em03Ni40NS0yMC45M2gxMi43N2w0LjItMTIuNDYgMy45IDEyLjVoMTIuODZsLTEwIDguMSAz'
    b'LjYxIDExLjg0LTEwLjUyLTcuMTItMTAuNDQgNy4xNyAzLjU1LTEyem04MyA0NC4zMS0zNy43'
    b'MiA1My43NC0yLjM0LTEuNjYgMzcuNzMtNTMuNzJ6IiBmaWxsPSIjZDU5ZjBmIi8+CiAgPHBh'
    b'dGggZD0ibTQyMC43NSAxMTYuNTUtODcuNjUgMzMuNzEtMS0yLjY4IDg3LjY0LTMzLjcxem0y'
    b'MC4xMSA2NC42OC0xMDYuNTktMTIuNzcuMzQtMi44NiAxMDYuNiAxMi43OHpNMjg0IDI5OGgx'
    b'Mi43Nmw0LjIxLTEyLjQ3IDMuOSAxMi41aDEyLjg1bC0xMCA4LjEgMy42MSAxMS44NC0xMC41'
    b'My03LjE3LTEwLjQ0IDcuMiAzLjU2LTEyem0tNC0yMDVoMTUuNzhMMzAxIDc3LjU2IDMwNS44'
    b'IDkzaDE1Ljg3bC0xMi4zMSAxMCA0LjQ2IDE0LjYyLTEzLTguNzctMTIuOTEgOC44NSA0LjM5'
    b'LTE0Ljg0em0tLjM0IDg2LjE3LS4wOC0uMWMtMTIuMjEtMTYuMTMuMjEtMjIgLjQ2LTMzLjQ2'
    b'IDguMDggMTUtMy43NiAxOS42NiAxMC4zMSAzMy41N3oiIGZpbGw9IiNkNTlmMGYiLz4KICA8'
    b'cGF0aCBkPSJNMjkzLjE0IDE3OS4xOGMtNC4zLTYuMDUtNy4zMi0xNS43LTYtMjIgMS4zMi02'
    b'LjMgNS42NS0xMi41MSA1LTE3LjI4IDIuMjggNS4zNyA1LjEgNS4zOCA0LjQzIDkuMzMgMy40'
    b'Mi0xMC4xOSA0Ljg3LTE4IDE1LjUyLTE4LjUyLTExLjI0IDE2LjM2IDExLjU3IDMwLjM0LTUg'
    b'NDguNDl6IiBmaWxsPSIjZDU5ZjBmIi8+CiAgPHBhdGggZD0iTTMxMC42OSAxNzkuMmMxNS4y'
    b'MS0xOC4zNS00LjE0LTI3Ljc1IDEzLjUtMzYgLjY0IDUuNDItMy42OCA1LjQyLTEuNzcgMTIu'
    b'MDZhMTMuMTQgMTMuMTQgMCAwIDEtMSA3LjIyYzEuOC0yLjIgNS4yOS02LjM1IDcuNS04LTUu'
    b'MjQgNy45IDQuNjMgMTQuODItOCAyNC42NWgtMTAuNDltMS40MyA0Ni4xNGMuOC0yMC40NSA1'
    b'LjE4LTI2LjY4IDEzLjQ3LTM1LjIzaC00OC43MmM4LjI2IDguNTYgMTIuNjMgMTQuNzkgMTMu'
    b'MzkgMzUuMjRxMTAuOTQtLjA1IDIxLjg2LS4wMXptLTExIDQ5LjkyIDYuMzcgMjAgMy41MS01'
    b'OS4yN2gtMTkuNjdsMy4zNyA1OS4yOXptLS4xIDg5LjU3YzIuODEtMi42IDMuNjEtMTEuMDkg'
    b'My42MS0xMS4wOWwxLjc1LTM0LjY3LTUuMzEtMy43My01LjMyIDMuNzMgMS42OSAzNC42NXMu'
    b'NzYgOC40NiAzLjU3IDExLjA5em0yOC40OC0xNzguMzktNTYuNi0uMDZ2LTUuMzhsNTYuNjEu'
    b'MDZ6bS0xMy43OCA0Ny43NUgyODUuNnYtNi43MmgyOS44NnptLTE1NC45OS01Mi44OSAxMDYu'
    b'NTgtMTIuNzctLjMzLTIuODYtMTA2LjYxIDEyLjc4em0yMC4yNS02NC42OCA4Ny42NSAzMy43'
    b'MSAxLTIuNjgtODcuNjQtMzMuNzF6TTIzNSA3OC45MmwzNy43MiA1My43NCAyLjM0LTEuNjYt'
    b'MzcuNzQtNTMuNzJabTY0LjExIDM1LjI2djExLjQ3SDMwMnYtMTEuNDhabS0yMS44OC0yOC42'
    b'OUwyNjYuNiA4MGwuNzQtMS40NEwyNzggODRsLS43NCAxLjQ1bTEuNzQtMy44OS04LjU5LTgu'
    b'MzEgMS4yNy0xLjI1IDEwLjEzIDJhNSA1IDAgMCAxIC42MS4xNCA0LjcgNC43IDAgMCAxIC40'
    b'OS4xNmwtNy02LjczIDEuMDktMS4xMSA4LjU5IDguMy0xLjIgMS4yNC0xMC4zLTItLjQ3LS4x'
    b'Mi0uNDctLjE3IDcgNi43My0xLjE1IDEuMTJtOS4wNy0xOS43LTIuNiAxIDMuMzEgOC40OSAy'
    b'LjYtMWEzLjIgMy4yIDAgMCAwIDIuMS0yLjA2IDUuNSA1LjUgMCAwIDAtLjM5LTMuNTVBNS4y'
    b'MyA1LjIzIDAgMCAwIDI5MSA2MmEzLjIyIDMuMjIgMCAwIDAtMi45My0uMW0tLjI3IDExLjQ1'
    b'LTQuMy0xMS4xOCA0LjI0LTEuNjVhNC44OCA0Ljg4IDAgMCAxIDQuMSAwIDYuMzIgNi4zMiAw'
    b'IDAgMSAyLjgxIDMuNTMgNi44NSA2Ljg1IDAgMCAxIC4zNiA0LjczIDQuNzkgNC43OSAwIDAg'
    b'MS0zIDIuOWwtNC4xOCAxLjYzbTExLjI0LTMuMzlMMjk4LjEzIDU4bDEuNjItLjEzLjk1IDEx'
    b'LjkxLTEuNjIuMTNtNy4zMS00LjkxIDMuNjYuNy0uODMtNS41My0yLjgzIDQuODNtLTQuMzMg'
    b'NC4yMiA2LjYxLTEwLjkgMS43Ni4zNCAyLjEyIDEyLjU4LTEuNzMtLjMzLS41Ny0zLjc1LTQu'
    b'NjItLjg5LTEuOTIgMy4yNy0xLjY1LS4zMm0xMS42OCAyLjY1IDYuNzUtOS44NSAxLjQ3IDEt'
    b'LjMgMTAuMzJ2LjYyYzAgLjE5LS4wNS4zNi0uMDguNTFsNS40Ny04IDEuMjguODgtNi43NSA5'
    b'Ljg2LTEuNDYtMSAuMjctMTAuNDh2LS40OWMwLS4xNi4wNi0uMzIuMS0uNWwtNS40OCA4LTEu'
    b'MjctLjg4bTE0Ljg2IDYuNTEgMiAzLjE1IDMuNDgtNC4zOC01LjQ2IDEuMjNtLTYuMDUtLjI4'
    b'TDMzNSA3NS41MmwxIDEuNDgtNy43NCAxMC4xNC0uOTQtMS40OSAyLjM0LTMtMi41LTQtMy43'
    b'LjgzLS45LTEuNDIiIGZpbGw9IiNkNTlmMGYiLz4KPC9zdmc+Cg==', 'US_IN')

US_IN = b64_US_IN
index.append("US_IN")
index.append("United States of America Indiana")
catalog["US_IN"] = US_IN
catalog["United States of America Indiana"] = US_IN
country["United States of America Indiana"] = ('US_IN', '', 1)
lookup["US_IN"] = ('US_IN', '', 'United States of America Indiana', 1)
lookup["Indianapolis United States of America Indiana"] = ('US_IN', '', 'United States of America Indiana', 1)
lookup["United States of America Indiana"] = ('US_IN', '', 'United States of America Indiana', 1)
details["US_IN"] = {"continent":"Americas","capital":"Indianapolis","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_IN"] = ('US_IN', 'United States of America Indiana', 1)
regional["United States of America Indiana"] = ('US_IN', 'United States of America Indiana', 1)
#----------------------------------------------------------------------
b64_US_KS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc4ODUyIgogICB3aWR0aD0i'
    b'MTY3IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE2NyAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS2Fuc2FzLnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBl'
    b'PSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxu'
    b'czpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBv'
    b'ZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5r'
    b'IgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0i'
    b'aHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnM4ODU2'
    b'IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3ODg1NCIKICAg'
    b'ICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAgICAg'
    b'Ym9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAgICAg'
    b'aW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tlcmJv'
    b'YXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAgICBp'
    b'bmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc4ODU4Ij4KICAgIDxpbWFnZQogICAg'
    b'ICAgd2lkdGg9IjE2NyIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVBc3Bl'
    b'Y3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVR'
    b'dWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9S'
    b'dzBLR2dvQUFBQU5TVWhFVWdBQUFLY0FBQUJrQ0FZQUFBRGphaUQyQUFBQUJHZEJUVUVBQUxH'
    b'UEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2'
    b'bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBaApIMGxFUVZSNDJ1MmRl'
    b'WlJkWlpudWYzczY4MVRUcVNsVmxhcktXSlZVNWdrSUNWTUNRUWlTb0JlbEZVVkZRSnNXaHl1'
    b'MHJiUnRxMDNiCnRoZWFLNDBnM2tiYklNZ1lpQ0FFd3BpRXpGVkpKVldwZVo3UFBPMnAvemhK'
    b'SlpGTWVJRUYxSDdXcXJYT3FmUHRzL2Q1OTdQZjhmdmUKVDJEcVRTWVdMSHo0WUlpV0RDeDhX'
    b'R0dSMDRKRlRnc1dMSEphc01ocEFSUkpReFkxU29OamlLSUJ3TUthTGtSQlI1RTBQSTZrSmFU'
    b'LwpEOGlXQ1A0NnpKdldoY09lNW9acm1oaUxPRG5VNm1QenRuSmUvSzlOMUt5K210dHYzTW16'
    b'V3lvWkNUbVpOYVdYaDU1YVlnbk5JdWY3Cmk1TDhVUzVZM0lYUG5lREdheHVaT1MzTm9XWTcx'
    b'NndSS0NzSzRmZnBmR3BWQTErN3ZwVmt3dUNtejNkeXkvZVhBbUNYazZRMXB5WEUKczRSZzVU'
    b'bmZyU2xYMmZ2VTc4blBpWk9mRDBORElJcVFudytEZytCeVFUSWw0bklhcEZLUXljQXJXNHVa'
    b'V3p2R3cwOU81U2NQbkdjSgo4ZXhnV09SOEY3amhrenY0NGpXSENlYkdLQXFxeE9OWlltYVNB'
    b'dnFnamRTb2hDRWJGTXpNTUJ3eEtDeUVRQUJNRTM1Mi96UnUvL2VWCjZJWmtDZklzeVdtWjlY'
    b'ZUJwall2c2FqRzVCS1ZrUkVZSFFXcHpVUHErVHdjY2R2NHVFN0J3Smdkd2YrWkVRWXpCdEdZ'
    b'akNnSzNIcmQKRHU1N1pBNkp0TU1TcGhXdHYzZVlWRERDZDc1U1QxMU5uSklTcUtnQTk0Z1Q0'
    b'L0hpRTRnSklKa2l5cjRBUTgvN0FjZ0phSHgyYlJ1SgpwR2dSMHlMbmU0L3VvVHhlMng3RTV6'
    b'VTRkQWlhbXlHMjIzMWFBZW9aZ1lLQ3JHbHZhbkhSMXVPM0JHbVI4LzNCd2RZQXd5TXkwNmZE'
    b'CjFLbmdxVXRpbkdKc3hxbmlPemRDZHpjTUQ0TWdtRlJOQ2dPV2kzKzJrTWhiZEtjbGhyT0R4'
    b'NVZCbGcweWFSMjNJNFdRb3lKVUpvaUYKUlZJcFNLVkJDMlJ3TEF3VHVHYUl5am9OVFFPUEIy'
    b'UkY1S2YvT1ovQk1hOGx5TE9EYVFWRTd3STdHOHVJeE94cy9OVW1QQjZ3MlNCdgpjUXE1dkor'
    b'cUt1anZCOE1ReU0rSFZNb2tGSUs4UFBqanhpQy9mbUkyR2RVeVZKWlpmNStRNDRseTNkcmRi'
    b'RzMwVXQva3dPK0hTQVM4ClI1U2hMRU1zcVhEMTNhVjA5N3VRWmZqK0kxNkdYV00wem1obXNI'
    b'alFFdUs3Z0tVNTN3VVMzamovNVI5RE82RHk0RFNObDNjckxKMlIKelhjQ3BOSWlCOXU5N0Fx'
    b'N1dmK1N3Ulh4eVl5T1NmekdHMFlQRFZOd2VZVFF0cG1XMkMxeXZ2Znd6ZWxFRGhoa09renVQ'
    b'T0JFcWkvZwpQazgvTGtlR3g1OHJJSjZVZWZ5RktnYmZMQ2M1cjVWSGw3ZlIrK1F5VEYyaS9K'
    b'WVhNUTBOeFJkRmplUll3andMV0JXaXN4V1VxREw1CjFvMUl2Z1NtNWlDOHZZTGs2OVBSTkR0'
    b'ZnVHb1hqNzlZZzAxVzZSN0tHei9HVWRKTGNPMXVocDZyUXd1NzhjN3RKSDRnU0hxd3hCTG8K'
    b'bVdHVkwwK0hvR2VVb0MvR1dNeEJidEVndmJJSFVqbkUrOXpJa29PQTJJUExycFBJU0RodE90'
    b'M1JZa1JKeHRBMVJFa21WK25CNVU2aQpWSGVUYVNxbk96d1pRUlF3ZEIyNzIwMDhIRWZWQkV2'
    b'UXB5Q25sVW82RFg1OTQ1UGNmVk05VG1PQVgzeXhpYjJINTFHMDhLdklSb1M2CjFaZXlMT2RK'
    b'SHYzMlM5aU5BWDcxZDN2WTBWL0w1SXMraTZpT012ZlNTMW1SOXhnYmJuc1ZzMGZuL3IvZHg3'
    b'Yit1VlJkOUw4UTFCSG0KckY2RHh3TzliVmFRZEtwVWtxVTVUd05GU0ZQc0h5V1VjS0ZJT3Bv'
    b'aGtUQThZSm9Jb29ScDZBVHNFZEtxak1PbWtzb29wUEJnR3VZUgpEV21RNnd5VHpOaHcyaklr'
    b'TW5aVTA0V3VtMGd5YUxxQXJsc0pFOHVzVy9qSWtkTjZiQzE4YUdHUjA4S0hGbGFlODYrRVhk'
    b'YW9MUFpTClZaWkhTWTVCamxmRDVZQm93aVNhdE5NMVpOTGVNMHByYjVTTWJvblpJdWY3alBJ'
    b'Q21hdFdsckNpdG8vcWduN005RGFpa1dGOC9od2sKeFk4Z3lBaG9aTkpoWXJFb0htOHVrbk1h'
    b'VFgwbHZOSlF4Rk5idXVrYTFpMUJuaVdzZ09pTUFqSzVlR0VlWDdvc3pheml0d21QZFpOVAp2'
    b'SkxCU0RtajRYd1NFUlZCUytMeisvSDdBcVFTRVJTWGorRlFGRjJJa2VjYllWSmVON0hoMTNG'
    b'NEtxbnZYY0IvUHF1d1pmY0lKbGFPCjA0clcvMHFjVStQbkI1OVBVbXo3RXc1L0hjMERjd2tO'
    b'MmFncXpNRnZoNXlLR3BKakF3dzI3U1N2Y2pibEN5OGhOdHdEcG9scEd0aGMKZnZZLzl5Qzk0'
    b'VFJKVHluKzNEQlQ4dDhtRm1waHlMaUNPMzhqc1AxZ3hCSzBSYzZ6aDk4bDhNTWJjbGxSdFJI'
    b'UlVVbnI4TVZJbzBQTQpXYmdNWDNFbGhxNGgyNTJrSWlNNGZmbnNmKzVCL0NXVktBNFBzdDJK'
    b'cDdBY1VaUkJnS2FYZm8vZEU2RDI4aS9UL01xamRJWjF3dG9ZCnM4dGVSVTBPOFdMVEZmempR'
    b'MzFFcmY0TEZqblBoTG9xTC9mY01vYmJlSld3L0NWR1cyUFVWcGN6YWU1S0JnNjlUZTdrV2tK'
    b'ZGg3QzUKZkhTM0grWkFlejg5RVkySUNnbGRSQmJBSlpuNGJUb3o4bVdLWFZBNGN6R0YweGN6'
    b'MGxhUHY2U2FrZFo2OXJmMzRBcUVDZWdQRUJiVwpjTXZkZGc1MHhLMGJZSkh6NUxod25vK2Yz'
    b'N0FiV1hHenYvMENndWsrRmwxOU15TnQ5ZVJQbWN0QTR6YTYrd2Q1dFMzQklhMklNVWN4Cmdt'
    b'UTc1ZmVacG9FMzBVTzFOTWhTM3dnMXMrZmk4T1dSV3o2VHhOZ0E0ZUUrdHV5dVovN2s1OGdZ'
    b'YnI3NXdFeTI3QTFaTitJSU9hM2EKK2hGOFltbUF1ejczTW9KOU5vZGI1MUR0VWhFTkZWZE9F'
    b'YTdjSXZaczJjaUcrZ1JQeDJiUWJhc2daUXRRR0hBaElQREpCU1gwaDFOOAphbEVwUFdOSkxx'
    b'a04wajZjd09leUVjSERnRnpDemxRcGJlMmQyQVliMFFZUDRjNHR3dTUwTXptWXgvYm1Rb3B6'
    b'aDdpb3BvR3VzV2tjCjdrbFpOd1JNaTV6QStYVmVmbnJkNitCYVF1ZmhTVng0K1RweXltY3cx'
    b'dG5JYUY4SEc3YjM4SGhrSm9PT2NoQmxQakduQ0lEVnN3cnAKR2syZzZpWWRJd2t3QlhwRFNk'
    b'eDJHWWNzY1VsTmtKUm1VRmZtcDIwMHc0aFN5TjUwa1BSSUY4VmlDSGR1SVRtVHBsR2U3K1dG'
    b'TnhLVQpsMnBjV0hPSWZaMlQ2UjVLVDNoeVRuaXpYbEhvNFBmL3V3TzMyMGQvOXdLV1g3NmUw'
    b'WTVHZk1XVnZMcnh2M2xzcElwUlowWFc3TThzClFETk1EZy9FU0tnR1kvRU1raWlnR3laK3Aw'
    b'STRxZUsyeThUVEdxSWdZSm9tQlQ0N2RsbGthcUdIWkVibnJaWlJBRXFUemF3djdHUE8KZWF0'
    b'SmpQYVRYejJIRFk4OXdlSnBtMG5yUHE3NnZwZnVZWFZDbS9VSlhiNjBTU2IzM2lxUzZ4Nmlx'
    b'WFV1Zm5XQVZIUVUyZTVpd3g4ZQo0Y0hRUWthY0ZUaHNFbjkveFF6MmRvZloxUkdpSjVTaU5P'
    b'Q2dOTWZKalNzcjhUc1Z2bnBCSlE1RjRqdVhUY1ZsazdqNXdpcnl2WFlDClRvV3UwU1FIZXFN'
    b'MEQ4YjQvcFV6c01raVBjNnBQREE0a3kzUGI4UVpDQkx0NzZCVzZlT05neXV3YVh1NSt4czVL'
    b'T0xFRGdjbXRGbS8KK2VvU2xwUnNvQ3QxRTBXcFBnUkJJRExRd2NZZDdUd3ZMTUZRWE13czl1'
    b'Snh5R3h1SEdRc3JySzRNb2RJU3VPQ21RVnNieDJqc1RkSwpKS255UnZNSW1tSHlXdE1JcW1i'
    b'UU9ab2tGRmY1NUlJU212cGpWQWZkSEI2SXM3Y3JURW5BaWQrcE1KaFJPSmpPeGRmOUdzSklL'
    b'NmFoClV5REU2SkF2b0V6NkphSjdKVHNtYmg3VW5MQ2FjMUtld2cwWHZvMno2TE80aHJvUWhX'
    b'eTFabk1Ydkt5Y2l5RFpjZHRsQkNIYmlNc2gKUzFUa3VTajBPWWlsTmY3Zkc1MmtOWU53VW1W'
    b'ZVJRQ1hYV1pWYlJDN0xESzkyRXQvT0VWR043ai9sVFpVM2FTcXdFMXB3SUVBZUIweQppaVRn'
    b'dEVta2JRSCtFSnRMWHlUclkwcVNnTjdaaFpKN0pWKzU5QkRGdVJPM3dqeGh5Zmwzbjg2RFRD'
    b'dWJHcWFTVHNZSlJSTzBEWXl4Ck4rSUNVYUxBYStmbUN5bzUxQitqYXpSQlpZR2I0b0NEUCs3'
    b'c1FkTk44ancyMWkwb3hXMlhtVm5pSlpuUkVRU0JqRzV3M3RROEhJckkKdWdXbE9Hd1NLVlhu'
    b'a2UzZHpKN2twN0xBelo3T01PM0RDVzViTlFXZlV5Wmh6K1hQZ3dFR1EzSEdJbkY4UXBLWEdt'
    b'dkpoRjduNjU4dQpzOHo2UkVKUmpzUWQ2L1l6SnEwbWNiaVRwT2dna3RTcEt2Q3dSNjhrcWZp'
    b'SlozUzJ0WTZoR3liZlhEMlZMWWVHT05RZm84anZZTzM4ClluYTBoM0RhSkRwR0V0UjNSekNC'
    b'bHNFNGhnbTdPa0xvcGttT3kwYjNhSkxQTEMyamRTaE9ZMThVcDAzaU0wdkxlS3RsbEcwdFl5'
    b'UXkKMllrZ2RqUEZzdHdvblJHZGtHWkhpZzBTcks1amRra1RmM3pOU1R3OTRmelBpUm10Mzdx'
    b'K2pDK2M4eURQZHQzT1JmWjJBQjQvR0NOago5OUZxcTN4bjRDUkxaTFFzaVdSSlpISXdsNWFl'
    b'WGd6OXpPa2VVUlNvclNqaFlGYy9xcVlqQ0dCWEZGSVo5Ymd4WUJnd1ErMUcxcUtzCm5abGR3'
    b'ZmxLdW9TTGkrN2l3VzAzODh2SDJ5WmN0RDdoeUNsZzh0TFBEQXB6VEFaNnRtRkVLOUZUeGN4'
    b'YjhSdWs5OHJKMFVEUWpuMloKY0pLTWtLbElJSUFnNTRMb1FqQXpHSmwrTkRPUDNkdXVRSklI'
    b'RUwzTkZFNnFvWE80aE10dWo4UEVtc1UwOFpySFRpbXhVK2pjVGlTOQprTHpBQUVVem10bTFZ'
    b'L3JwaVdrSVlHU2ZZY0VVUUQ4NVNUUWRYdHhjVER6bVozSkZMd3RyWThjOUZTWklZRW9tZ2xJ'
    b'QXlSRWsxN1FzCjRVd1RURHVTNGtVME1oaktkdW9XTkRBdzVDT3FMYWM4ZHorVGcxTnBIOVFt'
    b'MUwyYWNPUmNPanRJTk55SDRoK20zQk9Ia01paWlzUEkKL2NyWmR5Y1V3QlFBSXh0U3FnTDgr'
    b'ZlZpRHV4ZENQRkZnRURyRHBXWE4rMWlaczArTGptM0M4ZVJidHVDNGdZMWhPeXR3d3pGRVp4'
    b'RgpDTElMTXpPR1lNdkJUUFN5dURLTU11S2hVa3JRSEk4UVRUZXd1RzRsN1M5MldPVDhPT1Bj'
    b'MmpqZS9EcVMyeHF4dVYzai8wK2FKaTgyCkZETVNENUxuSDJKK1ZSOGxmdU0wb2FTSktRcnNi'
    b'WFB4d3E1bEdKbWxKNWhkU1ZBZ3VZUkRPNWR3WUZjRHM2dTJjK21TYmhTYmdlQ2YKRGpFWjBW'
    b'VUpHUzlHb2cwRUhTRnVJbVFDRExmR0dPcFRxQ3Mzc1NjUFlKdFJ4Ym0xT245NEVZdWNIMmRV'
    b'NUE4UlRSVXl6YjZWdDl1ZAp0QTJWMEI4dVpTaGFqa3NwQXdUNmhtSEhvUUVLL1EwVStRZndP'
    b'QktZcG9aVFVRbjZVcmdVZzdjN1NtZ2JxaWFabm9Nc3VrK2ZFakZuCmNhQ2xsdjB0ZTVoVHZw'
    b'TVZkVU40aXlhQk13OU4yNG1hZjVET0hwbThUQ2N2UGxiTXdkNjFpRUlPVDI4N1JFbE9LeXRx'
    b'SjFGWk1ETGgKVWtrVEt5QXlkZDcranpDeFZDbC91amVFU0EyUytPNmVUMVZQMFI5dHh5WjVV'
    b'U1FiTHNXTkl0bVJ4TFBmSlNPaHRsUG9hMEdXMnFIUQp3MEIvQlltUlN1SkdKeVhPQlFqQ2lR'
    b'N3dxcHNPWWJObldQcDFHWVFKazVxZVdBR1JJdWc0bFFRREl5NFVzZnl2K3c3SlFWbGd4cEVB'
    b'ClNDV2FpWkRVa3FUVkpLSWdva2cySElvVHAzSnFiU29KUmJRT09jaDFyY1FNRzRRU1E4aVNS'
    b'S2xyMFVuSHg1Tk9jbndSUkJ3WTJDeXoKL25HRXl5RWdrR1pvN0wxSnljaVNRbzd6U0ZlNTR6'
    b'Wm1jeFJKSUJsSU5oRkROWkZjQXJJYkJBa3lJMkNMTzdFUEh0MVZReVRvUFgzWAp1WEJDb1ZK'
    b'U2Nkb2N4Q2ZRUktVSldMZ1Z3S254UnY1VFNGRTdTdHFCWFhYZ1ZnUGtTVVhZSkR1Nm9SUFhJ'
    b'N2dsRDI2YmwzZWJYMHoxCkgxMytlK0l5WU1rcDBKMW9JUmFKTWRWZmx4MWhHRVJTWTZpNmlv'
    b'bUJnSUJoWmdNeFNaVFFEWjJxNU1TYzJ6bWh5QmxQNmhpbUhjV3UKMHYrNTNRaHBBZnYzQXBq'
    b'NUJwbXZ4dEJFSFRFbW8zdFZCQVZJQ2tpRERtd3hGL2FFQ3praklRa1NvdVpFampxUStoeEkv'
    b'UzRjdm1CVwptS0tFSUlpbytqSDFwc2kySTQrRWdCS1R1Znh6Sy9uUlA5NkY2ZllqQ1NLaUNR'
    b'WXFzcUlnQ1JLYXFhRWIyWHltbURJUU1Rbm11OUJNCmhXU0dDWldIbjFEazFGQklhbTY4dHF3'
    b'bU1oVlFyMDBnNkNZSUpzN0hQWmhCQTIyVmp1a3d3UU1VcE1pUXd0T2FJTGZGd1dCTmdtaXgK'
    b'aW5sa3JxV3BnZEJRUWxuNlNxWlVyS0ZvMmh3RVFjVFFWR1M3ZzhWbUd3VStCMTN0YmVRSEM0'
    b'bEhJL3pici82VnZQeDhuaytXb2FhVApDSUtBM2UzTFJnR0dUam9XUVhFNGtXMVowKy90K1Jh'
    b'UnBBTmpnaG02aVRVclNaQVlpZm9wOU1ZeEV3TEtSaWZLNzl5WW9vQ1phMkRrCkdCQVRJSFJN'
    b'TEtJcWtOdGlKMVNXUmtrSWxHMzE0aDZTczVVaVFKQ0J1YjEwTGJtUGwveFg4dWhMRjdGOXl6'
    b'M0VRc000dFJqaHRFWkQKMXpERG9wKyt1RTdTSGlEakNOQVRWWEZud2pnOGZpVEZSaW9hd2pC'
    b'MFJGSEM2Y3UyNVU1RlE2U2pJVHoySVlZaXVSTXBVcCtZUG1mcgpZQjRYNXUvR3N6ZEk4cHho'
    b'OUpvTXBpTnJMclYxQ2VUTkR1VFhIV2lyRWdndXFIckZqN2RId1Q0blFlLzhPQm1QUVRMbjVH'
    b'VkUwUW5hCm9zTWM1aTRPamY0THJoMnpLWll1b0x4c0pZVVZ0Y2lTQThYbVFzdWswTklwSkVs'
    b'RTdqdUlYRHdEMmVZZ0ZRc2pDQ0oydHhmWjVrQzIKT1VpMzcwRnl0Tk02VUFmRUxISituUEZX'
    b'bzVlRmhmVlU2b3RveU44TU9RTDJuL294Y3d6VVQyZlhqUXQ5SXRLclRyUlBKT2hjR3FWdwp2'
    b'eE5ETVFtWFpjNzZQRkt1UUhwWkErMDAwRzdlZzM3QWpqTldpVGRUaVZldXh1K3Fwa0N3VWQy'
    b'ekdXZDVMWFp2THFyc1pzUmZqZW1lClJUb2VBUVJja1U0U2FpOXZIWmg0VTI4bkhEbTM3dXZq'
    b'MjFkVWNuNUJHUTBBa29tK01nVUpBVXpRVnFaaFpYcTh6cDd4Nm5RdGpZMmIKOGI4MlFTQk5T'
    b'WlBoSUNNY1pBUWdJekRsNFh3bUY4NWg4NmJmOFpVMUYrRzIyd2lIOTdGTGNtSVBWZ05RS3Uw'
    b'aEVLeGo2NzR1aTV3ZgpkeHp1VFRHWW1NT3l5YVA4c2xQQkxGUFJ6ajN6T25GVE9QdENXbEFv'
    b'NXViSzd4S09oSW5yTVZ5aUU1ZlB5WVB0OXpCZzlnQlErSmlMCmtrZ0FlN2tkZFNERWZWdWVJ'
    b'MWlTZzZtYVJIYTlSRXRSR1dYMlJWeTJwSkgyMFZvNmgwSk1zQ2x6RXpEUEtZZzh0YTJNenkv'
    b'ZXlOekIKODloZDl2SnBoOTh4NlY4cEV5b3hSQjI3MDQ2aEdid1Zlb1dIaHU5R1Rvbll3eEpw'
    b'djQ0aG1kZ2pFcXJiSUNxRm1PS2NqdCtWaDk4UgpRRk5WSW9UNGhmNmo4UkRVTm1xbnJDUklk'
    b'V21RMXhTRnNmNDRabXVTd3VKQ2hwTzloTllmWUhHSEF6UCtOays4dFF3SVc1cHpJdURSCmx6'
    b'cTVjZlVpcnB0UnhPNlVDSGFENEc0M2h0TkFjeG9ZaW9rWUU4RnVzbDE3RFg5aERqNkhIMklp'
    b'bXBCaC8raGVBSnhqTWxOK2w0K2kKaWd4TlR5QVBLK1FNeXhnMmt5OFUvZzFpdjRJcG14aEow'
    b'R3RqWkJaSEVCUVFIQUlaVDRaUkxVYjd3QUJwbHdhS1FOeWhFU3pMcFdHbwpFeUVqc202U2d1'
    b'aTRtQ2RmYnB1SXQybmk5dWY4eVkyVFdEWGxOOXpWT0l0OTgxNW04ak01K0xzVkZFMm1aWG1Z'
    b'MHBmOXlMSkp4OVFrCjhVWW5abWtHTWlKQ1drRDkxQWltTDF2OXlUL29KSjZqb2c0YnFMcU9L'
    b'WUNvQ2FUc0pvSnNZb29ta2tORTlJUG9GTEtwcDdQQWlzT1gKOFRmNVczbis4QzM4OERjdEUv'
    b'RVdUZHhHWGlWNUNrL2YyVThzNCtPVzJOTW90aU1MelNJU3NTSVY2YkJJS3FPQkpxSmhZdnIx'
    b'N05LTAp0QWxlTTV0OFB6b1JTUUk1VjBUeXZEYytvU1BrNVQ3L1NoeDJKNnUrWTJjZ3BFMUlj'
    b'azdZcGdyUnBJRmttOGFTMHNlUjI2NWd1N2FiCmRGd25ybXVvWVFNemFDS1ZDNGpGSUJlRDVC'
    b'V3AydUxqaGxtM2N1c0ZQMEFYTk5wanJVZ1ZCckpmUkxTZG1aaUtydURXL1dTazB3UmcKSmx3'
    b'L3NKNnA3dGY0eGFZTGVLTitqQWtLYzBLM28zbmdtUzY2MWMreWJ2WmJ6T2s5QjF1SmlGSXNZ'
    b'aXNTUWVHRVpSdUNDaVdIM2N3cgpYVVMrbHNQM0Z2NlU2WTN6czJNTThLWHpFTSt3TWNGQ2RT'
    b'blhTdXRPTzJaNTB5VmNYUG9LaDZMWDg5dE43UlA1OWxnOTRTZmxLenh4Clp4VEpIS0YrejNS'
    b'SWpwRklIVXUyaXdLNEhIYVM2UXo5ZllNNGdoV01wRFEwcDVjRjh4YXlmT2xTMmp1N09XLzUr'
    b'WFMySDJiSG15L1IKMHZBR2FqcWIwSGZZRk95S2pOdHBSM0hsNGk2ZVRiTHpqWEh4T3cyRlJF'
    b'WWxuVmJSRkQvekY5WmpLRE5aK3cvUU42cE41RnRqTlk4RgpXRklUNEw2YmQ2TlJRRXZESlBK'
    b'c3gyWVZtU2JFazhmTThDdmI2Z25rbDNEOUhUL0c0L1l3TURCQVQwOFBwYVdsRkFZTDJQN2lV'
    b'K1RuCjV0SzlKNXVpOHJtZEtMSkNYOXFPSEt4RVRVU3dEeDg4OXYwR0lKaVk3bHpLcS9iamRD'
    b'cDg4ZCtyMlhFb05ORnZpOVU4RnFCbktFWG4KU0JXWHpqbUlMemZPb2M0QThVaUlhQ0pGTkpG'
    b'Q0VBUkVVU0NaenREWDE4ZU1SZWNUOFB2cGJUL013ZTJ2MHRHNGwybXo2ampjM0V4agp3ejR5'
    b'bVRTaHdXNE13NlI3ZUl4bnQrL0hZYmRSV2xSRVRyQ1kxRURyRWVLYkpOSXFDY1ZEVGMxK0pG'
    b'bmlHdy9NNU0yR01TeFl6V1BICmNiZ25SVVBYRks1WU9rcGhmaE1KYVQ1eUtvWEg1U0N0YWlU'
    b'VEdXTEpGTHB1NGdya01kRFNnTnNPRFc5dEpsaGNRbGRyTTEzN2QxQTEKZFFhb01kVFlHRU9S'
    b'RktPNmpGTVJxU2tKNEttWVRYaDBoT0h1VmtLUk9PRjRHbTlaRVhPbWIwYVRxL2pHL1ZWczJU'
    b'TnEzUXlMbk85RQo1MkNLVnh1Q1hMeDRFbVhlLzBiS200dXAraWp5T1hEWUZmTDhIdHdPQjBZ'
    b'cWh0Y3BZdlBrRVJ2cVlmcUNjMGwySFVEUTRwUlBtVTRnCk0wQ3UzMHZPbEVWTW03TUVMVHhB'
    b'T0JKRHNqbEpoNGVRUllGZ1hnRlZjMjJVK0o1aTJMaUtMLzJialYzTjFyWXZ4NVBUOGpsUEFv'
    b'OEQKZnZERkNsWk9lUmFIWGFCM2RBVURYU0ZjaW81WGN0RFpOVUI1WlJXNllhRG9LUXpCcEtX'
    b'bkY4MEd4ZE5yNlE4M2toSXpaRXdOV1JIQgpOTW1JT21KR3hGRGR6QWlXTU1YN09raGVubTFZ'
    b'eFk4Zk9rd2lZMjJZWlFWRTd3SUxwdm40M3Vkc1RQVS9qV1o2T1pTWXlWT1pEbmFyCnV6R2NL'
    b'ckltb1VzR3VNM1RWbjVzTVNlTDRzdFk3UW93MVZtUEtNa2NqbHpPRHgrS3N1ZXdwUzB0Y3Y3'
    b'VnVUYVQ1WFVGM0hTVnd2U0MKSFdTaSszRDRadElaSzZJaHF0TWlKQm5MaEJtT0RhR21WTndl'
    b'TjI3RlM2NFdZSlluaDZtZUZKUGMvYVNqVGZnS0Z2TjJ4MXdlZUNiSgo2L3VHd2RwZTBDTG5l'
    b'NFdTWEluTHpwdk15bG1qMUpZUFlETmFpWTYxSVFqZ2NOaEJzS0ZtVW1UVU5MSWs0YzJwSWkx'
    b'TW9iNGp5Q3YxCk9XeDZ2WVcrTWNNU3BFWE85eGVLb0ZGUjVLS3FMSjlncmh1UFE4UG5VWWpF'
    b'VktKSm1hR3hPQzJkUTNRT3BsQU55UktZUlU0TEh5ZHkKaXBZTUxIeFlZWkhUZ2tWT0N4WXNj'
    b'bHF3eUduQnd2dU5qOVFDdDZ1WHRpS0tKbDNESHJZMUZZNy92eXcveHBKcEF3QU1oSnk4ZHVE'
    b'VQpMUVhYTG01RGtiTzV4amNiaStnZE8zVWZ6U3NXdFdOWGpuV0tlM3A3SlpuamRza29EaVE0'
    b'dDZZUGdEL3ZLU09jT0hudnpNSkFrdGtWCkkrUzZVM1NQZU5qZGxrOHljMmJSVHlrT003ZHlH'
    b'SUJJd3NZTGU4NXV3NnlLL0NqenFvWUorcFAwaDUxc2F5cGlJT1MweVBsKzR1RmIKWDhTdTZE'
    b'ejZaalhYL254VjlnZUlCbzk4OHdVV1R4M0FNQVF1L2FkUG5QTDQ2U1VoL3ZpZFA0Mi8vK2ZI'
    b'RnZDRERZdFBPZjVYTjc5TQp2dmZZWE03cjc3bUkzMjZaTnY1K2J0VXdHMjU3QVlCNTMvd1U5'
    b'UjE1Snh6dmMyYTQrMHV2OFpubHpZakhiYklhVHRqNDFtL081YUhOCk0wNzdlLy9obWgxODl2'
    b'd21BRlJkcE9TRzZ4bUwyVTg1M3V0VXVmZkxXN2gyZVRQQ2NjVW5WUmU1NjRsNXAvMnRsbGwv'
    b'SDNEN3VsMHMKbnByVm1qOTZiQUdiNnllZGN1ejZjMDVjeFhqVjRuZTM1UGJyYS9hZDlWaEJn'
    b'Q2UrdTRuclZqUWhpaWI3MnZONGJsY0Y0WVFOdnl2RAovVGU5eklXenUwOTV2Q0lackpuZmNj'
    b'TDdTK2QxbnZhY3Y3L3RCVDV6ZnBhWTI1b0srZTJXYVhRTmUxQWtnNzlmdjVQckx6aG9rZk9E'
    b'CndvTHFJZTVZdnhPQVYvZVg4TStQTFR6dCtFOHV5VTd5YmV6T2RuR3JMUjlsU3ZHWm14Vzh0'
    b'Ry9TK1BuT21kNS9WdGQyVVYwM0sycDcKQVhobzh3em1mK3RUWFBuak5TejY5alVrMHRrTlg3'
    b'KzZldjlwajgveHBORU5nYWErQUFCWExtbzdyU3lPa3ZmUk42czU5NDZydWY2ZQppNWg3MjZm'
    b'cEMyVjNEZm5TeFFjc2NuNFFjTmgwSHZyYVpoVEpZRFJtNS9yL3VBamRPUFZFaXNwZ1pOeC91'
    b'KzJoYzBtcjJaTGkya1ZuCjFwNTcydk41dmJFWWdMKzkvT3kwNTZMcXdmSFhyKzQvNWdPM0R2'
    b'aDQ1STBwTlBVRjhEaE8zVU43M2JLc2xuK2pzWmdOcjAwQjRMTDUKblRocytrbkh6NjhhR24r'
    b'OXN5VjRnZ3R4Ly9PMWJHOHVKS1hLRmprL0NQejBiOTZpcG13VTA0UWI3cjJRemlIUGFjY2ZO'
    b'ZW1EWVNlYgo2eWZ4NXFHaXJEWmEzSDVXNS91UFRiT3oybmRwSzVYQk0wOXpTNnJINnVsZlhu'
    b'V0FvcHpFc2ZmLzl3SnF2bjR0YTM1MGN2OVlFazArCnNUQnIwcC9lTVprLzdjNXVydUJ4cUt5'
    b'czdUbnBNWkhqZ3JFdlhYeUFXZVhIdG9iNXAwY1hjczd0VjNQeG5WZGE1SHkvc1hqcUlMZGMK'
    b'V2cvQS9YK3U1Wm0zSjUveG1FOHV5V3JJWjNkV29Cc0NtM1pXQUxCMFdqOUJmL0tNeHorNXRa'
    b'THVFUStTYVBLVlZXYzJqNCs4TnBYUgpJOEhMT2RQN2FmM2x3enh6eDdOOGJ1VWhYUGJUcjZw'
    b'Y1VkdERnUzk3VGMvdW1NeU9saUNEWWVlUmgrbmttbjdqamdxYSsvempVZjZlCm4vK0I3Zi95'
    b'R04rK2FqZUZnZVJIVWdGOUpNbXBhaUxta1phRVM2Y05vRWlubjRaV2xoOWowWlJzMFBUMDI5'
    b'bGRnVGNkMFVaWkxYVm0KN2FrWkl2ZS9VRE91bWR6MjAyOXIwUmR5Y2VIMzE3S3pwUUFBbTJ4'
    b'dzJmeE9mdjIxelRUZis5dlQrbjlYTDgzNnh2czdjMm51ODJNWQpBbi9lV3pidWhod2YrUjlG'
    b'UEsxdzhRL1c4dlQyWTdzZXo2OGU0aWZYYmFYNTN0L3l3MnUzSTRtbVJjNzNHN3ZiOHZuMTVw'
    b'a0F6Sms4CnpMZlc3am50K0t1WHRpSUlrRWpMNDhGTlkzY09yUU8rSTRIRzJabjIrMStvSlpX'
    b'UnlQR2t1VzVGMHhuSE4zVG1zZXoyZFZ6eDQ4dDUKOU0xcUV1bXN6MWNZU0hMZlY3ZWNOSG9X'
    b'UlpPMVI3VDhrOGNSN2FocEx3d2tXVHgxOEtUbjZ4bDFjL1ZkbDdMb08rdTU1N25aNDRHUQp5'
    b'NjV4eDdxZGZPK2FIUlk1UHdqYzhkdWxERVd5cHU3djErOWdSbW5vbEdPUHBveGt5V0RQengr'
    b'aDZkN2YwWFR2N3lnS1pQM0FpK3U2CnpxZ0pBWWFqRHY3d1pqWTQrZHFhZW9SVDdPVHFzbXVz'
    b'UDZlRmkrcTZxY2lQc21sWE9kZitmQlhGWDd5ZS83T3hibnpjeWR5RFpkUDYKS1Q1eVhWKys1'
    b'TUQ0dGY3a3VxM2pZNjVjMlBZT0gvWExseHhnL1RrdHpLMGNabmRyQWQvNDlYbE0vc3JudVBY'
    b'QjVlUGpQci9TU2lWOQpJQmlOMmZudXcwdkhJL2NIYjlsOFVuTlhHRWh5em95K2NkTmFWUmda'
    b'L3p2cSt6bHNPcXZublYzbjRMdWZ6WkpyNXFReExwbDc4bVB5CmZTazIzUFlDejMvL0diNTEx'
    b'WjRUVE85M0gxNkdjU1NyY0RMZmM5MnkxdkhYUVg5eS9Gb241UjNyQi8vSnBhMG5IQ05MQnIr'
    b'OGNRc2IKYm51QmZ6aE9PK3FHd0wyYlpqRWNkWXovL284U1B0TDlPZi9ybFJsODRjS0RuRGV6'
    b'anlYVEJyaHA5WDd1M1RUckw3Um1LNUpvWWhnQwozM2pvdkJQS2p3RC9kdjBidU93YVZ5NXE0'
    b'L0d0VldkT0s3WGw4OWJCSXBiTjZEOWxVcnQzeEVVaUxlT3lhNnlaMzBHZU44WElFWUtzCm50'
    b'YzUvaEFkOVVlUFFoQ3kxd3Z3NHQ1Si9IRnI5UW1mbjEvVHk3WExtNWxhSEdibXBMSHhmRzFh'
    b'bGVnWThsSlJFT1dpdW02bUZvZkgKZzZNTFp2V01WN20yTnhkYTVQeWdZSnB3OC8zbnMvTm5q'
    b'NkpJQmorK2JpdWJkcFdQKzVMSGE2S3R6WVh2SUM3QW12a2RYTEdvblU4cwo3RUNSREZUOXpN'
    b'Ymszai9OWXRtTWZyeE85WlRCMDY4M3orUnJsOVZUbGgrai9oY2JlUE5RRVQ2bnl2S2FiR0kr'
    b'bFpINHhYRW1IbUJoCjlTRGxCYkZ4RGYzY3Jvb1RQbi9qWUJIWExtOGVENHlPa2hQZzN1ZG1j'
    b'OWZuMzhUalVObjVzeit3c3lXSVhkR1pYNTNOZjZxNnlFOGUKbjIrWjlROFNCN3B5K2NVemN3'
    b'QncyMVh1KytxVzhicHluamZGK1VlcU5FK2VRaXR1M0pGTlF3WGNhYzZiMlhkVzUvempXOVgw'
    b'ako1KwpHK3Z2UHJ5TUIxK2FpVzRJQlAxSnJscmN4b1d6dTFFa2cvWWhMMnQvdXVZZHRmaWpV'
    b'WG9zcGJDNVlkSkpmK3RSamZpWCtkbC8zemlICk96Y3NKcFpTY05rMWx0ZjBzbmpxQUxKb2NM'
    b'alB6eFUvdnB5M0R3Yy9VdmYySTdXRzZGU3prdHgybGNzV0hLczdQNys3bkdoU29UQ1EKSE5k'
    b'VVd4cEt4Z09vNHhGd3A3bDRUcmJHM2RDUng4R2V3UGhuUjJjbEhlb0p2SU5JaTZZTVVoR01q'
    b'cjgvMWF5a29EL0puTW5EVEE1RwppU1lWT29lOGJHOE9vcDFraGN5SzJsNEsvRW1HSXc1ZWFT'
    b'ZzlxUXlXVEJ1Z0xEK0dZUWc4c2EwSzh5L3Vuc09tVTFNMlNtVXdRaUt0CjBEdnFZbDlIL2p2'
    b'R2ZRUmdMWEN6OE9FbHB6WFoySUxsYzFxd1lKSFR3c2NHTW1ENW5CWStsRDduL3dEZTM3T1RJ'
    b'QkE4eGdBQUFDVjAKUlZoMFpHRjBaVHBqY21WaGRHVUFNakF5TXkwd05DMHhOVlF5TWpveU9E'
    b'bzBOeXN3TURvd01Lb1hhS0lBQUFBbGRFVllkR1JoZEdVNgpiVzlrYVdaNUFESXdNak10TURR'
    b'dE1UVlVNakk2TWpnNk5EY3JNREE2TUREYlN0QWVBQUFBQUVsRlRrU3VRbUNDCiIKICAgICAg'
    b'IGlkPSJpbWFnZTg4NjAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_KS')

US_KS = b64_US_KS
index.append("US_KS")
index.append("United States of America Kansas")
catalog["US_KS"] = US_KS
catalog["United States of America Kansas"] = US_KS
country["United States of America Kansas"] = ('US_KS', '', 1)
lookup["US_KS"] = ('US_KS', '', 'United States of America Kansas', 1)
lookup["Topeka United States of America Kansas"] = ('US_KS', '', 'United States of America Kansas', 1)
lookup["United States of America Kansas"] = ('US_KS', '', 'United States of America Kansas', 1)
details["US_KS"] = {"continent":"Americas","capital":"Topeka","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_KS"] = ('US_KS', 'United States of America Kansas', 1)
regional["United States of America Kansas"] = ('US_KS', 'United States of America Kansas', 1)
#----------------------------------------------------------------------
b64_US_KY = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5MDYyIgogICB3aWR0aD0i'
    b'MTkwIgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE5MCAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfS2VudHVja3kuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczkw'
    b'NjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXc5MDY0Igog'
    b'ICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAg'
    b'ICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAg'
    b'ICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2Vy'
    b'Ym9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgogICAg'
    b'IGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzkwNjgiPgogICAgPGltYWdlCiAg'
    b'ICAgICB3aWR0aD0iMTkwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6'
    b'ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZC'
    b'T1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUw0QUFBQmtDQUlBQUFDM3N4MkRBQUFBQkdkQlRVRUFB'
    b'TEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FB'
    b'QTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFjCkowbEVRVlI0MnUy'
    b'ZGQxeFVWL3IveisxM2VtT0FvUXh0QUFGRnBJZ0ZlOVRZWWt0MFUwemJhTEtKMlpqZVl6WXhY'
    b'VGZOUkkwbTdocVQKR0RVeHNSc1ZGeFVWa1NJaUlGMDZETlBiN2ZmM0IyNUUxM3psOTkzZjYy'
    b'Y3kzdmNmdk9EY013L0Q0WE9mODV3enoza3VCTUFTSUNIeApmdzhzRFlHRUpCMEpTVG9Ta25R'
    b'a0pPbElTRWpTa1pDa0l5RkpSMEtTam9Ra0hRa0pTVG9Ta25Ra0pPbElTTktSa0tRaklTRkpS'
    b'K0wvCkc2ZzBCRmVSbldvZG5PQmdPZWhnVVZSOHBLZXlYcGNVNHlxdENaRkdSdkk2VjREQVl0'
    b'L1haeFpWOUxYWW5PVDB2Tlo5SjZJalEvMFoKeWJid2tNQXR1ZTE5bDU2OCs5eFh5d3R5MHF3'
    b'SUxPS1lJRW5ucHVid3V0MGowN3Q1QVVxSmQvYTFOSFdvZXV5azE0L0xDVzdleEthVgp5MDc1'
    b'QWhnQUlDck1tMmgyUGZIQnFJZm1WRS9JN3RqNTRZRy9QM1ZTcjZHa0NldW11VmRnY2Y3RXBy'
    b'a1RteDk3ZDdURFRYUmFGVS9lClhWbmJvbUZZQ01jRWhvVUJBTDFPVXErbTVETDJpeDhIdFhV'
    b'clUrS2NBSUFoRnNmSmluQ2pqdXAxeWhaTWFWeXpQZVhFMlRDdkh3Y0EKS0dTY24wSkZVZkk2'
    b'd2N2UUpGdE11UGVCMlJlZStUQzNiNm9LRC9HN3ZQaXFKNHRxbW5TYjNqank1ZktqR0NvY1Bo'
    b'M0o4WER0UmMyWgpxdEJ1bTZ5MHhnQUFxR3JVemg3WC9NN2pwMzg0SEVmaXZGYkoybHhrbjlR'
    b'K2VPSlVkSmpYRXUyK3FRWVR1a2xPUk1DdytQRDg2Z0NGCkRvcDExalJyNTAxcWV1eWQwWjI5'
    b'OGpVdkZTNStjMHhXU205bnI2elhLZXVUd20raFVUSXdMSVliQWhGRzMrSFRrWDJOdzlPc1g2'
    b'ODQKVWxaajJIb3dmbDloTklxSUhqOG1TU2RJSUhIK3RTVWxMQWN2bk5Jb0NHRDhrbG1mUFY5'
    b'b2RaSVZkWVpkUjgzdFBZci8vZkJCWVBPSwpJdzF0cWdNbm9ndlBocTE4OGxTc3lmdkcrc3lL'
    b'T24zd3J6QUF5QXA2ZjdQeDlZSjNOMmJjTzdPdXh5NnZxTlBIbXJ4YkQ4YnZPQkpYClVHTHkr'
    b'UEQveHJpYzVKbzdWREtTNzdBcWNvZjB6SnZZL09EZnhnMngyQnZiMWJ3QVNWN25EOHpkMCtw'
    b'R3B2Y1VsSmptVFd4KytzUGMKbjFiOU11V3g2VEtDNyt5Vi96LzhMWlpvdDE1TnYvaGcrVXVy'
    b'Y3dRQjZyVEo5bis2NzQ3bmIvbHYvSm0wd3JxUlJJZDVkeGJFM2p1egp6dVlpSWtOOXk1ZVVU'
    b'RjA2M2VVbG5KNXI5MWZLMkpGRHU0Y20yaTFtVjBRSXExSVRBQUMzbStyc3hldGJOQlgxK2hQ'
    b'bFlkN0FOZUtZCitsWTFBb3NsMVlZRmt4cysyRFIwL2F2SGFCWUJBQ3lZM0xEMVlJTGtkZjVn'
    b'dlBoQXVVNU5KNXJkYjMyWjhkUTk1eDU4ZlJ5Qjh5NHYKZnMxSlorNkVwa1czOVl3ZG40NXB4'
    b'OExLVEVCWTJqcEJiNjlYcFNKaEdLSUR2Y2xtaCtnclpaMUhqLzZyY3ZQdThCL3o0L3pVTmU2'
    b'NgpxRER2Yy9kV2JOeVZ2SHh4Q2NVZ1M5OGJQVFRKOW10QUxjVTZmd3p1bVZIMzdzYU1mU2Vp'
    b'WDMybzdOMk5HYUlJOVRySnEvb29aTnl5CnV5cS8vOVI3OTBNUDA5cG5lNWlwYXpkNUdURXNL'
    b'VGxtN2RxanExY2Z3WEgwK1BGNmp4Y016UjVSMjJiZWZpaDJ3ZUxYNWs2VEw1NXgKQU9ZN3ky'
    b'dERXTzZLRlpuYmh4OHNpb3d4ZVIrY2ZlR2VWeWQyMitSdlAzYUdZcEM2Rm8yMHIvTUhJTkhz'
    b'WHI2azVLTnYwdGU4ZUR3MQozb0dod3JsNi9YOEdOelBHdEZUdXFucm40emRLSEorczJSSmFj'
    b'T3lpS0lwcGFSR1ZsUjBBZ1BaMng0UUp5UjRQQmNOUVZKUU93NURhCjJtNm4wOS9TUnQvL0ZO'
    b'T3ArUGJ0RDErdDNIbDI1cGlMVjVubGVMaXJWejVyMlRTclEvYnhNeWQyRnBpVk1qWTQxeC9C'
    b'OXljMXRLa20KNUhUOC9la1Q3MjhhR2hucWYvNlQzS3M2RUJpLzZ1blRQMzJieDVsLytEay9w'
    b'S0NnZHNhTUlhV2xMVGlPSGpwVXJkSElBQUFQUGpqNgo4Y2NuTGxpUWxaSmk2dTUyQXdES3ls'
    b'cmRiZ3JIMGNtVFV4RUVlZk5qSVhaaTRZK2JzNzljZmx4T2N2M3ROM1dvR3RwVXE1OHYvSGEv'
    b'CjVic0RscEpxNDZ1TFM2Vlk1L2ZPWCs2b3loMXM5ZnBSdllhMjJzbmw2N0tjSHFKL0I0MlMr'
    b'Zm5UTTJQbWZWYmJrVlJmMzNQeG9qMDgKWEoyY0hMNW56N21NaktpcFU5Tit5N0xmejNDY2NP'
    b'aFF0VXBGcmwxYmtKZG5TVTRPTnhnVVdVbTFwM2M5TWV1dnVYYlhGUk1paGdvcwpCeStaVnpN'
    b'NHdiNThYWmJIaDNGOFVOMm9RUlhyeEVWNHlpNkVKSnBkR2NtMmt4VmhxN2VtMlp5eXEzU1Qv'
    b'MVY1NXN4dno5YUZ2djMyCnZwS1Nsc2hJN2FSSmczQWNuVGx6aU1VU3lqSlUvcmZUN1RVdnR6'
    b'VFhSeWZONkh2Vit2ZmYvdUhEZDFycUx3eWZOQ2t0TFZLcmxhZW4KUjdXM083ZHNLUlpGb0Fz'
    b'Ym5KcDE2NHowTmQvdkQ2V1l5N0d6SUVCSlp0ZVVrVzFQcmhvNVpVVDdzL2RXN0R3YUswbm5k'
    b'MHBXU3UrKwpUL2VmcWdqYmZqZyswdWc3Y0RLNi8xVVM1L2Q4WHB3NTg5dVdIdU9PSFdXcHFS'
    b'RVpHZEdwcVJIcDZWRmE3YVZJcUtYeUs3bG5kVmxECmlnZ3lrNGVOQlFEWTdUWXQ4RmVXbnd0'
    b'MFhCUzF4dmpFUkxrY041azBLQXA3UEhSVWxMYWdvSzZvMUxmZy9zV2p6Ujl2MlJmWjM3VUUK'
    b'YVBTaHVSZG1qVzF4ZXZGM3Zob21Jem1hUWFSWTUzZEhxRDdRMnFWY3N5MDFNY1o5NTYwTm4y'
    b'OVB2YXJEcXFlS3g4eGJRNEg0alJ0UAp6SitmQ1VGUVhwNGxMOC9TdjA5SFI4ZXBtb1M1TTkr'
    b'UXlTUDZXaGkvSDBWZ1hWaG9wNWN5aEZ4TytNcktpbm5ra2JGbFphMkxGK2RCCkVJRGxhWGx6'
    b'UDFuNTVPa3I1amdLbmZ2MDVDVXJ4aVJFdWRlOWZHejlLOGNHV3h5UzEvbmRNVEduWS9PS0k3'
    b'RVJuaDY3N04yTnd6cXQKVnl5cGJodDM4ZjMzWmlIR3UwZ1N5ODJOMjd5NWFOcTB3UWtKeHF1'
    b'TVlDaS8vZWNTbkFnWFVESnhjQVlBUUtuV1ZKYVhSQTBlelVRUApuelEyaXlBdVIwNHFGWm1T'
    b'WXRxN3QvS3h4OFpqR0FLUjhjT1N1eXZLS2k4MGEvdmJ2RzlXYlYyTDVxMHZoelYzcUdKTm5w'
    b'b3JyMHJTCnVkSE9FeGExU21ianptUzNENDh3K2pmdFRoUkVxUCttMzY1MTdmcjBMd0NFQUFC'
    b'd0hNM0xzNFNFS1AvVHppKzd0amk2YXlQREtGTjgKcnNtYzJOZFkxWXZYV1lYdXR0cm01dWFj'
    b'elBUKy9iVmErZkRoc1JoMmFScEMxS05HbWRkczJHWmd1TXNURTRIejAwYTNIamdaM1dGVgoy'
    b'RndFaW9yQk1XMEZ5UWNSTHo1UXpyQklxTjV2ME5DUHZ6ZnFxclhNazNlZk0rZDhBS0RyNUVK'
    b'MFhpeExNalJsekJ2Q3NIemhvWFU2ClkxaGNVaVlBNFB6NXFvcVNRb0tRZXh3a3ovTUk4dHYv'
    b'ZUFpUHlsengxenRmZWZ1cmpGL2JUbGFFdFhRcDc1OVZPMzlTVTJ1MzR1MnYKTXR4ZVBCaHUx'
    b'K0NRamtMR1Z0VHBudjFveE9uem9kbXB2ZjB2S1dYc3NzVXFXRDN1dWthYXFvL2hHRUl6cEo5'
    b'Q2NZZy9zZWU5c3lkLwpPcmo3cTZyeTAzS0Y1dWpoWFN3bnRyZTNYMmRBdFpPZlhLSzZhaHZR'
    b'SE81dDdWYklTVTRoNHg2Wlh5MkZ5YjhqL3JZdUt5UFp2bm5GCmthRkp2YWZPaGZhL2RNZmtK'
    b'bDNpNDllMXdIRU03YWpzc25JQ21xYzNUdWxsbFJwRFJHVlpma1dkaCtXNDVvYnE0YU1tK2J3'
    b'ZWh1V3UKYTBwbmVlVDJ5VTM5VzA1V2hJMFoxclg2KzlUN1hodi8vcWFod1RIbXdUQmhqVXp2'
    b'RHRVSDN2dkhVSU9XY3JxSnF4Smw3cHRqUmJUVApybXRFNEhrUG95TDQ5c2FHN1g1YVZlZU9i'
    b'VHluOGZzOGNrVUFRZEFvYzRKTXJuVDBkaVRFeDEwL2Z0VE52SGYyOG4vc1RPcmZ1TE1nCnB1'
    b'OUVqbEZMWjZmMDVoZEhTRjdueG5QbjFJYkM4bkFBd0lUc2p1bDVMVmZ0QWVibTVRQ1l1SzRS'
    b'bkpCbDVmM0o1MmRaanVhcHJ2dkgKZHQ4eWV0QzB5YU9qdzlWK24wY21Wd3FDd0ZKdUNCcEFB'
    b'aGRNamh3OVRLdWkrN2YxNldhd3hiSGkwZUsrWkdmSjY5eDRWbitmdHZhbAo0elNMeUVudXFW'
    b'VWorbDhhbTltSmFlNGNvQjJOTWM0VXBnUUF3QkRFc1p3Q2RaS0VWaEZyTEt0QUFRRHRMUTBJ'
    b'WUFZNnJOb0plUm5iCmRoK0wrYlVsUHRMejBwL0wrbkxweHd6cjJuVTBScExPamFlMlJYUDdj'
    b'N2ZnbU1CeThGVW5Xb1ltMlNCbDVvQXRZWlduN1l6SVVDSTMKTWljUzVaMXBVWlkxMi9iRE1B'
    b'd0FNRVhGT3JvYkJ1ck1sWmxEazliMWwwNWp1K3FoTjhZQ0FIQk1HSnZaS1lYSnZ5TVlGdjdQ'
    b'azFESgpNVjZZSEdpZVh1VytyeFd3Q2lka0JsMVlqOTBmRWhuREcrUFY0YkVZaGdNQWFDcGdp'
    b'b29mNkxDU2lZbG16Mis5ejBORndaRDhGZVJICitFemhDSUFIbW9ic3FDc1hJWi9aYk9ZQUgy'
    b'V2lCYWJYR0I2QkU2UUlSQUFBS1pNN25FNUJFUHFjMFBWQ1pXVkVlSkNudFFlSjE5R3AKNlZj'
    b'WGwxNlZOd01BMEtnSGVpUktGTVV1Rm9URXlTd1dMaWxCcUc2MCtkM2RBQUFjSjJtS0FnQWdD'
    b'TW93WEZ0N3h3QU5halhYaU0wbgpaSFVNVDdOSzB2a2RzV2hHM1Y5dXIxNTJWK1ZWN2RDQTcz'
    b'd0lndExIWlllR3l3RUFOTTNMU1V4QjhBQUFudWRoR0thcEFBQUF4VENYCnkvVy9kNEVoL3Zl'
    b'ZUtONzIvcUgwUkxzMFlkMWdsREoyVEdhWHk0dVBTdS9XcXVoeFdaMzlQd0VBQUxqY3pNQ3Rj'
    b'UndEY1FJQXdHcjMKYTFRRVRYa0FBTHpBb3hnbWlpSUFBSWJnQWMxV2ZiL2FkV2x4SHFLbFpv'
    b'MXRvV2pZNWNOVDQrMXVIMTdkcEpXa2N5T1pNNzc1YjM4cApJWEZlbzJDc1RwSVhvQmlUWith'
    b'WWkvRlJucE1WWWNYbmpRQ0FqazRPQ1A0Qmhqc0l4R3MxTWdDQXkwdnIxQ1JMZVFBQUFpOENB'
    b'QVNCCjczTk40Z0NMRXZEZXp1NUxWVlJ5Qi9la3hqdUdKZmNTT0wvOVNIeVhWZmJCazBWQUJQ'
    b'bkZFVHNMWWlUcDNBQTZySW8zdnNoczdWSm0KRE9xZE02NFpnUVVVQWF1ZUtwSVJISTd4SSs2'
    b'YjI5eWhyR3RWQzRGNldKRStFSU51cDVVVmZSb1ZhWW5SMlJ3QnI5Zmo4M2tabG9VZwpHRVlR'
    b'S3VEak9CYkRCaFE4Q1ZSdGJZdXE3L3M5eDgxN2pwdHhUTmorL2kvMXZsQVY1TzZ5eW53VU5q'
    b'NnJVNUxPamVIMGVlUHA4MFlBClFJQkc3cDlaRnhucXR6cklUN1lNM2xkb2pnangyZDA0QU9C'
    b'Y25VNzBsWUtCU2FlbDA0TXd6ckFRQllFaFZmVzlOQXZuMEJUSGNoQUUKa2FUY1puY0Fuak9G'
    b'aHcxSU90NnljL1dYanAzdlg3MVBJV04vekkvRE1GRVFvVmlUdDZaSnQrZDRkSTlkSm9YSk53'
    b'eVZuRjA4cjJiRgpvMmVTWTUxZVAyYlEwczh1cXJCRXV3cEtUWDJKRFFXbEpzNVZNRUJyS1Jt'
    b'M3hFZHBZUWljcnBjTkh4cVJNMktNVGgvQ0M1Zm1IYVhHCndER1VXcTBlMEh6bHpEOWVIdDcz'
    b'L2FHaVNKTXg4T2dkVlZVTnVwRVJGK01pUEs4L1hGS3llY2ZxNXdzampENUpPamNBQkJiM2ZM'
    b'TC8KMVlkS1l5TThEamVobExNWE81UldKekYvWWxPUzJaV1RhZ1VBMkYza21WTkZRS0FIWXBE'
    b'eDIxUUszTThxTEhGUkFBQktVQUlBWUFRaQpaWElxNElNZ2tKS2FPcUIzSmxERnAwcHQvejR4'
    b'dVBMcjlMd0hacTNjbkg3bnJRM1pLVmFTNUY3NUxQdkRiNGRrcFZoZmVhaE1rczZOCmVPdXcr'
    b'TjJCaFBHTFo0MjhmL1lYUHc3Q1VDRXkxS2RYczYzZGltM3ZIenp3K2I2b01DOEE0T3VmUTNq'
    b'bjNvRVl0TnV0Q0FJWndoUDAKcEYyckltSVQwZ0VBY2hMSE1KeW1LU0FDSEI5UWloYnYyTDFw'
    b'NXhXSkg1TnpPeUtOL2hNVm9SQUFuMjlOKzNwdjR0ODNENW13Wk5ZLwpkeVZKMHJrQnNCeTha'
    b'bHRxWTd2S1Q2RS81c2U5OG5uMjNrTHozUzlQbUo3WCttTituSDc4dlczZFNnREFsZ01Kcm9a'
    b'UEI3VFVWNnBRCkJLWTVIQldkTFowZXZXa1FBSUFnOEw1ZEgxRVVZWGhBMjBTdXByVmJmN25p'
    b'STR0djlpZFVOMnF5MG14TGR0MVdVR0s2YjFidHhKd08KaWtHS0trTWw2ZHdZOGpLNlR2M3pw'
    b'NnJ0Mjk1ZVd0elFwazZNZHExNitwU2ZRbmNkaTluNGVzRzhpVTBBQUpjWFgvMlZTM0JmUCtK'
    b'UgphQ0lwaHZQNWZBUUdkN29VT24wWUFFQk9rZ0FBQ0lJeEhCOUl4b1hnUExqNlMwZGZYWVR4'
    b'V1oxM1Q2c3poZmpURSsxUllmNTd0czdQCnhXdC8rT0NYcFF1cXZua3JmODFMeDZRdytjYVFH'
    b'dS80WnNVUmc0YXl1WWprR09mbkx4UlcxdXVWSlB2c3g3a2ZQWE5TSVdOSERlM3UKNjducTYv'
    b'VE9zaGVBZUoyejM2RlJnK3d1bW1OOE9nMFpGcGx5S2FKQ0xnMlJDQUM0N3FhT3lIU2RmZW52'
    b'bXk4dDZPNmJWZmZ5bjh0TwpiZnBaS1dPWDNYVk9waElZRHpUbHNlazVpK1lrelZuNDZaYkIw'
    b'cGJnamFHcVVaY3dlNkZDeHJtOE9Jb0lDeVkzeHFhNWRjM2FXMGUyCkhpMHh2Zko1OXVVTkd4'
    b'Lyt6RHVLcnkycjBNZ1grbHFPSDY5UFRBd05DN3RpdVJTZmtGeThEM2lwemc1U0RQeDcvNFpo'
    b'V1FBQVJma1YKQUNnVTE5bGFaTnZlZWVZZDlhK2xXQjU0ZmF4V1JSOWV1M2Y1d3lYZERqbm40'
    b'STdXbUZBRUFBQThmcXlxVVNkNW5Sc0d4OE45L3llTwpoN2Y4a3JCN1g0eE16UzVkZVA1UVVl'
    b'UmR0OWF2ZUxSNHp2am12cDViRGlSc1d2K040Q25zMDAxVlZlZWFOVmRQWWFJbzRoaW1sL3Rr'
    b'CkJLcUUybm82Vzd3ZVQxMzVHWjZsRlhJRkx3amhZVmVmMjlxeDQvSVNTWERsZi8vUExkOGR1'
    b'T0pNb05OREhDOFBpd3IxSDZtTGZYZksKb1M5ZU9WYTBhVWZ1NEI3d3h5Y1l6bUhobVBEQ0Er'
    b'VlBMenEzNk5iNmpBUTd3eUpUUnJabHBmVFd0bWlNZXVwTWxiR3ZDazcrNmZESgpnejZQc0V4'
    b'KzU0TmlzMWx2TUNnUEhxeVN5L0h3OEV2RmIxaVdyU3JlUG15UXdlNEtPTzA5NTg4ZTNienVS'
    b'Mjk5cGR6YkZjWFpVZGFUCm5qNG9OaW01cjNORGd4WEhVUVNCTjI4dU9uUG1ZczZRUU1tdVJR'
    b'dWVIZlhyQ1N3WndTMmVlNkhITG1OWVpQcm8xcVU3YnIxUVJIeTIKTlcxVWVvOWN4Z1ZCdmFa'
    b'Z2tNN1NoZWNmdU8xQ1JaMmh1VVA1YzBIczhDRldGQlpYYkJqMnlaYkJSZWRDR1JZUlJRZ0F3'
    b'SERJejBkQwpadzM5Yk9FRFM0MG1jMzUremZEaGNUYWJ0N0t5UTY5WEtKVUVnaUNJTEtyVkNy'
    b'd1VGQktSa2pseDZiaHBNMXZPbFFrY280bU9NY1RHClpvMGVvek9FQUFBMmJ5NUtUVFY5OGtu'
    b'K3RHbHBGTVdPR1M1MkZkOHo1ZUVjaDRjQUFHaFZkR1Jvb01jaEN6Y0UzbHBhWEg3QmNPcGkK'
    b'NU9telJzSE5OYmFwaHliYkZES3Vmd0xoSDVSZ0tKSlNzSDczTDZjaTMvcHlXTitQeVltdWox'
    b'NHN1dWY1OFFaWjRMTVhqNi84NTlCQgpjVTZXZ3c4VlJkYTJhUFFhYXRmcTB1d1phM3NEYVd2'
    b'WEhvVWd5R0l4Y3B6UTJHaDk3cm1wU2lYeFB5K2pWcTA2bUowZFUxQlEyOXJxCnVPdXU0WHYz'
    b'VnI3OGhLcnB4TklaaitYK1d2MXA4b2oybC85Y0JrUngxckpiajZ6YnJWRXhiZ3FuQTBpb1B1'
    b'Qnc0NjFkeXVwbTdjdWYKNVVoZTU4WVRGK2wrWTMwV0FHRFM4UGJYSHk2ZFA2R3BzVVZsVFlp'
    b'YW0xUlYxNkpkTXE4R2hrRzdWZUdua0pZdVZZQkd0KzRQajhMVwpqY3JrUStNbXo1MDNiTisr'
    b'U3IrZnVlV1dsSUtDdWkrK09FWVEyTFp0SlZGUk9xMVczdHJxcUsvdjZlNzJiTmh3M08ybWtw'
    b'UEREaDJxCnBpaVdKTEZodzh4NkhiNW9jdjdXalI4dWVHYWszWDI1dUU1am0zclA4ZWhIN3Fp'
    b'bWFMU2lKOXpMNGhxQ1NvdDNmTGMvZ1dMUWk1MnEKMTlabUMzLzgwcmpCSUoxL25Za0FBQmgx'
    b'Z2ZXdkhOT3FtSUtTaUM2cnZGa0liU1FpcDBmWDdEd2E4ODFlUzBXZC9uempwYzhqR1E3NQor'
    b'Vi9tMnNyaWVibmZ5N1hKNmRranQyOHZiV3pzVlNvSmtzUXNGcU5hVFI0NVVwdVhaOW13NGZp'
    b'cVZRZlZhckt0emFIVHlUTXlva05DCmxCd25USm1TbWhwZFEzUS8vdWh6WFc5dHlPaC93aHdB'
    b'Z0twZ0dpSWlOVjZkbWw1ZlBhSUlKTmVWNGtWbkRNTlRleGUvT1RZNzFacGYKSEF5NXljRlQ2'
    b'ZUx4UDFWRmhQcnVlUDZXL1NlaXk3b2k3QzdDTDVjTEhsNkwrRDlZZG1yeHZCcTNEeSsvY1Br'
    b'QTFQa0cvWVp0V3M2NgphVVRDN3ZrTHh0eDYyOHdMdFZhYTVsUXFzcjNkaWFMSThPR3hody9Y'
    b'SkNhR2RuUzR6R2E5MTB0YkxNYTRHRldjL2lSMzhabVBQdHh6Cnp3dER6bFJmc2VhQ0VJRElJ'
    b'ZDRyR3NZcXpEcFhWeGRKVEFxWllpdktpZW5hZTl6ODBYZERHQllwS0lrSWpnRVBub0p3azRh'
    b'M2w5YUUKT053RUFHRHB3cXFNNUY0WUZ0OHNuN3dzc1dEOVQ0TWdHSmowdnNQbDBYeEFoQkFn'
    b'OHBkZnFGRXlmNXJhY084Y2UxWnVEcXFkNEJNSApON1pwQnFmSG9TaGNYOStqMWNxZGRwczV6'
    b'QUhUcGJ6enlKbFR4WnQzaFg2M1ArR3FPcnJ5T016ZnhFWXVWSFgrN0lVeFNCVEF5bVduCnZ2'
    b'T01DSE5acDBaVTB4UTZlVVRiNkFkbUI5UGpJNExuUk1Tdnk5MlZ5NG9XVG1uNE1ULzJpNzFw'
    b'VmhHVW1hSTZZQU13a3VlTys3VzUKcExNb2dJZWdkRGVINldEV0lRQUFYRjU4M1E4cDYzNEFC'
    b'aTAxSnVPYm9VbTJwQml2b3d6VmFHUUFpSzB1cXFPTDNkeWlPbHRyT0ZZZQpibk5lbyt3QnBv'
    b'T05reFZkT3p6YUhKbXZtYVBiT1Q0Z0ZIUHhVRnNnMTlSWTA2amJ0Q2N4SWRxbGxMUEJKSjFn'
    b'SzBNNWUxelR1Mzh0CmZtbDF6bzRqY1dPR2RmM2xqdk8wU3ZGYTZWVFd4Z2ZhT05iT0F3QUlQ'
    b'WENVc29aeGN1ZVpBTy83YjU5aXBVekVBUXpDWjZ2b0hvNzMKQzRnY3RoM3hLeXlZSWhGZkhy'
    b'RXp3dURSS2prRUZaNWNPZkprUldnd1ZhSU10dUszMmFtMlhVZGpkaHlKdTIzY3hVK2VLenhX'
    b'WmxyNgpmRGJkenNFRXBMRGdkRGNYY1llS2lDSUJBRVFZRW5tSEdrS0FNZ1VIQUVBREhna0lB'
    b'UUFBWmZLbENjc3dVZTZ0WlJnN0w0OUJQVlUwCmhFS3lPQXpUSWRhRHZrYytuVEQxc1Jrajdw'
    b'L05jZkRZek00Z3EyQWFiRWY0M3R5UTJaZldOelRKVmxKdC9ESi9pR2FNalBQejNuckcKTkVl'
    b'bHlaYjVtbGg1QWdZQVFCVklvSU5SWnhCa0JPcHZZUFVqWllGMjF0L0lRaGdrMEwvcGl2QVFC'
    b'Rk1qZ1RaR20wTjZMekRLUVRnUQpBQVFEdW92RDlRalZ5aW51d1NFSVVOMGNaa0I5alFFQWdD'
    b'aUNQY2Vqenpmb2dteW9nODNyTUN6Y2QzTXJaS3pkUlRBMjNsSG9RK1J3CjFDS05yNVlPR1Nj'
    b'VGFMSFB3V0E2MkYxR2F6SmtpQXdtUWhFaUhOVmtFSWdTRHB1bVJKWFgzblRSWnBFQUF1b01Y'
    b'R2JHRUJLV3hhRG0KQnpYK1JrYWVnUGtiR05iQmg4OVIrWnRvcW92cjN1bDFuZzZBZnl2d3pm'
    b'V1pQLzByVnBMT0g0Tk9xNktoVFkzSVlVMldqTE1MOWUvWgozT2RvMWlYSUlsRkZQRWFFSWFJ'
    b'ZzBsYWVNQ0l3QWNNRTdLdG5kSGtLQ0FLdXMxVE1JM3FZdUZvOXFoUmNic0ZOYzFXY1N5Uk1H'
    b'S3BECnpBL3BlTDlnTHdwb00waEZFcTRaUnFJYXVPVkx0NmVDa3BtRC8wRjhRZnQ0a2VJcVkw'
    b'bTFVV0RGUUF1TGh5Q3lhTlF3U2VFNEVWQW0KNDR5TmgzRklGbzE1empPcU5KeXg4U0luQnRw'
    b'WlE1N2NXOHY0NmxpbEJjTkRVSC9EcGZ3ZW1JUWlibGVIVGxNeWRrNDloT3phNlFtLwpUU21M'
    b'UXEyL2VPa2VIZ2dnOGs4YXhzbzFmbWczNU1saEVuS1YwcHhia0tUelIwWHNWOEdVZFFoUkN6'
    b'V29ITUxVc1BXdzMxRVkwSStTCnk4MDRFWXJnT29UcDRXVm1US1JGSWh5VmhXSE9Zb3BxNS9T'
    b'alphNHpWRi80SFArRUhqUEFYVHU4SVJNVnp0TUIwendWcm9WNzl2bVUKS1NUZ0FlY1JQRlcw'
    b'SW9Fd3pWTWpCQ1JQd2d4amxab01uUE1JckkwSHdmc1k0cHZpMlo4UUFvQUlSQUVBQUpRcGVQ'
    b'UWlUYUNkYS8ySApVejJFQ0pta1JCVVE1eFY0ditBcW93Vkc1RnlDcDRxT2VVUjdjWjBUaU1B'
    b'd1RrNmEwTTZmUEZIM2FBSVhtYkFaS3RyS1lScUVhdWZrCkNSalR3L3N2TXM0aXl0ZkF3RGhF'
    b'UnFLY1c2Q3R3YXlZbTBzNmZYK29PbzNRalpZcExGaHZ2cjludjA4M25EVGRybXI3MmsyMXNX'
    b'R3oKVmFnU3B0bzVlVHpHT25nQUFCNkNjaTZlc2ZHYUxOSjlsa1pWTUtxQzdZVUJUSS93ZmlG'
    b'c3VvTDNpNDdUQWRLRUVrWk00QVRXSWZqcQphZmM1cG0vcjZPWVkwWnRET29nQ0pveUlRSXQw'
    b'RHlmeVFHYkdJaGFvdXZkNEF5MnM1VG1Ed0FKL1BhT3dZUFh2MldWeEdDcURJUUx3ClBoRTNJ'
    b'cGdhRm1peDU0QVBWY0htUCt0YU50Z1RudExYcjNRb2szSGNDTXRqY0VlUjMxM0JnSnVQNEgv'
    b'aThLWFFoeFZacDhCNUJTQUMKVElzUVJxUjdwNWV4OHRIM2FwU0pSUHUzTHRNY1plY09MMjVB'
    b'dzJjckFrMnNzNFJpZXZoQU04dDVCT05VQmU4VEFpMGNJb2RDSmlwUgpMV0kvNWcrMGN2NEcx'
    b'bFZHeWVOeDNpc0lsQ2hKSi9nUktKSHU0WUVJakpQaytsSHkxbzB1TWh3VldRREJFR0ZDVURY'
    b'U3NlMXlMVGZPCkkvQitJZnArcmJlR2NaWFJtQUhSWnBPOWgvMi9iaHRTYmR4TnFKdWJWRHA5'
    b'NEFaRW5VNjJiSFFKdENpTHdqcTJlenpuYVpFRlRDOGYKYUwyaU9oamR4VU1vRkRKZWJpOE0r'
    b'QnRZenNWaldvVHE0TUROelUwVEp2L1BZL0J2cjZIUGs5a0xBOWRjSHlrU3NFQXJLekJBNG1i'
    b'MwpPdGVFc1FraWMrM1poM1VJSWkrTjBHVmdhUWo2dy9zRWFSQWs2VWhJMHBHUXBDTWhTVWRD'
    b'UXBLT2hDUWRDVWs2RXBKMEpDVHBTRWhJCjBwR1FwQ01oU1VkQ2tvNkVKQjBKQ1VrNkVwSjBK'
    b'SDUzL0IraTRueHUwK2lRcndBQUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXkKTXkwd05T'
    b'MHdPRlF4TXpveU5UbzBNQ3N3TURvd01HSzNLSUFBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1'
    b'QURJd01qTXRNRFV0TURoVQpNVE02TWpVNk5EQXJNREE2TURBVDZwQThBQUFBQUVsRlRrU3VR'
    b'bUNDCiIKICAgICAgIGlkPSJpbWFnZTkwNzAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_KY')

US_KY = b64_US_KY
index.append("US_KY")
index.append("United States of America Kentucky")
catalog["US_KY"] = US_KY
catalog["United States of America Kentucky"] = US_KY
country["United States of America Kentucky"] = ('US_KY', '', 1)
lookup["US_KY"] = ('US_KY', '', 'United States of America Kentucky', 1)
lookup["Frankfort United States of America Kentucky"] = ('US_KY', '', 'United States of America Kentucky', 1)
lookup["United States of America Kentucky"] = ('US_KY', '', 'United States of America Kentucky', 1)
details["US_KY"] = {"continent":"Americas","capital":"Frankfort","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_KY"] = ('US_KY', 'United States of America Kentucky', 1)
regional["United States of America Kentucky"] = ('US_KY', 'United States of America Kentucky', 1)
#----------------------------------------------------------------------
b64_US_LA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmc5ODg3IgogICB3aWR0aD0i'
    b'MTU1IgogICBoZWlnaHQ9IjEwMCIKICAgdmlld0JveD0iMCAwIDE1NSAxMDAiCiAgIHNvZGlw'
    b'b2RpOmRvY25hbWU9IkZsYWdfb2ZfTG91aXNpYW5hLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnM5'
    b'ODkxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3OTg4OSIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9Imc5ODkzIj4KICAgIDxpbWFnZQog'
    b'ICAgICAgd2lkdGg9IjE1NSIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2VydmVB'
    b'c3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1p'
    b'emVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlW'
    b'Qk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKc0FBQUJrQ0FZQUFBQ1JwVUpBQUFBQUJHZEJUVUVB'
    b'QUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdB'
    b'QUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBagpRMGxFUVZSNDJ1'
    b'MmRkNXhiVjVuM3YxZFh2V3VrMGZRKzQrbmozc1oySE50SmlGTkluQjRna0YwZ2VYZGZRdkpT'
    b'bDRWbGwvZGxBNFRkCkRaRENMZ1RDTGlHa0VBZ3BwSkhxR3ZjeXRzZWUzcVdSUmhyMWZ1Lzdo'
    b'OHc0azNGTEhNRGo2UHY1NlBNWlNmY2VTV2QrOXpubmVaNXoKbmlzSUYzMWRKa2VPdndDS1hC'
    b'Zmt5SWt0UjA1c09YTGt4SllqSjdZY09YSml5NUVUVzQ2YzJITGt5SWt0UjA1c09YTGt4Sllq'
    b'SjdZYwpPYkhseUpFVDIxOFhXY0lnaGJDclU2aVZZcTQvemhCbHJndmVHMldhTUhkZHZaamJi'
    b'cjRhZzhGQUpKN2t0NXNPOGZjL2ZJWklMQUhwCk9JaHFVT1JFbUJQYldhQkordm54UDl6SVpl'
    b'c3VtSHJOb0ZWenkwWHpzSnYxM1B6UFA2Zk9LYlBiSlFFNXNlV0cwYk5nZlV2K05LRzkKazhz'
    b'V1YvSFFIUVVzemQ5TE9VTWdwWE1kbGhQYisyZDVTK1hKSm5FUWU1bkxDMzVIcFg2TVVnYXdK'
    b'a2R6SFpZYlJ0L25WUmtQY05tRgp5MmEra1JtRDhPK1JVMk9reHZ0WWJaRjVQUzB4cVYyVDY3'
    b'UVBzOWdVZ2tCZHFSMEJnYTZSQ1RLU2RNYm5GdW5UTkRYVUF4Q1BoRkZwCk5JaEtGWWhGSkhw'
    b'K2laejJRRHBGcVIzUzVncEl2T056NVF5UGZQMG1ybXB2UXFVVTJYaWduMXZ2ZVlvaFR5QTNq'
    b'SjZQdEZZVjBQUEwKTDNMNDUzZHg2T2QzMHZmSWwxaFlWM3pHNTVjWDVDRUlBZ0FxalpZM252'
    b'd0ZRMGM2Y0xuY0JMdzJvbjFCa0FRa0dmWkhDcWVkZTNHdApqcHZXekNVVERSTDBqTEZtWGpY'
    b'L2VkZFZ1VG5iK2NxLzNiNmVpZ0xyMVBQU2ZEUDMzWEhsR1o5ZlVWSXc5WGZQdGovZ0dleGgw'
    b'KzkrCnhZTVAvSmpkNGZWa3dqS1pxTUJrUXNBamxrd2RLMFludUxHOUZnQzkyWXBhcTJOOHFJ'
    b'LzFTK2JRVmwyWUU5djVSa1dCbFlzVzFPQWQKR2FELzRCNDh3LzBBTEdzc283Yllma1p0bEJS'
    b'bGhiSDlmLzZaeVZlL3pZSzVaU3hldjRHV0lpUFJZUmRLbzRwTVhDS2wxU0lMeDhNZQpqVG8v'
    b'dDM3eVl5VGpNUlNpaU5HYVJ5SVNKaEdOY01PRnJUbXhuVzlzV05HRUlBZ28xUm9xbXVhUlgz'
    b'cmNxN3hwelpuOXcwdExzOWJLCm9zMHdyelNGSVRaRW9QTk5ycjN0TGxaODlKTjQrak5rb2dM'
    b'UDkxZE5PMjllYmZhOHNIOEN2M3VVV0RoSVdVTXJFNjVocmxuWmxCUGIKK2NaVkt4b0JzT1lY'
    b'RWduNFNjU2l4Q0loQUc2OHNPMk0yb2dsTXdCSTVpcGtHWklqdTBoa0ZJd2Yya1JCWlIxQytT'
    b'TENhUjNmMmJYaworRW1wT0FzYnlnajV2RWhTQnEzQm1IVXFBS3VqZ0lheWZCcks4bk5pTzEr'
    b'd20vV3NiS21ZZWg0TkJaQXlhUUxqTGdDYUs1MVVGZHBPCjI4NUVJSnIxU2hkZVJvL2ZRS0hH'
    b'ZzdXd2xNbUJ2UURVM2Z3TW45MTdNN0hNY1FmZkd1M240emZkUUNUZ3gxRlNnVlp2UkszVlpl'
    b'ZHkKS2pXeUxMUGhRMlRkem51eFhicTREbEZ4L0djcWxTb3k2VFMyZ3VPZTZFY1cxWjIybmM0'
    b'aHp6SHJXTVJncWd4UklhQ2M2RUFRVmNlTwpFRkMrS3lsZmJWUGhLQ3hHb1ZReVB0aUx6ejB5'
    b'OVo1YXE4UG5HdjVRemR2T2U3RmR2TEIyMm5OSmxxWXMzSjlZTTcvNnRPM3M2am91CmxNSWwx'
    b'OUE1a2taMjc4YVlWd2lwck5VenFGWFR6cWwwbXJPaEVyVUd0VTZQU3EwaGswNWxwU2tJNkl4'
    b'bTVsWVgwbEpaa0JQYmJFY1EKaEJsaWN4U1haNzFDbTUxVU1odDV2WEJ1MVZRTTdXUzRmR0c2'
    b'UmlZQW1MdnVPamIxVzNBd1FrSzBFaHZhRFlESm9IbUhxdFBVbGRnSgorandrWWxFME9qMW11'
    b'M05xemdhUVRpV1JaWm1iMXJibHhEYmJhYWwwVXBSbm12YVBCY2lrVWlRaVlTS1RQZ0R5TFFa'
    b'YXEwNXZYZDdhCjN6OGw0dVpMYjJYZm9Jd1E2aWR5ekVyYUxjYXBZL1dUUFZ4enhhWElrb1Ex'
    b'djVDUWY0SllPRGl0UFpQTlFjRHI1cVlMVzA4cjlwelkKenZuNTJweHBqc0g0WUM5U0pvTXB6'
    b'MEU0NEVkbnNoRHd1Z0ZZTysvMFErbkdBLzFUZjYvWThFbit1RGRPWlBnQVNyVjJ5aG41RTFY'
    b'NgpPQXVXdFNNb0ZFaVpOTTZ5S25SRzh3ekxLd2dDMVVWNXREZVY1OFEybTdseWVRTkJuNGZ3'
    b'cEk5a1BJWWtaYWFzUzJGbExScWRmbXBZCk81TjUyeHY3K280N0dpbzE3ZGQ5aG1lZTI0YWdO'
    b'b0FzNFRCcHA5NnZjRm9RbFVwMFJqTSsxOGowTU1xeHNBdUF6bWhHbGlSdXVYaGUKVG15emxj'
    b'SThJKzNONVlUOUU2aTFPZ3dXRzBWVmN6Qllwb2M1OUNZTEFLdmJxbENLcCs2T3dmRkpla1o5'
    b'eHgyTG16NUx6K0VqcVBQcgppWXgxVXBSdkF5a2JqeXUxWjRmVXdjUDdLYWlvbWRaT0loS2U1'
    b'cFg2M2FQY3NMb1ZnMWFkRTl0c1pNT0tKaFNDUUhqU2gxcXJRMmN3Cm5mQzR2bzVkQUpqMUd1'
    b'YlhGcjBuNjJZd1cybFpzWTVvSkV3cW1hUzFvUloxSm9veTRtYjV2R3dndVdidVlsUWE3YlEy'
    b'M2oyY21oMU8KckVZdHQxdzBMeWUyMmNqMXExdUpCUHprRlpXZThqaDc4Zkc1MGdXdFZXY2d0'
    b'dDVwejVldXY0YUpzV0ZNZVU3S3k4dXhxMU1VcDhlNAovT29OSktLUkU3YWgwUnRJeG1NQUJI'
    b'MGVNcWtVeVhpTS8zM1ZzdlBhVVRndnhWYWFiK2FDdGtvOHcvMDRpazg5OGJibUYwN0Z2dGJP'
    b'ClA3M1lkaHlaUHYrYXQrWXkrZzdzd3V2MUlBZ0NEck9PQ3JPQW83aDhLclJ5SWtKK2I5WkxU'
    b'aVJRcXJQWmhPWktKNWU4SzFTVEU5czUKem8ycjIxQUlBaVcxaldkMC9LUW5tN3E2c0syQ1l0'
    b'T3BONm9rVTVscHp3MW1LN0ZJaUlLS1JvS2VBWncyQTBYMjdKQnR0T2Fkdk9NVgpJbEltbXk4'
    b'TmVOd2tZbGtyK0pVYlYrWEVOcHY0K0VWekFXYk1sVTZHV3BQTlYrcTBXaTVyUGZXU0k2Zk5N'
    b'T00xcFVwTldnTGtEQTZUCmxxckN2QmxlNTd1UnBBeXlMSkdJUlVtblU2U1R5YXpUTWErYXhm'
    b'VWxPYkhOQmxvcUM1aFhVL1NlempIbE9hYm1WeGMxT0ZGbWtpYzkKdHRnKzA5R29uYmVVM3Yw'
    b'N1FRWXBNTVpITHJwd3lucWRkSzVZVk1hT2w1NCtMdFpVa3JBL202SDQ4ZzBYNU1RMkcvajBa'
    b'WXRtdkJhUApoRWtsNGdDNCtydFBPWWU2OXZycldHeDBuN1Q5Y3FkMXhtczFiWXNZT0x3UFNj'
    b'cXdmbGtiQzlxell0SG85S2Y4cnZQWFhrNG1rMFlRCkJCTFJDT0dBUCt0SnIyeWtyc1NlRTl1'
    b'NWpGb3A4dkcxMlNFMEdwd2tmaXllTlhCb0x6N1hDR045UnpHWXJTYzhWMy9zZFZHcFpIR0YK'
    b'K2FTZnNheXhiTVpyS28yV1REcU4zbExBL0pZNW1QTE9iSTJhUnFmUENpMFd4V1N6WTdMWlNj'
    b'U2lLSUF2WHI4eUo3WnptUTBybTNCWQo5SVI4WHFMaElKRmcxbElVMWRUaktLbEFsbVZNZVk0'
    b'VGkrMVljQmZnVXpkZFE3VTBlTUxqVnJ4amJkdzBvV3QxeUtJR2xKcXA0ZkJNCnNCZVZNVGsr'
    b'aGl6THVBZDY4STRNNEI3bzRaTVh6NmN3ejVnVDI3bktiWmN2bmhvU3RUb0Q5cUtzRllxSFE0'
    b'aEtKY1hWOVdmVXp2d1YKYTFoUk5QTXVTeXRiS2lqTHQ1ellTdWtONkxSYTZwcGE4WStQelho'
    b'ZlBzVU8rWVlscTZaV0Q0ZjlFMHk0aGxHTEFuZGUwNTRUMjdsSQpjNldUMVcyVkhEaHdBRnRC'
    b'TVVhYm5mQ2tqOEhPL1NjTjdNYjhJeWR0NzFNM1hrMkxPRHoxWEtjUytOYW4xcDMwK0tMS09p'
    b'YkdodEFiCkRFaVptY0tLVGJxUTBnbVFUM3lyc01MS1dwcVhyNkYrOFVwc0JjWDA3TnZPSFZj'
    b'dlA2RkRNbHNSaGVvTC91VjgrQ0hmK3RRNnBNa1IKWXRFSWlZa3gvTzVSd2dFZjFhMExVWWd6'
    b'dmNKNHdJWEdhRWRRbkhpZmRsVjlFMXAvTDZtQjNUUVdtL25KMXo3QnF2a250NHhHYXg1OQpC'
    b'M2RUVUZIRHBNZUYxVG5kSTFicHpFUjlJOFNEcmorWk9oVEtFK2RDNDVFd2FxMGVFWW44ZkR2'
    b'UGJ1MDhMOFFtbkE5MzVjc3o2Umg0CjlNdnMyTGFGU0NUQ29rV0xNQnQwTTNLUW1WUU1LWjFD'
    b'VUlnb05RYml3WEcwWnVjSDhoMWtXV2I3QzA4eGYrM2xlSWI3VHhoUURvNGQKZ1dQeE5hMjFD'
    b'SVdvUXFVem4yRElsWmdZRzhJN01ramRvaFhNdS8xK0R2YVA1NGJSYzRIUFhiVU1uOGROWldV'
    b'bDdlM3RIRDE2ZEliUQpaQ21UdFN3Qk4wcU5BV1NaWkhqaUEvc09ucUUrTFBtRjlPemZjZExN'
    b'aFRHL0NsRnJSSll5YUl4MlZEb3p5WWgvcGdWUUtFZ25rNVEzCnRqRnl0SVA3UG5mbGVaRXpu'
    b'ZlZpTStyVWZPN3E1WXlNakZCWldZbE9wME9sVWpFd01EQmxjZnp1VVdRcGpjbFpnNm13anJD'
    b'bmo1QzcKQzFOaDNYdi93R1NTekVBdmttdDZsU0puZVRWMTg1ZWhVSjJpczVWcUhuemtXUVJS'
    b'K1E2TEtERSsyRHR0VHdSQVlWVWRQdGNJS28yVwo1WE1LcGtJNk9iSDlGYm5qNnVXWXRDSUdn'
    b'NEh1N202MmI5OU9VMU1Ua2lTUlNpWklKeFAwN04rUm5ac0pBcEdKd1dORGwwQXNubnpQCm54'
    b'Zjk0ZmNROUVaaUR6MEF3TUdEQndIb2VQTkpRQ1ljU3hNTUJtZk93K0xab1BMUG4zd1JkRTZR'
    b'WmRLSkNFcU5ubVE4aHQ5OVhMeWoKbzltLzlVWXplUVVsZUliNnVQZnZMeVBmWXNpSjdhK0ZT'
    b'YS9oQzlldFlPL2V2WmpOWmh5T2JBeHRhR2lJcXFvcVBNUDlSTU1oRmwxOApGZEZqbm1jcTRr'
    b'ZEtKeEROSlZ4d3hZM0lzb3dzeThSaTJTVS84VmljWkRLN0NpU1JTSkpPWnozTDdkdTMwOWZY'
    b'aC82dWYwQWFIVWJaCjJBSkExOTZOV1c4ekZtTm95eVBZaTZzSmg4UFRCUnFOQWRsaFVMYVY4'
    b'ODM3ZmdXQ2dGSmpJQkgwWXJUbW9kSm9wNWFvcTFRcWVudDcKeVNzcVpjSTFqTm5oUkpVSzg5'
    b'M1BmaVFudHI4V2QyNVlqa0d0UUtQUkVBd0dpY1ZpVkZWbGx3a05Edzh6ZlBRZzdnay95WWdm'
    b'UVdNbQpIaHhIYnk5RFp5M20vLzd3WnhUVnRwRktaZE5GV3EyV3NURVhRMFBEakl5TUVJL0Zp'
    b'Y2RqS0pWSzl1N2RTOFRUVDhKMUVFU1J4TzhlClIzUHR6VXhPVHFKTFpkTmNDeTcrR0R0ZS9q'
    b'VU9tNG5Pems0U2llU1VDT1B4K0pSb1M1MTUvSHJqRVhvSGhrbW4wNGg2RzFabkVYbUYKSlZN'
    b'cE5iVmF6ZWpvS0M2WGkwQXNSVHdjWXRMajR0Wkw1ck4reVp5YzJQNGFIdWdYcmx2SnZuMzdL'
    b'Q29xd21hek1UWTJoaWlLYURRYQpsRW9sYlJkZVJqcWRKaFNYR0hWNWtSVmFBdjRnZ1dDUXg5'
    b'ODZSRm1oSFpWS2lkOC95Y0RBSUQzZFBRd1BqeENQeDVHUnNWZ3NEQTRPCjB0V3hnMVRmRzlR'
    b'dXZoUVVDdlJmK2dZQWtVZ0VoWnpkdFpWS3B0SFl5dWg5N1QrUk1obThYZy9KWkJLVlNvVmVw'
    b'eU1jQ2lGSkVnb0IKdklLZDIvN3BYbjc1NkdOczNMd05nUDZCUWJSR0M3NnhZUVlHQm1ocWFt'
    b'SjhmSnhBS0xzSzJGNVVocnUvbTU5K1ljTzBqVFd6aVZsYgpEUEJMTjZ4Q1RzVndPQngwZDNm'
    b'VDJOaUl6V1lqRkFvUmk4V0l4V0lJZ2tBOEhtZGdZQUNOUm9ObnVCOVprdmoyUTA4eGtNcGpN'
    b'aFFsCkhJNHdPRERJK0xnSGpWYURKRW1FUTJGOFBqL3grQmdIZG05QjIvTVVjMi81enRTUXFE'
    b'ZWFTQ1FTeE9OeEVzazBtVXdHbFZyRnZEWFgKOHZ5UHY4ektqOVVRRElaUUtFUkNvVEEybXhW'
    b'Qm9TQWFqVExtandJNlhodlQ4ZHBEMnpFSUNTNSs2ZzJNV2lWeUlzS3QxNjVuK2RKRgpIRHg4'
    b'QkVtU1dMeDRNWnMzYjJaaGZnRUtVY1NzbHJqL2ppdTUrVjhmejFtMnZ3UWxEak9mMzdDY3Zy'
    b'NCtkRG9kaFlXRkRBNE9ZaktaCjBPdjFpS0xJNk9nb25aM1pZR2dxbFNMZllzQWJpdEUzRWVI'
    b'UnQ3cEFFSmdJeFFtRlFvVEM0V1BpU2VEeitkRm9OR3phdEJHcjFZS3kKLzBWS21sZURvWVJr'
    b'TWtrcWxTS1JTT0FhYytOd09OQTRhb2hFb2dTRElaS0dTc3JzR3NxYTJ0bThlUk5lcjVlSmlR'
    b'bjYrd2NRUlpHWAozOWhFdis4ZHEzYzFaaUxxZko3dWhrYzYwdnlxUzhOMTMzNkNGLy80Rmxh'
    b'cmxmTHljZzRkT2tSWldSbHVqNWRVTXNINFlDODNyRzdoCjVqVnRPY3YybCtDYm4xaUR4elZL'
    b'V1ZrWlI0OGVwYm01R1VFUUdCd2NSQkFFNnV2cjZlL3Y1eGUvZlFsZlhHQThtQ0FRVHpNVUJL'
    b'VUMKRXRxc0l4R0pKZkI0dkVUQ0VkTHBET2wwaEZnc1JyNHpuL3FHcTluNHUvOGtIUTh3YVZ0'
    b'S29xY1BRUkF3bTAxb2RWcEtTb3JwNit1agpic0U2UEI0UGFwVWFmeUJLdVBvbXJBWGxYSC85'
    b'OWZoOGZpWW1mQVFEUVV4R0k5dDJIeUNpdEo3eXR3V1VEajc1d3hlNSs1WUliZFVGCm1NMW1p'
    b'b3VMMmJObkQ1V0ZEa3cyT3ozN3R2UER2NytNcmZ1UDBEK1J5Rm0yUHhkTEswM2MrcEg1dUZ3'
    b'dXZGNHZqWTJOZEhWMW9WS3AKS0NrcElSUUtjZThEUCtFSGo3M0s0OTBhWGhuVnNTOXNwVC90'
    b'SUtOM1RBa040TUJZbEw3K0FXTHhPUEY0SEoxT04rVU5halFhZERvZAp5YnBiQ0FZakNBcUJV'
    b'RGlNM3orWk5Vb2FEVnF0bGxnc3p1am9HRU5Ed3dTRElRUkwxa0d4V0N3a2t5bmk4UVNaVEla'
    b'WUxNYUE3OHhDCkxWR2xsYS85YWh1MzMvMExTc3JLMmJWckY0c1hMMlprSW9CL2ZBeG5lVFV4'
    b'ZHovMy85MmxhSVRaVXdKL1Z1VkdkVUtLaDc5OE5UNzMKS00zTnpRd01ER0F3R0RBYWpZeU9q'
    b'akkrUHM2MmpoNisrOXhoamtSTklKejRXcHBiWGNnRnJaWFVWbFVneEh3MDExWWl5UkxKWkJL'
    b'RgpRc0c4ZVcySW9zaWV6bEVRRkZqTVpxS1JLRXBSekhxODFaWG85WG9zRmdzZEhZY1FCQ0U3'
    b'K1Zjb3NuTTZuUTZielVwZmJ6OXVsNXRVCktrMHlsZUsrWjdjVEY0MDBWenBaMVZxSlFpSGdt'
    b'VHp4RHF5MG9NYUhHVzlmQjFkZHRJSkFJSUJlcjBkdE1KTUkrdEVhVFZRVzJZbjYKM1d6ckRj'
    b'QXN5RERNS3N0MjY0b3k1czZwUksxV3MzZnZYcFlzV1VKZlh4OWVyNWVTa2hMdStON0RmUDN4'
    b'dllRRTh5bmIyZGZyNHRsdApuZFNXMkxuak01OWd4Y3JsMU5aVW85ZnJXYjE2SlNxVkNrbVND'
    b'QVpEaUtLSXorY25rVGh1b1lSakluYTUzS1JTS1NiOWt3d05EU05KCkVwSWtNWElzS0Z0Y1Vv'
    b'UktwV1RCd25rNEM0dDU5YUZ2Y2ZCbmQzTDk2bGI2WFg0T0RYaE8rNXQvczJPVXpyNnNoK3Aw'
    b'T3VudTdzYnEKTEVZVWxjaVN4UGUrOUdsV0ZzME82elpyeE5aa2p2UHRPei9CamgwN3NObHNG'
    b'QlFVc0dYTEZwcWJtMGtrRW56ekJ3K3pQMUZNUm4zeQpKVG4xR2pjYWtoU0lRYlNDaEVvaHNY'
    b'M3JadnpCQ0VWRmhheG9YNGF6SUp1WUQ0ZkNxRlJLWkVrbW5VNFRqY1lJaFVJSWdnSzlQanZj'
    b'Cjl2WDI0L2Y3RVFRRmtpUVJDQWJSNjNVb2o2V2pTa3FLYVdpb0o1bE1VVkZXUkVOWlBncEI0'
    b'TVVkUjluVk5Zb3N5NmlsMUNsL2QwUTAKOC9sL2Y1U3EyanBlZi8xMTJ0dmJlZjJ0amNRaUlT'
    b'ejVoVVFpRVI3OHg4OWdreVp6RHNJSGdWcUs4YldQcmFIandBR2FtNXM1ZXZRbwpGb3VGcXFv'
    b'cU5tN2NTRENwNFBFOVBsQ2NPcDB6bnRMejQzbGJlYVhQZ01HZ3hyWnZNdys5NGtUcHFHTE5P'
    b'd3JMZUR4ZTFDb1ZPcDJPClFPQjQ2a21uMDdGczJlS3B1WjBnQ0NRU1NWS3ByR1ZKSnBJa2sw'
    b'bGFXcHVuem1sc2FnREE1eGxuejlQM010VHhHbGVFZmF5dE1WTnAKaXZQQTBXcjJSRTlkSXY5'
    b'b3pNcVZkLzRiRnpRVzhNVExXekRyTlR5emFUL2h3Q1RCY0lTNHlvSmFLWUNVRTl2WkljdGNO'
    b'OWRLYTEwNQphcldhWGJ0Mk1XZk9ISUxCSUwyOXZaU1VWZkNGYi95RW1PTDBwVXF2NFVYbTVE'
    b'dHdpRzRPZFBxeG1XeDg4YzY3V1hKTWFLbFVpb2tKCkg2SkNRU3FkWXZHU1JmenhsZGRvYW1y'
    b'QVlEUlNYVjJGUm5OOERkckNSUXZ3ZXIxVFRrTTZuV2Jac2lXVWw4L2NwNkRXYUhuMjE4L2cK'
    b'N3RyQnVqVTF0RFliV2ZsNEMxN1pla2JkY0NDZzU4QzJFTm0wVi9MWVEzM3NBV0RKRGFObml5'
    b'cm1JYytvNC82SEgrTzc5LytNNHRJeQp2dlZ2RDdMcllEZUh1dnI0L1BjZXBqZDVlcUVKc2t5'
    b'Wk5vQWdDSXk1d2d3TmVKZ3dMMlBKa3FVQVpESVp2TjRKbEVvbGRvY2RoOE9CClZxdWxzcktD'
    b'UllzWDRuVG1UeVhUMzNFbHNIVFpFcXFxSzZmRUZvMUdFVSt3V05Ob052Ti9mdndFdG53YkZw'
    b'TWFsVXJCVitzTzhHSGkKbkxkc0tiMlQrN2RPWnE4TFdjVmpkejFFVWpUd2VOY081RlFjOUhs'
    b'bjFNNnYyN2NTSDFFeTRZMVNXR0JrK2RKeXFoZlVFd3Y1MFpscwpURTRHY0RyekVVV1JlQ3hP'
    b'T3BNbUZvMVI0SFNReVdSUWl1SlVmdk5QaEVKaGxLTEkzTFpXK25yN3ljOTNvRlJsMXhqNWZY'
    b'NXNlZE12CkFyUGR5ZnlWaStudDNJTERZU1NRVXJQY09NaldjUG1IUW15eks4NG1LRWlxclND'
    b'cWtGWDZNeFlhd0kvMkZaRVVkSWdhSTk2SktFME4KK1l6c2VaVmR2L3dDQUhaN0hvSEpBQk1U'
    b'UGxMcGJKYWdjL2RXbnJydk84UmpVWFI2M1ZUbFNzZ3VHZEpxdGNqSURBLzBZaklacWE2dQpa'
    b'UGpRSHFLUjZMUmpzN01CbWQyL3VadU1xR2ZaaWtiaVNRbFBYTTIyVU5rSDIwV0N3QjFYTDh1'
    b'SjdVejUxTVh6V1Z4ZitvRzJ1U1ZhClJVQlZpRVl0RW85bXhSQWQ2MENWemk2M2xpU0pQSHNl'
    b'ZG50ZU5vODZNc1NMRC8wSEU0UGR1SWVIVUNxVjA2cU9SNk14REFZOUFhK0gKRjM3NUUvTHNO'
    b'bmErOGl5L3ZmZWJQUC9vejBpbXBudVorNSs5RjdYQlJyNXluTWxBbkMzYk9uRkZOY2dmWUh6'
    b'TW9GV3o0LzdiK2Y3dAo2M1BENkpueWxac3VvTDdVd1cvZjJzOGRENzZBMng4KzZ6YXZzSFRT'
    b'VkNRUWp5ZElKdE9Jb29penBCeWZMOEFiVDk1UDVaeDVCSG8yCm9pdHNwSFRlSlhUdjJZWjM0'
    b'QWltUEFkcW93VzNlNXlDZ3VQN0ZiUmFMWk9UQVh6alkvVHRmSXVKb1c0UzBRaXBXSVMrYmEr'
    b'eTVxUFgKazBxbFVLbFV1UHNQRVJrN1JDUW1ZeFFpeEZNcFd1Zlc4ZjgyVlgxZ2ZYYno2aWEr'
    b'OTdkcnNWbE1xSlVpWnIyR1lEU1JFOXZwS0hkYQpTQ1Rpckdvc1pPUGQxOU05NXVjYmoyeGhk'
    b'Ky83My9UeFhLQ0I3cTFHZnJLNmk3bHpLL0I2SXh3OTZxZTB4RXhqNG5reXU1OGw3bzh6CmVl'
    b'UUZkcnorQW1QOUl5U0Nmdkx5Q3pFWURKak5KaFR2c0d6WldKdU16V1luRWZRelBOekZSWmUw'
    b'OE9JQkZ4WnBoQU8vL3g2QzNrNHcKbHNZMHNSRzFtQ2JtOHVDTEphaXVLK1hlblE0Q0dkMVo5'
    b'MVZKbm9FSGIxOURmV2tlZ3B3aGxVcVJUQ1paMVZySjgyOGZ5WW50Vk15dApMa1NuVmhJTVJw'
    b'a0lSQWlFSWxoVkdlNit0b0Y5dzZWODdiRTlTUEw3MnhCbTAwb1VPQTBNREtjd21qTE1xVkhR'
    b'TjV4aDY5dGpUSXdOCllEVHFjQlFXRUIzZnpPSTZPeFZYTmZMMnpuRWlvVW1PdlBBQVpmTXVw'
    b'bURPQWtSUkpKUEpvRkNJalBZZXdhUU0wNzY2a28xdkhlS2kKZGZYb2RTa3l3eHZwNis2bHNM'
    b'U01ReU5SN0hZVGtiQkFTMU1KUXo2SlAwNmMzVnhORUFUdVhOL0VSK2NYb2RjclNLVlNST0pK'
    b'MUdvMQpxVlNLajYyZGU4Nko3WnpieXRmMTMxK2cyS1lqR0F5eXI5ZkRnWjJiRUxWR2RFWXpl'
    b'ZW9NM2tDWWIveStGMzgwOVo3YnZzRFF3M2N2CmNJR2NwbThnUkhPRGpjQmtnclNrUktNMzRm'
    b'SEVVUW9oUWhFbEdVa2dFL2RTVWxGTUtBS1RNVFdLbUJ0bmRUTUI3eWlKbE1TY0plc1kKMlA4'
    b'bVd0TEU0MmtxU2tWaWFUTzczdDdMd3ZrbGhHTktVb2s0Nll5RVJxdGlkSENZQzljMnNXOGd3'
    b'NWQydFRDYXRyeHZvZjN3RS9NbwpNU2t3R28zRUJSMEh1d2R3QitKOC9UTlhveFJGVkJvdGhU'
    b'ZmNRK1I5N0xQNGMzRk9KZUsvZHZNRlhMT3lpV2cwaWd5MHpLa2dvN2JnCmNvL1RVdUhBa3Vk'
    b'Z0xKUmhVWm1XM1FOQjRxbjNGaklmU09YeFdIYys3VlkzUW5RQ3RWckFiTkV4MEQrQmU4eUwz'
    b'U0lUbUF5ZzFhbEoKUkZ6a0Y1WVRuQnhIU2dhd0dsSjR2QUZzMmdEUmNJaitubUhHdXZheHFN'
    b'MkdWaU5SV2FZamtqVFNjWENNbGtZTHc4TitmT01qNU9mcgpNSm0wSE8wY3hseGV4VDl0cStC'
    b'SC9hMkVKTzM3N3FkN2JtakdKc1pJS28zMFRTU3lkNWd4T1BqSFQyOEFXU2FSU0tCU0tsbldY'
    b'TW12Clh0MlhHMFpQeE1VTDYwZ2tFaVFTQ1l6R2JGR1ZsZlBxbURlbm5GODh0NUhsYzJ4Y3Uz'
    b'WVJKck9aKzk2NEQ5NkhkWXVnNDVNN1Y3QmMKMTh1ZHBrNktpdFMwdGpwNWUzTW5FOTRFb3Nh'
    b'R3FOUlQzMURPMkZpUWlrb0h5V1FHcnpkRktoYm15TkVZbFZWRlhISkpHNWxVQXBOUgpSY2Ur'
    b'TGhLUklCcURuZmt0SmZUMmVxaXVjUktOV29sRWt4UVZHeGkydFBFUCs5cEljSFlWd2MxYUpW'
    b'cVZpREsvaHZwaUs2L3RIMkxWCnFpVlVGV1hEUUZwZGRsVG9Idlh4MVorK21CdEdUOFg4bWtK'
    b'KythVXJhYWlaR2VqYzN6MUt6NGdIaTluSUpWLzl4ZGxmYVhLR3o1YnMKNTI4V1JORW80ZTB0'
    b'SFdqMVdpcXJpaWl2Y09CMkIzbnQ5VzR5NlJqbFZSVm9kVWFLaXd4bzFESmFOV2cwSWw1UGtH'
    b'QXdnc2xpSnBPUgo2ZXNaeFdBdFJLK1JVYXNTb0RGeisyczE5TWpGSDBqL0tBU0JJdy9meVk3'
    b'T1FTcUs3Q3h0bk5sUEw3OTlpTXUvK2RpTVdGL09zcjJMClBUMHVudHphd3orZFFHeHR0Y1cw'
    b'MVJiejBzNXVXaW9MNk9oM245Vm5wUVdSSDQvTzU5bHhQMStzN2VEQzloYlVLcEZvTE1YMm5V'
    b'UDQKUGVQTWJYVVNqU1RJYzFxUWxQbTg4ZVlld240M05wc2VSNzZCUEp1ZVdFS0ozcVFoSXlr'
    b'UTljVjBIZXhBcXhQcDFpN2d2OFlYa2Y2QQp1bGxVS0xpcXZZSHhRSlFiMXM0LytielhGVHJu'
    b'aEhaT1dqYUFyZmY5cjlQV2xjMWtKSjU4cTRQdi9Qck5ENndPUnAzYXhWY2FqcktrClJzbWJt'
    b'L29ZSGd4UVhhNWxTZnNjQW9FNFRxY1JqemVGcU5TUlRNWUlCaElFUXdtS2l3M29ESFpDZmhj'
    b'SWFUcUNEcjU3YUE0VDhnZVQKSERmcE5mek5SeGJ3dWF1WFVWMTArcXpKL2w0WEMvN1hBem14'
    b'blE2clVjdjRiLzRSaGVMRWtmV09mdmUwV3laS2tzenZ0eHptL3FlMwo4ZWIrdmc4bS9LSWI1'
    b'ZnFLTVVxTmNRd2FnVklyV0F3S2VycEhHUjJaSUJ5VDBXcjFXSzBHUkpPVmlGak0zdUVJUjZJ'
    b'VzN2Q1hreFJVCkgxZ1k2SmFMNS9NM2x5N0FZamp1VUF5T1Q1NnczT283TDBUN05mOUtPSlk4'
    b'cDhSMnpnMmpnVWlDaDE3WU9WWFk3NTJNVG9UWWVXU0UKc253TFdyVVNsVkpFb1JEWXNMS0pE'
    b'U3ViT05EbjVyK2UzYzdqYnh6QUg0Njk3Kyt3TDFiTXZzN3BjeXlURkNKUFZVT3RNWVEzb2NZ'
    b'VApOakR1TXBKK2QzR1BzOHcrVlJiWXVHbE5LemV2blV0ejVjd0tTM2MvK2daLzk5R2xwdzVn'
    b'djMxa1JnbjluR1U3Qlg5NzZVSis5TGtyCjBLcVBYdy9QYnp0Q2UwczUza0FVcDlYQVBZOXY1'
    b'R3Mzcjhhb20rN2h4Wk5wbnQzYXlWTWJPM2hsVncrQlNKeHptY2J5Zks1WTFzQ1YKeXh0WTNs'
    b'UTJvMkxSZ1Q0M3FYU0d1aEk3KzNwZEhCbnljUFdLcGhtYmxWMitNSGM5K0J5L2VldmdPZms3'
    b'eituNmJMWEZkdjc5NzlaegorZExqUmZpNlJ5ZW9jRm81TXV6bDFkMDlYTkJXeGZ6YUlsN1ox'
    b'VDNqUnJZQXFYU0d0enVIZVd0L1A1c085TFBsME9CZmZYalJxSlMwCk41ZHorZEo2cmxoV1Qr'
    b'MEpLb08vM1RsTVkzays0NU5oWHRuWnpjSTVKZFNYT2JBWXRMeTQvU2hyNWxlalVTbW5waEsv'
    b'ZUhrM1gvM0oKUzJkbDBUL1VZdnNUNjVmTTRaN1BYa3BqeGZFcTNJbFVtczRoTDFxVmttUTZn'
    b'OXNYb25QSVMzdHpPZkZrbXZibUU2OFJTMmNrT3ZyYwo3T2tlWTIvM0tIdDdYT3pySGZ1ekNW'
    b'QVFCS29LYlRSWE9GblNXTXJLbGdvVzE1ZE9zOWgvNHREQU9QNXdqTGFxUXZiMXV0amNNWUJX'
    b'CnJlUzJ5eGZ6Mk92N1dkVldTVzN4ZEdIKzRlMmpmT1BoVjlqZjZ6clgvNDJ6cC9La1VsVHc4'
    b'WFZ6K2ZJTnEyZ29uMTc2L1RkdmRYRHQKcW1hKzh0T1grTzVuTHVIejl6L1B4OWZOeGUwUHMy'
    b'NUJEV2E5NXBSdFM1Sk12OXRQOTRpUHJwRUp1a2U4alBsQ2hLSkpRckVFd1VpQwpTRHpKWkRo'
    b'T1JwSUl4WkpZajAzWVRYb05TbEdCMDJxZ3hHR20xR0dtdk1CR2ljTkVSWUdOeHZMOEdjUDhP'
    b'OWw0b0IralRzUGU3bEhXCkw2bm4vdDl2NDU5dldVTWlsV0V5SEVlbFZGQmdNODc0dnM5dE84'
    b'TDNuOWpJMWtPRHpCWm1YWmxUaFNCd1ZYc2pkMnhZenFyV2ltbnoKbTQ1K04wUGpBU29MYlFn'
    b'Qy9IYmpRYTVkMVVKOTJmUnk5T0ZZRW8xS1JLVVUvK0xmdjJmVWg0eU1MTU9nZTVJaFQ0QmxU'
    b'V1U4cytVdwpuOS9RemcrZTJzek5hK2RTVVREVDI1d014M25rajN2NXIrZTJjM2pRdzJ4ajFo'
    b'Vndsb0hPSVEvLy9mSWVubmp6QVBGa210cGlPd2FkCkdxZlZTRjJKblh5TEFhMWFSVFNSWWtG'
    b'ZDhZeWIxbjcvaVkwc2FTemo5MXNPVTJBem9sVXIyZE05aGd4bzFVb1V4MjZuZlRhNC9XRVMK'
    b'cVRSNmpZcWZQcjhEdTBXUDFhamorMDlzNU1LNTFaUTdMZnpoN2FOY3Q3cUZSMS9kUjN0ek9U'
    b'WEZlYXhzcmNScTFFNnpZaHNQRFBBdgovLzBxbi8yUHAzbHVXeWZlUUpUWnlLeXVGajRSalBM'
    b'SDNUM2M5L1JXOW5TUElvb0txZ3B0cUpRaWFwVklmWmxqbXRCa1dlYkpOenR3ClQwYW9Mc29q'
    b'R2s5aU5lcFFpUXArOUx1dExHOHFRNk5TOHYwbk5sSlZtTWVyZTNxb0xyS3hxMnVVVURTQlVh'
    b'dm1tUzJkS0VYRkRFL3cKOWIyOWpIaURpQW9GTCsvc1FxTldjdTl2Tm5OQld5WGpreEVlZStN'
    b'QWkrYVVjS2pmemZMbWNqUXFKVEpRVjJKblpVdkZERXUydTJ1VQpIenkxaGR2dmZacjdudDdL'
    b'L2w0WDZZekViRWJKZVVBeW5lSHB6WWQ1ZXZOaHpIb05WN1UzY3RPYU50WXRxSmttTmtFUXVH'
    b'SjVBeDl0CmIwU1NaVVltZ3NRU0tlSWFGVGRjMk1xdlg5dkhsMjVZUmI3RlFHbSttV2UzaHRD'
    b'b2xQelB5M3Q0NFBOWEFyRDE4Q0RyRnRUTStBNVAKYno3TVBiZDlCSTFLU1NpYUlCSkxVdTYw'
    b'SUFnQ2MydUtXTkZTUVVhU3VlMktKV2hVMmVGN2FVUHBPK0tMY1Y3ZDNjdExPNC95MHM0dQpo'
    b'ajFCempmT2k5TDBKOE9zMTdDNnJZcTFDMnBZTjcrYXBncm5LUVdyRWhVSWdzQ09JeU1zcmkv'
    b'aEQyOGY0YktsOWZ6N2s1dFlPNytHCmhqSUg5enkra1UrdlgwUnAvdlFTRDcxalB2cGRmbHFy'
    b'QzNHWTllenFHcVdpd0hyU09yaXlMTE8zeDhWTE83dDRlVWNYV3c0TnpuckwKOWFFVzI3dXhH'
    b'clVzckN0aGNYMEpDK3BLYUtySXA3b29EN1hxeitzb3lMSk16NmlQM1Yyanh4L2RvMHlHNDN5'
    b'WStGQ0o3WVNUVm9XQwp5a0lydGNWMnl2SXRGTnRORk5wTkZOdk5XSTFhVERvTkpyMGFxMEdI'
    b'U2ErZTRjR0dvZ21DMFd4NHhCK09NZUlOTXVRSk1EUSt5WUI3CmttRnZrTjR4MzRkT1dPZnRu'
    b'TzFzeUVnU1BhTStla1o5NVBnemg2MXlYWkFqSjdZY09iSGx5SkVUVzQ2YzJITGt5SWt0UjA1'
    b'c09YSmkKeTVFako3WWNPYkhseURFREplZDhRZk1jNXd2L0h5WkdycG11TzIyekFBQUFKWFJG'
    b'V0hSa1lYUmxPbU55WldGMFpRQXlNREl6TFRBeQpMVEkyVkRFNE9qQTBPakE0S3pBd09qQXdP'
    b'L1hvWmdBQUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3TWkweU5sUXhPRG93Ck5E'
    b'b3dPQ3N3TURvd01FcW9VTm9BQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2U5'
    b'ODk1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_LA')

US_LA = b64_US_LA
index.append("US_LA")
index.append("United States of America Louisiana")
catalog["US_LA"] = US_LA
catalog["United States of America Louisiana"] = US_LA
country["United States of America Louisiana"] = ('US_LA', '', 1)
lookup["US_LA"] = ('US_LA', '', 'United States of America Louisiana', 1)
lookup["Baton Rouge United States of America Louisiana"] = ('US_LA', '', 'United States of America Louisiana', 1)
lookup["United States of America Louisiana"] = ('US_LA', '', 'United States of America Louisiana', 1)
details["US_LA"] = {"continent":"Americas","capital":"Baton Rouge","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_LA"] = ('US_LA', 'United States of America Louisiana', 1)
regional["United States of America Louisiana"] = ('US_LA', 'United States of America Louisiana', 1)
#----------------------------------------------------------------------
b64_US_MA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDM4MiIKICAgd2lkdGg9'
    b'IjE2NyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01hc3NhY2h1c2V0dHMuc3ZnLnBuZyIKICAgeG1sbnM6'
    b'aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUi'
    b'CiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RU'
    b'RC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5'
    b'OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1s'
    b'bnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0i'
    b'ZGVmczEwMzg2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3'
    b'MTAzODQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTAzODgiPgogICAg'
    b'PGltYWdlCiAgICAgICB3aWR0aD0iMTY3IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBw'
    b'cmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmlu'
    b'ZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZzti'
    b'YXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtjQUFBQmtDQUlBQUFCc0NMZWhBQUFB'
    b'QkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFk'
    b'VEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFQCjUw'
    b'bEVRVlI0MnUyZGVYd2J4YjNBZjd1U1Z2Y3RXWWR0K1phUCtJanRXSGFjZzRTUU9PUWtRQ0FK'
    b'QkVvS0R3SzgwdEwzZ1FLdmhSWmEKS0MwRkN1SHg2T01CNVFodFNraUFsZ0NCTkRpT0hUdUhT'
    b'UnpIbGkxSHRoWEpzaVRydE00OStrZU1MWUlOOUErY1dKN3ZYN0oyTkpPZApiMmJtdHpPenV4'
    b'akRNSUNZWmVDb0NwQjFCTEtPUU5ZUnlEb0NXVWNnNndoa0hZR3NJNUIxQkxLT1FOWVJ5RG9D'
    b'V1VjZzZ3aGtIWUdzCkk1QjFnSGc4ZnUxU3hicEZ5b1A3L2p4cjl4RmhzK3JNejVwUDdIcnQ4'
    b'ZWpnM25Ba2ZzeUN2L0dCUmFQUFJ0WlRHZGZRd090UHJubmgKN1ZQWExWTWJqUFU0a0Z6eTdL'
    b'TE5yK1FXbVdhYmRmWXNPYyt1OXYwRCs3ZXRLaHdjV1o1V1ZIL2JqYmMvQmdBbkduYzI3ZHpx'
    b'WHZxSQphY2xtMU5aVGpYN0xTZk9lSzBzMTlwT09qTHpWdS9KTDZpYjYvTzYybGwyM1pzNjlh'
    b'ZUdhbjZKb0xxVVlzaDdQRURvR1hOQWZ6RWpQCkxrcytsRk5ZMDNEN2gzM3Q3eHg0OXduVTFs'
    b'T05uYy9lc0ZEMkZrWEQyNjFaeFF0dUxUV3R6ak5XamgrTlJrWjM3OWlZWDlaZ2FyZ0gKV1U4'
    b'ZGFKcCs5OFZiQko0M0NuUzAxUWtXdHlTcjl0NlZteDRlVDVCSUpIWSt0YTZrOXZwNVMzK1Er'
    b'dFhCekNZT3Z2L2NMUTNDWlJWZworek84L3l2UmtIMHcrV2g0TlBDSCt4YjJubWxOK1hwSS9i'
    b'Wk9rdVNlSjB2RnhPaFBYK2I1eUx3MFRzY3ZyamwzcElmemF1c1NBdlA4CjhwcXpFbm5hVDE2'
    b'VzBDenQvZjh4NytycnRyejY3TjBQL240ZjZ1Rm5QTWNPdmhYM2QrUGlPYTJ0cld3MnE3cXlo'
    b'RVdOMkR4RTY1R1cKK3ZwcUh1YVBnN1NwdWYyMnUrL1B5aWx1TzdRblFXTDFTOVlqNjdPTFlN'
    b'QXZsa2lSOVJuQWFEamFaM1Y4Zi9sbkd6UmlrU0ExNmlwMQo1dWFPdC9kc3ZmM0o3eS8vNTM5'
    b'MzE1cVZkV2lXNXRMQzV4Kzk0QnVaVlBTOTVvK3NYd3JXUXhkOGM4LzJEVXFGNU9zcGhhemhH'
    b'dVZlCktXZjQzOHJmSDBEV0w4RVFMQlQ1eW9uaDJPb1Zwb2JMcTcrZWtvdU5ac2lDS3ZhcGZ5'
    b'di9RRENNckY5eXhHS0o4eDhLOHpQK3Nlc3gKOC9GWDB0U3kzenk4cmFQNXBSOXYzOERDSjg1'
    b'MGhNenBjZXZXVlEzZFVQNEJDeExmTWY5NFBKRXlkVFZUb3puUFNLRDlWRjg4bmxDcgpwT2w2'
    b'bFU2alNKRGsrVVBkdmJiTlAzeDg1OHNQbEJSbEFjRFBmLzNhdXg4MFhmQnpkMFRGNHpnTUNw'
    b'OEF6Z2JCK0YxS1RKRFVlZmNXCnE4UGw4dEVNSTVPSzVwYmxJZXZUaDNQWSs2UDdkcGlxQ3c4'
    b'MGZsRmt6SHpsaGY4aVNTcDVESlpLaEIxbnJQbTVlZ3dEQUFDR2diRlAKQUFCVUlpamdRdWNB'
    b'SkJJa2NMNVRpZWZ6LzJEZmtYc2YrbDhNdzFZdHJ5a3VOTXhRNnpPMWh5L0lTNjhvelNVSURn'
    b'QjBtUWNQSGpxWgpQTzlRWk16Y3RiZHgvYWFIMTF6Mzh3eTlHZ0J5UmUzSlA0OGsrRGdHMlJw'
    b'Z0dQbzdsa2pUak04ZmVtckhPd0JnekVzLzNkVmZWcEtECmV2aHBoY05oMTFRWGRYWlpseFgy'
    b'NjJTajU4eUhlT0xpOGFQbVhsdVhlUkFBZXZ2c3ovOXBMd0RFcVZqeXovWFM0TEFQUGp3R1Fw'
    b'WW4KOXQxSzVQRTR2WDMyYzNZM0FCZ3kwNEtoU0cxTk1Zcm1wcFZJSkxadmY1dEl4Qi8waVp2'
    b'N2RCYnJPWVZDbk53dUwvZ3M1cEE0RXdNQQpIQ0szenRzN1IyZTNESUhEQzdXNXpvZVcvVTNJ'
    b'OW4yN2RTN2g5Z1MybU01c3JUMHRJMFkyWGJQRTV3dWl0ajZ0ZUgyaGE5Y3ZuRmRwCmZPemti'
    b'cTA0UkpGS0laODdaV3FHNGZHQUZ3NkZLZTd5dkpZMVZVRUJEOXdCV0ZnQyticTRUQVJOUFNm'
    b'K09iRDBtMHZrY2prVVJYVU4KS1V6WkRqY3BhVHg4U2lJU2FEVUsxTmFuRDcxT3VXcTVpY3Ns'
    b'T0N5cXl1RGtTdzNueC9oSkVlTVdFU2VHTVRFQXlGWUZqdmFDbUE4aQpIbVNxSVUwR2tUZ3NL'
    b'M1pnOEMzckVYS3BTQ0RnNFJoejBxWld5VGdMNjBxNVBBNXE2OU5OdWw0MWNLVFRGUkFjdHFR'
    b'WDFta2w0aW1YClJyTEU1a2drZ21NVUFPU3FJMXcyQUlCYUNtb3BBSURORGJsYVdzMXpERWYx'
    b'MzFDY1NpbVZTMFdEWHJGU0dHVXovZzFyRjZCWm1vdkQKaUQ5WXBQVmdPQ01YQzlTcUtkZEdN'
    b'VUpaWnlRM1ZaMGdHQmZHa0lFdzZ5c1hnVjRZZEdFR3VZUEZSQmlHbWlvVHBWSWlrd29MMG53'
    b'bApPcmZWYXFNb0NsbS9PQXc3blhKaFZNcVBDK1FHalZvKzVRUUx4ZitrZDk3eWl1QzdkMzBV'
    b'am9NblFBMTVKNDVTRE1jYjVtaEZMajMzCmhJSDRmS3BNTkdxNVFpNzJrMmw3Mmd0T1d3SnVU'
    b'd0JadjBodDNXazViVmRaWERLdFZwbW1sZ21Gdk1rRE1UYnBpMHFlZU04NDdNY0QKRVZhN0xT'
    b'MmFBRzhJQUdEWUQ3RUVlYXdIOHdXREdNYTRxYm1UVnhPT1phYXJKUkxob2dwaHc1eXpFaUpz'
    b'ZDNobWJyM040SEdkb3VsLwp0bmxQRFdvQVFKY21CNEFjZzdiampIV1NrMlJSQUdEeFpkNzZa'
    b'Z1dmTTBySHZiYlhoc3R6QUFEc0hqam5oWXA4UVhWR1lMQ1ZHNkVuCjd6QXk5R291bHdNQWVO'
    b'cUt0czk4QklleU9keVZGZm5JK25UamR2dmxaUE1QRjdqTWJwMG1UUTRBdVRtNnlhMWpGSThk'
    b'aXliWUZCQ2gKQk1HUUlCUkJNQUlETG9nbElEaktkRHY0YzdPQ0dJdVlxcXpjYk4zNUR6cXRZ'
    b'bXZkNlRpSjJ4MXUxTll2eHFEdTlqZjJhQ21LNGlyeQpGSEl4QUpTVlpMLzNqK1pKb2prY0JF'
    b'VFVHeDViYXplcXJLdm13dm82SUNtZ2FMQTQ0T0cvUlBxZFRIK29kS3F5eXVma2ZEbTZLNTgv'
    b'ClV1eUw4RGFxK3BIMWk0REw3YnVtc2p0TEdSaVJYb2xoR0FCVWxPWk9taktXWU92RkkrZDhZ'
    b'OWJUSmQ3Vk5lZDdmbUN6SUZjTDVaaysKWXlhTE9UMWxsRlArWmM1cXRTeEg1VmRMaG5wNzBp'
    b'aWFUbDdBUmRIY2RCQ094RnJPNmcrYU0vbVNzZTUzVG5FMm04WDZlc280eGNsWAplMWo0MkZK'
    b'c2p0clAvakxWaVQ3QU1LZzFNbzRSMWplVU5mNy9TYTJVRGdmRnpvQmcyT0h3K1VJb2hwOXVF'
    b'Z2t5VXg0czBia3gxdGhjCnJGREFxeWlicExtSFlqeVpNTTRBZ1ROUkFKaWJQYkVyaHFhQnk0'
    b'RTJNL3hmODVTekxzYjg5UEhKQUpWU3FrNVRac2lDVGo5MndlNGQKWkgwNjRCSWN1MS9VNTVZ'
    b'bHI2d3ZxaStiSk80THkyU0NSREF1RlhKQ05CVXIwRTFNdm1hbEFjT0FPd2d4aWpkVlFZdm1U'
    b'K1JKRUd4RApka0dVWkM4dUdKeTVFelV6ZUZ3WGkvakZXbzljRUNWREU0SFZrZ1hsejd5dys4'
    b'SzJUc3JaT0UweEhBNHJ4bENjajQ5RFJTNzhmamRiCnArU1k4cU00aTJudUFrWTJaUTkvMllM'
    b'eXIxUVpUa1ZpN0VDVVNKQVVhdXZUalY2dk9tRE8ydnRGZ2RWOE5CZ2E2N1FyeW5JejlLcXYK'
    b'eGZDRXc4c0JBQXdEbkMxSTBFUmhPa1JJMFg3YjFYSXhBQVBwV2oyTGtFeGFpbFFpbkc4cVRo'
    b'b1JtTTUrNm1DUG9hMWZod0dHckU4MwpXUm5xcXhjTFZwVmFDTkxlZnRJeUpoakQxcXlzblNU'
    b'MGk3TUFnR1l3RE9lTWhQa1lCdk9MR0FETTRTVk9Xa0VoRThNVUNsZXZNSEU0Cll6MWlOSlp3'
    b'dWYybnU2d2tqYkhaTEpsVWlIcjRhZituczlubGk3WTg4RWdVd3lEMjFzY3NOZ3NEYkw2cCtL'
    b'clZDMTc4Lzc5ZmVIRWYKNEFNQVErTUE0QXdJQVB5aEdCY0FFalN1a2NNSDNWbFQ3WjVidjdw'
    b'KzdFTFI1WHZ3MFZkczU5eHJWOVlwRlpMdVhwdEtKVVZ0L1NMUQpzTFM2cnFhWVlhRHZyT05N'
    b'MThDKy9XMlJTS3pJbUdtcUtyd2c1Vm1QWE13ZFpRQUhnSzRoQlFBTStxUUE0QWxnSzZ1QVRi'
    b'Q21pdDVOCjFXTlpOYlYyTmphMm5qRVArQU9qZytkY1YxNVJNME12MW1HbTMrZW1VRWllL3Mw'
    b'ZEhtOWd4NS9lZS9SM2J3TEFoclVMNXBibDNYekQKaXRiajNja3BlOXlHQW8zVjRsWUFnSlJI'
    b'QW9BL3pBQkFuaWFta2dDR1RiNnA0cFliR3JBdmQ5WjZCNXMybWJvNjdjcGxsMjBUaXdYegpa'
    b'K3ltT1VpQnV4dDFXb1ZPcXpCVkY0bUVmSUpndTl3K0FHaFlWcDF0MEZnSG5CTmhQS1VXY1N3'
    b'WW93SUFCc01BUUMrTFcwS0E0MWpuCklCNmpKOWtJbGFhV2pXK2RZQmltdDlmVzBwT3VGRVVy'
    b'U25QUDc3U2Z1YVRDdlM4ZmZYcjBuYjJOUjQ1MmxSWm5aeG0wQU1CbXNlN1oKdnVHcmNUeEdN'
    b'eGlHTVFBdzROTlJOQXo2bEFBUWlMSzZ6MDIrNGU2dTI5Ynh1R1ByTVM2M1ArWTVucS8yc1Fs'
    b'cFJycDZwdGRZS2xqLwp2T2xVeHhtcnplNnFxU28wNXFXUFJXR3I2b3NLTXBPVCtTTjhOazRC'
    b'UUpqa2hXTVFpaE1Bd09jd3ZTN3gxL1BNVEZkdnZtWmkvMlNQCjVSeVpTS1RMUWxVMWRkK3dW'
    b'UXRabno3eWN2VUFzTFRBZXJqNTJNU0o0ZGlqLy8wRExPbCtselB1L0d5NURRQVlYT3dOQWNQ'
    b'Z0FOQTkKU1BZNUpxbUVoMysybFNBbWhqK0x1YVBMcVhRR0JRV2xDMUtneGxMQmVsMU44VTEx'
    b'WjNMVXZnUHZ2elJvZDQxL1gxTmx2RzdENHZFLwpLUkFDUXdQREdNVk5uMzRCR3I0ZEFDUkNF'
    b'TExkSEN5ZW5PR3FGYVlybGt3OGpTNFNqWFVlK3loTDRVOVFSTm1jSEdUOWtxRFltQmxQCjM3'
    b'NzdSS0ZSWVgxajU5OHBldUltcGwvY2YrUDRoZ2dBaUpKOERiOWZ3aHBTUy9BTzl4d0FhTFdW'
    b'MzdLTVhHbWNXSlZYS2FXL2V2Q20KNVB3UHQzVHdvOGNwR3M4bzI1aVRwVVhXTHdrd0RMdDIv'
    b'YUtyNWxwZVAxTDYwbXVmTlI3dUdEOGtGUENlL2UzMjhiNjYyMU93T005OAowK1h3eDBOcmNV'
    b'SUJBS2ZkcGE4ZktUazFuRE0rTGp6NzIrMHE1Y1QwaTl2ajMvWG1pM3lDMUVoR3IxaXhKSG5J'
    b'bUxtd0hubmtrUlE0CkRaMVcwV0dsUjUzSGE3S0g5amVhNTVucXp1K3VBUUNOV3A1dDBPN2Jm'
    b'eFFBYUNBNlhYbjd1c3JpOUVUY2Jndm9mTkV4elQrLzc4YjEKcSthUEgwb2t5QmRlZkV2bzI5'
    b'Tm0xV3FLMTk2d2FSMk80Nml0WDBMTmZkMVYxNGJ4ek1wTXA5ODc4dUp6enlVL1JtYnRsWFgz'
    b'M2JQeApXek81WTl2cWJUYzJqUDlKMDh6YmYvM1lkdUxsa1ZGdVpiWnY4NmJyMkd4V2FsUlhp'
    b'clIxQUpCS2habUczUDk1NjFTSjN2V0ZPZVFMCk1WV1Z4ZU1MSnpWVmhWd2UwZFJ5ZXFxZmI5'
    b'KzI1djRmWHovZWdaTVU5ZGM5QnovOHl4UFZXVTZTWnBXc2ZIckpvcm1RS3FTT2RRREkKTW1q'
    b'NFVtMXpVMXVDeG1XeEF4WWJhU3d1NWZIR1pscHFLbzFwYXRuQnBsUEpkN3dDQUF2SGYvYVQ2'
    b'Ky9adm1GYytXZzQrdnJyN3o3Mwp3cXNaMHFEZEt5cXN1WHJMbHV0WnJOUjVta3VxUFZ1U291'
    b'bS83Zm44MERzUGVjTmNwU2dpME5SdTNIcDNaWG5ldU5HVHA4L2VlZThmCmJmYXhmYzBLdWZp'
    b'Wng3Y3ZYakN4VzZhclovRHBIYnVQdGpTdUtiZVluWXFLK1ZkdHYzT2JWQ0pNcFZwS3dTZUtN'
    b'Z3l6NzlPMjQ3dnYKOEk2eTdUNFJsOE1ZcTliVkxsaGlMTWpVYTVVNGpnV0M0YWQzdlBQYXpr'
    b'K3V2S0xtbHcvZWRENWlENGVqdlgzMlEwMkh6VTB2cVVXKwpWdzZYYWNXanQyeFp2UG5tT3dV'
    b'Q1hvcFZVY28rUi9ad2ErZU81M1prc0ZzakNmYmlnc0dQTzNOc2Zwa3NvMzdaWlpYRlJrTjli'
    b'Y213Cnk1ZW1sclcwbmVudXRWbTYybTA5clNyQzZ2QUwyU3dtVCsxdHRPVGRmTnQvWHJ0K2Nm'
    b'SU1YY3FRc204QXFUZVZQUFAwci9QbS8yakEKcXp6cmx0Wm0yM3VHeEllUGRBNjdmSUhncU0z'
    b'dXhqQ3cyZDJqNGFqTDdlOXAzNmZnOUZzOTBqbDZ6NkhlZEZwOTFaTi9lR3JMeHN0VApVam5N'
    b'aG1kRzkxanN6VzJkNXBNSFB6c2FkRHE5bDE4Mjk1TUR4NU1UTEY5YTFkTGNhakxHcGRyaW9y'
    b'TDZtaXBqV1VsT3lseWt6VkxyCjQvZ0RvMTVmcUttbDQ2RkhYMDMrL29GN042MVpXYWVRaS9r'
    b'OFlwWlV4V3g1bnhzQVNDVkNxVVRvR1FrMExKdG43WGVHSTFFZWo1TnQKMEphVzVLVHJsRENi'
    b'bUwxdkJZakc0dU9iSm1ZYjZGMFFzeEgwSm01a0hZR3NJNUIxQkxLT1FOWVJ5RG9DV1VjZzZ3'
    b'aGtIWUdzSTVCMQpCTEtPUU5ZUnlEb0NXVWNnNndoa0hZR3NJK3VJMmNTL0FBbWNKS3FYVkVB'
    b'WUFBQUFKWFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl6CkxUQXlMVEkyVkRFNE9qQTJPalE1'
    b'S3pBd09qQXdIVDA5RlFBQUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3TWkweU5s'
    b'UXgKT0Rvd05qbzBPU3N3TURvd01HeGdoYWtBQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBp'
    b'ZD0iaW1hZ2UxMDM5MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_MA')

US_MA = b64_US_MA
index.append("US_MA")
index.append("United States of America Massachusetts")
catalog["US_MA"] = US_MA
catalog["United States of America Massachusetts"] = US_MA
country["United States of America Massachusetts"] = ('US_MA', '', 1)
lookup["US_MA"] = ('US_MA', '', 'United States of America Massachusetts', 1)
lookup["Boston United States of America Massachusetts"] = ('US_MA', '', 'United States of America Massachusetts', 1)
lookup["United States of America Massachusetts"] = ('US_MA', '', 'United States of America Massachusetts', 1)
details["US_MA"] = {"continent":"Americas","capital":"Boston","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_MA"] = ('US_MA', 'United States of America Massachusetts', 1)
regional["United States of America Massachusetts"] = ('US_MA', 'United States of America Massachusetts', 1)
#----------------------------------------------------------------------
b64_US_MD = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDM1MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01hcnlsYW5kLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MDM1NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEwMzU0'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwMzU4Ij4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5DQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQmcxQk1WRVVBQUFCbVNnQmVSQURxcWdCMQpWUUQvLy8r'
    b'c1psdWRJaldrZHdBWUVRRGFud0QvL3Y3anY4UzNjbSs1WVcrZEl6YjkvUHk0WUcyNmFuSGp3'
    b'TVdmSlRqV282dkZmSWUvCmIzdmRzcmk3WlhMaHZNSk9PUURYbkFDY2NRRHUyTnZJZzQ2K2JI'
    b'aW5PVXIxNk9yZXRielVucWF1U0ZoSE13RFRtUURteU15Z0tEdjgKK2ZtMVdHWVFDd0NNWmdD'
    b'eVVXRHB6dE9pTFQvNjlQV3lVbUhueU0zOCtQbTBWMlh1MnQzSWhJL1VuYVd0UmxiNThmTGNy'
    b'N2JWb2FudAoxOXV2U2xuSGdJdkFjbjZqTDBFVERnRHczdUdvT2t1ZUpUZkpoWS8rL1AzMDV1'
    b'aXJRbEtmSmpuejQrYXFQMCtpTEQvWXA2N0Vlb2JzCjFOZnIwOWZNalpib3lzK3hUbDNRbEo2'
    b'd1RWMmpNRUw3OWZiQWNIemNzTGVoS3ozSGdZeW1OMGoyNnV6MTZldlNvcVRVbjZmQmMzLzcK'
    b'OXZmNTh2UDY5Zlg5Ky91cFBrN3k0dVc2WTNEejVlZklnbzJwUEUzeDRPTEFjWDM2OC9TdVNW'
    b'bnUyZHkyV1dqbnljN3EwTlN6VTJIcQp6OU8xV1dlZ0tUdXVSMWZ2Mjk3RmZZalhwcTI1WUc2'
    b'OGZYbmp3Y2FKWXdEVkxLTDdBQUFBQVdKTFIwUUYrRy9weHdBQUFBZDBTVTFGCkIrY0dBaFlT'
    b'TmRRdzE0TUFBQVNSU1VSQlZHamV6Wm41VzlNd0hNWXJYWTBLQWdMS09jNTVnS0NnSWdnb2dp'
    b'S0NDZ3dHS25qZmVOLzMKOWFmYkpsdEoyeXhOMWpleS9BWjdtbjZlOTFuZmZMdVBaWEZyUndY'
    b'M2g4MnRsS1h5Z2FPeWRoS1Z4VzlycGV4ZHU4c1N5OTVUVVpaWQp0aCtZRWF6S3FyM1ZOU1Zo'
    b'RlFJemdWVzdqOVE1OVEwbFllVURNNEcxbjdoWXpvRVNzV2hnSnJBYUtWWlRxVmhlWUNhd21p'
    b'bFdpd0pXCnF4akxia3Rqc2RvN09qczd1eWhXZDA5UFQrYWdISXV2S2g3THRnNGRCbUlkNmMz'
    b'ZnNDNy9qNzZqY2l5dXFvSllWdjhBRHVzWUNXRTUKeDJPd3Rxb3FoR1g1Z1NYSEdveGdEY1Zp'
    b'RlFLTFlCVUNTNDUxb29TMENvRkZzZktCSmNjNkdmNXVuUnBXd2FLQmliQm9ZSUFuOGZSSQo0'
    b'RWtjUFVPVXNMekFoRmhlWUpwWVkrTVRaN1Y3Njl6aytTa1JWckNxT0N4cnVsVUw2OEpGUW1Z'
    b'eW1saVhaaDNuOHB3SXkwNXhWV1VICjZwOHJ0M2lzYW0vaitTdGFXRmRydmMrcnhGaGNWUVd4'
    b'dUhLTHg3cEdkMjdTd21vTWxrYmtKbjVnNGNQU0R5d1dpKzI4b0lXMXlGOHEKd1BJRGk1emho'
    b'Y0MyQjZzUW1HQzBZSUZKc2NhV3NsbTI4M0kydW9ZcDFrb3V1bFlaVmk2M2RyMFlGZ3RNTlBI'
    b'UXdDUllOMjdHaml4MQpzZFBQK2tZUkxCcVllQkJ6QTVOZzNTSUFMQ2RURk11YVRoZVpEOXRh'
    b'SlZpM0lWaDNpbU5aRmw5Vmdmcm55eTF3QlNGMzQrOTVMNTY4CnkzRWtJenRYVmNGVGlTdTNF'
    b'Tlo5Q05hSUZJdXJxdkJoNlFjV3d0b1lyMHlNVmZQZ1lReVdIMWprREM4RUZzSWlaR290bDJQ'
    b'M1h4WFUKd0FyRkdoWlV4ekpqeW1hWEhua1h4NzEzc2NBRW93VUxMSUxsTFlhMUtFaWloV0kx'
    b'QzBKYzRDK054MktCaVNZZUd0aTJZZEhBeElPWQpHNWdRNjNIaFZWVURpNzNTRG1wZ3VZRVZt'
    b'US83QjRSWTlkN0dUNTVxWVQyYjl6N2YxTUd5N1hTYmVENjBXcWNGV0hQUEhXZjJCZEhDCmNq'
    b'SXpoTHg4cFllVjRxb3FlQ3B4NWVaamthblhrK0tYWmdtVzB6Nngvc2JSeE9LcUtueFlicDBH'
    b'MGpwNm0zRmZMTG9wVnBmN3N0SHgKVHRwdTZqL00rSUdGRDBzL01CblYrNzVRbmZaK3dHRDVn'
    b'VVhQOEh4Z01xeVBrWmIvaE1MS0J5WVlMVmhnTXF5aENOWWdESXNGSnB4NAp2TUJrV0o4TnBz'
    b'VUNFdzlpYm1BeXJDL2g3OWJYRlNSV3FLcjRuazFMbjhSdm80RW5jZVM3ZzhXeStLb0sxSC84'
    b'SkNYcnJhUllmRlZwCllqVlJyRVpEV0Z0VnBZbjFnMkw5TklYbEI2YUoxVkR2WW0zT21zUEtC'
    b'NmFKUldwKy9mNVQ2UmpFWW9IcFloR3lVMGxZSmNEeUFpdEgKTExlcS9wckNNaVFCRTRwY1Ux'
    b'Z0pSYTQ1ckVRaTE1UXlUU2h5VFNuVGhDTFhsREpOS0hKTktkT0VJaGVxVEhFaUY2bE1nU0lY'
    b'cVV5QgpJaGVwVElFaUY2bE1nU0lYcVV5QkloZXBUSUVpRjZsTWdTSVhxVXlCSWhlcFRJRWlG'
    b'NmxNZ1NJWHFVeUJJaGZwSm9FaTF5UldBcEdMClZLWkFrWXRVcGtDUmkxU21RSkdMVktaQWtZ'
    b'dFVwa0NSaTFTbVFKR0xWS1pBa1l0VXBrQ1JpM1NUUUpIN0g3RjBSQzVTbVFKRkxsS1oKQWtV'
    b'dVVwa0NSUzVTbVFKRkxsS1pBa1V1VXBrQ1JTNVNtUUpGTGxLWkFrVXVVcGtDUlM1U21RSkZy'
    b'Z1ZVcGtDUmF3R1ZLVkRrS21BcApLMU9neUZYQVVsYW1RSkdyZ0tXc1RJRWlWd0ZMV1prQ1Jh'
    b'NEtscW9FQklyYzhzQ0tpTnd5d1FxTDNIOW16NVEwVnQyVGdBQUFBQ1YwClJWaDBaR0YwWlRw'
    b'amNtVmhkR1VBTWpBeU15MHdOaTB3TWxReU1qb3hPRG8xTXlzd01Eb3dNQVg3SCtrQUFBQWxk'
    b'RVZZZEdSaGRHVTYKYlc5a2FXWjVBREl3TWpNdE1EWXRNREpVTWpJNk1UZzZOVE1yTURBNk1E'
    b'QjBwcWRWQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMDM2MCIgLz4KICA8'
    b'L2c+Cjwvc3ZnPgo=', 'US_MD')

US_MD = b64_US_MD
index.append("US_MD")
index.append("United States of America Maryland")
catalog["US_MD"] = US_MD
catalog["United States of America Maryland"] = US_MD
country["United States of America Maryland"] = ('US_MD', '', 1)
lookup["US_MD"] = ('US_MD', '', 'United States of America Maryland', 1)
lookup["Annapolis United States of America Maryland"] = ('US_MD', '', 'United States of America Maryland', 1)
lookup["United States of America Maryland"] = ('US_MD', '', 'United States of America Maryland', 1)
details["US_MD"] = {"continent":"Americas","capital":"Annapolis","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_MD"] = ('US_MD', 'United States of America Maryland', 1)
regional["United States of America Maryland"] = ('US_MD', 'United States of America Maryland', 1)
#----------------------------------------------------------------------
b64_US_ME = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTUxMiIKICAgd2lkdGg9'
    b'IjEyNyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxMjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9TdGF0ZV9vZl9NYWluZS5zdmcucG5nIgogICB4'
    b'bWxuczppbmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtz'
    b'Y2FwZSIKICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5u'
    b'ZXQvRFREL3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMTk5OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgog'
    b'ICB4bWxuczpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAg'
    b'IGlkPSJkZWZzMTU1MTYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1l'
    b'ZHZpZXcxNTUxNCIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9'
    b'IiM2NjY2NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2Vz'
    b'aGFkb3c9IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2Fw'
    b'ZTpwYWdlY2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2Rl'
    b'PSJsYXllciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNTUxOCI+'
    b'CiAgICA8aW1hZ2UKICAgICAgIHdpZHRoPSIxMjciCiAgICAgICBoZWlnaHQ9IjEwMCIKICAg'
    b'ICAgIHByZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVu'
    b'ZGVyaW5nOm9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2Uv'
    b'cG5nO2Jhc2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSDhBQUFCa0NBSUFBQUFnem5n'
    b'Y0FBQUFCR2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNB'
    b'NkFBQWRUQUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFB'
    b'QWMKT0VsRVFWUjQydTJkZVp5Y1ZabnZmK2ZkNjYyOWErbXUzdFBwZENmcGRQWU5DR3NJR3JZ'
    b'Z214QkJSR2JHaXpxQ0F3bzZWeDI5NnVBbwpqb09PNktnWDFKRkZJYUNCa0UwSUNRbGs3M1M2'
    b'MDUzZXU5TkxkZTM3dTcvbi9wRmNjYjMzRHpFTlNmMCs5ZGY3T1ZWUGZiN25PYzk1Cnpxbm5u'
    b'Q0x5a3J0UjFneUpLU01vMHkvVEw2dE12MHkvckRMOU12Mnl5dlRMOU1zcTB5L1RMNnRNdjB5'
    b'L3JETDlNdjJaa0ZzeUhMejEKbnFiUHZVZS9kMzJnY1AyeTBWUlJmSzI3ZWlvamwzMy83S201'
    b'TXJkOGRtSTg1VHlWZEYyeFlMTGFYM3FQMG1mNXlKTDMwTmVWZUd0aApRNnF0TmkwTFp1K1VM'
    b'NnNJMWY1U2xVK1JlQ3RkRkMyYktkUC9XOGtsR1Rlc0dIRkpaazdoajU4S1JMTnlVZVB6aXVB'
    b'VWpVcVBNcThtCk16VHRNZDlUSGZEZW9GL2xMYTJlRTd0MjZWZ3lMMFV6OHVDMGR5THRMS2k4'
    b'cW5ONWxkY01sbU9wVXpEZnQzaWNaYWh1TUFXTkw4KzYKNzVqbTFXWWl2dEpZd2pXWmxvZGk3'
    b'bmpPWVZFQ0FKUnFCanVlZEJvV0E0QVF6SzdNV1JhSlp1V3k3NzlqbXM3SXpkWFpFK1ArNGJn'
    b'bgpVWERZbEFDWVh4VWxacTVvZVd4S0NxcVFWUVRWWUlOdWJjL0pLdDFreS9UZk1aazI0M01Z'
    b'czZ2eW1hS1lLb2dBV254OXQ2d2FjQ0JqCjZVcFNDd0dvOHBVVzFxV21jNDcrcUxlY2NiN0Rl'
    b'cXMvUEo1d1NvTEpzemFBdmt5TG5rczZCYk12T3hjQXcxQzN3NWpJT044YUNKZFgKVysrOExF'
    b'cEtPdWVSREltM0RJc1JTZWxIQjY3Z2VWNWtGSTNLc21CS25FVXBOSU10MC8rYnFLaHpmcGZt'
    b'YytvRmpkZW9yR2t5Tkp5ZQpiTDJ5N2hETlpGNHE1L3Qvcytodk1iUERlZE1tdVpKQUtYak81'
    b'bGw2ZWdsV0xhU2Jja2tNMDBnK1oxdDZYcFFCVXZiOXYxYUVXa3RUCmsxN2JQdUp3MlE1M3dL'
    b'WG1GTDQyVUhRSXBtM1lWYWxNZGNaZ1lxa0d4UllydlBrUExMU1MyWG1iRC82YUczeXhhUVVs'
    b'YkpuK1g2VkkKZW54RGZMd1NyT3p5dmxIcHp1ZEpSU3JWWHRDcjRxWnJ5aWhJWExHbHpuWERX'
    b'bVUwNmwvYUZ2djIvNjc4dTVzN213YVZrNzJzcHBpUwpxMHovcjlLVXIzcHp0SHVaR09LMTdD'
    b'MmR4NVlldDAveHhGdyszMXhlMzN1b3MzM2pCeXBLMnVoWEgrY3VXWm96TlNwTDFMUk1TaWNr'
    b'Cjk3c2YvYnNoN2xOZm90TWJQK3dwbmFLV2FVaUJQd2s5N094aXJzWEpMZjdxSjduMnh1RkNy'
    b'dlpUZHdxU09EWTEyVEM3eWFSMjU1NTkKelhkc3FKZy9wL01YbTBLWHJGUk9SY2ZlT25TZ2Jv'
    b'a2h2QWVXdXpQcyszenE1S0xDRVJZSVU4UXlZN3M1MlhUVi9uR3F3N0hJNWJWbwp2UERkWjFz'
    b'Lys5SHBlRngvOWExbEg3dGR6ZWVIOXg2c29HenkzNTRZQm1XRmlwUFA3UXNZMmtsaUY1MkJ2'
    b'OURYMUJPdWxTdGJpeE5kCjJZa2VSZzZjci9TcFhUMitzOTJlU0ZzUUhXTFNOQXFXTGNTTy9T'
    b'bDlBSHc0NEsydXl0K3hmbkxQZ2ZCVmE0WUdSa2JmUEVUZU9EYWQKelUyeWdZN0kvTHprQmJC'
    b'eGNQOGMzVXhKbFoxL3FiT3A1bXU5d2l6RXBZcmFUTjhPeTFSWlZ5VVk3dnlMUE1Wb2ZlWm8w'
    b'c1J0Ly95cAp1V3RXWmx6KzlNRFFxTzFBUmNzZk5VdzdmSzVjTWpNNGxEN1FHZXlMSGR1NVZ4'
    b'T0R4OGZ5MnpuZndVRHptTXV2YzJmU2ZNazJaY0p1CkR6Y1VlTWVmR2hRWnZXcjFIZXpFcTVt'
    b'cFlhR2lWdkxWbG9iM2duY1NYajd2Zko4UUpBemtMRnkwZWxGbHlOdmFYUC9ON2dFcjMvaW4K'
    b'U2FMS1M3K3BXZ0FEQ05VZ2RPYWhoNW0rWThrdTNjVFRIV3VLcFBMMHc0UEJ4b04vMmFLV21i'
    b'aVNQbm43dlplbE12a0RoM1ovNThDSQpuaHpnSGFFWmpEOHpScDg2STFQMVYxdlpzWk5qMXQ2'
    b'akE1RkkrS0RSeW5xQy83LzBYMXRTZVRMaXlkUklJMzBERmlHNGZmNjJLYjFoCk11dnZpTGRR'
    b'OHY5YTYxSTV3b21pMnkwM05rUW9wWVhITmdtTmw4Mmc0OC93ck1zNFE2dm1SN2EvdHUvdXUr'
    b'NGFHQmpROGpINFBJUVYKL254cjI3cXQvYldQckIxWE5lcHhvYlVSVDd3SW0rS2pOMWg5bzBP'
    b'NUFrVGh5SDl0clgzaDVHVi9LWTRUVGpvNFpOOHJDQk9UOFk3dQpVYW41L1VTWTRheVV6TWla'
    b'UmErZy9jZG5ib2xVQmlzcks5OTgvWGxkU1hjY0gyaGJjdVhYSC9rM3JXSnhrZmovcUwyRFpo'
    b'Njg0cFY4ClR1MGZBL0hOVzFBekZYQmthc0lBRUV0aEloZm9uUXlZcWI1NVRaQWs4VnV2WDYw'
    b'enZqOXJWNkNsbjM5dVdUYVRlL1R4eldMVndzN3AKR1U3NXp2YXNTMDMxenNzYmZ2N3ZEMTJ3'
    b'ZWxVNEhIN21tV2Rtelc2N2FYMGJ4enN2dlBUYWVHejZmUmUyZFExTWxIVEs2VW5LT2tDSQpn'
    b'NlovK09IZnROWWJ0NnpEeWVUc1BlWjl5WXg5dzVMZTdUMXpwd3ZlNWJQVFR4eTdZVlQ4d0xw'
    b'NUp4NjRMYXRxMXJxNWZhOGNhN0FaCkI2ak5hbkdiOElSaEFVU2M2aGZ1dm14NG9QY0QxNjNo'
    b'Uk04OWQyNzgwYmNlaGxFaW92Y3ZEcmh6aWY1bDg5dzdmL2FWQzVZdlpGbDIKZUhnNEVBaXNX'
    b'Yk5tS2pyZGRhSTNvOGloVUdWVlZaWGY3N2UwL0xxYUo1NzlmTTlUMndUTElrOTkvR1dPdFlm'
    b'SDhjdDk5Uzg3TmduVgpxNHIreTEvb3ZxamZ2dXBZdW4zTDFGMjArVTZ1Y2tsSFlWMnNZNHRQ'
    b'eWdlODlMckYvWnNQVmRmSUk4Y2YyNlZPOXgrZW5POEoxVFJKCjhXOS80eXZqdzhkYVo5ZFFz'
    b'WEY0WkhUcjNoT080S3pTeUQ0dTBITHUwL2VTaEl1T1M3SnY4K2FYTjIvWlBxZDV0aWlLa2lT'
    b'Ky9QSzIKWWo0eGQvN2k0OGVQYjl5NHNaaEx1dlZuWHRtTGxxckN6UmVNL2FEem95OHEzemtz'
    b'ZjJuTWZ5OHJ1UUVRVmdDMVI5LzZZRzdxQlYvdApiV0p3TmdETzRSdDBmZXdOL1pOYnhtODhN'
    b'Y3pmdCthbG9KamNkMFNiMTJpK09uYVJ1MzVSYk96a2FOZmVZREE0ZENvM01qYjlwY2MzCkM2'
    b'RlczbHV0VGh4bEE2MGdNN0FuZWxZRFh6eG5mblRqNWI5OGNkY3Z0eC9uSkhkNys0S0RCdy91'
    b'ZS8wMzExM1pDdURCQngrMExFdVcKNVphV2x0M0hxbDQrWHBHZjl5K3l1WlJ0Y1lsLytEbGpy'
    b'OStqbDBhUlpXM0xqblYrUnlzTkJSYmNlV1ltNXlVcDNKSU9mL243NmdNbAo4MGh3OEg5S3Jt'
    b'bG5lTGFsNWxIUm1zK2ZPdFk5MnRyYWV1ZWRHeDkvTlc0NTY0eGlRZ3pNc28wQ0Vkd3prSGVj'
    b'VFdPVGluZnJidzlkCjkvNExKdkxjd3BicVdDelczZDA5R1kzLzhJbGZmL1A3V3g1KytPRjc3'
    b'NzJYWmRsbm5ubkcwL1RGbjMvbUJLK09zdUlmcHlYamV6NUQKTmN1a0E3WXJBUVlxczhjcTVw'
    b'SmRULzN4b0pZOG90TC9vL3NISHQ5OUljTkx0cUVRVHJ6MTFsczNiOTdzY0RnOEhvOXFndk5F'
    b'V01sTApPTkZXTStmQnJFdVlnOGVHN3JseDZmVEVpRm95VXZHcDl2YjJ5OWV1N3pnK0VBcFZk'
    b'bloyZG5aMjl2VDJibnJ1MlMydmJCZWN6anNYCmJkcyt1cFozVi83QjBuZm9wMXB3QjUzeXcx'
    b'VmlmV0NTdFFyWnlTTGtxYi95OTVzcDQ0ZStzZnpqdjNyZGV5QzZ6RjA3anhvcXo2QmUKak8v'
    b'ZnZ6K1h5OTE0NDQzZmZXWVg1Nm1DcFZOWVNteVFkVldkKy9uK1NNNTExNE5QcnIxZ1lmMnNO'
    b'cS9YKythYmIwcVM5TFd2ZlkwUQpBdUJqSC8vVUM4ZUpCellyeXo5K2MvWFNwbDlmYWo1d0FE'
    b'dCtiM1BJZEFVdlZUc0hTT3NvVTRTVkFGTTVUdU4rM2x1dFJJODdxdHAvCjEvSnE5djVzenZq'
    b'WjRZc2xqMWRMREhJT1AySFl4c2E2V2JObXliTDgzSFBQdVQwK1Rja1NodGNTUTlUU1oyYkZj'
    b'N2JIR3F6bGk1YzEKdHk0Wkd6NUJLYjMzM252dnVlY2VsbVdQSERrQ29HODBDb1lUR1AzdURi'
    b'bUxHcnFQRDNBYjJvOXJpY0czTzIvYlRmSFJiOUdtVVJCUQpIVVFBYkREMTZhVHlyMll4OWJi'
    b'alQzVmR1M2lnYTRCYjAzQWkxSGE1R3V1bnRzR0o4dmo0dU5mcmZlaWhoMHFsa2xWTTJscUJn'
    b'dXFaCkNkN2hPUy9vZitpU2lOL3YrK1EvUDhwYThYKzQ3ZWJyTDFweHpkckxseTVjOFA1TDEx'
    b'eXdldldoZ3dkQmJiZlRORFRqN3JYRFY2d3cKVzJkQmkzV2RmcStsNVVYWE11cktuZW5JQ05n'
    b'd0dEL0FBU29iNi90cXR1K1ZNeTBUSitxcWNQVWEweFd1bDZxWDZ0bHgxbEhCRlU4Wgpobkhk'
    b'ZGRkbDBpazlQK0Ixa3RKazU5U09SenptUk5nek01V0haelh5Vk10S3FNTC8wQTkyUzR6ditj'
    b'MzdsNW9KZmlwQmdRakZpZ3JrCnhqc3pKaHN6RktxeDM5Mjkrcjg3aEQxZjNaSElJTTkvWFN3'
    b'dW1VcitnQnRubFB4ck5PWkZmWllBWUdIblFYVXdIakJoVTR0M2c3QUEKY29sOVhreU1UNk1x'
    b'ekJ4bDc3ZUc5aHBLa1JWa3ErT25mZGtVRlZjc2V1RDJ1emRlOWVoakgwNU94Z2x3OWJvNWx5'
    b'N252L2pVcTZraQpTMnN1Qk1PZm0vUW5SazQrdWtrQXd4WnQxeHNuaTFmYmtEa0EwQ2hLTmt3'
    b'Z3pGbVQ2VUZDQ0NQNjhzUWJUMkh4WE9RUDhpbjk0MmFqCmprcUwzenpNTDdUdERJd1JFQjZN'
    b'QjBRRUFPMGdPTkUvbnYrbk1UVmlPa3VSZ25yQlF0ejF3NnZrMmtYOVQ5N0srcHNzU3d2VjF2'
    b'SnoKcnF6d3lSYklGNzcyWTVrMWJycHNkc2RiZzYvczZrK3JabXZJUGp3eHFvUVdNWkx2M014'
    b'NWlCd0NjMllMMlNvbHc5cUVqNE5GQVFMZApob2RGbFlEZVZIcHVrOWxRVlJyTFJXNWIxVDJS'
    b'Wlg0OEdhQ3lUWElHczN1Q2M2aldPR0NCOVlFNG9YZkFtZ0tSUUFBU1ZJeG1uOTBvCklLVVZE'
    b'NmJxdlBWanVjVkhkbTlyRHg3bmlScVBaai85a1ExLy93LzNkblgzN3Q2OTUyalhSS1ZmckE0'
    b'SXYrM0pybjMvbFQ2aEpGUzIKZGRNbGpPZytkK1ArNzVWNEVJWVZDQ2pBRXNRTktEWUlRSUFh'
    b'UnYzeWZlWkxYeDlkSm0rcENlTlQyLzFFWWxFdzRPU1FOMmdCaEFOTQoyRmt3UG9nWGdmR0JN'
    b'R0E4TUd3WDJ4OG5UZzRWd28zWFhOeTg4QjgvZHYyOFJuM1RhOThaLys0OVJ6bmJhR3hzNEht'
    b'K2JjSGlhMi84CnUyM2JkOTU0MDgyUVFwNldLeWJ0eUp3NnJ5enk1TS85Sm5PTzd1OFRObVBC'
    b'YjBOaVVMQVI0bUFERXpxeG5melRyNWlEcCt4UDNKVGYKK1JZdWx2UEh3M1drSjAvMlRVSVdv'
    b'Q3RzQ0ZZVVZBRW9BUEFMUVZqQUJLSUZremp3NWhSa3g3aVZlUHduVDdiWGRUNncwWDVxQy9a'
    b'MAp1Uld0R0FxRnBxYW1IQTVIcVZUeWVyMWVqNXRsYkNLNkJ1T2thckZyU2pQTy9aem5iZDhY'
    b'WEpTZThYY08wQ21pT3VvRTZ0ZjF6YnU4CnY5cGI3WGJpMXF2d1dzbURva2taVUpiam1TeHhn'
    b'OGpnWm9OckJ1RkIrRE5EZ2VwZ0F1QjlDclZaVkluN1YyalRYUDgvM21iTEVwN2EKRlhtcTU0'
    b'WUxGODVxYVdscGEydnI2T2lvcXFvQzRIQjZHR29UaHFnbVdJWXhUUE04b3M4Nmd6a0xJZ09i'
    b'SW0xaGF3WUZHeVpGM3NJLwozVlg0OUkyVHVRSUd4N0V1VU1CWUNZcEZyNjJ6VXlBY3JFbFkw'
    b'N0NtUUJXQWhUa011d1J3SUU0d01oeVlKb2FGd2NMN2E0cURwMUJTCjhibmJwejYvOXNWcXYr'
    b'ajFlZ1ZCdU9PT094UkZBYUNidHNSVHp1RUh3REJFWU9sNVJCK0V0UUVDTUFTVWd2RHlnSXFD'
    b'aFdBOTFxMDIKT2s2aVVNTEJMblQxMlBBS3FITndXd2RzbTJWRXNMVmdQR0JEc0dLd1JrRTRN'
    b'RTRRQ1hvZlczSTNLSkZHT3RjTGtkMTNuQnp1UWJhQQpyZ0hjZEVuK21yV3JUcHQ5NUpGSFBC'
    b'NFBnR0JsZmRETjJhWUdTZzNEeWlzelFIOEdLMG9zazRJQ0JGQnR3Z1htMU9TTzVTeDg4SG84'
    b'CitsTzh2QWRYck1Ub0ZFNUdQQVJBd2JJOGJnRUphc1BLaWlSTkxNSkpEc1ZpaU0xd0VGU2FB'
    b'WEVSY0VDTG0yaVV1cmtqOENSZXpNNnEKd2FzSDBEdUN5MjlVVHB0ZHVuVHAwcVZMQWF5ODhK'
    b'TGgzWSt4TE1PeWRqSnZCSjNXK1VTZjRXV1dJYkFCeUJ3RDN5eXBjTXlpYUc1RQpWUmlQM0k5'
    b'MERqZCtsckZ5WnRXdlQ1V3E1T3hpbi91Z2xXd0pRR1JDTDQxVGxpRzJ1eWl4SE1jWVBhTGhZ'
    b'SG1adGJyenlKZ01TeXdXCnFzd1hKL0MvUG9GSEg4VE9OMUhNbmpwdDl1S0xMOTY1YytmNjll'
    b'c2REdmxnWC9GenEwYzRUdHphSzNkSHhmT0pQcEFpc21vWEpBWXEKSll6a2o4RlppK0tTdVpo'
    b'S29Hc0FsZ1hENURKWDE4bWJ4bTBQSnhOeVdUajRsa21ZbksxSlBDaHRjVGhMQWFGL01tMUhK'
    b'QzZsaTVwTgpkWXZ2eW5BVWxwTk5YeGlTRGlRbTQ2QVVDMXZSazB1Y051cjMrN2R2Mzc1Ky9m'
    b'b25ubmlpWTh6Y01oVFFiVFlQMzh4NDRFelNaendHCkJZQzBDUUJwVndNQlBDNE1UeUNkZzI2'
    b'UmtiQWIzYm5FWEU4K0xKV3krakhCVkY0YS81Zkt5SWFHYWlscW5ocktrSUpSV0I0dzhxWVcK'
    b'a2JMdFhuMmhyM2hsWmQ3QkZ1WjVVVEJpRG9lbW82aGdZQXpFUE9QN0ZSVVZxMWF0MnJScFUx'
    b'TlRVMjl2YjVGS1dXM0dLdjFuMHZjTgp3V1Bha3dCY2pKVUhGTTlzclhCaWVCeUdnWWYvQTQy'
    b'MTlKWkkrb1VlVlNXVWRiSW9HaE1sZnBtcWJQN0o2Mi9tb1RhN1BUWVpHVTR3ClF6cVo0NlJG'
    b'ZzlrZkJRUEd5OWkyUlVaVVo4SzRwcDErNjZmb0g4TjNINFpIM0hUUEp6Nzc0Kzk5WS8vKy9m'
    b'WDE5WVpoRkFvRlNaSjAKVXdjOVE1OVFtK2RaM2FUbkJYMGl1QVFOQUVSUTJDWWpCNDdwVWl5'
    b'dGNoeTJQZzZuQXgvOW91MElGSmthZ01ETzRObzNWQWRCam1LTwpoRG1KUElDRWlZeUF6RUIr'
    b'ZkJiMFJhZEhza1hyUUZoZG1zWkVETTkvRzhrTVRnd2lyM0RQN0l0Zi9ldVhudi9sMHc2SDQ3'
    b'SEhIcnZ2CnZ2c3FLeXZITEJQMHpBcmNXemVmWVVocXJPZThpRHhFa0RNV0FEZ1lVRk1EaU9H'
    b'czJYMFlrU0JLS2hnRzB4WFFJcUFXcUFiR2hWY1cKNHBkaHZKakNzU0ttVFZLd0lETm9zTENn'
    b'aUEwbk1QY1ZVQk5nUVZpQVJkNkpnQmVnU0tSUkdjRGVMaGNJK2RRM1h6eHd0UHZwRjNmcwoy'
    b'YlBuOHNzdkh4MGRGYnpWc0UwQUJMYXZlUTNuOEowdmNaK3dZc2tHQllvMnFLa0NJSUo3eHh1'
    b'OFEwSTZCMHFSWjBFcFFFRjQyQ3JzCkVKaDJDQ3RCQVJGMFZ3NkRLblprOEVZZUZGakF3TzZE'
    b'TVFoekhFWS96SDZVRENnYVRBdXloQjBubWdCa0ZEb1N6VXAxSzU5OTl0a04KR3phc1dMSENL'
    b'TVNwYlFJUW5kNWMzNnVsYU0vNVFwOHpTMGtEa3pvbWRGQlRBU0F4NnJFK3l5R2lzUm9FbUxZ'
    b'QUNoaXdTNEFOT3dWNwpMNnFQbzFiQ0RnT3BhaHptRVNlZ1FFOEpyK1pnSkFBR1ZBTlZRQnc0'
    b'TWdWUlFIMEVGS1FyTmUrTTBVQ0xJelRiNlhRcWluTGRkZGN4Cmd1TzA3MnZGYkNrMlVNZ2t6'
    b'eGY2akZIMGNMQUJqb0F3UEFDdkdTMW85dmVmSlkzVlNPVmdUTUR1Ui9zSXpBSFlCVmh4MlBV'
    b'NFZZMmgKSmREbWdLMkNzQURzUWt6NmNMUUowVGJ3YzBFTHNLSllLSU1wSVEwVVNtaUk0SWRi'
    b'd3IrclZtTWNnWnZXTkwzd3h1Q1RUejZwS0lwWgppRlBMQU9BTzFaV20rM0YyRDlyTkpIMHpN'
    b'TGREblBPbXdtU0l6TGdxbWNJRWE2c0N4MjEvbFI4WVE2RUVQbzVGS3RycllIWkIyd2R6CkZO'
    b'WXAyRWxZNDdDVHNPS3dNN0RUWUN0QkZWalQwRHRoOUlDSlkxa2w1Z1BDSkhKRmRBM2dxYU1Y'
    b'djIzVk5yNzB5WnRuMS9qLzgvSC8KTWkxTDhOVmF1VEhaNVZYSER4TlAzZG5lN0pyQmMxdThH'
    b'cXN6dTB1NlpYQWVMdEFhVE8xT2NUV3FZVmM3amFNRCtNQmErNUw1YUs3RApsUmVLdStRblhk'
    b'V3JKZS9jMGtBZnBScE0wQktvQm1KTEhGZmw0QzhRcGZtU2M1RWdOQW5PV3NKVy9PQ0JLYmVN'
    b'VDl5S1NBaWZlN0twClAvZDJvU0JSRTl1ZS90N3E1ZTJkdytuWERnOUw0VGw2Y29nUVcxVTB4'
    b'aGs2OS9OOWhyRTQzZ2xMRSsxY1hxbzNPTmtodWptTzJPNEkKNDJ4M0JVcUQyYkdoUHF4OHJl'
    b'K2lCZm5qQS9ES0dnRHZ2S3ZVeEdEVkZRK29zVDVscXFzd2VpQzQ0azVMeVJaUEhYWTFyaUtz'
    b'd01sKwpTeXRReXpDeTQ4QmhDbmhjK08vdDN0Mng5UUt2TWFmcjlLa1ZOR2pHckhwaWUxOEY1'
    b'ODRicGZ6d2Z0WlZhV2dHNjJ1WWdiempMRmVRCkV6VWhDTHl6Zm5ucDFGRlg0NHJmMjNTRGJl'
    b'b0FzajFiOU13RUFON2gzUG5OM3JrTjlyWjkrTXBySDhtTDdid25ZaW9aMFZzejhhc1AKUC9Y'
    b'bDdNNmpYazV3WERJdit1RnZ6USt2KzZJVWFxYW1ycVZHZkxMeVlPTTkxMTZDamo3MmhuKy9W'
    b'cXhzSzAxMlNlRld3Zk1IOVZLVQoydFRVTXoxYlhRMHJ6V0pDTHhWTnpuMk9SeDZKTVcxRFlW'
    b'ZysyLzFTNDYwLzRKd2hSbkE2cXRwY1RSZHlyaERuREJaUEhXWWRIbVd5Cm0yMjQ0c1hEYzFi'
    b'VkRTaWFIZkZrRDhlWHFyRStMVEZvNjZVSzJyTjZiazVrdElDendMSTRNQkFvNlpLanVvMFZY'
    b'Y1d4UTNjM2Y4OG4KSktlUy9JZCtlSDNKa0NXM1g0MzFNN3pnckY4dStCdGNzeTZnbG00VzRz'
    b'N2FwWXpnVUtaT2NFNi9tWS9saC9hYy9Vcm1zMTYvYituZQpwZ3RLazhlb3BRZFgzcFh0MlVv'
    b'SWxPbGV1YnJkMW92WkU2KzRHbGV6a3B0MVZ0bXNRN09sWncvT3IzRkZIL3JneE82ZEozbzZS'
    b'Nm1wCmdXRVphcmRWamhFQ1FwREs0czNvU3I1NlpYSDBnRExkczhTMTQ1RVBIZjNwYjhPZis4'
    b'MEdIVElZanFHRzRBNWFXb0dUM0x5dnhsYnoKUmlIT2NDSUlZVGpKeUVYRml2clVzZWRaWHhN'
    b'akI4L3h1RzhUemp0L2ZYR2lnL0N5YldxbWtyYjBJcWhsNlVWcWFyYXQyNGJxWDNRegpPZkdL'
    b'cUpjS2lRbEt1UDk4NjVybmpvNS81bjE3Yjdnd3Z2bVl3NlU4K2ZjM0laM0RZMCtCNS9ESjIv'
    b'QkUyOWJIZHFRNFIzVGRpb0twCmxSYmN2eTVoMUlJQnRRMm4wMFV0MWJmNGx0anU3NVdpSnp4'
    b'ejMxY2NPMFNwQlVMVTZWNWYyeldjeSsrYWRZRzE0MTlGZjlQWmovdG4KUGVkaGVKWnFXcUlm'
    b'bGg1WS9pRUFJRVQwMTB1QldjbER2eEI4TlZKb2poUnE1a1FYMWZJOHo3RWNiNnJGZ3VYZGZu'
    b'TEJydTVJVThXMAp4eWMvK1ZyVGtWNjY0YUppZlFRLzJScmUzdFBjSElnV0RlbUp2UXUzRGF3'
    b'cTJSNXFHVHpSUlk1S3dWbUJaYmZCTXFWSVc3NS9GN1VOCjMvejFSblpLVDQ5VkxMMVZqZlVy'
    b'MFc3TzRjLzJ2ejRqQnlobUlPZlI4MGxHY3FPWUF1Q3NYMzc2WVg1d044TUpaaW5scVdpZ2xr'
    b'RlkKWGdqTU1oTTl2Q1BzbHhzTTB5ekdSbFEydEczNGQwbmhrcDRkTVp0QzQ4TFEwWE82MkpD'
    b'bDBMS1MyODlZbEhVRTNiUFhFSllYUE5WSwpLY083Z3B3cnFDYUc5RnpVMDdyV0xDNDJTeG5l'
    b'VzgxS1hzTHhqQnpDVEdnRzZCdUZPRFYwUFRVMnV1blQ3UCs5VGNISVQ4czFpNTMxCnkxbUh6'
    b'OWFMQUtpcC9lSXJ0My9zMnp0MDkyeGtKenlWc3lnbzRTUXRuekJLT1VzdEZLa0lDbUlrR1U3'
    b'Z0pTY3ZlNmxSNUh3TmhCVTQKMmJ2Y044a3JMNzVsckJMOGRXSkZnNVljcVZ6elAwYWZ2ejl1'
    b'cUdkcVVVNjdRbWFDV2liaHhQT0ZmaWs5U2RRa2RkY1VVOUV6azBFaApHbDYxa1dFRlovMEtT'
    b'MG1ieFNUcjhMZmFoelJ0YlpYVEZOQ3pla1hGajkrd1hQVXIxT1FnTHdpaVdBbStnUkdjREdD'
    b'b1dhb3IxRFpZCnljdUhXeGlPVndaM2ZlSFd5My8rMjB6ZnFPUmRPSnRhQm1FRnduSzJvUWFX'
    b'M1hacTgrZFpYeFByanB6SkFreE43M3VWY1RmTUNQMFoKV09zU3pnRXB3TWhCUnZLZGZvSGFW'
    b'bnBZcmw0bytHdXNVc1kyVkNNemRzY3lmdE9XMXovOWtXdnFBOEowTERIcXZzTElSeStURDdm'
    b'Vgp1WWEwaUJScWxxWmVRMzZjcTEwVlVMb0RGUlZGMW45OTlXQmZJZWhvWEwzWWx6Q3lrNHNi'
    b'M1VkN1JyWDBtQlJzNHR4aEl6TnA2VVU5Ck13NVhOZXV0UDJOZERoSm41T3hYc2MzOFRzUGJN'
    b'N0hrMVpMRHhhRTlncS9PVkRKV0tTME9ibUo1N2tTY08zaXNqK2paSFNjVUdteW4Kd3pzdVdW'
    b'd2Y4RGdPamhwU3VLWGRtK1E1VmdtdWFuVm5IdmpRSlNlTzdxc1BlenJHU25La1haODRuRXls'
    b'OXhZV3JBckdFNW1DeFh0dApOYTluSnpMSGY2T3BHbGZSakhlSDNpMzNzckh1Q0ZncDNmRU15'
    b'NHU4dTVKV0x1MFptbWFiMWtXajBhc1dCZDVTRmxHOXVMRzk2SFk1CjU4NXQzWDNvSkFuTzg1'
    b'ZDZWVTBwdU52MDVNQm96NkZGYyt2YjVzN1pmN1RiRUlOakU3SFAzMzJGSFQxME1tcmt4QVpx'
    b'YXNWVGgyUDcKZjJaTFljNC9DKzhhdll0dXhTT0NpNnRvVmhNaitaNlhHWVlWUTAyRVVpTTFQ'
    b'RHd5cGdnaDc5UldsbXBQZDVEWTRCRy8xNW1XV3Z4SwpqMlZhZWZlQzFLbnVsWFA4TDBUYm5i'
    b'a1RqSlpNdVJZYnhlVFduYnVIaGVVbExxeE9uMHdlMjZTV0ZDNjhnUEJPdkp2MHJydVRrSkY4'
    b'CmpLOVJTUXpuZTdjeHZNaFhOQ3BTRFN0NjBvblk0RlRPdTJCRHRPTmxGODFPNVdGTkhDaWtv'
    b'M240U3JGQm1lYW5yV0RYZUdraXp3cmUKQ0FpQkhGWmp2WW5EejJpR3pRYm5NOUs3OFlKYTht'
    b'NytiMmxiU1ZxWkVYZFZpMVExbjNlRndEQ0VzSVRqV2NITlNpNUxWMEJ0aHBOcwp5N0RWdEtY'
    b'bVFSallscW5tY2lkM0t2a1VWekdIY2ZqeExoWjVEL3l6TjdXdFlvd1dKbm1IVjNTSEJYOHRZ'
    b'VGtBSUF4QUNDc1FsaldMClNTMHhxS1VuVGN0bVBiV01NendqWjgvUFJmcC8yQlhVVUttbHdk'
    b'U29wUUVnckFoT0pKeElPT2s5Y1FQcURLKzIva3AzSWJ4anB0THoKZDM2U1ExbGwrbVg2WlpY'
    b'cGwrbVhWYVpmcGw5V21YNlpmbGxsK21YNlpaWHBsK21YVmFiLzN0WC9BVW5laVJJZ210cXVB'
    b'QUFBSlhSRgpXSFJrWVhSbE9tTnlaV0YwWlFBeU1ESXpMVEEzTFRFeVZERXpPalF5T2pNNUt6'
    b'QXdPakF3OENMQzdnQUFBQ1YwUlZoMFpHRjBaVHB0CmIyUnBabmtBTWpBeU15MHdOeTB4TWxR'
    b'eE16bzBNam96T1Nzd01Eb3dNSUYvZWxJQUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAgaWQ9'
    b'ImltYWdlMTU1MjAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_ME')

US_ME = b64_US_ME
index.append("US_ME")
index.append("United States of America Maine")
catalog["US_ME"] = US_ME
catalog["United States of America Maine"] = US_ME
country["United States of America Maine"] = ('US_ME', '', 1)
lookup["US_ME"] = ('US_ME', '', 'United States of America Maine', 1)
lookup["Augusta United States of America Maine"] = ('US_ME', '', 'United States of America Maine', 1)
lookup["United States of America Maine"] = ('US_ME', '', 'United States of America Maine', 1)
details["US_ME"] = {"continent":"Americas","capital":"Augusta","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_ME"] = ('US_ME', 'United States of America Maine', 1)
regional["United States of America Maine"] = ('US_ME', 'United States of America Maine', 1)
#----------------------------------------------------------------------
b64_US_MI = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDU0NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01pY2hpZ2FuLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MDU1MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEwNTQ5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwNTUzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FZQUFBQmtXOG53QUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBdgppa2xFUVZS'
    b'NDJ1MjllWlJjVjNudS9kdjduSnE3dTZxN3F1ZFJMYlZhZ3pYTHNpekx0bXhqV3g2RDdjOUFD'
    b'Q0VCd2cyWEJZWUV1SVFFCkV0YmxzZ0xjWk9HYkx6Y01jWUF3aE1FRU96WUdUOEtENUVIV1BI'
    b'ZHJhblczZXU3cW1vZFQ1NXk5dno5S28yWFp5aGREMHFhZXRiUzYKMVZYbjFLbXpuL01PejM3'
    b'M3V3VUwvdEttZ2dyZVpNaktMYWlnUXF3S0tzU3FvRUtzQ2lxb0VLdUNDckVxcUJDcmdnb3F4'
    b'S3BnRnNDcwozSUkzZVBLMHdsUTJIbVVKZ1VZTHFXM2h4WlVtcmpBcU4raTNuVmkxeFVseFRX'
    b'cUhuRzhueFV1ZVdyMmxjYU43N3V0Qk4wdGRZVUswCmxhYkVRanNsNXFnQ25WVitFUU5hcmw5'
    b'SDd1VmRCR3VxY1lvbGNwa3NkampFNUlsaEV0TGtPQjdkNzZuU2h6MzF4SDJOT3VtUGFZQ1AK'
    b'akQ5aTZOS01pSHZyOVF2Vmw2bWhVSmV1RU91dDhnV1Z6YXFaRitVdHVRRlpKUTBtbGMxL0Uw'
    b'SWNLb3dMdjhxeklqOG9iaWhOeTRWUwpNbi9oUXVyYkZ5THI2ekNXOW1JLzlTSm9qV2Z0R3R4'
    b'WUk4TG5BMERIRThqNVhSUy8vQUFBeHFyRmdueEJXRUl3YkkxeGNPQWx0bHV1CjduSHpvczRJ'
    b'c2NPYUVPK3pwbzFVdWs3L0lMSkdUUVdhZElWWXN4Z0JOOGZieDM5aHJOY2xrUkdTZ0pERXBN'
    b'bU1jdmo3bWVlTk5WZGQKU1VOd09iSXhTdW5CSi9EZGRBMlVITlQ0RkdwNEhFd1RpaFk2a1VJ'
    b'ZEdVUkVJMkE3YUt1RVNHWFBmSTZ4b0J1ZHllSFA1Rmg0MnozMAo3RGpBMjExWFpBZUcyWFh3'
    b'QU5VekphYnRBdlgyalBqejZhZU5YL21hOUJQUjlXN0o4TDlsNzcxNHEwNUMxeFVueEFlbm56'
    b'RnVObjI4ClVFb0QwQ2c5ckk2MU1pZGJBc0Qzb1hlaE16a1FBbXdiZDk5aGFHMWs2SmtYR0M3'
    b'bG1IWVVTZW5WU1dHUUVnWVpOSmJXVkN0RlREalUKdVNWUmk2S2xPa0wzdWpYVURJL2o2V3dE'
    b'QVhKcEw5b3FJYU1SMU1seFV2djcrZW5tWjhncWx3N0R6NERXZkQrOHdqMVNQVjlyUk1WaQp6'
    b'WVpnZTNsaWgveExhMGl1OHRaeVhCV1lVaVhlNDI5a3lXZnZRdzJOVWZxWG53UGc3dGhQZW04'
    b'ZkI0cHBkamxhNy9hRTljNGpSU1lECkszUzJKcXh0NmIya3o2c3B6WWpJaXhNMGx1SmlYVitm'
    b'V0tWSzRvclJNZW9uVTNnK2NBOXl4U0pDRHoxTkRTWUJLVEVSdk0zajUrMzUKSThhRHVUNzl6'
    b'ZkFxTlJGbzB4VmkvUmVGUjVXNGV2SXA0K09xSUpaNFFnU0V3SEUxN1lhUHRIWlJBeWNSVlVH'
    b'czJtcGVtUnpoaVpkMgo2aWVEYy9SdzNWcFZOQUwvdno1VENVblNGOU5KWDR3VG9MY0NmbFdn'
    b'K2RpZ1hGMllGci96aGI4UjF6YTFNeFdmb3QvTnM5QU1FcFVtCjg0MEFSYTI0MXJHRm1uN2Ur'
    b'SGIwS25jMDJQbVdJZGVzZFlVU2hicUlEQmV4cHNYdFU1dmszL25yeElQV05OL3h0YWhWdVdQ'
    b'eXBsQXQKQnh6RmovMWQ2bEQxWW1XZEUrTVkySFNZQitXOGFJWVhwcGFwZ0JkeGJXOUJwS2RQ'
    b'ME5MYXlZdDl0ajZhUHQrcWVJU0YwaElYejBXdgowK3NXNmNrY2xvdXRrK0xGcWdWcWVmYUkv'
    b'S0NiRWRkNHd3eTRCZDdwNzFKSHcwdlVXODBkemtwaVNSUVJNU0ptZFB0Rm4vRDdSMzVpCktt'
    b'SHd4ZHAxYmp6UXJNTldYQmphSmVHdnZ5Q21hZlFNaW52blBHdXNXUlNodWI2YXA3Wk42Mkh6'
    b'Qm4zMzIzcGt6OElsakE0ZVlmMU4KOS9JbkgvdUUvdGJXZGxjanVMMzVGL0wyWlFVNUdjL1Jm'
    b'OUxpd0hTVFBxa3VVOVB1bkRlME9rMzVJWEZUNW9DOFMrWEY0eHI5alpaNwozTGRhU0dJUXUv'
    b'WXZaNTMvRmlWQ2NrYmtkTjBaeTJFSUIzWEtzMWVYRWlKbmpZbHZOV3gwczk1YUFDd3pTTUVN'
    b'd2F0SUZSSUo4ZEhsCm13emJ5cEhPbGVob0NYUHdXRUw4MDc0cjNVMHZITmJ4WGQrUTczamZK'
    b'MmhvNldSUmI0ZDQvdkVIR2JjYWRXOW9uMXkzS0NpaWtTQmUKNGJDMHZTUXVieHlVYmNZK01a'
    b'RU5rTlhSaTE1LzFoTm1UMVdQL3RmUWZEWGtDVk13cXpHRVRiUFJMeks2L3EwUjY4N0dpNjVo'
    b'WERqSwpkOWJkNkp5b2xTTm5HSlB6aFBXdm1tNS93M1JlNG5KejlGRlpMQlpJWlN5bUV3VnMy'
    b'OFVtb0FGbWRMcythWFdwNW82NUFNeGJ1SkkvCnZMVmRla1dCeHlkdWRiL3g4Mm1keTVlWVRo'
    b'VTRPamhELzhBMGN4dGM4WkhWTHhtZDV2NDM5RzJPTkprSXRHc2xKRFZpWE5SNmt4Y2MKRXhN'
    b'bkJFRFVHQkpWeE1YcC8xZUk5U2JCTDhxNmtVOWtXUmZaSkIzT1ptd0JJNFdoblBNQ2FvMDRj'
    b'NHhKaVZveElnUWFEOFV6NzF2cwpmVlplM2lORUptZFJYeGZFTkFTSFQ4eXd0RXVJWnZPb0FE'
    b'ZzI0V0g4NU1DWlkrNzl3L3RZWGJOVjJ2alpscjFCSFQrWm9LMnhob0RmClEwMlZqMFM2UUNa'
    b'WDRsMEx0aGxoeGwrWEJJWTRlODBsUXN3Sm5oQkNsRDFwblJnV2paNUJjWFhzUlhsMXpXUHkv'
    b'UXVlTXU1cCtxRlIKMERVVmkvWG1wcStXbUc5dWx1L3QvTEY1OS9wYW9UZzdUOWRzRG9tOERs'
    b'OXdUS2ZjSlFIbWVyWkxGNU1XNDVCUW91d3VJMkpNM0RyLwpoRXhtTEFTQ2RNNUNLYzNZWkpx'
    b'NmFqOGZYN3ZONkRHM3l1WGRobWp2WG5qbW5DMGQ4L2pndTliSlJ1T284TXNzTFEzVkRJMGtp'
    b'ZFVHCnlSZHRYRWRqR3BLZzMrQnREVTlKZ2I2QVRHMmVBd0pnb2U4VjZSZVpzbnZVVWIyZ3pl'
    b'QTlYUThiSDE3MHNQR2xqYThZLyt1bTdjWUgKYm9tSjMxOW5TVU5LdGlRMnVEbnFaa1htT0d0'
    b'aXJCSkJQTUlpbTgySnh1cWlPQnF2MG9ZdUNvc1ExMFNlTW80V0ZtcUxLandVVVpncwo4TytX'
    b'aG1taXRlS3E1b055TXVOSG9FUlNOMnVBalkxUEdHNHhMZ0krazVMallob0dOZFUrcEpUczZa'
    b'dGdhVzhENjdyVFl1VzZtOFZsCnE2NDU3MXE2ZXBhUTZ2K1p2R3ZoTVdtYW12SHBMSVdpZzk5'
    b'cllob1MwNVFJSWJpc0t5ajJESnM2bzJKbmp0Vkk1bFVkbFZFeExBcTYKU3Q4OWI3dXhMOTZw'
    b'WFR3RTNISHhCOWVaMHRRNVlUdUtVc2xsNEdTQzUvdE0vZURBaldyUzdkQUdEajNtVmhsWDdm'
    b'cS90aUg0TDQ0dwo0OEl2TXBpR3plOWZ0azhHdklndFIwUDYzWXYyR3BzT21Eb1lidEo1SjZ5'
    b'amNsaGszQVlkRWFOQ21nWlh0ZldKWjRjdlU1Kzk5aVhqCm1lM1RPR0tKR25NWGFJQmFNU0xX'
    b'OVZoaWZOcFB5WEhSV3VQekdsaVdnK05xWXJVQmZ2bmNFYm83NjdoNlhSTUFtZFFNMWVFNnN1'
    b'a0UKUnc1c3g2dFQ1UEpaQms0bUtaVmNiTWNsWE8ybnBzWlBLbDJrV0NvaWhlQ1d6cDN5Z2FP'
    b'OTUyVjlPOVByVkZRTWlrNXpyNnl2c3NYSApMdnVwT1ZrSTYva050c2psdldpbHlWczIvU2VW'
    b'Zm1sc3ZyWUk0aEVGNXNodGNuRnNRbXhQWEtZcUF1bC9FQ21hZElrZ0RlcVlmT2hBCnV3NTQw'
    b'ZEVxelk3akJkNTlsUktHTVNIKy9sZU5TbW1EWHZNNTZmWDQrTWgxazNJNm9Rbjc5aGpmMmpw'
    b'UEhjamZwVng5OXF0ZVdiOVQKS2xkVEUvSXprODRUOEhzd3BFQUlFQkpNMDZDNW9acHNLWWpw'
    b'OGRLMzV5VmVlZTduM1ByT0QvUE16Ny9IaVNQN3lDV0dTZVNUS0tXSgpWUHVvcVE1UUxObVlo'
    b'c0J4Rkg2ZlNWT3NDbzhuTHlMSFJrVlN0K2pUd2ZpMDd0TFNNTmpsM083dTNGNk9CWnZNNDhK'
    b'UWZiSzdXWXA4CnNjVHdlQnBwUnZuSXRTZmxrWEdodTJPdW5Fd1cyRFBSb0VkTGMvL0x1OE5a'
    b'SzVBS0ZJdDltK1c5UzRka0xPTG54RmlldWExVjlCMmYKd3VjemVlV0kxQVBPTWkxUmpLbGVk'
    b'VHJvRlVMenVSVS9NQVVPVnNsaEtwR25veW5NZERKUFcxTU42YXlGYmJzSUtaaUk1NmlxcWlW'
    b'UQpWVVZOUUpHM0EwU2JPc2hQN0dYd1pKeVM3UklNZUFqNFRRd3AwV2lVcTVuVFZzdUJZMU8w'
    b'MWxlanRPWlhBeTFxYytJbWRkcGFMZy92CmtBaURMSTE2VzJLMU9qZEwvZFBMZm1DMlJMM2s4'
    b'aVhXTG05RGE4aGtMVWFuMHZ4d1c1MTZLZjIyV1NHbXp0b3BIWi9JTVZ6cTFWL2EKdnNKWmJE'
    b'NWxYRGV2Skt5U3d3dkRIZXB3Y2FVMlJQbDV5ZWlZdGprN1hWT2xwNFVoWFVxMkl1RDMwaFNU'
    b'ektRTEJBTWVoc2ZTeEdxRAptS2FIYks2QTQ3aGtzd244WmhGSGVNbG5wdkhwYWRMWklyYmpZ'
    b'cGlTb045THZsZzZFN3lYWE0zQVNBWnBCdEdBMXlOcDhKek5EaE82ClZlOUllZFN0SGR2a05m'
    b'WDljazMybUVnNXRSUnNRVmQxbk43T0txWm44aml1NHVEUktRWW1ITDF0dEZudlRWNnZNOVRQ'
    b'bWltZldVbXMKV3lQZk4rbzhreUtWc1hEOUhUcGgrWW5XQmxnNHQ1NjdyVW41K0tIOWFsdGl0'
    b'YzRUdVdBZ2FveEp0QWJEa0dSeVJmeGVENlloc1Iwbwo2bXBkc0d5eGJ5S2lxL3cxOUtmYTli'
    b'cm00N0prdTh6cnFDYWR0YkFzaDVsVUVZL0hJSkV6bUJDOXlpcmtHQ2tVUkZOMUFZR200UHJK'
    b'ClpBdEVxeDNoOFhpbzlhYUZ4T1YwSnB2V0RmcEhnN2U1WWxBVEVqT2lTczRROFdSRkltM2ps'
    b'UlBDNTVFY0gwN3dvMzBMVkREZ1l6QlgKcjdORVo5VTg0cXdrMWl2WjY5VkhWajVuS01laVpC'
    b'ZkYvSzRnRFhVTkhEK1pZSG9teFlldXI1TDNwamZ4NDIxaDlYTHlLbld1eGFyegpUQXZERUF4'
    b'UEtGcWpYbHkzSEEvdFBCbldoL09MVlVCbXhhSDhjdVZxRXc4RnJqRk95SkdKREpsY0NjZFJW'
    b'QVc5RkFzT3pRMVZQRCsrClJCMU5YcW1rY0VGck9qTjlRbXVEV0NBbm9tSkE1UEl6UkdyOFJH'
    b'cThoSmdScjdZNEdrRlJWMnZsU3RIb25lREdCVE95ZDA0akNFa28KNEdHcEdKQk5zUkRqOFQ2'
    b'K3VQbGE5M1NjVmlIV3J3blRUb3YrNHJhN25EcUd4WWVXdjJDRXF3TDR2Q1p6MjJ1cENmbW9p'
    b'd1E0T2p6RAorNjh4NU4yWm44c24rNkxxOGJFTlNpT1pHNG1MOFprU05WVUJacEpaREsvSkV3'
    b'TkwxQkZyaFRvMW1YeG04R3dDYU1QUDNBNFBKOGRUCk9LN0d6UlRwN1k3aTlScTBuRGdranJw'
    b'WGNqb3hPRjVjb2dGT1dGckhSRlQwMUQ1aEpGSUZHdXRDMUhqaVpPejZNMjc4enBaZkdKZlAK'
    b'Y1lWcGFBd3BhV21zWnY5aGgwek9waWxXUldPc21wbFVudjdCTk44L3NIeFdrV3JXVHVrQTJO'
    b'cFBvMzlDQkVNZUN0YlovS08rTHNoRQpQRWR2VjR4WUpFaTR5dVN5eURGWko0WUZRSDJWells'
    b'NFVDZHk2SjNqTGZxbng2NXkrNncxNnJVcUZEd1VxYXVXckZqVVJGWFFSNkZvClkzb2tDK2JH'
    b'YUk1VnNhaWxLTmFHSGpFOG9zaXJMZEdVN3RiYkp6clU4SlNOYVVyYWd0Tm40cXpiR3g4elZu'
    b'ZVZoT3M2TEo3WHdOeU8KV2tKK0QrdFhkZERTVUkyVWdzWllFQ2tGVHgycVV5ZXN5MlpkT2My'
    b'c1h2NWx1ak9pSnVqRGxJSjhzY1RSd1JrY3BXaXVyOEl3Qk1lSApFK1R6TmhaQm5hSmNaNjZk'
    b'SWpONXlkYlJ1YnF2c0VLTnlHNHQyeWVFaUdTRWlDYUZiSjBVR09WRXJkbm9sNnNXTlJLTEJJ'
    b'blZCc25wCldwM0psb2hVK1dsdkR0UFJFcWJCR0JLcnZROGJRUklYcEdyYmNqZXFZNmxHblMr'
    b'VU1NNVI0SHRiWEtHVXByNHV4TzYrY1g2NStTZ1QKOFJ4S25YMlBGSUsyaG1xaTh2aXNIS05a'
    b'WGVnWENacTZZT1ZGaTk5azRHU0tZdEhtMFUySHNSMlhvdVd3TzdWWUlhc1pjMXEwbzh1VAox'
    b'b1dTSnVFMjZTSFJxNHJ0bHBBaUx0UllUTXVHR1NGcWNrS2RiTkRHc3NOU0oycDAzV1NXVEs3'
    b'RWRLSkFZelRFWVdlTm1zdkwwbkdWCkFHaUtWdEZuOWFwKzYvTFhGQ3dkdlBRWFZxbzFpU2NO'
    b'eEZsKy9PT2VLOTNGb1cxeVNjT2tPRFRtMTlVaUl5YWJzalJFZzNqbDJTRXAKMlM0bDE2TXJ4'
    b'UG9OSTJsNUdKM0swTnhRUlZkYkdPVnFsaTVvNU5DeGFmYjBqU09Vdzc3UzJ2TjBuNkZNSGNQ'
    b'T1VwMm5scHBzVmk5WgpkVUllV1gxWTl1WnFkV1BudU16RnA1V3ZaT0paT2lGZmZMUkJQYjkz'
    b'RDltMFJiUzJCZzlGTWV3czA2L3MzUzljcGJGS05pV25yUnczCkdSWWVsUmQ1SGRibkZpRE8w'
    b'S0YzRGdYME9OVm5DRExsZHVsbjAxM3VDeG1MR3NiRkJ4WTlaU3hkMklRcHp4NDNuY2h6YkNo'
    b'QlRsWFAKeXJHWjFhNHdiM3NJZUUxc1J4SHllNmtPK2ZDWUJrdDdHN25oeXJuY3NYaGNYaHQr'
    b'eEpEblZCRWN5aTlScHlkeWI3MXpoNUczMFRkRQpvTDQrS1ZKWnZ3N1g1a1RPY0RGOE5qMnJo'
    b'K1dOdHkya2ExNlVsNGZxZFVDazhZb2Mzcm9BL2pvZmgwL01rQ0dxbTQxK01kZTNUOTUvCjN3'
    b'TFpHSmdVa3JNR1RHdkJRR21wSHJXNkw3QThBWjBTMTRRZk14Yk5yYWRZY001N2JYZ3NqV1U3'
    b'cEZYRHJMUllzN0xRN3pTYVBjZEYKYzNCQ2FDVUlCano0dkNiaWxISHlldzM4UGcrZGRRVXhP'
    b'ajdEaEZOZUxKclh0V2VPUDNBeXpLVFhFdnVlVzZ3T0c1WTR2cWRMSHhpcwowOGNQdE5Ga2pZ'
    b'dTdHN0lpUDFQZzVGQ1NOY3ROMFdhT2lYdHVyeFpqSTBtNjU5ZlQyUjFsNVBCeFVkVFZXSzdK'
    b'czFzSCtOM3JJOUluCnNtSndKbmltVWpXclk5cm0vTnF3WnFOZjNOTHdxSEh0cWdhMDBqVEdx'
    b'Z0N3U2c3Rm9rT2haRE15a1dGUGNwRks2OGFLSy94Tm9qV1UKRUs2clFXdnloUkttWVZBVjhJ'
    b'QUFqOGNnR1BDUXpoVFowRFVrRC9kblZWRlhuVGxXQkN3bytuQjN6MWNpbGhEdW5oNGx2Q1dC'
    b'YlNMYgpwa1JxT0t5L3NqdWkxODVQc211Z2laclJBdmxpQXpzblVpS1ZxU1psVzR4TXdvQjd1'
    b'ZkpRUkdwSGZQSzlsNGxIWG96clo0L1dxM1BkCjRia2xQbEN1TGR0UTg1Z3hwNldXbVdTUjlx'
    b'YXo3aTZaTG1MWkxqVWhMMHByaWlvNE94T3IyVXlzRnhQclZVL2taOFowSWs5ZEpFQmQKV0JC'
    b'UEZZaEd5b0pvYlkyZmcwZW5xUEVyWXZLRU9PbWVUZHQxd1hkR3M5TFR0ZVdmbGtlVEFYYzZv'
    b'cmZSVlhaSmh4UWFDYWM4MWFHWgo4cy9kdXh6T25kZ0c5Q2UrVThUbWpVdUxiZTBqNGRacWp5'
    b'RkY3NXdvZmwrWmVMYmo0cXJ5Zk9QTCswY1pTM3QxbnJwS2pQV2JSbG8zCjZzT0oyQ21QbzBs'
    b'bkxVcWw4Mk9WcGIyTnREZlY4TzVGTzQySU1Tb3VqQVZzNWdZT2lpdnJYcEFCa2I3Z00vUkZi'
    b'dEdyU0hWS1VQVVQKRWduUjY5c3A1M3QzeVhNclJNK0ZqNnlJVlNteHBMZUIybW8vQVo4SFJ5'
    b'azhwb0hqS0x4ZUE2L0hJSmV6UkU3WFZyTEMvd3pzVEs1Uwp2dUpQak5xd254TWpLUzdyYVRq'
    b'L0N4b0N3NVNnU3Z4QnoxUEczL2U5MjVHNGRQbjc1ZXFtRTJKbFIwSDBkRVlJK2IzOGJQUFQ0'
    b'bXQ5CmQ1ZHJwN3hCYUZrbWljNFQxRFFKUEtkY2twMkg5TGhtK29obWRLL0N6cDhWVklYRnB5'
    b'NS8zRmkzdElGQzBXSHpuZ2ZGUCsrL1FrM3AKczRHN1gyUzRQZnBqWTJGN2tLbVpQS0ZXSHdM'
    b'SUY1d3o3czgwSlBtQ3pZQnp1WnF0NHpMcmlaWFFiWHJjWEtOR0ovcmtpa1ZOdUs1aQpPcGtu'
    b'RmlrVG9WaHk4Wm9HRFhWQkRFTnkvZGdqeG9aRmxwamZHZUh4dlFHOWI3SmF2OWczUmpUb01s'
    b'MnFnNFplUWRNU1NlTkNnWHlOCjIrT3RndGc4UVd5ZVlQNk5rb2xEbXJHOWlwa1R1azN1a2cx'
    b'MVZYejlWeDRkejRWNCs4S0UrTXJ0ZTR5ZnZYSkFQelY1bld2cEVFc0QKTDBtZktCQ3VycU9t'
    b'eW44bTJhZ0plUm1aU0pNcjJOVFhocEN5WExkZklkWi9FaHk4bk13MzYvWE5Sd0NJcDhwaTVw'
    b'bVUzbWNTOUpzYwpQRHBGVmRETG9vYWtXTDI0aDVmMnAvbDI5QmRDQmV1aFE0RnJnZWtIL2gx'
    b'TnI2UUp6VXNFelVzTXRHYkFMZkpoNVlNZUtTZ2s4ZTI2ClV2L2gyenppSTdjSHhOVkhIak0z'
    b'N2RGNlJYdFdGRXNCaHNiU05OZWZyMUdGcS93VWlnNERJMG1DZnBORzQ2ZzQ1bDVSaWJIK00x'
    b'RXMKdVpSS0xrWEx4dTgxVVZxZlVhL0hwN1BVMXdWeGxjWmpTalp2SCtiKzZVOHBGVHdWYUFz'
    b'SlpnRCtJeFpDaVBJNVRpdnNnUWhiR3Y1YQp2N0Jubkh6Um9TVWFJR2FPQ0svWDVJcWxiY3hw'
    b'aTFBbzJyeThaK1RNS1U1T1pzb05SYVJBU29qVUJDc1c2ejhUN2NaKzJkRmNRMTNZCno5eU9X'
    b'bEpaaTF5dVJNbDI4WGhNdkY0VHJZdTRTbEd5WFE2T2UzVnkrVjN5TkIrMEJpbEF2Y2xoY3I3'
    b'MVJ2bnN0bFdxWnU5T09aTXEKb0FDZlI1NmFIUGZ4M1BaQnV0dHJzUjBYajJsUUh3a3duU2lB'
    b'Z0V5dVJESlRtclZqTXFzRjByTEpkYm04NW5tak5lYWxJUnBpMTZGeApPbHZDWlBNMjZWeUpr'
    b'dTB3TlpPanM3V1c0ZkVVcnF1WmpPZkVlQ0xvT3EzcjVPZHVnbzl2Z1BuMWNHZ0NmdmdIOE1o'
    b'K3VIc3AxUGpoCkU5ZEJSeTJraXZDVk82SEtDemYyd2l1RDhNRjE1ZmZjc2hBc0J6NS9DMXpW'
    b'RFNNcG1NNEJ1My9rVHFlODJrenZFRFUrVzl5NGJpNEwKdW1PbnJKS2twYjRLcFJSSEIyY1lt'
    b'OHpRVUYvRmRDS1B4NVRzN3B2Z3hkSzdYUWRmeFdMOVowQmhVQ2g1ZGREdkZRZVB4WWtuOHh3'
    b'LwptYVMzSzByRHFWZ3JVaDFnVjk4WW9VQzVzRy9RWHFaeThiVDJPMG4rOXBrSUovNEtmdmU3'
    b'NERYZ3lpN0lsV0RQS0lUOXNMSU5IajhFCnlRTDB4T0RJRk15THdkdVh3SVo1OE0rdndOTWZo'
    b'cnYrQ1phM3d1QU10RWVnZjJCYWQyY2VGRmQxSHBickZ0U0p6dFl3cGlGUlNwUEsKV3ZnOGtt'
    b'REFpNVNDUFgwVFdKYUwxMnVTemxxRXEvMzRBalVVaWpXemRsemVFcTR3SEhKRkptY3h0NzJX'
    b'eFQzMVZBZTlwMFdvOHV2VgpQcTVhMFU3L1FKekIwU1NPS0UrdkZLZEdOVTBSQVZDMHdUbG5r'
    b'ZGJwYU10eUlHdUJjZW9QQjhiZ3YxOEZ6eDB0dTg3VDd0TThGVnJWClY4RkVCcGFsdnNOZnYy'
    b'ZEdta1paL2loWU5vV2lnK01xRXFrOGpxdVJRakN2czQ0TmE3clkwemZCUkR5TGNqVkhCdU1N'
    b'Wm1kM1M2TloKVDZ5b0dCU0xPd05jc2F6dHZMOFhpallIams0U0N2cHdIRVZMUXpYZGJSSG1k'
    b'MFc1WW1KSVByUC9oUGlSYzdzTytSQ0hKcURhQnhtcgo3QWF2bVF2ajZUSlpSbElRRHNEbEhl'
    b'WGZhNFB3UkI4OHVMdnNJcStaQzMveEdCeVB3NG1aOHZHL3V4SWUyVkV1Wjk1eFlJS2h1TkNa'
    b'ClpFSVlXS2VzcktZeFdzVU5hK2VVQlZPdnlacWxyUXlQcFVobExScGlJZlN4QXR0R1orKzR6'
    b'T3BXa1FZMmR6WDhpL0g3TnpXS1lPREMKN250NytzZlp2bmNNaGFZdTdNZXlYT3FqSVJaMlIz'
    b'R1U1bVA5bjFmNXVmZGNVbVo4T3NpL1ZGdzkrbWw5dmVkSDR2NWRHOTJVYnRJYgovUDlvMUhr'
    b'U1lzR2NLRDZQU1gxZGlLNjJNQjd6dGRXTjUxNFo1Ry8yM3V1Y083OVpzVmkva1FzdmNYWDF3'
    b'OGJiVmxhOUpxa0FlcnRpCkpOSkZoa2RUWlBNbFVobUxyZE5MMUw4ZENYQjM3MEdKNjlBUXlu'
    b'SnQxOUUzOWRxZVBURVBxUnpTQlVWS2x5dFhMVkdISVpNb0RjR2cKaDREZndEQXV6dWw1blhY'
    b'TU9iaGRIckkzcUFxeGZrUHdpd3pYVmYrcmNkdWFrSmpiWG52UjkyVUxKUUsrc3FiVjBsQk5L'
    b'bU14N3M3VApDYWROdzBFSnNMUnhsSi9jKzUwMzlmcXUrODVIb04vRmRzOWFvMzNGRFNwaVRN'
    b'bVM1UWpUa1BoOUhseFhJUzlpc1pycnE3aDE3akU1CjJyOUFueVpuUlNEOU5TTEVqTGd1OE0v'
    b'bWhpVWVNYi9yNHMzTmNzVVNZNU1aQ3BaRGRjaEhMbStUMXhHZHBFVkxYTHdlbzd5a1hyejUK'
    b'WXlhRVJxQ285dXN6NTgvcXFONVplSnNhbmlxU0s1UW9XalpTWEZ5UWxWSncvZHAyZnFmNVVh'
    b'T0t1S2dRNjljSW44aHhlK1BEOHVZMQpNVHBiSXJ6T3VKRE4yV1J5TnFtMFJWZHJoUEdaQWx1'
    b'czk3cEttL2pKQ1BPVXBmaDNFOHRvQnQ4R0NMNFh6SjZMQks1bE5OVDVDWjFECmlnbDNudDZj'
    b'dnRVOVBKeGxkRExEeUdRR1IxM2MwM2s5SnJkZTFjS2REVDgxYXNXSXFCRHIxNFFyQW84WmQx'
    b'NVZMN3dlazJqNDRsMk8KWjFJRkJrY1NUTTVrTVF6QjRFaUtmYmtybEVWWjF3cDc0a3pONU9C'
    b'MU9xd1BIRXVjdDJybURIUUpQRXZBdXhJY1A4Z3dsSnJCcy9BOAppOFdwWUw5YXhzODdmTnp0'
    b'MFQ4YmZhZjd3aEZESHo0UjU1WGRJd3lOcFM2ZTlVWUMvTjZ0Yy9qejladU5pQmdYRldLOXlX'
    b'ZzFENG9OCnZYbGhtcEw2YVBDaTAzcXByTVhBeVFSS1FUWlhJaG9KY2lJWjFrZWNkZXFzUkRF'
    b'a0dxTEJVOWJsdFMzVy92MGVEaCthNU9HSEJILysKaVQxbncxRVJBbjJxemtxdmdOQ253WGNi'
    b'K0g4UHVCcENmOHl5MWdDbVVBeFA1TW1yQzBYT0xGSDlpNW5mYzc5KzREWjMwK0ZhdmUvdwpC'
    b'SHY2eHBtSTUwaWt5bjBoWG0yNWxzNnY1OGI2bjB2SjdPaURPMnVDOTdubUR0blNXRTBxVTZT'
    b'cC92d1VYR3VORUlKVXhtSW1WU0NUCkx6RTFVKzRlODVQZHplcWdmYjA2dDJEdmlIMkZHcHY2'
    b'cnVSMUNsT3lxV2xlMkNMWXZmMDVRdFZocVBvalNyYUpvaGwvZWovNEJrQjQKb0RoWk5rM0ZP'
    b'TWpGWUhUak1TWXhwTVpSa0RyVjZPMDFId0xkck5PV1I0OVA1c1RRYUpyYXNKK081Z2dMdXFQ'
    b'VXZjb2kyNDVMTEdDSgpOdDlSTVdUMTZncXgzaFN6NmxMdm14VGRiU3M0TWhqSE9HZVpsT3Nx'
    b'OXZaUEFwcVpWQkhERkxoT1dkWCt3ZjdsNm9TNzhvSWd4dEFsClVTdzY0THRZakNXSnRsek9F'
    b'OS84SnZsY2h0Yk9IZ2FPbDBnblIrbnVqZUEzQXBBZkFsOFVwQWVzeWZKUEl3QjJHaUZnTUYz'
    b'TjlIajcKNjBvRlljWkZUL0NnYkcrdXdlY3pLVm8yOFdTT3pkdHovTTROdmVjUGxDR3hYWVYw'
    b'OGdLb0VPdE51VWhSb2laUXZ0U1paSUd1MXNpWgoxNUlaaStIeEZINnZlYWFQYURwWG9qRmFR'
    b'MXgxdk9ZQUZBanJROU5SVGV0cldDeFJCYUUvNE1aNzVsSFh0QkxsdWp6NFQxL200Kys2Cm5J'
    b'YVdUcjc1MHkyZ2FrSFpVQmdESXdpK2VuQnlZS2NnMElwUFdneXhYQmNLNXVzU2E2RnZzNXpU'
    b'V2tOdE9JQnlOZk83NmpBTWcwZTIKMnBwWE9Yc3BCVUthbkhCWHpBcGRhMVlRU3lPSjV6MFVT'
    b'amJCZ0FldjU2ejJVN0lkUmlZeTJJNUxkWldQYURoQVF6UkVkM3N0YTFPNwp4Vk5UYjd1QVhB'
    b'cURGMHUvNTJLMnlmTXNsdkNBMlFIdUVNSm9aZG1hNi9udS8vdFpKc2VHK056ZlBVd3VrMEk0'
    b'T1hCU0VHZ3FXeWxPCnRRRlVGdmdhUUZtNDJrUE9iQVVPdmU3M0Noc3pCSHcraElhbVdCVzVv'
    b'dVovUHJQTTlaUGtqNWd5em5lRmlxVFRQR3YwckZrUnZEdmEKeTQ3OEJuZDBQRTF0amY4OE56'
    b'ZzVrNlBrS0pycnEybHZxc0V3QkxidDRycWErbXJuRGJJb2dVT2F2SExMcEFxK0IwTC9EVHpM'
    b'UVNWNAo0ZW1ma1UwbnlLVGlCRU0xS09XQzRZZlFITEF6TVA0MHZQaE9PUFMvd1ZNTHZycnlZ'
    b'eUF1emFoSTA4VHJOWWpVQkJoTDJIenFpV3ZjCk1hdGQyNjdBY2M4L3g5YTlJenc3c1V4VmlQ'
    b'V21XaXpCdE5PcEI0WlRSR3JPQnJYVHlRSzdqeGIwRnVzUDNPTlRIbjFzS0VFcWJXSFoKTHJh'
    b'alNCUzhiL2lFVDhtbmFmcldWdTc0VlI4ZmV2WmYyREYrZ0pUdFl6VHZ4ZFlPOHhhdHdyRkwy'
    b'TFpGWm1xZ25CRTZXUWkwd1BCUAp5aWRKSHlySFdmRlh3SXBmOGsyZEtkWmdDSUhqdVB6ajlz'
    b'VnVWcGRYYUx2YTVNamd6Rm01UThQUlNaK2V1b1R0VkNxdThOOEppeEM3ClJxcjFqVmQ1QmNE'
    b'b1ZKYURSeVo1ZVhLcFR1cG0vVnp4dmU1YTlTTURwa1Y1VmJIbVlMenhEUWZDRVQxNHZiQnRm'
    b'SnpkbmdsK2VYd3IKeXZiZ2lEd2JDdzBzRWMySTZnQmZlZXAva3d5R0dEejB1OHlyYThaUmlr'
    b'akRYeU8xaGRZUW4xbUFrZ0ZzVjdGN1NnTERiL2lkY2pxcQpIWGRFektTTGpKUjZ6bHpyaEpx'
    b'bm45KzNWV2V5bzJMQjNIcThwbVRIZUdlbG85K3ZDeVVaMFFoRU9tTnhaR0NhL1FORkJ0Mnll'
    b'N0FKCnNOKytTVFg2LzhXd0haZDh3V2FxMUhvSlo2Mmh1aG9Nczl3MTJUUUt1RzRCcFRTdCtS'
    b'Q0RhZ1RYdFJrZjJjZkpsVTE4ZGRkSHVhUDcKQ3l4clhjVjA0THF6Y1p1R21UUUVmSEFzZVdu'
    b'Zko2K3FNQTFCUEdmcWMzZmFVTnJraWNsYlZaMy9wNGJXME5OVlIwSFBydnIzV1VXcwpoVTFG'
    b'b1pUSjRGaUswYWtjVzYzYlhWdWZMZDFONm1adEdCSy96MlJnVXI5bUQ5SUxwQWZUUnlBSXdZ'
    b'QTR2ZEVxVW9KaENQYW1qcEcxCk1tVHY2RWFHVzJpdlcwakFyS2Nxb0puT3dJa3BDSHFncmhw'
    b'cWdoRDB3ZUV4c0M4eEVpb1Exc2RIa2lSS0Y0cW9HZXIxNXZIbDZ0NW8KdjNSY1JjU2NZY2l0'
    b'RU90Tmg0OGNiZUdNZUhsM2t2NkJhYmFsMWw2d2hadkV4VERLRFVLZVAzNXBLNGhWc1lHRkxi'
    b'OXpLbHZVS0draAp0SmVBcHdadmI0Z09ieU9ka1JYRWdtMFViVWhrb1ZDQ3FtcFlPZWZVNy82'
    b'eVJwb3Z3WndHOEY1aWtPWGdKVkxsSStBNmd2RUxYKzhyCnJWVXZIUnNXVFEyV3VIWk9SdXp0'
    b'cXhEclRjZlN3QXZTY1Z5T0Q4K3dONzFFSFhHdnVzQXVoTVdFaUVXQ21JWmtyQkM5cFBNYTdo'
    b'SnUKbjd2a2ZCZGx3V1FhaHVPUXpNQ2lHS1R6c0xrUERneEQzd2o4OFkxd1JRK01KdUJmWHk2'
    b'WE1LK2RCK3NYbGkzZXBhQkdUQW5iVVJ5YQpxTkVYUzFvMloyNTF1L3ArWkM3dENZdTYvdUhY'
    b'M2FPeFFxeC9KK1lHK3NRN1ZrM0xaTWJsVUxwSDdYZHVVcTh0SHJnVXJmSVdKdTJoCkNYRTA5'
    b'VVlaUVlaakV6QTBmY28xV1JEUGdzOERmck5NTUZmQjVrT25sZzFLV05BS0hUSElXZkRNQWNn'
    b'Vm9iY0Z4cEtRTHNMK1lUZysKQ1ZqcE54QTZOSXRxRGdwcGVIZ2hkZU5GbldkUlY3RjFZcDVh'
    b'c1dCYUxxbzVLcmFrMml1Yk5MMVphREg2NWZ6b3REZ1p0M2s4L3YrNApHdU1pTVV1RXdVeUQ5'
    b'aGY2WkZkdFJoeE5OdWtpcjdQU3BaRFF4WEN2ZU81b1NBekh5MXBuUnd3V3RrSlRMVFJGb0NF'
    b'TXBnR3BIRXlsCllXQUN0aDByVzdUR01HeFlERjRQRkV2UVB3cWI5b0dWbU5UMFA2bFFGNi82'
    b'N3ZUc0Z5dGlBL0tuZ3plNE0rcjFPeUlMWFdKZTZJamMKTjFtdko1ek9pc1Y2TXdYU2t1TXlu'
    b'by9wMTl0L0dXQmFkK21INHU5MWxtUTJ5ZXRyZjI0OGxualB4ZXZHUzNsNDhmKzZPdHd1ampY'
    b'TQpGOGVpUGVMUm1rWWhoYUFwQWpVQmFJMUJhMTA1UUcrS3dGVzk1ZVZoUTlOd2NCZ2UzUUcy'
    b'b3lFOW9Za2YwVXdlMXFTRzllc1Z5SHVFCnhUWDFXNDNuSnE5UVkzYjNHeElsbytwSnBvb2sz'
    b'VmhGeDNvek1XbTM2RUp4SjBjemwvYTAydHJQVHVzMnBjUW1ibzc4MkhneWVhOTcKMFEwa3RZ'
    b'YmtrQ1k1cEluMENiUkdCV29aclo4dlJ4dm1pNzdSQUFFdnpHOHB2L1h3YUhtcEdHNEpaazVv'
    b'SnZzMHVTbU5WcEE4ZVVuWAp0enl3U1JxR1IvY1hsbDlTL21ob3UzeVpwU2dWWXIySlNOS2k0'
    b'eW1iUkNueTczcGlkeGR2VUdILzQvSmQ3VDgxbnhpOTBwMXc1cjIrCnhVdVBhN3JYUzJJOUFz'
    b'TUhoWXhHSnlsb3haNlpVenFUV3lyUERRb0RBclhRdGxJd2RSZ0dYbmhEa25oRm5yWFZ6OGlW'
    b'amNQeWljSGwKbDd6Wmt0OUlvOUhrUkoxR1Y0ajFwa0ZyZ2NkMzRVYmhsNExuVXplcnZQTXNi'
    b'MnZZWXVTczU5bmt2MFpsWWg1RVRWcmd0eEdlY3RHZQpMcGxROEtIVC9WcWZyRlpxSXFycGVi'
    b'dkVzYUI1aWVUd2syVVZhZjVOQnVQN0ZOSUxSLzlOeWNhNEVMVVpJYTdNR0FRc2hQZlUrV3dU'
    b'CmloNTB1a2JyUkxYMmpQdjFuVFUvTm1NaG02ZFA5S29qOXNwTG52ZXJsVk1pYXdkZXM5bGJo'
    b'VmovVWF1Vmw5cVFMcTh1b0JRb1FrWlMKK0VTNUFWcEoreWlvaUhiMEtjc1V0TmpaMGNYK1Jv'
    b'OVd6V21oalFGcEFEZ1NEQTJucWh1RUZxZC9MN1BYbGFpaHc4cmRQVWRwcHdnVApCOHR2RE5R'
    b'cU1mbWtNcFpOU25udlFmUDBaZ05sTm9uenorY0tNTXZseEZyQlk1Tzl1dnE0WURLNFF1dVVG'
    b'Ny9JaWxyUGpMaHNqa2ZvCndxaElwdExrUzZaT08xRWRkOXAwUVpkbGlQYkFTUkhQQnl0VE9y'
    b'OE9lRXhCVUdUT0ZMbDVoTVdpK2tsNTU0WTVjc08xZDdGaHd3WWUKZU9BQm1wdWJHUmc0d1pO'
    b'Yjl1a3QxZ1I1VDBpNzhWcGRIRjZoTVJTeWMwTEllVU5TQkN6YzNmTVZyb0ZjT0NEMWVKMVdF'
    b'MUZscmpwawpxT0VtaGI4b1pPZWdKSkFXNm1CR0tWVnVlU1N0ZjlYeXl1T0diRWdJTlJyVldI'
    b'NHQyOGFsczJPUkt4dW5wV2ljUWZWM2FReUZjZGt4CnFVNDBhalVlMDNveW9pVVdKZiswdUd6'
    b'UlNYbnIvQ1hpbGl2dnBMYTJsaDA3ZG5ESEhYZXdhOWN1dG03ZEtvNGZQeTcySDNpSjBVS24K'
    b'U3FsR1BhOXVTaHhJOXFnS3NYNE5LT1N6WW4zTFFjWk96c2NVUlhINzhweHh5ODAzc0dEQkFp'
    b'Ni8vSEpHUmtZNGZQZ3cxZFhWM0hiYgpyZHgzMzBmRndNQUF6enp6ckhqMDZaMzZ4ZjF4blha'
    b'cWRYSFBQT1VlN0ZMR2lzUFNXSDVZT2k5ZnB1ekgxanVlRGRzTjNUY0grK2sxCnJybDJuN1Iv'
    b'ZVpWclhyUERVS01OV25aTUNEVlZqdTlrKzdoUUo1bzFKUlBuK1pXdTU5WXRodjMwR2hlUEEr'
    b'MDI5cyt2ZG1YYnBKQmQKSTlKNFpKVWJzVEtpcmE0Z3JyKzJSYTViZXpYejVzM0RNQXlrbER6'
    b'MzNIT01qSXd3UGo3Tyt2WHJ1ZkhHRzZtcXFtTHYzcjNVUnNJMApOeFdsVFB3YkhvL2toZFIx'
    b'czRwWXMyYUpmVVNNaW5kMC9Kdmg4VmN6RTd5Qyt2cDZRcUVRM2QzZDFOWFZzWERoUWd6RFlH'
    b'SmlncXV2CnZwcGNMc2Qzdi90ZFlyRVk3ZTN0VkZkWE16SXl3a3RiZC9EQ2pnRzk3M2hCWitv'
    b'RjlxcGhZZi9xY2xkYlhveGxSNlM3WTRFeWxoMlYKYXJoQlkwdU01WWVsdTIyeEs3dEhKVnFn'
    b'QnBxVnNmcVE0ZTd1ZFRFY0llZU9DSGYzQXVXOWFvY1JlS1ZOaFZSS2hCYWt4VTNOdldMTgpx'
    b'dVdzV3JVS3BSU0hEaDNpMldlZlpmSGl4ZlQxOWJGaXhRcEdSa2E0NG9vcm1KaVlZSEI0akIx'
    b'N2orbmFvQzI2dXJvd1RaUHgwU0Y2CmVJN2R4L0o4ZS9BUEhhMHJGdXZOajdGMGk5NlRYcWw2'
    b'NUpoWXRLcFhYTEYySGFsVWlrS2hnQkNDSjU1NEFpa2x0aksxMXhjUVM1Y3MKcGxBb2tFNm42'
    b'ZS92SnhRSzhjd3p6N0IyN1ZwdXZPRmE0ZlY2UmJGWTVNakFVUTdXRHBueDRaTGVrNmpXWTVG'
    b'QldlZ0w2bEw3bU9CWQpvMWEyeG1zVmhMSWRCQnF2a3hKdXppRlVISk9lMWh5TFZWUXN1TTB5'
    b'T3pyZVJzOGRjNDNGaXhmVDNkM05ZNDg5Um1kbkovZmZmeitHCllkRFcxb2FVa3BVclY3Smt5'
    b'UktPSHovT2RNcldILzdzOS9WNHZsWlgreDArOGU2RnhvTDU4eGdhR3FLNnVwcGNMc2NMZTJQ'
    b'a2pTcDgKWkVXUnFvcU85ZXZBMXNRVjZwVWtMRXZ2TTNvWExCTGhjSmlPamc0S2hRSTlQVDFV'
    b'VlZYeDRvc3ZpenYrK0R1dThBUzRmVjJ6dkdsOQpnOUJPbnZyNmVwUlNGSXRGZnZXclgrSHhl'
    b'R2hzYkdSNGFJaVB2Zi85dExXMWlhMWJ0NHFHaGdabVptYW9yYTNGc2l4czI2WllMQnJaCmJC'
    b'YS8zMDlOVFEyQlFBQXBwVEJOay9iMmRyN3puZTlnR0FaNzl1dzVZMFVIQmdiWXZYczMxMTkv'
    b'UFVvcFlyRVl1M2J0NFg5KzVWdDYKNTFGTHA5d0diZW1RRm5SeFZVOUszdjlYNzVkZFhWMEVB'
    b'Z0hpOFRoSGpoekJ0bTFjMStXN3Z4eFJSVjFWQ2Q1L3ZkSUQ3STB2Y08vLwp4a1BHMzN6aG8y'
    b'TCsvUG5VMU5RZ1Q4MzhkblYxc1d6WlV1TURuL3lhK3ZZVFNmZGJUMnpIRkNWV2RFdHh5L29W'
    b'c3FXbFhWeDk5ZFhNCnpNd3dOVFhGODg4L2p6N2xZelp0MnNTY09YTjQ5TkZIdWUyMjIranY3'
    b'OGR4SE1MaE1LVlNpZGJXVm9RUWlGTkxzSVVRYk55NGtVY2YKZlpSYmI3MlZjRGlNeitkallH'
    b'Q0FhRFJLZkdhRzcvL2tTYjNuZUVHbjNUcWRVMUd0ZE10WmZVcmt4Q2ZmM1NvLzg2ZC9Kb0xC'
    b'cy9WVwp3V0NRcXFvcXRtL2Z6ZytmanF1eFV2ZXNhd3d5aTNleDE2eHFQbUY4ODIvL1JLeFlz'
    b'ZUpDclRPZDVuTmYrRC82R3o5UEt1czhGNktwCjhXVEVWVXRyeGFwRkRXTFpnaGF4WUg0M0xT'
    b'MHRURTlQTTIvZVBMNys5YS9UMjl2THlNZ0k2WFNhV0N4R2YzOC9HemR1Wk9mT25YUjAKZE9E'
    b'Mys1bWFtcUpVS3FHVVluQm9tSU5IeC9UK0kwazlsZldTMXpXNm9NSmE2UXRMSFNRdXF6cXo4'
    b'aXQvZHBmY3NPSGFDMTUzWFpmUApmT1l2K05ialUyN2NidE96YzN4bWNYOHNnTTdnZ1B6YlAv'
    b'OGRlYzg5OTV6Mzk2R2hJUTRkT29USDQrWFB2dnlnMmpsY3F5NG1NQnJDCnhVZEdoSU1sZXRx'
    b'Q29qa1dFalVoRDBHZnhPdVJoSUlCTEVlVHl4V1lUbVNaak9mMDRHaVNaQTVLQkxYbEJyQjBT'
    b'T3MzcUhZM2hVMTMKYlZ4KzVvK3ZsZlBuZGZHTmIzeURqMy84NDV6N1lCU0xSZjdzTHo3UEE3'
    b'L011YmxUTmZDekViTytvOTlnZm83NjRPZWYxTHYzN2pmKwo0ak9mUG1OSmxpOWZ6dDEzMzQy'
    b'VWttY2Z1bDgrOEUvZmxYLzMvVzFxTU5Pb3pvaW5weTJFTnNnVDBma2NqUFdqNlljem0rZVVo'
    b'L3RjClJRMkluUHAzYWZDTGpPaXFHUmNmdUhlMS9LTVAvQTltWm1aWXZYbzFxMWV2SnAvUE16'
    b'NCtUbE5URTZPam8zejhmM3hSUDd5enlyVjEKM2F3ZWwxbmZOUm1ncUtyWWVqQ25kMng1V0Z5'
    b'K1lvRTRjdVFJVHozMUZFOC8vVFFMRml5Z3FhbUpiMzNySC9uQ1p6NGdybDNpbFptcApvMHds'
    b'Y3RqOCt1cklUV0VUTlVma2paY1Y1V2MrdUZaKzVrL2ZKeDUvL0plODlOSkx2T01kN3lBV2kv'
    b'SFFRdzhSajhkcGIyL24rUEVCCjd2M3YvNkMySEs5WGIxVEJVWEdGdi9uUW5yYkFzUHpzaDli'
    b'Sms4TkQxTmZYYzk5OTk3RjkrM1p1dWVVV0RoNDhTREtaWk11V0xmVDAKOVBEVXB1ZDVlRk8v'
    b'T2pFVDBoazNwditqVzR3RVJGclVldUxpNmhWUmNkTTFTOFdWVjY1bGNuS1NhNis5bHE5ODVT'
    b'dnMyYk9INzMzdgplN2l1aTJtYWZQakRIK2ErKys3amEvLzByL3FianlWZUZRdk9icGk4cFNB'
    b'NFdlaFFmM0wvSVgzTi9JVDg5TWV1RjBvcFB2bkpUL0toCkQzMkkrdnA2Tm0zYXhKZSs5Q1VB'
    b'SG5ua0VUNzNGM1BsSzYrOHdzNWRlOW0yZDBodjNUZXBwekxva2c1aXFZQzJ0ZjlWSnQ3R0k0'
    b'ckMKSTR0NHBVVjlsU3RXTDZvWHl4YTJpc3NXWDBsVFV4UDVmSjUxNjlieHpXOStrNjkrOWFz'
    b'Y09uU0lLNjY0Z3M5OTduTjBkWFd4YU5FaQo3cnJyTGk2L1lqMDMvK0gvZFlmVFVRMVZiN0dS'
    b'ZUV0WnJGZXA5ZWFFdUdPTlYvN2VPMjRUYytiTW9idTdtNXR2dnBuUjBWR2tsR3plCnZKbHdP'
    b'TXpHalJ0UlN2SE9kNzZURDM3d2d6ejQ0SVBVMTlkakdBYlpiSlppc1VoNWJscmo4WGdJaFVL'
    b'MHRiWGg4L2w0NktHSGFHOXYKNTU1Nzd1Rjk3M3NmeDQ0ZFk5ZXVYV3pac29WRml4YlIzTnpN'
    b'azA4K3ljcVZLOW0yYlJ2RllwSCt3OGY0NmorL3JQcW02OVZyWlkwVgppL1ZmSEVtblVYL3ZS'
    b'ZTMrNHBXZmlPdVdTUG43NzdwRHZPOTk3OE4xWGY3cXIvNktxcW9xRGh3NHdLWk5tOGhtczV3'
    b'OGVSSWhCSi8vCi9PZjU5S2MvemNHREI5bTRjU1ByMTYrbnQ3ZVhiMy83Mnp6NTVKTnMyN2FO'
    b'elpzMzg3V3ZmWTBmL09BSDNIdnZ2UURjZWVlZHZPYzkKNytHem4vMHNDeGN1eE9QeDhQNzN2'
    b'NS9SMFZHOFhpOVBQL09pL3RiRGZmcDRJcW9ValcvbFcvL1dKdFpwb3h4MzJ2UlBkK0grWXZj'
    b'bQpNVGVhRU8rNmRiSDg0UTkvaUdtYXpKMDdsMlhMbHZIRkwzNlJqMzNzWXdEazgzbm16Sm5E'
    b'dm4zN1dMTm1EYUZRaU5iV1ZqNzYwWS9pCjlYcUpSc3VWbk92WHIyZjM3dDE4OFl0ZjVGT2Yr'
    b'aFR6NTgrbm9hR0JtMisrR1kvSHc3Rmp4K2hkc0pELzg4RFA5U3ZIREpWMllob2EKK0cyQXlX'
    b'OFI4anFpOTAxSDlNSHZwVlhOdjN4YmRFVy9MbTdmMENzLy8vblAwOTdlVGl3V0ErQVRuL2dF'
    b'Ly9BUC8wQkhSd2VoVUloOApQcy9TcFV0SkpwTnMzTGlSTDMzcFM5aDJPWUlvRkFvODhNQURh'
    b'SzBKQkFKOCtjdGY1dnMvK2pmOWdULzllMzBpN3RVWk42WmQzY2h2Ckc5N1NNZGFsd2lmeUlt'
    b'Q2tpUVV0c1hKeHMxaXlvSjFZSkNqcUlpRWlrVEJDQ0RLWkRBRFpiQmF0TmRtOHhjUjBTay9G'
    b'OHd5Y1RPaEQKSjFJa2kzNWRVR0Y5N3VyczMxWlVpUFdHZWxRSkExdG9ZV2hYR1NEQTFaN0tq'
    b'YW00d3Y4WUhPM0Z3WHQyRVlPdTNKTkxnYXpjZ2dvcQp4S3FnUXF3S0tzU3FvSUlLc1Nxb0VL'
    b'dUNDckVxcUtCQ3JBcG1BZjQvRWx0SUd3aUFUSGtBQUFBbGRFVllkR1JoZEdVNlkzSmxZWFJs'
    b'CkFESXdNak10TURRdE1qVlVNVEk2TURNNk1qWXJNREE2TURCRmVGYjRBQUFBSlhSRldIUmtZ'
    b'WFJsT20xdlpHbG1lUUF5TURJekxUQTAKTFRJMVZERXlPakF6T2pJMkt6QXdPakF3TkNYdVJB'
    b'QUFBQUJKUlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTEwNTU1IiAvPgogIDwvZz4K'
    b'PC9zdmc+Cg==', 'US_MI')

US_MI = b64_US_MI
index.append("US_MI")
index.append("United States of America Michigan")
catalog["US_MI"] = US_MI
catalog["United States of America Michigan"] = US_MI
country["United States of America Michigan"] = ('US_MI', '', 1)
lookup["US_MI"] = ('US_MI', '', 'United States of America Michigan', 1)
lookup["Lansing United States of America Michigan"] = ('US_MI', '', 'United States of America Michigan', 1)
lookup["United States of America Michigan"] = ('US_MI', '', 'United States of America Michigan', 1)
details["US_MI"] = {"continent":"Americas","capital":"Lansing","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_MI"] = ('US_MI', 'United States of America Michigan', 1)
regional["United States of America Michigan"] = ('US_MI', 'United States of America Michigan', 1)
#----------------------------------------------------------------------
b64_US_MN = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDYwNyIKICAgd2lkdGg9'
    b'IjE1OCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTggMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01pbm5lc290YS5zdmcucG5nIgogICB4bWxuczppbmtz'
    b'Y2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAg'
    b'eG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3Nv'
    b'ZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94'
    b'bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpz'
    b'dmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZz'
    b'MTA2MTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxMDYw'
    b'OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'CiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIi'
    b'CiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hl'
    b'Y2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIK'
    b'ICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMDYxMyI+CiAgICA8aW1h'
    b'Z2UKICAgICAgIHdpZHRoPSIxNTgiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNl'
    b'cnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9w'
    b'dGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2'
    b'NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSjRBQUFCa0NBSUFBQUQ0N2g1VEFBQUFCR2RC'
    b'VFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFB'
    b'T3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQWYKWjBsRVFW'
    b'UjQydTJkWjNoVTE3WDMxOTdubk9sRlV6UXpra2E5akxwQWdFQ2lWMk13SmpZMkY1ZTR4RTZ1'
    b'bmJnR2w4U3hnNGtUeDQ3dApHOXg3aVdPRE1TNllZc0FnZW04Q2RkU2xrV1lramFiM09XWGZE'
    b'NUF1Z1gzZit6NFpmT2YvNk5Qb25QUHNzMzludDdYWDJnc3R2SHNqCkpQUjlGRTVVUVFKdFFn'
    b'bTBDU1hRSnBSQW0xQUNiVUlKdEFtMENTWFFKcFJBbTFBQ2JVSUp0QWtsMENiUUpwUkFtMUFD'
    b'YlVML0Z0SGYKeTdlaUVNblcrYzNxWUpvNmtLSUtxU1dzaE9Fa0ZBOEFFWjZLc0xRM0xMTDdw'
    b'UU5laGRVajYzR3BlSUlTYU9OYUprV29KbnVvUE1WVgpZbkpMR2U1YjNoVm02Y1pCVGIxTmU3'
    b'alhOT1NYZm05cUEzMFBIR2pFTkQ4cjF6WW56MVpzOUNCRUx2d3EwaUdaR1NSR0pEWUFvd1Fz'
    b'CkJrb0tBTUNIZ0k4QjV5ZlJZWWdNa1pBVllxN3pkeENDbW9jMHRlMnArN3BTb2h5VlFQdnZs'
    b'RnpFWFZYVWUzVnByMW9TQXdEQURGS1gKSTNVcFVoYUFTUHR0bnhKekVuOGI4VFlTYndNSUxB'
    b'QjR3cUpOVFpsYld6S0RNVHFCOXQ4d21pNHU3cnVwc2wwdTRnQUF5VEpROGd5awpxYnpRTk1j'
    b'U0lZSzlGNmRtamY1ZlBremNwNGhqSHduMUEwQWd5bng4T205clM0WndlWTdFbHlWYWk4RnpU'
    b'MDFUdHM0UEFFaVJoMUlXCklsWEp0N2xSNkRncFdMZFJsUThndVJSb2VreiszaVl5dUkwRXVn'
    b'Q2d5Nmw2NVZCSm0wTjkrWDM5ZVpOV1hFNWZJaUpMUzNvZm1WMnYKbFVlQlVlT01GVGg5T1JJ'
    b'YnZzMjk3SjZQU2V0am1OL045YmlvM05sam8wVklZa0Q2cVVpZVFRSmRHckZuWHNFQUJtZ2Mw'
    b'aWJRL3YrUwpTc3crUHE5dWNYRWZSb0FNczZtOHU1QTg2enU4YW5hNTBINEFzQUVYM0l4VENp'
    b'NzlHVW1NV0Q4VitBZ0s5WmFsdUN6Sm5wUDl5VEdlClNxRDlYNVpPRnYzZG9oT0ZCZzlRVXB4'
    b'OUd6Yk9BL1RkNWpoQ1p6TTJWbE5UN2hXNmU3QTU1OXRaZEdpa0xrVXlNL0czcENxOFZlbU8K'
    b'NDMyR0VIdDV6SzB1RDJ0VWhpYnd3dElqbVJvL1NFeFU4YStRcHZLN1BrSG9hT1lPL0l4NG5D'
    b'UVVFcnJmWmJlOStSMUdnYVFLcXZBWApJREZrYUFKL3VPcFllbElnMFdyL2Q1UXNqenk5Nkhp'
    b'eVBJTGttVlRCQThBa2ZlZEhSS05BVVNTcXg4bHBTS1lFemtobEZpR044YnVZCmRtUllXd1hC'
    b'RGhrNHFyT0dqdlNhZ2pFbU1VUCtmMUtTTlBiczRtTnA2aUJTNU9EOCt3Q0x2K1dOWkxoYmNM'
    b'UkNvRWNZT2dpRWgwZ0gKSURFQ0VTRXNFaWNUc1Jra1dweFVCS3AwS25mcXQyNzdVYUh0SlJM'
    b'c3Nub1VqMjZ0OGtWRWlWYjdQeFNOeWVxRkozTjBmaVJOeFFYMwpYMkxOK3RmVmFlY2g0Y3hM'
    b'UXVkMjVIeWVjeWNqL3F5UGxMc2lpaUUyZDRSa2NGaUxsSVdNN3hTRUF1QjVuL1MzazdiM2lU'
    b'OE1VUWFwCkRJQXZ1b1JGTkVvYVI3d05hdHBWYVBEdTZVZ2xnQkpvL3llNmRXTGJqSnhCWUZT'
    b'VVpTWFF5a3MzcXA1VC9NSDdCSHNuWmpjNDROcGQKOWRwNzkxc2FQY1lYVzY3MFEyeHpmM25k'
    b'aU9iRWlQNnRNOW5iMmpXdm5jMzMrb3hFUFQ2VnFvTUFqNXlQQzA0MUNYcXhMZ3ZRMk1DdwpD'
    b'Q2VWRTlkeGc4eExZVGhyMHlYUWZtZE5USGZjWGQyQ01NYTVkeU5wMmlXdTVqaDIrMC9KOERr'
    b'STdtc0tUWHRpYzhVYjU4WWZpMDRuCjBneEw4Z2pCekx6VWZRSlFGQmFrVEdTeXNhSEk1RGda'
    b'WE5US2x0WGFNdDV1TEcxMXdNVDBaQ2w0MGNocXdaTU5DQ05WOHRoMUprVXkKTTNFZEx6YTZX'
    b'b2MxZzM1WkF1MTNrSVRtbnJ6aXRFTE00dFRGU0ZkOWlSNjRiYWR3ZGgzeWJ2ZXltdXMvbTcx'
    b'eGNMcGJWcGJDRDY0cwpIaWczK283WTlVYjVDQ0JrRGFhcG1BQXZVRHFKSzhxTDYxMmxNdFkx'
    b'WGQxdTRvTW5TZlhhVmt0Ymw2MjZwSW9aWENmMHJxVXNQd1pxCnpPVURFaWNEOEJEb0tEWjV0'
    b'cmVteCtlZVlKeWl2WGxDKzZSMEI1S200T3dmQVJwN2hVWUkzN0pIYVA4WWhUOTdzKzdXWHgy'
    b'dHJoN3UKbUc0WVRBdlZ1amp4cHNDa2VlbWh6MnZmYS9VZFB0eCt0cW5KTnlLL3ViSEh2YnY1'
    b'cXlQZEVSQjBkNnBickVIeFNWd0JDR05LTkVBcwo3eDlqTEVaUmhxRkVPUHNnOEZwc0toMlRy'
    b'aUtYdU9zVTJDMFFhTERyRW1pL2xWSlVvWWRuTldBRU9QY25TS3kvV0h0dFB3THQxM1AwCjVJ'
    b'Yy90K3lNWFYzZDlQbFZsYXBscnowbFBmYXJoYWtIdExhK2x6bzIwRVcrYU1DTFluTlNDdThG'
    b'QUpITUZIUTE2WW83dlBZZEtyV3UKaUR1K1ZQL0JDczBuZWJyY2RMblROU3hzZGs0YXNuZFB6'
    b'M0tUTUFWZUswNGROd1piaktTcHhIbXMwT0RaMjVrYWgydWhlRFJaWEZmZQpSV0VCYVNjaVJk'
    b'N0Z1QjU3blRRK0hTRzMvT3pEU0ozc0pvU3BpcUZXMU5VUEFLcDVyN2kxVDIwS1dTRVRDUnlS'
    b'aHMzWHo1NTFiWVgxCnhxckJ4VVVkY3ljc2p2VkpjdWVuZm5wa1U3bTVSS0plR0ZQZHV2anVH'
    b'eGNVNkg2OS8xVVJvRytDaTI3WWVRMEtIeGJhWGlFZXo1Z04KVjFtQU5PTVpTbGhXM2gyUDY0'
    b'dDRLNUJlRnBtYmJ3TkF5TFR3WWx5N2pnbEQ3U1Eyc3Z6UGpOOTA2L2tmNjNYNUZTM3RoMy8v'
    b'SWlvcwplSGpUODhPVVcrV1c2ZGkwRDkvYWFEU3FZakhlNncwampKVUtrY094NUpuM0g4TS9R'
    b'ZzkrVnZ2U0EzK1FpaW14V09Lc1BXQUVSQWdQCmdJWmc0bE5IQTAvTUdlWjNWMVBUZGlCRHh1'
    b'aDBVNjRrN3JyNStmM3J6K1E0ZzVKRWgzd3hMUi9mV1dweW82UnhXRGZ6bjFhWnhPVkEKVXZr'
    b'RnRMVXJnQjlZdEdGZVFETy8rOWhqanA1WFkreVdIdjJFYjVUbWo3NTVlZTJKTDMxc0tDWGRz'
    b'TER3aHFjZmVkRm9WQUlBUWtnbQpFOG5sSXByR05NMU1IVGQvdUQ3UXAydForLzZHREVPYTQ3'
    b'VjFiTzJKNThxdkcrQ0gvYzZ2RU5GWW9TSlgycHNwUjRSTHd1YVNNUmE2ClNnaGJjV3lRNDNH'
    b'OExZVGl5eHFGRUx5L1lxOWVGc0VGRC9LTkozRnFGVEpsQ0IybnFaSXBRdWRadnVFZFpKeEts'
    b'UzNtamowRG9kQ2YKajRaZWFaOFk5UCtCNTBQeVpLa2tTWVI4VkhDSHJYekcrQm56VjF4NTVW'
    b'S3hSS3BXU1VLK01PMzN5ZHd1UjhlZ2Q5aVhDaUhhNVdabQpUQ0xUcWpoT09GdmZzdVBReG4z'
    b'N2RyYjF0cWNXL3pIZzNpRlF1eFVtNlVpclQyTjZTS2JJMzdsOG00VC9BcFh0eE5ubDdNRlBt'
    b'V25MCkFVQVlzbUZqS2dDd3RSL1FrNllJN1M4Nmc1TGIxOCtNcTAzNytFSTd3ZXhZZmNVcEVH'
    b'a0JYY25YUDRSb0U5RmNqLzF2RXp5Ym1ud3IKVjdzY0dlYlIweC9udGxSN29obUx2NzZWRXoz'
    b'SlJjT1dSZWJlQTBORjEyWmV1MTQvMTlkQU9DUU1pSEU2RWdibG9PVElVQXdFUWxoRQpGNGE1'
    b'VmlsVEVRUUVpQ0hJY3Jmd3dJK3RMUU9TUWJ1Q1FhSE9OdHZ1ZzRkbGtaWU02Slcxakp6enhu'
    b'd2lYY3I3YzVXN0hwdnB4T3AwCklhSUc1N01ndngxbjFnaHQ3NkRrdWNMSUVDWnZFTVc5MkRR'
    b'RW5PZFgyeWJGVmNPTnI3RjJXdllRQUNCdEZVNnBFZnB2QVltU3FieUsKM2JJWkcvVVFJL1RV'
    b'ZDBnNHltMjdoVkFsSzc2MGVBUHZHc1pSam1hMlovOHdPSE44YjBobWhxS0NTSVFZbGlBQ1hC'
    b'U3BZMWpERWpFbAoyTVhZSE1VYUZrbkVKRUNCU0lQRUxzQ1VjTU50YWFFMnBHSkpBRXRrZ2w3'
    b'UEZpbW50YTV0ZWliZjZ5OWd0TGxpVi8zcDdlSHhqM0FmCk1JTmZvcHcvQVhVVFNIS3hNWnV2'
    b'YTBDNk1pcC9DdkhKa055QzlKbGs4SnZwMmZZRTJqRlZudUlFQUpSVUJoZ3pDMzhLQUNRVUZL'
    b'MVkKeXpjZjVrNCtnMU5yY09Zc2lDQnJJQnpSektTRkhhR1JpS2xjNS95cVlvbXJyZWorWlVt'
    b'UHJpU1JxR0FiRnF4MjlzaEpvYjFQR09sSApGRU5QejZQS0xNUVhZSXpEU0NibHU2eDQ4amlo'
    b'cTF0VWNUeDJYSW1OTVFFeElDQVNvRVRKV2kxSG5tblFQSlFUdHA3elJrTmJsWVluClhxMnJ1'
    b'VytjbXFKczFPd251SU5yU1RUR1hMV0ZlSDA0dXhCZ09nQ1FRQWNaL0tZODFaV1lJWTh1a3pK'
    b'c1ZJYUJraUJaNXQ4R0RKa2MKQUhCS0xuLzZCRVRTaGJySGtmamtJMS9jcUZMNnZBUmpHbUY3'
    b'NUZuSDJVbTBkQ3ZZUDF0ekhTMVBLNTl6Yjg3TUttWm1sZC9wMnY3aApSOWMvY0MvSGNRekRR'
    b'SXdOdjc1VzZMRWlzWWpiY3hTbjZjSHlwSGhjVXFSdjBGbk1hclB6RldrcGRHVkphRzExQm1Z'
    b'bTcvSFpwbElTCjdRQUFIR3pERDVUdUovMVJqa3NtMWo5eVhRWE00alU0dS9CdmhaUm5BUmFu'
    b'cWtKR1pUaCtQSm5qQ0cyeDBRVUFTSkVINkYrY1ZDZ0oKTS85VDRuVHh2Y0VBV2R4UGoxczF3'
    b'ZlBrdW1HZTRmL3pzTFNLbHIyaWNONUdmWklxUTlZd3QrOVB4N1EvMzc1djR5YTYweHJ0N2Qv'
    b'dworMm01eXU0QlZMUG9yaytrOTkwaTJJYVJWSUswYWdCb09IdXllZE5QZUk3TjFkajNINWRW'
    b'WHYxQk9aU2MzeHZRZUVYaFBrL2FUSlc1CmZXK1JXZTdYUHF3TWJLSzBHazY5QWttMVNKZjhU'
    b'eE5scE1nbHZ1WmlvenVCZGhTbEp3VUJBS1RtVVNaN1NScEkwZ2pERzdEdzN0R3UKSlFxNWJ1'
    b'clMwZ1ZmZkp3ZFRKTFBONngyVWpKMDNPUmxoU2d4aTZuUUlkdWJmNTRoMUtUcjlTWlZmZ0hY'
    b'c3l1NWhoMm5PM0Q0cFZ5WApmR0hWa3NjNWY1QjFEZHA2em80Y1cwV0xYTytjb1h3U2xReng5'
    b'S1lmc2R4YmZwMHFZOGp2cHBOZVdIaFBXN2l6YkU1cUdDbmJPdzVWCkpqVUxRcFJadEhMMDBz'
    b'dk00R3MybjMrRkJOcC9RUnNBQUNRWjIvbEJwQkdpVjY5dFRsV2VlUy9vZXZLcXFTVWhrR3JH'
    b'VFFtOGQyNjIKWVdPRGh6V0VwRVl6Y2tRRW5ZS2d2VzJHbVNrbEZpTmo5Q3FrQ0FCcThpTUFH'
    b'MzBIdmx6NU9TK1c0bm9iVVJWcXhScWpSeCtUSkltaQpFZUdQUGVHc1YrK1FaNmpIMmFRRTBO'
    b'czdCMzd4K0kreXBOekdYYWVPK3pJcUorV0RyeE5neXVnckRZbUpBSmpWZ1FUYVVaU3FEZ0VB'
    b'CmpJMldkUDhKMHp1SmRkNnlHbVBuNzM5ZlBIVjdxOTh5ZnRudnNwNzlhSzBjYVJYS0NGQTlE'
    b'a0dPQlU3cHU0M1JkZlgzaGh2bEgwcFMKZVo2WEd5aFFpVkV3TnVGVHRrQksxVCtVYlA1eVNM'
    b'c3J4TkxCWXBHSTUyTDlER3VOaEU4b2VXTlJyQ3Z2VGhrdFVzWnNiVjkrWXBvMwpULzdOTitM'
    b'TUZNSTVVTlE3WnVuRlJnQXduMytGQk5wL2tsTE1YckR2aktXa2FzRmh6Sy9mVW5iL0h5T2Jh'
    b'enVrZDB5Kzh4Zk5wK29rCmRpdC9WenFiSWFjQWNnSGdXbkE5MDY3bUdaS1hHK2xzdjhyR1l4'
    b'ZTdJWTF5Sy9OTkVibkY0Skc2ZW9Jbnl3SUZVM2t6NEJnYUNSTU8KRCtGQWwwUTBzcUFwYURp'
    b'RER3dDlxMjh2cG9QdWRHclAyVldIRjlrQ0ozeERjQVVEWEhSTSt3Q2pCQUNGaUUyZ0hVVVNt'
    b'anMvWXhyegppdUZORUxQbkVEenloemREU0ZCVVhYdmd6K3NkYTlaOVpaaHVsaHovNjFYMnQ3'
    b'ckZHSCtsRDVTNGhnNUNCNjBVTkZvbTllZkpaUU8yClgvdzI3QVdoZWQ3NG01YmNPaGhoYUZw'
    b'QVNNUnhKQmprZEhyNW5yZldsTEpIZ1FHbnN6TzMrb2VHcWp1QjQxcE8vNnlydis2WVdqMVgK'
    b'UkYvTU00dVNBSUJVeENYUWptSmlsTkQ4SmRBYXJnVlh4Mjc2NnhlNkhUZ3ZmT1RYTHh3ajhu'
    b'MjUxL0E4eHgwSXhwTFlXSmozZVlJbApUYmg3Z1N3OFU5dlpHQmFYWkxBZjI3dU1GTE9teTFo'
    b'bEZDRXNJK1MvV3JkSEh3MmtKTTJSSytTUlNGQ1RwUEI0WEI1cncxM0NNYUFvCkF0QXRTei82'
    b'NEdyRDdDbUJ4bk90SitvRmdtdENic0w1RU9zZXMyeFlBZ0JTbWtPSWtQZ3dOOFpQcS8xTDhD'
    b'UVoyNVhNVll0Q0o5c0wKRnRqYVQyVVoyZG5Ud3pVN0pMZkZQdmtrSXJydWp0ZHl4NDluQTRG'
    b'dGI3MVZlc2VVUURnY2RUaFM1dVpnbWc3ZjVhVW9LdUR6QlU4MgpBV3oxQ0p5OFJHNmFZKzNl'
    b'L0twMHVNYW9udUwyc0xHQTMrSTcza216YVNMQkhvMkZkWVZmV0h0bnZ2WkJmZ2ErVWFvV2pR'
    b'L3NkNlVnClNnb1gzVHlPTjhVTFdrSlFoS09rREE5Q0ZQRG8yOW9vNDNiU0RXWTl2QlFzZmJh'
    b'dGtjcU9JQTJuTjdBUEZIcTN2UDVCNWhvTEVMTHcKampzaURwZjEwLzFSRTUrVmxFVFJ0TnBr'
    b'NG5sZTZ2ZDdUdGQvclF3WVo4eDZVS1A4MEhhdzdDZUc0SEJEKzlkN29iYzBWYld3UGVQdQpa'
    b'cFlYQkU3bTNmNWJ4OXZqQ3hBU2labHFQMWRISVMwbjB5cUI3QWU4ZE13WEVDSUFFT1pvRWpj'
    b'N0JIRzBGUjgrSDNEQlI4YStvZ2VSCkF4TlNvcTFWZDkyVy9JTlZYeFYvTUNBNTNFdzVOcW1k'
    b'clQwQ3h3a2NKN0FzRXNqbTJqNFU0OXo5L2I3aFliL0w1ZXJ2ZC9YM081cGEKVkVxeG83Vlpa'
    b'c24vY2ZpSzBKR2czQ0FkZDV1NWFLWERudlJjdjJ1TElIQVkwK05DUXhNcmVhd1FzSVlQYjB2'
    b'YTJheTd2Mmx5ZU1JTQp3T05BblRsbTJmZ0lBSVRqS1I0M2pvcmlqekphV1pSdy9yR2NacWdK'
    b'ZDhZMjdwOVp3SDNWR0hYbnpUdWFOOC9lZU5jeXEyUk54a3lXCkVrOXRPWmRmV0VDSnhkMDdq'
    b'di9IMVFXY2dVbkp5K05ZTm1DenlUVWFtdWVEUVY4eUJ5Z1lFUGNPS1VvSzduY2xIem5aZGtK'
    b'N1Fwb2oKcWJnOW5RMzVlL2EvTVhRYVdWVm1ybzlkWjFWOGJhNFlNdGVJUzNPNHFQOGw0NStB'
    b'UFljTll3YWtFTllQQUlGNGNxT0pvMVpyODhvQgpBQ0pEWTFZZnh5TEJXcFJHK3dickFDQVdk'
    b'SWgwMEpQdmZyMWp2MEJKZnYzbUVVelQvWWVPbk42Nm8ydnZqcUVOWDlwN2Uvc2JHd01zCjI5'
    b'L1M0blM3SlNwMWpJQUNjYUd3YjZTdG14cHkvdVNIOTk4VVdZSS9qVVE5TVVaRzUxMlJRc3Rx'
    b'WExxOC8vQVd2S1p3aldDWldKTUQKQU5Kb095UEpKYXByVU5MWUd6dVJRUURvOThyanB6N2p5'
    b'TXNpV3hjb01ibEJrb0pVaGFPUHRUUURBVUs1MW5WYmFadG9rdGV6c3VBcQpSYXZWdlM0dDZL'
    b'WHFobDBld1JwMHJ2OHdhYmhURkJ5SkRRV2NLZms1WlhrOHo3UGhjS2gvd0xGN1QxUWtpc25r'
    b'M2hHSHR0Z0NMTzlwCjc1cjBnNlZYWFhGam9UZS9hMmZid1cxT3RmSCt3ZkNBZzkrVWViTU9i'
    b'VHNzV0pZRHdFOXo5NWZvMzBYSnkzRGF4REUvTy9kSkNIUWUKNlRYV3g4MitYaHkxMm42UEhB'
    b'QWdiTDNZUlVrWlFGbVdUVEt5RVMrbTZhQWpuRk9oRDR5RTFabVNTZmNKYit5dUhYQmVzQ3JJ'
    b'Skd6awp3RGQwS0lRQ0FWTldWdS9PM1NxTWtpZE9BSWJCTkYxNTA0cVFnSGQ4MGZEOE5hc2FO'
    b'KzlTMDh3c3k1VlMrWDJ1d1dkTGI5OXZYcEI4CmJsT3YvSmRtNytBSk51UllORGxIb0ZiZzdQ'
    b'a1hLMWpJQ2dCV2p6elJJWStpeGtFdEFCQi9CeEIrekU3R01oK3BURlhwSDZlTWZCM3oKSlN0'
    b'MGt0dGZqODZLS3RSbXViMXVwTUo3Ym1QWlE2ZGlxdk5yS2RUWFlaZ3dJYk9tcG12ekRwbHRB'
    b'TXJIVFgxa0pXSVlSTk9NVkRvUwp3UHRKNFg1MXpidXYxZSt0UGZQVVR1ejM3aHAvUjdSaFhi'
    b'ZGNKMHFkcUhkMStSRkdFN1M5RXMvemlBd2hmZmJZODN2dS9Pa0l6WVBhCkJOclJiRTBCeVdC'
    b'QUJrS1VCSHN2WnR6SXZKN2dKWTlmTGNUOHF1YjFFaU1SUFcxTkx2N1lRM2d5MVVPQUV1MnQr'
    b'UGxhcGlJV0kwUWcKL3E1dWhMR3MwS0pkZnNNVnoveFdwRkl4S2xYVTZ3VkNLcWFYWk5IV0pi'
    b'bDJmMUxrUFdzeHBVelhGSjdxM0RVdytkNGlJU3BvTXhVRApCMDBTbWVtWk9jMEVMYVRHL2Zw'
    b'aUs3ZEFOd2pSQWE5OE9CQkhUbzN4NWRHWXFmSG42WDNBS01jYWJnRUE2M05KNThkR2V1Y3BX'
    b'eldYCmVzOEJYYjZvLzlqeW9MUzd3Wm5PTWJJMGZNdEUyVlpxNFJGbGJ2YUN5Z3k5akJHTGFR'
    b'VEJVSmdXMFh3c3hnQ1ZVVGx4b0tjM3RiUWcKR0hDc0hURDYwK2ZlbDkzYzNkY2lxdWprd3J3'
    b'MlYxWHo3QWc2NmgzT3VPWCtXV1NjYUR0Z29DYmZjekcwam4wUTdEcllrM0xDbXB4QQpPN3BZ'
    b'bnBxVFo0T29FeHZtWENSY0Rxa3FCSnYvNnR6VEgrMzNjcWt6emxvV2JTeVkzNVg1ZGVkOFdY'
    b'WEljTTFqRDJudEI4OTRzMVI5Clg5cGJ1azdVZFc5ckdQSHpaTUFUYW1ycXRQSk1kNi96M0tF'
    b'V2NjUzk0STRWazQyeFE0M09CWk0xS3BGMTk1a2p0SVEySFF3KzBLb3MKajBvR0ptWThNdTRs'
    b'a0ZRemk5OEY2aUpIV0JDaDl5UGdJKzhmdHd3RnBJa09lWFNkc2VsR1FoSmdQU1RRZnJFKzJa'
    b'U1BkU2tVeGgvZgpLaVAydlFDQU1JTXBNU0VrK1VCOSsvNlRKWE1YM01Dc3ZYLzZON2Y5L003'
    b'YnIxdWdpcUpONTB5MUgreHIvR0Q3WndmWTlZRnBHcy9JCmpKWDN5SXdHc0IrOFIvSjBVbXEy'
    b'eDlHZlhtT1l1RHZ5OUY0NURlaEVtbWpOTXFkQXo4Rlo4NEc1V0lnMDhiVkN6TzBNU2hvSE5Y'
    b'RlYKbWZHRmxoRFkyNUVDQUdSNHp5VjZtK21Qb3N4clVtUnZ2SDE5TU5CL0JBQkNJOHk1TC91'
    b'MDk5NUswbk9sZmsrcEdrZFNuMWNXbG1HOQpac0t1RFFzUHYvQ0tyWEcxZDNCRzAvczNiZnhw'
    b'bXRkeC9qblI3bDJUSi9VMUhqNVJVRmd0RWxIWERza0prQU5xY3ZWamk2aklla3BuCm9jcVdY'
    b'YUxNdzNzQllGZDdhcnlkSEJaM01UOWJtakpaSGhOUFBRa1BYS0xvK2N1STV2RWMrR0w3OHNO'
    b'KzY1Nm9Kelc5S3JsOHpneU4KclZWRFI1T3Z2ak5yd1RJQU9MTnk5WXlJZ0kwU0FEaXRsMW9z'
    b'V1VXQ1lBOEt3KzJkQUZCKzE5cXRlM096TXpSSkNsbkw1MFdyWmp4NgpkODNNK1MvT2xORXZD'
    b'a25QVVZYM1hZSnJ1Sjk0RzFnZWY5MmFFVzgxR1hlQklTR1cxc3NqK1hvdmNLR0xuelFqZEor'
    b'bExWY0k5ak5TCmtmYjJpcnBUbmFtRGxEVXRwUGpnekR0ZFRVMXpseXpmOHNyTHh6NzhLT2RJ'
    b'NjhkYUNtZW51K2RWaVc5ZTJyamhxNk44dUxiZ0t1WDYKdFk3VHB3OGVxMy9QMlJGdzkyODVl'
    b'STdYWGpjM3ZlT2xCWjloM29SMTgzRFJNcVJLdWdUYXZrOGdZdC9XbW42Z0t5V0I5dEt5dWhX'
    b'TAppcTA0YWtQS0FpUWUzYmpETngwbkxhdTRjeWVZYVU5RHVCLzVhbjh3b2JTWVVUMjNZZmVn'
    b'Z2dsTThSNnEzU2I0bzV1TUxmdjdvNyswCnd3bUl5R3dPVDk5QThyQm5ka0Q0ZW03OVh1VGRF'
    b'YkRYUzg4VzNLZ2ZFSTBNdHhlc3Y4NjIySGdFMFFac25vWlNyK1FPdlU0SWpiWHAKZ0VmdjI0'
    b'aS9sUXhzWkhucXViMFZjUmlFR1k5b0F6R0dvZmhTazVzRWUzRHl0RkZEcDNGeUtsZC9IQ2t5'
    b'cVBFTFNVaEVULzYxMFBTYgpURFYvODV3MEpscTJkNWZPSHNscDljNFF3dGVIMURYOVBUdm5P'
    b'VU1DaFFsTjJjTkJuVCsyQVFvUUZaQm9RaUlKa2JTd3k2VVZ6ODlxClV0QXlKTmpvK2V0dzdu'
    b'Uys1d1R5UEFWME1jNmFQSmFaUXVoNEhiakErak81Ui91TUVIK0swNFBMUGoyYk95dlhiZ1M3'
    b'WVA4YXB5NFoKclRzbXpKVy9SUW9sZDJJcjZWMGpkTXlsWm4wdUREZFJMWGYrc0N6dGg1YWRq'
    b'ZUVWaHh0MnJPM09EeEUxME1vZ0N0Qkw1M0ZiYW0xKwo4ZWN6ZjZMQ1dJNUc3a2p2bmw2Ulor'
    b'YWZFNFFvNGNOVTBUVlU4VnZjcVMxVTdtU3N6UVg1WnNMRnhod09iRnNoTW1qM3lUNnJ6NDdQ'
    b'Ck9vemZjNk1xelNPckY1eEVDT0dDKzVEeUh5MFliSXp2cU9PYk56QlZQd1JWQnJ2bGRwdzZs'
    b'NTU5THdBUW4wY1lxaU90YTRCVkkzb0gKSDdrT1VLK0hLZ3Y3N1RGYUIwRUhyZEtySllLU0Rw'
    b'R3dGd2wxZ1BPUjNJaXlycUdLbHdBQTMzU01OUDlDaUJub2VXdXdNWVU3dVl1ZQpPRyswQlUr'
    b'VDBQNHFJZVNKN1pQT3hPc2hOUEY3QW8zZEp4TlJRb25KVFh3dFdEUHhIdzZOb2lpaFlTMkt2'
    b'SU0wMXlDVmtSNTNrekFpCndRWTlVQlFTUzdBdUcxdHVRTXA4Z3NvQkJWRE1LYU1EU3FZOUNj'
    b'ZVN4QU5xU1V3VWFRSTZEVkU4dGp5RWM1ZFNFKy9DeVphLzlQTnAKZkxzTkpWbW8vQ25jbHQr'
    b'QSt6VmhSRXRsL21Od2Jjd2x0TDhDUW16OTJkeHYyc3dRcjRycmt5US9PcFZmYkhTWG1OeEN4'
    b'OHU0WUNYUQpGL1pWaElGdVpLcEJtUXRBSkVOS0ZRbEhBbmV0RXQ5K0hWMmFUNVZaY0xJV0FK'
    b'QzVsREtYbnJjaGtXQVEyQWdnZ0wrNFhTSDF2OWp4CkJZR3JiNDI4dTBIeHg4ZUJwZ0FBNmZP'
    b'SWR4cVZYZ3BzN0c5V0N5N0F0NzhNWEtEQnJsMTdPaStlYXkrdWp3UWpnSTViRFpNemgxV1UK'
    b'Q3dJZFNEdVJSRG4rNkorRjF0ZEJYa3lWVGtkcUhRREVQdG5DdDNRd002dUNEejlMcGFmd3A1'
    b'dXcyWVFZK3EvV1FTUVNJWWtNU1dSSQpJajMvZCtINTBSakNLTFpsVCtqcDE2TWZiV1JtVmtY'
    b'Zi9VeXdEVEd6SmdNQVRpbW1pcTRDd3JBN1hrRFNWSlNrQlNFcWRMd000WDZyClI3NXF4NlJJ'
    b'Zk9jbmlQZmpONk1jZGJUSE9EVjdTSVljNEcvQitnbEMvMmt5c3A4cS95bFNKcDIzWUlWLzl6'
    b'bzI2Z1dySFdFc3ZmdkcKOEl0L0VqcjdJaDl2d3NsYTR2UUl3MDVzK2dlUEhIYlBVZUx5a0dE'
    b'SU8rOFdkdE51cWlDTHEydVdyYnFYTHNsbkQ1NkNRQWdBS0V2TworUytETy9ndUpUeFB1RXlj'
    b'Vml4MHZFcUMzYzZnNUxGdGsxMWhNY1MzTG9PVFZVTXNmWHBBUHpuRElVTWp4SHNXSjgya3F4'
    b'OEJRVGdmCm44bnVQUVlDSDl1OGg1a3lqc3JQRnJxdDlJUXlkdjhKckpEeERXMUlLZ25jK1V2'
    b'UkZUT2k3MzRhdkdkMTZIZXZZNzBtL053N3NVMjEKV0NGamFpcXhLUmtwNVV4Vk9YZW1oWms2'
    b'SWJadU05OXdqajEwaXBrK0VldTFBSUNJaU1qbUk3R1N1TlpEZUdBNElIbGkreVI3dko3dwpG'
    b'dGVHeHRHTkdCN0Z5czFUdXAxS2lBeVR3RG9TYWtLNkM0ZlM0MVFqWFYwcHVtSzZZQnNTMzNw'
    b'TmRQTnVxamlQU2s4QmhJamJSM3dCCktqT05QWG9HcDVtUVVhKzFIcUFubFFGRHkxYmRpNHg2'
    b'NGdzd1YweGpqNTVoNXRXd3RZY0JnQ290a1AzaFVjVzd2eWZzaFRnQW5EZU8KeWpRQnFZV29v'
    b'OCtqZUdUemxMaHlnTHJzMFFLQUt5VCs1YmFxazlaazRDTkMxN3RDM3lmbi9VTXBTell6czBy'
    b'KzR1T2lwZk9GWGh0ZApsTXNkUDB0UG04Q2RiYVVubHZGZGZYUk5KWGZvRk01Sko4Tk9WOFow'
    b'd3ZIaVc2NEpQZlVxOFFmWjJzTklMQ0tCRUZJcWtGb3BXTzNpCjZ4YlN4WGwwbVlVdXN3QUE4'
    b'QkdoYjUzUStTYnc0ZU45aG9jM1R4a0pTUzZYR3J1Y2N1b0Zvc3pxblpWdkh5M2tCRXdjKy9p'
    b'bUo0bnoKNkYvRERrU0xaMUVsK2RMSDdnYU9aeVpWQ1AyRHpOeHF3VFpNVjVhd1IrcW8zQXhr'
    b'MEduN0R0QkZlZXllSTZLRk15QWFvMnNxZlV2KwpVN1JrRGdBb1hsNkYwNHhVY1I0Mm15NU1z'
    b'cnoxZlBOdmlHTS9UOURhMDNsUDdhcTh2TkwrWEpiSllQTDEzcDlOYmNyVCt3QUFLWEtRCjZV'
    b'cWtMb0cvanljUkJPNU1DMTFSRkY3elBsTlQ2Zi94cnpRTlc3MXpiaFlHUjJSUDNrZThmdTdZ'
    b'V2Rsdkg4UXBvNllhSWNUYlFPemIKU2JBYkFOcEgxSzhjTE81MFhuN0pZQzdYRkU0WWtTc0xy'
    b'VGRQYUw4UXVpa3pJLzBNcEowQWxHeFVXSUFRQ1lTUTRxTFRIeTVJM0tlSQpZLy81L1VSL2xQ'
    b'bndaTUgyYyttRVhJNDFkSmtuWHBNeDNPTGl2cVVsUFVuU0dBQUFvcEc2REtsTGtOTHlIVUt2'
    b'b282L0pGNXJCTUlCCmdDY2kzbGlmdGJVMVBjd21FcS85V3lXbStSazU5cm41QXlWRzk5OGNx'
    b'a1JhSkRXRHhJZ2tScUFWUUlrdk5HZytCSHdVT0QrSkRFTmsKa0lRSC9pNWRJalFNYXZkMHBP'
    b'M3JUSW54bDMxbTMrOEQyci9Lb0FoWFp3MVhwRGhMVTF5eWI1M2tOQmlqR3dlMVoyMjZJejFH'
    b'UjFEeQp2YW1ON3hYYXZ4K0pzN1Irc3pwb1ZnZFRWU0dWSkNabGVBbkRBVUNFcGNNczVZdUli'
    b'SDVadjBkdTlTaDYzUW9oa1pyNGNwRkFVSmRUCjFlVlV3ZjloSlhMRko5QW1sRUNiVUFKdFFn'
    b'bTBDU1hRSnBSQW0wQ2JVQUp0UWdtMENTWFFKcFJBbTFBQ2JRSnRRZ20wQ1NYUUp2VHYKMFg4'
    b'RFkwT0M3MmRpaVVnQUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURJdE1qWlVN'
    b'VGc2TURZNk5Ea3JNREE2TURBZApQVDBWQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1E'
    b'SXpMVEF5TFRJMlZERTRPakEyT2pRNUt6QXdPakF3YkdDRnFRQUFBQUJKClJVNUVya0pnZ2c9'
    b'PQoiCiAgICAgICBpZD0iaW1hZ2UxMDYxNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_MN')

US_MN = b64_US_MN
index.append("US_MN")
index.append("United States of America Minnesota")
catalog["US_MN"] = US_MN
catalog["United States of America Minnesota"] = US_MN
country["United States of America Minnesota"] = ('US_MN', '', 1)
lookup["US_MN"] = ('US_MN', '', 'United States of America Minnesota', 1)
lookup["Saint Paul United States of America Minnesota"] = ('US_MN', '', 'United States of America Minnesota', 1)
lookup["United States of America Minnesota"] = ('US_MN', '', 'United States of America Minnesota', 1)
details["US_MN"] = {"continent":"Americas","capital":"Saint Paul","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_MN"] = ('US_MN', 'United States of America Minnesota', 1)
regional["United States of America Minnesota"] = ('US_MN', 'United States of America Minnesota', 1)
#----------------------------------------------------------------------
b64_US_MO = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDY5NyIKICAgd2lkdGg9'
    b'IjE3MiIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNzIgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01pc3NvdXJpLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MDcwMSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEwNjk5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwNzAzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE3MiIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFLd0FBQUJrQ0FJQUFBQ1U2RXhXQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBYgptRWxFUVZS'
    b'NDJ1MmRlWHdVUmRySG4rcnU2WjRqY3lhWnlUR1ozQ2M1Z0VBT0NJUmJGQlNSUTBSWnNxNkxz'
    b'cXduS3VycWVpdnFncUlMCjZLSUNIdUNDZ0tnZ0lDRElFVWdJNFVwQzd2dWFUREtaczJlbXIv'
    b'ZVBqaEdQai8rOEwrOXVZbi8vbXFtdXJxNnAvczFUVlU5ZGFDYzUKRmlSKzMyQlNFVWhJSXBD'
    b'UVJDQWhpVUJDRW9HRUpBSUpTUVFTa2dna0pCRklTQ0tRa0VRZ0lZbEFRaEtCaENRQ0NVa0VF'
    b'cElJSkNRUgpTRWdpa0pCRUlDR0pRT0pYSUg1dlB6aUE0ODFCdWg2NXFvOVNPQ2k1R0lnRVFS'
    b'dndheGhmaE1kbGNmZkxlRjRTd1hDRFI2aFNGMXBtCk1sZUhSVGFTS2xiNDhWSzBVUU1BelZi'
    b'bllBaU93QnlnTTdwYVIxazcwdnF0eE85QUVNTmNCSjFLOWY3WWxPS0lXQWRnbytPTmJydUgK'
    b'N2ZOY0cySCsrRVJCZ0xWZmxBMkdjQUlFVENFZEtkRmYxMXMxQWpleHJXRmFhMjJreHptTVN3'
    b'bGZpRWNPeXgvV29ESDhLeXQvYytLbwpXclhCRHdnQWNwUEQvM1o3N3RucXpsbGo0MnJhN1Fz'
    b'bkpQLzlqcno1QlVsNUtlSDVLUkVFanRWMjJCZE5USEhSZ1hmdW05TFU3YnphCjF1ZEhXSTAy'
    b'K0dCVVlsTndpTmxsMXdYOGtpVVlHdGdweGZiVVVTZU0wYXd3WVBmMVFmSXBXVkZGVTBmTXpv'
    b'bTdOUzloeVpwdi9BeTMKL2ZqVmFLTm1RVUVTQUd5b3Y3ajkrRlVBUUFnYVA3Z0hBQWdNdzNG'
    b'MDlHS3IzZTBUQUVwMFllZnpieXJvYnY1RFZabDYyRWxodVBVTwpUcHNzS3d0ditTN1U4bkpS'
    b'Z1lJa3d2U3FxVmtXaHVVMEN0SmlWQU9BdytNL1VOWWtSdmI0bU10TnRzdE5ObytQRVVNT2xE'
    b'VTVQSDRBCnNCalZHZ1hKc055MGtaWXd2VXBCRWk4WEZSd3pXaDZaZE12Sk1JdGtDZjVMWVRC'
    b'c1UwYmVkMFlMQ0FBQVlYclYyYldMbzQyYWNZOXUKZC91WXpZY3JUSHBWdDkxN3JxNzc4WGxq'
    b'SDkvOFBRQlkrNzA1ajJ3RGdEbTU4V0lpajg4YnUySC94VEVKcHFPWFdqY2ZyZ0NBemo1UAo5'
    b'WHQvYkxZNnl4dXNBTkF2NE9zeXhsME5EVjlhY1U3R2M1SUkvb3R3a3ZJMXVaTXI1VnJ4Njl6'
    b'OGhJa2p6REVtVFovTDU2SURZbUNYCjNiTnc5ZGY5SG4rNFhublBEZW1qNDAxUm9lcGxOMllp'
    b'QUJjZG1ETFNVbHJUdWU3TDgrMjlicDJLdWpVL1FiekxSUWM0bnMrSUNWRXIKeUxuNUNYdUs2'
    b'd0RnWUZoc2s5YXdxdVRvOEtnYTBEQllrTnBIS1o0ZmQwTUhJUWNBQlVrRUtXUXpzMlBUbzRN'
    b'Zm56ZjJVSG16MCt0Lwo4TDFqSFgzdUc3SmpWczBmbTVNWXBwTExmaU0xajQ4cHJlMWErMFha'
    b'VjJjYklneEI2KzZkcEZGU00wWkZ2NzZyOUVwejc0R3lSamZOCjBBRVdBS0laNzk5T2Y2c1Aw'
    b'SklJL3NNNFpOVHpFMjVNems2cWFPa05NTnhMZnloWXZ2NHdBTWdJN05RYmkzSWYyUVlBVHkz'
    b'TVhUazMKV3g4a3YvWkdMOFA1V003TGNnaEFRZUJLR1M0bjhKK2s3UEd2L2FMc3BjL084b0p3'
    b'WnMwZEUxZnRDTEFjQUd4Y01lM3BqMDZTTW55RQpKYmpxWE8wTHA3N1JCSHlTQ1A1akJIRDg3'
    b'K052cktlQzBpekJaOWN1N25GNGoxOXUrK05iQjhXcm1UR2hjV0dhRHgrYXFRK2lCdDZyCm56'
    b'blUwUFZaUmF1ZjVRODJkRDZZazdTdnRrTkZFbVBDRFI5ZGFwb2NFMnBVS2hha21RdWpRMVV5'
    b'WXJBNnVHZmRvYXR0OWt0TlBXTEkKNW9kdUtNd3doMnFWdVk5c3EyenBUZkU1bnpsOWtPU0dj'
    b'UHRnYVBzSjNoMVZVSzRPQVFCQmdMdW5qN0NFYWhJajlGb1ZkYUdoSjhCeQo3ejh3NDVrNzho'
    b'UWtBUUFYdS9zWDdTayszTkJkWlhNZGE3Yk9Uek1mYmJUU0xOOUwrLzBjMyszeFc3MitwWm14'
    b'L3lxdlY1SEVHOFhWCkJ4dTZSb1hwRFFxU2t1RUxDcEpTelladHg2OGFndVRQTHM0dm1qYkNx'
    b'RlBhblBRL2RwMmpBNnlOb0hvMHV0ek9saUZzQ1ZwM0hSNmkKV2YrMHV2ZUpVMjBBb0ZHUzY1'
    b'ZFBWWkRFbkx6NDFUdEw5eFRYOWpqcDByVjNtdlJLQU9oMDA3ZnZMcDRhWXpyWTBOWHM4TW93'
    b'NVBBegpMajlibEJWenFLRjdhcXl4MmVIdGNOR2p3L1Qvcm16VlVJUkZvMnB5ZUtiRUdNT0Q1'
    b'RjBlMzVhYmN6U1VEQUI2SE43OHh6N1RLc2k1CitZbFBMQmk3OTB3OUhXQlhiRHppOUFZQTRN'
    b'MkpsdmtKK3FFcUFrRVFobUsrMjJ5dXRPVmJYRFNERUdpVlZML0hMeHJxVjNhVWNEeC8KNFow'
    b'bGFnVUpBQjllYUR6VTBIV212VmNBNlBINDg4ekJwUjE5SDgvSnZmdXIwcHhJdzhYdS9sQWw1'
    b'UXF3QkliTWFtV0hpMzZxSVBXQgpnK1ZKQm5WMXIxTkR5ZlJ5TXNFUTlLZVJzYk1USXdDQURy'
    b'Q2o3djlFQU9HSkJUbDN2M1VRQUhRcXl1SDFDd0pvbExKTC8xd3Fqa1JJCnpxTC9KLzY2OGFp'
    b'TFpnRGdyc2xwK2FrUll1RHoyNHRkdEwvODdTVnFCY2tKUXRHWEpROGRLdmR6dkkvbExSb2xS'
    b'V0F6NDhNQ0hILzcKN21JU3gvcDlqSjBPRkdYRkxreU5hckI3Q0F3MTlMdnYzWGNPQVN3YUVZ'
    b'VWhGQllrZC9nWmh1TVg3em56N1BkWEJBQUZTWlM5ZlNjZApZRi9ZWGl3K2NWeHF4SjJUVWdI'
    b'QTZXVld2bjljOGhqKy8zR3lzbjEvV2VOYnl5YXRXemI1MWFVRnFXWURRZ0FBTFZaWDJib2xH'
    b'aVhKCkM4SU5ueDZQMHdmbG1ZT2JIWjYwVU0yOFZIT1dTYXNrY0RtT3I1bWVOY3FrczJpVU1U'
    b'cFZaWStqMWVsTjBLdlNRalFUTGNhWEoyZjQKT1U1THlXTDF5c1hwMFpsR2JZWE5PUy9WM09u'
    b'eTNmTjFLUUNvS0ZuWlczZTEyVndBZ0JDa21BMnJpeWFzV3piNXJXV1R2aXlwLy81SwoyNUJV'
    b'Z1RBRW1mRDRaekJyVGZDaTljMVdweGh5c3FJOWFkbUh1MC9WaWw4YjdHN2Q2N3VmUFhhbFlQ'
    b'T1I5cDVlWGhDcWJVNk81d2RUCmNQZ0NIUzV2WDc5OXdZS1lPUXN5YUordnJzOUZNNng0bFdW'
    b'Wmh1UHIrOXdPcDdQWDY1K3c5ZWdUUnk1UnIreTAwd0V4d3I3U2hxUmwKSDU2c2FCZS9ObHVk'
    b'd1l2V3c2dzFCWTl0SDRybE9mVGFCQ2NyMnljOC9tOEFpRFZwS3pZdTVYbmhtN0xHaGF1L25w'
    b'UVJkZlNWQlQrSwpHNEFKQkVpU1hMLzUzWXZ0VjhITkdQVEJCTUp1bXpuSEZHeU1qSXlrYVhy'
    b'VmZURVVibU5ZWUxEa3R6KzRqQkQ2eDRmcmJwMDA2K1pICkY1dWl3ekVNYjdkMTFueDBCaUVr'
    b'Sm9pdXljYmNsNy9jZTZadXh4T3piOHlPeFRBMFl2bld4bTRIQUpTK2VlZVlSSk5VSFZ4ZjN2'
    b'dm0KMG9BYklEWWs1K0Z0K1k5dUR6QzhJTUQyeDJaZEcrMmQxUzhXSmhqL3NtaE9lbHhxUldQ'
    b'VlBzZlpIWERxMDlZRFMxNWI4Y0Jyai9NOAovOEpqdVJyS1pncEdJVHBRWVRVYjEveXhwS3gw'
    b'ZmVPdXFTOHVZc2ZyMnMwMDZ3MWs5OGdQN2QzMTBwTXJlMjAyOU5Oc2ZQRGdERUdBCkFNUG5Q'
    b'N285NStGdG1iRWhZdmhiZTh1azNzSDFwZC9qajFqeUhoMWdqVHBscjVQbWVBRUFva0xVTTBa'
    b'SHYvL0FEREdPMCtGNFp1SGsKS002dXBmQXVEOVBGVXM5L2NYcm0vZk43WWhqQ29CQTRucTYx'
    b'Nzc1MzQ3b05yK3JvZmJHUndMQlEweVMwVVJOR2p4bS9CenNMQUFJdgpFT1d1Y1VKa2VGdHBu'
    b'RTdPOE1JcElYTFQ3Z05LcGZMYXpEeTg2ZGl1VTdXdE5oY0E0QmdLMWlpcy9WNGxSVmcvWGY3'
    b'Ym5tbkpFdnl2CitPWmNvK2kzbjVNYmY4UG9HREd3MWVaNmNjbDQ4WE5mYis5enQ0eEpKNXk5'
    b'WGdZQTVBUktVckZiTjY0cjNmYmROMFh2YXh1QjZmRXEKVTRMdk92YjBLVmw3cUVFZUZnTFI0'
    b'VUJReGpxRFp3OTJsbk1Gb05JNUYrVis4dkE3c1oxbE9FSUEwT3RsSitFZHEyWmtlanp1YXpQ'
    b'ego5S0k4VVFFQU1ETTc5cGJjZUFEdyt0bkJvZXFod2hBYlJkeFgyakEyTVN4VXExZzhLUVhI'
    b'c05Rb1EwdVA2M0tUTFZ5dkVtM0E2cmxqClU5VVlBT2dWQkFEb0tLTFo0YTg1K0NWNjVzVzA1'
    b'TlR6R3c2ZlBWZnk1aWZydFRqbGNWeTJwUG5qb3hBQWRQVDBnVzJFMnA0ZXBqWTgKOHU0cUFQ'
    b'akw5TkY1YWxKOGFGaVFEQUF5dGZEazNNSTErODdJWkFQLzhtQzFQQzhsUENwRWJRbFZ6OGxM'
    b'NEhpK285ZmQ0NkQzRk5mTwpHNThvaWVCNjhXMTVzeTVJL284L1RaeVliZ2FBUHBkdnlacHYz'
    b'bjl3dW5oMTA2dFBKNm9IYkp0ZVRqQzg0R1A1YmpKMDI2RVNBR2h0CmF2amdpZnU0dHFwd0lG'
    b'cDBDcjI4K21JTk9uTkpFQVNrVm5LQzk1ajFZaTl2czYwcS9mNm1leDRtb3pNT1h2ZytYQTVC'
    b'SkJhaWtHa28KSEFBeVpJN0hGdDMwNXVlSHhLWWlBRHg5ZSs0ZHIrLy9lT1dORTBaRUFnQ0cw'
    b'Si9mK2Zaa1pidlVNTHlPWGtLcmc2NXB0Ni84NExnZwpnTnZISEwvUzVxSURoZWxSWW9TNm8z'
    b'dXZqUy9Ea0pyRXpaenRucHNucjVpUXZPOHYwNG51R2tkc1NOTFU5alJ6alRqaW9GVWpoUUpJ'
    b'CkV2S3lRRUZkaXAzVTQvUjFscTlad2JWY2VmTERMOUx2ZWRZZDRJTklEQUQ4SE0veVFocmR1'
    b'Ry9YanNGSDVLZEd1T2pBOFN0dGJoOGoKQ0xEeWcrTTE3ZlptcTZ1NzN5dUo0THB3c1hGZ0hD'
    b'OC9KV0xlSzE4bUxmdlFFQ1RITVdUVUtrU0hCODR6ZzVFcmJRUEQvQkZCNURpcwpjNlNHcS9F'
    b'Z05NSTFjZlNWSThXYzJ5dm8xQkFUQ1lWajBMUThOR2NLcXFvWERGcW9iMkVpTGRYZWVIK3Nq'
    b'Tjcrd0cwbnRyeEo0UWhECmlCZWd4ZUZuZVFFaE9MRCtoY0duR0lMa0Nvb3c2WlFqbG0rWi9m'
    b'eWVzWWxoWXZqNXVtNnBPcmd1MUxUYkI4eit3Y3UrQUFzQXozeHkKYWt4aW1HaWNFVUpWdmI0'
    b'c2t3b0F2QXpQOGNKRnF3Y0JTalRJRlFSMjFZTnBNMXJNNGV6T1E4TElaQ1Fnckt3OTRxTFBj'
    b'cURlZmR1NApOSVEwc1FuRlBrZUZoK1p0ZGlIUzFNT21xUFZWaG1RNVcyOEhBS2l3ZVpNTWNn'
    b'ckhBRURsZHpBTU05Z3lLRXlQZW1MTENRQm82WEhKCnlZSHliTEk2SlV0d1hlaXlEOWhZY1lx'
    b'd1NFSGF3TUFCeDNGaEtxS3AzdzhBU2htV1lWUm1HVlhKd2ZLYVByckU2ZzhkMWRQVHk5QisK'
    b'R0plRnFoMVJHMnFXN1BVL2NOaDFhN00vUGkxcjlxMTNiWGp3MmZLOG16Nk1pczZJajBMTkhV'
    b'SjNuOU1mNy9Nd3ZDQWdBS0J3SkNvQQpBRUtWc3Y3Ky9zRU01Q1NGRFg1ZStFUEcybXh1eVJK'
    b'Y0Y3cjdCOWFOM0hkanBvb2lsSlNzcHNNZXBsZUpnVmFyTlRzODZJclZxNUJoCkpwWHNoMllC'
    b'bG1WVWZkSGxVdG1jY2dyNlhWQmlUZHZiZHdkUFVMOU12M0RhWFNPeXBuNitlU2xiZjBTbmhz'
    b'anc3cExtcEdpU0JZRHEKWHA5QlRvUW9aUUNncGZEMmx1YlEwRkR4THBOZU9Uc25MaWxDNy9V'
    b'elM2YWtmWFMwRWdDNis5MlNKYmd1K0JrdUtWTC81SUtjWkxOaAo0NHBwdDQxTFBGRFdwRk1O'
    b'dk03aUl3ZlVKSjV2Vm5lNEEwZWFISWNhKzc5dDdOOWVhYnZhU3lmZ2VHWXlNZ2FqcXI3b3ZY'
    b'Mkw1Y29CCjNTaXBuLzhIUWtMRDV4VnR6Y2djMGRvRng4OEpjU2tOSEtEcVhucDhsRnBVQUMr'
    b'QUs4RHQzUERHNEMzNklQbUJzcWJieGlWdVhERXQKMld4NGNrRk9VcVNlNHdUSkVsd1hjQXo5'
    b'TW5EUTRYbDYxOVprQUFBWVpWSU5YdVVGMkZqajBDSjZMQUVhRGI2L1lwcE1vWmlZYmo1UQox'
    b'cVNTeS9KVHdodlAvNWdVSndnWVFxSEc4S3k4aDkxOXk0SVVndFBOMUZENk5HUTN5QWNLNm5T'
    b'Yk04dWs4bFdjOUhxOW9nT1JaWDlsClloay9wUHl3UThrU3lIQ3NwdDMrNnM2UzZyYSs1ZXNQ'
    b'N3o1ZE96TTdwdHZoRWJzR25wYnFYOTRTNFBocGhmeW9QUHJNSmVGSWRiU04KU1BZejNMS1pt'
    b'ZnVmbTN2cWpVVzFIUU5WdTlkUkJRSi8yNDdUcjUydUN0QWRCWk51cG9XMG5qN0IxZytrclRO'
    b'TUpSUFZkcjdMazJSUQpxRWs4MmFBb0t6a3o2TW1lbVIyeiszVHQ4dldIcTl2Nlh0MVpVdE51'
    b'cDM0NloxV3lCUDlubUg2by90Lzc1cEpZOVFLQVdCMXdIRWZoCnYySW51ajJNUWVPNlVnTVVD'
    b'WjNFd01xaGhhdS96a2tLcTJtMzI1eDBQQUFJZk5mbDcwajl0eXR6Wm9lUnZ2WXJ1MGt5T1h0'
    b'TWJsdFYKaGJPVEtnaFgrem0reTgxYzZQWVVXalE2T1FFQUNFRkhZeTFNbWdJQTlaMk9yMHNh'
    b'QnNUa1p3ZXlhbEJKSXJndVJJV294UTg3VHRZTQpCcDZvYUFjQUhNZjl2MVlOdXprd3lIaExH'
    b'QkFFdXRMa2lPSUdaZ1MxbG9NQ0lBcEFKYlFDd2hCbGRIVmJVK1BQa2JLSTFpNVBTRzZDCnZN'
    b'YWtWRUJQSDlyZlovZXhmRnFJOHBaRUE3cEdaaXd6OEw0UGxEVU9CZzVtektoVlNpSzRMZ3pP'
    b'NFB2ekRSbnR2ZTdpcXgxL3VXbmsKTTUrY0NyQWNTZUFLY3dLd25UOXZTM0lRRmdJcGNSaUdn'
    b'Q3RwRHUzcisxa0VxOXJUenpnRVhSclQxWDd2RnBRVTJudW5CUU5TalJPSwovZDhMY2gxdGlX'
    b'TlVqY1pZM1U5NkV3S0FPVDRaQUZpZXIrbXdyeTZhc0dIZmhZeVlVRXVvZXVQK2l3Q1FHS0dY'
    b'UkhCZEdPeVJGMS90CktGbDdwOGZQL1AyVDB3RFEwT1ZJTVJ2Ky9NckdieDY2V1UzaWd3MUdo'
    b'S0NteDVYWWk1OHFaMTFleUpMSkxGM0JWSWpPTkNNL0tEWVMKRU9xL1dIT2k3SE92UUZmNHVr'
    b'WW5aRDcyK1JFVkgyNlpQMi83anQxYW9pVTZBdUxNcUtOUFZkdEh4K29vQWFDNmwwN1F5d2tN'
    b'bmUrbQo3OG9mQndCdFBXNUJnTzUrYjhYR0loVWx5M25rVS9IcG8rS05Vc1B3dW1EVUtTMmg2'
    b'cVJJL1pvL0ZTSUVRWEpaWWJwWnJTQjNuYW9GCmdOUVI2ZVdlSDljWWxYVzVMMW05RVVHazNh'
    b'MGxaUkFiaVR5aEhnRElYUDNnMkUxL1Qvdjdzb1Q3NzdBc3VrR2gxeHVKRUdTcnRQWmUKTVM4'
    b'cU5OMmM4L1huR3labnE1cnJpazNCNkVLMTRQTVlza3lxbzAyTzRqWlh2RTVPWU1nVDRPNTRi'
    b'WXZZTmZpcXBGNnRJQXZUelVGeQpHVUt3NWsrRlNaSDZDSVBLcEpPcWcrdEdRVnBrYlVmL2E1'
    b'K1g4b0tBWTlpSmlyYVoyVEd2N0NoNWNtRU9obERCZ2lJNHZFbU1hZEZTCmZUUmJFS1c1NEFx'
    b'bWhON0dkaUVqeWROMnpqbWE5bDk5YmJPN3NWMFZIZDc4OFQ2YXNSTVlNWDN5c3l6UEVKZ01B'
    b'S1pib2krVTd1VjkKbFFXalVWZ28xSGVrbXV4VnRYMG9PMXdsd3hFQWxIdmtEMDJkTGxZS0wz'
    b'MTJkbVoyekltS05vTmF6dkg4Rzd2T2FaWFV1SlR3b1ZXcQpRMHdFdDQxTG5QL3FWd0FRR1J6'
    b'VTN1dmVmMjZnVVhhMnVpcy9KWHpSM2ZldDNiUEJySllCUUplYlNkRExNUVJxVGJKRlc5N1d4'
    b'WFgyCjhlRVRPODg4OEFvcFlBakhpQ0FsNDNCRHhBOEZnZjB3RjBoZ21pNjlqU05oOHhkQ1hw'
    b'WThjOEo4VzhNTEtoSVgzY1o5UHZheGpaK0wKRVM4MTlsZ2QzcDBuYXdEZ2FwczkzS0FTODdO'
    b'cS9oQmIyVGZFWmhiTnpJNFIzWHg3ejlZZlBOODAyR3U0NSsxREFvQldxODI2OXdYUgpUNk9Y'
    b'NDBvWnh2SkM1cGhKR2xPaEpnZ2hCRldjdTdtd3dZZHhBc2N6amwveDdGcTcyL2QrL0ljTEZ5'
    b'dnRUbUZzT2pJbExwMHhjMDVECnZ6OUlob3ZKTmhLaDZWa2p4Y2pMMXg4ZTdMQWNLR3Y4OG13'
    b'OUFLamtzaG1qb3lVUlhFZFVjdG5jL0FRQXNQWjdaK2ZFcFVlSFpNU0UKckM2YVVOblNlL1Jp'
    b'Q3dETVhmeUgwcDZBQUNBbk1CL0xOenY4Si9kK05tSDJHcmxjSGFKRHRBK29MR2Z6ckpyTDBS'
    b'M05LWjB0U2lmLwpvK2RST0hab3k3ODN6cnhjZml3bERobURrVXhobVRMN3BYZGVlem5BQzYx'
    b'T2Y0WE4yK2tPM1ArUEQ4WDRKVFZkeFZjN1Z4ZE55SWdKClNZOE9tWjBUWiszM0FzRHRFNUxF'
    b'eFU5RGlLRTM1Ynlzcm52TVE1L0NMNmFjYTVXVTlkUGxNZ0lyTzNONjE0WVhNYkllbzV5MEZ3'
    b'aEsKTnlKclpMQnhSTXZsVnh2Yi9JblJxTFpab0dSZ0NrRWNENTFkQ0ZNbFJGdmlLYXhOaVNv'
    b'dlhPWGpMZERkQzNxdFJoYzExOWx6d2UrdQp3aURnOU1pZGpzamdxSnRXUHZjbUFMQWNiMTc2'
    b'TDZ2RCs4c3A1MmZYTHI1MlhGR3lCTmVGN0FTVE9KZkw2ZlgzT0dpVlhEWi9mTktKCjF4WVpk'
    b'VXB4VVhwMjNyaWlSLzhZRjkwQXZNM243OUhJNnh6dG41ODY5SHpNNkJjaXd2VHRWaGlWaXRu'
    b'c2dzQ0R5dzBXczZDUjFTWUUKSHdUL0ZZYmxaNHhEelIyZzBrWnl1UEZLeWRhbStndkFCK3dP'
    b'Q0ZMNGVLaWJmdE5BUmZEQWU5OXBWZFNKMXhiTkg1K2trc3Q2SExUVAo2d2VBS1psUlEwNEJB'
    b'SUEvOTl4elF5N1RLVkhCSDM5WCtkS1M4ZFZ0ZG5PSSt2bHR4Y3YrK1cydjAzZTV5UllmcnMy'
    b'S0RjVUpkVVhwCnBqZ3pHeDJKSmVhK0pXQktKYW9Lc0dSV3dUTTRDbFJYMTBTYWdNQ2hzd2Yw'
    b'R3ZEUVFwd1o2VFZJclVTWGF3VWFaV2JrcjJxci9wZ1YKREdNS0gvQUhDRG5SNitQMXdhYk1p'
    b'VE9mcE9SQm4zeFg5ZFJISjN0ZHZzMkhyemk5Z2ZUb2tEMm42eVptbUk5Y2JObjgwTXlodUNa'
    b'MQpxSzVLbnYvS1Y3dE8xd0xBWFpOVGJVNWFuT1VkWTlLMDJkemZ2alIvVW9hWlpabldobFAx'
    b'SitjeUVHWkllTEw4eUwxbEZZRnhvOGpnCnlNTHVmbDFiM1JFVjFhOEpFbWdmSUF3TUdzekhC'
    b'bUdLVEYzb1dCbHE3bTQ4NktVOUFZNHlSdCtjb04zbEoyK2FjT3RuSktVQWdOTlYKSFlWUDdE'
    b'Q0hCRFYxT3dIZ3hqR3hoaUQ1cDhlcUFPQzJjUW03bnJwbEtCYm1VQlZCczlXWnNXTHJyeTVO'
    b'cisyd2YvWHNyYlBIeGdGQQpTOFBaK3VNVHVwaUZxYU1XdDFhOWUvbjgvdFpPd1JTTUVtTW9K'
    b'eFB0WTRJRXdNTWpZZ1RXMVd0dEJLYUpZZnpsVlVKY0ZJcExHaDhVCk10N2RzVFV5M0RocDBS'
    b'bENSZ0hBOTFmYUp6KzVJeUZDOTh1bDZUb1ZWYm14S0h4SWpSdjlLSUlkSjZwaGFITGlTdHM3'
    b'WDErQVg5dWsKNG1wYjMrdDNUMXd4YXlRQU5GdzlBcmcrTm1FVVFxaW5zL3JDNlhmcUxtMmxh'
    b'WnBoSVRvQ2pwY0tDUmJVMWkyWWdoSExnVXhHak15OQpQV3ZjeWpCenBpQUllejh1bXJuZ0hi'
    b'bENBd0QvT25ENTRVM2ZwWmdOdjdwSnhZcFpJd3N6ekVPMEpCSE1XZ05ERnJtTThERXNBSVJv'
    b'CkZCZi91U1RDRU9UeE1ldjNYWGhqMXptYms3NXhUT3lPSjJZSFhiTWl6T3YxSGpseUpEa3Bv'
    b'YWVySWpKY2IrK3A5UGtDT0lia0NoVXUKMDN2OVZGaFVsaUJnRnN2QW9EUExCZ2lDOVBpWU8x'
    b'N2Y5MVZKUTRoRzhkaThNU3RtalZUSlpSMTk3cXkvZm14ejBnQkF5WEEvTTRUMwpMQnJhTzVy'
    b'NkdGYjBIUmwxU28yU2F1eDI3RHhaczJyekNmSGR0TnZjK3R2LytkSFJTbkhKSWdDUUpEbHk1'
    b'RWlQMTNmc1pMV1BqMHpJCkxBcU5uak55L0Y5SlhXSHFxUGsxalc2RElkVG4rM0VyTW9USmRw'
    b'eW8wUzlhMzJ4MUFZRE5TYS9hZkdMbnlackdib2RHU1JsMVNnQlEKVWtOYkFVUGVFb2dvU0dK'
    b'OFdzVFB0ckFqQ2Z6VUc0dHlIdmxVRUVDaklOOWVQbVgrdU1ScjE0a0tndUQzK3dtQ0VGdEZP'
    b'STRqaEFhWApGbm45eko3VGRTdmVQU3J1Y250MjdlS0pxLzR0dnV4cnQ3QTdYZFV4T0pGRUVz'
    b'Ri9HQ1ZGaUMvak56YXpSQWltajR5K2UzcDZYa3A0CnVFRkYvbUlHR01QeFBRNzZiSFhuK3E4'
    b'dkhMM1VJZ2p3MjV0WktraWNEZ3lIblcySHliYTJYaitySkhGdmdLTURMQjFnM1hSZ1lVRXkK'
    b'QUl4Tk5JMjgvK09PUGpjQUxKMDY0b3ZpdWtQbHpUaUdlRUZReWNsMFM3QldSVEVzMzlYdmFl'
    b'eHkrQmdXUTRqakJaMktXanAxeEpiRApGUjE5N3BYdkh5OS9ld2tBTEN4SVBuUDFXSStESGpR'
    b'L29oUWtFZnczNlNEQVVRVHVaemtBMkZOY2QydCtnb3MyUmhzMWc1NzhNTDFxCnh4T3p6OVYx'
    b'RXhqMitPYnYzWFFnMnFqWmU3WWVBT2JreGxlMjlBTEFxMFVUV0o0WE43Z1c3MUlyU0FMSExq'
    b'Zlp5aHVzNHNiR1lsMHoKYkJRQXcreThBei9MSVFTVURQY0Z1QzY3Si9lUmJWb1ZsUjRkM0d4'
    b'MUxpaEl1cU13T1RNbU5DY3BMT0hQQTROQVJwMnlaTzFpQU5oMAo4TElZOHZxdTBycE5kMnRW'
    b'bEVtdjdMWjdkcDZzQ2RPcmt1L2Q3UEQ0bjdzemY3QWpFR0M1NFZSdXcrMjhBMEVBWDRDalpQ'
    b'aFRXMDdSCkFiYkw3amw4b1VWRzRFNDYwR0oxQVlCV1JjM01qaEVqcStTeWpKaVFqSmlRd1Fi'
    b'anpPd1lyWW9DZ0Jhcnkwa0haQVIrNUdKTGw5MUQKQjlpL2JUMUpFdGhRN3dqOEtqZ2szVEQ4'
    b'ZmhYSEN3SUlDcExnZUI0QWZBRzJxcldQOXJOeUVyL3gyZDFSSVJyeCtKc3BtVkVhSmVuMApC'
    b'amhlRUkrL1NZc0tYdm5COFJpVFp2TzNGWHVLNjhSbHJ3aVFYSVlIT0g2d3F6bk1HQ2E5Zzkr'
    b'QUpEQ0VrSi9oUnNjYk8rMmV6cDhlCmhQWElyZGtDd0p0Zi9HUzNxWENES2x5dk9sOXZwV1E0'
    b'endzTU44d1BSQnYrUitJRjJJRlhlS25KUnNrd0RFUDhOWDlvY1JUcUo3WVIKUXk1dlFKd2hN'
    b'aXlOLys5UkJJT3dITS8rNGovZGFuT0I4UE9xeE8xajRQZkU3KzZFMUovQkQ5TnEvbmZkTzVD'
    b'UVJDQWhpVUJDRW9HRQpKQUlKU1FRU2tnZ2tKQkZJU0NLUWtFUWdJWWxBUWhLQmhDUUNDVWtF'
    b'RXBJSUpDUVJTRWdpa0pCRUlDR0pRRUlTZ2NUL0RmOERYamt3CkN1NHZtbzhBQUFBbGRFVllk'
    b'R1JoZEdVNlkzSmxZWFJsQURJd01qTXRNREl0TWpaVU1UZzZNREU2TlRJck1EQTZNREF4VEhJ'
    b'SUFBQUEKSlhSRldIUmtZWFJsT20xdlpHbG1lUUF5TURJekxUQXlMVEkyVkRFNE9qQXhPalV5'
    b'S3pBd09qQXdRQkhLdEFBQUFBQkpSVTVFcmtKZwpnZz09CiIKICAgICAgIGlkPSJpbWFnZTEw'
    b'NzA1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_MO')

US_MO = b64_US_MO
index.append("US_MO")
index.append("United States of America Missouri")
catalog["US_MO"] = US_MO
catalog["United States of America Missouri"] = US_MO
country["United States of America Missouri"] = ('US_MO', '', 1)
lookup["US_MO"] = ('US_MO', '', 'United States of America Missouri', 1)
lookup["Jefferson City United States of America Missouri"] = ('US_MO', '', 'United States of America Missouri', 1)
lookup["United States of America Missouri"] = ('US_MO', '', 'United States of America Missouri', 1)
details["US_MO"] = {"continent":"Americas","capital":"Jefferson City","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_MO"] = ('US_MO', 'United States of America Missouri', 1)
regional["United States of America Missouri"] = ('US_MO', 'United States of America Missouri', 1)
#----------------------------------------------------------------------
b64_US_MP = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTE4MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9Ob3J0aGVybl9NYXJpYW5hX0lzbGFuZHMuc3Zn'
    b'LnBuZyIKICAgeG1sbnM6aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVz'
    b'cGFjZXMvaW5rc2NhcGUiCiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291'
    b'cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6'
    b'Ly93d3cudzMub3JnLzE5OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8y'
    b'MDAwL3N2ZyIKICAgeG1sbnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAg'
    b'PGRlZnMKICAgICBpZD0iZGVmczE1MTg2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAg'
    b'ICBpZD0ibmFtZWR2aWV3MTUxODQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJv'
    b'cmRlcmNvbG9yPSIjNjY2NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtz'
    b'Y2FwZTpwYWdlc2hhZG93PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBl'
    b'Omdyb3VwbW9kZT0ibGF5ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlk'
    b'PSJnMTUxODgiPgogICAgPGltYWdlCiAgICAgICB3aWR0aD0iMjAwIgogICAgICAgaGVpZ2h0'
    b'PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9'
    b'ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJk'
    b'YXRhOmltYWdlL3BuZztiYXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQU1nQUFBQmtD'
    b'QUlBQUFCTTVPaGNBQUFBQkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJ'
    b'UUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0Qv'
    b'QVArZ3ZhZVRBQUFzCnlrbEVRVlI0MnUyZGQzeGIxZm4vbjd1MDk3UmtlZS90RENkTzRneG5R'
    b'd2dKSTRFUTlyZnNsaksvNWRzQ2hRSnRHUzJ6WlpRQ1lYN1oKa0pCQlFzaDBocDNZOFY2eUpk'
    b'a2F0dmFXN3RVZHZ6K2NzcHBBMm05L2dJM2VmK2tsSFoxN2RPNUh6em5uT2M5OURnSXpOa0dh'
    b'TlA5cAowSFFYcEVrTEswMWFXR25Td2txVEppMnNOR2xocFVrTEswMmF0TERTcElYMVV3SkRr'
    b'UjFyZGVsK1NBdnJQNHhFaEZkTno1eFhxa2gzClJWcFkvekVVRXVLVlpVb0V4VGtjU2ZjR0FP'
    b'RHBMamdUaXJLa3Bia0tpelBTTlJROFpZR1ByaWt1bGdsWXA5ZmhKZFBkbFJiV2FaRkwKZURQ'
    b'SzFJRXcxZGJ2TzJ0ZTVuc1BMeElKTUpLaXIvanQ0VUNFSFBNbE9nWURYeFMrWW1sbVlaMmVm'
    b'R2JiV09NYzI1Z2wzWHMvSVdGSgpoZmpUYzZUL3RUZklzTngzRnRiSStXODh0R0I1dllGaHVh'
    b'dnVPM1RGNmdLUkFBT0FTQ1MwY2FWeDFmejhRREI0eDFQZHU1dkhNUnlXCjFXbCt5d2ZVSDhN'
    b'MXVlWVVsNWJVVDB0WTBTVE5GV1ljazdMUHVJaS9OM3RQcWJ6cjE1VXNxVE0wZDN2SHZMSGw5'
    b'WWFKaGQ2VGQ5WU4KMnNJVFpWUktwVjQyN3ZERWxSTGlwdlAxTjI4b3o5VGc5T1orbG8weGZR'
    b'NmtJV2ZQZm1kYVVqOHRZWEVjM0xScG9IVVo3LzYxV2R1SApvMDV2Y3VMOWhkUDFDNmJwTzgy'
    b'QmdrekpRemRVRXdTeFlvN3hqYTNkTE11aUtBb0FTaWt2RktOT3JuUlFsR0ZvQkVIRUlwRmNC'
    b'QnlXCm9wdEdzTE95a1dZdlpBbXhJRlZmWTlyWjdMZTdZMmxoL1lUbVdIR1MrUnMvNDNheDdN'
    b'aGFZNjlRdU9McDduTVhacjMvOEFJY3h3QmcKKzRHaEpKa2tDQUlBTXRUaVVEaXNWQ2lBY1FK'
    b'bXhCQ0VaamdzY0JhcjNCcU5zUm81N3JlTVN6b1NyTnNQRWd3b2xtTnBicTh0NDVaRgo2eU1S'
    b'cVdqR3BmZnNaOWkwdStHbmhGcEtNSWNIUVpxczBIUGJubHl5WWFrZXcwNzJnRmpFZDdsY0RN'
    b'TUFBTUVUdXQxdUFHQjk1N0pNCnNpSmYwdHBsQjBRV0NBWkVJbkZ3ZXovbGlpWjN0MkN6OVlo'
    b'Q0hMdjFIVHhIWWZqbFFnUkJJdEhJZVkyR1gyNG9IL3I0L0RjZm1qK3oKWFBPVEZSWUd4dk4r'
    b'SWorMXNTN2p4dlY1RWcrRjhPU0VUbG83TDlmdDlSdTBFZ0xIQVdEWUdROTV6Vm1aR1dqaWNW'
    b'OWlKc0lsQ0FJVApDa1RPZ1lUa1dLdTd5U2t3WEpWcUdWY2hPRnFscEhjUEM2NmRrM3F4RXls'
    b'VzRya1pzb1pjSHRJTm1NSG44L040ZktWTVhGdXNyQ3BVCnJsMW8zSFYwYk55WFRBdHJ5bkw3'
    b'eHZLL1hsL05kd1hZUGdjK080dUxVSmhCNHZUUlNDcWdVcW1BSGtpbUZNUG1BWWxZcUVqOVJa'
    b'TW8KN280WVlvTXQvRS9NYlg5NHhMOTdsM3J0T3V5WUYydklTcjY0RXplWnFDT2RtRlNKempH'
    b'QTJjY213NnBadVp6djdCVC9Hb3ZWR3FObApPUWFKV0lnRFFDam9KZmlTYytZYk5RcGhyeVhF'
    b'c2x4YVdGTUVuVXFna1BJaXNkU1RkOVRKaHNZWVh3eGhDUVNBdG5qSkhpK3Jsako0ClVpb1dZ'
    b'OEVWQ0w2cXJTZWdIR3hGbnVoT2J2OWNXRGNidit2R2JTM05RcExNWkdnWlQ0NWZzb0o1dlZ0'
    b'd1Z5UFRPc3ByTEdmSGd4QWwKY2NHSWNMeWJzVnRvdG5CUGI3U3N2TmJ1cHNyekZRQVFDb2ZE'
    b'NFpCWUlsKy9OSGYxZktQVGt6amU1MDhMYXlxd2NtN21aMzlkZnRlVgpWWElKVVYrdEUrVktL'
    b'SHNJMWNtQW9MbHduRk5oY2hFTTBYTHk2QTVKd2RuSDk3YUlYbmxCK3VtMk1iK2ZEQVFTYUdw'
    b'dlQ4ODBqaW5qCldBRUFscFBIeERUQWNWaU5IaElZYzhDRkw4eG13NEV0OTkwV09IcDRhTS9l'
    b'RVZGcDFkbm5kVnZJdWxJeGovb0x4N2c3K3lpKzFDUVcKRUJxRklCd0pHelNDSEQxZnArVDNq'
    b'MFIrQ3BacnlnckxxQlh1L010aWpVS0lva2g1bm1MY241QkY0dkhOUnhBQkQxVXBnYytqdHB4'
    b'UQpicHduUHZJWitjanZtZ1lpa2dBWmJEbXFSamdUeDRrQkRIVzFGUUlSTDA2U09hVlFPeFBQ'
    b'TWFDRk03QktEWFBjQzFJaXRmMHdmbjUxCitNbjdLSnMxQUtBR0VLMjVZT0RwdjJxR0Qyc1VL'
    b'cjVxYTY5enBWUm1jUG01R1dWcUFCaDN1NzFCK3F4NjNjcDZyY05EZGc1RjBzS2EKck13czE1'
    b'dzdWeWFUU2dGQXdNZGM3ckRRRjhZV2wySlp5dmdmTjJQNWVtSkdQdFhiMC9tN1h6b1pSbXkz'
    b'MjByTHRYMDlZZzdFd0NGUwpHVzVDTlEvUGxsejd5bEQxMHBxcjEyTlYwNGQ2MnRzMWRrR0pW'
    b'TnlUNUYxVFB4N0hLamF1TTBnay9NNzJSRzdCamdGTGVkZVJ4TERaCjhzbm0xTHNCUVNSdXpw'
    b'eXpaSmFCaTcyUVlvMjJVWTgzeWpkcGVjRlFpQ0NJUTEzQmVKSUJBSkVBMjNOTjhldnRBV2JL'
    b'R2JFcDZNY1MKOExBYjE1VnFWWHlIdzZsUnEzbXhLeW5CdzlyUExkemFFdnJGRHFRaGw3ZCtG'
    b'cWFTUWI3OHhQVTNKeEVRY1Z3RlRjNnNybEZma2MzRwo2NDhubEFwMXltU1NBZmNhajBDVEpB'
    b'c0FZcm5rUXV0dlJ6dXhoaXpzNDVYdldnTGpDU1FURVltbGwrQ2xzMjdmMTQydkdYUVA5UjZm'
    b'Cnd6SThnR1FrN0pIbHprdjIwUllyS2ovYVk1L2xTeXFxOC9rQVFLVW9sVUxZLy83YUcvNXc5'
    b'SjFkMXI5ZWxxL25VU2w2Q25xOXBxQ3cKTGw2UjkvQXZhbEFVZS8yREpqNi96NmplS0JwOUJz'
    b'bWVOM2J6eTdCdXZ0WVh4a1N5MUJFN0ZrOUJYbjd4bUVNM2Y2RWpzeklsbGVwVQpUeENsUDJk'
    b'UGVGQWtBR0lqZ3R3RkFCTzJoR2JKRU1rV0tHUERRVHdrZDBNUUFVQUFBTWo5V1BrTGV0UWNL'
    b'dEdkYXhCc2VmcnhPUlNKCksxVEQ3ZnZDci81SmpIQ3B3aExoekszYW1YUGtPYU9CK0h5YVlX'
    b'VVNzVkxLZStUcTRsSVRmMzVUeSs1RmM3aXBPT1dhZ2c3U3lueFoKWDI4dmlpTDFkUlg5dytQ'
    b'QlJPbmdPNXpyanB2anltRzlSb21vaEZSYkIrK0NNdFlleUwzMXp2SVR2WnFuWHdpdnVKZ3RL'
    b'VVBsZndaQQoxSEkrZy9CaXNaUGJNZ21TQVlEUHpWdHhqSzNRQkpNcHpCVWVJQWg4UWcySTZ2'
    b'VklsQlFJaFJpT3lxNG9PKy9sbnpXTHBMN3I3cDFuCjd1NUgwQkVPMVF6MkdkOTh6a1FjUVpq'
    b'aGNEaE1zWXE4RjdaNGJXUEVzTzhxUzQvdzRzV2R2ZDRwT1JXWmFzSlN5ZmtPYnhMRnNLSDIK'
    b'WHhRYnpJQmcwVU10amcvZUd3Y3c3ZC9COXU1RkZXSmNrb2xKZVo2RnhlRndoQXZlQ3N5WVNz'
    b'NUxrQnlEendPQXNqeTUzY2Z6K253VApGVGFkR1AvZlR5MTM3M2lxV3VzM0Nvb0JJQnp6aW1S'
    b'R3Rady9VY0ExUHVhUENtcUxWUkI3aFY5OVpjNURqM2FMNWRwN0gxeURnaDVZCmtrUEdGRnF5'
    b'N05MaytKVzZJY2dKVWZ3TEZzWmZPTUo1SWtSTkdUc1dGQXF3OU9UOXg4N2NHdTNPdnl4dHFO'
    b'SFozWWxBQURmSzluSFkKRE40elR6VDV2ZE00bGk4UkRXUVFROWthdlV5b3pubG4yRnVIMEFH'
    b'VFBnQUlwdE9XdDV2akdCZFVLcFFBSU9Eano3eGpHWGJGUHRvegordndIQTd0NlB3MHEyNm9W'
    b'eWYwSDVpSnFXeFpiZjdCRnZQR3NQQUR3K1h3a1NYbWlndEpjT1NJOHorNE1KQVFaWE1KZDBi'
    b'Q1ZuWGM3CjcvQXhlVFFpTy91WE1BQnNJSVRWR3BsT0IwSVFpSUpCQ1FFek1OSStMZi9lTjRZ'
    b'bmpHSmFXRC9XWDRJZ3ovMTYxc3d5clV4TUJLTGcKc0krSG4ydWlUclNCUVJjYkdEQVoxR2ZY'
    b'OFo3a2VkODI3NU1VRHk3UnRjZlF5eENnY2VFOHNhd1NBUGc4Zk1kaFQ0Rkp3TERZWGMrMApQ'
    b'dlB1d0NjSDdBZmF4cE1rbzJsNHU5b3cxbnRvTlNOM3FyV3VqMStmZWJRekVZdlRCU2F4TjB5'
    b'L3Z6K3dZVVVlanFFa1NmcjhQbGVBClA3MlU4STBkSWpYbkMrVGxRRXF3MWF2eEpibjBZUnVX'
    b'cFFFcEwvbjZYdjdpR3VEenVKV1Z0YVVaSTJPSlk3Mis5RkQ0NDBXcjRsZmwKbmx5TFRDdFI4'
    b'U2pld0xFVy81N1BqQjN0WlhmZDdYNzRZeUpmT1BIcForWnVqL0RsaW55Rkt5SWQ5M2dtcGxN'
    b'OVE2RmJIejlSdldGbgovcG9QL3Y3UjRKZGpxOG1NQ01POHVIcWdjdzR0ZHlsWVlUU3NUQ1Rw'
    b'UDd6U1dYckI1dWtiZHp6N2JuOXJuNC9sdUdnc2JoNFROdFRxCk1vd1ZJZmFtSWM4d3M2eVMr'
    b'UGtOZ0NGMDB3aG5EYkJqRVM1QkNTOXJwSGExQTRJWmRJcGdLTGlpM3BBZUNuKzhTSVI0UllG'
    b'aXhTeTUKU0pEQ1l2OGRJdXZKdi81eDBHWnI1R2d1RkRUa0dBV0xsbXRFMUxiQlRnQUlKVEdq'
    b'YUtRdTYreENrL1RZQUxscG0rMnRIZFpIWHVzTwpSYWx3TEJWUDBnREE1Mk8zWHB4MzNma0Zi'
    b'dDNmOHhRV2Q4ZDFzMHBNTnZHdUN3dVhWZWpxKzZ3eGltWVpsdU00aU1icER6NGZPZERtClB0'
    b'd1Z1R2w5bVVpQXAxSXAyNmpkbjhKdTN2djdkYWxwS01ibi9CRjhSUmxyZFNKaER0WElBT01K'
    b'cXdWaWpjN3BkUG1pUkNTZUdod0oKcDkwTlB6b1FCUDU0ODR4cjFoWWQ3WFJHKyszVGkwb0Q5'
    b'dmM4blIxVkhBTW9tdmpaalZsWEhGQXBYRFdCQy9NMXI0NkhrUmlKZmpDNApmNFp5ZjJWMjNa'
    b'QTkrdWlyM1FDZ2ttSjNic3pQTjhrWUpvVnc5S0paUmVVRnFqZ1ZmUHhaeTBXMWE2NjU4bGVi'
    b'ZTk0YzNKbTRmTkhsCnVlZFB1Mkc5MytJTVJXTFU4KzhON2p2aEQwYW83VTBPQWtjd0ZLMHJW'
    b'd2w1WU5RYUcyclp0dTNtVi9KK2YySEpJNHFDWElTaFdaVVMKWW5TS0RPdk8yc0pYclkzRll0'
    b'RllWQ1FRYjdwLzNnMi9QL0x1Ymx0YVdEOHVjZ3lTbjYzSjV4Rm9pc0cxTXNuT2wrbU0xa05F'
    b'NDlMSwpNYWVqNFFKQlF4VW5YUTZwRTNNcjE4L3VNWDQ2NktneEpZOVloSzlpTHg1K01ISml3'
    b'Ry9TQ25JejBIUHE4UFZubTRSQ1FVOXZieXdlCjk3dVpaT2IwVC9yZk5rbVQ1MWZmQXdBblhK'
    b'MEdNZVFvYXdDZ29rQlZVYUFDZ0ZYejgvN3kybWZIZWlNZk5KRXBtbnZ4bzhFWFA0TFMKWFBu'
    b'N2p5eWt5VENLc0wzQkpnOHo4cWZPKzIrcmVVYmtjTGQ4OWtRSytMWDMvU0pxUnl6RG54ano2'
    b'eW9LRkJ3ZDNiQXliNG9KYTVMTgpzV2FVS3U1YWxyRitybjVablJZQXhFSU1BREsxb25nOEJn'
    b'QUxwdXNIeDBYeVVkdm9rY01GV3o3ZzZ1cXJMNnYyeHNRRFZoRWlYQThBCjgvS3FhUmJKdzNS'
    b'Q2d1Mm0yZ2FkSTZ2bTZwcGZYZjdyRGRLeUhMeXp1NnY1MkxGb0xNYmo4U3JMeWdVQ1FmTkk4'
    b'N2xsSzlYaUxBREEKVWF4SW00TWdYL2FZM2VIbzZteXR5R0lMVldQSVY1NG03TE9HR3EvYmRl'
    b'TWZ6QVRHRWdnMXM2RE9IKzg3ZDh2bC9rRDNyUDRldzBDNwo3YWIvOXJxY2pVdVcwWWhJSThm'
    b'ajhSaVBOOVdjRHBOTVdGU0t1ZVM4Z2orVjhqY3R6MnA2YUZyUDlVVTNyODIxdWFLaFNDd2Fq'
    b'VUp5CjUvSjZyWHJmWGd1QzRsSjV0TEFZajE2dmxwZ1JYRHcwUEV4UkZKWlM4RER1ZU5QTUty'
    b'bG95TXZMS3JCU0taWkFHZTdyem0rTzR3QkIKQUNERmV1YmxiWmg0YzFIZUFvWGd5NGhRZjhB'
    b'L1lCNzArcndBa0lxT2lYaXByOWJnRGlUMnRib2xCR0FvRncwbFRUSVptYUlLcnMvawpWVlhu'
    b'SVdqMlJaY1VaR2Z2M045Zm9QV2dLSklreVdDWTNMQXlUeUlrMHBQM0h3WjNnSHJsTTJkY0pa'
    b'elozYTR0S2NTeVJYTUZlTkVjClE5dGdYRXI0Y1AvT2xQY05jeHVHaFVJbGovN1ZyQ3dqZU5P'
    b'S2N1UU92ODRUeGxwNi9NL3QraGhSamdaN1ppZDllbEpqTm1JeWh5WDMKeml0bmFEVWF1OTMr'
    b'aGJnWWhyR05qTkFNWTQ3c1BLLzZkZ3pGQWNBb3l4NlA5RlFaR2dIQTYvTWVQbnFVSkVrQWlF'
    b'V2puMjdiNnFMTApTUHByODRvRXlXVFhIRGJKZ3huWWRiYkkzcEdJLzRacHJFdDBmbkxSV3Nk'
    b'cnp4bytlRmUrZUdaQnpoMlc4UWJBbEZxMTlKbzFCUXdICmU0K1BweTNXRDBPQ1pKN1o2Ym9x'
    b'bGNYRWcweUhneDIyTjlMVU9nTWVaOVMrdmNxdWl6OUhHR2IxcTIrcTUwVjBTanhNRnRoYzZy'
    b'STgKeVlMcGVsK0lvdmxqR1JMVzQ5STVyTm5acWhUSG90TkxaUmlLcUpSS25lNmIrVHlHaG9m'
    b'S2xOTUpUQUFBd1dBUVE0bFMzbGxqNCtPSgpST0xJMGFNc2UzTG4rRWpUUVkvWGMzTHI4QnRy'
    b'VlJZRmdHeTlPRStiSytPbmhuMjNEUnZxU3hjd09WNjNOeFJVUG5DUGZjZkZnQXF0CmJyWWlY'
    b'MEhUOUxYblppbGwvTFN3ZmtnT2R3V1NVaEZlbTRzdktXT2RJU1JibXR0bkZ5cDFIZzRoK251'
    b'Y2I3M09NWUZ5MWEwcEVKckgKOEwzSDdQYzhlK0srRjA1d01nOC9uTWt3V0NJaHpKSXgwWWlN'
    b'cEU3cUl4YUwvL05WaklJWlhwOHZFQXpjYys4OUI1dWE3RGJ2c2RiagozYjA5N0ZlR3ppVXJW'
    b'aFpYTnNTU3B4akZ4Q2tSUlFydmY2RW5Ha1hWSXRyaWxhK2MyWXNLdG1Ncnpna0F3bEEwb3ky'
    b'emVVWDFWVm9BCkNBU0RDWXErNjRwS3JYSXFhR3V5cmdveEZEeHFzWEI0aEl0eHFGR1orclFO'
    b'Y2VIQ2kydEdDVjVWZG1IcVo3ZU1lQ0UzYTAydFNnNEEKN2tEeTZ0OGRqNUJCWEJnZE9ib0FB'
    b'SUJETWhXcHp5M1pqQ1RHc0J5R0lnS2hJQkw5WnZ4ZHlJRzF1SS9STkQwNk12cldXMit0T0dz'
    b'bAp5N0pPbCt0cm8vUDRtTTNIWjA3MUYwMkUxWW1ZNS8xdFEzMHhiK1ZNWk5XOFRLRGpGdGUx'
    b'MUJKM3l1VnVGdUN6ZjNONzVrWFhTMnZuCnM1VEk3VWs1dytvN0x5OFhDL0dmUDNJMGJiRitH'
    b'RFFLWGxiVENLckw0S3dKTkZ1T3p5N0hseGF3WHY2aURSc0xuN3JXSHVERkVyUXYKZUhJUFRp'
    b'UG55OFNFS2RmS1E5R2gzbUlBSUhoVXdLMFBlRlY5STdHRHJRNEFrRW9rcDd4UUtwVnlPQnlO'
    b'aXhjbjRxY3dhY05tODdNdgp2dGNUS2p2bGR5TWhkU0ltQVlCVWlxL2dhd0hBRjFhSFk5aW9x'
    b'a3J4eTF2WWdmN1dSRUwweXVPSkE0LzNtcU1LbFZHdkZ2cjhQcDFLCmtCNEtmekFjbm1SN2RT'
    b'YkgwTVRGRmN6Uk1lcTFBNXdVNDJJaGZlRUtVTzVmWExremtKUU9PZUkrbnk4VWp0N3h4TEZl'
    b'YTBoc3RISGUKckZTS0FBQ04zdE84dHdFQVdCYmUzREVZRG9lQmcrcktxbE5lNjBScjIvcDE2'
    b'd29LQzczZXI0VzRSTUxoRDk5N20rWHBveVR2ZE1KSwpKaVVUQmxLRTVBeGJMR051bnlPc21s'
    b'LzhRVGh3ckdyRzNFT0E5M0hnL3U5akVudW9iNFFxeXhFbUV1Uys0Mk5wWWYxZy9PYnE2cndz'
    b'CkhacXRpRzN2eFJ0TnhNSWFoRVVRb1FpUmlnTWp0N0RZdklaYVhWR09ybmVVK2VPci9ZKy8y'
    b'UXNBRXFVL2FDdWErSG95SWV6dk9tbG0KWHR3OCtwdW5Ed3hiTFlQbXdWUDdPQ2pTWURCc3ZP'
    b'U1NFNjF0WDd6cGNqaWVlL3JKZ04rUDh5U25hMlRRbHhHUEtnQUFFRzVvS00vcQpGY1JaNWRu'
    b'elRFSnVleWltODg5ZXRaS2wzUWcydkdCRkcwWE95WG5ST21McnNuR1huVk5RbUNWTEMrc0hR'
    b'Q3dnZnI2K3NEeGY3aUJSClVhSEIwVDdBSlVqV0VXSGJBMEFBZzNDaG1Bb0FsREplUTYzdW5J'
    b'YXNpVytabE1td1h6bnhPdUJWQVhkeUhjZXk4UEkyOTV0YnVrTGgKVTJ6WWViM2VzdEl5QU1q'
    b'TnpZMThwWUJBSkZJb2xSeUNoaURuZE8yTUJEVkJUd1lBWUNqamQxVXZyalBVbFdzQW9OZnpt'
    b'RlNWbFZkVAp4Tjk0aFdUSjh2aVJwanI3cCtPeFpWYVBjRmFsdGp5SHYyWmhWbHBZUDRUSGdh'
    b'TDdodDBjeDlVVWE4WjZEd2EzdkVsMmZZS1E0NndvCml1cEZyTm96Nm83YlJrY2NUbWN3Rkg3'
    b'dWc0R1RzeVZTbUtKT1BXYkZTT3lqTnQzRHIvUU1XNzQ1RExVZU8zN1JSUmROdk03SnpRa0YK'
    b'UXdBdzduSzk5UHhmYlZZTG9WOWdEdWhQMTA2T1EreldNZ0NJaGxWTnpVU2ZOV1IzT0hyNysw'
    b'UmlwVXpCR2ZJT3BoWXU0ZHJha0lBbgo4ZlNXa1dQSkpUTkJMZWQ3ZmI1WWdrNDdTSDhBT0E2'
    b'TVduR2VqbExMSE1UK3Q2M2I5NFI3MjlYWmpYaFpFU1FvbFdrN3dpdTB1cVdSCkpIclpmVWUy'
    b'TnprbXZpVVV4OG1rSUJSUW5ySk9oa09kRWZuUWFGRE11YkpOWC9xME90czdMci84OHBQZUI2'
    b'UHg1WmRmQ3ZpOUg3MzMKVGlRU3gwMHJlOExUYWZiYmRtTW9VZ2dBOGFnOEh1ZDUvS1FoUThX'
    b'QUpKRkM2MHVIaGh6NS9xUytMdTc2YkdDQXo3SVZ0cjJpV1VoUwpOQzBjaVc4KzVPMGREcVhk'
    b'RGQ4M3kyWWJmM0Z4UlpkNWpLUlFVNkVDQndBRVJWZFU4YktROGFBZ0hMaWdNTDhnTXdNREFH'
    b'L2d5OFNOCkhjMHpNa3pma2IvSzdGTy8xZVQvL1BBV05IRDByRldyeFZKcGRuYjJGNThXRnhl'
    b'UFdLM3R4NXRaWEJIWGI3RDRNczdVeE1aa0FQRE8KWjlhWjVlbzdMNi9nT0c1a3RNb1hwWXB6'
    b'NWVqY2hyTStmcjhaeGZSWnhRTEZwYTdSRVh0UTl1eXZabllOQnZ0dDRiU3d2bGN5MUVJKwpU'
    b'bFlVR2pvRzNMVCtmSm51cUNzanh3Wk1acmdqUnhYYzE3ZFNLSFRLSk5MRFBiR1JzUzlUVmRF'
    b'MGJyZG1mMmZsV2pudnYxWk9Ed2F5CngxeXVsdVBIbm43cW1hOStXbDFUMjlmZEVVL0VFZmZy'
    b'MmJyL0dna3AvNldXZjdSdjVQS3pqVDdQV0RRbHpGVHN5aENNOWRMbDZNOXUKWDdWNlJSQ1Ew'
    b'ZEI0S0psWlZTaWpFZ0dOUWppcGhUVXBoOEpvbkY3ZElETm9wTGxpenZYdU5yVllvTkVxK0Zx'
    b'VEF5bEJzY0xwRmRtOQpObXJNejl6MDhCRlA0RjlPTmR0UXdWMjFmc0d5cGNzeGdyRFpScTYr'
    b'NnFxdmZtb3ltY3hEd3hkZGNpbXc5SGlZNzQ0ci9xWEtSOGZqCldYcTVYS0hPME1va29yd2ha'
    b'MzVJWG14U21rQW93ZzQ3RC9JdHg0T2JaWGpDNjFVKzhaYVptc3pQRzA1S2l6WHNpUHptdVpF'
    b'SHJpWU4KU3FsNit5dFVLT0pCb09TY05SbWxPYzFkTG45a3FNU2szTjhlSHhxSi9odVZHM1Nx'
    b'NHNJaURNT0tDNHR5Yzc2NTRxdXVyaWFwbEVncwp6c3pLNWxuL25jeDlYY1BCaTFka3M2bUkw'
    b'OHVHVW9veUdaczY2dUVzWHNZN3ZreGVOTXY4MnZQSG03Sm9BMDlSRG9uY3RNWDZ2dW16Cmhj'
    b'MHVEczNhRkczdUlvUEFJZ2kxL2pxcG5LZ3VNUUlxTkR2SVh6M2Q2dklsL28yYUYxYnpNOVdn'
    b'MCtvMmJkcTBkdTFhclZiN2pRS0gKRGgvV2FMV0FRRWZmbURQK0wwZXN0L2I1R1FiUmF4VjZq'
    b'YXhVL1ZxOExSUFJpYkZTSFNhWDQ3WDZXazNwMzd1MnU1Z0Fvck9aMU42RQozOERRdkxURits'
    b'N3hZUisvT2JCbm1rQndEc1FkU3JWU1lSZ2RqNlZTWXpLeE9GTW5kTGpqcDFwUDBzTGdUcE9L'
    b'd2ZEVDNxMytZOWpqCmc0UldvN1haYkxmZGR0cy9GMWgzNFlYMzMzKy9ScXZCNCs1U3d2TXRM'
    b'WXhGSTZOa0NjaSs2ZEF2ekpMV1Y2cG9oaG0xbnlzSys2bUIKWGxTcTVDMnJvazg0cDlIeWs4'
    b'NFJqckVvQjNObUI0SmRDME0rUTFwWTN4TXlaYkJxMGU3WGowc0hxcGpwR2JNS2RJWnlGVE9T'
    b'VUF3Ngo0K2JSOFdmZTdmTUdUNVZIRDhFVHNrYU8rK3gzZDF5ODdvTFYvOTZsNitycVB2bmtr'
    b'Mjh2UTlQMHJiLzYzZHVmdWY1WlZRRHd3WjZSCmMrckZpV1J5MUMrb0xGTHlWZE01Q1pwNGNL'
    b'dm93VFhiT3p1MHJNaUR4a3M1bVp0RWJIeHZVYzNlMklFTDZOUWtzMXVUZFNoc1hMV3oKTXg2'
    b'bUE4aWJ1d0laQXhaK1QyZWdZV2x1Z2JFd1d6R3RWUFhCNXlORDl0T2tDa0lKUDVSOHZxK3A2'
    b'OWlucTFZdXhyRC9mRXl3MVdvNwpaOTMxVzdxeUlrVGxLUXRFWXFrRk0zSUJGemZVNmhPQklD'
    b'ZkF1STV4ZkhrMXBLaUNJTGZkMmVOQ0EwS081MjllclplSGZFSy9qaFdGCkFwUHMrS2RKNlhu'
    b'bjhjbk1zdTRCRHkvR1FLSzZLSVFnWVVBR25FelBvTjNwY25ZTytPVWlkUGN6RFgrNlpjWkVV'
    b'UHlwaHRFWmI3WVkKNXl6WjBEOHcrSjl0MjB1Yi9uZlIybHNQQjVhbmlNelRsWW5FYVQ0UG5W'
    b'MnBRVkhFaGlsU0NoR1Nxd05mbkRINzhDTGpnN1dYcUZtaApGMG5LbGU1Z2Q0TUVjSUkzK2JL'
    b'WVRrcGhGVlgwOTNrdzRBQ1hRV0w2NGhSd0NJYXRXbElXaUxIL3U5TzU5YURscXFWMDFOZXpZ'
    b'YWw2Ci9iSzgwMVhDRUJtdDhWVXJOdHozekxNdi8wZGFsVWdrTHZ2WjdiZi91ZG1HcndYMDIw'
    b'YXU4eHV6RlZKaTg1NkJ0M1phTXRTQ09QQ0IKamJFaFAxNnFwM1ozNUF1MUdsb2FRMG1KeWgy'
    b'THlWVTRGd21wMDhMNlBzak1IVEY3ZVZvK2JlTFl5aFVYRHkrOVNIWFpWZHp4bG1rbAoycm9x'
    b'NDltelJaWnhCQUFzVnN2aW1kODY3VVZ3RzdMaTdyK1pMN2praG1nMCtuOXBVdHVKempsTExu'
    b'bXpKVE5JMUg1bjRRdVc1UERCClk3R2ExeTNKRGNkU29TUmdGVGtjeFhBNHgxdFNMY3N6bE1x'
    b'TEVBUTRJZzRjb2hFbC9CNVQydDN3ZlRDbjhXQlhNRFczUUlrSzhVS3oKWHJUdFZjM1JnOVNJ'
    b'MHpadGxVNGw0dWh3S01IbklSR0JRSUFMTlF6RG51N0lyZ2xJUk5NN0pudi90VDlYbFdibDVt'
    b'VC9xNDNoT082MwpELzc1emo5OGFHWlhjcGo0VEw2eXVNNmdseVZTeVdEckVPTUowbWZOemVU'
    b'eGlSaERJZ21PZGZtQVN5bWtrdDMyVmdrcjlEdUs5Q2J6CjZHQnQybUo5SHlUUVpMNktyeGFw'
    b'TldLcGRsYWozbWdjQWl3NWFxOHBVaFZueThRaWtWd3NBQUNqd1JpUGhWLzY3ZHpyTHlqNWpo'
    b'b0oKK1FDc3ZlVFcxMjY3ODk0dm5wSTRFN3hlNzdMVmx6LzJYdGlKTHdIa2pEcnpxVHRuS2NS'
    b'SVptWVduMEFrUXRTa0V3RUFUOERMYXFnYQpVY3BUbjdYVGg0ZW5qU21WR0FJb2l5QnMySk01'
    b'R2UvUnBCUVd5YWF5SkJveElSRHorUDR3cGI3dytoQWdQRDRSaWxJQUlCS0pFeWxHCnJWSTVB'
    b'M2pVUHh6d3U4OWJkQ2JoVFlnTG1idjFCTy9LSzYrTW55b0srWjg1Y0dELzB0Vlg3M2JNVFJB'
    b'Rlo5ank4eFpsWDN0ZW9SSzMKN1R6c0tDOHRvMU9NVVNzNjB1bUpKK2xkUjEyakhscjNwOHVK'
    b'ODJaSkZoZnpFRDdIQVlKeVRsdnBaTHhIazlLUGhlQTBHWmJxY3hXQgpaRVFreEl2V3JmS2t1'
    b'UHcxODV1czBXTnQ1dEQ0aURmT21PYk03T25wMEVoWkZFV2p5VFBkTVJTckN4RFVMQkNjVWRS'
    b'NU1CaEtJRG80CnMrRnZndklDZVNJUlRTWVRCRDB5NktwbzI3MUZoaTJsQmJvUDkwWVZVbDZH'
    b'V2lnU0NsbUYyTnR1NVNPOEJsVm0xVFRkQnkxNDJtSjkKWDBOaGdtKzNjVTFOak1zWG4xZWpF'
    b'L0F3cUp5TktsWHpwK25HKzVwOU94OWlMRTI5dlowYUthTlJhekNlNGtpblorRU1QWVorOTZH'
    b'NgpVajZyVkNnbXp2MzZUbGF1WEtuRTNXZmEwU2o4K3FxcWZLTW9FTVBsTXBtUUIrM05oM0o5'
    b'Ny92ZnVVekNSemF1ekNzMFNTMk9LQUJJCmpLcE5veGlaWkRPaytqL0tYQi9jbEY5b0VxYUY5'
    b'WDFBeGFRc0pUVDNLYnl4YUtjNXNPdW9xOThhQWdDU1lqb2RiSmJRVXhKNk4rSVoKazh0a2xa'
    b'VTF1dzZaMTgyRG5jOHN2dVdTc3UrdU90cTNhdFdxTTJ3R1FSQW1neHk0TThySDk4RDEwKzY4'
    b'TkQ5RFlHbHE2Y2tycWxISQo1U0p2UzduWVlvdG5kQTJPc1N4WGtpTmpnYlc1WWc1My9PUDlk'
    b'aEV2OWVvUlpvOHFKMHVKNzloZ2ZITFZKRHZ2YVZLYVdUS2dwV25jClpjdXFta1V1dW5abjZ4'
    b'dG5WeFVxRG5WNEl2R1VYTVpYUktJRVNsdVBOMis4ZE4wbis2eGl6dW9hQXo2Zi84ZGZ6Tmg4'
    b'd0Q3NHJVRk8KUE1yUzJQamJNMi9KeGV2V2JybXZqUklVZjNzeG1aaG9uSm5oY3Jsb21wYmg3'
    b'bjFIMkZRb1RqaWJRQUo4WFo1ZU5QYmFObk9CU1g1TwpROWEySnNldGYycnhoOGtsWmZGV3Er'
    b'azZ5eGpBbUVuTDk0VlRhWXYxLzUyeHdWSUJ3U1RqUWo0allwSGsvalozaGxvNHQxcUxJYWts'
    b'CmplVXQ5RUlBeUdPT1AvV25UV0p1YUNJUERKMmlNUlQ1M1hVMTlaWGEwM3NPbUV5OURNZFA4'
    b'V2ZyN095TVJFNnhSM1RPT2F1eXhkOXgKQ0hSOXBmYkEzMVpTS1ZhcFVKeWNJNUt1Vk10VERJ'
    b'dXdIR0tzV3lNU29DS2NhcWpWYVJUODBmR1lQMHdDd0tpNWl1Tk8zaDI3aDB5UQpreXcyYTNJ'
    b'RytvVmsrZ3p2dU1QSXh3QkgwRWhZS2hmU0hmMnVjWmQxVmszaGtRR1NkQS9uQ3NkRWtSNlBx'
    b'RnF1RU9NNFBxMm1kbmVMCmM4a3NZMm1lWXNjaEI1K0gvWE5LV1Y1eTRMYzNOWmFVbEh6RFRm'
    b'WFlZNDl0M2JidDdiZmZ6czNOemN6ODJ1SWZ4L0h0MjNlWVE5bW4Kek4wZzVPTXlNZkhrSFhV'
    b'U3pHVWVDVlNYNTZkU2lWQTRZajE2WUZwcXF6MnBjZURWMHByemFrb05GdHZRaWNHZzJlWTcx'
    b'Qkh1TUFjQQpJQnBXTS9Ra1RqNHpTUittUUdOUkNVWHkvZU1aUEQ1bGQrSlhuVnVVcjJmenM5'
    b'U0REazRoSTFzSGtqWDhFM0k4Y3RTTTZZb3FGemJNCjZSNk9qbGg3OUVwQlhwWnU0WFRObzdm'
    b'VURZNUdlb2EvNWpndEZoMS83S0hidjdvdDdmRjQ3cnp6enR5OHZCbDFNNnRyYXJaczNuTDQK'
    b'OE9HRkN4Y2lYMG1IeGFiaVcvZWFXZnliTWNvM3JpdDUvdGYxNjVaazU1dWs3akVibC9LMUR5'
    b'VXJ5MHBhRHg1QitqL0s0UHY1R0oyYQorVCtBeE5UYW5Ob3lnMUxNRk9kcVB0dy8zbWNOQThD'
    b'a1ZoVk0zdWdHaXB6SW5JRWs0cUlFeVd6ZWJ5L09NNFNpbEh0c3BMelFFT2ZsCmNpT2ZTN0FF'
    b'U2JGQmI5aktGQVM5WnBXRXpkRHIyZ2JEVkxpdk1DOTdab1YyNXhHbkwvU0ZKNEtiWHpCK3lV'
    b'VnJ2N2pFN3QyN24zLysKK1FjZWVJQW5GRVNqVVFSQjh2THpFNG5FMDA4L1BYZk9IS2xVT2xH'
    b'c3FERC9qZGRmRGNDWHJxeWNEUEg4YVJsUDNGN0hrUjdMVUhzZwpJVEZvZVA1QWdJK0dQOXZa'
    b'a2pQNGFEVEYwL01ESFpKMWhtbEw1MVpuSERyZTVmU2hKQ2Q3WjYvMWpXMmpORE1WVHFxWUlz'
    b'bHRFeVRqCkRWRlhyQ3FvS2RFS3BicmhFZHRvUXErSWR0QWNYb2syOXpzcFpYYWVWQ3pNeVMw'
    b'NTNOSWw0WkVxcFNyTG9Lb3RWV0VvMnRybkJ3QTgKWWI3NzJybFZsZVVBUU5QMG80OCtHZ3FG'
    b'N3IzMzNzN3U3dkh4TDNOV3FWU3Fnc0tDcDU5K2lpQ0lpVUdUSUloUFB2bGtPSklEZ0Npawp2'
    b'S0pzNmY2L3JWUUtFek1yTTlzNjJpbUtzcmtTaStaVWpZeU9EUFk1czRjZTEySGpycVFxeXN1'
    b'VTFGMUFVUW1Kd3RSWVgyelNDV0lwCjVvRVRONFVHeXhnR1R3dnJ4MEtoU1R5N1F1NFB4T3pq'
    b'd2NFaFM0YWNPbWZObXBkM2pNMFhId2FBVk1SdmM4WnI1cCs3ODlDQVNSbEYKRUtTMHVLVERI'
    b'TkRKdVl0WEZyTU10WHBCcm5kb3g4UDMzMElRaE5WcS9kV3ZmblhwcFpldVhyMjZzNnZMNFhU'
    b'OHM1ZWhzcXJxME9GRAoyN1p1YTJ4c3hEQXNGZ2tlNzNHLzlPQlpqOTB5M2FnbXFncWwvZjN0'
    b'Q1ZZbHhNbElKQ0xtVXowMkxqdzI2bXQ2dFVKa0JnQUhwWXRVCi9IekpvdXBFekRmcWROdkc2'
    b'SFpyNHFtUGR6ckZSL0sxeVRGTC9oUzRJMU1oei92dkxzbmZlMW5PM1d5a3FrUTdwMUplbUVs'
    b'TXE2bGwKRUVGZS9kSk9iaTRBeEJoaEEvdFIwL04zSUpGaEFNalB5eE1LUmNjNkJ0bFVsR1k0'
    b'bzlTL2NabHFWcWxjSkJLOTlkWmJEeno0d0pOUApQbGxWVlFVQXNjUnA5M2JtenB0WFhGcHk2'
    b'YVdYOXZmM1g3cmgvRG5aam5WTDg0Yk5YUUd2alFPK1dpN3E2VGRuWitWakdNWXdyTG5wClEy'
    b'WHpyMlZvR0FCSWpxQ0x6ek9ZbEVLcHFiU2twQ1JYdGJRK3k4MVl6SGJ2YkIwaHpocUFLY0hr'
    b'dGxoaUlYYlB1YWFyREF3cUVpSW0KQ2VvTjJsQjFRMTNGZUpEOTdNRHhYQjBqTDVobkdSaEtV'
    b'WlJCNE05QWJOYmhzU1EvYS9sWksxN2QzS0VWdUNzcnlyZnNHOVFJZ3dNRApBeXFsNHZYWFhv'
    b'c25FemZmZlBNWEQxQ01qdHJqcDllV1ZDYXJxS3g0N05GSFF1R0UzenUyZHMwcXU4T0JzUkd6'
    b'Q3lrdjBvYjkxajRICmthRVVISHovbmNiVVMwSTBHYVdGQUhCVWNlUGN4Yk5SU1BUYlU5TXFp'
    b'NHJ5YzFwNkEvYzIvVUdKMGdtdklhKzhyK2ZRUEk1RDBzTDYKd1NCd3BPbS9NdWRyaEFpQ1lJ'
    b'U1lDOUxDZURBakZ2L1FtdkNQOTZyRkpJSWdDeHJxandXeW8yT1dITndDQUg1U1hCcjU2UFdk'
    b'TGtJcQpySjlaMVdWSnh2eERBaDdzM2YzNW9lWVRTNWMxenBnK295Qy93RFl5b2xhcEFNQnFz'
    b'eVdUeWRNdlRqbno0QUNDQUlVbzkzNzJrZHBZCk9iTzJ4TzZ3dS8yUnNwTFNjTWpmMTNLUVBQ'
    b'aG5mbnhVenc4QWdKZ2c5d3F2TDVuVFdKS244UWNDQWpUUzN1OStlWnY3aGM5ZjRtY2YKRlZL'
    b'SzBZSGloZ1hIV3ZiUFk1aEpuMFI1RXM4VCtRUW1rL0lCMkFqQmQ0UmpVaEVFVFRsbFE2NU1F'
    b'VHQ3MFd5djE2MVNLcU1rTGhhRApmT0dGcmEzaTZha3RMQWM0d2pTeXIvVTJIZnBiMzVxOGlu'
    b'S1RIdWZ6K1hQbXpzdVpVYWhTdVJtV09kN2FXbFJZZVBKdmgzL2JEVVlRCnBMdTcwK1Z3WFhQ'
    b'Yk5iKzRadDBIMjQreWlLZ2dQNThiR3Y3N3BrOFEyNzc1OEQ2S3NwMlF6d0hpcGRYUjZYYzNH'
    b'QlhPWUloaURlVWwKcGVGSXhJaEo3M3p1dUVnaktwTFFVWm9YOUN2SmhJQWllVEQ1bWNUQzJy'
    b'akVhS1o1KzIzUmh6OGNZdjl4OUcxNW52VGhldnJoNk5FYwpWYUZKd2h0M3RXZklhUVFSbDEz'
    b'NXdONjNNckRnd1lsaUplSmh4dmVoc0htN3piaTRkdWtGc3F4U0daT0F1RHNjRGsrNFBVLzJ6'
    b'bmM5CmFuSGVCZXQvOHovMzZOUXlnOEZ3MDlWcjM5NDVMSXJiUnc5dG5oMzd4Qncxb1ZJV0FJ'
    b'cEU5ajNSQmFuOEZYZGVkTzcrZy9zemxYVFQKOFg2NVVwK2lzYzBITEo0Z21TRVI1Q2pwbHJD'
    b'Q29iR2h2cUtwTWNlYXhNTGF0TlArdDIwYysvWFRsSHNza2RXV1NQbGxUd21qeUdPegp0a3NO'
    b'V0RRR21jYk1jQW9yYTVnMzFKZHR0bjFZeUxVaUNIQWNGT0M5NE80ZCtQdFdOR2VoU3pLbnN1'
    b'Umt0QXpEbkhUSzgzbmZsbWZXCjR4NXZPMzZNNFRDSlZMSnIxNUhBNEJIYmlhWlp4TjVxaFB2'
    b'Q0R4OW5oRjJLRFhrTnMrTU1uMFA1QW9FZ21VeG1xVk04TVV5VGlXSUQKK0VjQUJFR3B4ZlRv'
    b'Y0s1QWxHamUxNUFXMWc5TWtqcnQ5aG5MSVZKRzZnNVNGelF1Q0lWQ1NxWHkzVTk3QkFnVWxt'
    b'VUZNNiszdU8yZQpZKytYL1dPUFQ0WDUxZTVOWWYrWXNQYnFSQ0lCQUFSeHNsdjRndTlJWUx4'
    b'L3orY1lncjc4MEIzbnk3Wm5BSXVCQWtWT0NqM0ZZU2ZRCjVYVEpoYk9tYVlPaGtKam1UdlNP'
    b'ejV3K282Ky9UeTVYRER2d1ZNY29ZWkFCZ0ZMckgrNHJDbmhWTUlXWWdrZjNBb0NZQUNRcGZm'
    b'UG8KVzUrMmpFWXAvb2Q3UjVEa3laTnFjck4xU3kvNUdUWDlobUg5WlZZcUJ3QndsT1VBZ0JC'
    b'VWxKVWhDS0pVS0ZTcWswL0ZmSHNvcVVnawpCZ0NFWTZOSkNvVUpsWE1Ba0dMeFRtSjVyR2hk'
    b'MXRJTnhWVlZHSVlEQUE5SEJvZXMvaWcrZTFiOXNGdFlIUFNpVXRHeFhqOEFaT1haCjlteGRQ'
    b'c1Z1QVQ0bGhTV2lKUVRCV0dPSGJ0ei9UdUR1cTg2cXEvNzl0V1c5L1gwOEhxKzZzbkovcTZP'
    b'eVdBSXdoMkVYdFhRTXBHejcKWjNMN1JLWmFvOEZvSGg0dUxTbEIvN0VWNlBjSFRyc2taTm11'
    b'am5heFJCS0xSZ1BVeWFtWWg5WTZsR2RoUmVjc25KY3pQRHdFQUNSRgphWXhxbjk4SEFHWFoy'
    b'T092dDUwelRWZVRTcUFKaXROTDIwWVRQRDdWMlRMTjU5YW1oVFVKaUZ1cThtWTFqd2VOUWg3'
    b'cm9mSFBqNDA3Ckx5bzllOFZLQkVGQ1VjcnBzQm1WQUFBbFJTWk1rczFVNTFnODY1VEcwb21G'
    b'bm9EL1pWd3lRUkJ3bXNRaU5FTnYyL0l4UVJBQUVDRlIKcy82cUVNK29NR1ViRlh5aHV0S2dG'
    b'MDBJaTRxNUhQNjhxdklLS3BWcTZxWldWS05WbzZOY1BJblZGaDdzY0IvdkN3THdSb1p6cDk0'
    b'dAptRkpuUW4rQjM2MmJQZi9vUVBNY0pHTm8vc3pCOXBiU0R6OTM5VmxEKzFyZHU1ckhMbDZX'
    b'NFE4RVpGSlpiWFgxZ2VaK21ZQTBabVlvCjFZYXNET25JeUloQUlKVExaQk9QR2ZiMDlaNTJE'
    b'b0dpWXk2WFdDSW1TVEpDQ3g5KzVsbUJoT0JZRWdCaUtjSE1xaHhBZ0NDSWFWV2wKZjlnMFpI'
    b'V25qdlVuSG5xcHI3RktudXYzNGlYNWlBemZ1TWtTaUtSZ2lqSTFoY1hRK0xqRHFNM3dSTTIx'
    b'bGJPTzZUSjhKNDRWbnhnSQpIT24wRE5rakRUUHlWaTJlbnBlYnUrT1FVOEE1VVlTTnNacEZz'
    b'L0l4REtGU1ZEd2UxMm0xVHBlTFlSbTd3L0V0VGl5RlFwbHBNbFZWCjE3WTI3YkFFZFJldW11'
    b'MXl1WEFNS3luSTN0c1dhSmllcjlGbXZMYmQvdWhyUFFmYXZJYzZmR1NLdFhqSmk1Ym1ZZEVv'
    b'NjArODBoV2QKd3NMQ3Arb1BHeDNPQ2ZxVWtaQXMrT3cxNTE3NmprUWFpVWFrQU9BUGtSdC9j'
    b'MkJadllIQU1JV005K2RmTnZnRGdaNlJGSTlBQVFCRgpVSWxVQWdBa1JmTDUzN0VrSkVuU2xK'
    b'MXRzd3dEY0YwOVBTcmxocFhMVndEQUc5c3RWOXgzc0w1S0cwL1FKd2ErTmt0ckh3eXZlTUY4'
    b'Cjl3cmpZZ1g3ekJyOWVTOWF2MlZ0bTdaWVAxSW1ZcllTY2RGZ1Y1a213eHY2UjVKM2ltYjdy'
    b'T0h1NFdEM1VKQmkwRG0xMlh0YTdIT3EKRFNSSmRuUjNUYXVwcFNpcXA2OVhvMVovNDlpY2I2'
    b'QlVLZ21DMTluUmJoa3ljOExzNDZNS2I0QjhmOC9Jbjkvb0RVVlRvK1B4TWQ4cAp0b044NGRU'
    b'UmtmakdXclZKaVJYbnlEZTMrZE1XYTdJU2kwcW9FZDZwUEdITUgxL3BmT0xON28wcmpRRFEy'
    b'ZDAxNFYrSXhXSXBpbUlZCjl0dk5sZGZqempSbDhYZzhBT0JZK3ZuM0I1NS8vNHhpRTV6ZTVP'
    b'SlhyVGtab2d0bmF6UUtuamRJcFlVMVdUbmQwUUVBa0tSWUhvNEMKQU1Pd0dJYVJGTm5aM1VV'
    b'elRDd2UrNFovQWZuSzg0YUpXSHgweExaL3orZkJnQjhBZ1AzWHN1amEzVW03TzluVTRaK3FI'
    b'VDZWaDhJegp4eGNnUlFMR0Ywd0tzSGdnNEE4RWd4ekgwVFNkSkwrVVMzZG5oMDcvWldMM2FD'
    b'UnFIaHhvYldtZU9BY0ZGZWhjVkVHNkozOXlGdXZiCnNZd2xyLzM5Q1FRQm94cXJ5STNVNXZP'
    b'cTh3bU8rOXJaRURhYnJiSzY1c0MrdlEwTEZpSUlNdTUySFRyU2prcHlDTEVKK0RKdktpZmQK'
    b'alY5Yk5jT01UZWxlK0dmVU1uUjFQVDh2QTBlQWkwWER3V0RvY0hOWHJ0UmhHUjZxcUt4bU9X'
    b'WjRuRGVHelhYSFpCU0RwcnNyTGF4LwpINDBvbGlNYUFzb0hDSm9rY3Z1OFdReWtKWlVlQ3Yv'
    b'UGVPTmliN3c2M1E5blNQby9seVl0ckRScFlhVkpDeXRObXJTdzBxU0ZsU1l0CnJEUnAwc0pL'
    b'TXhuNGZ3MHRQYUJETWExZkFBQUFKWFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl6TFRBMUxU'
    b'STRWREF3T2pVNE9qRXkKS3pBd09qQXdsZlMwZ1FBQUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5r'
    b'QU1qQXlNeTB3TlMweU9GUXdNRG8xT0RveE1pc3dNRG93TU9TcApERDBBQUFBQVNVVk9SSzVD'
    b'WUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxNTE5MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_MP')

US_MP = b64_US_MP
index.append("US_MP")
index.append("United States of America Northern Mariana Islands")
catalog["US_MP"] = US_MP
catalog["United States of America Northern Mariana Islands"] = US_MP
country["United States of America Northern Mariana Islands"] = ('US_MP', '', 1)
lookup["US_MP"] = ('US_MP', '', 'United States of America Northern Mariana Islands', 1)
lookup["Saipan United States of America Northern Mariana Islands"] = ('US_MP', '', 'United States of America Northern Mariana Islands', 1)
lookup["United States of America Northern Mariana Islands"] = ('US_MP', '', 'United States of America Northern Mariana Islands', 1)
details["US_MP"] = {"continent":"Americas","capital":"Saipan","currency":"","web":"","lang":"","tz":"+10:00","altname":""}
regional["US_MP"] = ('US_MP', 'United States of America Northern Mariana Islands', 1)
regional["United States of America Northern Mariana Islands"] = ('US_MP', 'United States of America Northern Mariana Islands', 1)
#----------------------------------------------------------------------
b64_US_MS = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDY4MiIKICAgd2lkdGg9'
    b'IjE2NyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01pc3Npc3NpcHBpLnN2Zy5wbmciCiAgIHhtbG5zOmlu'
    b'a3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgog'
    b'ICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQv'
    b'c29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5'
    b'L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5z'
    b'OnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRl'
    b'ZnMxMDY4NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEw'
    b'Njg0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2'
    b'NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0i'
    b'MiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2Vj'
    b'aGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVy'
    b'IgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEwNjg4Ij4KICAgIDxp'
    b'bWFnZQogICAgICAgd2lkdGg9IjE2NyIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJl'
    b'c2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6'
    b'b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFz'
    b'ZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFLY0FBQUJrQ0FJQUFBQnNDTGVoQUFBQUJH'
    b'ZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRB'
    b'QUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBVApHRWxF'
    b'UVZSNDJ1MmRkMEFUeWR2SEo1VWVBcUdGM2tFUlVFSEFrMlpGUlZGUDBiTmhSYytPM3RubFJM'
    b'R2VCYjNEaXFEbzJVQ3hnb0NpCklJSWdJQVFoRkVFNm9RVkNFdExMKzhmKzNoeUhOQUV4Nkg3'
    b'LzJoMW1kNTdzaDVsNXBqeTdpSGhGVy9EMWhkRVhhL3FKT3lSbVZHQlgKM1ZBR1A2UkNsN2FP'
    b'TWVCMVNLdy9nK0JYSWdhaGRDU0E5ZU1KcGc1VGh3VlRod1ZUaHdWVGh3VlRod1ZUaHdWVGh3'
    b'VlRod1ZUaHdWVApod1ZUaHdWVGh3VlRod1ZUNzVzbVcvSmc2aitXbEdURjI2Y3dVRWlZK3Zj'
    b'b1l3UHQ5cWVLV0pHdWlsQlhSZWhreU5mQ2lTeTErTkNwCkxMcTdxMkRxUTB6K2ZqNDJ3MHlj'
    b'SGF3MUNIZ0FnRUNFWE83RWl0blFQSHNrKzFpYzR2N3B6Q2ZybW1lTTRQQkZBQUNnUWNBN08x'
    b'amIKRERQeDkvT0JxUTlKNlJMVjEvbk1jbmF3em9xOXZHTEI5QVlxRFFEQUVZQkR6NVEyM2xF'
    b'dXJFUFgwbEJ2U3JETHcvRVhreFdFSWdBQQphS0RTVml5WW5oVjcyZG5CZXAzUExGMmlPa3hk'
    b'MnVYaFBnYUpSS0RSS0hVQ0hnQlEzOWhTVTllRXhXQUFBT1RpOHZZNVpURmlYMmZXCkdFUGVh'
    b'bWVXNEw5Yk9LR2NXQXltcHE2cHZyRUZBS0JPd0tQUktDUVM0ZUUrQnFZdWRScHRiUjUxNVZE'
    b'cW8zUFFLVjhnZUJ5ZlFpS1gKako3cVM2TXo1ZVZrSkRsZHpiakg0eFZQSnlpZWVha3czdnhm'
    b'VDE1ZVRvWkdaNDZlNmtzaWx6eU9UK0VMQkZCNjZxTnpVVmNPamJZMgovMjZlRmZyNytCbHVU'
    b'clp6cHJxTUdtR1dsVnZVU21kSzBqZnRQVnRSVS8raDRGUDd6T2NTRlNoMEZBQWdMRldlaUJO'
    b'SzBsbHNidWp0CmFPZ3FTV0lyblNrU2lUd25PbWxyRWxJejhwTFNTSEJkbHdvaEVJaW1GbnJ3'
    b'MVNnT2w1ZWVYYkJ5b2Fma1R4VTE5Wi9uaDVCL2Z0enAKVlNzWGVxWm5GM0M0dk9DclVVMHRk'
    b'QVFDQWRmMWJ5WlRJNTJTc2hwell6MDZvNjJ1c1RtL3FJeGNYRDdNekhEMzBjc0RXOURGNjQr'
    b'ZwpadURHL2VkaXNSZ0FvS1d1aWxOU0tQNVVCZGtBVXg4OHJWN29xYVZCR0RkbWhLWHJVaWhG'
    b'TEJZZk9IM3RLeFYzNFBRMUNEa0FvTEdaCmx2enc3NVNNdkxvRzZxNGpsNGZpMHh1cUxUeU56'
    b'bHc4WjVJcUh1Yzl3MTJTeU9GK3JVblc5bmYybnVHdWlzY3Ruak9KMXM2QmdLbC8KZGRuWldL'
    b'amljYmtGcGRFSmI3bGNQa0VGTjJoRkUxUndYQzQvT3VGdGJrR3BLaDVuWjJNQnQvQ0RwS3pj'
    b'b3F6Y29ubWVicFcxRGUreQpDd2F6YUdvTC9VRnNjbTA5Vlplb2RqL21OVnpYQjBQamZ4b2xP'
    b'WDRVbC9MK1EvRzMrYmY3VVBRNFByVlRxMkRxQXlZVUN1bnY1K1BqCjdYSCt5RlpKSWw4Z0VB'
    b'aUUzOFFlZ1VBb21jTUJBSncvc3RYSDI4UGZ6d2MxUkZieGhvYVZRcUVvUGlrejlPUU9JMzNp'
    b'eldCLzZlbE4KN1d3c2JnYjdHK2tUUTAvdWlFL0tGRUlUK2pEMWdkSmNUOWVLbXZwV1J0dUpD'
    b'N2V6Y291a3g4TTRjZUYySzZPdG9xWitycWNyM01JUApxTStKUnAwUGYyanV2UGhKZkVwT2Zv'
    b'bFUyWmFUWC9Ja1BzWGNlZkg1OElkb05BcjI0UWV5SHkydnFnTUErQVVFOStjK0NBUmkwZXlK'
    b'Cjh2S3k0Ukd4UEw1Z29NenpDd2dXaWNTUWhYQmRIeGc1TzFoTGpwbHQ3RDdmUjE1TzVrSG9v'
    b'V3RuZHA4L3NqWDI1Z2tsQmZtQnNyQzkKVmUydGhhbjNSY1lHMnBwcUtvSGJWNWtZNnZSL0ZC'
    b'Qng4WURuUkNmbzFNWFJKdnJHTVp5aS9NQWFiR0tvRTdoOWxhYWFpcFR2d1pKcQo2cXA0cGF5'
    b'NEVHY0g2OWRSZngzNGZRVVcwL2YrYU44V253N2JJc2JhV1NWRUJBMFVIaXdHZmVEM0ZhK2ov'
    b'bkoyc002S0MxSEZLOEhVCis2aE1VbEZjWW9aUUtFcDZtN1AvNU5VKzk4U3VUclorcStjMVVt'
    b'a2Qwa2RhbWFZL3ZXQnZhOUZwZCtBOXcvM1BmYjllT2JIOStONjEKbHFiNjNSZkI0d3Yybjd5'
    b'YTlEWkhLQlRGSldaa2tvcGc2bjJVa29KOFh1RW4wM0dMcU0ydC9XbmJ6eDMydTNEOWtZcHlK'
    b'L1VQajFOOApFSHBJUjB1dHZjZTNhcUZuV2RyZFcrZjh0L3A2TDVzL2RkdWErYmVDL1h0VEZy'
    b'VzUxWFRjb3J6Q1R3UG9OUHh3MUJsdHJLQ1F5R3BLCjQyOEh6L2Y1SnRNbk9OWFVOWmtiNjNV'
    b'MXJOSlNWejIwYzdWa2lCank1KzhYajIzcjBFVDNjalh2dDRQbnF5bU5RU0dSakRZV1RMM3YK'
    b'QXkxSis5bnpMMEVpYkllYlRuUWViV1ZoMUI3d25Ha3UwUWx2dmFiODFNMjEzalBjRmVSbEFR'
    b'Qm5Ball1bXovMTh3eHA3OG05TVZoaQpwNVJ2dVpIZThUb1NpVmkxMERQazV0UGVaTWJqRkdO'
    b'dUhCOHowaEk2WmJHNUtSa2ZiajE0Y1M4NnljWFJodG5HN2dwREpxbG90TFc1CkRCWmpZYUp2'
    b'YXFpOWRxbFhwOWw4dkQxSUJhWGhFYkc5Tkg3MUlzL1EyOUVpa1JpbS9tWElIVWNOMzdmRlJ5'
    b'Z1VNWmlzeUtlSjNlZWYKN3pWZWdoenl4U2E3Mms5eXNTc3ByekhVMVZybk02dXJDOFZpOGN1'
    b'VTk1TmM3UFMwMVFPM3IrbzBUMzFUQ3dLQldEYlBvemZVdldlNApLeW5LNzl2aWsxZFlscDVO'
    b'bGs3dzB0akNvMURJTGF2bVBRay9xcTFKMkxoOHpvdmtyQjR2MFNOcWZKN1lUR09vNG52WWNH'
    b'R2tUL3hRCitBa0FRR2V3ZFA0LzdFR3lXUXJTaStRc0JxTk5XNVBRRytOZkpHZHRYRDVIVzVQ'
    b'd0pQem9sbFh6cEhNVlRocHRFZ3BGUVNHUmY0ZEYKa1l2TFpXUXdiYXllNStNK2xsZDNNb2JH'
    b'b252MHdrUmlNUXFKQkFBd1dXd1pMQVlBd09YeGI5eUxiNS9uUThFbkJBTFJ5MXJieG1MTAp5'
    b'R0RJeGVWL2gwVUZoVVJLNXlxYzlIcHoxWlJHcDVuckovL3ltNmE2U28rWkh6NUwvdHh0VmxL'
    b'UWI2YlI2Y3p1M09uSzZubzlIWTJxCjJrWWpQUzBBQUY4ZzJCNTRZZG9FeC9aNWN2SS9xcXJn'
    b'YWh1b3ZURmJVMTFsOGkrL09jMWNYMDFwaEgzNEwxYm83V2cyaDF0YlQ2MnEKN2ZueDBabXNi'
    b'UUhueWNYbHFabDU3ZE1YelpsMDVkWi8vTUc3anhMVysweFl0bkk1cFlFS0FDZ3NyYlF3MW91'
    b'S1NabzJ3VWtvRk8wOApmR25UaXAraG1DbElGVFgxQW9FUWoxT3NxbTNvamRsVnRZMjE5VlEy'
    b'NTM4QkZURDFyNnRyRWM4aW5pU3lPYnl0QWVjeWNncWh4UFhMClpzY2twT1VXbEVLbmR4Njl6'
    b'SDI2WjVOTDB6YUhiTDhOUGcxVVdsNWhtWm14YnNUVHhHbmpIYmNHQks5Y01OM0VVQ2ZpU2FL'
    b'a3I5bXcKSitqZzlwVUFnUFRCM2FEM2RUMm5wVml0d1NoR0dTZzZkVXlzYlVVOXpwWHQ2cEpm'
    b'ZldabGtvcXdHRFFTaVJTSmV0VTdKcWZuSWxISQo0M3ZYcG1UbWhVZkdzVG5jWWFZRzJwcUVl'
    b'V3YyRHpjM1ZDZmc5Kzc0ZGNka09nQUFoUVRqREJtSFFsUHdXaGIxVFMwb0ZETHhiYzZZCmta'
    b'WjFqYzFXNW9iV3c0eWhHKzQ4Y3RIU3hHRGg3SWs4dm1EOXJ0UE1YbmdZR0RRYWpVSUtSU0xJ'
    b'L3E2eXpiTGw2dUE3YnY5cVMwT0kKV2dkam9DKzk0L1hOSzM3K3lkNUtMQWJML1k3Mm1CbUxR'
    b'WSt3TkZaUlZpd3RyM0didTJYVkw5UDNiRnFTVjFUbWZ5TFUxY24yd3RGdAowUWxwQjA2SDcz'
    b'YjlkMllYZ3hLYktsVTd1OW10M1htS3hlTEl5Y2tTTlZSM3JGOElqZXc1WE43V2dITmNMczl4'
    b'MVBETi9uK1J5S1YxCmpjMjlNVnNnRkY0N3N4dUJBUGJXRmxEY0REeGU3NVhNamZVdUhOMXFa'
    b'cXhyWnF6cnRYeFBoM0ZVaDhtN3VkTmQxL25NY3JLemtxekkKTWR2WS85eVBYL0JyQUk4dnNC'
    b'NW1mT3JpM2NmWGpzenlHSmVkOXpIZ3dENTN2V3BySXFlWmpTbHR4b2FseVNYVGJuclBjTmZW'
    b'VW1lMApzYkp5aXljdTJCWjU2Y0NMNUt3L1RvYlZVQnBkbld6THErcVdlWHNNTnplVWxjRlNH'
    b'cHBmdk03ODQyUllUVjFUTnhNQWR4NG1QTDUyCkJBQ1FjUGYwdXQxQnhaK3FwTzBKSTZUemF6'
    b'OFlOUHBsWkZBMXBWRWdFRzdhZDdiVEtCTXNCdjFQOEw0NVUxMjZLcFRIRitRWGxiMU0KZVY5'
    b'TmFRb0syQUNsM0l0T1NrN1AxU1dxV1ZzYXV6clo0bkdLa3Z5VUJ1cTRXUnV3V093NGV5c1Bk'
    b'OGRwRXh3NlhVUnBhV1Y0cjluZgpWWEFySHFmNDk2RXRhRFJLbDZnK3dYdHIrNjIwLy9GVnYr'
    b'blhmcVMwaGVjTEJBK2VKWis1RXRuTktIbnRVcTl1a0VQL0ZxTkdtSTBhClllYTFmTSs3N0FL'
    b'SFVjT3dHUFNpMlJNWHpaNzRlV1lhblRsL2JjRFZvTjF1VGoxVUF4VmxwWHNoQnkxZGwxSmI2'
    b'SjNlWitubXcwZ2sKd20rMWQxZklZUisrUzNXUEhBRFFZNkJUVG41SjhOVW8veE9oYXFyS3E3'
    b'ZWY2QlNTQkpYM212MEJ2NjNvRWJta1FzLzFkT3R1OGtjawpQbk1sVW1xZnJmUjZjejNPaFYy'
    b'OUcrdTMyaHRhSyt0VUk2MU1SMXFaUXNlUDQxT1diRHAwUHlTdy9Vc3JKUDhjU3pZZG51eHFQ'
    b'OUY1CjlCZTBSajB0QTBydDBvdFUxM1hyWWNZbWhqcG9OTXExaS9wWFVWMDMxOWYvOHgweUha'
    b'MXFnZkJWYW5aMFF0cnJOTkxFQlZ1ZlBFL2wKOHZpUTIwVWlsL3k2Ni9UZTQxZk9IZkVMajRq'
    b'ZHVPOXNkdDdIM3RoV1ZGcloxWUtRcTVNdEdvMHlNZFNSRFAvZ3V2NEZxcUUwa2hPdgpWMU1h'
    b'emw2NTMxV2VoRGZ2amNjdTlIQWZNOWJPYXBpWmdRd1dpMEloUjFnWXFha3FKNmZuWnVVV043'
    b'VzBZdEFvQUFDSlhIci9TdUJ3CmM4TUw0UThEejF3WENrVnRiSTY4bk16WkE1dGNIRzBBQUVk'
    b'MnJYNlhVNWhmWEI3NU5CR0pSQ0lRQUlGQW9GRW9OVlZsUzFOOTk3R2oKeEdKeEZhV0J4ZUpr'
    b'a29yMkhBdnBhcmV1Z1k3bTZmM3JkWWthdzkxOVlPcGZhQllhNWJ0NHByS1NBa0hGZElTbEVR'
    b'cUY3R29aZzhQbApQWXBMZVJTWEltblZEMjVmT2RYZHdjWFJaclMxK2F2VTdQQ0lXSGs1bVlo'
    b'TEFmcmFHZ0NBbzd2WEJKeTZ0blR1NUh2UlNXMXNEb1FjCm1oUmljM21QWXQ4YzJlVnJacXdy'
    b'bVp1ak05dXdHTXlId3RLb21PU1RGKzkwdjc4RGhVS09zRFN5SFc0cUVBaDlGODg4ZGVudXQ0'
    b'ckUKRzVMVVZaU1ZNa21GWVhkaURIUzFTUGtsbHFZRytVVmx2Ymt3SjcvRWEva2VuS0s4b29K'
    b'Y2JUM1ZmZXpJc3djM0RUYzNiRCtlZG5XeQpxYWxySW1vUUpydlp0NzkycTY5M2FVV3QxWVRs'
    b'TG80MnRzTk4xRlh4TkRxenBxNHhPVDIzdHI1WFN5K1dwZ2FrL0pLNHhJeUs2cnBNClVxR0tz'
    b'bEtQSFJCTS9WODFVbWtKYjk1VFcrZ0VGVnpDbS9kZmVqbWR5WUtXMmd6MHROb2poeVoySm93'
    b'YmZTejQxanhQTjZKR3h5VnoKWTMyaVdDeCtuVVo2M2FkM1RlVVhsZVVYbGRVM3RWQmI2TklX'
    b'bVRVMHZEbW9NMzZWbXQyZk8wUThmbFZVV3RsSnBUVFROelhxSkxLaQp0S0syLzJhL1NzMG1r'
    b'VXVsK2NGS05YV3hXQ3daLy9RdHJvRE40WTcyOEYyejQ2UmsyUTNTYkEvbnp6T25aT1Rkakhy'
    b'ZVoyc2xGb3BFCjRtNW1rZUVXdm1maEZPVlhMcHdlbjVTNWUrUGlwWnNQOStFT1BMNGdMdkdk'
    b'akF3V2cwYTVPTnA0VFI0bjJkWEU0ZklLU3lySkh5dkkKeGVXeHI5NlJ5UDFxazg4ZTNIdzAr'
    b'T1lVTi91dzJ6SGRiK1dBNjNyUFBiUWVVWVAwUE5UVVVLZjlab2N2VW0wOU5Ud2lWbFlHcTZ5'
    b'awprSlNXQXdDZ05GQ3YzSG9hZERtUy9MR2lvYkVsTlRPdm44alZDWGhUUXgzUzgxQTlvb2FV'
    b'SXg4Q2RWMU5WWG1TaXgwQVFFbFJidHVhCitjZUNiN1l5MnZyVzFKKzRjT2ZTamNmelpyaFgx'
    b'emFpTWVqNnBwYUNqeFZuUSs5MU0xUGJTeWtyS1d4Yk0xOUpVUTRBTU1uRlRrMVYKdWFrZndU'
    b'b3dkYUNNVS9SYXNYZitUSGRLUGZXZmZuUzZrcFlqN0U1TTJKMllnVFd5bGRHMisramwvS0l5'
    b'b2lZaDRrbWlNazRScHQ0dgpsWmJYQUFDQ3J6N1FJYXBKdWFscDJlUWFTaE9id3dWU3I2R3hi'
    b'NDdONFVyZTJJcEdvOW9IUEh4YmpSbHBLWW11S2ltckdSTEl3ZEI2CnkrQndjME5qZmVKSUsx'
    b'TTJoeWZaRC9sdDVlcG82K0UySmllLzVGTWxwY08zQjJEcUE2UENrb3JBN1N1OXBveXJwalJx'
    b'YXhJT25iM1IKMHNyNFZzYW9LQ3Z0MjdMMDUrbXV1a1QxeC9FcDNtdjNENkVuT1pSMlJvdEVZ'
    b'ZzZYeitIeXlpb3BnV2V1ZjBQa0FJQ1dWa2JnbWV0bApsUlFPbDhmaDhxVjVOWDFvVXllbzRL'
    b'N2VqVEYzWGtJdUxwZUc5elhUNkV4eWNibTU4NUtyZDJNRzh3M0dQMVlMVDIyaFE1R09lNDZG'
    b'ClNCS045SWtpa2JpaWVwRGUrbVdvcDZXanBaYVM4YjhJbXozSFF1aE1GcVYzd1ZCd1hlL3Zz'
    b'QnM2a01GaXdrN3R0RERSODVveWJoREsKZFhhd0RqMjVvLzMzSDZSL0d1NzdvUTRKaFVLR25k'
    b'NTE5OGtyQnBPMWMvMUNoMUhETlBvNlpkdWp0TlJWcDQxM2JHaWluYng0TitUawpkdFFRLzli'
    b'bkVMWmVLQlNkdW5TM3RxNkp6bVFoRUFoZExYVXFqVDdncFdBeGFLSUdZZS9tSlFyeXNwcnFL'
    b'czllcFg4bytHUm1wRHVrCnFRL3RMM3U5LzFCY1VsYk41ZkVMU2lxZnZVb1hDa1dUWGUwOTNN'
    b'YThTTTU2bnR6Zk56Z3JLY2ovTW50Q2ZHS0duWTFGYVdXdG1iR3UKajdkSGNucnUzdU5Yd0JE'
    b'WGtJOXBwVE5aWEI3Zjc0Ky9vWG14STd0OHo0VS9iR1cwcWVKeFB0NGVJeXlOdnJnZW9GRytp'
    b'MmY0K2M2Ygo0bWEvY05aRVdWbVpLa3BEOE5VSEhBNHY4TXgxOEYxSWVtTmF2MGc4UGg4Nk1E'
    b'SFFwak5ZSzMrWmJtOWovcW1pZHJTMU9ZOHZPSGZZCmo4RmtOOVBvYkE1M21Ka0JHb1VTaWtR'
    b'WU5Cb0JFQm9FUEZHTDBOeENCd0JzV3ZueittV3pXMmlNNVF1bUNRVWlPcE1WOVN6NTRPOHIK'
    b'UDVaVkZYeXNTSHRQcnUwNnZPMUw5VzFqV3IrM3IvUDYveG5HNW5CM0JGNVFVcENQUzh5WTVH'
    b'SkgxRkFWaWNRSzhySnJsc3dFQUl6LwphWlRucExGQkFSc1dlRTB3TmRJSlA3dmJXSitJUWFN'
    b'QkFQL2NmMjVwb3ZjcU5UdnlhU0tidzUzbjZjWmdzbllmdS96eVRmWjM5cFRRCjM5bnY0UXNF'
    b'eWVtNTBFamF5c0l3OUhhMHZvNG1pVnppNW1RYm0vZ09BUEQwZWVxOWtJT05WRnAwUWxwaFNh'
    b'V21tZ3BPVVFHTFJmTUYKZ3BaV0JwZkh0ekRSVDNwTDRuQzQzMEgvL2FOUWw2aUJTb08rdmkw'
    b'bksyTm1wS3VvSUFlOXZLU3l0dUZjK0VNQlg1RCtuZ3dGU0hDNApQSHNiQ3loR2RkWHZmNVpY'
    b'MVFrRXdrR2I5b0dwZnhXeE9kd09XeVhESTJJUkNBUzBvWEhrbE5YdC96UkV2OEQ1by9mcnZa'
    b'U1U3MkdGCnFjT0NxY09DcWNPQ3FjT0NxY09DcWNPQ3FjUFVZY0hVWWNIVVljSFVZY0hVWWNI'
    b'VVljSFVZVW0zL2c4bEkxdGtsVkp4YlFBQUFDVjAKUlZoMFpHRjBaVHBqY21WaGRHVUFNakF5'
    b'TXkwd01pMHlObFF4T0Rvd05qbzBPU3N3TURvd01CMDlQUlVBQUFBbGRFVllkR1JoZEdVNgpi'
    b'VzlrYVdaNUFESXdNak10TURJdE1qWlVNVGc2TURZNk5Ea3JNREE2TURCc1lJV3BBQUFBQUVs'
    b'RlRrU3VRbUNDCiIKICAgICAgIGlkPSJpbWFnZTEwNjkwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_MS')

US_MS = b64_US_MS
index.append("US_MS")
index.append("United States of America Mississippi")
catalog["US_MS"] = US_MS
catalog["United States of America Mississippi"] = US_MS
country["United States of America Mississippi"] = ('US_MS', '', 1)
lookup["US_MS"] = ('US_MS', '', 'United States of America Mississippi', 1)
lookup["Jackson United States of America Mississippi"] = ('US_MS', '', 'United States of America Mississippi', 1)
lookup["United States of America Mississippi"] = ('US_MS', '', 'United States of America Mississippi', 1)
details["US_MS"] = {"continent":"Americas","capital":"Jackson","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_MS"] = ('US_MS', 'United States of America Mississippi', 1)
regional["United States of America Mississippi"] = ('US_MS', 'United States of America Mississippi', 1)
#----------------------------------------------------------------------
b64_US_MT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMDgzMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX01vbnRhbmEuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczEw'
    b'ODM2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTA4MzQi'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTA4MzgiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFEck9WNm5BQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFiCjdVbEVRVlI0'
    b'MnUxOWQzeFZWYnIyczl2cC9lU2tGMUpJcFNTRVpvQUFvcUlnTWpac24vT3BZMkg4eHVzNGVu'
    b'V3VldWM2NmpoNlIwZkgKT3piVU85Z1kyMkNCRVZHcDBva0lKSkJDZW5MU1RrN3Z1NjN2anhO'
    b'Q2hCUjBtRXZ3bnVkMy9saDcvVmJaWnozcmZkZjdycllwRkQrQgpPTTVsMFBFbWlGTVlSNXpD'
    b'T09JVXhpbU1JMDVoSEhFSzQ0aFRHS2N3amppRmNjUXBqQ05PNGY5aXNHZTNlbzZSWnVUMXBG'
    b'Z0MzUzdkCi9zWmtRV0xpbFB6UFVmalExYnZ1WGI1LzhISE45dUpmckxvUXdDMkxEajk5ODVi'
    b'QitQZDNGSzU4ZWZHcDJTbUszSDNwTnc5ZnZjdXEKRDhkaStuMmFSOSt2K1BObjB3aWhUazIv'
    b'OW9HUExwL2RBRUNRbUNsMzMxeG50d0xZK2VUYkZRVjJBRjhkbW5EaEk5Y01UZi9BNVh1ZQov'
    b'T20ya1Y3K3Z0WG5QL1BKakZQajM3dnZreFZ6Nm1MaGtuLzUyZEdPaEdHelh6ZnY2SnBmcll1'
    b'RkgzeTc4dmQvT3cvQUw1ZFZQWHZMCnBsaWs5Y2E3WFFIVnNIbnZ2M3p2VXovZEdndmYrTnls'
    b'YjI4ck9XdUtWS3NVemRySTRPK0NLYTJ4K01xU2pxSHhXcFV3TEgrdi83OE4Kejk2eWFaQS9B'
    b'QW1HMFBPM2ZyWHE1eHZIRk56Ly9MOWJ4bnc5WHZ6ZXZkT2c0WmROYnh4OHZIWmUzZW5rK3ZV'
    b'VmU1Sk13ZE92NVliNQpSNFowaGRxek9SYlNOQm42bUovcVRqUUdBY3pPN3hvejcrMFhIYnA1'
    b'VVhVc0xFbDB2ZDBpU1FOdmN1dUZoMjVaZEhqMDdNdG1OQzJhCjBqWjZHa0dpdnU4L3VueFdn'
    b'MW9wRGo1ZVArOElSWkhUSWY2MzErNDR6U29tWnptbVpEa0dIeThzYmJVWlEyZVBRc2duQ2Rh'
    b'Y0lydEYKRjhsUGRZK2VrV0hrMzZ6WUdRczcvZXJTWDkxYytJdmJaajl3b3kra2lFVStjdTBP'
    b'aHBGSEwrVHBtemFmMUlkT3dvWUR1U3Yrc0h6RgpINVkvdjM3NllPUWZQNTBSaTF5M1AzY1kr'
    b'YWdja0E5WnBnRGtKbnRtVHV3K25hYTQ5WUxEa3pMN1QwOEVqdzZ0Z21Pa3F5dnF6cjRVCml2'
    b'SkFJWE1LTzJmbGQ4VjZiamc2b2g2YmxkZWRhZ2tNdG1sTmV3S0FxcWJrRnphVXh5SXpFdnpU'
    b'YzN0R3I3MDB1KyttaGRXakpHanEKTVgyd3EvQ0RYWVg3amlVUFJ1NnVTNHRGTm5SWlRrcWZZ'
    b'ZzZjUDdrZEFDSFUyOXVLQjhlODAya0tocEdmdm5uejZiVFlkWE1IQ254egphOG1aMHFVL25F'
    b'TG1PSVhlb0xLNTF3UmdYbkhuN0lLdW1HN2MyNWc2VXNiOHRCTml1cTBtWXpDOGRVaTRJRzFF'
    b'VVk3MVh3Q1AzL0MxClRzV2ZLYnZ1MnJsMU1kSGYzNWo4MTY4SEtMeG1idjJZK2lEMlBvdExX'
    b'eGFYdFl5ZWNsNXhaNmJOQnlBUTRmN2ozWGt4cTIxT29UMFcKZVRha2NNaFk4L1hSZEFCbE9Y'
    b'MnhJZXJiMWtSdlVEbWlFY3hJZytHb2NFSllvME1NRUphV1JzcmUwbWZjV1pjZWs1dWg0OG8v'
    b'aUVFcgo0NU45RTNmV3BjZFVTN0lwc0hCUysrZ1pCMFgyNHJMbU1hbzRycWczZnB2VDdqRFVk'
    b'bHBqQTlDZ2FKNU5jK2Jyb3hreHpUNm5zQlBBCmxzT1pvMlJzNlRVTmhzdnpUaWpNOHB5ZVlk'
    b'T2NCRUtvKzFjdkdOYngrTUVvVEhPV0gxZmQ3UTVEZnFxcnFkdDBtcnIwcFkzVG1ucE0KWTFh'
    b'aDVNU3JLdXBqNGRvT2EzbHV6N0Z1ODBBVmxiVm5Td3JKU1ZKNFFpVWVHWTNDblhWcGc1Ykxm'
    b'Y3YzeGZ5S0pGUHc3a3VyWXBHZQpvSEpYZmVvb0pleXFUMXU3Si84TVVuaEQ1UW1lM3ZybCtx'
    b'cW4zeWhJYzhVZXI1amRvRktJbzNvdnpFUHZWSTVaeFNYVFdzemFTQ3o4CjhJcGRWVSsvc1h6'
    b'bXNkamoxQWw5eFJuOVo0RkNoajR4U0RSMFdYbzh1a0hyWmtkdHhpZ1pJeno3N0xxWnNYQmVp'
    b'dnZBTTZ2ZnZQdnYKQjU1WlBUZ2tQUFBwektFS2RsZzgrSGJsbVpyS29TaHkvZndSUmMya2pT'
    b'NlpOb2FHZkg5bjRiNWpLYWZ2RGc0elZ6QzM5bXhJNFhkdAoraDIxYWJIQWdhYWtRU0ViQ2Iv'
    b'N1lQYjJJd00wWjlwOE55Nm9HYlJSdHg3SmZPcHZzOGFzdmFITHN1cUxxV2VFd3RrRlhUbEpu'
    b'bGo0Cnc5MEZkN3kwK0k2WEZxOThlWEhvdUZGOVhlVVl1cFFRNnY0M0Y0NlN3S2lOWGxyZUZB'
    b'dnZiMHlKVlhISFM0dnI3WmJCS2s3SEIvMG4KS3RLaHVuUnJUZWFZZVFXSnVlU3hGYTkrT1hY'
    b'UXZJeVpkaTkvWHJia3NhdFBVN3dlZmEvQ0gxYWNXUzM2eUx0elYzMVJ1dXFMMGxjMgpsbjYw'
    b'dHlBV2VXbDVrMEV6aHVtN3JTWmpXRjh6aGl0bjF3OXE0ejkvVmg2cll0VVhwYTlzTEl0RjVp'
    b'WjdadVYzLzBBdDhvTjNjOXVNCkliMktCeURKZEp2RG9GR0t5YVlBQUlkUDR3OHJkQ3FCWTZU'
    b'WVVCR01jaU1Wa21YekxTNXJUallGdTkyNmpRZXoyeDJHa1ZJbW1ZSmEKcFJDanY2TmZQK2pN'
    b'cVJVaWdERFBkcnQxdzJiVXFZVFl0QkdBWG8vMjFKZEpzd2FVckFpQWdHcnBOUTRWSGF0dVlQ'
    b'NnZ5NjJMOE95dwpaZHBkdXBqYTE2dDVtMkZncXFYVllSemFPeE1NSVlONm9CTjBPdlc4T05C'
    b'SFZRb3gxVHlnZnZyOW1qRzExeG1tTUk1eGd2aDZZWnpDCk9NNDIyQi9ySHl0T2NkaU13VFJU'
    b'Z0thSUs2QnhCbFZIdW15QmlDSk80ZmpGckJ6N3JmTU9WaGEycFJvREdxVkFEVzhKMDg2Z3Vy'
    b'bzkKOGIycTRqVzdKMFhFSDhQZlArZk5tY0prNXhOWGJiMm9wRW1qRUw1WFJwbFFOWGJic3h0'
    b'bnZiRnJTcHpDczRNNWVSMHYvSi9QcDJUMAovWVBsK0NPSzU3Nlk5ZHQxYzJXWmpsUDRQNFFr'
    b'UTJqZDNlOU9uM0NLTDh3bEFqS0VmdEJheUVHd1ZpaVNJWVVnaHlGNUlZY0JDZ0FvCkd1VGts'
    b'UkIvVkhuN1g1YTh0Nzg0VHVFL0hmOXgyZGNQTDlzeGRJWVdBTlNGaURTQ3RTTGhLa3BkQWtn'
    b'azJrWXBzOEhvSVBrZ3VxSEsKaFNJZGdiM0V2UUcwQ3JRS1hETDhlOEhiSWZRT0Z2Tk5XOHFp'
    b'Lzd6ZUYxSEZLZnluUU0wSlg5NjNwaUt2ODU5YVM0am5saisvWWxQdApoRGlGWnhncHhrRDE0'
    b'NjlZTkpGVC9nRUg2NVZnRE1jRnpnVjFBY1VsUVpFQ29aOUVPeEN1US9BUWFBNmlCNUlmY25q'
    b'TXVnandMMnN1CmZtRlRlWnpDTTJsMlZ2M21kWTN5dEcxT1ZSNFlIY0oxQUhVNm5BM2JNaytz'
    b'cjNqNG93WGp2M0VZMkJhTjgxZE1OUVdxSDFzMUtuOFUKRWxZZ2RBUUFsRm13WEFiZlZnZzlJ'
    b'Q0tJK0lQcm5aZmZ3WXZzam1NWmNkZitINEpPeFZjLytzcFlQaCtoc3A0Z3pyVWdJdlRuVWFv'
    b'SgpRNWJCYU1RMlN5b3pvYzZISWgxY0FzSU5BQTNXQWhKQnRCUHFmRVRiNGQ4TnlYOVN1WTlm'
    b'dWFYRHJYOTc5K1E0aFQ4YzJ4NTRjM0MvCndpbjB6a1NrRWFJTEFBUW5OTVVJSHFhMFUwamsr'
    b'RTR5eTJXVWZqWnBleEFBb3UySWpyQ1J5YmQ5Wk9uR2Y5K3lmazlUZW1PZmVkdzIKMGJoMlpw'
    b'KzRja3RaWnUrQXc1ZHdEYlJsVUJkQk93V3NCUUFZSFpYei9FRFNhRHQwTXdCQVV6TGdKS2h5'
    b'cWF3blNOZXpwemQyNWtKZApDR1gyd0U5ZEJHWFdRQituNWUyL2ZwT201VGlGM3hzWkZ2Lzls'
    b'K3dHbHdqek1naDk2SDhQd1c4UnJrV2tGYlFHQUx5YlFTbVFjQjBBCmhHc3BWUjRBS0NjZ1hB'
    b'OUtRZVcvVFRxZmhPQUFBQzRaaXZRUkdrQURReVgwRlZUQzFUQXVoT0U4NkVxaEtZUnlBcWlC'
    b'eGVGa1krQ0YKRzc2SUs5THZqZlYzLzVXbUNNbDhoRkxudzcwZUlBT3lsZk04YWJsM1lBeHMr'
    b'emVxK0RQaTJVQ0NoeWpybFFBRnpvWklFNVgrSUNJdApjTHdEQUxicnFkUmZrY1pid0EvblVN'
    b'cWhtQ0lkZmVQS2JmTVBQUG4zaWphWElVN2g2V0xKNUtiSjZRNUpVeUR5alp3eWpaN3dGRnJ2'
    b'CkI4VWkrem5DR0tpMGUwbmpiUUFRYVNJOUwxUHBENUdlRjVGeUYxZ0R3blhRVG9YMUNsSXpI'
    b'NnlKeW4wWm5JM1VMZ1BmUGVCRUpxOEUKeFVCd1Fwa0JBRUlmMkFTSUR0QnFpQzQ0MWd3dnF4'
    b'VDU2OC9YVnZ6dXByaGZlTHBvZVBMRnZFUXZuL0l6d3VoQU1VcmJIYWk5VWpJdgprbGdkZ2Fn'
    b'MHIwRGJyK0hlQ0FBVVN4VzhUK3F2Qld1QTBBL0dBT05DUkpwQXE2aUpxK0g4bUhRK0JqbjZ3'
    b'MTVEZ1BGZ1RjckIvY0lGCkN6b21aUE41RC95aXBkOFlwM0Jzek1xeDczN29EVWs3U2JSY2NI'
    b'd0dKbGxwdXlQUy9RUkl6THVnRmJvS3F2SE9BY3VGTlVLWmkrQ0IKRTBWd2lWVGhXdEo2THdM'
    b'ZndEQ2ZNaStGcnB3MDNZNXcvZWlXZ2FUSmh5SXBIS1diNjZKMUJ3UDFCN3BFVVFhUW5pSGV0'
    b'dEszdVhiQwpCVS9mRUZla1krUHhLN1lDUk5KUE8rSDNDVDJ5MEVVcjB1Vm96R0dRaFVpdHN1'
    b'UkxjcWdjRkN1bjNVK2JMa2J6bmZEdlBTNCtmYVR4ClppcnhaNWo0RnNLMXBPOE50UDBhNU9T'
    b'TmhJVFJnV0lwMFF1UXNHaHBkWmJaTzRqRDd1NXNjQVE4M3puMjE5bkJkbmN4OC9JN2FGb2UK'
    b'YjJ0UzQzRjI1dFdiUHFOVmlaSmg1bmVqSmM1NHNSVGFQMkI1eUdGR1AwY0dKUmxtaVFoRDhq'
    b'T3FJbmlHbkJDMlhBcStBMjIvUnQ5cQpoR3VCb2F0TGxLek9GUzBYOXZIVGRtN25mSEtKWnNJ'
    b'Y2UzOVd3NkgrN2hhWHQ5L3ZjUVNHMFZjVWlvcjRQcDl1ZjJ0cVhBcEh3MC9LCjZoV01KR3BQ'
    b'WHJlVFFvZFovZmswbXlRTEE2ZUlwWEExTElzbDcwWUFrbUJuRTI1RzYzMFlQTGphOStad21w'
    b'SUxVYmtIcXhOM3JHOEsKZXI4YWpGYnJWYW5aVnBWV1diWndvakZCdC83Vm5jNXU3MGxaYTZx'
    b'VlM1YUZicTQ4K09LVzhqaUZvK0duYzJvQXlNYzk2NkZxajNlKwp6Wm1XOHM0MU1aVW9Cdllx'
    b'TENzR3B0QklWSTYyMEtZTDRQa0NGQzF6Q1lSTEJoQ05JaEF4ZDNmUjZUbHFwUW9PcDdueGNG'
    b'YzBGQTE2Cnd3QVloa3JOdFdsTmFwRVgyNDcyQ0x4MFpQZUl4eWZDWWFxN215MU82Ujl2TFRi'
    b'dUtKeVpiU2UwbW5ERFRHZ1IwU0VGOWpMS1hDbFMKQ3dBa0t2cTNzTHJ6eE1CT0FFSmdtOUo4'
    b'TVFuczdSVVdITm50cjluWkxNc2s0QW1KUXVlZ0pzeklUK3BwZFhJcUZzQ01DNHVtVk9hMQpO'
    b'L1FlMm5KTTRNWGMwdlM2ZldPYzMyODh4czFQRFU5TWNoL3JOY2NwSEJFMmZaQW9UcHpLb0dn'
    b'MXJTNmhHSU1VcWlhaVE0clVjNlpsCkF4UUNNdC9KNmhkUTRXb2krU0JIUkYzRlgxNUo2bXor'
    b'ZXRpU0NVRjdmUytBL1BJc1c3ckozdVI0NjNlZjg1R0JDWFIzbjMvTWQrdXkKTTZDd1pFcmpu'
    b'NzZjRWFkd2VCaFVFWTZSSlhVdXJVaW5XQXZGSmdGRUN1eWhXQ3RyV0VnRWh4VGFUeVF2eFNV'
    b'UndSRWI5c1RnZnM1OAp0ZUJkVDRSZUtiVDFrZ2RYTzV2cUlzRkFpNGVYSXdHTDVDUnlKQnIw'
    b'aUpKSVE2QWdaay9PelNpYXNIdGpsU0FFYmJscExLMm5hR1YvClI2dklSd0RRREN0TG9pekpm'
    b'SGlZaXlqNkhReUE2UlBzUUp6Q0VWQ1Ixd1dBMGMyR2NxSVkzQTM1OFBGaE1DQzdPbGo5WE01'
    b'OGxSUTYKekdwbkVEbEUwUm9wMGlCSG13VFJ4ZW9YRUtHcjMzbDRxeXZ0WUVEZDZ3MFlOYXA2'
    b'di9mTkc4c0R2TlRrQ0xsREVZdUd5YklhQllsOAoydTdlbDdDZ3JNejY4YUcydStibkorcFlu'
    b'WkxwY1BzenpIcFJGdXQ2QXpPenpCNnY1M0JmTkZXdm1LU1AwZ3l6bzhWVG5xWmxJS0puCitz'
    b'UWs5N2hxdFBIbDRxU2FmUURFOEdIUnZ3VnlCTURiVFlmdnIvcVNseVZBRnYzYkJkZjdGSzBX'
    b'UE90RjMyYlJ0NGxvRnh3Vko0TkUKQmZlSG9CaTlOcEZJSVNYTGFCVFU1MGM2SjZkYWRqVDcv'
    b'VkdaWTZqcUxsOTFsOWVzWnJ4aDhkMnFqalpYZ0tHcEpvYzNRY2Q4OEczbgp1bXI3YzF2YnRq'
    b'YzVqbllIMWg2MC85ZTJkZ2ZQMlgxNGFWZVhWNVhjUmF6cldvUnZ2TG9xdjVWUUdzT1p1NlBo'
    b'UnlpRkNib3dnRzZoCkxjSkVvbkt3M2hPK2JlY09BSjFCMTMvUHUxUkZhNGtjRW9QN0pZcUpT'
    b'UDJDNlBybHh4ZXZiYXRmbGpQMzlmTi9jZDBuSzFtYXZTMDMKbEdkYnNhUTQ4YWJaMlUxT01j'
    b'RExSM3ZDaVRvMnhhanU5d2NKNElsSXY3dXM1TXU2N2d5VDR1Zno4djBSZmxxbTdaQzkxeDJL'
    b'cWxobQpmVTNuamJOeVJSa1JBVXBXN1BTRTZucjh2aWgxMWJUc2hsNnZYcTBVS0pWYUVZMVRP'
    b'Q0tVckFTZ1BycXZSNUI0Q2ZjZXYwUHQ0N1pqCjB6S2ZsVVRkckNTcksrcVRhVTlRSUhVdXZO'
    b'Y0NBR3NidDFrMDJ6N3ZCSUFxNTExUFY5Z2JIUGVjbU9lVWlOMHJXSFU2czFhM29kWUwKd0JF'
    b'UWs0MW11MWV3NmJYdU1CWGtwY21wU1JsbVM2NU5HeGJSNjVlTUtrYWpvSzh1VGIra09OV2dw'
    b'TzArb2NYSmU4SlNmcEpLOXNvcwpJOGNwSEJHZWtBb0FTd0NBcGhBNnZ2R0ZBSS92Z296QWtw'
    b'ekEra2JNU2tXREMvMUR0ald0T1g1UTF4R1NBOVFUQnU1d1JIeU1rQk5yCmhGR1JwQmk0VExP'
    b'aTNjMnZxKzZlblcwV1pjWWZGWE1UdEN4TjZaVzBUa25YOTBVNFJpRVR0TGtqZWlWbjl3ck5E'
    b'cDgzSXBTa21OUUsKTnN0cTZQYUpMTUlSUVJtbmNFVDBCOVFBT0VJQllHbjgyeXhVMWJEYUVL'
    b'c3RpcXl1Qm9ETmJaRElBSDlxRnRsR2lGN0d5VWxGVnV6dQpCRTFqY1RZMEhFU3M1OWdObER4'
    b'VmxLY1JlVEdSNW9ZRjZwVWRiUmxtWFhhQ1BqL0oyT3dNWjVwMW5CU3BhZWhuakVuQktEcmNv'
    b'Ym8rCkgwZFRKYW1XaUNBU21SZzFpaHliWWUzQkZwdU9xKzN4ckp5Ym0ySlVNazFDS0txTlV6'
    b'Z2k2cnF0QURTRUFzRExlTDhla0dVOUo0WjcKY0Q2ajZORUxoV3BhMTZaaUp3Yzd2MUdya3FN'
    b'RkNXQWJEWDN6M2ZsbUxEbGlVYzhNV3ZPaXh3VlhJdlFCbWo0QXZFWVJDODFkdmJ6MApPaUpu'
    b'QWVqMmhTS096dDVQWGhENlc1WHBrMnpYL2o0cW9kMGRzbWlVRm8yQ3lDUlJyeDU4cFN0S3N3'
    b'bEJpbEhYNUJRNm5ZNkpFQnorCk9JVWo0OXYyWkJuUUV4b0FSK0h5aVVqU3lCdGFaTHNmNllX'
    b'OFNjQ21WaWtwTWVnNGhvQXFuQjdDdWlQSXlIQ0x6WGc5Z0t3a3Q2ZVoKcUR1UlpZQkJpZk5T'
    b'a1hkOENvVlFMcHA5aFdaZm9lUk1VVjZXU0daSm43Nm92K1FlenBycDIvTmU5NHMza29wYnRF'
    b'a2xkazh3VWFlNwp0ang1WTIxL25rMGY1R1YzU1BpbXcxT1ViR1lvR29BUlRRQU9keVRGS1J3'
    b'TllaNHpNWEpzUHF6SWlnTzkyTmdDQU5jWFkzVTF2RHltCkpxTEpDNG5nOGdJVVdxQmlBU0Fr'
    b'UXNNU1hrYUFCMDJCbzZFNDdpNjVOeG4wNVVIV0pBRWdkRHN0ditoNDc4T2thNWxvenc3bko2'
    b'Mm0KUlN1dEY5K2wxZXRjSVhGR1ZwSmV4ZTd2Q0I3dENRZ3lsV0xRTURTYmFkWWR0cnYwU2k0'
    b'aVNpYk50OUJqVjJONjNDOGNkUjZ5MTJ5Ugo2TUdlTmNHQTg2Q1lsVUFabENpMG9rekJGbGhn'
    b'VUVESGdzWUFmd0EwTEFBb2FGaFVNQ21oNWNBeEFCRHRVTGcyNlduTkNSdlM4WkZKClZ4WWl2'
    b'RHZTdkNiMXpreDEzalJPYTJ6bzg2emUwN0R4YUZ1enc1bHVvTXZTdFNYSjJtQTA2ZzRMV2lW'
    b'WG1HeFNzblJSc3FsTXQ0OFEKZkhvd0wwN2hhTmhZazBNRGlmTEF0UjdOWHFRYkVBWllDaXlG'
    b'UXBtYm5ZcGJFeFFYNmJuQXlOdURmWHUxUFc5WkNZRjNqOVk0STBncgpCalkzK2F1MGNvVFdG'
    b'VVQ2MXh1VFZyZ1p4UXNSWE9Qbi9lbG04NjBWQlJrV2c0SlZOZmJ6SEt0WVYrTUlDZ3hMMHdB'
    b'VURKMXEwZ0pJCm9mYjIrblM4Tkw1VTE3aGI4ajNXazNEM1JmdEVFRHNqQVVqVm9TQkxxa2dI'
    b'eDZEUWlxeHNFUlNPaVJLdmtuTk5NS3NRYmxhNlBqY3EKRTBWUWtQeU1IS1pGTjhPb1pkZFhC'
    b'b2lVYjc5V21TRkVlN2x3b3lyY3BIU3VOeVd0Y0hlL1kwMjh3cTFJRWdGczdtaHI5MUU1aGtx'
    b'YgpYbmxIUldwNXBoNlUvSmM5N2ZQeWtyNnM3VjVmM1o1cDF1bFVISUFFY3FnWXF6K3Z6djJn'
    b'cW1oY3RkaDQzRHZUK2Z5emllcmdWbWNvCnBJWE1JcUtHT0xJbjV0NnFWNlh6blM4a251NGY1'
    b'b2g1dnQrNjFBdkFGY2I5VzFGa0xmanJzb05HSldYVmNVcVdsZ20rN1hBL3Y2MVYKeFRKUC9x'
    b'U2t5ZUYvWVh0em16djYwb3hYOC9IK2xOL2NYbU8zeGMyWk1mRE85cW4vZXNudW1ZMXNwRzNB'
    b'dDVjWlJMU0lhaEV3d1pzQQpydzFCMDNFMW9wV2p2WnkrTE1SWlRqNEI0OTZ1QjJDYUY2Q0Vu'
    b'QlR6UkVrUS9GNTdXRk52V1RLd0l2L0N0K0JsMUxzYjk3UUY2cm85CkdnVVNkSW9KVnZYU1l0'
    b'dFR5eldmVmpzZStYdXRKTU9pMVZka1czS3d2cytuSFcvOGpWTXAxQ2g0OTUrZmdWOTBid3dQ'
    b'djBXWHdvRTUKVkg4K0FTQ0hhUDhoaldGR2tHSy9relRjcU94OTM4SlpSSFZ5M3RLYm5zckxu'
    b'QmVMbDBnMHdEZHZhcmtreUxmdHRDTXNJRmxIbFJudQpDNU9sa0FzSVdDVkxXYldzTXloR3hS'
    b'TUZscERYWitLeGgvKzI0SW5QNW95MzVocVBHL0pEdk9KdlZVV2NpVmFtbm55Zm5paFRlM3FN'
    b'Ckh6WW1WYjJXR3FwVkFhQTFzdkc4d0VuOHhVVFF2Q0NRdEdoT3BDYXFFNnduQm45S2FWUVdK'
    b'YWhuQUppVGhnc21ZRklDRVJSL1lKVUwKQXNqc2psU0doR05kWGlIR24xN0ZwQm81TGN0UHhm'
    b'T2hLUGY3RFJYanNMbkc2Vzd1bFc5ZWZGVjVyYlpNd2ZlRWg5NXN3TklFRlByRApuRVNvbnRj'
    b'U0xsclFreFFWZzJZNFU5Q1hqZWp4U1JXK240MjJLaEl2VjdIcUhjblhxOTk0OUxKcEQrY3FG'
    b'VVl0U2tXMm5hTk4waWtiCkV1dWNlSHEvd0V1MWo4M3VMN1lXRkNlcEtRcTkvZ2d2eW1iWDc1'
    b'VjY3Mjgvcnp5elZ4SC9hQzNTNDdQU0xNT1FoWk03Q0lIUTk1MlYKZ1hSZHRNem1MekFGWnlU'
    b'NmJHRkpFWVhXQzFzbkV1em9LSUtXeXloTmZyeG5xMXRPc3VzbU84Q0dLTE9QOThqT0kvMmF6'
    b'RFNOMnRqZwpmczRSMnVtTG5yd25lRmNYdWdNSWkrZ01mcFp2dXFMUHArcnc4SzZRVENJdFN4'
    b'WDM5bmkwbC8zWGl2SFozY2YxUVczN0g1OVBOdmc5Clg0VUY1OWpyTzNaS1VYTVRYMnk3WjNy'
    b'cUh3SFV0MitvN1g3TnIxNExnTWlZU3EzTkwxcjRXZFBra0REYWJRdGRBZXp2eHBTRThnelYK'
    b'R2pBSEdLcGptZkNPRVkzem43eHh4N0hNOGRsSzQvcDg0WUtuYnBSbDJqQlhSU3ZIMEdBZW50'
    b'M1VZQldjTEVNUEtOUHM1RVVLc1JnQQpFVFVXLzhPSm1SbGZkMTQrT244eE4zVDVSR1NidjJI'
    b'VkJheml1cG5rMzAxb1hMVjEycmpsRCtQOHJMMHJxSGFGTkV1bk5iR0pkTFJkCmhBeUtaYm04'
    b'QWliQnhwZ3RGRVZKNGRBeGo2YmVvOTNjYVlrSVRMUlRZWnVhazUyNEZNRE9QWi8xNk80QkpW'
    b'SzBFRkZ0Yi9hOUd1UmIKeDdBTEtFNGU4Z21jUXBHYkluQjEzUWxMbnJ0MlBIZjA4WDVkd3Y2'
    b'VzFDUmphRlp4RDJ0aXVocW9OcS9TUSt1c0Z5N1VUcCt1S0p1dQptRkpLcFNTNTFab0lUL2ln'
    b'eER0cDJoS0tSdEw1YUV1WVc2WG5xSURnSVpTazU1TU5Lak5MSzBUQ2srOStwMGhIbTNOVjVa'
    b'TTE1NWRxCkx5clJWQ3BwVFovUVFrQ3lSWFkycjNRRjFKTitjenMvdm0vYk93ZXVBcnp6cll0'
    b'VGpZSEx5dXAxbFlxUDNqSkVPOE5kaW9hbFB6c1AKd0piMURTbzFsMU9TcjlHNnl4OHE5UFQ2'
    b'TENrR2x2MGFBQnV4dEZWSlVhcFgxUHYwTlNXMnllYmlzb2xkVFU1WkZlUzVvTXBNUTJKMAps'
    b'S1g3VUpCVE1ZZnJlcysvSnYxUTZLdUc4RjRBQlFJM1ExQUVvb3FTZjEvcGp5akhlZnVjQTVl'
    b'V0FIaDNYM0cyelZzNXBhZHdLdS8wCkpsNXlheVhMc1FBYUQzY0d2UkdPWTNwYlhYcXo1dEQy'
    b'eHE3Ry91eVNGRC92MmZ4YURVWFlnbW1aV2JiY1VDZlZmY3hyeW1WcU5uZlkKajdnbG4ySlM4'
    b'YVFqbjl0ZDdaRytEcGMxMVhoMFQxdDZYb0phcitxSzFwYnlYS21vY0FWVkpRK3Y3UEZxeDMv'
    b'am5Cc1VBdmo0MndJVgpLMTR3dGE5b3dad3dFKzJYZTF4Q3B6NmZKQmVZRFNwemFxNU5yVlY1'
    b'SEg2VlJwRStNVEVVOVdYbFpFeWFrOU93dmQvZlNpcXZLTTJlCmxPSVhQQXl2bXZlVEtjMDEz'
    b'WHhFNkcxekMxRWhlWUtWMVpEaWl4S2pFcDlrU0N0Z2MxSkM5aWFIdXVpaE81MEI5VG5STXVm'
    b'WU5YcHoKSjdaL2RzOTdPaVhmdzBqN09ONUh5d0FZaXJXeWFTWTJ4VUJibGJSYWh0emIxMnZ4'
    b'RlVpOHBGQXBmTTZnSlZVdlM2VGF2eVdySUZYRApHQml3UElsRTVhQlA3bmVKWFVISlF3UDVJ'
    b'bGNxY0F5VTZ3OU5YUDZubjV4RGJYTHUzWVJvVUVVK3V1dkRCWVZ0TW9WR1ZqaktDTUZUClBt'
    b'VElkM09WNXV0c0tXWkh1Q2NjRFNRYVVxaVE2cFBhVjlWNTBWT2RxaHlSblNSeU9wbDJCdFRY'
    b'cjdyaXl5TVR6cTBHT1ZldmxKMWYKMkxyNjFuVlpaaDhCMmhteG1STzdhT2w3Zlc3RklOUFpF'
    b'cHNyc2hwQ2hVWG14VTB6L3ZYOVJlZGlVNXpiRnp0ZldOTDZwK3MyRmlUMwpVeFJFa0c1RzZt'
    b'RmtKeTM1S01LZjh2MGNHdERKdEluUWlSS2RMREVtUWdQd1JMalh0a3gvOE9NRm9uaXVmaXpn'
    b'eC9DcEVZczI5TnZMCnZsNVcxcEJ1OFE5K2hpaENFWUVhbU14bUNEaFFha0xGV0NLQU44SlZO'
    b'YVUvdW03dWVKNTIrVjlFNFFrNW8rVmxVeHNYRmJkT1N1L0oKVFBDb0ZKS1NrUmdRUVdJaUl0'
    b'UG4xemJZclh0YjB0L2RWOVRuMC8xby9uWDhnei9uZnNlTk4wR2N3amppRk1ZUnB6Qk9ZUnh4'
    b'Q3VPSQpVeGhIbk1JNGhYSEVLWXdqVG1FY2NRcmpGTVp4N3VML0E4T2dXMURuV1dFaUFBQUFK'
    b'WFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl6CkxUQXlMVEkyVkRFNE9qQTRPakV3S3pBd09q'
    b'QXczb3hHRVFBQUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3TWkweU5sUXgKT0Rv'
    b'd09Eb3hNQ3N3TURvd01LL1IvcTBBQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1h'
    b'Z2UxMDg0MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_MT')

US_MT = b64_US_MT
index.append("US_MT")
index.append("United States of America Montana")
catalog["US_MT"] = US_MT
catalog["United States of America Montana"] = US_MT
country["United States of America Montana"] = ('US_MT', '', 1)
lookup["US_MT"] = ('US_MT', '', 'United States of America Montana', 1)
lookup["Helena United States of America Montana"] = ('US_MT', '', 'United States of America Montana', 1)
lookup["United States of America Montana"] = ('US_MT', '', 'United States of America Montana', 1)
details["US_MT"] = {"continent":"Americas","capital":"Helena","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["US_MT"] = ('US_MT', 'United States of America Montana', 1)
regional["United States of America Montana"] = ('US_MT', 'United States of America Montana', 1)
#----------------------------------------------------------------------
b64_US_NC = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTY0MiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05vcnRoX0Nhcm9saW5hLnN2Zy5wbmciCiAgIHhtbG5z'
    b'Omlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBl'
    b'IgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9E'
    b'VEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8x'
    b'OTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHht'
    b'bG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9'
    b'ImRlZnMxMTY0NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmll'
    b'dzExNjQ0IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2'
    b'NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRv'
    b'dz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBh'
    b'Z2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9Imxh'
    b'eWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzExNjQ4Ij4KICAg'
    b'IDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAg'
    b'cHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJp'
    b'bmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7'
    b'YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJPVjZuQUFB'
    b'QUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFB'
    b'ZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBTwpP'
    b'a2xFUVZSNDJ1MmRlWFFVVmJyQXY2cmU5eVdkZERheWRHY2pLMWxJUWlBUXdpS2JoRVhralNJ'
    b'UUdYQ09DTWZsemN6VG80UG42ZUF3CjU0MGdPbmhFNUVsUUJvZ0NDandCQTJGSlF2WkVJUHZT'
    b'U1NlZGRIZTZrL1MrVjcwL1dpS0dDQklhZGM2NXY3K0tXMVgzOXFrZjk5NnYKY3IrcXdpRHVE'
    b'L0RiNDJKZk5RNGtJSDRHMU4vbzd5SkpRQXAvSGppNkJFZ2hBaWxFSUlWSUlRSXBSQ0NGQ0tR'
    b'UUtVUWdoUWlrRUlFVQpJb1VJcEJDQkZDSW15d092Ri9yejdOR0JCbm1BY1lxZk9ZQnZDK0Ji'
    b'T1hTWG1Pc1VzQnh1QWdlQVlTdGoyTXcwV21pREJrNy9DS2RuCmlOYzZJRlFPODBpMC9QY3JL'
    b'bVF6UEZreXpjeG9kYVpjc3lDeG4wbnprQ1JnR0FDQXk0UGpHRW1RV0xOS2xCcXVtL0IwZ3NE'
    b'cWV2MnYKdEFSZjc1U1dkd1JxREN4MDNYODVoV25odW9KMHhZWlo3ZUVTazRmQWpIYjY5YzdB'
    b'YkxubWxYL04yTGZoMnVBb2U4dkJPUktlM1k5cgpkN29wK1FrcWpDUzVMTmU4ZUpYM2RMT2Q5'
    b'dnloM0w4OVdhVXpNbGVtZC8vbmtrYVRqWGFvTFBaMFkzaHBjNGpMZzRaeEgwQUJTY2FFCk96'
    b'SmwycmRXVi85elE5bXNXTFdZNHlBSTdFU3RMQ1ZVLzQ5ekthY2JJNVltSytPQ1I4MTIyblRa'
    b'VUVsVEtBblk2OHZyUGl1UHZ0d1MKWXJReGFoVCthUkU2T3BVdzJlbUh5Mk1LWjdjNjNOUm5E'
    b'OHhOQ0IzKzVrYlk0Nm05THl5NGxST3RNVHRvWFZxaGg4RHVibjJEUVlVaApPWk1PWi9nczE1'
    b'c3Jhc3YvY3Fwd2RodU9rK3Mrbk5jM3pIVjZjTFdCVmRZUitNRXpaVDFEdkNYVGxBQVFKTFMr'
    b'Y3pyMXJkVTFBS0FhCjRVVDZtMmJIRFVwNHRqbHhnemY2L0FEQWoyc1BGRmlaTkE5QlFIYVVa'
    b'a2FVWnVtMDN2bTdscWxHT0lsVDlGOXVQMSs4N1h4cXVCNXAKOEhsRVNpeFA2NlhpeE1iOWMy'
    b'c1YvbUVTMHl0SFpqaGNsS0t5MlBmT0oxMXFDWmtScFZFYjJBQmd0TkZkYm56WG1XbHJzN28r'
    b'dVRMMQo2WndPSWNjUkh6ektZem9GYktlM0xqcVZJRW40KzluVXQxZFhlemYycml1L2NIUEtw'
    b'by96UGl1UFdaN2E4K25taXhRY2hUbytIVWpwClZJSWdzU1VwU2hiZHMzTFBJaW5mTm1SaWli'
    b'Z09JZHY1L3ZyeVhoMXZaWWJDajJ1bjRDU0Q1bG1iMVpVWFB5aGtPV0tDREVvZFR4NWcKaUFz'
    b'ZURSRlpnNFJXYjIxTFVwUU9OelZFYklrT05Mei9iVkpDeU1qS0RNV0oya2dnc2RkWDFKRWsv'
    b'UGw0ZG1PdkJBMmtQZ3RuRmliMQp2N1c2V2haZ0xLNlJyNW5lTlMraG4wMTNMMHJxNDlMZC83'
    b'V3N3UnQ4RnBYRmRBL3h1elNDTGkxdnlNeHlPS2xXSitXSGZvMlRQSWFMCnkzSUdjTzFSZ2Ni'
    b'b1FFTzBkRFE3U2dNQXY4dnU5T2ZiOXB4UGZtSjY5ODdUYVFCUTNTMzlxUEJxbE5Ud3o1SkVq'
    b'WUdOZkV3Q2JDd1YKbU10dy8zRkp3K3NGOVRoT0FzREhsNmV1eTJsdlVvblZCdmJpSk9XWnh2'
    b'Q1RkYktyYllHS0lmNGttcUZUUGFsaHVubUpxbzJ6MnNSYwp4KzV6eVhsVEI3TGttazZOd0hz'
    b'cjBxUVNiVHM4cTdRNXhIdjhSV1VWU2dWK01JVmhmcWE5ejFRVXBDbnUzTGYzUXRMMmhUZlBO'
    b'b2JWCkt2ejNmcHM4YkdZOGZIdVJBYWJOczVzWEp2ZW5Sd3dkcTVLdnplb2EyK1YwNDlzTzUz'
    b'NXlKYzVEWUVqaEE4K0ZBUUo3Yzcvbzg0cm8KcnhzaW43eDlXZTB1NnA3emlUS3BPVDFDWjdU'
    b'Ujc1NnhKc0hXK1UwYmM5dlZvOHppR3ZtSzlCNHV3dzBBZWpQemxTTXpTcHFtV0IxVQpxNU9t'
    b'TnpQUlhQakFjMkdIV3RDaEZnREFZMGw5WS92bXhBMWt5clFqRnZvWE5mTEdYaitmdE5jeUlP'
    b'd2I1a2w0OXJXWjNWSyt6VnNvClpEdE8xVVdxMFZ6b2szQW1PdERnM2ZBUTJPY1ZNY2VyWk5m'
    b'YWdveDJ1cS9hTzFFak85TVluaEV4dERDeGYzTmVTN0RJQWdBVW5Jd0oKR2tVS2ZhTXdSbW9B'
    b'Z01ObHNidlBKelg0WXVTOEc2ZUxVdEVSV05FUitNRzNTV3V5dWw1ZlhoY3Nzc1JJalZkYmc1'
    b'RVBIeWhrMFYyUAp2N3Y0N0hmaHY4RENnczdNK1BCaS9PbjY4QmNYM1lpNjNmc1JrNytwQUFB'
    b'cVRvaTVEcTN4VjFoSlNBZ1pibEtKeC82Skl0S2Z6NC8rCndPWW04Ri9GSHdEYzZROHhlWVVJ'
    b'cEJDQkZDS1FRcVFRZ1JRaWtFSUVVb2dVUGt4ZE9Gb2cramRYdU9YSlhIUkJmM2w4OWdJdkZw'
    b'TzIKODZXQ3owOVhteXoyKzNWV2NrVmFUM3JFa00xRnVkb2FmTFV0Q0dud3NjS2k1eTR0Uysy'
    b'OTNpRmQrbzhsM2hMMUI0ZWtmRnZZaSt2NgpocmsvVmRHQ25La2lQbnRlZHV5cGk5L2RvejBH'
    b'elhOeSsvbkZLY3F4a2srdnhXNzZKSThnMENEc3U0R1V4M0tKMkk0bEtjcWZla1ppClFwYm5K'
    b'd1BBc3JsSjl6N3NqWUs2Ty8wQndNYmN0aTE1TGNqRUk1a0xYMTUwdzd0Qmt0aDlBNW1sYzVJ'
    b'QTRQRzg1SHNFTld5NmU5dUMKV3dCUVhDMFgvNkZRK3NJRzd5aTZNa09CVFBoeUlNVnVyL2F1'
    b'emU1OHJUaXpiNWc3YnZtWHlhQXRuWlBvVlRWcXRKRWtLWnNpQ1pUdwpBU0RBajdkOTNWeVZk'
    b'blRzWUlJZ3Y3bmFaTFU3QVdCYXVJN1BjZ0xBcThWWkkxWUdBT3dyU1p3ZE96aEZiRVltZktv'
    b'UUF3Q283Z3JJCmxHdWZuOS8wNnZHc2NiM1E3bkQxcVBSSDMvMTlWSmovM2FmdmZuWE4yTFpH'
    b'Ynl4OHJjanJEd0RpZzBjQXdHQ2xkMm0rVDBZOVZpVS8KVmlWSEdoNUpSUHJlaGFTaTV5NDls'
    b'OS84MTYvVDdsNCtyMnRTcHEzYStlR08zejM5ZU9aUDFYQ3lwSEh6RzUvcFJ5MWpKWHlXQ3dB'
    b'Ngp0WUw3L3F6WitrcDBsL2t3dlpBRUFPVXc3MHhEZUVGNlQyRnUyNFI1TkNhTGZkMmYvdmRD'
    b'ZWN1K0hmL0JZZjBvUzlobWQ3MjYrOVI3ClJaZkduVUtoRUFDQS9ZeU1DcHhPUXdvbkg4NTRC'
    b'MUljeU4zbmt3SGdwVVhmM2VOaUZuMVYrWmU5WjhZVkh2NjY2bTUvQURCc1lnSUEKbCtuNjRX'
    b'NlM3azRKMDA4TDB5RVR2bzlJY1p5ODBocmMwQ3VKOURkNXN6MS9pc2RteFk4cktaaVhUS0ZN'
    b'VUxOeW1Bc0FFUkxUbU1YVgowN3NiM3k0Ky9mSTN5TVFqNklVWUNRQjd6aVhmKzN5SmlKdWZI'
    b'UXNBTHJmbjNVOUxOSG9qQUVqOStEblRaSGNmWEtmd2R4TTRuVXE4CnM2WUt3d0RENEltTWJn'
    b'RG9udFNqTm9qNzlFTHYyUG12eWlqVkNPY2U1NjllbUVxbDRQM3FrYmtiZHIreTY4dTBWVHZM'
    b'Njd1ODVSTU0KcEJiR3Fkb0lBSGhod2EyK1BZZDdkMzlXa040REFNY3FvNUFKbi9aQ0lMMERL'
    b'UUM0UFBoSGwrTHZjZjZhUldrbDExc3pudmliMTl5QQoxcEMzL3QxZEJ5NnNYcGlLWVJOTW9T'
    b'OGZ5ZWtmNWdCQWlNaml2UjBzYlFuNXFEUWVtWmcwRXp6bEd5UzBHbXlNY3pmQ3ZNOXN0Z3lL'
    b'CklpVG1acFg0VkYya3pmbWpDRmJFWjNQWnpLMy9mZFJzZGZ4d0wwK1NKZGRiQjRjTUdJWnA5'
    b'YVp4bFJ0dDlLT1YwUlNjZExncExTclIKa2V2Uld3L2xPdDJVY1lmdDJMcDB3djhCaUltNjNH'
    b'L3lhekdlcG4zb3B1Smg1MElFVW9oQUNoRklJVktJUUFvUlNDRUNLVVFLRWYrTwpDamwwMTYv'
    b'eU8xRDZqTThVYm4vczVvTEV2bC95RnpDb25zTFpiWDllMW9CaytFWWhCWVB6Znp5Ny85bXJD'
    b'YUVqajdwdEdvVlluS3c4Cjk2Y3pCMzlmcWplaEYzWlBrdkc1TSsxcUlZYkI1cnptRGJOYVA3'
    b'MFc5MFZOWkhsN2tOWHA0dzl2UjBtTitmSDk2MmUyejR4UjMyNVgKZ0dUNFJtSHI3VXRKcHhK'
    b'YjVqWnZtZHVzR09LZnFJa3NycEZWZFVrZnZyMzhlTlcyQlRkVHczVTBDaEVzc282VnQ2bUZT'
    b'TVpES1pRRgpHQ1ZjR3dER1liaHNUaXFMN2dhQTdpSCtubk1wT2RHRGVmRURHaVBUSndybFVx'
    b'TXN3S1FhNFY2NEdmWlVUbHRNb0FFQUNBSkxDdFVuCmhBd0RRRjJQLzYxKzlBNmFCMWRvdHRO'
    b'ZVcxYS9LYS8xem4wbmFpUDNQblB0Y212UXR6ZERUOWI0Sm1IM3kyclpGSkZsZXFUMnpWWFYK'
    b'WDlUSW9xVUdEQU1jSnc5dXZreVM4T2JKNmNlclVCTEdnL0g5cXIzRlFmdm11ekMxa1owWE8w'
    b'aW5FZ0J3dGlGc2ZzSUFqK20wT3VtcgpNaFFwNFRvT3cyTjNVdlJtMW4wZnNaZ2djc0hKdEFq'
    b'ZFV6TTYvK2VwaXJWWlhRTUc5cGUxc2cwejIwdGJRMlFCUmdCUURQRUtQODdmClh4cnYvZVFN'
    b'V3JXZnpGem9JdkI5SlFuWE93TGZLS2hkTnEyM2Y1VDdXRXIvb2JMWVRMbTJyc2YvV2x2d3Jy'
    b'WFhPUXgzcmNLL1Z1SGYKbytOMWF3V0tJZDZnZ1dWejBPeHVpdFh4ZlZWc2hwdkxjSEVaYmpI'
    b'WEpnOHdSVWtOMFZKRHBsdzdOWGdFQUdxNkF3NWVpYnR3YThyVQo0QkdUazhabHVvWXR6QU9s'
    b'Y2UrWEpIbHphaEFQeWdTSkYxU2NXSnZkZFdEVDVhMUZ1UVNCdmJhOGZ2ZTU1SUswbm1OVmNq'
    b'N0xGU0swClBELy9GcHZ1dnJPVGpGZ1pGanRWWjJJSjJBNHh4ekgyaFlNeHVyWDhvNVZSNFJK'
    b'ei93aW5UaUhSbTVuNThhcGVIVy8vczFlZU96aDcKLytYeDZVOG84V0x5RVNrQTREaHN6RzM5'
    b'dWo1aWMxN0w1WmJnNnU2QXN2WWdENEVKV0U0UGdhZEc2TjcrS3QxRFlyRkJvK3RudHRNbwpC'
    b'QUNJMkE0UjJ4RXFuaUJqdUVmSGUrZDBhcWpZWXJUUjUwZ0duczVwTC94NDdvcjAxbmExd09L'
    b'Z0FzQkxpMjhjcll6eTRWdHJrVUlnCkNDZ3FpOTI1cGpwVWJGYnF1SjBhd2U2bnk3TmsydU5W'
    b'OHNNVk1aMGFma0ZhcjlPRFhXc04yalQ3Ky9DbnFEeEdiV0QzNmJuOWVzNjIKaFRlRkhGZW5t'
    b'dTk5eDNlM2xxODJzRDhxdkxydllvTFhOMG5DVXpNNnJyVUhiY3h0SzY2Uy9mVjBPdkxuWTRW'
    b'dUFqOWNIbk94S1dUZAp6STRYRjk2Y0ZhTU9FbG93REJxVWtxOWVQUGZteVF3S1RzVDRtK3NV'
    b'UHp5WkZpWTJLM1c4elhrdEpVMGhwUzBoR2lONzFFSnZHUkR0CldGbWJINjg2MHhpdU16SDVU'
    b'SmZKUVFPQXhTbEtrb1RCVWZaYnA5SXZOWWQ0MENQYVBsZm9aV0NVOC9lejB3NWNpVnVVMkw4'
    b'c3JXZFYKdW1MOXpIWSt5OGxuT1RWR1ZrN01vTmJFYWg0UVRRMGF3VEFRY1J4Y3B1dDZoOVJv'
    b'bzIvSmE2N29ET3dmNWxKeHdrTmdGSnhNRGRmZAo3UGZMaU5RQ1FNdWdzRWtsbnI1alduMnZQ'
    b'L3FpNGFOVjZHWFl6RHhTR1hXa01pcFlhSjBabzA0Tkg4cUpVbWRIYVdnVWNuTmV5LzgxCmhn'
    b'VUtyR0tPZzgxd3h3U09ubTBNZHhOWXAwYmdjbFBtSmFnNERCZEJZaFFnTTJSREZlM1NyK29p'
    b'S3J1a2pVby9oNHVDcnZ1ampVanYKaTVEdGxQa2JRLzFNWW81VHdISUsyRTRoMjhsbk9ad2VD'
    b'cERnOW1CR084Tm9wYWtOYk5Vb3AwL1BWUXp4SHZSVGhTZ2k5Vmt2bkpCUgpLNzIrVjFML2FO'
    b'NmZqM2hRMEtvOVVvaEFDaEZJSVZLSVFBb1JTQ0VDS1VRS0VVZ2hBaWxFSUlWSUlRSXBSQ0NG'
    b'aUVuei8rdDkzRjhMCnJMSEpBQUFBSlhSRldIUmtZWFJsT21OeVpXRjBaUUF5TURJekxUQXlM'
    b'VEkyVkRFNE9qRXdPalE1S3pBd09qQXcwYTJTa2dBQUFDVjAKUlZoMFpHRjBaVHB0YjJScFpu'
    b'a0FNakF5TXkwd01pMHlObFF4T0RveE1EbzBPU3N3TURvd01LRHdLaTRBQUFBQVNVVk9SSzVD'
    b'WUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxMTY1MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_NC')

US_NC = b64_US_NC
index.append("US_NC")
index.append("United States of America North Carolina")
catalog["US_NC"] = US_NC
catalog["United States of America North Carolina"] = US_NC
country["United States of America North Carolina"] = ('US_NC', '', 1)
lookup["US_NC"] = ('US_NC', '', 'United States of America North Carolina', 1)
lookup["Raleigh United States of America North Carolina"] = ('US_NC', '', 'United States of America North Carolina', 1)
lookup["United States of America North Carolina"] = ('US_NC', '', 'United States of America North Carolina', 1)
details["US_NC"] = {"continent":"Americas","capital":"Raleigh","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_NC"] = ('US_NC', 'United States of America North Carolina', 1)
regional["United States of America North Carolina"] = ('US_NC', 'United States of America North Carolina', 1)
#----------------------------------------------------------------------
b64_US_ND = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTY1NyIKICAgd2lkdGg9'
    b'IjEyNyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxMjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05vcnRoX0Rha290YS5zdmcucG5nIgogICB4bWxuczpp'
    b'bmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIK'
    b'ICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFRE'
    b'L3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5'
    b'OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxu'
    b'czpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJk'
    b'ZWZzMTE2NjEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcx'
    b'MTY1OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9'
    b'IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'Y2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXll'
    b'ciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMTY2MyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxMjciCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSDhBQUFCa0NBWUFBQUN2ck85TEFBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQW4KSWts'
    b'RVFWUjQydTJkZDRDY1YzbnVmK2RyMDh2T3p0Ylp2dXE5dThyWXhvVmlUTDBRRXhJZ2w3aEFR'
    b'c0NFSk53a0JNaUZKTVNCaEp0Rwo0SklRbkFzWU1ESEZOc2Jkc2lXcjk3S1Nkclc5ems0dlh6'
    b'MzNqNUZsaEdSakcyd2tlWi8vNXB1Wjc1czV6M25yT2VkOUJaZCt4QU1FCmMzaTFRU3B6eEw5'
    b'cUlaUzVNWGoxWW83OE9mTG5NRWYrSE9iSW44TWMrWE9ZSTM4T2MrUmZnRWo0eW5Qa3Z4clJF'
    b'YzV5YmFvUFEzSG0KeUwrUXNDQTZUY3lvUHVmN0lkMWllV0ljVGZGWW14eDkzbnNKQVVsL2FZ'
    b'Nzg4d1YremVIaXhrRzZJck5uSlhOWmZJS1FadUZKUVZPZwpRRWM0ZTliNzFCa1YzdFJ4WUU3'
    b'eXp5Y2tmU1VVSkYzaERHdVNJNmU5dHpBMlJUSlFRbGRjWEUvQlE3QXFNVXIwWnpTRnJyaDBS'
    b'V2E1CnJHa0EwOVdJRzVVNThzOFhxSXFIcnJyVStTcUVOWXRyVTMxRWRST2Y2ckFnTm8xUGRU'
    b'Q0VpeXNGUHNWQlZTUXJFdU1BQkZXYnExcU8Kc3lBNmc2cEloSkFZaW50QmtxOWRrR3BmZFpC'
    b'U0lKSEVqUXFLa0Z6ZGVwU01GUURBOVJRTXpjR3pBelQ0Q2t5WllSSytNZ3ZqVTZ4SwpqRkYw'
    b'ZkFCNFVoQlViVFRGbXlQL25KQnE0ZEVhekZOMWRXYk5BSzVVemlCZVV6dzA0V0s2R29xUU5W'
    b'TVFLT0ZKZ1pRQ0Y0R1FJSVJFClZUMXNWMFVJeWNMWU5PTGtBbmRRdGFpNk9vcVFCRlI3anZ4'
    b'ekFhNVVhQTluOGFzT1FkVml5Z3hqdXlwajVTZ1ZWOGRRWEZ4UEVESWMKVEZmRHB6cllua3Ja'
    b'TVFBbzJRYlQxUkF6bFJDbXF6RlpEbU43R2tsL2lTWi9BVk5xYU1MRGtTcCsxVWFJbWhuNVdZ'
    b'Y3hvRnI0VlllUQpaaEhSVFV4UDQzaStmbzc4VndKRjIwZE1yK0tnME9ncllrbVZwbURocEdh'
    b'UWFJcUhLeFhDdXNuaFhCTlpNOEJFSlh4cUFqd1hZa2FWCjVtQ2VWQ0JQeERBSjZEWjV5MDlJ'
    b'czFpVEhNRlFYTUs2aFpTZ0tSNnE4SkJTc0dXcWMwN3lYeW5NVkVPMEJQT29lQ2lLUkxoZ0tD'
    b'NjIKVzVQV2lxdXpPNTFpcUJUSDhWNjRUNXV6L09Rc1AwZXlqVVIxa3dXeEtkcENPZnlxUTFz'
    b'd2h5VlZORHdzcWRZMGpCVFlVcVgwQ3liVgpIUG0vUWt4V3dpeXZLV0drRklRMEM5dXIyZTBU'
    b'eFFSN1oxdXdQZlg1d3h3aDhlUno3MkRMMno2Mno3UnpPTmZJbXZwUm9ub1Z2K0pRCmNYVUNx'
    b'b1ByQ1d4UEpXLzVzWDdCcytaQ3ZWK3gzUy9hUHlOdG91YTg3Yyswc0dPbTdRemkvYXBEVTZC'
    b'd3l2bUw2aWEvMGJPTDVYWGoKcDY0cFF0SVp6cHpWeER3eDJjUFJRaElQUVVpM2tJQ0hRRmM4'
    b'UmtxeHVUai9sWWJwYWtoWkk2SHE2R3lkNm1Db0dEOXJSdSs2dGlQOAo4NlYzbjByV0ZCMkQx'
    b'WWt4VnRXUG5aTCt5eHNIdUdQREQxa1FtejdqSGxMQ2tXd2orMmViUVQ2ejQxWGdlQXF6Wm5E'
    b'TzIzODUwQjJaClJWZmNVM1k3ckZ0b2lrZEF0YkM5bWlmdlNvV25aOXFacW9SUGtTMWxMVXRu'
    b'ZXlwU3d1NlpWdkxXNVRnbk5ZSW5CWi9hZmQxcHp4cXIKUlBuM28rdnB5eldjbHVselpPMGVB'
    b'UDJGZW9Tb1pRbDF4YVZvRzFUZDh6ZFZJcmowSS9KYy9YR0c0bkJONmlqK2t5VGJub3BQZFZD'
    b'RgpoMDkxRUVnZUdadkhhRGwybWkzL2c2VlBjQ1RieUwwamkzNnA1Mzk0NlNaT0ZPcjR3ZERT'
    b'MDY2dlNZN1NIQ2pnMTJ3VUpHWEhvT0pxCnpKcEJQRS9nU0JYWEV4d3YxSitSaDVoVCt5OFFs'
    b'cWV4YjdZRjA5TndQWUgvWkxKRnlwcjA5aGZxVHlPK3BoMU1kTVZGRWQ0cGUvNVMKVUdkVUNL'
    b'ZzJqcWVlU3Z3OGc5M3BWbFRoNFZmc1V4TXhvRHIwUkdhWkg1K2hPNUltWXdYUGFlTFBlY2wv'
    b'QnN2cnhsa1luOGJ5VkFTZwpDUmNwQlBjT0xUNnIybjBtc2ZQejNuekNWOGFuT21UTndNbUVr'
    b'RVBTWHlacitjK2FBd2ljREJ2UGh0WmduaXRhK210WlJEeHNlZEtrCmVJSytmTU5wNW1OTzhu'
    b'OEpITWcyTTEwTkVkRk5ncHFGRklMOXM4Mm5pQS9wMW1tT211bHFaeEN2Q01uMWJVZjQ2dVhm'
    b'd1R2cHN2bFYKbDY5ZWZoZlhwSTRpQkdkb2lwOGxQbVpVYVFubUNaN1VQbVBsS0pPVk1GTFdu'
    b'cWNMRjUvaU1GeU9ueGZFbnpma2UxS3dkYXFEeXNsYwp1MTkxT0ZGSW5IcC9WV0swNXFsSFQv'
    b'ZlUyME5aM3RLNW42aHU0a25CVTVOZGZHenJtOUJQcnRJSklmbUxuZGV6ZmJvZEtXdmsvNitW'
    b'CkQ3RWtQbmxHeEhCMXl6Rytmc1czVHJ1K2M2YU5vRzVUN3kranF4NnpacENEbWFZNWIvOVhq'
    b'WXFyODloNEQyL3Yyc2VXcWM3VEVpdUQKeFFSL3ZlZHErdktuUzF4RG9NaTdlM2ZTbDJ2Z1lM'
    b'YUp3V0xkR1JtOWJUUHRwMTczUm1aSStNcW5yZTAvNDJOc251cGtvSkJBVjEwNApxUkZ5bHA5'
    b'Wk0wQ1R2MGpWMFhoa2ZON3pKbzdtYlA0dmliWlFqblk5UjVJS1VvWE54WGJTenhOcmQ0U3pa'
    b'NDMvbnd0UjNTUnYrL0NwCkRrSFZKbXNIVG9WNjlYcVpLMk1uaUhrMnVMVzFmajNvVUFpcS9I'
    b'QndLWG5iTnhmbnY1d1lLY1g0aTlJT1docG15ZlFsdUg3eElIMngKT04vTkxXTGNqQ0lFdEFj'
    b'ek5BYUtiSjlwZjFIRVF5MnRLd1M4cHJtZjMxMjRoUTl0Zmh2cGFwRDNOKzVpcVpsQkxRcWl0'
    b'bzF4ck9ZZwpTdURCMWhieXZqT0pEMmttSmVmY25SQXE3UmQvNmx3bSs1THdNQ05Xakt0aUo3'
    b'akJPRWFiVzJSWklZTUllVGhaUDFwcmxjYTh5WnJZCkdDWERZS2dhNDBOTG5tSkQ0ekJicHJv'
    b'd3ZaYzJ2ek5XZ0txck0xR0pjbXR5Qnd0bmkvZ21WY3FOSGxwZXdRMkQyK2dnREVreTdiSXAK'
    b'MUlLcHFLZDhoQTgwN1NCZGlqQXIvWE5xLzZYaTQrWU9ncWtTM1VkdGpLd2d0OXdtVWJhWndz'
    b'LzJSSkxsVnBwSTFVV2RVaWwyZU55dAp6R2QzdVpubVFPR1g4cnFGZ0RxOXpLMmhYYlJNMlFU'
    b'OEpxNnBNdFRnWjU5Uno1NXlNd1hiNEk3TVV4aEprd2tsaUltR1dwVTRRcUZoCnhPT1BVeHZJ'
    b'Mm9FNXRmOVNjRlh3QkxQWkVLMjdiRlRQd1RiQW54Zms4VkVKYW54OVpoVkpvOFFINm5mVExV'
    b'cm9CWlViZllOVUF4cGIKYzIzUHh1U1JLdi8xN2tIcWd5NTNibzl4NTZFbDVJb1ZTbFhyT1ov'
    b'ZDdzdnlPNkc5TkJhcXlFWkpwdUxucDlFVUQyVG1uZlk1VjVkWQpWWTBXeDhUR3hqaWhBeTZ1'
    b'WC9ER1JCLy9OYmx5VHUyL0ZBdzdVVjdUZWh4ZjFPTHByanIyTmNXb0tpcXVGT3p6Sjlodk5W'
    b'SjJEYmFXClcwazFabWd0VlJFSm13VlduaE42aEZtNzVnait6elZUM0x5eFNESXN1V1pSaGN1'
    b'V0wrRFR0LzhobVh5WlhYMW43dHRmRXgzbE42MGoKTkxzVlpGbGpJdUxqbjZxcjJWTnFPZU96'
    b'R3hxSGlBeXJsQ28rMENTRFhRWjlyV0cydHNXNWUzcnBPZTM5bjNmZS9uTW1MSVRrMW9idApM'
    b'SnZLb2ZzY1ptTWFmNWU1aENrN2hBSmMxenZGd2VrdzkvOXVQeTFSbDVtNld6Q2FMK2YvL21n'
    b'Ym4vblB4MnFTSUR4K0k3bVBTMGZTCjFJMUJwVW15c3p2TXYwMnZlODc5QWJyaXNycHVqQ2Fs'
    b'eFBaaUsrT1Y2SGt6WnVlOHcvZENJUkhzS0xjeXYzbWFxTFNwSzdrc2o0K3oKdGRxR0tWVm1L'
    b'd1kzTFoxbTYyTUtMVTAySGY2OWZQaVQzK0REdDl4Q0pwZG5mbkVUN3dvZFl2MytJb0ZaUVhx'
    b'aDVQNkdWcjR4dlFydgplWEwwbmxRWXJjVG9LeWRQN2ZxZEkvL1hOQUcybDF2cERhZXBMOXI0'
    b'eTdDaWZvd3Rab3FDcldNVnk5eThaZ3d4Sklra0JGZHNYTWI0CnhBaS84ZGJmSkh6M3d4aERN'
    b'OHgwQy9iM2hQa1BkemxiYysxY3lMaGcxUDdQcStLUDFEOU5wMVhBUDZGeG90M0hoQXl4Wml5'
    b'RExqMUcKcmx6S0RTMEZFbTErbVBjMkhEVktVZXZtVDc3NGYzbmtxUGVpOXYyZDE2YnlRdnhU'
    b'dHFmeWhabUxlVkp2b1dUckxOcGxzYkU4VHJsTwo4SzFrTDUvZTBzSjk0aEtpQ1FmcFZ0SGNQ'
    b'SkhxSGk1WnVlaFZRL3g1Si9tTk1ZMjRMQkVxamFFTGw0bzBPT0sxWUVuOU9iK3pORHJKCnNt'
    b'S0dKOHgyeHZUUXFldE5NWU1IUHJFVXg1TzRIa2drUXNEMW56dElwbVMvZ0lHRDFkcHhWblNF'
    b'V2JjZ1NUazNpeTFCMFNNVWxDQ0QKWm93ZGd5YUh4OHR6NUw5VUxHd05zQ0hsMGFPbGFZN3Js'
    b'R1puR1Q3YVQ3NVV4WEVWT3ZVWkhuV1dzOGwrOGJ0MnZ2UytYdDY0dWc3WApremduejJWODRN'
    b'dEhlYW92Ly94bUJZZDMrWjlraVRMQ1Vic0JwSWN0TkZSWksyYXE0Q0VVQlQzV1FQT3k5WXg1'
    b'TWU3WmxXY3FiODBsCmVWNEkxdmRHK0kwMVlRWjJicUc0ZjVCUnA4d0FPaEtKZ2NTVktpb1dP'
    b'Uy9BRGRvT3l0SmdwOVB6b3A1eGJLSkNzUnBGMXhUS3BrdXgKNnJKaFh1Z1hrdjk2ZlJmcmxl'
    b'UHN0Vk80Q0JTaG9PRWlFUWdoaUhhdFJORjBqRWdEbmlscEVsbHV2elJFMm90ejE2NGNnOVBt'
    b'bkxkLwpOdFNIZFQ1K2ZaSmxFWlA4VEI1L09JRWFqR0VwQWRSeUdsdW8yR2hJSVpGQ3haV1Nr'
    b'aGZnRXVNWVExNlNXUmw1UWM5cGp1bTg5OHBHCmZKcUNvb0NxQ01JK2haVWRZWDZ5TjBPMmRQ'
    b'YVR1YXUwQWQ1ZzdHRFFyYWZnR2FoQ1lxRURFcDhHZFl1dndCZEpZdmpER0Nvb1N1MWMKb0dr'
    b'NkJPd3lyMStkWU4yaUpJZEd5NVJNYjQ3OFozRDk4aGp2V2FGVHplUnhIUmVCd0pXU2dEOUlN'
    b'RjZQa3V4R3NYSTR0a2tBRXlsVgpWRHdjSVpFb3JOUUdPZXEyVXVUNUYxTlNkVDcrL24wOU5N'
    b'VjhHSm9nb0N0TTVtd0tWUmZibFNpS1lQUFJ3aG5mYTFlbWViZnZTVEtFCnlMa0dVcXJvd2tI'
    b'QlF3OG1pWGF2UXd1RTBWWFFOTkNFd05NME90dmpHSWJLMGhYdGREUkhtZDhTNEYyWE5HSzZI'
    b'Z2RHeXFlV2pGK1YKNU1kREduL3gxbGE2MVNMeHFJK3FJd21IZkZpbWphNEtUQStFbE9pNmlq'
    b'L2VpakFDV0xhTE5DdTRpa0NpVUpVcUlXR3hUQi9paU5ORwpoYk1mb1RJMHdhZmUwY0hLOWlE'
    b'eG9FYkVyMUkyWGZ4Nnpjc1ArUlZhNjN4OGU4czAzczhJWmxTVWVaLy9FVUxDWk1TS29RaUpG'
    b'QUlWCjhEWE1JNXlhUnpnY1JsV2dKVlZITUJha3E3dUIrcmlmM3U0RzJsdmpKR00rSEFtNm9v'
    b'Q0FpM29qWExvZ3l0N2hDcG1TOCtvamY4TzgKTVAvNC9oNVdkSVpwYW83UjNWN0hvbmxKNnVz'
    b'akJFTUd1WUtOb1hnSVJVT1JIbjRkQXNFSVJxeVJRckdBN1NsSVdUc3dhYUVTVTZvcwowNGFa'
    b'bFdIUzh2UlVhelNnOHVrM3h1aXFWNmlMaFpqTVd3UjlLck41azRCUHhaTVN4NU1rSXpyaldZ'
    b'dERvN1ZESGo0YzN1Ti9qSlNTClljU0xVWkVHbnVyRDM3U0FlTmNLQW9sbWRMOFB6V2R3MGZw'
    b'TzVuVWxTRFZHaUVWOFJDTUJMRWZpMHhVc1J5S0VRRlVWWENuUlZZVmsKUk9ldDYrdVp5bHYw'
    b'alZkZkhkNitLZ1MvZDMwTDc5bllSTWl2NExnUzAzYlJoSUlqUFRSVndmTWs1YXFMb2tqNmg3'
    b'TTRsc3Z3U0E2UQpsS29PUGtWU3ljMlFteG1uYW5tUUg4Y25iQko2aGFRb2NNRHRZS3M5andr'
    b'WnArQUZ1S0g5RUN2a01STEJkcUl0TFpCb0owQ1Z6UEY5CnJIalRUZWlhWU1zUGYwUmZYdWM3'
    b'dzYxTW1nWXBkWllialcya3hBelRYb1FaNG9UOEVjS2RTd2tFZ3FnQmc4WllnSjdlSkltNEgx'
    b'MFQKMkxZRUNhNEVWUUcvTHFqWUhoWEx3NitydFkyaVFxQUljRDFKeUtlaUNQam5CeWY0MXdm'
    b'SFQ5TTRGeHo1QVVQaGN6ZDFjc1dpR0g1TgpJVjkxOFdrQ2dRQWtIaUE5MERTQjUwbFVvV0E2'
    b'SHZVUmpVclZaU3BuY2VEQUtMbWlSYVZzNHlFcEYzSVVwNGFRbVdFOG9SS1FKbzFhCmdZaW9Z'
    b'S0xqS0JvRFhVdlltbHZBbGVFOUxMRDZFYmFMUHd5SGpWN21PeE9VM0NhY3pCUVJYNUhqdmhR'
    b'SEJ1S3MxZnFKaXlMcFFDZDUKbzVsSSsySU1WVUVDOWNrUTBWaUk1UXNhMEZXQjdVcE1SNkpy'
    b'TldKVkFaNEV4NVVvUXVEVGF5bG8yL0dRZ0tZS2ZMcEMxWko0bmlRUwpVTGxuUjVyUGZHK1lx'
    b'dTFkZU9UWFIzVCsvcmU3V2RVWnhwT1NjdFVqR0ZCd1RxcEVBQ2tsQ0ltaEtsUWREOWVEV0VE'
    b'RjlhQm91aGlxCndIR2hYTGJJRkV6U013V0d4cklVODFWY3o4TE9UbEF1NWxEekV3Z0VxdUxR'
    b'M0dqeXI5YTdtTFJxbXpnMTRSQldxeFRjMnVHS21GYWkKTnpTRjVTbE1tbkZ1Qzk1TllDcEhK'
    b'ZHFPRTJ5RittNVFOVUJCRTVLRzVqcmFVakdhR2tLNGJ1MDMralFGVFJkb2lrQlhZR0NteXZi'
    b'agpSUzVmR0tPMXp1RDcyOVBZcnNlTnErdnhHd3FGaXNlaHNUS3JPa1BvS2hTcUxvYXE4TTJu'
    b'cHJuang2TVhWcHpmbGZUeGJ6ZlBwN3ZCClQ3cGdvNm9ROHF1WXRsc0xpWkRZcmtSVEJZYW1r'
    b'aTNiaEgwYXNhQkNzZUxpMHhRTVRRRXBTWVJWVk5VZ0VqYm9hSTNRMHBiQXJOb2MKUDVFbEg0'
    b'MFRNazJLRlJNNWRZUktvVUIvS01ia3oremVkYVJHMWdtZmVwMXpRdXpNZFFQd21zUitMUDh5'
    b'bkFXTmlFQUkyNjVKYVRRVwpJcFdLRVEvNzhQdDloRU1LaWdDcENLVDBNSFRCNGRFSzM5bzh6'
    b'Y1h6SWl6dkNKSXR1N3poOHdkWTJ4WEJFeDVianhiNTByM2pYTGNpCnptVUxvMnc2a3VmUHZu'
    b'MkMzOXJZeU5zdlNtSTdIdW1pYzJHcC9lYVl6amQrYnlHdGRRYjVza1BZcjJHNUhxcXFJRjJK'
    b'aDhSUWExSlQKdG12WGc3cGcyL0VpVmN2bG9ubFJpcFpETEtBaEVKUXRGMVVSMkk3RTlpUitY'
    b'ZUI1VUxKY0RFVXdsYW5TM3o5TnRtQ2llUlBzSGsvegozYW1MWDlCdi9XRDNvelJGVjFHcGV2'
    b'ajhHdkdJUWJLNWpzWkVrS0JQUTFGckJrb0lTYUhxWXRxU25rWS8zM3M2VGE1aWM5ZVdOTVBw'
    b'CkY1L0lhWXdhdlBQU0pHMTFQdjdrbXdNWEJ2bjFZWjJ2M1RhZjVxaE8wS2RnMmJWenpoRy9T'
    b'c1gya0JJaUFaV0pyRTNBRU1TQ0dtTVoKa3kvZFA4NzN0czZ3cGl0TXNlcnlsWnZuczNlb1JD'
    b'eW9zTFk3d3Vpc1NTcmg0NUVET1Y2N0xNYUphWk9PZWg4VlcrSjZrcXJ0a2kvYQptRTkvazND'
    b'cGkxMXFQM2ROTFdKbm9RdjVIR3YwU1QzSDMxd3hSakoxRWJtaVNUQ2cwMXdmeFBGcWlTRFBr'
    b'eGk2Z3FZS2pveVZXWm9LCjhuaGZudi9lTmtPNjRMSjM2UHlwMXZtS2tQKzFXK1l6TUYxbFhV'
    b'K0VFMU1WVHN5WTNISk5DLysxYVlybEhXR1d0UVg0K2hOVGZPdkoKYVY2M3FvN3R4MHZzR1Nx'
    b'aWFDYVdlV2E4L3JZTjlld2RLblBUcFEwOGRTVFBnWkVTdlUxQjNyUzJqdDRtSHlHZlFtZERn'
    b'S29scVpvVwpRMy83dDd6MmM5OW0xK2YvRDdHTHU4aG5EOU0vTW9DYVdrQmg1aURSdW1iVXFr'
    b'Mm9iR09heDJsNXg4ZFJOQjlCUTZWcVNWUVZOQVZjCktSaWNydElTTTNqc2NKYlpvc09EKzNP'
    b'czdRbnozUzB6cjRpVGRsNUtmcmJrc0xBMXdNSFJNdk9iL1ZSc0dFbFg2V255a1M0NDVNcTEK'
    b'ZEdySXFGS3kvTlIxSDBmNmJNcURIVmlWRjE0QUlSSFc4T3NLbHkrTVVUWTkxalROc21yN0lk'
    b'YmYrbkd5Qi9zb0RvK3k3UFpiZWVMOQpIK0hxNzN5RnAyNzdZM3JmODNic1lvbitlKytucjMy'
    b'TWk2OTlCenNHOHFRU2Z1ckNHbnRPbExoa1FaZ2Y3OHl5ZjdUTXdaRUtmUlBsClduaDVIdU9j'
    b'VzlWcmlHVFowSFdJSjZ3NFd0TTAxWFE5NVFOTFgvTDlPaUlaL3QvR2J2UlpTYzlOYjJIL0Y3'
    b'N00wby9ld3RBOTk5TncKMFJvSy9ZTlkrUUtkTjE3UFQvL3BGcjVZM2toN1k0Z0g5MlZwaVJz'
    b'TXpaallybVJGWjRqdC9VVXVKUHphZHk3OC9ObjM2VUtjZUtESQpIeXpjVE5KZmhLWXBBbldu'
    b'RjFCZTBkYi93dklKd21TUk5VRGRzaVhranczZ1dRN0o5YXVaZW5JckxWZGV4dFRtN1RSZHRw'
    b'N00zb01NCkg5M0YzNHkzOGZSQWxlOCtuU1piZGprMFZxRmtlVml1dk9DSVB5ZklqelZNRUZs'
    b'OGlFRGJNRWF3TnNCMzc5cUlrQW9mVEJ4anBUOEgKYmFPSW56aysvZHBGTzBpR2N2ZzArM24r'
    b'bU9RS1pRK05ib2JwRTA4U2FHbGtac2NlbWpkdVlHckxUcExyVjVMWmQ0aTZaWXZKRlBkeQox'
    b'L2MrUjF0dWtHWEtDVjR0K0xXU0gvQlZ5RTAzWTQrMklsc21jRGZzSnJENEVJNHErZHFtTjFD'
    b'eC9Md3JPa1NxZVpSQXNFUmQyeENxCmFpT0JpM29PY3YzU3JjOTU3d1ZpaERZbGpZN05VOXYv'
    b'bS9qbDY4Z2NPRUo4eVVLc2ZCNGhGTlJBZ0w0SGY4VGgraWxHeGdWeFVXQzEKY3BTVU12MnFJ'
    b'UC9YdXJDalJZcUVseHpFYlJ0SEExVERSSVpMK0ZzbmNFMC9CL3FXc3JMdE9QWENZWGUrRVJj'
    b'VlpkRVJlbHlQcGMyRApMR2djNWFuKzVWaG5xYzV4cGJJWHY3Q3hoVWErckxPb040cVk4SWow'
    b'ZEZJWm0wUUxCeGs0L0IwZTJmTmRqZzZIY0ttVlgvR0VRaFVmCjQvTEZsVlBWVklGM25tMkYv'
    b'Ylh1NUVucFpkYUpITUoxd0cvaTEwMkU0aUlWbDlLeVVVcTJ3WU5qQzNsOTV3RVdKWWU0N3Y0'
    b'dzk2TXkKMEFzYm9sa0FGcmNPc0cxZzhSa3EzNmZZbU9qNHNNQ0JIejEwTjIrOTdQMU1QNzBU'
    b'cnluQW5xZSt5SlBwSVdhelBqVGg4b3hWRVZLZQpxdHp4QzAxV1VHTkRUNWlleGdEcFFwVWY3'
    b'c3hpdW5LTy9CZUM0OU1wMHNVWTZ6cVBzTFIxZ0lSUndFVlFyZ2JRS2lIOEtHaVJXY2F0CklO'
    b'YzA5RE5UdDRLeUNITlVGSG16cStOWGJWVE9ETGVTSW9lS2l4QVNwMWFrbGNrWmwxM0h2MGRN'
    b'RDlFM1BzU0p5U0N1RjN6VzlnbE8KSHEyU0ZPWHpINjVNaEZTdVhSS2pNU0tRcGtWbE5vMWFk'
    b'ZW1KZWh6T0NPUWMrUzhNMlVxWUJ3K3Y1Y0hEYTUvM2MxY3YzVWI0NmtseQpzMjFFTW5GMlJl'
    b'TmNFcHBHdGVIUHgzZnhWTGlSaHlLcFdsNUI1SEhRTUxDeGhJYndKS3FBemZzcUNGSEZsUkVV'
    b'NFJJU0psVU1GQ1JLCmJTMFJWNmlrbjJNcm1CQ3d1RjZ3cGxrU2R2SWNQMjRUSjROUkdzVXAy'
    b'MHliQzVDRTV5VC9sMFUwVUtZck1VNWRxSWdRSHRQWmVycGkKMDNpakxlaU5FK3dvTm5CUmNB'
    b'YmRjRGd4cjRvNzhhektEMUZsaEVZU29RQU5EUW1LdVZtcTJWR2trUGc5RXdXSkxYVXFVaUFV'
    b'cUtLaApJdkdFb005TE1TdlBQRzgzTDZHd3RsRVE5NE1pQUNTS25hY3lmUVFwcXp6cXJpVXR6'
    b'eC9pejBueUc2TVpibHorRkN2YWo2T0kwMVc2CjR5a2tJam0rdHVtTkRKV2pQQjJlb3FWemlI'
    b'dXJLMG1YYWxKdjRPQ0Z3cnh6MVJqN1MvUHhxMEVhV2x1cGxIcVFWb1Z5SVlOYnlxTjYKTnFX'
    b'cWcyTkVDTG9GaXVVSzhaWUlmM1d0dzJjZnlwQ0tXaXh0THJNMFdTRm9hT2lLNVBCVUE3dEdH'
    b'M0JyTzdRSnh4TGtwZzBlY2xlUQpsNkc1RE4rdkFzbHdqcWI2U1dnYm94aXNVblYxdkZLSVdF'
    b'Rmp1Vk9pTHBWbGZMb1puMTdQZGN2NzJEL2V6T3hVRzNIZDRycmVOT3U2CkhMNnlyWUYvMmRy'
    b'TmwvOW5EN1BUZVVvbGkreE1FVnRLL0g0TjAvSXdESTJLQTdsQ21YL2I3ZEVWcS9Eazd4L0Zq'
    b'NFZsMmJpT2g2b0oKREorQlVBQ2hjc2RQRjNFc0hXVmYycU52eWtFUkRoWHA0M3pFT2FuMmM2'
    b'Nk8yWkRIR2V1RWJBd3JGOGYxRkZZVVJyZzJzcC9QakYvQgpwNjg5d2J0WFo3R3RldFFlQjhm'
    b'cHh6RnRoS3F5Wnp6RVh6N2N3VzNYTmJBZ0ZjWnRDZE0zTUl0aGFEaVdnK2JUcUVzRWFhd0xJ'
    b'NUQ4CjRUY0hjV1NKM21pQnYveXVueWs3eFd2bXcydm1qOUZUNTJIYkZqNmZnVzI3V0dUNTVx'
    b'SFFTYWRPQlhsK2xscy9kMjIrclZQYXNmYU0Kd2dZUFIxSnNkeHZJRlh5c2JSa0J6OEV3Tkt5'
    b'S1ZUcy81ZmN4bVpXczc3Ym9pRlo1eDRZR3lyWkVBTXNYMVpQT3h3anBDbzZzN2FlWApudVNo'
    b'dlRNd3ZJZlhhMmtTNDBVeUNBekdlY0M1bktOVGRmeld4ZjJNek5helphaU9iRlZoeDZUSGhY'
    b'S3k5Wnc4b3UxNUt2S3NzYmJBClZHcnpkU1JiaCtONWpHUTFJaEdWMlFwODVJRkcvaXFUcDhr'
    b'SjRMa1JWc3hyWTlQaFBPdTZJK1RMRGtGRHhhVzJoN0JzZVZRc2x5L2QKdVpuRnptR0NXSUNv'
    b'YmNrR1pEbUxIV2xqODJDQ0h4MkpNcFFOOHVTb1FkK013WVdDOCthZ3BxSjRCSnNuaURST1VD'
    b'eEVpYmhoWGh0cApKR0ZvT05Mamlkd1VuZUV3ajBmM2tsTnQ2dE54c2dlVzg4ZHZibU00YmZL'
    b'SGIweXg4MFNKeXhmRXVHLzNMTm1TeXowNzBod2FtT0ZTCjdTRHRZaG9MRmFRQUlabFY2am5z'
    b'VzhWUVVkUWN2RjhUMmtJNXVpT3piSjdxckcxeit4VjI5ZmlWazc4d1BrWE1xSElzbC95Vk5p'
    b'SUkKaGdvNGpvWmxQcHVBOGFrd1B5RkloUlR5bGtmV2dzNkV3eFBSUFpUQ0pZTHBPTlVEUy9B'
    b'OGxSdlcxckZ2c01RSHIydmxzOThmSmw5NQo5amhXbHpMSk9yVVBIeVlsNldlSHQ0QmhyL0Zs'
    b'SjdiZVgySnBmQkpGU0xiUHRGSDh1U0tPdnpsdko5ZW5qbkR2eUdLQ3FzV3hmSkl0ClV4MVlu'
    b'blp1a2U5VEhXNWJ2Sm1PY0laWk0waFVyL0pIVzI4NFBUUG1LL09CUlUvamVZS1JjaHpQRTN6'
    b'M3hBcnFmV1ZzVHlIM005VXUKZnlsSHhqRFJsdStuR2lsVFZ3eFFQcndBcy9qOHRYTG1LeU5v'
    b'ZUJ6eDJsOXdldmRGYXk4aGllbFYxaVJITUQyTno2eTluKzB6N1RpdQp5cUw0SkgreTdZMm5s'
    b'WS83NkxMSENhZzI5dzR2cGlzeWl5ZkZHYlgvendtYjcwcUZEWTFEZlBQNEdseFBvUzJVNDdH'
    b'Slhqd3BNQlNYCmp5NTduRnNXYjJIV0RHSzZHcWx3bnJkMjdlZWloaUVVSWZuSFMvK2JubWlh'
    b'ZzlrbTFpVkgrSk1WajdBNk9jcXhmQU9GRjFuVzFITTEKNUV3U1gxMkdqdVFraTlxR0dEb3hE'
    b'L2s4bGJGbVpaUVpHWHNPWCtPbFFWZGMya0o1Y3BhZnRsQ09QMXp4S0o5Wit4TU9aWnY0MlBM'
    b'SApxVGc2OXcwdllxUWM1OTZSeGR5MmVEUFh0L1V4WTRZWUs4ZllNZFBHcHNsdXhpdFIyc05a'
    b'N2h0WmZPNDZmQ0hOeGxCY0hocWJ6MEFoClFkb01jVVZ6UDEvZStGMGVuK2hsZHpyRlZ3NWZq'
    b'Q3NWN2hsY3lnT2pDN20rN1FpTDRsUFUrYXA4NCtoYXZualJQU3daTFNGK21xQisKU1BMbUZY'
    b'dVk5Zm5vTDd5NFZUYnBxY2laSkRKYVlGMzlDTWNMU2F6Q0sxY3BxejJVNVY4dSt6NDN0ZTVs'
    b'UmZNb0M2TFQzRGV5bUxoUgo1ZTNkKzVpdWhyaGwwLytnN0JpOHB1VTRVNVVJajR6Tlk5TmtO'
    b'Myt4NWdHQ21zM09kQnVTbXZDOGI4RjJIaDZiZis2U1AxU004LzZGCjIvQXBMb2R5VFRoUzVZ'
    b'TkxudUtmRDE3Sy9TT0xHQ2drZUZQSElUb2pHZDdadlplN1R5em5SME5MV0JDYkpxS2J4SXdx'
    b'a1RGQjliRWsKaWdlS0pYQ09oOWpRTWtocjV5emJaOXBlbEdSS1Q4V2NhbUxjZ0dEZExQblJW'
    b'NmJBMHFyRUdIL1Y5U0NWZTV1b1BwMGdPS213ZlA0SQoxOHcvVE1reHFQZVYrZUNUYjJlc0hP'
    b'V2p5eC9uYTBjMmNERFR4Rmc1UnNZTThzRG9RdjUwOVlNc2pFK3pJRGJOcllzMzgrMytWUXlY'
    b'CjR1Y3UrUkxCazVQZFhKdnE0NDZMZnNoNzUrOWd4M1FiM3htb1ZhR00reXJNajg3UUhzN1NF'
    b'Q2p4NCtFbE9GSmgwMlFQdlpFMFY3VWUKSjdNN2laeCtWczBMQ1ZxK2taYnlMRmV2UGNTdWJP'
    b'dUxNZ1BTVXloTnRxQjZDazQxaVBjeTE5eTVOdFhIeHlKYnFmeWtFYTFhbTZoSwpXYUV3RUNP'
    b'NVlvYjJhSVl2SGJpY3h5WjZXUnFmcE02bzBoSE9jazJxajkrYXQ1UEh4bnZKMjdYbWpyY3My'
    b'c0wyNlhiK2J0K1ZITXNuCnovMDQzNU9DYlRQdCtCU1h0UTBqZkh6cm02aTRPa3Zpazl5eWFB'
    b'dVBUZlN5YzZZTkNieXpadytQanRkczhaTlQzU3hMVEZCZmNISEcKbmoxZnJ3VURYUGZqTzVt'
    b'NmJ3L2Vyanh2V2JVSE15ZzRuSHR4M25pMUdIMVppUmNDUHJCd0srOHNIY1BhVkkveWM0NnJZ'
    b'Z3VVWnBNKwpFdnoxbnRmU0VpeXdKam5LZnh4ZHo4NTBHMDlNOUxBcm5lTDNsMjdpMFlsNWpC'
    b'Ymp2SGZCZGo2ejYxclM1c3V6YnZDeWpjWjBOY1MrClRET3pacENrdjhURlRZUDg2ZmJYc3lm'
    b'ZFNuK2huanVQcmVXQjBRVmMxM2JrMUtUNTAyMnZKOVBsNGdTZUhiblZuL3dZTXp2M1lxWXoK'
    b'clBudzdWVHViZUhkTThmNSs5VS9QR3NUeEY4SElycko1MWJleDFWSFozQ2VqaVBPRXJLNEtq'
    b'aFJqMC90dUE1UENqWTI5L1A5d2VYRQpqUW8zZGg0ZzRTc3pVb3B4NTlFMXJLNGZwZXpxekpy'
    b'QjUzVlN6MW55QlRCMnN0dGtLcFRqTy8wMTFYOWp4d0UrdSs0K0d2d2xIaHZ2ClpYWDkyS252'
    b'VkZ5ZGorNjlrZHpWWmR5b1MrcmFLOGozRDFJZW5hVDdmOXpJN080RDlMN3pSbm8yM0V6VFl3'
    b'MThvZTVCUHJ4bzB4bWQKTVY1SlhOcDBncThzL2o3dGo2bzB4RGRnUk0rK0Y4Qy9Mc3NkQXh0'
    b'UGRRUFRsRnE5djArdStTbWZYUDFUUHJyOGNRQ09GaHBvUE5uOQpVeEdTNldyby9DTi9yQkk5'
    b'MVhkZVFaNXFpL0tPN3IxYzMzYUVQMS85MDVQdmVWeVg2anYxdmJ6dDQyT0gzOERBUnNuWThV'
    b'YzU4cFU3CkNhYWFDYWFhVURTTmxpc3Z3elV0cnYzUHIrRHQ3R0Q5MWdwZmJmMGhOeTk0K2hX'
    b'ZEJNMkJBcDllOFZOdXQzZmkvTGdSSmFPeDZOYjMKY3RFLy9DVWROMTUvdWlBc0t2R3R3RHdl'
    b'bjZnVmpGb2NuNkl6bkVFUkVsVjR6RlJERE9SclBZT1cxNDF6Tk5kQTIwbUJlVG5iczcxcwp1'
    b'ZjJoWWgzdlg3aU5Id3d1SldNRldKa1laN1Fjbzc5WWo2NjRoRFdMSHc4djVvcm1mbDdYZm9T'
    b'TUdTQ2lXMHhWSTdoUzRaSHBYb3llClBFdnFKakNQT0F6YzlRTldmdUxEN1BpenYyYnFxVzAw'
    b'YkZoTmNYQ0VGYmZkUnRDZFIrU2h2YncxdFljbGJhTmtaSURKU3VSbEdiQ20KUUlIZm1iK2RE'
    b'L2wyRW5vaVNOUzNsTlJWRzhrZU9JSmk2QmpSS1BFbDgybDk3VWJHSG5vY3NiaklEMXJidU92'
    b'RUtucWphUzVyUE1FbgpWajFNMmd6eDhOaDhPaU1aYm4vNnpleEtwMmdQWlZtZEhHUFRSRGMz'
    b'ZGg3Z2NMYVJrVit4aC8rS0xleEVkSk1Gc1JsMnBWTzBCUFBFCmpTcUhzazFVWFIxRmtXeWJi'
    b'dWZtUlZ0WUdKdG1vaHlsTFp6ajZ0WmpQRGxaT3lxOVA5Tk1YeURPaXZwSDhhWUVoaFpsNFFk'
    b'K0V5MFUKcFBHU3RZdy92SWxRV3l0akR6M0JvdmUraDh6REl6Uk1oYmpFN3VNdFhmdm9iRTVq'
    b'b1RCVERUMXY4ZVJmbUZwV2JUWTJEM0JieDlPOAp4enhDNDNZVmNTTEdtai8rR0l0dS9XMTJm'
    b'K1lMZUxaRGVYU0M5amRkeStZUGZZTFJoeDlIWFovaFA4TUwrZjdnY3BiWGpmUEJKVSt4Cks1'
    b'M2lIZDE3Q1dvMmQvV3ZRaGNlTjgzYlJjeW80a21GaDhibUV6T3F2TDc5TUhjZVczdCtMK3g4'
    b'Zk1XalBEUTJqNTB6Yld4b0hPTHkKcGhOVVhZMXZIRjNMeHVZQi9tejFnMHhXd3Z6N2tmVWN5'
    b'RGJ6OXE2OWZIN3ZWYWZiUzlYaGxvVmIySmlleEYrNW1QYlhiS1Qvcmgrdwo3Q00zWStVTFJP'
    b'ZDFjZXpPNzVFOWNKaVZuL2dEaEtiUy82My9ablRMTnJUV0tyNk9FaE1SSDBkRm5LRnFuSkZT'
    b'akpsS0NOUFZLTmpQClJoWmgzVVJUWEJKR2hjWmdnWjdBTEF1OURHM0ZLdFpZZ0lDVm91c3Ri'
    b'MEFQaHpuODVhL2ptamFkYjc0ZXo3SVp2T2QrQUhyZi9UYU8KZnVkdTFLdG11U056TVR0bWFr'
    b'MGZPc0paTG00Y1pLZ1lweldVcHplU1JpRDVsME9YbmhhNk5nY0tmR2J0VC9qZnU2OTUwZjJC'
    b'empueQpEY1hocyt2dVo3SVM1djZSUlF5VjR0UVpGZDdVY1pEV1lKNDc5cjNtQlM4QTlVYlRm'
    b'S2hqTTYzSEpVNWZpS1UzdjU5RC8venZYUGF2Cm4rZkpXLzhJZ0ExLyswbDIvK1VYY1NwVkZ2'
    b'N3VleGkrOTBHc2JKNXdSNHJKZzRkUVlnNUsyRVlQMnloK0Y2RjdDRldDSy9Bc0JjOVMKY2Nz'
    b'YVZzYVBVdFRRSkxTLzRScEc3bnVJMXoxd0YvdS84Sy80RzVPRTIxdlorYWs3RUtyQzVWLzlB'
    b'cHMrY0R2UzlaQWRKdVBMSkovcgp2L0lYL3EvR1FKSGZXYkFWVGZHWUxFZG9DMlV4VkplLzM3'
    b'L3haVE5icDYyQnZOd1BzRHlOajIrOWdUWEpFZFkxREhOVjZ6R2tGRHcxCjFjbk9tYllYZGEv'
    b'aitYcHUzMzhER3hxRytlM1g3YWJ2OFMvaCtlb1kvdkdETmVmUk1GRDlmcXg4cllaZWN0MEtw'
    b'cmZ1SXJGaU1VaVkKM1hzUTBpcWtWUno4clAvOG53TlFHaHJsNEQ5K0RjVXcyUGpWTDdEcGR6'
    b'K0c0VHBjZE1lbnlCdzR3dXllQTREQU5VMkdmdmdBaXE1egp6VDFmcnlXUlhJLzlYL2d5c2s1'
    b'SExKL2dMbThoOXh4ZTlvSVdxS1lxWWY1Nno5VVlpa3VEdjBqTzlwK3hzbmRlay84TWRzNjB2'
    b'V2l5Cm53dGJwOXZaT3QzT3l2b3hicnArRC83MHQzQVRNYUtKRkVNLytNbXpXUmNKZ2NaNkZ0'
    b'MzZQalo5NFBZejdoUHVTUEg0Ky82QUsvN2oKSHpqNkg5OG1zV29aVHJsTTF6dHU0UGgvZlE4'
    b'OUVtYmVlOTdPNW0yNzhHeWI0b2xoVnYzWlI0bjBkakx4K0dZQW5KQ2tGSHVTWFowTgpmTG52'
    b'aHBmVVc4L3kxRE1hUWw5UTVMOGMySk51WlUrNmxjWkFrVGV2UDhoR2ZTZmxnYjI0d1RCQlg1'
    b'enhSNTVrK042SGFML2hXc3BqCkUyZEovVXJjcW9sVHJ1RFpEaTFYWG9wZEt0UDc3cmZSLzgz'
    b'dmt6ODJ3SUYvK0FyejMvOHVCbVAzcytVamYwN0RSV3M0OU8vL2o2bzYKaFAvcUFudUNqWHhq'
    b'NERyR1JxUG4zZmhkY00wV2xzUW51YWIxS0t2bE5ORUpxSXlHaU1UblV6b3ljRVkrOXMzYjdt'
    b'ZnM0VTNVcjF6SwovYSs3aVV1KzlGazIvLzcvb3ZNdHI2Y3lNWVYwWFZ6VEluUGdNRm9xZ2Fz'
    b'TjQrOHNNVkxuNCtGc0R3K096aWR2K2MvYnNib2dPMjA4CmczcC9pZlVOdzZ5TmpMTEF6UkV0'
    b'dU5nWkgzYmV3QzVxUUF4TmFLaUZQRVVnV0JmRU12TW91a1NQV3VneEV5WGlNQllLY0lCNmRt'
    b'ZGEKMlR2YmN0WjI2M1BrbitQUUZJOVVNRWNxbENOaGxFbjRLdmhVQjBWSUROV2g1QmkxTHBx'
    b'bENCT1ZDT1BsS0JrcmNPR09CNjhpT0o3QwpZTEh1akc3YXIxWW9jME13Ui80YzVzaWZ3eHo1'
    b'YzVnamZ3NXo1TTloanZ3NVhJamt5N2xoZUZWQy9uL1RWS2FRS1lsYXFnQUFBQ1YwClJWaDBa'
    b'R0YwWlRwamNtVmhkR1VBTWpBeU15MHdPQzB5TmxRd01Eb3lOem96TXlzd01Eb3dNTDQva05J'
    b'QUFBQWxkRVZZZEdSaGRHVTYKYlc5a2FXWjVBREl3TWpNdE1EZ3RNalpVTURBNk1qYzZNek1y'
    b'TURBNk1ERFBZaWh1QUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMTY2NSIg'
    b'Lz4KICA8L2c+Cjwvc3ZnPgo=', 'US_ND')

US_ND = b64_US_ND
index.append("US_ND")
index.append("United States of America North Dakota")
catalog["US_ND"] = US_ND
catalog["United States of America North Dakota"] = US_ND
country["United States of America North Dakota"] = ('US_ND', '', 1)
lookup["US_ND"] = ('US_ND', '', 'United States of America North Dakota', 1)
lookup["Bismark United States of America North Dakota"] = ('US_ND', '', 'United States of America North Dakota', 1)
lookup["United States of America North Dakota"] = ('US_ND', '', 'United States of America North Dakota', 1)
details["US_ND"] = {"continent":"Americas","capital":"Bismark","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_ND"] = ('US_ND', 'United States of America North Dakota', 1)
regional["United States of America North Dakota"] = ('US_ND', 'United States of America North Dakota', 1)
#----------------------------------------------------------------------
b64_US_NE = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTE3NyIKICAgd2lkdGg9'
    b'IjE2NyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05lYnJhc2thLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MTE4MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzExMTc5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzExMTgzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE2NyIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFLY0FBQUJrQ0FJQUFBQnNDTGVoQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBdQpkVWxFUVZS'
    b'NDJ1MTlkMkFVeDluMzdQWGVUN283U2FjdW5YcEJJQUVDQ2RGTU5jVUcwNHl4amUwVTI0bXg0'
    b'KzQ0Y2VMRWllUFkySEh2CnhuUWIweEVnUUNDRUN1cnQxSy9wZXE5N3Q3ZTczeDhuQzRIQlNk'
    b'NDNYMTZSM084djNkN00zbWgrTTg4ODg1UVpDR1MvQ3FMNEx3TWgKMmdWUjFxT0lzaDVGbFBV'
    b'b29xeEhFV1U5aWlqclVVUlpqeUxLZWhSUjF2LzlvSkxEOFh3WG5ZSVVKZXA1REpoR0RsUEpZ'
    b'UWpDLzZzNgpnZlNmL2UrUmllamE2VDBqWnNIMnltYWRnNU1lYTV1V1BGYlhuMVNoR09uV1NT'
    b'd2Vwb3p2eG5ESTdhZjZRaFNubjM3b2FqYUZoTGFwClpWNlk4aC9jTGRCL3BCMitRRzdJbEZv'
    b'WDV3Mmt4OXJPOTZWSXVONXpmU2swVXRqb1l2Y2JSVlFTYW5TeC9FRXlqd2xqR0JRSWtmUGwK'
    b'UnFlUGh1S0VnZ1REMnVuZEpoZExaZU5UaU9pWjdyUjJqUlRIb1NqclV4ZXhITyswNUxITnM5'
    b'dnRYdnFvUmFBMGlLK094Sm5jckgrNgpVeUM4T0VrL0oxTWxZdm1OVGhhUmlMZXFaSmY2azZL'
    b'c1R5M2t4cHMyenV4SUZ0c2hBRjc0WnFIV3pnMGkxeFl2QWdISE1LZ2tlU3c5CjFob25jQjlw'
    b'elJvd2lpSmZwVXRzczlQVnZpRDVRRk9lZ0Jud2hjaVRLd0lBVXNUMkpRVURXVEt6enM2OW9F'
    b'enAwRWdDSVhKMFhmOC8KaGtKcTJUaXJZMmFhNXIyYTBnL096MUJiZVpPSEFwR0EwU25oejdZ'
    b'ZnpIcjZseVhKdXVrcHVqOGVxN1M0bVJObG5yaWpqa1RBam5kawpBZ0JLVTdYemM0YVN4WTc2'
    b'd2NTL25DeVBGQml4Q1A1MnRveEZDMDFMR251b3NvbEJRWDUzWkY2M0xqYXF3Ly9mUU1yei9P'
    b'S095enUzCkhLV1RrWVd2M2YvdDFad0k1U1hKWTcrLzZ6U1RHbnAwNFpXVlJYMXdpSlFhWXhl'
    b'eGZTTm13WXdVWFhtR0NwNDBtMzl6cU1vTlU5KzcKN3pDTEZqclptUUVqNUU2dFpIOWpIZ0NB'
    b'eTRCL3UvWnNwSmdYcHRRcWt4LytiTld4RHNWRDg1cWV1S091VUc2SXN2N3Z4dXFTbmwrdgpy'
    b'dUhRZ2p2MkxIMXE3NUtKZGYyM2E4K2VlZnFURDg3UENJV0oxVjNwOTgxdEpSS3hpOHFreFht'
    b'RFhwaktwZ1hkZnVvenkyc24zdlBTCnFuTjFBNG5WWGVsd2lBUUFLTTlRTlE0bmFPMWNPZ1Y1'
    b'ZkZIOXp4ZGNpUlRiTnJlRlJRc2hLSEhYNWNKZmY3dkE2bVcrdU9yY0F4VlgKYjlQZUl3THgv'
    b'TnV1MFR1M0hLMVFxSGFlbnJXbklkL2tZazg4OXdVcEhScHBITitUR21zLzE1dnFoYWxQTGJ2'
    b'MHU4UHp6RzZXMXNacgpVY3ZlUGpPcld5ZTVvRXlacUhLOFE2SFV4M3pYa28zaEVKTWFpdU43'
    b'TGcwa0V3ajR5NnRxK2czaUpRVUQ3NThyUlZBaUJNQ0Zaei95CndOUUJvOGdkb0hWb3BIVURT'
    b'ZHNybWxOaUhLMXFHWW9Sb3F6L2Z3U1BBVmMvOWRucDd2U1h2bDJnc2ZFQWdCUlN5L01yTHpR'
    b'T3l5TnkKTzRDUXpXN1dxM2VmM2xWZjZBclEzamhaN3ZUVCsvUXhXanNYeFFpVDZhR1FVQUtF'
    b'QXdpYTJKZ2hLUEdDTXNYbVpjQUlXV1hoTnd6TApINmk0ZXFJajArUmkzelc5bTBvT0gydkw4'
    b'c0JVRElmQ0tORURVOC8zcFJZa0doNmUxenhxRVJnbkRiNm9Edit2UkhHUy9vL3JUajEzCllQ'
    b'SFYwYmpJa3hWRnlvZm5OYjcwN1VLVmhXLzMwU01QQmN3QWpZTG9IWnhydGhvU05qMUpDMEdR'
    b'Z09WYmxEdllxWlVpR0hISEhYVWYKWFNqeHdwUlYwL29PdDJZNWZIUW1OZFNyanhrMGl0d0Jh'
    b'cVFpaXhiaU1tQUtFYjM4NHZ0TFg3K3ZYU01GQUJ6ZjhVWFRTUHhmVHM2SgpXSElxRlNPL1du'
    b'NXg1K2xacHpvem9xei9pN0V3ZCtqRGJZY2UrbXoxbWU0MEFBQ0Rna2k0SHBPYjFmWHFXOTgw'
    b'NTc1eHF0emd2SEcyCnhRdGNNOU0xWkFJNlBVVkhKbUtudTlPUk1CRURvRjh2RG1NRUtnbjFC'
    b'aWdvSUVoNEhqb1p3VEFvSjk2VUliR09tZ1ZTdnR2Z1lCOXEKeVhFSGFHR01RQ0pnbTJhMWYx'
    b'VmZoR0hRK3JMT2Q3WWNMWHJoNTc5YWZ2R3hyMVpFZmlnMXh2N0NuZWRhUnVQZU9Uc3p5dnEv'
    b'VW5kNwpwS3BweCs2bGtTMVRXWm8yVTJKNWJGRjl1MGE2dnpIL3cvc1BsYi95c05iT2pSUm1V'
    b'SkdTWkoySTZmL05tck12ZjdkZ3lDUncrdW1UCmQzUi9keEVSc3YzclpuUVNJTnpzWnVzYzdK'
    b'TWRtWkd2NUVKbjQ4dnZiWG4vN2lTeDQ5T0xKUmgyeldiSFpjQi91L2ZJVlZYY1c5V3oKcHI0'
    b'dDd6WmdmY3ZzdHEzbHJZL3RXdEU3RmhONWN2TEp6NWU4ZmgrSEhteDk1ZTJNWCsyWW16RWFV'
    b'ZERZOU9EMDVMRWRTeTk5ZWFuSQo0bVcycVdTTzc4VStpWURseHB0b2xMRERSNmVRd2hRU09y'
    b'RzZJMkVpakpBR2pLSlFtRGo1ZDRVc2Y2TElVWmFtellpMXZYMW1wdGJPCkRZV0p1ZkdtbVdr'
    b'YWc1TjlyRjN4dytIeStvWVRaamZydVFPTG90cmMvd29WaXRFSEtxL3UyTDIwVHg4ejhmQ3Bw'
    b'WmRZdE5DbC9pUXkKQ2JzOGtLaXk4Z0VBbFZranM5SzBwV21hbHc0dWJCNUpHRFlMWVlRTUFN'
    b'aVVXc3ZTdEh3bUhNZDNqWm9GYTB1NmxZYVlSYmxEWFZySgp6RFR0Z0ZFVUwzQ1RpZWl5d3Y0'
    b'Z1Fvb1h1SmsweE81bEFBQUNJYkxCeVdsUnhhRVl0R0ZtcDRnVjhBVXAvUVp4bDFiaWhta2Vt'
    b'QW9BCktKQWJYbDU5VHNyenRLbGxNRUt1NlUxOWVGNFRteDVzVmNWRldmOGZJaWZPOUdEbDFY'
    b'ZlBscldxcit2RUMzMHBLNHFVWW83dnZacFMKSElja1BNOWppNjZRaU5pb1JmQko3WFEzVE1N'
    b'bXlkamYzWFhtV0x1aVV5UFpVTmJKWndheTR5d2RHcW5leVJXeS9FS1dINExBN0F3TgprWUJm'
    b'R1V4czEwZ2xQRzlacXRic1lYbStWK2h3SEJvMkM2K094a200bnZJTUZZMGNIallMSTVRREFD'
    b'Ni8rTUc1bnRTdkxoZHZudDNlCnFvcERVT0xsZ2NRZFMrczhBZXFFMFRmSytqOEJGaTMweDNY'
    b'Vk5iMnB4enR1bEtWV0wvTm9XMVprUHVYR21mZitmTS9IdGRNdktwT1UKaHBqSnhXamtjRXFN'
    b'L2U0WjNhYzZNN3hCS29aRGJIcG95Q3dVcy8xc1dwQkxENGJDSkRZOTFEc1dZM0t6ekc2VzAw'
    b'K1A0WGhucG11WgpsRkMzVGpMNVZZRVF1ZDhnZGdkb2xZcFJDYy9UYnhSSEZ1OHNtZVhaQTRz'
    b'NWRQaTFkZFdmWEN3QkFMaGhtdE5IZjN4eC9kRzJyQnRNCitsSFcvejYyVnpiRFlkSjdOV1VZ'
    b'RHZFWU1QeURIbVJTUTJXcDJqL2RjK3J1blJ0NzliR0JFSVZCUWZMbHh0UVllN3JFSnVGNXBU'
    b'eVAKdzBmbk13TjU4YVlQdHgzcU40ck5idGFobHB4dVhXenZXR3lYVHRLbGszUm9wRFl2azB6'
    b'RTBpVzJMN1lmZEFYb0tFYndCcW5KWWtkeQpqQ09NRVp4KytzUXZtdDJzRWF0Z2Z2Wndnc0Rk'
    b'YnhLakdNSHVZeXd0NlAvZy91OXErMUw2amVJS3hXaS9RYXl5OExuMDRNcml2dHIrCjVLbHB3'
    b'Sm1pckJjbjZiZk5hWG45eEZ5Ymw4R2toczQ4L2FuU0lOYlllRnRtdDQxWWhLRXdrY2VBNXlw'
    b'VUs0cVZtOTViNzRacFFsWkEKSWJXVVo2aUh6Y0lZanM4RFU3TmxaaW5QdzZZRk5UWmVFQ0VC'
    b'QUxXcnBUZ08vVkR3d2dqSjdHYTUvTFRIRnRlZjYwM3RONHI1akFDZgpDYXVzL0h0bnQyRTRs'
    b'Q3gyY09uQmlCM0dDMU83dEpJRk9jTlNybnZRTEZaWitIb241MHhQMm9CUmRITEg1d0pXb0hj'
    b'c3h1Um1ENWxFCmR4YjNrVWxZejVUMDAweEYxdVA1cm5lMkhuM256TXlta2ZoeGtlNWhmdjdR'
    b'TndCQVZESjZxVCtKeTRBckZLUEZpZnBuOXkvR2NXaFcKbXFaQWJwRHhQUlZab3l4YWlFVEF5'
    b'RVRNN0dGZFZjV1AyYmtNS3NKbHdEQkNadEZDQjV2endyZVlmTDRnUmFrWFowaXNCaWVuYmlD'
    b'UgpTa1kzejI0LzFablpwWlZnT0VRZzROT1M5RGlBN0Q1R01FenExRXFYRnlscDVQQ29XZUFP'
    b'MExMakxBZCt2bnQvVS81SHRkTTN6ZW80CjNaVWVRTWloTUdsbFVWK25WanBaV2tSM2JyZkVy'
    b'NVpkRElaSmIxWFBtdnd3V2V4NDU5NGphM2R1d2dFMEwydTRQRVAxd3NGRkUvcmEKMFRaRmhz'
    b'UnFjTExGYko4dlNBa2c1TWh1elJ1a0RCcUYvNVM1TkQvQldKeWt4M0NJQU9HZFdnbVppRkxK'
    b'NFMyejJxdTcwcFVHTVpNYQphaHhPQUFDSVdQNlhWcDM3L0hKUjYyZ2NBQ0JMWnJaNUdXR1U2'
    b'QTVRSndiV3B3OSswendhLzE1TmFaVDF2d014eC9mRlF3Zld2TFVaClJrZ2NlckJDTVdyeE1L'
    b'MGVSZ0FoajlrNUFJQlphZXI3SzFvZS9HVE54Qzc1Wnd1dUFBQmlPTDVweVdPSFc3UDNOZVJw'
    b'Ykx6L2ZVdTQKRExna2VZeERoNTArdXNyS2YvWHU2c090MlVLVy82dkxSUkdUYlVxTS9jMU54'
    b'eDc0WkkzbEZ1RTZRcFovOTAvM2JYeDN2YzNMaUVyNApIOE9PTytxdWpzWTNqU1FBQUJKRnpx'
    b'OGUyYjhnWi9pUnFpYTlrOTJxaXN1UVdqOTY0TkRkYjIrS3pLYzRnYnM0VWY5NVhUR0tFY296'
    b'CjFXb3JMNHdTajdabi9VdXNZMEdFTkdvUktQVXhLaXYvNjUvc1A5K1hXdE9iOW5CVjA5Nkdm'
    b'QXduQUFBY1B2cW9WZkRpeXZPSFduSnUKK29aQWlPendNWjVkWG51d09UZksraTJSSFdmKzVS'
    b'MlhYenRXNFE3UUFBQTJMMFB2NEZnOWpDMGZyR3NjVHVEU1ErOXVQZkxJNTZ2TQpiaFlBSUVI'
    b'Z1NoWTdjQnpTMmJtWlV1dmVLL2w3R3dzdUtGUCtFY29oQ0t5c1RHSFN5UWFyN3g5cDJFUHpt'
    b'bkVjWXRPQ1IxcXpVbVB0CkhIb3c0dUhWT3prUUJPWmtxbG9tbVdWSUJPeG5DeG80OU9DSVJZ'
    b'QmhoUG5adzFvN2Q4ekJqYkorYzl5UlA2Q3g4cXE3cmptdmV2VXgKSzRxVVYwZml2VUhxdXRL'
    b'dXhwR0U1cEY0SEVCclNuclRZbTFVVWhnT2szTGl6S2U3MHAyQmYxUnBFbkJwSDcrODhPbjdw'
    b'Mis5TXp0Sgp4cm5jYm9DRDRSK3ZVamVRQkVGQVplVmY3RTgydXRpSlFpZURHclo1R1RnTytV'
    b'S1UxQmg3T0V5TWhHVStVdFZZbXFxYmxqd0dBTGd5CkpIZjQ2QlZabzBRQ2RuVTBQc3I2VFVB'
    b'bW9xK3NQZk5tZGJuRFI0L251NTVjVm5lK0wwWEM5ZFFOSnBuZHJMUlltMEpxYlI2SnQzaFkK'
    b'U1dJbmdoTHJCeE1yc2xRdHF2Z3JRM0xzWnZONzhleWt0NStkOStyanMxZFhwU21TQlVRaVFX'
    b'TndseGZKRHIyNXNqaDczSjZUbXk2NgphMkY2eDRCRmEvUmNzNml6cVhjdnpyaC9kVzZoUXR3'
    b'emJJZURZYnVQRWRIR0YrVU9zZWtoS2luTXBnVjFkaTZHUXk0L0xWN2dGbk44CkEwWVJqa05H'
    b'Sjd0eE9PR3ZHMDg4dmUrT0JLSEw1R1pkSFkzLzAvcFR1K3FMd2xObTd6NkZXUC9wL0VhNTBQ'
    b'WHhoZWtZRG0wdWJ6L1EKbFBmRWtzdE1LdUwwMFcxZXhoeUZpc2VDVG5Xa0FBQ2NmcnJleVFt'
    b'RlNZM0RDZmFiS1VvVkpmRWYvWHJCTHpZWEpVallOQXBKSW1LVwo1TVRldlNoOTY4cnNqRVEr'
    b'UklCRVBEb0VqUThVRG91eWNha2lQME5rZFFTNGJPcGJ6MVMrOFZURmlvcVVRb1c0dkRqdXZq'
    b'dXp3eWplCk1XQkJVUnhHeUJvN3J5REJJT043ckI1bWtzZ1JjUUZZM2F5bmwxK3M3VXZ4QlNs'
    b'dW1QYllvaXNLbWRYcHB3K2JCVllQMHgra3hISzkKK1hKVFJQbVBzbjRkVmhRcG0wYmlJd3Zr'
    b'VCtjMy9HM3JFVitRYW5DeVQzVm1KTWM0UHQ1MktHN2Erd0lldTZQZkdrYXhtL3duUkNnbgpW'
    b'Ymk4SXVYVng4dWYybFlTRjNzVHZackZJQ2ZKT0NJZXZWL2wwSnU5UkNLQlNTZEhsdm1NUlA2'
    b'R3BZcmxGU2x3TUd5eEIweDJQNDRECk5wTkNvNUtxU2hQV0xjcXdPZ0o5bzNZRUplb2RuQXJG'
    b'YUs4K2hrekVtTlNRMWNNTUlPUXdTbHhXMUYrclRBWUFFQ0Q4MWFQejZnYVMKN0Q0R25SeEdV'
    b'S0pDYWkxTzBoOXB5NHJ1M01BTk52T2RXNDQrOGZWU2IzRGNzU0ZpKzM1UzFkaHZGTzl2ekh1'
    b'a3FqRTF4cFlxQmZMcApIL0M0QXAzSlM2TVNCVndhbDBWMSswSk4zY2ErRWZ2MnRibGNGdldm'
    b'K2xHZHlXdHpCcWdVWWtZaW4wQzRjWTJ3dTJDMXdSME1vVlFLCk1TOWRSQ0lTT2dlc3IzN1VW'
    b'RjJ2d25GQUpZY0JSRTJTY1RLVCtQa1o0b0owNnRWTGZ6M1ltRFJzRWtJUVhwUm9tSldtdm1k'
    b'bTU2N0wKaGUrZkt5VVE4SVpmdjdmb1QvYzdmYlNwME50VHhUMndlWGFia09XUFVMNjZwS2RE'
    b'TFMxTU5MeCtjazRnUkthU3d3d3FVcGFtSzBuVwpxYlR6dmp5MGFPV2E1OU1TeFZaSDRGRE5V'
    b'SG9pYi82TWhHVnprdjhuUnNCWVZud3NDOE53dXdzVzhlay9WUG9FWEJvQUlJeGlhcjA3Ck5Z'
    b'R1hueUhhKytlbGZTTjJsemVVSUdIRnhWd1RKeUVFSGU2UmlObStZWk1ReDZHMzd6MWlkckdP'
    b'dDJkR3ZMMFlCaDI2bXIwNGIyQmYKUTM1VXdsL0R3cHdoWDRoUzA1TUdBSmlWcGxrOXZYZDlh'
    b'U2NSd3B0R0V1UWkxd01WVi9QaVRGUXkrdG5GYVJ5S0RiRWRibEFYVTZuRQpoVE1UWldJV2lm'
    b'Uy8wcElnQ0dMUWZ5eWRoVUNBSXZTUDI1SDQ5UGhZRnNBQmxVTHNVaXBqUlNJQUFKRkk4TG4x'
    b'QWtKRFRVOHlBQURECkNIODVXVTRqb2NsaVIrTndBb1lUMGlXMlpKSGpZbi95Vk9qdHFhSlZ6'
    b'a2pWSFdqS2kvejlRT1hWR1NuYUpYL2VGckdrTHNvWlFzS2sKT0lHYlNRMDl0K0pDZWFacVVY'
    b'WWI4TGNpU0JBT29qOThsYkxuckI4T0I0S0kyeHY2bDdmVDRZYjNIRHJpaDhQOUkyT252M3VV'
    b'ckY1Lwo4Y1FUcDQ4OE42aTJKV1d1bFBDRENxa0ZBTkNoa1N6TUdUclNsdlhIWXhVSVNnUUFk'
    b'R2lrSEhxUVRFU2pFbjRjYWJFMkNjOHprVWEwCjRJOFBoTUxFUnhkZDJYc2xId0k0RGdDTmpI'
    b'dy9ML0hpUlAyWGw0dCtXdjV6SEFlL2VYZmJ2ZmY5ZnJKd3R0ak0rc0dEaU9Nc25XZ3gKMjN3'
    b'SmlrMlEvNm8rTU5NNmRpNFFJbUk0a01ncmpab0xBQUF5Q2JDRXBRNVRJd0NBUlVOUldtSEEy'
    b'UVVBWUZJeENuL082SEFEaVlDTApPTUVBSWMvbkhBQUFNS240bUMrak1LL2dvWnl0eG01MklS'
    b'RVY1VVlzUEo4Q0FHRC9oMWRWU1MwaitUeG1BQURRcHBhWjNLeEN1U0ZmCmJ2UUh5UWViYzd1'
    b'MHNYL2RxSlB5UFA4U2EvRi9nb1RQVHpDSzJmNGpyZU1xYmhnbDRqalVNQ1QzQnFrUUJGVXBS'
    b'bWFsYTJSOER3Q2cKVXl1SjRmaHNQaWFPUXdKV29IK01jcm1oeHE3ZVBXemlwS2VrQVFBTXV2'
    b'YW1qZ0dUSTZneWsrUXhVRzJyU1czdzZBMTZxeFBPVHpCZAo2cUVURVpYS2lFNUxjVFFvYWNH'
    b'Z1JXTkVwcWZhVzRicFZJSlZiVUNucDR6VnRGSDdoclFncEJIU1ZGelNDQmxwQjJFakFUTU42'
    b'WUl2CkwzbFhwMmxPRVZ1NWRKaEJSYTZiUFVSTUxyUUh3OUNZZ3hzWnZudCt1bmY3dk9aa3NT'
    b'T0lrQzRvVXpDY2tCcGpGN0lDYldwWmRLNEQKQUlDUTViZDZidTZmeUlpMWJpcHY1OUpnQUlE'
    b'SnpYTDQ2Ri9WRnlta2xwT2RHWGZQNk41UTFzR2hCeEdVNFBRM3RQWTJGbWZITVhrWgpTMVk4'
    b'aWVNNEJFRVFCQlpuQWh3SE9JN2pBQkFKMEpaMG5FU0VNQXdRaWVDZVRCekQ4UGJ1TGtRb1hi'
    b'RkMxTlpSbHk3OEFncWFINXJqCmt3dWRMRnBvMENTaWtaQ20wWGdCSTh4aEJMZFhOaEloYkhG'
    b'T2Q2UmhRMlpocXRnT1FUaU1rTWhFakVqQUFBQU1Ddkp3VmRQK3Bqd00KZ3c0MjUxMFprcit4'
    b'OGJoYzZCeFhENW1CYzcycFVRay9qdklNOWNsYnBCRFF5TWluRjZhOXRlVVlBQ0NXNHhXemZI'
    b'a0pSZ0V6d0tFSAp6M2FuSm9tZEtXSzd3Y25Pa0ZxVnphOFZaTDRsalJIZmJERU9kUGUyU21Y'
    b'WjhWSTJqVW9DQUpodG5yYWFiVEwyNkpZMDFaQlpmS2sxCjg4NmlWa251TmZPYzJjM3l3aFFT'
    b'QTAwUk8wWXQvREFLWVJoMHZDTXJOZGJHcG9XT3QyZmVONmUxUXlNWmMzSnBKQVJBWUg3Mk1B'
    b'QWcKUTJKOXI2WlV5UFJiUE14Qm83RDlkenNmL0dTTi8vdk01d05OdVl2ekI4LzNwVVJaanlq'
    b'Sk9KY0JSL3dXRlZtak5UMnBrNy9pME9ISgpId1hNQUFCQUliVmt5Y3puZWxNSFRLSkt4VWpU'
    b'U0h3NnIvNzFUMDgvdlgweEhBdzN0Ylg1M0dNKysxV09lQWFGbWNhMzM3ODhRK256ClVQYlhy'
    b'WjVlK1pyZWJNVFZENjByN295OE0xdG16SllaalM3MnViNFVvNU5OSWFGMENxSjNjRXBUdGNs'
    b'aUJ3Q09va1I5SUVTdUg1U3YKS0ZJaUtPSHlZQ0tMRm5xM3B1em5DNjRVSmhvQUFLTlcvc0ht'
    b'M0x1bWQzTVpNSmNCVThrb0FPRHlZQ0pyKzhzMzVGaE5rWUNxS2NFNgpoWVJHRkYwYUpWeVFZ'
    b'R2hWeWJ3d1JjQU1tTnlzN0RpelFtYVpYRmhqNDNWcFl5RUlwTWRhcTdLSDFWWmVxMHFXbjJB'
    b'a1FIaHF6Q08vCi92TXZjNFRudHMrOUFFUUFwSURJWHBrZ3dnRUFUR3BvMjR4OURzdVJOQ3BD'
    b'eTdubWJuRUhxTDRnNVdpYm9qSnJ0Q3ByNUhSM2VxTFEKdVRSL1lQSVJSWFFLVXFFWUJRRHNi'
    b'OHpmUEx1dFJSVTNicWdCQUFEQXBvUW9SQlFBd0dmQStYSlRicnhCWitka1NLdy9uZCtBQVlq'
    b'UApDUHpwK053K2ZReVpoQVVSWXBUMWEzNlhTTGc3a1lEdFdGTDM3SXBhSmpXMDdlTzEreHJ5'
    b'blg2YTYvc0lKTDJETTJBU0pRb2R5d3I3CkFRQ1JGS2NZamk5UjVQeTZ2bkRUclBaa3NlUE4x'
    b'UzhkYTFjOHMyOHhBQUFEQkplZkNnRHd3bFE2QlZGYmVTR1U2QXRTZkRBbEdDWTUKL2JSUW1P'
    b'Z0xVZ0FBYTBwNlhsNWRreEpqQndBc3loMjhWVHRWVm42aXlIR3FNOU1iSk5NcDRTOHZGMU9J'
    b'NFo2eDJQd0VJNTJDT0h6MApNRXJvR3hQN2dsUUFBSW9SNERDNVBFTlYzWm5Pb29ZQUFCMXF5'
    b'VStxR3FLc2p5TWx4aTVrK2lQNnptKytxL3J3L0F3SUdwZmtYcGc2CjRVK1Q4ZDB5dm51aWxw'
    b'VG5zZnZvZGk5RGFSQ1hwbW9iaGhKS1VzWWFoeFBTWW0yWCtwTStPRC9ENVI4M3JiQnB3ZmZ1'
    b'Ty96eGhaS0wKeXBzWVNXUjg5MHVyemlVSW5TUUNCaU1rR0NIeEdMRFRUek81V0E0ZjNlR25X'
    b'ejNNUUloczhUQTVkSGp6ckhhMWpSYzVzZ0JHU0VxRAplTlFpT05XWnZyOHBQNUxzdUtLb0R3'
    b'ZFFSUGVjbGFabVVKRHlUUFgrcG53QUFJc1dHaklKbzZ5UG8xMHRjOE5VQUlEV3h0MTlwVEFp'
    b'CjgybVVNQUFnanUvaHN3SzNxaWhnQmdUTVFGcXNMU0lKaUJBK08xME5BSGh0L2FublY1N2Yv'
    b'UDc2bzIwS0FNRHNETFUvUkNhVFVBb0oKdlNHdEtWS3g4SVZIcjl2T0VyQWJGdUI0dnV2RWsx'
    b'OWt4NW1KQkl6UERFejREZ3JsaHNnSUtNOVEzLy94V2dCQWFvemRHL1RXOVNkeQpHZkNaN3JR'
    b'M3EyZXZLZWtaTkFrQkFERmNMNEpGSmZ6RTlreGlpY3pMTUVid3dwVFNWTzI3V3cvLytjVGN2'
    b'UTM1WmcrOWVTVCsxU09WClBEck1ZY0E4QnN5aHcxeEdrRVpDbURRa0ZDYjZZRElBZ00rQ0FR'
    b'Qk5JL0VjZXZDYWxUZDM4RUpmc2dlbW51ck02QjJMK2ZheHIzKzEKNzQ3STNpbWU3MXBYMm5X'
    b'cFA2bjUrMkNIZUw3TDRhY0hFVkw0K2pUM2NUK05nL3RWZmRHVFN5N3RiY2cvMTV0eWYwV0xP'
    b'MENkbWFidAowRWpTWTIxREprRmtwWWlNSVUrUUNnQncrbWh2VnMvMndOUXY2b29qWDJsdHZF'
    b'ckZTSlQxY2FpdC9PUVl1OWJPaFNEOG8vc1BsV2VvCjlqUVVuT3ROaVhTaWdBRlA1RFdPVzhJ'
    b'NVByblEyVEw2VCtTU2pUazQrWExqaHJMT0NPdlBycmdnWUFWbXBHcWYzTDFVNStBQ0FCNloK'
    b'MzlTcWtqV09KRVJpTW4rSVB4K2ZjK2hxOXB4TTFlL3ZQalBtNEJUS0RSNllXcGsxUWlKZ2VR'
    b'bEdEMHg5NFp1RkxqOHRnSkJkUG1yRQo0TGh0VHNzSDUyZE1aT2p4bUlHRDMxdWRvNnlETVNl'
    b'SFRRc0JBSEFjdWpJa0g3WHdZN25lZUlIYjdHWlJpSmhDWnA0b21TeDJQTE84CjF1UmlVY2xo'
    b'R2M4VG1jci95RTlVWm8yMnFtUzc2Z3R6NDAzZHVsZzNUSnVkb2ZHRnlMcnJ3OWtZRkdSdFNY'
    b'ZDJuUG1WdzFXUko0dnoKQnF1NzBpTi9TN2llN1JYTk9YR21uRGdUQUNBVUpxSVlnVTVCQUFB'
    b'VUlocUoxMU5JTGIyNE9HSjR2OWlmdkw2MFN5NTBSb1QvakdRZApOalc4SGxPQzllSWsvY1RF'
    b'L2FTMkpOSy8rUWxHQUlER3pwMmRyaEZ6ZkJZM2swNUJEajc2ZFhHU0hnQ2dzdkFYNWc0ZGEx'
    b'Zjg5bERWClB4S1p0TEtvNzN4ZlN1MzMyaHliRnBSd1BidnFDeVBMOC9iSzV0SlViUmdsR0Z6'
    b'c0RUTTdyVjdHTHhkZkZyRjk3NTRyYzhQVXlESmYKbktUZk5yZmxSR2VtMmNNS2hZa0htdkl1'
    b'S0pNWFpnLytZa245OUdRZGxSeStzN2ozcTh0RkRHb29JaTErdXFEaGhaWG5qUzcycDdYVApJ'
    b'Z2ZlYVd5OFRabnRVZGJIOFZWZFlhRmNQekdsQUFCV0QxTXVjZ0lBSEQ3NkYzWEZiRnJRNG1a'
    b'bXhGcFZWdjZJV1VBZzRGeDZjSDdPClVLTEk4VTF6VG9kRyt1UHZ6NDR6UDFMVitOSTNDeUs3'
    b'ZGlvSmplTzdOVmIrZ2VZOEFBQ1BFZGd3cThNSFV4Nm92THFsdkEwQTBLT0wKaFFBZURKTit1'
    b'K1lNQUZBNFRHZ2VqWDlqNC9ISWxuMUNhV2hWeFlVeHdrZm5wNzl3WUdHcldpWmdCc2hFVkdQ'
    b'alJjSmh0VFplMVI4ZQpWQnF1MlFxVFkreUhXN09pckk4REJ4Q1Roa3hNU3BPYlJTT0hQVENW'
    b'UVVIOElUS0RHcnB6RGljK2VlN0lVSE1ZdlNCaSszbU1BQUJnCnhSdjNmdlhJZnJ1WElSRXh3'
    b'aWh1ZGR4UzFVOFVPaWtrOUlrbGwxZVg5RUlRZnFKZDRmRFQ3OGdmWUpBUk9nWHh3TlF6WFdr'
    b'NEJqVU0KSllSUkFvY2VkUHJwY3FIREh5UTdmWFFVSi9RWnhJa2k1NVVoZVhtR09tSnZCd0R3'
    b'R0hCVjluQmtmNS8yNUpPSklxZmR5MkRUZ2tWeQovYmZOdVJFanhJRHB1cHk2WlFYOXJ4NnBq'
    b'TEwrdmZYRHdsOVYzRXNpWUdHTTRQRFRjUnphV3Q2S0EyQjBzbXVWeVhZdm82cWdhZW1hCnh3'
    b'YUhHYXJlUVFmcWNubGNabi9pMHNYejJ3aS9mUDkzMU81Qks0TkdybS9YQjRMaEVJSjI5RnZI'
    b'ek43Sjc2OGZraDlyVjJSS0xFS1cKbjBqQUJPd0FsUlRlZVhwV1ZjN3diOWVlWGZMNmZSOWZt'
    b'QjdEdmE2S0Q2WkU5bmgySDhNTFU1OVpmcEZGQzUzclRTbE8wZ3RaL2h2YQozL2ZhWDhsRTlL'
    b'M3FXU2U3TXJ4QmlpdEFqZWU3T1BUZ3F1TGVoNnVhMXJ5MXlSZWtrSWtvbVlSaUFJcXlQZzZs'
    b'UVJ3dmNFV21YZk5JCnZQcXZmMm9laVdzWWx2dURaQURBK2I2VTR0VDJvZEdSOU5TVTlOVHhL'
    b'RCtqMWQvUmIvN2kyR2h5UFBmQk5Ya3NCbm5MaW5IaGllT2cKdGM5VTMyNUFNUndPaHBXamRv'
    b'M0JzK3F0clh5RzkvMXRoOFZzWHd6YmMwOVpaNXRhVnQyVlhwS3Myeml6L2NQek15YU90Ymtw'
    b'WGppNApNQ2ZPNUF6UTM5aHczT1pqREJoRkdBWnRtdFZPSm1KRmlmcElySVNJN1dlUXc1RjFL'
    b'bE5tNVRFRHY3L3I5SE1IRm1WSXJHMXFHWnNXCk90V1pjV1ZRSG1WOUhLRXc4WFJYK3ZKQzVa'
    b'NkdBaGdocFQrMUk1SklOaXRORTVsMlZoZWh2YnZQNXFYRFFiU21VWU9FTVpzVFJqRnMKUlVY'
    b'S25mUFNvT3ZuRHdTQmFkbXgwN0t2U3lIMkJSQUttWGpnVUt4ZXMyZDdaZlArcGp4L2tKSXVz'
    b'VkpKNkNOVlRSK2VuM0dydG5FWgpzSWpsbC9IZEVJU3JiZnpuRGl6KzhwSDl2ejh5RHc2UmRw'
    b'NmVOVmVoS2tndzVNYWJnbUhpci9ZdFdWdlNQV3JoQXdBdUR5U3VtZGF6CjdwME5xMHQ2dnJ4'
    b'Y0JBQW9UZFZPblZ6MnFSSXRTU1JnRTNFSzdnQjFkcnA2ek1uWjkraWVqS2VlQ0lUSVRoL0pN'
    b'WGJxMUZVS2dRQU4KYVJ4NTZhS1VlTTZXRmRtVDR4Vi9ISkVJYUJhLzRPN2NKMmprOExvWlhR'
    b'Q0FZYk9nYmlBSnhhRDdsb3ZUa3ROUDFxbWF1b3hJK0xydAoxYVpaN1grNzkwakVpNE9nUkFJ'
    b'QmJ4eE82SG4xVGF1WFlmVXdDK1NHWDM2OTdLM1RzM3JIWWhSU3l3TnpyeTc2MC8xa0lycDVk'
    b'dHRqCnU1YWpHT0h5WUdMa1BhdW05YmIvUGEzejM5ZmJVeVJhc2swZDkvcUdrNTlkbWhiNStO'
    b'MHZkdDJSUDNpNk05MGJwR3BzdkFHaitMN1oKbHh6aDNMS2lqRFVMMGpjdHk1bzNJNEhEL0tl'
    b'dmF4Z2NiQzRXZlRQeHNYWWdXNGR1RUpOYS9TSEd6N1p0MmJSTThlakd3bG1GVXFtWQpTU0lT'
    b'SEc0NGhHQUpBbGV0TW9WRkMwVU13Q1FpSmhjNmFlU3dnQm1JRjdoSlJHeDVZZi9TZ3Y2M1Rz'
    b'OWVYOWIxWFd2MmtFbVluMkI2Ci9zN3p6Nis0d0dmQ2Zmb1lYNUJDSW1Ecnl6cmZPVHR6NHJp'
    b'YjZGd0hBQUIvaUh5eFAzbEova0Frdk9MRDh6T21wK2grTXI5eGRxYTYKL0pXSC9TSHk3dnJz'
    b'bVlXNmRZdlhqVy90N0o3YTA3L1ZHSUwrSUJyQTRoTGlFOUpqTFY3Q0RIK0lialcyWmFUbkw1'
    b'cDdFNkh0c1RTQgpTY0VzNXZDQytQU0ZjM2d2ZGpyR0kzbm9WTkw4VXZuOFVqa0F3T0dHMzk3'
    b'ZHZ2c0UwMmoxdlZkVG1pNnhmZjdRZ2NpaWN3T1N4WTdjCmVDTUFZTUFvQmdEY003TVRSUWtH'
    b'Snp0SjdMQjZHUkh4YnZFd2IyWDErKzlsSFFCQUltTEZTV01SMWwwQkdvWkRjMzczOElSVTFO'
    b'aDQKQ1ZxbFdxdE5URWdBQURTZDJiNXRXdldmVDg2NXQ2SzdXeGRibnFIaTBXR2RnMHNrWUlP'
    b'WXNGU2syLzNkenJ0V2JaajhmZ3pEWmJSTAoxMW5pdU5uSkNSS2pqaDByWC9qRDl2QTV0TEow'
    b'WS81OTVyRDdTbEc4TWlmT1BPRlF2d0cxeW1RUjI0OWlrTWJLRlhOOEVNQ2YzTE4wCmZzN1Ev'
    b'c2I4eUZxK3ZxeHppbmpiSXBoQ1orVzg4dDI4aGJsRFlvNFBBTEN2TWUvaHoxYTFhNlFQVmph'
    b'ZmUvWmpDZ2x0VmNuRWJPdUoKVS9zai9ER0plbitJbkNhMm9TZzBadWNRSVp4QXdCTUVMZ0V6'
    b'MEc4VTB5bUlJUFFSaGwxM2MxTnJqMmFlb20veUU1ZmJhdFpkNlRlSwpKTEtieDIraHRrTnJN'
    b'bDZuMHlqRlNYcC9pTnlySDljUWUvWFNpd1BqSjJNWm5PekhkNjM0Njhiak5iMnBBQUM1MFBu'
    b'MHZqdWFSdUxQCjk2VkdmSzlzV2pCQjREcldwcGc2WFQyRjh0d1FsTWhud0F0eWgycDYwZ0NB'
    b'bUZSazFiUmVNY3QvNkdwT2ZvS3hWeC9UcXBhOXNPVEwKRWZlTUJKbnM5QlhUMXhjRW1WSXJu'
    b'UkxtTVlJRUNNY3dnc25EOGdjcHJnQTlVZWdrRTBNaDd2Yko2UTIxRi9iTWxsZVBqd0NWN01x'
    b'ZwovTW9BTjUvemNjTlFRaUNBR0EzOWFvTXJUcFpBbkpUNkJOSHp6bmFuVmk1NThidWFnVkRD'
    b'L2hGM1JTNTN0OTNIR0tRZTZSMFRubW9WCk9yaHZoTVhQc3dKZmYxV1hjMlVva1VKQ24xeHlx'
    b'WEVrQVViSU9qczM0b2piV3Q1bThiS090MGRadjdXUnJqREpNR3dTMm4wTUZDZFUKS2taM25w'
    b'bGxkck9lWFZGN3NEa3ZpSkNHVEFJaHNTRWplL0hNR1JWZm5ySzFEWkVnQ0F5YmhXeGFVTUFL'
    b'bk8xSkpSTHdIbDFzdk1DdApOTVFrWk4xUHBWenpadysyN1N4S0dBQUFuTzFKU3hDNjRnVHVl'
    b'aVUvaEVMYjVyVE1scC9NNHAyUVV3NzJ0dTA1ZmFFbUtXTlZwS0tBCkw4akpMcVpSeVZuNWF5'
    b'Uml6cVVyTlMxS0Y1Y09ENHdhaWNnSUVmZXVYUFdMSzNWZnRpbXROZDBwQ0Vvc3oxQlRTR2ha'
    b'cXZieVlGTGsKUndYTXdNY1BmdnUzTTJWYU95L0srczB4NXVDdUxGVDZRbFNsWG96amtKVHJl'
    b'WHh4L1JzYlQzVHBKSkc1NGcrU3hVd3JodGpTMDRzdApBMy81NjhadkI0MmlWdzdQVTF2NTY4'
    b'czZFNFZPRmkzVXA0LzVTODBHV3lCcCthSjUxMlExaWdlMWYwZ1cyd0VBUjlzVVpDSlczWld4'
    b'CnZFaVpMYk9FTVVLSFJnb0JjSDZneUlpdG5idm9SU0dmT2FFS2pPcHM1K291b2hpcDhkUjlR'
    b'dms5NWJIdjZ3UzFjY2tMWWNPbnNWblAKV0Myak5iWFZuUnJSZ0ZHMGRVN2JIOWRYTHk5VXpz'
    b'OFo2ZFJLSTBlY1ZlVU0yNzJNcitxTHdGVENsRHVOaUUwTGZ2UFkxMnQyYm80cwppdE9TeDhS'
    b'czM5bnV0QW5IMnZSa1hYbTJJeTQrcjVEM3lmeWM0YmZQekZ4ZDBudTJPN1Z4S0NGTzRCNDBp'
    b'c1pjZ204K2ZBMEpZK1JKCitXOERhb2ZVWEJqUGQwVSs3cjVTc0hGbXg4UzM1L3RTbFBBdk50'
    b'NTk3L1dHbmRDcEEvZWxpWWRpV1U2elYxQ1dNbml4UDROTGQzZDQKZGl4WnNxWHBTS1V3OS8x'
    b'dnYvdElidzN0Yjd3dVo1RktEcU1vSVl3UklBai9iUHMzZnpsWjNxV1ZUS2xPbm5KSFhucGc2'
    b'anRuWnY1bQp6ZGtkdTVjQ0FINFlPdEU4R2g4dmNHTklmVlc1SHdDZ2tGcGtYUGZDbkNFQks1'
    b'QWxOZHQ5akwyTjAxQVVKMStmOG1pMGVJcTQxOExkCkJjekFEVU10N0NkaEdENDVuM2xnMUxo'
    b'NVJuWGtkT2xNWUFZQXpNL3VBd0FVWVU4ZU83NnJReU1MNkhhRmdzNzlqV1UzdEhEaUlOSFgK'
    b'MXAxS2piSDNYUjhTRXRYaGI0NjZnU1M1MExrZ1oraFdCUTYxWkh1Q2xEME5oZldEOGdCQzlv'
    b'VW91NjRVTGNrZlNJdTFKNHNkQXFhNwpxVXQzUXhXZkx4QzV6d2NBMEtXTmJSaEtHRFFLUnl3'
    b'Q3A1OEdBSUFSTW16YXUvT1RMNjZORXF1WE5iWWlRdm14am9JYnpJaUtXQTJLCjR6aXNmdmRz'
    b'MmEwYVdaVTluQ216cnRtNUtUejFEaFdkaXNmYjJuMzBZMjJLUlhtRFBXT3hQN3poSVlMUExr'
    b'NTdzS0psYjBQQjR2eEIKVjRER29JVE1MaWFWaklwWXZtVUZ5cjMxSFRNTHJ6c09CTUdnRHEy'
    b'MGRUUXVYdUJxMTBvcnMwWlVWcjdTRUFNQVRpVGdEaTg5Z0pDWgpwUEZzSmppSU5weDllbXVK'
    b'ZXJ3OW5OZmExQS9LaGZiOURYa2ttb2lFVzRaTVBIK1EvR2IxN0Z2OUN6d0d2Q2gzNkwyYTBz'
    b'bDN4MFhuCit0L0JWL1ZGQkFoZlc5SjlTMjBmaHo2OVdPejAwK29INWErZm5LT1FXa1lzZ242'
    b'anFGTW4yZGRTSlJEZTZOcWlVQ2dsU1dQRnlXTkwKQy9wdEhnYWRpbGc5ek93NFV4Z2pKSXFj'
    b'c3pQVno2ODh6Nk9aSW9WUG52cjAzbW03ZS9XUzNhTjdkblUvTmJNNFMxYmUza2xweGlFaQp4'
    b'RjNZb2s3UjJUay9RamtBWU1QTTlpQktuQ0paYmJmSFhBY0FZQmowL3JuU1g2K3U2ZEpKYXBV'
    b'M3ovUkhNY0xYOVlXTDhnYm5aV3Y3CkE5dnZXYjdkRHlOY0Z2VzVxcHNVcGxGSTNpQ0ZDR0VZ'
    b'RGhVbDZpOFBKTElveUlhWkhWdzZQQzFKMzZtVjBDa0lCTVpOYjNQbWJycHMKV3BneVBXNFpu'
    b'UXpBK0dWeEdVa3gzeDZRaHpSMW94Wk81TzZaVzJGaDd0RDhuSkVkdTVmK01BbzdPdGYvRG9a'
    b'TXdwM1ZzMTViZnlwRgpiTC9sNE1DaFU1MFpYOVhsaGgzVmg3LzlnOS92dVZWSk9vM29DMUxn'
    b'TUJrSHdPcGhZaWprQ1ZKQ1lXS1d6QUpCZUlIY0FBQ1kwUDlFCmZFYWVJb241dllYSDZmYnNQ'
    b'VkxkZlhhSjJVaysxNXY0NDVUUHl4cjVjTnVoZlExNS8vaE5NLy90Ky9VYm9IZHlmRUhLTXlz'
    b'dW51d2MKUCtEbGh4Q3kvR29ydjM0Z0xsdlUzTlpXcHpHNkJRSXBoM1hqYXVyeWhrak96L1FP'
    b'VGs2Y3VjOGdQdDZoV0ZhZ2hDQWc0MTBiS0MyYQp6SnpDdFpOcitlRndZOFBoYnc3dnptRHMr'
    b'ZjEzWlRVOXlUYnZqNjNUK1FuRzUxWmVlR2JmNGhNZENqQ0ZNZFh2ZmVuV1NZU3N3STRsCmw2'
    b'cTdNZ0kvSUY0aHRYUyt1dk83bGh5OWsxT3JUS1lTL2FpM3h6bDIzR0RTY1lTNURCcjUycUZ5'
    b'VE1xbjMvVmJuRkJGMW1qanNCekgKUVZHU0VjV2d1RWtwVkEzREdmblR4bG5Yam8yZHF6Mm02'
    b'M3p1eEdYendCaGg1K215VVlzQXh5RU9QZmk3dTg2YzdVa0RQNGlGU28yeApQN2Z5d3RHMnJL'
    b'bHp3dGh0dHE1UHh0dG5adktaZ1YwLzJiZjkweldUblpVUWhLOHI3UXFGU2U0QTlZR0txelc5'
    b'cVRXOXFVMGpDVkt1CmUzTjU3ZEJBUTRpVU5iTTRpeU9hbnB1WmhBTndaMzVkcHpZR3hRZzZP'
    b'MmQ1VWYrSW1SL0R1ZTRRV1grSTNOMnZzbWpQREF6M3EvUysKRkpIdXU1YmNOcFZzSWdHOVVH'
    b'NzQvS0dEa1RNa2IyaGtnZHp3elBMYVhmVkZKenB1Zzd2OGJvOGJPeThQSkFyWi9nZm10RFFP'
    b'SjBRTwpGZ1lBM0RlbmJjQW8ybHJlR2tESXYxbFRvelNJMjlXeU1FYXdlcG5uKzFKTUxvYmQ1'
    b'UjdUOVMrTWUrV2QvZnFycmZWZXIxUHY0S3B0CnZQcWh4SGlCNjFpN2dnamhSamY3YkU5YWRX'
    b'ZDZ6MWlzMWtZM2E4K0Z2ZTE3NnVJNlZLSURUWGxhR3krU1lwMHB0VDUvNS9uNm9jVGoKN1ps'
    b'MFN0amhvMXM5MTBSOVNmTFlLMnZQSEduTlB0Q1VCd0EwOWZ2emRycXhjMDZtYXNlU3V0ZFBs'
    b'TmNOSkVXZXBNWGFwaWZyNWlwVQpMR3B3eXdmcktoVWpCeDdkSS83Wjg1TnJ5WGdlS2MvTnBD'
    b'SnpGYU5lbUdMMU1GY1Y5NnBzdkM2ZFpHYWF4dUpoZHFxbFRHclFHYUMzCnF1SjhRZkxrczl3'
    b'cEpMUWthYXhkSS8zNkovcytxUzJKNVhvL3ZUanRudExPcXV5UjdaK3VqcFJaVjlwMTM1eVdO'
    b'MC9OUHQyZGZydjAKSkFuY1ByalVuK1R5MDE2OXU3cHVRUDIzczJVZW1EcGtFdHE4ak9WRnl1'
    b'Y09MTjVlMlR5UmJicWlTSGxQV2NlM3pUa25PalAxVHJiZQp5UVlBWE93Zkh5dDdHd29JUkN5'
    b'RUVIZGRMa0t4bTA5Tkdqa01JNlMzTmgrclZTWW5paHhFQWxhWWFGaFozTmV1a2U1cEtOalRV'
    b'QUFpCkY3U3ZPWnNTWTMvaTYyV1RzeDJtUG02eks2UTd0WksxYjIrYW5hRSt2dU9MaUN2RjRh'
    b'TnZlbTg5aFlRYVhleERMVGtVVWhnQXNEQjMKME9Xbnpjc2VlV1o1N1Z6RjZLK1dYVnhaMUJm'
    b'SlRRRUFoREVvaEJBQkFCT1V4L05kaFhMRDV0bnRNUnd2QUdESGtycVBIL2dXQUpBcwp0bi95'
    b'NERkUExidjArc2s1MDFOMG4xOHFudkNqU0htZVE0L3ZVbG40Mno5WmZYdFJEbTdIKzlkUmpQ'
    b'Qk5jMjZTMlBuSS9FWUVJNDZZCkJXR1VhUGN5Qm93aWdFTVpFbXY5WU9MZjdqM2lDVkxKQk95'
    b'dDA3TXZQdmZoL1IrdmhjUGtxdXlScTc5NTk5T0xKUS9NYlZtVU4xU3IKVEthUncrOXNQY0pq'
    b'd284dnJyL1VuN3lpV0JuSk9SMDBDZC9ZZU9LTlUrVXNHckw3U2dHQkFQWTM1SDkyY1ZyelNE'
    b'eUtFV0k0M3ZuWgp3MDhzcVh2eDRLTERyZGtUQjkvZVJpQ0IyeENoTVBHRmd3dlRZbTJiWnJY'
    b'UDN6eGMwNXNhT1ovVjdxTnZlUGVlR0k3M0QwY3JMdzBrCmZmbndnVUNRWlBVd3pXNlcyYzJ5'
    b'ZWhqK0VMazBWVHMvWitoOFh5b0FBRVpJUkFoblVZT2ZYNW9HUWZqUjF2Rk50dFhEVk50NFN3'
    b'c0cKOWpia1Z5aEdYL3BtUWVTK1Z4SUJXeld0ZDA2bVNzRDBQL0xacW44d25UWTYxLytWc1Bz'
    b'WXRjb1VHQ0UvVUhHMUtudkVIYUJaUFV3RQpKZnFDbElaaHVkN0pxZTVLTjdsWklaUTRWNkZL'
    b'RkRwUmpMZzRiL0FubjY5YVVhUnNWY3Npc25wUjNwRFZ3enpVa3Iya1lNRGhaNHlZCkJaR1g2'
    b'K3k4aS8xSnJnQk5hUkJIYmdWVFNDMnZienhCSmFFTncvSlhqODRMaFVuZ3RzWHRwTVBmMHRw'
    b'S1FiTGp6S3VLZXd2a2hqYTEKN08wek15ZHZxeWFRTHJHVnBtcjNYc24vOWVxYU16MXBrVE5x'
    b'SGwxNHhlWmw3TDVTY0t1WFMzbWVyZVd0V1RKekhOLzl5T2VyZEhZdQpqSkJ1OXg3N1QyQjlz'
    b'a0YwVnJwNmVvb093d2dPSCsxUWEwN0xhQnlDRXY3Wks1OEV6QUNOZ3F3dDZaRndQZmx5NDk2'
    b'Ry9KYlJ1TnRPClpmdHZZWDBDRllyUnNsUU5qUkpPajdXeGFLRWhrK0JZbXlJVUp0bDhESzJO'
    b'aStFUWpSeU94RlBReUdFaUFjTndxRFJGNjRacHM5UFYKMDFOMGRpK2RRVVdPdDJmaU9EVDF6'
    b'YXRSMW04aTFXVThONXNXbko4OUxHTDcxRFkranhHWWxqU210dkp4QUNROHI4YktwWkhEZEFy'
    b'UwpNeFpMSnlPdDZqaVZsYWV6Y1Vjc2d2L2didmtQWi8ySG9KQlFQaU9BQVVqSzlZdzVPRGdP'
    b'd1FocHd0TCtYd0lTK0M5RDZQdUwxNlptCmJOTy9Cd1FRUlpUMUtLS3NSeEZsUFlvbzYxRkVX'
    b'WThpeW5vVVVkYWppTElleGY4OS9oKzNBMEJ3b0MyTyt3QUFBQ1YwUlZoMFpHRjAKWlRwamNt'
    b'VmhkR1VBTWpBeU15MHdOQzB5TmxRd016b3lNam8wTlNzd01Eb3dNR3dBR3h3QUFBQWxkRVZZ'
    b'ZEdSaGRHVTZiVzlrYVdaNQpBREl3TWpNdE1EUXRNalpVTURNNk1qSTZORFVyTURBNk1EQWRY'
    b'YU9nQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMTE4NSIgLz4KICA8L2c+'
    b'Cjwvc3ZnPgo=', 'US_NE')

US_NE = b64_US_NE
index.append("US_NE")
index.append("United States of America Nebraska")
catalog["US_NE"] = US_NE
catalog["United States of America Nebraska"] = US_NE
country["United States of America Nebraska"] = ('US_NE', '', 1)
lookup["US_NE"] = ('US_NE', '', 'United States of America Nebraska', 1)
lookup["Lincoln United States of America Nebraska"] = ('US_NE', '', 'United States of America Nebraska', 1)
lookup["United States of America Nebraska"] = ('US_NE', '', 'United States of America Nebraska', 1)
details["US_NE"] = {"continent":"Americas","capital":"Lincoln","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_NE"] = ('US_NE', 'United States of America Nebraska', 1)
regional["United States of America Nebraska"] = ('US_NE', 'United States of America Nebraska', 1)
#----------------------------------------------------------------------
b64_US_NH = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTI2NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05ld19IYW1wc2hpcmUuc3ZnLnBuZyIKICAgeG1sbnM6'
    b'aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUi'
    b'CiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RU'
    b'RC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5'
    b'OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1s'
    b'bnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0i'
    b'ZGVmczExMjcxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3'
    b'MTEyNjkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTEyNzMiPgogICAg'
    b'PGltYWdlCiAgICAgICB3aWR0aD0iMTUwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBw'
    b'cmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmlu'
    b'ZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZzti'
    b'YXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUpZQUFBQmtDQUlBQUFEck9WNm5BQUFB'
    b'QkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFk'
    b'VEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUF0CjFr'
    b'bEVRVlI0MnUxOWQzeGJSYmIvM0tMZXUyeExsbXk1MTdpWEpIWWN4eWtRVWtsQ0lKVFFXNVlG'
    b'bHQyRnBTNFBXQ0JMYjBzTkJFaEkKQWdtQjlPSzR4NzEzVzdZa1c3WjY3N2Y4L2pCcnN2djYr'
    b'L3plU3lEKy9uVWxYYzJNNXF0ejVwd3paODZGUU5xTFlBRy9aTUFMVTdCQQo0UUlXS0Z6QUFv'
    b'VUxGQzVnZ2NJRkxGQzRnQVVLRnloY3dBS0ZDMWlnY0FFTEZQNDdRR0ZpZ2NKZk5zbzFrOW5S'
    b'cGdVS3IyaFVKbW9QCjNISlFJM0lBQUk3ZCtYVzVSbmZwcDllbWpXeklITHowblZLMS9zQXRC'
    b'd0VBMFZ6UDM2Ny9ZVW1jL3BjK0F3aVFWUDdpQnMybGgzYmsKOVhRWjVTOWRjKzZWNjg1WWZh'
    b'eTM2NHVrYk8rVWsxcy9xY1FJSkVOdWZ2R2FjeHN6Qjlla2pHWEl6Ym1LbVhYcHc5TXUzb3li'
    b'NHdyUwpTUktZUEt4WkQrZWhwYzJQbGpmUlVMeEdxMTZmUGp6dDVvWnhaSUhDLzExQUVKbW5t'
    b'UFdGS0t0VHhwZkc2UjljMGpMcDRHL2ZlMzJPClloYUdRT05rTEVZZ0FBQ3pselh0NHQ1ZDBp'
    b'N25lSm5VaUpBWitNdTVwUTJUU2dCQUNFTjdaMlFaY25PYzBQbDFSOWJHektFVlNWcWMKaExP'
    b'alo5dW5ZbUo0YnF1UHRVRGgveFo0OU5EWE93NXBSSTRoczhRZVlEeS91bnB2Vy9hRjhiaXFK'
    b'SzJVNDB1WFdTSUViSER5NW02ZQpjWFBVQW1lKzBnZ0FPTlNUOW41andYdzc2VEpMYVp4QnlY'
    b'TXZpcGs5T1p6Z0N0SnZMK3g4NmR6U0NBRS91TGgxYzliZytiSDRYNUE0Cm9yK2d2OXZ2S2hw'
    b'eUZUTXZuaXNyaTlldHp4aDZwNkZRNytBbFNXemJjM3JadERBQTRPSHlwaFo5ekhzTmhkLzNK'
    b'OE1RdVRwMTdNa1QKeXdNWTVkSHlSaFFtTUFLdVNocmZXZGkxTW1rY2dRa0FRQmhIRG5hbnR4'
    b'aGlMRDdtUTJVWEQzV25mZEdXZldUbk45TVZEVStmckZpUQp3djl2eXg0Q2t4RWNBUUFJR01G'
    b'UFduSXpvODIzRjNaKzA1V1JJVGR2eWhxYzlYQWUvTzRhRkNacENERnVFMzdmbi94TlZ6cEJ3'
    b'dEU4Cjc5bGh6ZEdCNU03cHFKcXhPQVlGY3dicDB5NXV2TkFwWnZsOUVXcmRST3hkQjlkRmN6'
    b'M3IwNGVzUGxialJPemRKUjBESnNsWDdWazQKQVhjYjVRQUFHb3JSVUR4eVpVc2tkSVhuem16'
    b'T0drQmg0cHV1REFEQTBqajlZOHZyVy9VeHV5OHNYcDZvZlhKRlhZclVRcExRYXpVbAovM0sy'
    b'N0gvUStGTlZOWStVTndFQVp0MmNWeTZVbmh4S2VHQnhhNHJVK25aOVVjMjRDZ0N3S1hNd2pN'
    b'TS9EaVF2S05ML09WYW5qRWxZCnZtKzZNbWdvcGhTNHJ0K3pEU1BneHlvYUJtWWxKVy9ka1Np'
    b'eEI4TG9sSXM3Witta1NLMkZTcU5HYkU4VTIrUWNMNWNlWWxFakFBQmYKbU9JTzBtWTk3Rkdy'
    b'YU53cWJOWkhEMXZFSkFrOWY2YjhTRjhxa3hMdW5JNHFWUnMyWnc2K2NMWU1SWWd0MmYxekZH'
    b'N1A2VFY1MlFzVQovazhRTDNLOHMvRzRVdUNLNG5oaGlMUS8vN0xCeWIxbDM2WTVLMFBuNE05'
    b'ZGpGcUVGQmhmblRKMmZkWkFtVVpuOXpFdTZtTW1iSUlKCnV3YUdTQmdpS1FoQmtoQkdRQVFK'
    b'RVFUZzBzTTVDdVA5aTF2NWpFQ2RWbldvSiszY1NGeUVRQUFBZkVZd2dLR0JDQW9pWU5Bazdu'
    b'ejAKQXo0OXlLT0hRaGlhTGpPYnZheW5UbGFNV01RTGl2Uy9BU25iOStHV28zT3VlcmRSdHZH'
    b'ejdZNEEvUjl2OE41ZjJyWTl0M2ZRSkQ0MgptRVNRUUMxMEFRQkNFWFRDenRjNytKNHcxUk9r'
    b'QVFBNDlCQ0hHbzRWT09PRVRob0ZJMGxJWitjaENIRnQ2bWlLMUxxdkkvTzl4bnl6CmwzMXA0'
    b'MUZjejdlM0hraVZXUUFBdFZyVi9kK3VuWFp4RnFUd3Z3ZXpsOVV6SXkrTDF6c0NkQjRqNUF6'
    b'UzVqOFNzL3gvV0Y2L0lXTm8KWDJmbWkyZVhwc2t0QWtidzlJaG1iMXQyR0VlM1pQZEwyYjU5'
    b'blVxQ2hDNzlReXlKMTlWUHhGNFlWeU13a1NVM1Z5V1BENW9rMy9XawpKa3J0RGJzK1BkeWIr'
    b'bkwxWXB1UE9lK1RJREFaeEZBNmlyWG9ZcTVZL3E3RUFOdkYzM3hjb2piTVhSZkZUdDJ5YjBQ'
    b'dWEvYzI2eFRGCnFpa0FBQXlST3d1NkduWjk2ZzlUZGw4b1pWSENrdzdCSDQrdCtLeGwwYTM1'
    b'WFR2eWV3RUFKYW9wZ29RUWlBQUFiTXdjbW5NTmI4cnIKK2VoaVhsWHlPQURnMW9MdVpZa1Ro'
    b'L3RTSHo5ZU9la1FNSkRJN2d1bHdRamF1T3ZUMndxNllJZ0VBT1FyalFZWEovLzFlKzcvOXRy'
    b'RgpjVCtOSnpkbXB2cStQUXRPeGI4TE5pMGN4aEdEazlzd0VVdVFNQVhHYTdYcUZyMGloS0Uv'
    b'RGlRRkl4UTJMZlRWanU5UzVaYTM2b29TCkpZNlR3d243T2pOWEpHbmJwNko5WWVxVWt5ZGdC'
    b'UHBucGZrS0kwWWl6aURkNm1NTm1jVkdOd2NBd0tSZ04rVDIrY0xVK2duVjNjWHQKb3hieCti'
    b'RTRBQ0NkZzM5NkpBR0NRR0dzOFl1MnpCdHkrcmRtOTU4ZmkvZUVxWisxNUxpRHRMNVpXYmRS'
    b'N3ZEVENSSzJCeGdCak5JNwpJNk1pT0U3Q0N4VCtBMHJVaGhldk9YK29KeTJLNjUxMENBQUFM'
    b'QnFXS3JWTU92aHpOK1FwWnI2OTdjRFJ2aFI3Z09FTTBML3F5RGE2CnVXRU0rVzE1VTA2TTZm'
    b'eFluTlhQMUlpY3d4WnhzMTdST0ttY2k1UFJVQXlGQ1p5QUoreUM2ckc0K2drVkRKR3VBT1Bv'
    b'MzQxTUZDWVMKeExiZUdkbnBZVTJPWWpZVVFjY2R3amZXbjJ5WWlOWC92ZXRZZ2N2aVkrRUVq'
    b'Qk93bUJXWXRQTS8zblpVNStEUGV0Z0xhK0hQK09QeQora1N4SFlaSUtvTGZXOXEyZFZGZnN0'
    b'ajIzT2xsRjhiVmMvcndoVFhubmo2NXJDeGV2N3VtTkVsaWUzMzl5UnUvM0l3Uk1FRWd0VnFW'
    b'CmdCRjBCT2lOazRyTm1RUExVdTFpUG9QRG9yR1lGQmFUQlFFU1JZaFFDSE41UXc1MzhIdy81'
    b'N3ZPNlBsK2FTaWVJcldOV01RRUNRMmEKSkxWYTlhTmxqYytlWHZieGxoOGVQMTU1cEM4RkFK'
    b'QVpaZHEzNDFEWHRQejcvdVFKdXdDQ3lBTGw5Qk9WZFZ1LzJMSmdrZjRFT2lWaQplT3IxRWJQ'
    b'NDhlT1ZhOU5HN2lwdUJ3QU1tOFdWSDl6cUMxTnVLK2g2dUt6cCtiTmxpNkpOejUwcWp4QUlE'
    b'SkhMTkpOQ1p1QlFUNXFJCjVYY0Y2TmRuRDIwcWNNbGo0alJaMTBVblZnRG8zNG1ua0RqdTdO'
    b'VDFIcDZjR1ArMm1mMWhYUnhHL0tRUGx5ZE0zTCs0OVlVelpVTVcKMFo5VzFIVk95NSt1cW5t'
    b'dHB2VHp0bXcyTFZ6L3dDY3FvUXNBOEVadDhabVIrRmZYbnRXSTdhcC8rVzBJUXhjVUtjaU5t'
    b'V0ZRSXZlVQp0Qi90VDk2UU9idytmVGlNb3ovMEo5Myt6WHBua0w0eGMrang1WFV2bmkrTEZ6'
    b'cGVxeTE1dVB6aXVFM29DZEVtN0FLY2hCeCt4czJGCnczL1pPblBERGJma3IzazhXbFBwN1p1'
    b'T2lMaXZISDZsdXF1Nkl2dm5PT2ZUWHp4ZE0xQ1RHWnR0YnpQRWxPNVFaVzllVVNEYW9Ea3QK'
    b'b05tYXhrVUFBa3ZqZFFBQ01vNnZUcXVxSGxkZmx6N3l3MER5N3lzYVpqMmNuaG5aOGFHa2pD'
    b'aXpTdURLVnhwbGJGL1ByS3dvZHZxYgpyZ3dSMDIvM002OTJDbCs4OXR5VWk3YzVhL0RNaUta'
    b'bVhQVks5WkpuVHk4NzFKUHVqMUNYeHVuZldIL3lxVk1WY1FMSEs5Vkw0a1dPCmNvMXVXWUpP'
    b'YStOYmZTd0YzNzFuWis4Tk8rN2pwOS9ZWnpYdlBidTNPQzV2WU8vbmI4K2NiRGUycDh2UytR'
    b'eStWQ0FGQVBScCt5Yk4KazJmSHovWk45TVcwR3NRRitTOGVmSm1neStNeXQ2OHBpVitqK0s3'
    b'ZlFEcytFSjhxdGI3YlVFaVMwQjFGbmNjSGt4YkhHYjd2VDM1aApUWFdYVWQ0M0k5dlhtZmxK'
    b'Yys2UEE4bGhBa0VBV2F5ZWFweU0vV05sL2Y3T3pLdWFRam5YODAxbnBvemp5MWZNbkJuUjdN'
    b'anRmV2JWCmhSV0oycS9hczhRcy82SGJEang5Y2xtdVl2YUZjMlVBUURZZmM5d21GREFDcDRj'
    b'VEhsM1IrOXd0a3RLdEgzNVlkL1RsVXk4M2FCczIKNW03czFIZC9ZVzgwQkF3QUFpNi9LMHVS'
    b'cFpLcEFBRERodUVqM1VkOHVNOFNzSFRUL0NRQ3E2U3ExNnRmUDl4eDJCZmhicjMrMWVXeApq'
    b'V3g4OUxYemkwZ1N1cmUwTFR2YXhLT0gzcW92MnA3YnQ3OHI0Ni9yVGgvcVRnOWk2TDZiRHox'
    b'UldSK0lvTjNHS0pYQWRXWlU4MFp0CkNZY1dEa1FvVis5YStNbTI3ejlzeWxNSlhkZW1qc3k0'
    b'T2ZlVXRObDh6TTJmYit1ZGtSN2V1YjlPcTFMeTNZLzlVQlhHa1d0U1I0NFAKSmdFQUVKajQy'
    b'NDB0cTlmZlR0Z2wzaGpCZlYvZEY4dUtqV1pHQjROQlpiUnlXZVl5R29XR3dJZzZTczJnTStZ'
    b'N0NnUURFek1UQkVHRQpJcUVMdlJjTVJnT2RUamY2alhxZi92MGQ3N09uSEt3b3h3L2ZmWHpI'
    b'Ri9sM0ZYZE0ydmtkVTFGbUw0c0M0Nit1T3ozajVoYXJESnYzCmJNdFhHZy9kOGcySEh2NmdN'
    b'VDlSYXZ1cVBWdnY0TjFYMm5ybmdYVlhxUlJDRVBubWhoTm1EMXZFRE9BazdBN1JQMjNKL2VP'
    b'eEtwMkQKZDF0QmQ0ck02dlRUMzIwc3RQc1pBQUFKMjJkdzhoQ1krT0syeG5VM1BzVVE1QXkv'
    b'K3o3SVN5VjlwSXdqcy9sc3ZkN2VZZXN3N3NYWApscXlOa2tSUlVFbzRIRFlhalR3ZUR3QkFR'
    b'U2tTZ1lURDVPdzV2ZWVVOXBRSk13bXB3bmhKdklxdFVrZXByWHYyUjYrNUtTMHpLNXZ5CjFS'
    b'TS9GSVJ4MU9qaThCbkIxYW5qMy9XbUZTaW1GSHdQQlNhUER5WiswWjZ0Yy9Lak9GNUhnTUdu'
    b'QjhVcy84MzUzVy9XRlFNQVhaMFUKZ3Z0SzI3L3F5RXlWV1Q5b0tuQUc2QTQvZmR3bUZESURu'
    b'MjQ3K2xaOW9UTklOM3RaYzBHdnVlMzREMis4dVBIbVowOFBUMlFrWm4zcgpIaHcxanBJazZT'
    b'YmRIZFlPSlVmNTRxWVh0MVJzb2FBVUFNREkyZk05VDc4QUpnMWordys1VFNhbjF5TldxU2dv'
    b'cFR5N1BDOG1yMXZmClBlWVprN0tsZElTdU5XcG5sUHppck5MalhjMnJsMjFRNDE5LzJaeUF3'
    b'c1FyMTUxaG9Kak96cWRUOEk3cHFLZXFhdmQxWmRoOHpEQ0cKZGhqbEY4YmlsbXAwSGRQUjY5'
    b'S0czNjR2dmpTWWQxV3RoZENCcnZSRWliMUVOVldyVlMzVDZOUWlWK09rOHMrcnE3dU04aVNK'
    b'NDZQbQovSzNaL1ZFOGJ6QkNjUWJvdjZ2c3VlbW1XNDVyOVVlN2ptWXBzbzUwSEVrbVpVVVhS'
    b'amtyeXF0U3ErNWZmWCtNTk1adXR6TVlEQURBClNFZW56MkV2ZS9sNVVxTU8yWjBVdTZObDc1'
    b'R1B2NnJWanZWZnMzYnRxc3hWYXA1YXlCWm1IMmoxUnNzNm5RT3AwYW52bkhzSGgvaHIKQ29w'
    b'SmEvV0VqY1duaDlSQ0Y1OFovTHgxMGM3Q3pzN3A2S1h4K3JPajhYY1VkZVlyalhvN2YxMzZz'
    b'TTdCZi83TXNqazljZlg2aFR2eQp1aS9xbEdOVzRYdzh1bkhYSjMrdExXblZ4MHphK1g5ZVhX'
    b'M3hNcnVNVVJNMi9tY1AwK3R4NWFHK1F4V0tDanlDYTJJMUpydnA5c3FkCllwSEU1M2FQN0R0'
    b'dzVNZUJnUkM4Ny9oZlR1eDZWSzVTY2JNemt0ZXNuR3ZXUGpONzZMbDNuMm1ON0ZnRVh2M2tM'
    b'L085VzIyV1Q4NTkKS2hmS3RYb3RRRUNOc1daTDVwYkY4TVN0cjJFaVZrREM5aDBmVFBTR3FQ'
    b'bEtZMDdNek84ckdwYThjN3ZwNzBHWmVKR2pMRjYzcDNYUgoxZTdhaTFrK3U1ODVyNGllWFhr'
    b'Qmhra0dKZkx5K1NVWUFUc0Q5R0tWb1VXdk9QNmJ4bFYzSFZuM3lpWStsYTlrS3llOEU1YWc1'
    b'Zm4xCnp4ZW5GUk1FVWZQVTgzeWxJcXhRdW5BaW9CMkppMUZrYmQzMGIzWjMrTUNCalZ1My9r'
    b'TmdmZURpazk4L0tXUEkxRXkxenFmelJyeEgKSGp0MC9HL3JyM3RuOGFYcThiWDFKLzBSYWdT'
    b'RG56dTliSDR0bDdGOWx6M01kbmxpdGZsSzQ3MmxiU2hNeUxtZVY5YWVtWjhwQ294dgp6KzBk'
    b'dHdwK0hFaUdJZkt0amNlZnJxcHBNOFRjVmRLYnZmeTNBRUpUUmFreDdCaU5VbU1NR3F1U3E0'
    b'clRpZ0VBUG84M1pETEZibHhiCnRIWmxRbWJTK29kLzgrL3hSeEFFUXZubmVFcHhXbkZWY3RW'
    b'MFlGb1RxMUd5bFNtaUZBQ2g2VXNmMkZuVWQrbHRSL3RTUnN5aTdUbDkKODBuK0pBbjllWFcx'
    b'bU9VSEFGeVhOcHlubUxtS0tHeWZpdHBaMEZWOS81N3FlNys0MUtsYWthUWRNRW5TNUpZNmJl'
    b'enRoWjMrTVBXdAoraUlTZ0MxTFNJRnlhY1AxTjZXcjBnRUE1MGZQWjB1ejc2NjZHd0FRRG9Y'
    b'R2pwMUVWRW9PbjY4ZEcrdHVhLzJaTUw4aE5QN0JwZjIyCk5sK2NHQjM1MStPNXArcWVMSEZX'
    b'OVdnMUFDQXROcTN4K3B1aUVsZHNMUTFjZWlTalJxdEtsbHBIcmNLS2hJbEx2M3YybnM4UDNm'
    b'Yk4KWDlhZTdUYktyaUlLU1JJNk14S2ZJVGZMdVI0NTF5dGgrZWJlMzV3MWVHSXdjYzRFL2N2'
    b'NUpXL1VGcWtFcm0wNVF4bWx0NGNpSWVQTgpWWjFqblZVTzdnUE04amZ2ZUpQUDRRTUE2ajcv'
    b'a2hFVFZmSDRZMVFhemVOeE41MDdHcGs5K1ZNdllWdGs5c1RQcm1IL00xUXFsY240Ck4wd1BQ'
    b'b2YvMWwxdjNjOG9XK25rZDQ1Mnp0eXlLaGdPSmhUczNKUTE5Tk0wUVNTWEZ2WUVhY2NHRXpk'
    b'bkRjN3ZqakVwRVpYUVZaa3cKY1d3Z2FUN2NlbFZRK0ZEWnhmdEtXK2ZqeStmdSs3d3lZUUtD'
    b'eUtYeGVwd0VwMGMwVDFUV3NhaVJJYk9rMnlqYlZ1eVdKYTc4NE9nSApmRVVNalVaakxDa1NG'
    b'ZjJjMTF0NTl4MHA1VXRSRkFVQWpBNE91cjJoME1nYlA2MVZLQXVDZmhKeDNOSG1jMXNQNzk5'
    b'MzRvZWpCUEZ2CkgzY1NGdWN6RmhkUzZWUnVUTlQ3UjkrUHoxcTNJYzhKQUhoMFdlTlhOMzJi'
    b'S0xHZEhZMFA0K2d5elNRRWtSVUpreTBQZlhSdDJrOHkKdmJPdzg0NmlqcXVGUXJYQWFmS3d0'
    b'KzNkY3JBN2ZjckZsVDN6V05idSs4K054YVZJclE0L1BVN282cHVSY09taEI1YzBiOG9jbExC'
    b'OApNYXJFVTYybk9zMmR6Y1BOdVhHNXJ6VzhMNGxWL1N1eEpnY0dCbVpuWm54QkhKVXN4V3dY'
    b'QVFBQVpRUDRKd29IRzk0M29XdUtGeTlXCkppYkQ4TSsvdXFHbXB2Yjh1YmxyaVZLMXUrSGR2'
    b'UGk4NXVIbXp0bk9VNjJubEVxVmlPWGYyNWJ0RE5Bck5CT2QwL0pZbnNzVG9pYUsKYmRWajZv'
    b'eFg3MDk1K1VGdmlIcHFPT0hCNzY2aG8xaWkyUFovUDUrWFlhOWswc0dmMjhpMWVaa0lSTXlu'
    b'dmhjb3B5L3FZMGdBTUFMNQovWTlWYzI5dXp4M1FaTjZ6Kzl0MzJTamI2ckRXNm1zTGxZVUNy'
    b'dURTQm1kblozVWRueXpLS1c2azBmaGlNVTF6ZjNEd1JkeCtrYUxjCkJpQms1TnhqSHRhS0JE'
    b'SEdLMWhiVTdkYnA1L3dkejdDWFBUcTNJYVV6V2FkRjBvaFQ1Z2NuZnp4eFkvVHVHbGNLdmZ6'
    b'aHM5ZlhYTkwKZWZ6WHcyYng2N1hGYytsckNFSTBUU29MWTZmbnRoaE5IbmFMSWVhVjg0czdw'
    b'cU91TG90MERwMUcrV2V0T1h4R2NPNWxvc1ErYmhVRwp3eWdBWUhYS21KVHRBd0NzelBUQS9Q'
    b'UVozd3hFUUZ3V04weUdKVnpKZkFzWWhvMk5qYUVvV2xoNU42YjdkTEwzT0lNSmg4WS9nSm14'
    b'Ck1EdkJwbS9zR3ZHdzZTQkxHV1NxdGdVSFg1bzFqSHZON1RPZ2RJNC9sOHQxNGRUSit2Tm5m'
    b'L1p3T09Jd0dlYXhlSUFBMDU1cHZxSmsKZVpwOTBzSFBWODZreWMwb1RJUXhSR3ZqSjRnYzg4'
    b'dmgrNDBGbDVHL3k2WklSeDUvZSs1VVEvMUU3RWRiamdvWVFRQkFvdGp1RFZPMQpkZ0VBb0g5'
    b'VzZnclNBQUJpQVpQTEZlUkc1VW81MHFTb0pKaUVsNlgrNUpZWmpjYmg0ZUdFaEFTeFdBelJK'
    b'S3ppcjZhTUxnNFlSWGpwCkJEVm1aS2pQYStyT3pkU0lKREdZdlJsM0Q4S3NXTCtwamkzTDlT'
    b'RkpmcisvdmIzZDRYREFFRmkzN2NhZ3k2MDlWL1A2aTNzOGd6aEMKSWtueUpDbGJXcUFvWUxG'
    b'NE1pSFRIMEVWUFBkVEsycTM1L1pPMlBudUVDMVJZZ2NBY09qaER6Yi9lSFlrSGdDQXdrVExR'
    b'eC9PYlF2LworaW5VT1hrM2ZyazVKMloyemxKWWthVE5VeG9CQUhLT0J3TGtYQ3pVNE9UT2JZ'
    b'Z0x1WXlaMXZadGNMckpZM0w0SGRmS1Y2ZXIwd09CClFIOS9QNVBKVEU5UEJ3Q1F1QjhBZ05t'
    b'YXdrRVBoWnZjMVh5cXQ3c3BJVjZoU0NxRG1VcUFzaEJCUHNCOWhOOFFaaFRFYVZJUEh6NXMK'
    b'bk5iblpxalVhalVYUXJtRG81WTlYNXM2aG8rM1RXSWU2TEdxeCt4K3U4bGoya0ttenJaMzhq'
    b'aDBrb1RDT1BMbk0rVjcyN0wxRGo0QQpVQlRQRFFCWUZEVjdiZHJJcmlYTkFJQTBtZVh4WTFW'
    b'R0ovdXFXQXNoQU5vTTBjc1RKdExrNWo5VjFnRUFmR0hLbkZKQ1lPQUowY28xCk9uZUExbW1V'
    b'QXdBWVRBcE5KTlFIYkJpRzdkcTRxNnV6OC9lL2VhQm84ZEt0Tjk0RVFSQUFnTVNEdnNZdEVN'
    b'b09NZ3RobWlUZ3M4RDAKOUl5a0tJU3A4cmZmUXdTbUFRQXdVOGtxMlcvVk53Y0RyUnpFRkMv'
    b'RHlJSG1DRzBITmZiR3lvUVVCUUU3S1lncUpmNmRHRUVQNWw5ZApzSHAxd2VyYi9ucmJWTkNS'
    b'SkJTd0dCUUF3UDZ1ZERxQ3k3a2VUNUNHd0NTYkVwNy9PYyt1dW5CeUtJRkhENTBiaTRNZzhx'
    b'cVF3djAzCkh5clg2THhoYWxXU0ZvSklzNWZkYm9nR0FMQ3BFUlRHZldGS1phTDJ6dUwyeFhG'
    b'NkdvcFJLQXhHdFB6Nit4NWowVmgyaDUzR29hOWUKdjZtdnQrY3Z6ejc5OXU1WEpyVGFZeitl'
    b'ZEdzK2NzVytlcmpHSStDUUVpN2s5RVFjN3BCMThvTGRNdVgwa2s0dmFUZnJMY05IZWdidApi'
    b'RVlnT2o3VENGVjRsUC9pNDZ5eDIrM2RvOE1YYVpCbysvV013dHh6SmtOaGVmbmcyT0RNN0F3'
    b'Vm9sYmNjSHVRVGdNUVFrT3hHM1A2Ci9yYmxod2NXdDNvalZCVEJPYlFJQUtCdEt0b1pvTU1R'
    b'dVR4eElvZ2plWXFaejI0NGNsVklJVTVBWDkxMGFObDdPNWZHNjRJUnluMkgKcnYwbnAvaTl4'
    b'bnc2Z2djd0ZBQlFOMG5aOWVvQmhCcnJ0M00ydmIwSFFUUG8zRUs3UHdDY3ZzTGhGLzcwd3h0'
    b'V0p5UlBLT2t5QkZDTwpIR0VYMVkvSE01eXhBbk1SQUFDQUIzOXV0Qm00dXI3MU93cFJYWnBE'
    b'MS9hanc4MFFPc01lczIzUUxaSmx2dnRGT09Kek91b054eWk4CmdIdUlpSndNKzBWYlArd0sr'
    b'MGR2a0tBQUFJS0V1b3p5VVl2dzBuRUdJdWlEaDYvWmM4T1Jpb1RKTXlPYVUzZnY3WnVWWGhV'
    b'VW5oeEsKWEoweWRsZHh1NUxudVhYL2hoS1ZJVjF1ZnJ1K3lCdW1ZRGpDb2tac1BtYUZackxW'
    b'RUdQeXNDSGNoOUtnY1BBQWdrcHhvcGxDamFldwpCTkxzNjZ4OUp4d0dRSWY5Q1FwK2FrRU9U'
    b'RnhjdmpxL29mcGNPS1MzVE5EODB3MWhocFFpVUtFaUZVVVFTMlVLQUFDRVp4WVZxUkE2Ckcw'
    b'Rm9ESkhhWng0ai9BNTg5SnhKVzBNbEk4cllXRGtuR21Wd2tVQXdFbTZCMGFSSWVEK1Z2UVNG'
    b'aVJDR3RocWlKU3kvMWNka1U4SVkKam5oQ0ZBREE3VVdkVERSeTV6ZnJuMTU1NGNhY1hqSExm'
    b'M0lvNGVwUXBGM3BXcHRnZWNMRVo2MkwwdVhtMzFVMFN0aCtBSUEzUkNVQQo0TkpDajFVMDlN'
    b'M0tkaTF1QmdBUUVZd0VBUUFQUlFJT0dPRmpvWFlBQUFRajRvdzF3NUlIYlI3RU1PMzY0TFhk'
    b'clEzMUx6LzFoSFprCnhLSWZ5OWZ3WmE2THoyNVJDN3QzUDU0L2plOVpuai82T1BaRmxTYlNJ'
    b'WjM0aHQvelRrS2szM3R3cDJ6a0UxcnZKL2Z1ZWpBek5YRnAKb1VMSm56VkZlQkNNUk1LdE1N'
    b'eVBCR3dRUEVxQ0VJN2hBQUIza042a1U5UlB4SExvSVp5QXZCRXFBRURGZHo2LzVyeUM3OXJi'
    b'bGwyWgpxSjF4Yy9hMloxOFZGT1lyamMrZVdoYk45WVF3cEVRMUJRQ29HVk1EQUdZOUhKSUVT'
    b'b0ZyeENMY2tkZnREdEVCQUJ4Z2hhRTBBQUdFCmhwQVI5YzgyRVl6SWw5Nmo1Mit5K0hqWGJO'
    b'aDA2NzBQN0x4dlYxcldJaHpIdi8zeWk1Nk90b2QyM2pMVTEvdkVnL2M1N2JiZTloWVEKZGxF'
    b'Z1BGckVsbkhnL0F5VmpCRytibFdwbklHVnJhZ2E3dXQxZVVJV0Q1ZGJ0Qk1BQUFHSWpDaFJP'
    b'b1VFRUlXV0V3NzRBUUF5anZjdgoxNTU5dXFwR0pYUkNFRG5qNGdJQWFyVXFBTUF5emFRblRF'
    b'MlRXNTQ5dlN4SmNobWlNNWRodjNEWGttWkhnQjdHMFkwWmd6TWVkaUJDCitkUHhTZ0RBODJ2'
    b'T1c3eE1Ealg4d3JtZmoreCtkdjFCbDhrOUNBUUdDQ1VCVFVFcVVFRmFrQzZMSUlJSXpBMlQ5'
    b'TmhQN3RQN3pJdmwKRkxzWGdtaDhscEtKc21NeE9qM0NoTU1VQmtTaDRCam1kRHBjVG9mTDRm'
    b'QjYzTUZBd09OMi8vT1lFQ3B2K2Ura0t4NERBSUNwVXpiZgpXUktDR09JVlhOSHlsVlBYM0x1'
    b'dkFvYklWOWVlUGpHY1dLSXllRUpVUGozMDdPbGxBSUMzTnB4QUVVTE04cDhmaXd0RjBHaXUr'
    b'OUxCCi8yclh3Zzh2NWhFRWxLdVlFVENEcDBjMDMvYWtQYlBxd290bmxvNWFoTG1LR1UrSWR1'
    b'bk5EVHIxaXFoMjJwQmR4b1VNR0QzTE1ET1YKMXBJS1JWQUVpMkFRUWFDdURGelJ6cHlRMjV4'
    b'V3RDREZhN0ZEWUhZaTRrYWxVUkZ5bkU3U0NRTEdXRzVPakFvTHVmazBObzhaTDNYaApmSXda'
    b'ZENGQ2hBNHd2OVBzQ0E4YkhPSmxEd0VBL002Nmt1WkR2WElYalowZTMzbElsTHpuNGhnZmdr'
    b'Z1VKaDc5WVJVQW9Gd3pHYzl5CnRoaWlFWmk0djdUMVR5Y3J0MlQzYjh2dUc3Y0t6bzdHWDVi'
    b'OG1jdmhGMEprNjI4L2V2clU4cTg2TXNNWXNsaXRqK0Y2S0NqUmFvaDUKWUhIYjZaRjRCQ1p3'
    b'QWk2S25XcldLNDRNcEYrWDJPME13Qlk2TkJGRnB3bUJnMHFKOWptVFkvMU1Pc0FKd2hkUGh2'
    b'UEpMQXJ3QmNnZwpEb2xpOEdDSW5MVkhBZ0NQellpMERCQjBLcndpTjNTOG1lQ0tuVG9ySkE2'
    b'VExBaUJYSURRb1FpTkRFdUQwaDZPbTBua3RGZEZhTkorCjFEU3JkamdvdE5UWkxwVURSS1hp'
    b'THd6Y2RHOUpHd2tnWDVqeWRVY21Sc0FsYXNNN0RRVVVCQzlQbUJ3MFMrdyt4dEgrWkp5QUcz'
    b'ZDkKdXZMRG16MUI2cStmd21DRVVxT05lMjNkcWNYdjNQN1ZUZDllKy9GTko0WVNBUUJEWmpH'
    b'ZkVaeTA4ek9qekYzVGNnbmJCd0N3K3BnKwpnbVZVK2owMHVqb1luSVVRaDVCckNBU1JTZmlT'
    b'L3dSR3AwZjhBUXFkR3VZd2NRQlJFcFFZbDRGNS9NaTFTN0Jna0RTNVFYa3VjSHFCCktvWVFj'
    b'UUNGZ25lT0VxbnhFUm9DaHFmSkRpSWtqVWFrOEpRMmJISkpaWWdSVm9lQ0hoRnRtaGxnRVJ5'
    b'N24wRkRjQVkxd3FSRWNtSm0KRFE0ZW14b1p0WXBJRXJwK3p6WWFpdTNiY2VqZVE5ZWR1Ky96'
    b'Vm4zMC96MS80SEpsc0hVYlpTcUJpNElTSW1iZzI1NjBlUzZ5bzJkbgpQT3gwbWFWaE1uYkVJ'
    b'b1lnTWpkbTFobGtMbzdXdFNEOGNBVERNVExFb1RzaE5DbnN2OVFvd3pBS0JHQWNwL2lEdEZB'
    b'WURZUlF0NC9tCkM5SjlBYW8vU0F0SFdCQ0UrQU1ja21SQktHNjJzd1FjdWx4RWtvQVJLNGRT'
    b'VTBsMU5LQlNJblZzYVFSQktHNVBCSUdETE5wS3Z1UEgKc2R4QnM2UlJGOXN4SGQweEhYWERv'
    b'cjRJam9Sd2RMNkFBazdBMTZhTjRBUXNaZnYvZEx6U0dhUmZGWW9VQUREajV0eHo2RG9BZ003'
    b'TwpwMU1pd2IvblhuelhrM3BQU2R1UVdRSkRKRUZDSkFsdHlCeDY3blQ1OWVsZGZIUFlFQ1hr'
    b'VFZyVERPWUJFWi84ajNOdlNaZ2c1N1l5CmZ0cko4Z1hvRUFReEpFbWkyQXlPMytseldVMCtC'
    b'NTNKOEdFUTRORWpnQUhSZUI1UGQ3eUphaUY1YmhrdDJ1NUYrT3o5M1ZtclVzWXEKRTdWN1d4'
    b'ZDF6Y2c0OU5DU09QMGJkY1h6L1RBbzJOY2RXU2VIRXZaZHZwTVZsL2xzVmExV2xhZVk2WnVW'
    b'ekFXMXo0N0V2N0hoMU9IZQoxTEo0bmQzUHVERzN0MFVmUTVEUXNkRzBRa24zTk1IaFVpRVRR'
    b'WSt4NEZPWUlpQmt4ekJrSklIREVJRmpZWmdJZ0xDTHhBS0FKUGc4CkRwTWpvakg1QUFDVUla'
    b'U2xMS054cEFhVGt5ZUsxdGxDMHk0WWltWXdXRndyUnNVd3pCdEdKb3cxcEkxQkpXUmFFUUFJ'
    b'SFVCbjVjbTMKL2RCUkkrUDRFa1gyU2JzQUo2RmxHdDJJUmJRNWMvREMyRSsrRFowUzBZZ2Ns'
    b'OFdkdjRJb0JBQ3NUQjdMakRMTlpXTkdDR1JmUjBhQwp4SjRaWmY3RHNSVi9QTGFDVFF2ZlVk'
    b'ajVTVXYrZ1p0R1NxZkNzNXcwRXFVb2pTRmVBTzhRZUVWMHRZZ3ArS2NHQ1lKZzhIZ3BXUVU5'
    b'ClUrRXBQeE5IZU9IWmlIWmNHSVpaWUw0MGFSQUF6MCtYWWUrSTE3c25WNXR1WnpNbW8rZ1V1'
    b'cExKZWpNWGUvYjJpNWtZQVIvc1NiODUKcjN2TUp0eFplTTRmb2V6cnpKZ1BCOTZVMjh1bGh5'
    b'NUxVTzN5cjRYem9GTWl2MW5TdkRwMWpBSVRXeGIxK3lPVVU4TUpiNncvOWVOZwpJa25DTXg3'
    b'MlM5ZWNpK1c3cDl6YzJvbjRtMHRzTEZzU2Q5cGVJN05TbytMTnNGbUg2ZGtSTm8vRy9RY2xD'
    b'a0MzWFhMTVV6N2lqNXFOCmlFMGh0aFhqNGRDL2JXZ0VuUFYrejU4QWhGbWsxODZDVXpsR0Na'
    b'ZWFWUkZ6K28zdm1EQ0pQVk4xb2Q4a09kS1htaE16QzBIZzNwTDIKKzcrN2RsSE03UGFjdmhp'
    b'KzU5RmxUUXdVTzl5WFNsNitiUHpMU1dFTXovUFo5aVB2YmpvZUozVHlHY0dLaE1ranZhbmY5'
    b'cVQ1d2xRRgozODFBc2NKWVkvMkVLai9XMkRTcEhEU0xKKzBDTWN1WkdJY0dLRXFGTUdrOE1D'
    b'YUpTRndVdHlWc2phZkd1WUtRSGVQcUNNMGttVGdLCjVib0VKZitWTVpBazRUSC9BVUErQ0w4'
    b'V3d3YTQ4cWNJcGlvdVdqZloxOWMwek9ZemdnZTcwMWVtalBmUFNuKzNySkZOd3daTjR1LzcK'
    b'VTZaYzNKVko0Lyt5NWp5ZkVkU0lIYjh0dTdna1R0K3NWem9EOUt1TFFrK0lkcWc3M1Jsa3JF'
    b'alVBZ0FHekpKN0QxMDM5MUg3VlBSZgoxNTMrdkMwckk4cjhabTN4b0ZsQ1IvSGZsbDE4dTc2'
    b'Z0lIWkV5eEEyZWZyQ3BOaE9oS2hrUlFEWXB2Q2JkY3hFRTFVZDRCV0U2TkVrCmxmK2Y5aDcy'
    b'RGtjQ0pzampDWVliS09pMlNQQWlBdE5DdnU5bFBDVE9YL1BTRVRXZkVYcCtUWFVFcHh6b1Ry'
    b'ODF2M3ZTeVgrZ3RPMk8KQStzQ0VRb0EwSVh4dUMzWi9VSm1FQUR3V20zcEkwZFhXWDJYN2F6'
    b'djVjeWRJVWhvMHM3SENYaHZXN1phNEN4V0djUXNQNXNXdHZzWgpMMWN2dmlXL0owRm9Wd2xk'
    b'UytQMDZ6S0c1Vnh2dm1MbUQwZUtFL0hoQkVrVnpoNG5HVkYrY3BnZ0padE9QbzNRSkc3cnc4'
    b'N3BwN3lXCkEwVEl5bkszSU5nL1JORVF6TTF5dHhBaHE5ZHl3RG45bE1mMktFS1RiRHp5T3hM'
    b'bmhmelZDSlVIMFRyU1pjdUtRZE1qZTVPb0tINWoKVHMrRW5WK2tNcWdGVHJYQWNYTnU3d3Ru'
    b'bDloOFRBcU16K2tNQmM5emJDQ0pKS0VXZmN6bFBYRi9tZGZDOVJsRG56Ym52RmxYdks4egpN'
    b'elBLUE8zaTFqLzRXYzI0K3V4by9OYnMvbkc3Y0dYeTJGZnRXZHV5Ky9kMVpyWVpvalBsbHIw'
    b'dHladVVkVHpCR2l1SXBiR0tZSlRmCkd0TUpTQVlnRlFBK1JZTFdrTFBwYjVxbmhKNTZ1ZmZr'
    b'QkZJQjRjR1Y3dHVMNFQwN1pTOS9QVEZCd3VjQU1NQmdIWUVaV21NNjZldzEKTkdZK2hEQUtS'
    b'V2x4cnNhSHZraTV1NlJkeFBUdmFjMmhJdmpYSFpsUFZOVTVnM1E1eC92a2ljbzRrZlA0WFY4'
    b'ZkcwaGFGRDM3eEluSwp6MXB6Wmp6c09LR3pTYWU4ZWlrY3RZaTZqRkVBQUcrSU5tQ1NRaEQw'
    b'ZEZYTk1zM2twODA1WjBmajM5aHc2c3YyN091ekJ4OC92bUxLCnhkdVFNVnlxTm9oWWdYZHJj'
    b'OUtwN1VVeXY0VythZDMzYjR4azNrbVNaanhZaDRlVVpDUWVrSEFDZFV4R0owd0czZDNLZDFi'
    b'UzM1L1MKbStLbG9RbFBwTjZkaDRkVWVJUUx5Q0dZS3FmU3E3WWRQNmpQM3JsZWVHR3FmK3o1'
    b'dy9HcGNnc2d3WTY4WG1lQWZuWTAvcGxWTmUzNgptRjFMbXEvL2ZKcy9Ramw4Mi81MHVlVzFt'
    b'cEtHeVZoWGtBNEE2RGJLRFU2ZSt4L2p1bGVSSXAyTG53RUFkaFowclVvZUF3QUlHQUVBClFM'
    b'eklVYVNhTm52WmR4Kzg3cm1WRjlxbm9oNWIxb2pDUkhiMExJT0t0VTFGQXdBK3VaaTE5d1M1'
    b'eW50bi85cE5KQjRoTVJ0TXlRQ0EKaFZDWkVLVC9WQzhsTUljb0trckNjSXZwYnA0OG1nZzdQ'
    b'NXVTUXVRa1FtVUNrZ2xUTWtqY1RoSVI3YmFiTnlPUHZyZmY4KzVwQlFCZwpZRlk2WWhHM0dh'
    b'TDFUdjdqbGZYZDA3TG5WbGZmZFhDZHhjZktVOHpNUFMrQnp3Z0FBQXBqcDdjdTZnY0F6SlhT'
    b'dkhxbGNBNnhBbGNFClI5UUNsODNQWEpVOEptQUd6NHhvNUJ4dm5WWTE3ZUkrdCtyQ2p3Tkox'
    b'NlNPZnRTYzF6QVJPMzhZek94bEhlOVZKaUoxYStRZEdLcXkKNENNSVk1QWdiR0lzNFU3cFVF'
    b'NlV6Uk1ndlRqUEhtSXpnVHRkYXBmZ2pFRlBvWi9TanpJbVNZSllKSXhiVFRzMzBEdnh6TGVK'
    b'SnRmUApCeTBjQVViWGpHeG5RWmZXS255eXF2Yng0eXZPamNibnhzeEkyYjdOV1lOR04rZHZU'
    b'UVZsOFRvWngwZERzUjZqL0xMUDNoVkI0YkJGCnJMVUpKK3lDSkluTkdXQ1V4ZXZlcUMwNWNN'
    b'dEJGQ0UvYmNrSlJLaS9yMmc0M0plNklYUG96TERtMHVKbkpJQjZabVFuZTZNVStOQWEKcVR1'
    b'UklVV1pHMUhCaW5Ub1dJU2dWUWQyZkFlOTJZamZHZ3BHUkVBYndKbGovT2ZVYk9WU3Ftc1JG'
    b'T2p2OHI1MFZOT2hFLzVUcUk2RwpZazlWMWZiUFNwOWFXYlA3UXVtQjdvdzdpanJlM25qaWs1'
    b'YmNXL083WDY4cHdVbjQ3S2ltZjFaNkpmQUhycHdDWGl1VHgxZW5qSTVZCnhLMkc2QmszRzRG'
    b'SUxqMTBWMUg3N3VyU3o5dXlYVUhhUzllY2UrYjBzdDNYbmY1cmJhbk96cHYvb2xyZ2pCYzV2'
    b'dXRKL2E0SGlGaisKc3ZqVEJRbUhobG1aRXhHbWlHcXRBRzlDRUlDb3dWYmZLaXdVU1BlOTFE'
    b'SXErSEpRWnZlckFRRGxHdDI0VlhDcEpsUUxuSStVTnpWTQp4TDZ3NXZ6dmY2dzYycDhNQVBo'
    b'dDJVVWhNMEJETUxPWFZUOFpxeEhaWDFsNzV0UlF3cm14dUFVS2Y4WkZuZUtKeXRxZEJWMk9B'
    b'UDI5CnhrS04yTjVtaUU2WG0rZW05ZnYrWkxPWCtkSFdIejV2eTk1WjBLRzFDYjVzejU0N1dM'
    b'b3hhL0RocFUxM0hWeDNhamhCeUFqbzdOekQKaDVNdkZTa0FRQWpqLzMxYmlxeE1uSmhMVzEy'
    b'UnBQMW95OUgzR2dwZXZiQVlBQUJENU0xNVBYRkN1OUhEZVdybGhaM2ZyRythVklwWQpmcHVQ'
    b'eWFXRlJxMGlFY3YvZmxQK1p6Y2NVZkRjV3B0Zzk0WFNLMlRxcnBSS2lDRU0zZCtWUVFLNFFH'
    b'bXNUSnpBQ2ZqYjNqUXBPM0N3Cks2MzNzZmZQam1yYURER0h1dFB2SzIxVDhEenRVMUYzRlhk'
    b'WWZhd1pENXRIRDlrRGpJOHU1Z0VBaW1LbjZSUk1heFBDRVBuQTR0YXkKQkYyZFZzV2poMjdP'
    b'NjFFTG5ZTW1TYjV5Wm1kaForK3MzTzVuVE5qNVVyYS9jMW8rYWhVVnhocC9WOUV3WWVOZmt6'
    b'WXU1M2l1LzN6YgpzRVdjS3JPMFBQVHgyL1dGWlJyZG03VWwxNldOM0ZIVXlhQkU5clpsMzNs'
    b'Z3ZlMXkxKzI2NGlnRUFHQUVVcWRWSGVsTmJkWXAvUkZLCmlYcks1bVBVYU5VWHh0VnRobWdB'
    b'Z0M5TVBkaWRqc0xFczZ0cU82ZWltZFRJOXB5K0FaTmtmMmZHM0VOaWxpZE1IaDlNaXVBSUNh'
    b'QVUKbWVWd1g0bzNSQXRFS0htS21lLzdVOE1ZQWtFZ1ZXcWhVK2JNRUtoSnA1Q3dBcnNXdHlB'
    b'SXlhSmlEeXh1L2FBcDc4a1RsYjR3RlFCZwo5YkZxdENxYmo1VWtzUmNvcDZmY3ZLODdNcDg1'
    b'dGZ4Z2Qzb1F1NEtxS1Y5eHo2bllrZGNqWWdVNnBxTzBOZ0VGSmRhbEQ4OVpPdlAyClM3ZFIv'
    b'blZIWmxtODdxN2lqbTZqSENQZ0xka0RlVXBqTUVJNU1aUXdIeWlSY1h6ZGZ6YzNsSHgzajFF'
    b'MkY5VWJORXRhZERHNWl0bWIKODd0WEo0K0hjWmpQQ04xVDBqNW9FdDl4WVAxRm5aSzh4THBS'
    b'QzV4M0YzZkFFSGw2V05OaVVPUXBaaGJGbU9xMHFpdHF4cTdFOHVvUQpSRDVRMnBxck1KNGVT'
    b'UmkzQ1o2b3JIdnNoNVh6VlUwQUFNVXF3MFdkVXNyMjNWZmF1ajJuYjlRcVBEYVlHTVlSdGNB'
    b'RlFXUVlReWJzCi9Da256eG1rZTBOVUFBQ2JGdWJUZzBxQlN5MXdVbEdjSUNDOWcwOUI4TFZw'
    b'SXdsaSs3N09qUGNhQ2l3K1ZwcmNQSERKemxFVTEvUE8KcHVNdm5DbVRjYndiTTRkYTlER2Z0'
    b'UzdDaVN1dUZQWVZXaUZmeVhlL2RNM1pOYW1qZno1VC9tNTlvVXJnU3BaYXBHei8zdmFzVy9L'
    b'NwpGNnNOODJYUFVKaW9TSmpZbkRXNFREUHBEbEl2NnBUak5vRW5SSVVBQk1NRUNwRUFBSXlF'
    b'Q0FJbUFjbWxoK0tGemhLMWdVTUxWNCtwCnYrdE5yUjc3dVNUcFIxdVBmdCtYZkd3d2FVUEdz'
    b'RGRFbVhGenBsemNoOHVhZnJPMHVWbXYrTTNoMVFzUE9maHZnNFppODRxUmhtS2QKai93Tkl5'
    b'QWwzLzNDdWJMZDFhVUFBQkhMSDhFUjk5K0w1eWRMclFYSzZRU1JJMUZpaithNk9mUVFteG9C'
    b'QUhoQ1ZHK0lPdTNpamxtRgpZelpCaXo1bW5veTVZdXB6eHUzdkt4cCtWOUU0WmhIS09ON00z'
    b'ZmY3d3orbGcwalpQclAzeW4yYzJoWDl0SmhMZHdCQ0dIcCtMTzZtCjNCNEF3S2FNd1I2ajdQ'
    b'eG8zSk1yYW0vSjd6NHhtUGpJMFZWbUwydllMQjQyLzFjRlJjQUlQcmVxZW5QV3dPa1J6VjBI'
    b'MXVVcnA5ZWsKakZKZ1BGVm0rYVlyWTU2L3VURFFsVHhMdjVpSDN6MVMzdlRna3BhNWE1MkRI'
    b'OFh4K2tLMEQ1dnpic3p0elZjYXIwa2QvYm96NjgrcgpxOFZzLzRCSlFnSm9VK2FnaE8zWE9m'
    b'Z0FnRHpGVEliY3JMVUo1OXpCbS9PNm15YVZQOXo1OWFya2NXZVFzZTdURzh2aWRRK1ZOY3U1'
    b'CjNybnp4bWt5aThuRDZiNHlnaSsvRWdxbGJDK1RpcjFSVzJMek1iT2lUWG12My9QRFFQS0VY'
    b'VUNTMEl5YnN6WnRSTXdLVEx1NW1WR20KUjhxYnhLekE2UkhObXRTeE1JNE1taVVBZ0lxRXlV'
    b'WFJzelhqNmlkWDFMNisvdVNjejNCblVTY0E0TWtUbGEyR0dLMU5lS0FyNCtQbQozRjFMbXQ5'
    b'cktQenJoY1Y4WnNEZzVGM2VXckcvaHJYd1g0UFBDSDYwNWVpV0w3YnlHY0hjbUprSWppQXdJ'
    b'ZVg0cmtzYlNaRmFmdnY5CjZ2MDdEckdva1lyM2I1dHljWVNNd0toVk5CZEdEMkVJQThWYUh2'
    b'NklJS0NidnRyMHhJbzZkNUQyWlh2V29Ga01rUkFFa1hvbnp4MmsKSGQ2NWYrZitEWmNyaGVK'
    b'WHJram5FTVRRbmhtWnpjY3NVazN2TE94OHM2NTQwc0UzZWRoalZxSER6MUFKWFNlSEVrNE1K'
    b'bVZIejE0WQppOXVlMDllaVZ3QUFic252cmg2UHU3Mnc2OHhJL0luQkpMWElhZkd5anZTbERw'
    b'a2xKZy9iRTZLOXZ1R2syY01hdHduN1o2VjZKdy84Cm92QUxrOEovamRVcFk3OVowcHluTk1J'
    b'UU9lWGlXcjFNUjRDaDRMbTdqUElraWRVVG9vVXhSTXIyOVp1a2FYS3owMCtub1FRVndXSUYK'
    b'YnBJRVBUT3l2MTRvYWRZcmZ0RXpnUDZpUnc5QnBKTHZpaER3d0t6RUdhUjNURVhWaktzaENJ'
    b'eGJCVEtPNzZHbFRSS09qeVJCRUVPUAo5aWUvMjFBZ1lmbVoxTWpLcEhFYWluSG9ZUVhQWFpX'
    b'a2JUWEVFSmMxaS9CcWw4Skw4WEI1azV6ai9jT1BWWlVKRTQ4dGIvaXhQK25kCnhnS1NoRzdN'
    b'N2ExTTFIN1RsWEY2V1BQY3FtcVRoLzNlSlU5bi9xWGpWMFVoZzRLUmdBeitoMllrang2Q0lQ'
    b'S1haYkQ4bWhYcFB5RVEKK2M5L2ppdElBNzh1d0dBQkN4UXVZSUhDQlN4UXVFRGhBaFlvWE1B'
    b'Q2hRdFlvSENCd2dVc1VMaUFCUW9YOEQvRy93UGcwUTdxbUt0RAp6UUFBQUNWMFJWaDBaR0Yw'
    b'WlRwamNtVmhkR1VBTWpBeU15MHdNaTB5TmxReE9Eb3dNVG8xTlNzd01Eb3dNUFRyVElZQUFB'
    b'QWxkRVZZCmRHUmhkR1U2Ylc5a2FXWjVBREl3TWpNdE1ESXRNalpVTVRnNk1ERTZOVFVyTURB'
    b'Nk1EQ0Z0dlE2QUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMTI3NSIgLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'US_NH')

US_NH = b64_US_NH
index.append("US_NH")
index.append("United States of America New Hampshire")
catalog["US_NH"] = US_NH
catalog["United States of America New Hampshire"] = US_NH
country["United States of America New Hampshire"] = ('US_NH', '', 1)
lookup["US_NH"] = ('US_NH', '', 'United States of America New Hampshire', 1)
lookup["Concord United States of America New Hampshire"] = ('US_NH', '', 'United States of America New Hampshire', 1)
lookup["United States of America New Hampshire"] = ('US_NH', '', 'United States of America New Hampshire', 1)
details["US_NH"] = {"continent":"Americas","capital":"Concord","currency":" ","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_NH"] = ('US_NH', 'United States of America New Hampshire', 1)
regional["United States of America New Hampshire"] = ('US_NH', 'United States of America New Hampshire', 1)
#----------------------------------------------------------------------
b64_US_NJ = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTI5NyIKICAgd2lkdGg9'
    b'IjE2NyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05ld19KZXJzZXkuc3ZnLnBuZyIKICAgeG1sbnM6aW5r'
    b'c2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAg'
    b'IHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9z'
    b'b2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkv'
    b'eGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6'
    b'c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVm'
    b'czExMzAxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTEy'
    b'OTkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2'
    b'IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIy'
    b'IgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNo'
    b'ZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIi'
    b'CiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTEzMDMiPgogICAgPGlt'
    b'YWdlCiAgICAgICB3aWR0aD0iMTY3IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVz'
    b'ZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpv'
    b'cHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNl'
    b'NjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtjQUFBQmtDQVlBQUFEamFpRDJBQUFBQkdk'
    b'QlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFB'
    b'QU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFlCncwbEVR'
    b'VlI0MnUyZGVaQWtWMzJndjVkblpkMVYzZFgzTVQzM1BacERneTRrSVFraGdaQ1FoREJnTU1Z'
    b'R2pJK3d2YnVFdmZaaUczdU4KMXc1d2VHRzl2b1JzWkFWTENNU3RFV0FrQkdoMHpFZ2F6VDNU'
    b'UFQzVDk5MTFYM25uL2xFampZVHRaWDJFQTZieWkrZy8rcWpNNnBkZgovZDc3L2Q1N21TSTQv'
    b'Q0VUMEFrSitmSENrc0kyQ1BseEpaUXpKSlF6SkNTVU15U1VNeVFrbERNa2xETWtKSlF6SkNT'
    b'VU15U1VNeVFrCmxETWtsRE1rSkpRekpDU1VNeVNVTXlRa2xETWtsRE1rSkpUeko1Nng2UktQ'
    b'SDVvakNNSzIrUGRFQ1p2ZzM4N252ajdLMkZpUmsyT3IKZk9EZXJiaGVnTzM0ZEdValllT0Vr'
    b'ZlBmaDZibHNseHN2dVpubGJxTjdmai81Tjk3ZnNCZlBueUtDNU1WZEZuaThQT0wzUHl1YjNM'
    b'RApleC9sOHdmR3d3WU5JK2UvRDdXR3crODhtdVA4YklHUDNGcmw4SlRDNDR1YktaUXFlSlZs'
    b'ZHErVmVQZU9aUTRjMC9uVDk2Y0FXQ2syCkdac3VFWkVrVkJrTUlKdnltQ3RaUFBpRmNjYk9W'
    b'Zmo5Lzd5SHpuUXJnbjc2MFNxN0J4cDhmMXpsVktFRDMzUFkxT1h5NjdkS25GL3kKK09KelBy'
    b'OTJxMHgvVnhoeHc4Z0pPSzdQL3o1UVlqNXZFblVYU01VZC92dmhQVHhoM3NhQU1rTlN0Zm10'
    b'bTFkd1JROGZQM0VMeHF1OApPZkQ5S1pTYVMxU1RTY2RVZXRNUk52UVpiQjFNa091VU9IdXF3'
    b'Z05mR0h2bDd3dlZHaDk5NFFZZW05dkVrcG1rM0JRYzFlL21YVi9hCnprY2ZIMkp6enVUQkow'
    b'dWhsYUdjTFZSRllyR3U4UnNuM3NtcUxkTTBSdkI4bjk5Yy96VzZWSXR1UXpCYlVMbnFkYS9E'
    b'TGs1eDJ5NkIKN3dmODd2ODZ6Tmp4WlJJUmhZNllTa1NWQWVoTWFXd2RTRERTR1NWdk5qaHhv'
    b'Z2pBTjE4c2M4aDZQVmFsd01iSUJIOTh5M2wwTlViZgo4cGVSOE5ENjkvTDZyU292TG1hb05w'
    b'elF6SGFYODhoWW1kLzV1MG1PWExBUWtzSjBzSUc2Mm84ZnlCaWFRSkU5cnVxZFoyTzN6K21E'
    b'CkR5SDBKQy9PYVB6eXgzK0FYSFdJNmYvOHFLZ3ZhNUF3VkNZV3FqaXV6OHhTZzJyRG9YUHRU'
    b'bFk3MzRTcXFyeDNiNTQzYlhGNDZPN1QKZU1VSi90dWpNWlRkSDJDNWFJWm10dXVZMDdROUhu'
    b'bXF3TGgwS3lPNUw1UEtxVHdqQ1d3NURZN0x3QlUzYzJ6NklCZnNJVjV3aHhndQpITUZRQ3pp'
    b'bVRMRUd4YUpGRXd0Tmx2Q0FnY0VrdFliTjZuS0RnWXlCcmtqWXJvL3N5d1MrejlrTFpWTHBP'
    b'S21ldFZ4cmY1YVhxcHM1CnZ5VHh0WWwrM0pYenJCYnIyTVVabk0xdlI1Y1ZQdno0MVdRcno1'
    b'SFdQSDdyTG8wMVBVWVlPZHZtRXlrTHppNUY2UjhjWVRKeUp6dDcKUGU3VS93L1p3YTNJc29w'
    b'NzdBRjhaTHE4YVdSWllTWjJJNmVWMnhpSU4vakk3VEtmL3VqMTdOblh5NTY5UFR6d2lWdjRq'
    b'US91b1dtNgpyTzJNb1NzWG0xVEFjcU5CTm1KZ3VTNzcxa2dJV2VIRmp2K0VVeXR6NExTTXQr'
    b'RStmdWE2Z0doRUlydjdIc3hhQWFkWjVmWEpGL25OCjJ3WFozbTE4OXRsRTJLMjNBdzk4NGdp'
    b'ZnVlZTduRDFkNFBmZkdXWHN6RkY4MStKTHA0YTVhNCtNTXZWTll0bGUxa1VXV2RzaDJENG8K'
    b'YzZQOEtPL0tmWXRjNVRtdVM1NWdwV3pUbFkzd3ErL2V3WWZmdVoyVmdzbXYvTjczNk5GVmhM'
    b'aDBycnJwc1NtVHBScFl6TXpYV2RjWApJemIzS0t1akIwbkhmZWJGSnNwVFIzbGhVdWFuYitx'
    b'bWVlWWJSR0pwQnBjK3orL2VyZlA5TXpJam0vZWhDaWVVc3gzd0Q1V1EzUUNoClNqUk5sMnR6'
    b'eC9uRDI4YTRmZk04NmJqT243NTFDYk13dzVsU053Zkdockg3MzQyeDdSYzRNUzNZM3VWZ2JQ'
    b'OHdmL1prRjdXTENVc1EKd0c5LzhobEdNdis0MjQzcU1rdk5PdnYzNUxqN2xqVUVBV3lPTDVO'
    b'enpyQXpWK1VOL1ZNODlPWm5HRjl3K2RSak5meEF4NTkvbGsrKwpzNVZZMVJ5TkUwODl5TnYz'
    b'TnRwV1R2bGpIOXo3MFhZWWV6NXpkQW5qZXlYV3FEcVRBNEtkMjNOc0h0QUEyTnpmaW5xSnFF'
    b'TEttZVI1Cit4cm1GaGJRRmg3bDJ1NVRIRG92ODdZckJSbjdCTys0MGlLZGFMM3VtV09MTEUr'
    b'V2tWNGRNaTlTYmJvMHloTEx4U1kzWE52REk4OVUKcUhmZXlaYjRPTC82MWl3ek04c2NuMnp3'
    b'b3ZwV0p0aEdnTTlmdkhtVWlDYWhLaElka1NwYkJuVjJqVVRiMVUydmJSS2k3Mzl1ak5zVgps'
    b'WStudXBsYXZKbmNxU05jdXkzTjhka3lUNTVhWW5jcXltb1EwSkUxK1BrMVQvQlgvbzJNMVZP'
    b'Y216L0VwaXZmemtNSHY4Mm4zNitoCktwYzZteWVmbTJYU3lXSkZPeGdaN0dPc0tKRUlTdWh1'
    b'aFF1bEdyNC9TU29sNk0vRmVNK05FUXExZ3l5c3dLOS9JVWUyZXg4RHdkZlIKa3QyWStTayt1'
    b'dmM1N245MmxrRkpRZllEamxrV3YvMm1qVzJkcll0MnVRWGlYOTMzQkUvRUJ5amUrMHVJYi93'
    b'ZGYvUkJsVjFYZFBQZQpCMTlFYjNwc2RGUW1oY01NTHA5OTN6NCsvRmtmTjdNZGtzTlVGODho'
    b'bHlmWm1DMFJOWFJzWDVEM2NtenROcENNSEJkVzh5UzlhVXlyCmpxMTJzYkVyeWZtOHdJNE5z'
    b'c2Y3TmhzSERReFZZcTRVY09DWVJ5dzFUTDVjb3h4ZGgyeXU4SmwzTFBLRGlUejNINXprZWs4'
    b'bG9xdDgKMTJ1d2I3aURQN2wzYTd1NmFiVk41UHhpWngvNm5iK0NlT1JUL05SUWpTdjM3ZWZZ'
    b'VkJFMGlaMVNodmU5N3gzOHd6OGM1T0h6eHppMgpVT0wrbjgzUW1UclBnVVBQOGVmV0hTUzNY'
    b'TWV5YmRGWW1jQmJQc21PTFd0Um1zK3lJZk1TVVhtUzFWWG8xVFc4WUJSM3llWDlWdzFUCnFD'
    b'enl5UEYrSHJPdm9qeC9Ic2RxNE5WWFNWUlhHT21Kc3IvekNCczZMSWE2dW5qeDZRbEdGSVY3'
    b'MzNrZnVxcFMvL3dYbUs2M2Q3MnoKYlJLaTZ1NWJxWDM1cjluVHRjSUhmbTgvQUR1SE1teXAr'
    b'Mnpldko1QUNOWnVXTXM2TTJCN1g0cXVqTTZoMHlXK2N6Nk5zRXMwSzZ2awpscjdDbCs1NW52'
    b'NlVZTFA4TkIrNUswNXRxVUJoTEVLa0ZxTStxK090NnZoTFVjNGNMM0wxQm5qZ2ZUNUs0UlFE'
    b'S1l0dG1WV0dycnFICm5tdmV6Njd1Q3YvMXJoVDNYdGNGd0UrdDYyQjNORUU4SGtNM2REWU9k'
    b'UEh1d1d3b1p6dHdtL0k5ZnZ2MmdEMnY3N3MwcGhHd3NTdU8KNUptczVpdDRUcE9OSFRFRzBn'
    b'WUhEdVY1K014bWZ2bDZDOWVYeUM0OXhqdTJsL2o5TC90ODdLMVZmdUcyTkRNclplcXpHcG9z'
    b'NDdzQwp0eXJqdVFJOGllYWN4bXExaGl3Si92Q05DOXc3Y283dE9aUGM2amVwVEQ3UHNVV0RK'
    b'NCtWV1NsYUFHd1p5VklxMTlBMUZSQ1lqUWFwCnVQYmFEQ0VJOE50SXpyYnAxdi9nNTlheFZB'
    b'cTRrTStSTDgvVGtXcGQrRVJjeDdOTkpCenE1V1ZpVVJXQTdxd0JzeXEvK0dDVHhONzEKdkNW'
    b'NWlHK2VpaFByMjBPcDhuMG1BNGV1ZEF5MXc4YWY4WkVVR1NYbUk4a2dSSUNXZGtoY1hDVXlO'
    b'dTl5VHJ3SjJ6dkcyN2NYK2N1RgpEZHlzSGVUcHlsMUU1cjlOTHRNYThydU9oOTNJSTJTRndQ'
    b'T3diZStWOXovWHRIaG9LbzhFckk5SE9MMlFZR09ueVYxRE1YVDU4b3d4CmJWTktBcGl2ZHBM'
    b'TjloSmhBVU9YZWZ3SDB4dzV1c1IxTjEzSDRPQWdpVVNhNTU0OVN0U1EyYnNselkzcmkxdzFF'
    b'dkJrY1E4dnpTa0kKczhUcGlTVytNei9Na1prTVduT1dvZlVCMDRVQ1BqNWFMRUJOZURUMUp2'
    b'dXV5ckp6dUk5ODJlVDVNNnMwWXJ1STFvOHpVVGFZcUtSWQp6VmRZcDQ5eDc3VXBpbVdUaDc4'
    b'eVN0OWdQL3V1dXBwNFBFblRyUFBjTTJNTURhVXdZaHAvZlg2WlFzbEdXM0R4RHljcEIzc3By'
    b'NnhoCndYTFkwWE5aamszYnA1UlVhN2pvMFM0T1B2VUU3MzVUTjhlZVBFZmwwQlRYOVhmU056'
    b'QUVRQ2FiNXBwdWc0a25ScUhTWVBjMWEraEsKYThpcVNsUHZvdHE3QzJuaExMKzE1MFcrY2po'
    b'Zzc4WVkzZGtPaWhXVHlmd3FQVjJ3dk9LeVBwWGg2ZzNyT0R0VDUyT1BaaWhvbS9GcgpEa0Zq'
    b'TjFLOGkwZ0VIdndaR1VoUVdHbnkwSjhmSmJYc3MrT0QxNzd5Zm5mczNFdnA4OGY0MmwrZVpQ'
    b'aStFVkluVFc0NHNNTFo3VG42CnRreVFqdGFZYnI2Tm1OMEpGTVBJK1pQTVFrbkNEcEo0bFFz'
    b'MHFoYlM4eGN3Q0lpWkpvdXJTM1J0MmNiTTBSZFFqaDlEc1J5b05PbmIKUFlnUWd1OCtNNGF3'
    b'Uyt5UW4yTjAxZUQ4K0R6LzgzMFJjbW1kQ3d0RlZxc1ZUTTlDQ0FraEFnekZRRUhGOVhUR1Yz'
    b'VGV2V21jcDhkTQp0R1F2UXBMb01WL2k5bTBlc2l3NDlPZG42WG1wU2FZTzNvdVQ1STBBczJF'
    b'eStjbXZrcDF1RWx0MmlaNXRJRjBqMGJ6S0k3SGV3WWxDCnNSU253UmFNN2xGMmRybGg1UHhK'
    b'SmtBbUZvc1RqV2xjT0RsUHpuVEo2aklseTBlY0hlUG93MytQUGoxTDNYU1JoS0REZFpnY1gy'
    b'WHQKeGh3WmQ1YnIxbWZvMUpzNHpURSs4QWFORTlNTG5KcFpKcHF3Y1cySjNtNE4zOUZRTXc2'
    b'RmZJTVRLK1BVeXpKM1g5RkpPdHFOcnVuOAo1bzZEZk9yUUFHL1pYa1JUVTlUcUxzSHhLbkZK'
    b'eGllZ1dMZlI3MytHdWlIVHFOcTRRcENVWkdKNWo0VzhEVG1CSWdsd0JBZ0YxL0ZZCm03eDhj'
    b'OXEya2RNUEJLbEVERFdTb2pCN2pvanQwMlVvZEJveVJkT2pmbVlDV1pNWWlLdE1WbXhzTDBD'
    b'czFHQmpqai85UU8vRm8wUzQKODJvNE4xN2x1MzlyTXZoV0I5K1hRQXBvTkFTNkhGQ3ZDQUk4'
    b'Q0JTaThZQ25QMjl4NjUwV2YzM3ZBajJaQkJzSFZvbnFyU25KNmRONQpzbzdFV2FmSlpzMmdW'
    b'OUVvZUM3MXFzMmcwa3JZUnUwbW16UUQ0UVk0VmtCRWIwMlZGbndEUjY5elpiOFp5dmtUWHpN'
    b'VHJjeFgxYk5VCmluVzZJcGZtd3pNUm1hUXVJMS84a1VDZ1NvSkdzZjVQSG10NEtNYUdrUlRU'
    b'b3pVR3Q3bjRtazNjaU9CWWdvZ2hJZWxnTndSTDQ0TEIKYklaTlcrUEU0NjBxUUgrbi9NcHh6'
    b'RGtUR2RERnBlaVhsUlZlWGQyVWFiMHB5UlBvTVlFRTJGN0FtL2NJVW9sWkZOa1A1ZnhKUjVj'
    b'cwpITmRGVVpQSXdLTHBVaW9JWHBkdFNmT3ltQUZ3dU93eG5GUlptU3d3TzFzbWtZNVNhWG9F'
    b'S0t4V1pMd2c0TmIzWkZDVU5FK1BuMk8xCjZWQ3IrYmkraStLbytDSWdtOUs1N2U2TlNFSm1m'
    b'TWttYThvRXJrTXlCcG1FVHJsa01mWGlLbXNCSy9qbkJYTnBiWVlYR2ppbVFJMUMKSWhKbHgz'
    b'QVVLSWQxenN1QjNnNk5zWlZsaE5TeVVFMUhhWHIvK0M0SVFRRFpyaGhMRFF2TGw4bXpFVFhT'
    b'UnpKajhLa2pLamYwVk5uZApwL0xFTXlmUUpKUE5hM2F4UEMrd3JGTmtqVHhWTzBvZzcyTjl0'
    b'OHkzWHNoait6SHV2ZjBXdm5xNnpveWQ1ZWU2cXB3cmxyQWJWYXB6ClI1aHpIWTZyTnYyK1Jr'
    b'S1NYL05lbkNCZ2JuK1Vqak0rbHVxUmlncndCYnMyOUxiRk5XdXJiUnAyZlJsRno5SndmRWFp'
    b'S3F2RkpuNmcKc05od3lSa3lraEJNVld6VVdKU3FvbEdJWmxrWE1Wakt6L0xIWjlaeHVwYmg0'
    b'UXNaZXBoamtBNFc1UjVXcDZLNGFwcTAvbWFHckNlWQowbTZnWkt2bzQ2dWtWSXRlZjRuN3Z4'
    b'eWw1SGVoU29MUmxTYS9zYmxPUEowbGZmTUd2RWRPa2RxZVpPNGxDd1VIWFVqb2txQlRWaW41'
    b'Ckx2dXVIMkV1bThlMVBleTZ4THF1VHJvNjQ2R2NseHVWcVZHcTlTaTZMRmhkS0xNdXFURmF0'
    b'SWlwRXVkS05nTG9qaXJvdXFDdTZSdy8KZkk1Ty9URWVIUG9RRjVvNWpHaU1xQUNYOVZ3STFp'
    b'R0VJQjZYcVBveWM2N0VuUDUyQUZJeG42Z1V3dzU4Sm9OMUtMZ2toWUhBNTNTagpqejhabDdo'
    b'NzVTc2NlL1FrZDZ0eFJxZWFkTXNxVVVuQ0M2QVJlTXc2RmtsWklWN3hpVzgwaUVlYjFJc3BG'
    b'Szk5bnFIYlZuSU9EQ1dZCmZ2aEY0cHBFelhUcE1oVGlxa1JNbGFqWlBnbE5vbXg3cU5VbUZh'
    b'R3dOaDNoMDlHZm9kenNKdEFOVmwzbC82dlp5cTVFR1FtQ2dCMjEKZzBTeFdOWUd3SE1wcHpa'
    b'enJ0ckwzNmwzOGRiNktXcWF4ODZTUWtaUlhzN0dpQ0JJU2FBS3dlcjNWckJ2MC9GcUVXNjc0'
    b'ejRxaTRmYQo1bnExMVRhTm9hRU1xNHJLVXMwbHBpbFlYb0RyQnl6VVhXeS9OZjZzT3dHMkg1'
    b'Q3hiVkpxUUlkU0phSUl5dTYvL0hNOFdEM0tSR1FMClJRc1ViQmEwWVlxT2pDWUwrcUoxMGtL'
    b'aTRMbDBLK29ycjZuNUhsWGZ4d2VzSU1DdTJSVHpOdHUzM2tTNVVxWTdSU2puNWNxK3UzYXcK'
    b'b1M5R0lFdFlubzhRWUhzKzdrVTVIUzhncGtqRVZZblptc3RkaVZNc05TeHlhbXNXWnAxMWlv'
    b'M1djYUxXeWl2SFREcVhwZzhWdTlvSwpnTDVINExrWVpvSEZ4SGJPNlRzeGxRUjl1a3V4WWZH'
    b'THU2YXhEWWtmM3VDeDZybDRRWUF1QkhYZm85b3RJWndvd3lORHVNMGxkSzE5CkxsbmI3VnZQ'
    b'OWlZWUZBR1BOZ0pNMytXR0RvMG5LelpKTmFBN3FyQnNlc3dqNGRkdGNtczdlT011aDBkT0ZG'
    b'bHlvL1RVejNPbjloVDkKVVF0RmdybUdSc0ZQNEVoUnhxeHVyRUFoS1FTSHpUVWtyR1VXNDV2'
    b'cHJwNWxKZkdxN1JhdXcrN09BcnV5Rlo1TENxTExyNjBZQkVERgo5OGpLQ2o3Z0dBRzlXZzdI'
    b'ZFltSUFpQ0hjbDZ1MU9zTzUxM29VV0ZEUW1QTWxkaVdNM0J0bDhlWGJjeEE0aTFKbVNkY25Y'
    b'MWJ1MGhuCkRYWm1Tbng3cVp2RjJDYitqRTFJOVJwSnYwU0dNcnZsZWZLdVFvZFVZVWprY1lI'
    b'ZEhFY09xbmlCenVlTTIxNXpmdC96MkpsdVJkcmUKS3pwUUg4L2pCZ0hLeFUxeUVyRGtPWFRL'
    b'Q2hCZ201RE5kckc4Tk1YR1RybXRybFhieVpucmpOSVRWeW1XTGRZWTRtS3NnaVVQWkRWQQpD'
    b'RUhWOXJrbEt6TmV0UUhvaUZnRXI3b3pySy9GOFR5NE91UHpnNVV0bEtVa1BVcURPUnp5UkJs'
    b'd2wxaXhLampOT3FzOXd6LzBEbnc2CnROWUM0NEdlR0NWUjVMeGpza0V6V0hadDZyNlBHd1Rr'
    b'UFJkRGtuQzhnTVRhWGhSdnJ0MHVWZnZKNlhrQitZYjl5dmR6TlllODZSR1IKQlU4VmZXN3Fs'
    b'SW5JY0w1c2s5dlRxaWNXTEIwaHBKYzlwdHNyY2tlZlIyYzh3MC9uWGo1UzdOV3BFQUJQemxw'
    b'TVdUS3FYY0hSa2hkSAorUko1cDFVT3F1SFRDSHhBY040MjZaQVZGcjBtc3ltRmxDZkFEVWhI'
    b'dTFpemFaRHhrK1BRSFFubHZKeVpXNnF6dUZpbmdzUmt4U2FpClNIUkVaQndmQ2gwYnNMUXBG'
    b'dW91SFJHWmNxVVY0YzVYNHdoSmhvc0wwL09ld3Q5UHk2OUUzWDhPWHpiWVhmc09xaFRnQlNt'
    b'S3JvNlYKM01oRXRTVjl0dE1ncFdnNFFZQjZzVnZmazA3aWZmRERUTWdHcFpQUGNITjlrYWNm'
    b'ZjRaNHpBTGFTODYyeTlhSCt1SnNXWnRoT0tHUgppc2owUkJWMFdXSlNHQ2pycnFNUTdjQUxB'
    b'dEs2VExvemhoY0l4aXBKeEt1MlFyaGFBa2RQL3NpdndmcHBUc2F2b2VLcVRBYmRURWEyCmdD'
    b'UXhXa2tRQklLSnNSSWx6NlhxWDlxT2NYNDRTN3g3R0ZWVjZkMS9DM08yeWRKTFp4aS9NSVhy'
    b'QnFHY2wzM1hub3FTMVFSNUN3cW0KeDdJVE1EdDBFL0ZZa3FuSUNBTUpsY09MVGFKcGcrOHRk'
    b'Rkd3RFpwQkt4blpZejNMMWM3VERKaGpLRlpyNFVXWHZmektzUk4ySzlrUgpubzJOUW1malBK'
    b'T0p2ZVFqYS9CbEhVY296RFlUSE01M2tPeU00QVB4aTNQcVRSRXdmOFcxbUZZVFdWRUlBdkRl'
    b'L2wrSW5heXliN0FIClJSRmh0MzY1WXdlUWxnUE8xVHdVSkViNzlxTU43eU93VENMYjcrVEMw'
    b'MGZwamluVVNpYlBLams2b3dyemprSlBmWlFyOUFteVVvVmMKeEVTV0JFdW1SazJPTTJOM1ln'
    b'WUtpbEE1WVEyZzFCYVlOYmJTYlU5aXFzbFh6cjFpeS9SRUZINndsT05ucituaDNNT0xyRmdP'
    b'L1lyRwp1ZjRvUFh0dW9Gb3BFZmcrUXBLUkpJa3oxMXpMV20weFRJamFBV0c3Tkd5ZnZCV3cz'
    b'RGxDNTdVL3grTDhESG9rZ2hEd2ZHUXIxNXRIClNIZkdPRG1SUm9oV015M0dOdkczYkdvZHcy'
    b'eVNOZWZaSDFsa3hqVklpRG9ibEJXcXZzTE40aERKZUkwSVIzaEFmOXNQMVRFRlFsWTQKV1V5'
    b'VDIyYnczV3hBZGxGZ0M1K0piVmZRQjlpV2hhYnJWTW9sSW9aQmN0OGJFWWxIUXprdmQxelBa'
    b'KzVDbnYwZEdwTm1ndDVkUHcxQQpxYkJLYi84UXJ1UGdyNytKdzhjWFdCK05NMXBOa0k1ZlNv'
    b'WmVwbE0ydVdkOW5DZm0xOUNNUm9rb05xUCtXdXBvNUx3Q0svVTZsdTFRCnpBei80dytISkRO'
    b'YVRuSnVvc0xjVEkzTmtTVFBEMGJwdS9FZUFLclZNdldGS21helFTd1dKNTN0cE80YWdCM0tl'
    b'Vm4vdzdLRTBaM2kKOGZRVnlJa29FYU4xKzhKb1BJbnJlYmllaXlUSmFGZmVSMTVhb3U1b3hI'
    b'OW9hTjVSbitHR2JtaDZLdGQweTRCMThUY3lMWXRUREhhbQplTEVnZ1ErNlhjYlNMazJLQjBL'
    b'd2JPdUlkSTZkNlFSVGpzUEM5VyttSndnNGUvSW9hOVp2b2xHcmtsOWR3dmRiQzVGclRpeVVz'
    b'eTJ5CndQMTNrTW5leVBpM1BrY3FuYVhScUpGTXBhblhxdlFQcm1GK2Rob1hqWldtVGtRQjAz'
    b'L3R6RXcrTnNnak5hRDJJODdqTyt5cmZBY2gKQlVDQ3ZCM2hRbnczYmlEUWhHQ2lxRERSTkZu'
    b'ZXY1M2ViYStqa0YvQmlNWlFGUlZGVVVnazB5d3V6RktyVm5CRUJUYTMyWFZxUnprdAp2MVVF'
    b'RDRMV2pGQ3BVTUIxSEtLeFZ2MVJraVNVU0JvMXFHTjZBbFY0LzdxeVZmVW9SK1BYVW5WVnhv'
    b'TkJKbzNXSGVNVUVlQUdrTkZjCnh1NjVsNTU3UHR6cXppc2xvckU0cFZLZUFJSHJ1aVNTYWZS'
    b'SWhPMjk3WGNUMmZhVU0yaDE1VVlzUnFOZW9kbXNJVW1YbWtLV1piUkkKakV4UVFCVXV1cmhV'
    b'WDl4dlBzMjE5bE1NTmtkUnpGYlpxTWVhZitYM2NiTlZWcEk4Q3l0UXlkWEdtRWp1bzZnUDRN'
    b'dXRENFVnSUszYQpPS2JENXYxdmFHWHh5d3NZUmhUWGRSQzBwbFU3Y2wyb21rb3NrYVE3Mlg0'
    b'UDFtelBVcEt2b0FHUlJJWjZjUWxkaTJCWkp1S2lvSklrClVTa1h5WFpaYkV1WFdYSmpnRXBQ'
    b'L1N4YjlCazZSSVczNkVlSXFMRFlVS2pLY2Vic1RpeGZna0RtakxVR3FicklqTEdKYm1jV1Mz'
    b'bnQKUXdlRTU3STFYYUxoeFVCcExRYnhYQmNoQkpHSThacDUvRWdrU3RTWll1TkFKSlN6SFhC'
    b'OGxXYWpUalRkZzFQTG95VDc2ZXJwWjI1NgpnaUFJa0dXWmJHY1grU3BjblZ2aEMxTTVEQzND'
    b'WW13ekQ3NDg4SE50MHF2bjJCdGRZVTRrU1ZGbkhZdlU1QWczY29SRXNrSk1IT2QrCjZjN1hu'
    b'RHNtK3pSc2wvMERCY3BPSEJTWW01MWlZR2lFbGFWNUtwVVNpVVFLMy9Pd1RCUGJNbG1Ubld2'
    b'SHk5UitjcjRjbE9xMUtyMUQKR3hnNy9DMlM4VjR1bkR2RG1uV2JxSlJMdUY0cml0VnNuZmV2'
    b'djhEWHBnZUlTd3FUM3FYN3MrZjhNdmRzeWZEOWhTU09HaWNRRFVhOQpJVXpKSUZHYm9XSlpO'
    b'RzJiWXZmUXBZZ0o1Q1FUWDZwd1UrSVVYejJ6aWJvM1N2L0FHbGFXNXRHMENKYlZ5dnlielRx'
    b'S29xSTN6M1BOCjJncnR0STZ6YmVVVUFycjhVMHo1KzVCa0djdHNzcncweitEUVdoU2x0WVl5'
    b'dUxncXZ1bEZTR3MydjdaMWxJOGQyODJhcE1TVUZTRmIKdWNEMWZRcE5YMk4vdDNTeGxDUmYv'
    b'UEloMncvQTh5dmVxOFFNV0tPYkxGVWIvTkh1czB3c1NwUk5oWkgxNjFBVUJkLzNxZGVySk5N'
    b'WgpITnZDTWsyNmh2dlFsdzhUajhoaDVHd1g4ZzJWM3ZXdFpXM05Sb1AxMjBiUUl4R2FqVHFT'
    b'Sk9OZlhJaXhYR25OWmQ4OU5NTmN3K0QrCjhZME1SejBxMldHK1ZKTi9aQ25wNVQwWUhhcEhI'
    b'SlBsYXBOZjNYU1dHN0xUL00zWUlPczNiY00wbTlSclZSUlZ4WEVjWE50R1ZYVWkKUmd4RjFj'
    b'Z1hLMEI3UGlpckxiTjEwNC9SV0Q3SmhYTm4wVFNOV3JWTVBKRmk4c0lZa2lUaHVpN0xjMlBN'
    b'Rnk2OTVsYzJqL0hKdlM4UQpZWmxtbzhLQVVtZEFzMTZUeWIrYWlCd3dvRmtNeUhWcXRRb0pz'
    b'Y3lucnp6TXoyOFk1L2g0azhHTVRMTTRoZTk3bU0wNkFrRTBGaWNJCkFqelBCUUx5WTA4aEta'
    b'MVU2dTM1b0t5MmVackdxM25nYTh0bzhRN09UcnNzMXdJNkpKdFkxS0RpeXRpT1EwUlQ2SWpX'
    b'TVNLQy90VXgKdHZUcVNDbURhRytTM0ZDV0oxYUhlR3kybDBPck9WUXBRa1JYcWFOVGRHV3lp'
    b'a3NVaTdybGd0L2txdHdLYitsZjRKYWVlUlptaXBpTApaY2JPRjNscFZhQWxScGlxeWZTdDI4'
    b'cmNoVE1ZNlJ4eUVPRE5IaWVlN1NRcmxxZzZIajkxWTVaMTIzb1I3YlVveVdvck9WM1g1OWkz'
    b'CnovSEUwaG9PcWVzWTYzbzlQZEhXRGJ4a0VXQW9BVlZYSWlVSEZCc1dTWHVGUm53UTA3TElO'
    b'ZWZZVmp2Tnh0cHhkdlpXU1cvckpkN1gKelplbmh6Z3cyOGY1ZXBac1ZDWGZjTm1VV09XTy9q'
    b'bnVHWjdGTEJSWk9UblA2S1JnMU5qQnNjZ1dDb2tSS2txTWJqM0FEZ0tDUUdESQpQcVl2b1l1'
    b'QW1pL29VSHlXTElGUm1XTi83U1Z1a3A1ajE1dEdTS1Fpb1p5WEk0dnpGVDd5N0ZVY1N1eG5W'
    b'OEpoenBJWk1WcTN5a3FwCkFiWXZXTEFrdHNaZHp0WVVVcXJQOFlyR2pSMG1SeW9hUlV0Q2tY'
    b'MXl6VVh1S242Ykc1SW5XWHZEZWhLcEtIOC9NY0pueHRieFM1dEgKZWRlYWFTekw0OExUNHh5'
    b'ZTZ1SkExeDJjaWF4blM5eEJFYUJMQWF1T3pFakVwZVFLYXE1RVNtMXRVelpkaVVsVEpxMzZa'
    b'R1FmRDhGTApaWldjczhvRFBYL0RwcjE5b1p5WEsvL2ptekgrVnI2UHBCS3dLMm5UOENRS2pp'
    b'RHFtU2pDeHdwa0hDRmpvaEpWQXM3WEZMWWxIVTVXClZLN09XSmllUUpNRXM2WkV2RHpGUjFi'
    b'L2doMTNqSkROeFJpckpObVlyR0JhTHNlL2RJTFBSTi9EUk9jZU5zUmNMRmZnaUFBQ3dhcmQK'
    b'MnEvdUJ0RHdJQ1Y1Mkk2TENGeGtTYUZJQkMrUUdJNjZuS2lvZU1CMWxlL3l3RDFUU0pJSTVi'
    b'eWM2NXgzZkhFbmZZck50YVdEREtxcgpkQnBORkUxQlZpUk14OGNRQVUzTEkyOUdtRGNUbENN'
    b'OWpCa2JPQkhiU2pTWkpxa0VCRURERTFpRlJUNGgvd1U3YjkvMHlqbkdYNWpoCkUxTzNzTlMz'
    b'bDA0dFlNbVMwQ1JZclpoc3FKMW1SM09VVkdPT2JxMUNWNlJKUkJjNFFpS215elJzRDhuMUtK'
    b'c3EwMmFHWS9FOVBLbnQKNUJ2WEg2QTdxN2JWbUxNdDY1eS90L2xadm43UTVlNzNKRWtsTzMv'
    b'a2E1YVhhOVRtbjhKYVBNRFpVWVBITW05bXBuTTNkaUF4SXpxWQpMa0QwK1drMFE4VzFYSXFM'
    b'Vlk3NlBSU3FHcnVURHNyS0JIY1Z2c0h1N0FMUndTUkdYNHJ1M2g1azZmOTlLMFBiOWpqM3Vm'
    b'TjhQSDJVCjdteFBtSzIzQytNTER1dDcvK1dScU5HdytlSlg4emgxbFlmNjNzdDBBellhTm4z'
    b'T0VnbXZUbE5FV0ZVeW5QU3lSSFdORHkwL0JHNkYKZDkyVEpOc1IreGVmYno3dms0a0ZHTzFY'
    b'aUxmYXNnZ1AvS3ZFQkloR05ScDFqNjhxMTNEbDVGZVlYL2NoT2pNdVMyNHZOVGtnb2ZwSQp0'
    b'c1NJSnhnYyt6cFAycjFzVVExc3UvNnZPbDlmaDlTdWw0ajIvYy8vRGJ4aHE4TWJ0Um0rdGU3'
    b'OXBIVEl1eEtxQ0RoWmxTbmJncm9uCjBFWEF3WUczMGQrWjRjN09NL1QwSnNLR0M3djEveGdt'
    b'VHkweWQyeUZFKzRHeGlQcnlDc1o2ckpCTkxCSk9XWFcydE5zY1U0eXNpWEsKMm4zRHlMSUlH'
    b'eTNNMXY5aldWbXVZK1pyT0hVTHMrR2dHeXBxUkVYSlJ1bnRTN1hickU0NDV2eHhJdGNWZzY1'
    b'WTJCRGhtRE1rbERNawpKSlF6SkNTVU15U1VNeVFrbERNa2xETWtKSlF6SkNTVU15U1VNeVFr'
    b'bERNa2xETWtKSlF6SkNTVU15U1VNeVFrbERNa2xETWtKSlF6CkpKUXpiSUtRSDFmK0w3eW1k'
    b'V0NOUFVHdEFBQUFKWFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl6TFRBNUxURTFWREU0T2pV'
    b'NU9qQTAKS3pBd09qQXdxRm5SdWdBQUFDVjBSVmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3'
    b'T1MweE5WUXhPRG8xT1Rvd05Dc3dNRG93TU5rRQphUVlBQUFBQVNVVk9SSzVDWUlJPQoiCiAg'
    b'ICAgICBpZD0iaW1hZ2UxMTMwNSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_NJ')

US_NJ = b64_US_NJ
index.append("US_NJ")
index.append("United States of America New Jersey")
catalog["US_NJ"] = US_NJ
catalog["United States of America New Jersey"] = US_NJ
country["United States of America New Jersey"] = ('US_NJ', '', 1)
lookup["US_NJ"] = ('US_NJ', '', 'United States of America New Jersey', 1)
lookup["Trenton United States of America New Jersey"] = ('US_NJ', '', 'United States of America New Jersey', 1)
lookup["United States of America New Jersey"] = ('US_NJ', '', 'United States of America New Jersey', 1)
details["US_NJ"] = {"continent":"Americas","capital":"Trenton","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_NJ"] = ('US_NJ', 'United States of America New Jersey', 1)
regional["United States of America New Jersey"] = ('US_NJ', 'United States of America New Jersey', 1)
#----------------------------------------------------------------------
b64_US_NM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxODAwIiBo'
    b'ZWlnaHQ9IjEyMDAiPjxwYXRoIGQ9Ik0wIDBoMTgwMHYxMjAwSDB6IiBmaWxsPSJnb2xkIi8+'
    b'PGcgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2Utd2lkdGg9IjI3IiBzdHJva2U9IiNi'
    b'ZjBhMzAiPjxwYXRoIGQ9Ik05NTYuNSAzNTMuMzk1djQ5My4yMU05MTguODE4IDMxMy41djU3'
    b'M20tMzcuNjM2LTU3M3Y1NzNNODQzLjUgMzUzLjM5NXY0OTMuMjEiLz48cGF0aCBkPSJNNjUz'
    b'LjM5NSA1NDMuNWg0OTMuMjFNNjEzLjUgNTgxLjE4Mmg1NzNtLTU3MyAzNy42MzZoNTczTTY1'
    b'My4zOTUgNjU2LjVoNDkzLjIxIi8+PC9nPjxjaXJjbGUgY3g9IjkwMCIgY3k9IjYwMCIgcj0i'
    b'OTMuMjUiIGZpbGw9ImdvbGQiIHN0cm9rZS13aWR0aD0iMTMuNSIgc3Ryb2tlPSIjYmYwYTMw'
    b'Ii8+PC9zdmc+', 'US_NM')

US_NM = b64_US_NM
index.append("US_NM")
index.append("United States of America New Mexico")
catalog["US_NM"] = US_NM
catalog["United States of America New Mexico"] = US_NM
country["United States of America New Mexico"] = ('US_NM', '', 1)
lookup["US_NM"] = ('US_NM', '', 'United States of America New Mexico', 1)
lookup["Santa Fe United States of America New Mexico"] = ('US_NM', '', 'United States of America New Mexico', 1)
lookup["United States of America New Mexico"] = ('US_NM', '', 'United States of America New Mexico', 1)
details["US_NM"] = {"continent":"Americas","capital":"Santa Fe","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["US_NM"] = ('US_NM', 'United States of America New Mexico', 1)
regional["United States of America New Mexico"] = ('US_NM', 'United States of America New Mexico', 1)
#----------------------------------------------------------------------
b64_US_NV = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTIyMiIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05ldmFkYS5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMTEy'
    b'MjYiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxMTIyNCIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMTIyOCI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQU8KeUVsRVFWUjQy'
    b'dTJjZVhRY3habkF2NnJ1dWU4WjNjZEl0aXhMTXNpSGZJT05id3p4dWNIR2tBRHJCemtjTmx3'
    b'SkNRa1BTQUlFRXd5NwpqeVByeE92c0dyTmN4Z3NPWUdPRXdOaVNqQThKK2RReEdzazZSOUlj'
    b'bWtOejluVDN0MzlZT0Y1WmtwZTF2Q0c3OWZ0clhrOTE5WHYxCnE2KzY2cXVhSVREOUhXRDhM'
    b'VU5aRXpDRkRLYVF3UlF5aFF5bWtNRVVNcGpDLzlmd1Y2dGlsS2djMXZOaDVEUURTVE1RMWxm'
    b'K0ZoVHEKaVc5VnpvZUxzazlQeis0YmIwdVl0WGordW96UUYrSWNIdTJ4N3F3UE94WlUraFlq'
    b'Y0t6cHh3b09zbTY5OGxvS05iWFB6WHp1MVZWdgpMYlE3ZFh5NHpRdGxlVktibHo3MHRrN0JR'
    b'VkdHcEZQaGprcCtjYUgzOFlYSE4wN2NZNUlhVHZVWHhXVTlFM0NWMzRVbzNXemIrZHZKCmp4'
    b'RVFSeXBpNVh2K1plNUQ5ZDk3dHNqcXJtM243MzlUWjlIaHFTNWVSa0FBUVFTZUlnRFV1emlI'
    b'bS90VGxmcllPZjcxSTRvZnpqelQKdlBHQlRlTmZKaUNOR05QVTkxVHBFeE5WVlV6U0ZVUWhv'
    b'YzdZbEhYMjkwT1JSRWQ4NHFYdnMwWFd2UlhybjFzd0lWaGVyOWhlcFg1dwphYXdrVXpwMmpy'
    b'ZnFjUDlacFZXSHZnalZLbUZ5anJUdnROS21SMENvNitDZldCWGQrcmxHd2VFZDA5b1dwMzVT'
    b'M2pFdElwa3U3VDQvCkd2OVNWRkx2YzkvT0pJME91ZXhPaFlYdlBicitKMmF0OVBicC9JZVBQ'
    b'NVpBdy9ucmQrZHYvY09xenhJaTJmQkh3NVoxa2I0UURTZkkKcWluQ2wrMThXWjRJQUtFWThZ'
    b'UTVRc0NrbG0xNnVjMUxiWHA4Zkk4MjFTRG5tT1VEVFFxdEVsNjhQZHdkNEc5KzkyZU5rYkx6'
    b'MWVZbwptNStaOWZMU1FuZE5wM0ZOeFNzSVNpYnBTaFVDZ0JJaVM5UDJQbjdkM3ZMbXJGK2Qz'
    b'UXdBUHhqM3l0YlZCdzg1RkhNTGtwdGUwM3NHCjZKTnJvbGFkRElTK2VxTGtzKzdaUi90bkpj'
    b'QnlZVUMyY3AxelU0NnVIbjkwWFdtWEpKTjNhcFFjQisxZTdyb0p5VFNEUEM0RkY3ejEKU0VO'
    b'a0dnK0pmY3QvR0plVXZ6KzU3SUIzcFlBYVptaHNGSDQxZVkzdm5QY1B6NTY0TzAvZjlkNnR1'
    b'MS80UkpNVTRaeVg1bG5sUjFmRQp1Z0w4TTFYei8rM2NQVWxValZLSmlYTS9OT21mZjM1RC9X'
    b'Y05DZ1RZZVZqMTNUa0ppeGJIcGVMMDEzKzNQdTlkRTllLzJmRWJBTUxjCmpMM0M1YW03UHJq'
    b'dG5VOGFkWFB6WXhhZDNPTGg3bjFOTjJ1OCtOQ3kyRWVONlp1cWZ4V1dVNGJja3E0TDlFVk1s'
    b'L3FZcER1MmU5V0wKb2lnZGFGSTA5WEwvdUNHaTR1SGpCdVAwM0xBbnpGKzMrNThDWWhwek04'
    b'WUtweG9xcSs5OFdjSGg2VzYrekQ0NFFXM3M1V1FaUG5JVwpQUHpsMDhQR3plYTc4STFQZzZl'
    b'N3paZCtsYUxzL25UTkwySUpzVFJIMGlvSFY1Q2ZOaWlXbENRcm5mb2xlLzh3ZWpRenZuYUNi'
    b'ZHZTCjdWb2xIbWhVWFBBSEFNVVpVbFZINWtqK0FQQ1dtOHZXTHpRT1c2Rlh5RjYyNStsTUMx'
    b'endCd0F6OHNWbU56ZC9Rdmo3QmR1WW16RlcKV05HUzljRXAxWTNYSkMrK2VNYWx1di9ZU1A1'
    b'Z2NrNndzTEJnN2JKU0FCeTJnRHVaZCtjSGQ4b1hmV25Tb0pLRFF3NEZRWW01R2VNRQoyNk9u'
    b'TnZNWTNlTC81ZFFNejRLSlNVSUFFZTc3OVBhRXJCdnBsZzJMVEFCUWVtM0p4TFJxaDlzOGJK'
    b'bEQvZC9hZWJ4ODQ2eHVBRWhLCmNLU1ZmNk4reHV2dGR3M0lxY3pOR0VjaEFOeVU4ZUdQNTdr'
    b'V0ZpWGZPRzd3RE5DZmZUVHpjOStLVVZJNzY3NDF1TlJidjBBN1NyVVAKSC85NVRZYzZLcENE'
    b'RHVYOFF2RTcxNXdSUU1mRWpQbDBCamZtYmZ2anFnb2xENGVjaHBYN254OFFyVU9GelhBLzg5'
    b'T2JGSXJCL0xYQgpZTERaYk9jL0M0TGc4L2tTd3VBZzNOdnJ1ZWVwby9XOWFSZjFJMEZOb3pl'
    b'bDczMzkyMzlXSzdDaXlYUkwrZWFReEFKeGpCU21LOXEyCjN2RHMzNVg2Nm50VXI5VE0ydGF5'
    b'U1JvaFl6Sm5mT0ROTFRmbTU5bEhxVzEvUmRYRzM3YjBEUXdmWjJYR2cxdm03Vnd3SWRUcDV6'
    b'ZnQKWC9leDV4Wm1hQXdVZnJEc0I4ZGMyYnZhVmpWRnlnWWpob1NqYUIwK0c2ZUo3WGcwZC9Y'
    b'TkN5LzlTaENFSjdic2V1NDl4WWc3VFNnQgo0UUFnZzJ0Y25WdCszNnhqajN5K1pwOTdQWk4w'
    b'UmU5Q0FxS0NTaytkZWJ6cHF4em1USDM1SnlzZldwSDIxckRsL1RITm1zZmNUNzd3CjVwRHJp'
    b'VVRpaGp0Mi9PNDk5VWorZmx5d1pkZkNINTJmdS9aS3hkdmE3cit2NHZaRk9YWE0wSlVxWEpu'
    b'MjlwYmFOV2F1RDFBQ0FJNTAKVEVzNUd4VWxxOUtyaERBTU8vVW4xRDh3OUxwS3BRcEVSbnlX'
    b'QWlKenM1MTJjMlN1NVdOQ1l1Y3ZIdlRmcEtDaWlrYVpwTkc1ekpadgplelMvVjhncFgvbndG'
    b'RVBWUjY2YmVGV05nNHU4N1N3VkVoUDNyUGhOS21tbzlDNjQ5SzduN3l1MDUyWUJRRHdlNS9u'
    b'QmRVdFBaMU5sCi9TVWhpUEx1UmQ5Zm5GRjVYOTNOSDdjV042azljdFJ1NVh6bEt4K0lSWHd2'
    b'TlQxZzV0d1IyY3c4L2Mrak1JRkdRT3dPOFhVK0M4YzUKWk15SzVBVERjMXl0bXBPK3FPS2ty'
    b'L0RTVzdKTTRUbXpwZ0xBNFNPMWs5YTgvdmMvK2RkUUtBUUFxNWVVRFBzSW94bzdvaVNSM2Rw'
    b'UgowaVNuaGhETmVtVzNKd3JUVTFzRjFMakZmQ2JwU3FjekNtMEZGUlZ5WGgxMnpSWmpjeWwx'
    b'NWVac3Z6UEYvWExkSTBITXZiVDgvU3ZpCkx6eCsyK2FYZGovNUpoR1JBNEFKcWFIWGZqMTEx'
    b'c3lwZWN0ZTdRb2FocFEzY041WnBvTkN4aGMxL3BKNHp3WUV2ZEsrblFTdEJnNzcKZlV0a3dr'
    b'THd5Z1pTQUVBaGMrR1U3WmFVeEhLaC80eVlCQ0xYclhoWEQwS1Z4K0pQNkJHR3BrRHZYYTEv'
    b'OExuS0haL3I1SzlDdkQrcQpldlVqRHhjNW0yV1RhMXFHTGtoRVRlOENRL1dmRmpjby9lcURV'
    b'aDRWRkw4WTkyWjF2cHdlRUh6aCtjelFHQ2k4TVhYUGpoc083M1dhCk1KYlNGTTdFZVllY1gr'
    b'UWNEbXBzK2paUGNIb016VU1XQnZ1UEJsdThRdzlTeUVBUG5LWk43VkZCVmc5TitoaDNONEpK'
    b'Q0VYZjZDdjEKVHVpbFhlbmZzVmRQSVA2bko3VnNxMThKN0t6Ym1HUm5MSHhWVk5jbVc2UFlQ'
    b'dmZiT2UvdlJYMnNXRkpXalV2RVZsdzRHS0dHd0dUago4V09oWmFOWFphUzlJU24xL1BwdjhH'
    b'MnNhdEZZenNVeSttY25XM3ZhcjNlWkhCaEoxU1VENnRqTVhybUVHUnFES0FTVTBWUXBqK3N4'
    b'Cm1rTjJ2L1d3TFNoekZLakUrelVab0F0SmcxbTB1K3piUzR5TmszVEh6THg3aXFtMlBad2xv'
    b'Z0lJQnlnUkVLMmNhM1hXZndnUy9yUmsKNnl4TDlTSHZvZ3Y3R3huVUV6TDBTRVd1bnA3aUFH'
    b'K2NvcWp2Syt4UEtvV29kNEtNTE1kMnhUTlNBT0FVVFJLazNPRlRuaWcrVFdTdAo3RndvNnhP'
    b'U2hUNllkWExMN09jdmJDUlpsZTRrRWw2aC9HN1JaMUl5cXFIaGV3dGUzSlMzZVczbXY3OHc3'
    b'WkVGNlFlcnV2TnV0Zjg1CkttblZ2TEF1ZlhBN3NFaHpaTytxSjB1NEdJbHlxS0xRVzd6QkZI'
    b'akhVSi9wbkUrTXpwRjJxUmdYYy9uTkpra3NVZEtUSHhMYThQNk4Kdks2VzZ1elN5UTNjbE4y'
    b'T1FMNGptRVpBUkZBQXdQUE52MTZXK3U1eC8rdzVHYy8weERMNjVYd3FSeE5vV3BKZGgwUngw'
    b'bGM4TzZPRwpFTG15WjNLRlp6WFN3VGRpWE5Uc2IwNlB4c3pnMWNpTnkybk9nYnFBL3YyTzVU'
    b'MFRxK1RtK2V3RXpSZ05wQUNLZVA1UzNjZDY3S3N1ClZDMk1lM2toelIrd05Va3FCNWNrTVNK'
    b'akZnQUFJYTNSU1hFMFZydUtyY3BBdDFCb1UvUld1RzhVRXJHM3o2M1NLQVFaK1YyZHR6ZkgK'
    b'eW9EOHBkOE1wRFVmNkpucnp3eHlqZk92MWRiR0RaMHVxcnZlY0x6RnVTd3F6R1o2eGt5aGpn'
    b'dG1rdGFZVGt5bmlUdnRyV3R6Nm5hZAptMzVIN3I2VHFVcWFERXJoS1JlZEVpWlJ0SFlMaFFE'
    b'Z2pGNGJRNU1qT2pXTXFUNHh1ek14VVNiLzVUZ000ZHpVWHBkcGRrenlTeW9hCnJyL245NTkx'
    b'NmpyQ0dZVkNyMW1wZFVaTG1aNHhVNWhBblRNK3N6T0JSZ0VqaVhDZE85dWg5Zjh5citPVW9Q'
    b'QVI0SFNuU1VTTFgyK2YKSFduS0tXcnB4Snl1TGJvenJaNlVYaDN0YzBXTUNYRDJsNTJLWEY4'
    b'ZnVwNzlkR1lzRlFJQUVFb0FmZll6RFZUYmxMU0JxTjVmdjBaUQpkOGVUdXVSVWdTY3RYQ0NP'
    b'a2htSStuTDFKS25HUlJVdE9POExTS2pRRk9xc20vcEZhR25JM0g4a25sYkxxY01hUHVhYndR'
    b'NXhYd1dGCkFJZ1dQdEVISWkvbkJFaVVUeFNkSGNoWGdESko0MGpkV25GdUp4ODdKdzlNdTF4'
    b'UGlKSTU3NE1HUVJzbFFUV21CZnZTZ3B5WFlFRXIKcW5nTVowRmZNU1p0VE14WUxpb3Vibi9r'
    b'U2JMTVQ4OWxBcCtnYlVhRmt3Y0NrcG1Ec0JVSXdkNHlnb0ZSL2NVQVJmUVdvQzRLZlZsbwpk'
    b'MUdmZ2JnSzBlYUI5bXN3YnNGeFRoU1p2NnNXaFFCQWswbU83MEJUQkFCa2U0UzZiTktadTNq'
    b'amNmQ25FdUtuQ2hmT3FLSHR1WWpECm54MGxCZFcwNEREcFNVVk9CY1orMGpCZGJya09jcHRC'
    b'RlVGYkFBd0IycE1pZXlheHBOcFZWQ2hqT2hkS0VtTWYrT3lrT3dmdGJTUy8KaGpyeklidWQr'
    b'TklKbHhUSEllOE4wamd2NDVCZ2tvalNCOFUxYUV5UUFRMzRzZ2dmUWRTVHllWEVOUTY2cm9H'
    b'b21mZ3NjdnRpQUFXegpjaFVWY29vVE9MdFN6S05nOGxFaFR0MW1HcFBsRXJlVVJtazhSc0k4'
    b'YlRkaHJndlNuTmhYQlBDWDN5VVJleTAxT3RBYUpTZG1FQWhqCmFSTVlmVVNLa2I0ODVDU1lj'
    b'QUtMbWpISHhZV2lPSkI5RmY4QjRQOGk1T3YrRXlLaFFZSUpUbmNHaTArZ2d0Q0dpU1RDZ2Q2'
    b'SGRsZHkKdklwekpXbVlTbWtTZDJwQzByZjJ3a3lJek50SjQwa01aV0ZCTzRoSVcvSXhtSW15'
    b'Qm5KYXdkSkgyb3JCazQ1cUVSSkdqR1l3SzFjeApDZ0VBVU0zckR5V1hOcElZUXMwaWVmWnhj'
    b'WElBdENIaUhFYzVIdzJyU1ZnUHlnUm0rV2xYR3FJVlFLUzVSeUczQzRQWlJGQVJMa1RiCjgy'
    b'VTE0TFFUSkxPRGRLUVRmNDQ4NHhoUitySDFla2lhbUpLdnk5Y2VzZ2dtaUxXTkJrUTR1cDVM'
    b'M3lkSGtQTVM4ZlRkWk5vTzBwNlgKOUt3SEFPZ0Fqbk53bWVXVWZFRklWSXBOd3ZLTktHa1Fn'
    b'TFQ3WWVZZWFMcU8rT3hRK2ptazlJS2pnSnk5Rm5PZDFOQXFEeFF4SlZkOQpJQVVBam5NZ21H'
    b'VXBEUUI0MVJFeE1STkFvdFF2eSttREUxZExQUlRWb2pjSDJrcDR0UU9MYTRqUElMYXR4L1A3'
    b'dzBRZ2FoL0dNb20yCkV5UVZ4bTFBa05xK2xIMHpXVjc3ZjBuaHFFaWtwQnhTZTZCMk9VYXl2'
    b'M3FHd09mdGxBcENwSHFKbEpqQ0d2MnZ1TFQvYi9RSVd4TXgKOWtIMW1nditBQUJCbVd6L0hu'
    b'ZmFUcVpVc0MzQWI3eENTeHZXcmtWcG1BeEwwck9PbnN2bU5VZFlvMzl6RlJKSVlFY1ppdWFS'
    b'Q2dpZQoyekJwWUkzK1Y1NlJqcmJjQUJVSWwxblZTZUsxck5HLzBRTXBneWxrTUlWTUlZTXBa'
    b'RENGREthUUtXUXdoUXlta01FVU1vVU1wcERCCkZES1lRcWFRd1JReW1FSUdVOGdVTXBoQ0Js'
    b'UElZQXFaUWdaVHlHQUtHVXdoVThoZ0NobE1JWU1wWkFvWlRDR0RLV1F3aFV3aGd5bGsKTUlV'
    b'TXBwQXBaRENGREthUXdSUXloUXlta0hFMStVK1AyNFB0RzQySHFBQUFBQ1YwUlZoMFpHRjBa'
    b'VHBqY21WaGRHVUFNakF5TXkwdwpNaTB5TVZRd05Eb3lNVG8xTkNzd01Eb3dNUEM4WGdzQUFB'
    b'QWxkRVZZZEdSaGRHVTZiVzlrYVdaNUFESXdNak10TURJdE1qRlVNRFE2Ck1qRTZOVFFyTURB'
    b'Nk1EQ0I0ZWEzQUFBQUFFbEZUa1N1UW1DQwoiCiAgICAgICBpZD0iaW1hZ2UxMTIzMCIgLz4K'
    b'ICA8L2c+Cjwvc3ZnPgo=', 'US_NV')

US_NV = b64_US_NV
index.append("US_NV")
index.append("United States of America Nevada")
catalog["US_NV"] = US_NV
catalog["United States of America Nevada"] = US_NV
country["United States of America Nevada"] = ('US_NV', '', 1)
lookup["US_NV"] = ('US_NV', '', 'United States of America Nevada', 1)
lookup["Carson City United States of America Nevada"] = ('US_NV', '', 'United States of America Nevada', 1)
lookup["United States of America Nevada"] = ('US_NV', '', 'United States of America Nevada', 1)
details["US_NV"] = {"continent":"Americas","capital":"Carson City","currency":"","web":"","lang":"","tz":"-08:00","altname":""}
regional["US_NV"] = ('US_NV', 'United States of America Nevada', 1)
regional["United States of America Nevada"] = ('US_NV', 'United States of America Nevada', 1)
#----------------------------------------------------------------------
b64_US_NY = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMTM3MiIKICAgd2lkdGg9'
    b'IjIwMCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAyMDAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX05ld19Zb3JrLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MTM3NiIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzExMzc0'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzExMzc4Ij4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjIwMCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFNZ0FBQUJrQ0FJQUFBQk01T2hjQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBdAp3a2xFUVZS'
    b'NDJ1MTlaM2hkeGJYMm10M0w2VVc5V3BMVlhPWGVLUzRZWThBWVNPaWhCQkphQXR3azkwc2ps'
    b'WkIyS1FsT2MwZ2d0R0JJCndMRkRzYkdOZTYreW1xMHVIUjNwNlBTeSs1N3ZoNDdrQXZoQ2to'
    b'dEgrTHlQZmtpN3pONTc1dFZxczJZTmd2RVBRd1laL0t0QlpMb2cKZ3d5eE1zZ1FLNE1Nc1RM'
    b'SUlFT3NERExFeWlCRHJBd3l5QkRybjBXV29DeWFJTElVemd6Ly94Mm9DL0NiQTBuYVp2aCtk'
    b'ODg0azdZbApOT3BnYy8vdWhtQmpuNFkvZ21rOGc1MDg4a1UvVnVNRlRxZ3B0Sko2dktsam9E'
    b'MlZkY0VTQzEyd2tmY2E4dUI0dTE4UXJkV1RwbzJiClBNT1RQMFpTamNQSE85N2EwLzd1NGJn'
    b'NVRMTHZYZlRhMUhsM1RidjRpeHMyYnI3OXg3c1VBNDIwa09kQXM2cWRFOHM4QlRtT1hLOUQK'
    b'U2NVVDRmNmdyNjMrOElGalBlcFJlVndLckJsaVhZREFOZFNoOFRiL3lOOE90M2ZpdExrTExy'
    b'c2EwY0pEajcvK3pwSFkwUEdiNWpsZgplT2FidnQ2ZXlxdC9ubERTeHNPcjM1cTdjdVZWL3A2'
    b'T1hadmZiamk4dDdYcG1DeWxNRUJuVERpZ3pkSVJlNEdyd2d1WldFQmdmUXF6CmU0dzFka2FQ'
    b'SUhUSFE5OHVxWm84OXRyZkRoMnB5aUVhMy8ycHBtbVRyL3ptOFY0ZEFMSnR1R1BqWTEydFRk'
    b'OS82SE9hcW96Y20xUmcKYTNKR0ROd1pHK3VDOWdwTlJCMVVwalpGWFNuVk5JZVZIOGI0MlNl'
    b'K0YraHVyY2hLZDQ2c0dnQkEwL1IxYzlNMjA0L3ZucGFNUlo1OAo5TXNqck1JWUZNM1lrNXlR'
    b'WWRVUVNNaWVkU0YvUDBiVWdKbmpwUUlpS1JQRUtmdnA0TzczcjFneVQxWjFnVEh6K1VnT0Y0'
    b'dEZRdHZmCitOMjhpWG1QZmVueTBuelhrOTk1YUxEZk4zSzlvaG43RTlWK0tNbFFLcU1LVDRH'
    b'RDFIUm1wMWRRcU5PNFJUUHNwQm56cEdTaThjZysKd3pET2NidW1HMEdGZjE5Wm1PbkpqTVE2'
    b'QXpyUVhYb2hvY2VzUkp3bTB4clFOQXhmVjl0QVh3L0c1NHA0NmJxWjBza0d0YVpxYkprdgpt'
    b'TXAwWnNiR09rc24wdlhHOVAySm1rQ1MwbzB6bURSNTV2eGI3LzkvTk1QZStkQzNyL2pNSGFl'
    b'ZmtsUTlxcURHVktuRUZkcXRmS1liClIwQmx1dUIwK0tBc3BHVG5hKzNsYkpmSUFFMGlBQmhY'
    b'Tit2eWEyL1ZWWFg2L01XS0xLMzc4N01BZ0FFd3hnT2E4NEF5WFFQV1E1RTAKU1dZNk1FT3Nq'
    b'NFFNbGxaemZLZFVXU2kzNVhIaG1DRTJkQ1dXQVRoeVN6czdPOTFPTzBJSVl4eVErUVBKbWho'
    b'NEFSRUFRSk1rUldmRQpmMFlWL3U5V0Y5T09xM1pJczQ2cEUxN1kxS1VvaXRQbC91R3FkYjd1'
    b'anM2a2MwdGt3bzdVckJqS0htSVZBTkFVU1dVazFxZkRlT2RKCjVhcXFocjY0UlRhWS85TUg5'
    b'Y2V3MUg5c3cvdnZ2TEliak9qK0xWMmVrSkZsbkNuczNYYTJJTnZXMEI3TVVHclVTNnpQVnU2'
    b'cXRUYkUKbEgrSHlmelNqaE8xSmJ1SmdweEJIUDc2TlljcHBKOTFBVTBSR1luMUtTSFdGMmMz'
    b'dFVSTHpJLytCQnBVZ0g4Mk44WnFJeStaVEZSUAp5ZnJkd05mTHFuTFgyNzY4UGJ4NFVaMWh0'
    b'WjVCSTRva2FDcERyRThCc1RBT2hMVks5OEJIbmI5amJNZkdhL2FzWG5CUUlOUi8rQ0Z1CkQz'
    b'TkZWVXF4RjNhYTQwMUVESkJlakNpZlh1cGsyV1ZWc3N0emFxYVpvc2hQU3F3Wm5zQXNiNEFB'
    b'bkNIV2Z4SVFjanZZVzZlMWY3NTIKNHdSWCsxa25hK3k5dDA3WVMvREppanovQXhPTy9tTlBv'
    b'R200dURRbGtIaU0yczVnclowcGlaQU9BcHNHSWdFZ3ltVmRVcHFrYUhTYQo4ZjRKT3ZQcTRy'
    b'YlZ5N2VzdXZ5OW44elprUWszL0dmaHZTTTRwdVp6cWVhZ011VU1RaURqcnBxWXdTMHZuMzB2'
    b'Z1ZGbC9CbFhneFJTClA3RXA1aXgwVzJoL0oxVzRYWndsSXk3dExTTEtic2EyaW5NMVJDOHd0'
    b'NWVWMHMwdHFhRndBLzFKd2cyekN2cGFnOVdlb2tzbWVKOW4KUUZLQnp4RHJQME5nZ1FtQXl1'
    b'c1cvV2d0M1pzVVRqOVZabzFQelRVcTU5d3pFSTdGa25GSHpxUkw4emF0NmNqL3BJOFFYTGJY'
    b'clROUwpKRy9BR1RwT1J0eVN4RVlOMFVsQ01PMXVnQlFBVUJUNitCSnJzaXM0Yzl5ME9WOTRV'
    b'cGJsbnBPTGFyWStmVGlVSWRaL2lJa0Z4RGYyCjMxMDdhTS9PcHRwQ1p6ajVKb2F1T0RmRjZy'
    b'SGJzMk9KZUNEUWFXWE1ULzRBczk5YTdESENKa0pKUWh3NUxKcXA4Zkp4QUtDeDVqQ2kKVmk0'
    b'YnNBbUlvQ21TK3RnMjFoVWw0VWhBanpYMHFwcUdvdkZyeGlxSGQyZHNyUDhrMUxqNWJJL3Q5'
    b'Q01zb2QxV0hSanZTZTNZdHprVQpqVVRpTVY5WGZhMHIrUS8waklSWkZyUWFwWm5DK21tRVJt'
    b'Y0lUa01EUUVNMjFzZWYwZ2twRkdBa0V1emV2WHNkdEN1UGx6TEcrMzhXCjV0YVVUaXZ3V05s'
    b'VFgzRm5WYzhWWlJJQWFKckdzYXpMN2tCbWZHR3BXbWFKZnJLbUVVQXl6cHZ5QkxsK2FXSURp'
    b'OU1KZlNtQ2Y4OXkKMFNaeGZndFREZ0FoalFPRWhyekNqeW14cmlyeTNWNGJ0ZUFRUXpQTEw3'
    b'bHN4NzczUFp6RUVscUdXUDhweUxiU2R5K2RlOHVjY1U0KwpQYUljMGxaV3hBRmdTOEE5ZmZK'
    b'Y3A4M2hkcmdRU1FIQWRlV2hUL3lBL3Q0QTVRYUFMRDF3UmZ6dHNlcUpvY09kZEdFN1U5TEds'
    b'QmhBCitBUEtpRmRJVThUSG9DdStvelpJazBneWFkM1F3N0dJTEFkTEhlYTM2azQ1dHZOcXJJ'
    b'WHVVUjhTRzhWZTRjcVpsUnpEdGc1RUI1TnAKVlZYaVNxN3BLempobVhYeDFZdWROa3VhQjJP'
    b'dXBIcGV1NkhhOTBaYnBDbm0rTi9iSlVud2VDQWVxZEoyVFJDTzlxdHVOV3FrRUhJZwozd3B4'
    b'UjcvcTNSbWZDY21ZalJsUW5Ob3k3ZTN0d2FKRjFZMDF6czNJVDN4bGtmNkhIZE1HVTdhUGFw'
    b'c2wxYTZvRm9QNCtJbnpLSkp5CjJoenpKNVh2MmZaMkZuL0tDcXowdW1uTWRRY0RHV0tkSDR6'
    b'TmRkVjM5TDUwb0Q2bFlRQ0EvTHltaWRjM0FZaElXZW15LzkwM3NMd3cKQ3dESWtxbzE1SU0v'
    b'UEhwTXorcUNhUFJNRytrRHNTdUU5Y0pDWERNZGRQV2hrbnZ2bmwvZjd1Y3UzdmhNSjFGYnA3'
    b'Nzk0bFcvNVJuegp2OTY0OU9lcEg3Wm8zaDlVUDNYTmxMYUJLRFA3MjUrOWFmYnlUbC92MVFz'
    b'V2RjYzJ2N0tuN1VNYnZ6YnYwSGV2MlYzb2tLSXFNRms4CndBTUFrRjkyZVozeERUTFkvU1Bh'
    b'LzcydEYwczY2eGJZSjc5eGJjMkR6M1NGUnJIdE5Zb25vZWVNemFNcGRNUTNjS3d0QkF3SlV4'
    b'Y0EKU1FPQUJsU3B6WXl3N0k3QitMczlBMW1GdWJ0T0JIMHBhOUF6RnNzeGlNVSsySlJicE85'
    b'YlBQRmJLMmRkTjcyWWp2VWY2VStBSW0vdApxeFhDclJRQk9kTHg3ZTNGUFZyUjhYcFZOR05q'
    b'M2Y3RDlhZy81ZDdjVldXTHR3WGozTnYxSlFWT2UxRk8zdXp4NDY2WlZkdmg5eC9wCk9sdnpY'
    b'b2Nidjdsd1IwbVJwQnVNUUJ0QkxlN3lQb2dRQWdCRDNXWEVtMmNWUmxWVjNkbFRRdEg2d3ZH'
    b'bCswNzJuZXlQWlNUV2VVQjMKS1BaZjE4eDd1N2taQUtDNEhCaStxcjJsdWJRQ0EzcjNlR2g2'
    b'UGdVTUw4ZlZvMGQ2R2djMGg2R0podFpiT3cwaVFVaWNJUWtXamN0OQo2bzdMZE4xNDVmMTlq'
    b'NjF2ZEFta1JlOU5xRGdHOE9XRHk0YXZhZ0tBTjJETUc5dkdEQi9aRXdENHdvRXJoLzU0OC9C'
    b'N2xYM0IrLyswCi8vR2JMbjcyZ2VzY3d0cW4zejArOG9nRnVPdFgrYnVvbWhRQTlFU3JTbHhI'
    b'cldTc3UvczNvaUJpTFNxcktZb0hTYkxjTUtuM3FiMHEKeFpLaFJNUWhqTzZWaWFPWVdGMkJL'
    b'RWN6RTBweUtmYUVYbG9GQUx5VUlreHNFS2dsakhwOU1SUEZHVTJMV2hFQVZkbmRUV1M3Vkk0'
    b'TQoxRXlCL2R2QVJBQmdaWWx2cjV6MTVTdm5yWGo4aGQxdEE5KzludnJEQXpwTjRaU2txS28r'
    b'YkhFUk5FVWlBcW1xYmhocFM0aGhLSklrClROTlVWWDBvSVo0Z3N6bHgvTTRlOHQ3Vkc4Zm1l'
    b'WjY2ZTBXKzIvYjFWM1lOSlRuUEpBSjZxY0lRWUpnMFJXb0FRRWdHWTN6ZE5NSFEKZ0V5QnJv'
    b'S1ZqbkYwK2NMU0ZvdWx5R2F6S0xxUklkYjVRZWRBRkFBbUZlZTZxOHI3S1JZQVhORXdhZWhp'
    b'U2xGb3hoc2FERHJjcktaYQprd2xMS3VHTmg3QmIxTUxkM3l6amYrbDNudWlLTEt6SmVlcXV5'
    b'MnVLOG43MitxWjFoM3Z1WGxadU0zNUF4Q0p1SnlvdEp4Z2FPbnZOCllTSUJ6NktpUEJRSTRW'
    b'QTBQV2VNRUhoZHlHRkZIYjJtcWdIRzBONURYai8zR3o5NE9YYnpVMjlzZit6T3I2Njh0RHpI'
    b'ODlBenIzOVgKMzNZOTdZOGxTQk5UbXNFYUpnRUFQQUdnUTFLbHNHTElrdE5BbHJocTZUTnI3'
    b'MStTMkI4aUJ1SkJxMFdiV21GTFNGcFMxaEtTSGttaApjNi9weUJEclg0YTJRRHdoU1pXNVdU'
    b'OWNWdnZiWnVWd0RCR2F3c2x5aWhkc3lSaXQ2NlJocUJRdE0yeWVraWgybWU4aThrWVhQSGp0'
    b'CnBZVTVUbGszYjdob0tnRHNhbXg5OVBYZDJVNXVldjZ1TENIYTBsTmdDdU5DblVqZ2FKb2lO'
    b'R3lxbXFFYkppalFIVWNXa1RFb2JCaW0KSk9zQTRQY0J4MUljUTZySVBIcnNZRzF4ajBDOVA2'
    b'RnM5dEhXMEozUHZQSFhyOTEwelp5SmpvUHJMOW5qazBpelBaZktTZVhZMkdBZwpVVkxzUEs0'
    b'WXZLVGFXSGV3dFkza2hDeU8xblNUaUVhcHNhNUdsVFd5dUlYdkgrM1RNT0paa2laUnRvMklS'
    b'T05BaVJsaS9UdWdHSEMwCjNWZFY0bGs1c1RUZkhydi9oY01DNGRkNFdxZW9rTjNKS1FwcEdq'
    b'R0xWYVBva05YdUNDZHN5Yjdjd2dJQVdERzNicWlGbzIwOUszLzYKRjBEb2tTc0pHMTVITTB6'
    b'Y2V0dTNXcWVkOWFBWjNvWTlnWm96d2xFSVkzeUdlM21QWjRvby9OU0N0dDQ5TC91eFNONzZ3'
    b'OTFmK2VPNgpKejkvOWJ6UGYrbDlLY3FWYmN2S2xwT3F0YWMxa1FwM1FpR3dwS1JRRXN1Q2d3'
    b'WkNiOHF6UVV6MlpMSGVRbXNIay92ZCtxNXdaMmhJCldob0FBSVlNNWlpTG9JN3V5UHVHbzIz'
    b'SUFDQlJLSjVJQ0paNVd2dll2Z1lBWURRMWFyVVJwcWxSTkFBRWFKNDBwUnd0Zkx3ai9NN1cK'
    b'blpxbUE4QnIydzR0L3NGTG5FZy9jWmN0QzYvTzgyaEh1aTc1ZFdCNmhMSVpQQldoYkZVNVhi'
    b'T0tqanZzeWEvVi9TbEtXeU9VYmVSbgpjZW0rR0cwNS9janZJbFBxL1lzWkduS1kxMzk4c3pT'
    b'dDJ2dlVPL1dQdnZnV3pZa0x2dnJqd29yOGdXUVI0QlM4NHpUYjBqRlZVZ1E1CkFpSUxpZ1lB'
    b'WUdGRFRyNy9ZTi9ZaW9ybDc5VjNaQ0x2NXhOLzJsSlBFR1E4bWRqZk9jaEx2cWxHTk1Hd0FL'
    b'Q1RkSklYRWtJNlJzcGkKZ3pYazZsU3ZxdVB0Zi9oRjVRTlBYL3l0M3p5OStjQmR5enpmV0hy'
    b'WXBmNHN5eEUvMnJ2Z2RmV09MdE1LQUxlVy92MmI0LzdRRkN2KwoxcmhuWjN1UFhwUjE4S2Jp'
    b'ZHdDZzJ0N2hZU01DS2Q5WnRuYU14UWNBQzNQMk9aaDRzZWdQZ2ZDOGNrdDkzMUtPTVp6R2I3'
    b'ODRlOE5qCnQyYnQ2aDI4NGVkL090RFNsbEpKQnp0US95YWVoeElvbmpiY0tBdUUrOEV1QWtt'
    b'QWlZRkFaaW9SOHhUY3IrdjYrZ01uVDMya3FRTEIKQUJDQXpWRTBOS043SlhRNHBiWDYrb3V5'
    b'cUZkMitVdWlMUmZIV3cxdjhqTDd6aS9hWDcwVTc3ZExralBKWk9ueXpHVGJSR1pyY1NEYwo0'
    b'UmgvV2RmYVZjbVM3OS9wdkc3U1drRmFrMk52alV0TWxQanNjNkZiZHNodWdaUnZMMXYzKzlZ'
    b'ckw4M2UvN082WHp6WHR1eS9hNTd2ClRtVi9wbmpqeTUyTE55Kzg3M3NUZm9jQjNWNjJia3Qv'
    b'WFoyckdRTjZkZTQzbHVUdVh0TzFzRnV6OU9rMVZhSmRUVFFWdXR0dHNPM3kKdW9IU2tySVgv'
    b'L0pXcWJncjNHTXNQQzR6Q05kYjJiSzZjRWVRT3BySWVhK2h0Rit5T3VsRVRLYWViWm50U2FZ'
    b'cUozNTE0K0htMzJ4cApPWTFZR2hBMEFBWnNBREZxVEpkUnY2N3dMM3RPWEZ1UzJDM1dQZG4w'
    b'eHlTd3QxRHJCNnhFcmoxWlVpYmRDT3NHazdSZmR0aFpUVEFsCmRNSzdNWFR5RWpwNjFjUXNH'
    b'SHhPTnRvYTI5akNza3U2cWNXLzdLeGt1T1FUZFU4ZWlWUUlsTHh6MGVmdjNmY1ZBSGg4MGpN'
    b'QXdKTUsKQUJ4YmRwT2RUZ0RBOVVYdkFjQWwyUWVtdUp0S0xIMDViUENuRFRjWENmN21lUEZo'
    b'emZHVnJxdnZ5NStnUmQ5cWE5NjgwSHJNU0FSeQp5dTh1ZHI3WXZxWkFSQVlBYk9HSzczajN2'
    b'Nk9XVXVBc1lNUWdib09lZmxxSmFsbGpiMmo0K1pUNEV3MUhBd0JWbzMxY1JuM3RoZ29JCjNs'
    b'YUdqU003djVJODlDUHEwdS9rZmZtZG5pV1BtMTlvUDJSVTIxcFRDcDFJVWNFRTRSSGkxZ2F5'
    b'SU5CWlJzaUhhcWFXZUJ0MU5XUzEKRng3UzczNjhyellGZEZ3WEQ0VXIxOHo3K2l6UHNTT1Jp'
    b'aWZxbmpxUktBeklybHA3ZW5xWUk5TzU4eDQyQ2dEVFBRMkZ3b0NWU2ozVgovRm1Dd0MvTi92'
    b'YmZldWY1WmJjQzFMYTQxMDRYVGN1cVIyWUFJM3RJR1IvWTJiUW9LSE1JQU9DTzNIc0tiSU1M'
    b'MlEyTDhXdkxoSGZuCmtac0ZiVEJFNUtiWWJDNmxmcm4rK1JhSldvdExUdE9ETkNBRVE2azdH'
    b'WW4xYjhNNEZNa2hITCtQdkdzQU1aanJUVEdXUUVFMkJ2UksKN24yTm0rYXBORU9ZNWp4Nnc5'
    b'eHJYbFlwUEo4SUE4QWYxM2NtcnI1cmhtZDFhVllya1Z4Yk9IaDN0MmtCZ0FIWldidnU1U2Zx'
    b'bnJ4dAp6SG9BdUt0czdjZDVnZmxaaCtLYXNHRGpyNjEwdWlLSUhhY1dPLzQreHQ3VTBwUGZv'
    b'bjNweDYrMi9ZV3cyK2tCQUFnWjZPZmxQMTFlCjJ3MEFyZUdjT0JRYmlKcnBQUUZVNjA5UFRH'
    b'NFJKd05BQVVxTU5KNWxoWkljRGhBeWRFU1ExTUhXaEFGc2hsai9EdFNnNk5DTUd3WTAKYUhX'
    b'T0dPd0EwSjVmRXJOYUhiR1lFV1lBd01qVklFSURBQTNtcXJVZCtiZmR6QVllc3dqdjNaaXo3'
    b'TWUrU29UdzE2ci9wSm5VSzUyTAozdXVmK3Zpa1ovTDR3ZE1maEhWQ1YwaVNOUW5xakppNGhp'
    b'bS80bjV6d1ZlOGJHVEo1cWMyK3FkZG54MWh0YmVEWVFqQVozLzhjcHVKClFSODJ1L2RSNHZM'
    b'YXRBaDBpdGh2dVl1eWxwSVlvNEYxRlh6WFZyUThCbFFoT2xXeUJsSDg1MWRNS3NuM1lJelhi'
    b'MnZhMTlxZWtWai8KSmxRVFVaNGtVZ1FsbUhxdjREMzlWRklVbmRHSVRsRW1JZ0hBeU5PaEVR'
    b'Q0FCZ3dBejIrV0hsb3d3ZXM4VUp6YUJWQ0pNWHE4NGRZYQpXL3VkNVd2dkdMUE93Y1JQYjBx'
    b'TlU0b2ZnNkVCSXBoc21uV2NpaXJOY0I4ZloyL2JNVGhoZjdDNks1a05BRlZvcDlzYWJld2Ur'
    b'MmFqCnpjUkpBTEFRNlFtaVlOWXBVcnFZL3NuSkJ3ZkNKVHdSeXViN1g0SWJkVVpvWnJ6amNS'
    b'K3JLZ3JCQWtCLzFQamkvK3dwOGpCSnhlaVAKamlhdmNOVFhiaGlId2t3OG90cWNBQkE5TXpi'
    b'dGlvVGQwUkJobW4ydVhBQXc4NGZTYTRBR0F3Q2F1NktZS2JOWmtJME44RnFTUU9aMQpSZTh0'
    b'enR0am81T1NlYmE2VWZxUmtoSXhKbFJaVlB3SUcyZjBtMC95elBUVWY3MzJqenNYZjk1Q1NY'
    b'YktaNXJBV2l0Mkh2VU5XN0xwCjJSaWhPSEg2alJ5bEtpbWJwcnBVZzVOTUR3QzBjOWtjZ2p3'
    b'NGRabHVvcllCYlhTeGF0UkxMSnVackNHbGVDUUlUbzhlRHFnVWZmcFoKU3pKdUlzUm9XdFJ1'
    b'QlFCYmxobmxEWWRFR3NNNVdaSnVpY2F4SXNkc2hMcXdaUHZ5L0cwRTRHcDdSeTUzaGhJMFRR'
    b'SnJCc01rRElPbQo2UlFDUTFkb1dqZzEwbUhWK2xUelo0NkVLL2FIcWxYRnBBa0ZJZEJNY1NS'
    b'QkhpRUFBQlZEU2RrWkdkSUVNc0twUEgrOHJEMDBNWTZ0CmdLQ2R6NFlZRktGayt5aXZaVHE2'
    b'aVZVRFlRb0JoQWZCbTRzQjhKa0NtSmVsRkM5U3VqWlNSMDNQMGFDZFZJZVhjd21NWkJqQUM0'
    b'NHcKWmw5c1gvSmkrNUlobS8xbmRVOFBSUmJTdzArWUJFY2JzbUdhTkVub1FGQVVmMGJ0aHVu'
    b'dWh1bnVCZ0I0dVhQeGpUdStoeWdSWStCbwpCUTJ2OEVjWUFLRGJvTXJ5ejg1Wm9FbEZNWGdU'
    b'RXhFc0FvSUJ4ZzRBQldqVVZ3WWMzY1NxSm1NQUFPRkJWRG1CUnVCUW80UHNxWnI5CmdpTEhy'
    b'RGFWWWUzUnRBVFMzVHEwZ3dvRUFKVGxpclJ4eE1RZzQyeVZTcTlNdks3b3ZkOU1mNXhBWitz'
    b'ZExzOU05SkMvT1NJU2hEQzEKT0w3d3pLSWcrNFBWTDNZdXNkT0o5a1FlQUVUVW5Gd1dsSGpM'
    b'dE9vSmV4dUhpZ0JnQUFnUzlBZDNxckJ5ZzNtMmx0YmdsTEJwQVFLQwpsQVVBQ2xCeXRLKzhI'
    b'OTNFcW9Rb0FQQ0phSWdUN1FCV0pUVjQybDRRZ3BUU1NUcHFzVG44Y1FDUUpFalFKZ0RJbUFD'
    b'QUcrZHpOdW9RCnk3QUgvT2xvNURSWHcwdHp2bjBvUExiTzJZelFHUVA3L0I3clN5M0ZEVXda'
    b'QUVDRFB1WlE5MDBWblYrOE5KMG1PdFhkU0NEenl3Y2YKMmpZd0NRQ09TRk5jbWpYZmNXTEZs'
    b'TlRlUmdCSWE4UVk4U0ZMSk94c2dLRWtsK0FMbVU0QUNGRldBQ2dlL2NRYTNjWjdCWW9CQUFk'
    b'WQp3YmdmV0ZNNW8xQ1dSbEVhVGVrVUJSRmVYZVcwUCtOeGJiTkdUUlFueER1V2xvemhYK2Rv'
    b'cFN0MjhSdko2cUhyajBYTDgvKzZyaUZhCktwdk02Y2tMUDFydi9kYUplUTMwR0Zkbmo4MC9Z'
    b'QjhJaGdQTUwzWldYUDdMeXU0QUNRQ0tRZis4NmNhYlM5NStmdFozaTBUL2E2RXMKWFZoaXRl'
    b'Z2VlUFhoYTBzQkFBRUdBSWs2TzkvZXdDUUdwT284VGZrRzZHSUFpRk04QUJSbVZPRjVKaFp4'
    b'S2lnUUpWaE9QVlZZeGhzSwpLQXlya1RRQVJBaFBPR1h2d2xRV2ppUk5hdmJFL0FuV1Y3SnR6'
    b'WEcxZUplMG90ZE0rNUtYNWUxNmVzci83QXRXSHdoVlRiVWZXYlBiCnVxUGZXeDl4dFZHNVFO'
    b'TUFnQWtDQThJa0FwcUs1bVVmaHZ5clhuTitydXpFZzR1REQxZTlmTmVlcng4T2orVkpSUUoy'
    b'ZlhEWmN1V1kKMTlxazZhdXZuSGNuN0FRQU1OSFpVa2pSUmNPa0VUSTdOY3BFREFERVNRRUFD'
    b'bEV5UTZ6ekJzR1Vxa2hwMk8waWlzdzRhWndpRm1GaQpqYUpWaGtFWXQxakxIdW03bVRMMHJ4'
    b'S3ZJMVBQOWRoMHVXdlhJWU1zdnUwM29iSzBFVTNvWUpvTG5waVY1ZXptS1BEN3BxVHljblNP'
    b'CkhRbDBJd0NOWXhKZU55MHBwS1lEQUtIcFNnai8ybCs4c2RINThqMU5oNWJldW1XZzdudkg3'
    b'dHpjUDJWTnZLaVV1Wk5vL0ZwZWRsZTIKUXpReEFnRHlUTXROMHF3RU1qRVFJaDBaM3hXNzAv'
    b'KzdQK1RkcmhBVUFQaE5Oa09zODRaaWlBOFhFWUtFcW5LQVBWcmtsQUN6Mmh6eApxRTVTdkN3'
    b'bFJRdUJUUUNnTVI3QURBQXdOSkhqUmNlTmJPNzRzeHpkYm1pY1JOVzhkN1RCVXNWMFFUR2JU'
    b'SWxvVUF5SE5aYVg3UmFUCkpFbGRGd2JEbUVRQWlJc2xESnJrSXpFK0ZrT0dDUVRSSG5GTWVX'
    b'ektSUXRxY3JMWVNlaTk1dmIzUXltN2Y4Nmw0NTBNVFdFWU52UmQKK2hrU0t5Smx1NFJla2xB'
    b'ZGZIOVM0MWEzckwyMjZ4aG9LUURvQUV1R1dPY05YblJxc1kxaG1nQXdWdk50SFRsQ2tDWkNK'
    b'a0hZRTdHNApZQ0ZNRTJGdERCRnZndXdoOGVPd0lxbS95VmtaQkxBQmdBVk9BcVJOTkVVVTlJ'
    b'SmNTeUJvMGlTVFRKa0VTUnFHWWhVMGpnZUFwTXNoClJpSk1OSDVtMUFCdDNOUVkwSExZUEpN'
    b'cTVKd1FaTTEyaTBnZ01BREFSQWdBc2d6bEREMW9pTEp1NWNnVUFDUklmQXhwODFOdHZhb0oK'
    b'SE9rQ0pVT3M4d1luU2lzK0ZZT2RvVk1FTlV0cFhqMXlOaFpHZ0RGQ25DSnBGQVVBMldiSVFa'
    b'c0puUnJ5L2trQ1NKSUFFMGhOWjFKSgpoRUhsZVV3Z05wRkVKc1lFU3JrY0dzY0JBR0RzOFBW'
    b'ckxFUExDa1lFRzA4UTVvZkV3WGtHOHBuK2hHblZnUU1BaW1ZSUJZYTJmaHFTClZBSVloZ0ZE'
    b'cFVOTVRPZ0duVkFkZG00QUFGeFRsYjBpY3Z4TkxHQ0kxN1hzMjQwRjUxNVlteUhXLzZYRUd2'
    b'NjNUaGpZb2FaVW0zTnEKL0ZUaVpZRy9OeW1JR0NIQVlJL0hBTUNGa2dDZ25lWUlJNFF0Z1JD'
    b'VFNBd05JaCtPWWtBSnI5dmdHSU5LOTR3bE1LaHhmTnpyQW93dwppUkRHR3NkU3FzYkc0K1FI'
    b'Vm1pUmdPM3htQnBQcUtKZ09tVkFhWG9NcmE4SkltYWtjR2xDY2ZGMFhGSnRYckVMQUdnS0tO'
    b'cGV5SmdBCjhIdWxQSWt5TnRiNWd4dWRwaThpUWVUMkZvY2F4VVRFSFkvM2VYT3N5YmpLTUVP'
    b'dW5DTVMxQ2lLMXhRQUdBbTdBd0lLRERhUkFBQ00KUUJNRWt5Sk5rdFI0RHFOVDRzS2dhY3Rn'
    b'MEtRb2c2Rk5ralJIcXFzUlpIcWx3d2ZBZ01ra0V5SnJranBvMmltSjVhT1prdUZyNG9wYgpZ'
    b'S0t5TGpDa0RBQVlDRVd6QVVRQVFFYWZoaUs1bzVoWXI1amxTNVNPdVV3S0FIQm9FRGs5TVpL'
    b'cmJtK2xESjB3ekpqRnptZ3FaZWdLCnpaQzYwVkJlTTZtaENRQzBZUjFEREplVnhRQUdUU2Zk'
    b'VHBNa3NXRmFhSGE4dC9oa3hEK29KTUEwRlZIa296RkMxNUZwR0RSdGlBSUcKeEtRa1pCbzZ4'
    b'K2cwcTdNMElFVHFPdElOd3RBMVFWQXNBbUJRTVl0eGVwYVFBUXdBOGRNczhwUnV6YlcyS25v'
    b'NjRxOXF2S0dsWDR6Qwo1bWpYZzZPYldKM0lyaE9zWkNiRGh1a09CM0ZaMVNCbElVM0RsNTJY'
    b'NG5oQWtCUG90eWJpTXNjSFhCNlZZYnV3RXdBMElBR0FKTUEwCkFBQlNEcnRzdDJLQ0dBb0hY'
    b'RlU5SzVTSUxxaWNWTnJmN1U5RUVvbmsvbENIYkxVWURLT0lBZ3hMTXRtZUR2QWJDWWxpR014'
    b'OFFNWWcKTUlBMGh4a2lJQjBBTk11cFpCc1M2UVNoVThOWnFZckpnMG9PNjFNekk3SE91Mk9v'
    b'MkVpa1lFUkZRN0xWS1JwS3hHYnZ6aTBBQUpsbApzd2Y3T1ZVaFRDTnVzWktHR1Nmc1VST05q'
    b'TzNRWmlWQ05NYkZFNWdnZEpaSmVGd1hsVSt3Y2Z6aTJRczJIZDdySCt6dkRRWU85TGVtClhN'
    b'NFBmYnBOSjJ1TGEyNlp0L1RlTjFaOXlHbUVFVXBUa1FNREFDaW5NbUpnMmJuQUtSMEpvR2dD'
    b'R283MTA1K0tBdDJqbWxnNEd5bCsKelhSVEJHMXFneGpHbXJHa2t4bEtWcEU0UVdZNW1XRnpC'
    b'dnU3OGh5OEltZmhvSjNBNUxBZU5FMlFKVDJhUW9oRUJFMWkyU2hoTFRzTwpIWFh3NHJHVzF0'
    b'M0g2cXZIbENxYXRzdzk2ZFZqaDhBa3NJRk5XWWJoSFg0RmxyMW04Y1VKUlo1VE0xbjdPU25M'
    b'S3RaVU9NMWJURTZYCnNCVUlBZ0NBUnpvQUNDNTVPT3JtZFBCK1ZlY1ZJMTNUVmpWNEVxZXRO'
    b'd3BsSk5aNWhXaWtHRXEzVTBSNkNnNGhBQmpaSVpWVFpKbmwKSkk2M0pXSXl3MUc2WG9UQ01K'
    b'SnpoeEFBaU9LWTdwN2g1a3cxbjh1NWRPSjh1OTNXMng5TGhQcXYvL3hTQWhIZi8vWGJrZm9j'
    b'b00rTwpXTjU5ODh3cFkwczI3RGp1ZGJsbTVNeGZ2K1BzcEdHU3lETk5HQ29mS1lJaFlTZ3BT'
    b'VS9VMkxnQVJ5VUhrd1U0elhOUURaNGFkZ1dvCmpDbzh6MTRoU0R3QnAwL3Nob0h5aWJscGlT'
    b'S25KSmFUV1U2VVVnWkpHaVRGWVEwQVJuYUMrRUFvaWdoMU5MejlteDBJRVlxbUZRRmEKL2Uz'
    b'M1NXVHVicytHRDJTN0VHQk1LdmRNSEp1N2NjY3gwelJ2V0Z6ejkrMHRHTkZuUzFRQWhKQ3Bx'
    b'M2JDYkRlWW91dzBkUVE2Sm11VwpwT29raDFPV0RaT21zWlpSaGY4UjZDRmNUNnFsRDlEdFZq'
    b'Sk5MaWZvNDhPTmg3eVRBWUJWMVlSb29YV04walVBMEVtU3dNYnBwckZoCkF0Z2NjT21Wb0tw'
    b'ZzZLQnJUYWJSbEVwQUpBVGhJRWpubWdZMmdiemwwYlVMOC8xelM5QVA3OThnY09DY2ZGRUl1'
    b'WUZtQUNHZ2FDQUkKY0trNGlUSEdvS1pFQWdZUVhYaGFDekhGbmRUc05qYWRLR1pna2g3ZWRs'
    b'b0VJME9zOHdrVEVUTGlNSUNHZ1VZQTZBd2ZuWmVrbnV3OApUeVNrVXpRQTZDU2xJWExFODAr'
    b'SExCRUF5d0diM25VQ3BCUUUrc0hmQStiSFVFYUkyTmlidGJGYkI2c0RhaWREWHVFSHVqYWRy'
    b'VVVaCkdnS0lubGJhMlRRcHplQ1Npc01qZGcyem5LSzF0QVZtUWRxblFHYU5icS9RQXBxQ3NX'
    b'M0lZQ0xKRkVtTHd3a09ncFFDUU5aNHpPL08KQWdDREpCVk1qM2orUEVkaUE1OGRMcUlvUUFo'
    b'SUdzeVBOMVdIS0NBcGtGUUloaWlzRnN0cjR1S0VRZWVsQ0F5VFNJZk9MUUpCR3lvQQpwQ3lu'
    b'eUpMVTdDeVZWQTNPeW9TSEpSYkZFMmxpaWNqSUVPczhJMkNTTm1iWVMwOUVWS3R6WnF4cGU4'
    b'NE1BTEJJU1FDd3BoSkQwUWVNClVKSmdob2lGTWNZWVNBSWhMY1dGbWxWYmtVbnhBQ0FHRG5C'
    b'd0V1eFJLK3NYK0Znb2tqY1FMREh4R2JtUUNKbEZ1WTBXTVpTU2JNRkkKdnFJSlZpRm9VdzhL'
    b'a1RnZ3pDczk3dEFtZytCN3NtL0IyR3RpSkNrbXJXc0FnSmxUWkVrb0RwYVdjbTJ0UEIwZmtW'
    b'Z01xUXdOaHdWLwpHbXErajI1aWRXT1JIZEdBb1FCeWUyY0VtdFAyVmpUTXFiSWdwV1FtN2RK'
    b'SGtBQUFBaGhKU1pNMWl0QnhscjdqY3Q3UzFMWXFwWHNKCnBBbFVFR2lBNGFDVng5bmpjdmcw'
    b'alkwbHZQM0JrcUdETG51ZlZRd0NnTWhIUmY1RE5pVWdRU1pOK1JKemM2VmtWeFNaNTZ5Q2xB'
    b'QUEKVWpzbEhoVkRKRWlESms3SlJjM2dnTldIaGtQOFZLakNVVjRmQzQzcEc5bTNOeElFcDJk'
    b'S3JHMG83R2dTUkhsbnE5K2I0dzJuQzZZSApHQnNBWklHeTUzZ3ZJYzZhV0VWVnVkZGNWbmpn'
    b'dHJtWGw3aFpnUW9PU1E1WnNlZ0dhNXBrU3JhSElubit3VEdCOENuN1NUZm9jNytTClhjait6'
    b'TXdycnlodExSRitkL0YwUU1MczVNbVRBR0JhVHlVaDBvUWlxWGFXU3VjZlk0eGszWUtIcy9X'
    b'dEtHTzhuMitFa0hDdk92a3YKL0I0RUFPRWdMaXJMeFVta1NaZ1d3alpIUmNmSmc3V1RaWVpq'
    b'RlVWaDJUWkhuaG1DT2lwcVJpTy9lci95MWhrM0ZnaHZqeStxNytwcgp1bjNxUmNmREsvNjRz'
    b'U3NRRWs4WEZqd1hkMWdIdk01dWlsWUFJd0taRlBXUjIyclNCTHRnM09LSm51T3M5a1J4cnRZ'
    b'ZnR1OXNYZkxxCndiR1B5bjg0VHJDemwvaE9OVXZISS9Gc0orOERBTjFrSk0xcVlrTGgwLzho'
    b'OXRHZmpBV2ZnbW96VGNodE1lS3pxWWlpYVhqU3pMN0cKNWwrVTNaQTlPT0FORDRwU01tK2dM'
    b'eW1JQSs0c2pGREFrMS9idG5NaUVhTU1xWU9QT0ZpdFIxc3VLN1ljUjZlRmJuYVRSeGZXVmZE'
    b'Mgo2b2EyQ0FZZ0NjMWw5NU9FZ1FGcEJxdXF2S2F6dXNrb3FxaHBuRzR3REgzRzhJOHJ2ZWky'
    b'V1VVNTV2Tlo0bEdualdqMnoycFJ2dkRZCmErcmx2ZHZ1WmJvMkZwS1RwcHdxMms0UWVtKzBN'
    b'czkyZ2lJMGhFeGZyQ0lxWjdsdFBlUkJYVUJJdy9oWFprMkdXT2NmMjNIT2ZOUmIKZ1JNRHRk'
    b'TWYzUy9OekVvUVZtRjdWaVdKaU83Y3doTWxGVU5wTUNaQjFpUHJQZUdkM05pZzB4NXRPTUo2'
    b'M1NmL2VHaUtPMmN4VnFXYQo0dlpFOEVpUjJMUndScTFPSTVyWmFiTUVMV0pZMDFsVjQxU05W'
    b'MVJSa20ycXhwc215Yk1wbWtvVHF5Uzc5b2FaVXd2TnRYWml3NFFLCnRTTXdybFc1NTJmcnZX'
    b'L3U2QU5WZVo3WktXRTRNZE1WayswRmp1RUFCS0ZiMkxESVJJY2lIc0ZrWVZ4eEY5cGJ6ZjJH'
    b'RFJFdXBMK2sKNVllUmtDSFdlWWFPeUhlTVhNbkV2VFV6WGVXVlg3eDhnYlYxVGVmaGhxT2tP'
    b'eXdJa0lyQ1FPZWlnWFZQVlEvTXRQczJoaEp6VnJZNwpRNmtyWWdHK1RPOUxhbi9lSVRXRzYw'
    b'UytGdW5CeVdPN2xmRHUyaHg1VE1HeTdtQkMwV004bDdDS0lidDEwR0VkY05qNjdkYUFSWWdN'
    b'CnNjb3BlcSthdW5DNnQ5NXVySmxTSFFzbWkzZDFYUDNTd1ptcjMvSkhZaW03RWYwZHNXa2NF'
    b'ZDlNT1VzdnVvMHdDaHY4WnFtN2QraWQKaHd5c1FJeGFkN0E4WXBUeFNwdGprNzgweFFBQWlX'
    b'QWFCRjR4U3pRMGlnMFZCT01mSGoyT2hsNld6ZFRWRkpibU96bUdjam1zQk9nMgpxMVhUVkk0'
    b'aExSYUxuRXpnM2dNY1laRDVFemk3eSsxeWpkeHJGWVcremI4dkxGbW9ZNzUrenowekMwNE1I'
    b'bFU3dVZsa2psc3R2cm01CnozeHUzWkg4SE0reW11WWNabjIrSjlRM1NLWFFncWJZekhjUHZh'
    b'VVlaNi95SXhFOXQyWkpYZFpKaS9sV3JrZU9TbzZ1NkVVSEJtYksKc3Jwa3p2ajhiSnZYWmN2'
    b'eU9BbUNvR242eExwVkZGMmlLMG1kbFVKaUVRSU5qQ1F5SkZtSzA1U0Q2dHpyeXBzaDZTanB5'
    b'Z2VTbGxJUwpRMUlBMEJ0SjZpUS9HSW9xR280bHBQYmUwTjRHZnloRlpJajFMd1pMNmV1ZXVH'
    b'bmhndW4vVENNdCs3WjBOQjM5NmZjZmZlVzdpYUFQCm9RWTZWbGhvVExwaTZwVS9hZTNvcVYz'
    b'eEU0cm1QM2RaeVhqSDVsTDNGbE9YSXltN3hsKzVveXRuVitQNmtSeVhDV1h6bDFZUkVIM1YK'
    b'SVFSRmdUNFptTkZqcm5qeXRiWVNMM2w0N1E4Uk9qdEpUMHJFMmplOXdCVk9Hak41OWdkZnlk'
    b'RDEvcE9IRUVLZTB2RTBjNjZNNUVOSApHK3B1L0JVUVRNWXIvRmRDMFloQU9QRlBOakoyMmtW'
    b'anAxMzA0cXZ2ZEtjNkMzS2FlNC9nL096UERhQVRxcW9xc2dSQVNxcjVxN1Z0CmVlN3F1NWRN'
    b'SzJEZm1scDJzS1hqK2VtMm9va1hYL1Z1VThRMDVjdkhGeHVEcjdHSmpxcHk4bWpuK01iQWxh'
    b'dmVsanY4TFFEZ0cxUWoKa1lqVGVYYnlGbSt4MVZ4NTcwZmFJaFNWVnpYdDQ3ejh1enVPanha'
    b'V2pTb2JDNkYrZi84ZDExMzBEOXphMzkvZjB0SVNpOFVDZ1FCQwphTkswYVNjUHZaM3R3bkh2'
    b'T0tORWNKUmRUZkE1cTE5NFkvT3h0T01XbDdRdHg1TDkybVNLS0JQcDRNU3lIaVc4MTQ2ZzFC'
    b'TEtZLzg2Cm9TSTJFQ3M4NUx2MmhRTXpubjEzSUpKSUJ5QlNHbklpWDkzRVdwbytPOWJWMTlm'
    b'WDA5TVREQWFibXBxY1RpZkxmdUsxRXJLczNQT2QKbDRLSlVaTlJNNXJNdyswTjRkZlh2Nzl5'
    b'MllKUGVxUFA1eU5Kc3JLeUVnQUNnUURKY3Q1WlA0am5GRHBaTmg2UHg0R0JSS0l2ZG5aWAo3'
    b'RG5ldjdlQnVtTDIzVXR3bzFWZmY5WGNldE9FZmZYaTNvNUw5dnJuUFA5MnU0SDlaeE1vemc0'
    b'TURFaVNwR21heFdKUkZBVWhoREhPCnpjM056YzAxRENPVlNuVjJkbzRiTis2VGZzSXp6NjFy'
    b'NlJ0TlV6Mmp5WGdIZ0drVndxNVh2ek13TUJDUHgwM1QxRFR0K2JYN0NJbzkKcDB4Vy91dnpW'
    b'M01jMTk3ZVRwSmtYbDZlelhiMkRxaW1hZFlzL1gvTmZmcUh0aUJ5NU4xWEZDK3Azb1VRMnRF'
    b'eC84blhUc1pTSDM3bApwQkwrME5vZmZQQjRXMXViTE1zSW9hcXFxdTd1N2wvK2FTTTY1enN6'
    b'aEhiakZUTUlnakJOMDI2M0M2Smw4b29mZEF5T3BvajhLSE5vCjk1MUlQZnI0cWtmdXZUazNO'
    b'NTNRMS9tYkRXdTI5cDdqbHR1WGxybGNMZ0NvcmEwZGtsNCtudzlqakJCeXU5MWVyeGNBdHV3'
    b'NDBPeFQKMDJud0gwQlNOcDU0cmUydnVlVUEwTkhYZEk1bkhlMU03anRZUDYxdUhBQU1EQXdF'
    b'ZzBFQVFBaVZsSlJ3WERvNXA2aW95QjlLL0duRAo4WE8wODlVYkoxUlhwMnZnaEVLaGIvem90'
    b'Nk9MVlRBYXAzUmVmSzl6NWZJK2dpQUNnWUN1Ni9lc25Qcit3YzZCeEVkK3lJcExKNXorClox'
    b'NWVYbDVlM3REdlEwWVB4cmlodVhWaXFkRFVGVlUrdWhwSFIxLzhmM3MxN09TTUxUc1BXSGlT'
    b'SUFpUHh6TkNqclB3OEIxTFg5bncKdEFZZmJvbVB6U0d2V3pTdW9hR0JaZG5pNHVMR0U5MnZi'
    b'TzRlZFNNMStvalZNWWhuMzc2YVFjYlBIMTU4MTQzTHZGblpNOGZ0V3J0Nwo0RU12em5mZ3Ba'
    b'Zk1QSWZ0OWR4eno4MmZQLys2NVJmZmY5ZG5Cd0tEMi9ZZU85YlNkK3lrdjZGMW9NTVhsVEgz'
    b'VVdJTUFKQ3A1ampJCnFoSnZUVmwyVFZuT3VQTGNXZE1tZEhSMC9PUW5QNUVrNmNvcnI3eisr'
    b'dXMvWEdQV1ZpeVpVYlJ1ai85RHoyYTVyVmFidTdLaTVQdFAKdmZ3L0x6eVJVQWdkNkZFM1RL'
    b'TXl0aXRyU0FicVc3L2E4dGpxemYxaEpXVjhwQk0rb1NLSG9qN3lHNDhkTzliVjFjWHpmRk5U'
    b'MDRZTgpHNkxSYUZsWjJWZnZ1Vm9RaEZBb0pBakNrZU10L1lNeFRUY2lzU1JOMDZhSlNaTFUx'
    b'SlRMNmJSYm1MTGlQRldSdytId3RHblRWcTFhCkZRNFk5OXp6ek9yVnF3OGNPTEJvMGFLS2lv'
    b'cHpmTUpsYzZvK2lsamJqMGZHWC90RWxnM0pCaFZSUnV0YSsxR2NOdU9QbXUyRCtCeXMKQW9D'
    b'UnpYWS9GSnMyYmJycnJydEtTMHZuejUrL2RPblM1NTU3TGpzN20rTzQ2NjY3N3VUSmswOCsr'
    b'ZVNrY1pYUC9mWUpwQVNsWU52aQp1ZVAzYjExNzA0cUw3N2hoK1lsanV3dzVWbi9zYUdkbjUr'
    b'OS8vL3UrdnI0MWE5WmNkZFZWUHA5djc5NjljK2JNS1NzcmUvREJCd2NICkJ6L3EwWGxadG5P'
    b'OG1JYXAzaWdaVEl6aXRLeFJYK2Y5M05oOTNIK3M4ZVNIRDU2bWlhSVlpOFZlZXVrbGhGQnpj'
    b'N01nQ0E2SG82R2gKSVJhTFRaOCsvWUVISG1CWnRxR2hvYkd4OFlZYmJzakt5dHErZlR0QkVB'
    b'RHcxbHR2clZxMVNoQ0VpUk1uTmpZMk9wMU9uODgzSlBDSwppNHVYTDEvdWRydC8vZXRmZnpD'
    b'Z05ZUkVNdm1YRFljLzNUMy9LU2RXVENGWGZPblozNzY0L29NYktrY2lrWXFLaXNyS3lnY2Zm'
    b'REFZCkRIWjFkYTFjdWZLdmYvMXJjWEd4S0lwRGJoMEFFQVR4NElNUER2MWltaVlBZEhSMC9P'
    b'SVh2M2o0NFllZmVlWVpqOGZUM2QydHF1cTcKNzc2N2FkT21lKzY1UjlNMGpMSGRibi9qalRm'
    b'Mjd0MTcxa05UcWRTdm5sODc3ZG9mdlBCZTE2ZTc1ejhOMlEzblJqaGhyTnZSOXNaYgpXNVB4'
    b'eUxqS0lwWk5xODV0MjdidDJMSGptbXV1Y1RnYzk5NTdyOWZyTlF6anZ2dnU2K2pvbURObnpz'
    b'NmRPMFZSSkVteXU3dWJZWmd0Clc3YU1HemR1NjlhdHVxNHJpdUx6K1RpT3UvcnFxM3Q2ZXE2'
    b'Ly92clcxbFpKa3V4Mis2cFZxNVl1WGFycitvc3Z2amhuenB5Ly9lMXYKbDE5KytkRHNZVytm'
    b'LzVmUHJiLy9oNjg5OTNicllOeUFUenNvdUNDQWpuUXFSNTdaK2NObnR5NmVNV2JaL09xVnkr'
    b'YjdmTDVGaXhZRgpBZ0ZGVVd3MlcyMXQ3WXN2dmtqVDlNYU5HeSs5OU5LYW1wcW5uMzVhRUlU'
    b'UGZPWXpPM2Z1Ykd0cisvNzN2NzkwNmRMOC9IeVdaWGZ0CjJuWFpaWmRWVkZSODRRdGZlT1NS'
    b'UjNpZVg3MTZkWGw1dWNWaTRYbWU1L2xiYjczVjVYTFYxZFVsVThxZjEyNWV2NjFoNDc2dWhF'
    b'ckQKQlFNS0xpU0VKZXJQVzdyK3ZLWHJ2c2ZlbUQ2dVlNNWtqdUQ5bGFYNGxsdHVHVDkrL0p0'
    b'dnZ2bldXMitwcWlxS29pUkppcUlrRW9raAp3OHN3REVWUktJcENDTGxjcnZMeThqZmZmSFA2'
    b'OU9rSUlZSWdWRlY5NUpGSGpodzVzbUxGaXVQSGowK2NWTGRoNjRGMTIvZHRPOWkyCnI3NVhn'
    b'cUdxelBRRjFkV2piRXJuWHcrTVdaU29LSExYbEdhWEYza0tjcHh1RzJzVHlBVnpaKzdaczJj'
    b'b1hFNFFSRU5EUTNaMmRsMWQKM2I1OSsyYk1tTkhVMUZSUVVGQmFXaG9NQmsrMGRmY054bnI4'
    b'NGI3QlJHdjM0UEdUL3BiT2dFYUlnS2dMdVY4dmVHSjlLUFFVUzJvZQpoNVZuS1pZaExTSlBn'
    b'T2wwMkFBZ0VvMWhSRVZqY2Qwa1U2bFVNQ3BKR2dKS0JJUXkzWGJocXNLUDNTdUNBdEFiQlFB'
    b'VHdBUVlTaXM0Ckt4dk1BS0FBckJlWWlzdUVHekxJRUN1RERMRXl5Q0JEckF6T0gvNC81bVVa'
    b'aWNVcnZnNEFBQUFsZEVWWWRHUmhkR1U2WTNKbFlYUmwKQURJd01qTXRNRGd0TWpGVU1qSTZN'
    b'alk2TlRZck1EQTZNREM1WVZSZkFBQUFKWFJGV0hSa1lYUmxPbTF2WkdsbWVRQXlNREl6TFRB'
    b'NApMVEl4VkRJeU9qSTJPalUyS3pBd09qQXd5RHpzNHdBQUFBQkpSVTVFcmtKZ2dnPT0KIgog'
    b'ICAgICAgaWQ9ImltYWdlMTEzODAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_NY')

US_NY = b64_US_NY
index.append("US_NY")
index.append("United States of America New York")
catalog["US_NY"] = US_NY
catalog["United States of America New York"] = US_NY
country["United States of America New York"] = ('US_NY', '', 1)
lookup["US_NY"] = ('US_NY', '', 'United States of America New York', 1)
lookup["Albany United States of America New York"] = ('US_NY', '', 'United States of America New York', 1)
lookup["United States of America New York"] = ('US_NY', '', 'United States of America New York', 1)
details["US_NY"] = {"continent":"Americas","capital":"Albany","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_NY"] = ('US_NY', 'United States of America New York', 1)
regional["United States of America New York"] = ('US_NY', 'United States of America New York', 1)
#----------------------------------------------------------------------
b64_US_OH = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjAwMiIKICAgd2lkdGg9'
    b'IjE2MyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjMgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09oaW8uc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2NhcGU9'
    b'Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHhtbG5z'
    b'OnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9k'
    b'aS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsi'
    b'CiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3ZnPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczEyMDA2'
    b'IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTIwMDQiCiAg'
    b'ICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAg'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAg'
    b'IGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJi'
    b'b2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAg'
    b'aW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTIwMDgiPgogICAgPGltYWdlCiAg'
    b'ICAgICB3aWR0aD0iMTYzIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6'
    b'ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZC'
    b'T1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtNQUFBQmtDQVlBQUFEcWdZQ01BQUFBQkdkQlRVRUFB'
    b'TEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FB'
    b'QTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFaCjZrbEVRVlI0MnUy'
    b'ZGVWZ1QxL3JIdjVQTVpGOEltNkNBdUNBQ2l1Q3RWbEdMTzlaOXR5cDZXNWRTVzZ1L3RtcXhv'
    b'a2F2MXJxMWVxdTEKYXUzdDZsWnIxVXB0WFdwZHdicFExK0tDVWxrU3dyNW56KzhQSkNJa0lZ'
    b'UUVnc3ozZVh3ZXcwek9uSm41NUx6dk9lOTd6aUU2KzR3MwpUT2NUdW9GK2trS21rRi9BRlBB'
    b'VVRCSHZBWVBQdTBteHFic0dOanV4N1pMWldhQkZ5OEVpNERQRkFBQ2Q5U3BNMFJRalFsOWU0'
    b'eVJTCkxEQlFybUkxSlJHVmtoSnhGbFBNVDJWeTJXa0VsNU5DOGRtWHl2VHVDU0hTaVdyNmNk'
    b'S3lDNHlWc2dTbDJVSW9FcFNMU0UrNmlwVXMKRDVjOHBvQ1h5K0J4TXBrQ1hqSWw0RjVqVU9U'
    b'dDF2cXM2NFJVcXFjZk9TMnJZYXdQbEpiRVlMTkF1VXMwN0JhdXhjKzRBMXgyS3NsaAozMlZ3'
    b'V0tmOGw4VEk2RmRDdzJoV25mUnFUTlVVMlExS1M2ck5IWUNlZTZtTjlEVWwvZHFhS1l5TkFX'
    b'VnR3TEs4UE1xcnV3TU1OdXNCCnlXUGQ5dGNyenRIdXdITU9ZNlZDOUdwRU93R1VadDBCRmdY'
    b'S3cxVkRTb1RsbEl1d2lCUUwwNnU2QXhTYlBPMGJOeWVEZnZYUEFZeE4KQlVwci9WZFNJczVp'
    b'Q3JnS0JvK2R4dUR6YmxKODlpVzJubm01cFRTbWpNYWppY0Q0UEVCcGpUdEFpZ1hGcEpDZnh4'
    b'VHpVNnU1QXhjSQpxVlJMSStSRU1GWXFXSy9DTkR2MnZwMyt3YkVvc0txNUF3d2VWOGJnc2xJ'
    b'cEFmY2EyTnh6YmVObS9VTWoxZ2d3Vm9leXA3NGNSRE4vCnVCYmRBVFoxVnljVUpiUmZPRjFC'
    b'WStnZ0dDdlYzcURHTkUweEluVmx6UjdLT3JzRHpUUzZWUzhZMzN0OUtINDhkaG1wYWRubW9k'
    b'U3IKTVUxTFExa2ZkNEFTQzQzUnJlcnVBSU1pYi9zdm01UFU3R0djTnlNS0M5OFlqdEJCc1pn'
    b'NHZBYzZCL2xpYnR4WE5KU042QTQwNVdTWAplc0U0ODVXKzJMbHVGblE2UGJRNlBVSUh4ZUwr'
    b'STdsbDgwMUQyV2p1Z0xNbnU5Z0U0K1JSRVZneWJ4U0NPL2dZZ2JwNDlUNTZqWlphClhVWTd2'
    b'UWJUdFVVMGxNN1NLamxCc290Tk1ES1pESFFKOXNQa1VSRllFRE1NQm9NQmFvME9TOWJ1eDhZ'
    b'ZDhYVXFLOFRQQS9NaUFqQlEKd0lRbUt4ZnFyRnlVcDJaQ2xTNkhRVWRIOVpxRU8yQ25aSmQ2'
    b'bVdrUE54RlNFelpqeU5TUFVGeW14SVJoTDJMampuamtGWlRXdWF6UQpJRC9FelJ1TjhjTzZn'
    b'eUFJR0RSYWFISUxqSENxNVJXZ0t2L0pmUEk1QjJwRkhtQXcwSlE0c3p0UUxicGxLZG1sVmhp'
    b'NUhCYktsYVpkCkNaSmtZdS9XdVJnZnM5bHVOOU81b3krV3poOWpoTktTZEdWS3FOTGtVR1Vv'
    b'S3Y1bEtxQk1rME9WbVYzeE9UMExlaFdkOCt0VTdnREoKQk9VaDBWRnVMcVdVUkp4UENubHlC'
    b'cCtieGhRTExqOERvMWpJUTB4MGYyellIZys5M29CTjBtazRlT3d5emw1S05sdTRSTXhIZm1H'
    b'cAozU3RkRnlndFNWdFFETFU4QjZvbnJhb3lWVmJScWxhNkF4bFpNR2gxTkNXTktNckRWZWM1'
    b'YnRETUdpM2p1WVBMNE92dGhyc1BaZWoxClFnZTRoTXlHdGhGZmxyMmdyQTNZcCtiL3FUdWdr'
    b'dWRBTGMrRjhyR01kZ2NjSkY1QTYzTDNvWDM2dFZrV2M2a0dqUDBpZ3ZIN3ZpVUEKZ0lLaU1u'
    b'U01YSUNzbkVLN1ZxQ05yd2NlV1Jnb042Vk9nVDVZK01ad1JJL3REUWFqWWZ2ZmVyVUdhbGsy'
    b'VkxJY0k2aktWRmtGckZtNQpVRDVLaDdhb2xDYXJqbkxwSFo3dTBTY2t2T1dDbUp3YVBtUExG'
    b'aEpjT0NTRnY0Kzc4UXRGeGVYNCtzQlpMRmkxRzJxMWZaSlVEbi81Ckh1YkdmWVcwek53NmY3'
    b'Y3hvYlFJckZKbE5QM0tmNTYwc1BLbkhTNVZwZ0lHRFoza1UrRTRFbkFmMmljeHVDM1ZxK3BR'
    b'a1JGR0RwdUYKVGRKb01Ka01VQ1NKYWVONjRmMFA5K0xIWC82RVBMdlFiQ2ZHRnVYZTNJNmR1'
    b'MDhqZHMxZW04dHdWaWl0Y1FlTUxXcXE3RmwzSUUwTwo2Si92NFN3R213WFBpVkZiQXpjdG1t'
    b'dFZiNW9pbVhpVXNCbGhVWXVSazFkc2wwcEVqKzJGUlhOR1FDVGtvblVyZCtqMUJwUXBWYmoz'
    b'ClVJN3A4N2ZoOXIxMEt3RDB4YTI3YVNhaG5EcW1GNWhNUnBOK1VRYTFCcXBxN2tDbEQxdWVt'
    b'Z2xsYWdhMGhTVk45djVZbm00Njk3SDkKWGd0WVBmL2JPZzN0dlAxYUZENzkzMitXS1djd3dP'
    b'T3dVRkptM1J5cGZoRWhPTHpyWFFnRkhBQkE0clg3R1BES2h5Z3JOOTNxem55bApMMjdmUzBm'
    b'aXRRY1lIQm1LLzVzWmhhSFQxNXM4TjZTRER4Yk5lVDZndE5VZFVNbHpvRXFUUTFmbWZIUFdC'
    b'Q0h0U3lSUkViM2FMcGw5Cnc2ejFybThLMmUvN2xtREszSzJRWnhjZ0pub0E1TmtGT1B6YlZi'
    b'UG5KeDVaZ1JmRDJ3TUFEdjEyQldObWZXTDJYQjl2VnlUL3NRSDMKSHNvUUd1U0hyVitmd1B6'
    b'bDMxaXNUM09Cc3E3dXdEUERXUTBjM1hMcEhmN1lOVEkwM1BmZFdYbVd6aVByZXlHZFhvOTda'
    b'emNpT1NVRApBVzI4NFJYK3B2bUxrVXo0ZUx0aFNQUmFsSmFyOE1XNjJSRHcyU2dwVlprOFAx'
    b'MldoK05uYm1ETXk5MEFBRVA2aHFKYmw3YTRmUDJoCjJXdmN2cGVPZjcvek9kWnRPOXBzb1NS'
    b'ZGhCQzRCRUxRSmRDc082REpLNnpad2hxalhSWGcycU9qNGpHeTc1a2dQMFovNHQxWnRkSmYK'
    b'cjVhUkpKbll2ZVZOVEJqV0F3Qnc1TVExakpxeDBlejVyWDNjd2VWUVNINVFFYjdrODlnUWkz'
    b'aklsT2ViUEgvd1M1MXg5T3VGb0VnbQpBRUN0MXVKaFdqYldiajJDcjM0NGExVWRnd05hNGYw'
    b'M1J6VHJsdEltZDBDbGhscWU4d3ljVlR0Y3F2UXM2RXJOVHpGaDhqZ0d6d21ECjEzWDRlR0dz'
    b'MWV6YUN1UElRVjJ4Y1ZrMDJ2aDZHRit5WG0vQStzK1AxcXVYWEtsV1hxN1lKSTNHamVRMGhB'
    b'VDRZTUx3RitFU01ndkYKSmJiNVF6U1U5cGRha1djTXc2clNGVkJsWkVHVm9ZQmFrYWNTZHc5'
    b'OXRjMnkxK3NFUXIxYVJxR0FBemNYSVc2ZCtnaHBtWG40YU9zUgpoQWI1WWMvaEJGeTU4ZEIr'
    b'emkrZmc4dnhxeERVZDBHOXk2S2hkTGdTQUl3aENLTE95YngybVFPVGVHUUYxbTA3aW9QSExw'
    b'dnBkUlBvCkV0d2FQYnNHSUxDZE4xcTJrTUJGeEFNQTVCZVdRcVlvUVBLRFRDUmN1NDhiZnor'
    b'R1hsK3pTc1A2aHlIKzk3L3M5c1NDMnJkQzdGczAKbEhiV0hnQXpDWUt3YVlxb1hXQ2NOclkz'
    b'dmo5MG9RWkVYVHY3WStZcmZURnBSRSs0U1FSV2xaV2RXNFI5UHlkaTE5NC84TmR0eDgvMApw'
    b'S0cwaXd3QVZoSUVJYTFYZjhjUnN3UERPL2xqVGV3a1JFV0cybjUzQmdOKy9lTUdZdGZzeFky'
    b'L0h6djhhYmIxODhUN2I0N0FqRW1SCklKOTBtR2hacFJJQTBRUkJISzUzNTlzYUdIMjgzZURq'
    b'SlVGaTBnT0w1N0ZaRk5iRVRzSzhHVkYyYTJXMFdoMCsrZUlZNHRiOUFIVUQKeEhacEtPdWtO'
    b'QUNqQ0lLd3kreEVKa1NkYTIxYUQyeWZEMWwyb1VXejZkdlNEU2QyTDhiWWw3dlpOVmJNWURE'
    b'UTY0VU9HTkszQytKUAovWVhpVXNkR0YvSUxTM0gwWkJLK08zZ2VYQTRMWFlMOXdHRFE1dHVF'
    b'TGdBWVFCQkVpdDNldGJrRDYrT200TVR1eFZpMWFDSUc5dW1FClZpMWN6QllTMk00YkYzNWFq'
    b'cTZkL1IxMjU5MjZ0TVhGUTFJRXRQRnFrQ2Y5S0MwYk1iRzcwT0dsOTdEais5OGJOYWZUQ2JV'
    b'TFFIK0MKSU95NkdvWlpNMDJTVEp3OXNCUTl1cmF2bUpOaUFMSnlDdkh6aVd1WXYvd2JZeGFQ'
    b'ajdjcnpoOWNqdFpWMHM3TStvRmFIWXF2L1EzbApZeG5VaWp3UUJBSEtRd0pPNjVZUWhuY0VZ'
    b'WVZaVEpmbG9kY1lLUjVuNURibzAyL2o2NEhZdDBZMmQvT3RBN0NFSUlpMWppamNvczg0CmNs'
    b'QlhIUDd5UFFDQVVxWEd2R1hmNEt2OVo2RjUwa3B3T1N3a0hGNkJMc0YrbGozY0cvZVF2bTAv'
    b'OGs0a1FGdGdPZ3VJbElqZ05qZ0MKcmVaTWdLQlRnTVh5cnQxTVJjUm9LVlJxVFlPL2pXWU1a'
    b'VEdBcVFSQi9PeW9DNWlGa2NFZ2tITGhFNmpWV29pRVBHaTBXdmgxbi9mTQpPVnRYdjRvM3B3'
    b'OHlXN2c2T3c4UGwyeUI0cWRUMXFmdE14andIRGNRN1ZiTkJlVm0zalhZdk90WC9KLzBXN3Mv'
    b'RUFhREFiMFZPWVgrClBoNVlQTGZaUUprQ1lDUkJFSGNjZVJHek1JWjM4b2ViUklDVDUyN0Iz'
    b'VldJazNzV0l5enFnMmQ4dU1Raks4MTJWa3B2cCtEMnRNVlEKUHBiYlZERjJTdytFZlB1aDJX'
    b'Qy9YbTlBejFITDhlZGZkdk9mSVJKd01YdEtQMnpjOFl2VjMya0dVSjRITUpZZ2lHeEhYOGpx'
    b'Y2NiQQpkaTN4SUZVTzNaUFVvM01IbDZGM3QwQ3padm42OExuMXpxdGpDbmdJTzdvRi9FN3RU'
    b'UjQvZmZFTytrOWFiYmVIc1hYVnEyanQ0NDdoCnIyNm84M2VmVXloM0FuaUxJSWdHOFlkc0d2'
    b'VHUwejBRWjM5Y1p0bzBLL0tRTk9oMXFETHMwOUZpKzdSQStJbnRZSG00bWp3ZU1WcUsKaEt2'
    b'M2JTNS8vTER1V1BIZWVHVEk4OUd2WnhCa2lrS01tcmtSOXgvSlVXTERNTkp6QXFWRE95cDJo'
    b'ZkdiVFhNd2JWeHZrOGZ1L0RzTwpPZkZuN1ZwSmp6RURFTFJ6dWNsalgrNDdnNWtMZHRTci9F'
    b'a2plMkRQbHJuR3FiQXF0UlpYYmp6RXJJVTdrZndnMDZZeWZkMUZtRE9rCksxNGIyQmxza213'
    b'eUZES0Z2RkpSMStCWENJSTQydERYcmpPTWJCYUYzSnZid2VleGEzYTNydDVCMHBBNTlwOWpU'
    b'QkFJTy9ZWlJDK0UKMURoVVZGSU85ODR4eGg2K0xSTHdPY2k1c1Ixc1ZnVTBMMDliaDEvL3VH'
    b'NlhxcmN3YURGUlc0eFIyaEpRVGc0aXg5ZEw0ejZ5MzVoMgpLOStNYjR6cjF6bTAwUE5mN1Uy'
    b'Q0NBQnBXL1k0WnJLN3dZQ003VCtZN1hSMEQyOVhyK0xYZlRBWmNrVUJGdjVuTjhxVmFoaGd2'
    b'M3ZJCklraDhTa2t3bGVPTkE2UUFHaWNGVVJEYW9kQjk5S0JPalFXaVdSajdSUVJiZ05IMEdL'
    b'QmVxVUwrcVVzT3EyamU4UVN6NitaRS9LdUQKMmU5WnVwZEsvWEw2TC9qM25JOE5PK0l4Y2M2'
    b'bjZCNVdON2dqZXdUVkdnSjFaaWhkQi9UNDJ6dXllOHQyMHRmdk5XWTlUTUw0K1pxWgpjSFdw'
    b'U1BuaWNkbnc5blF4SHV2WXJxWEpnZ29UYnpwMFZwcXV0QnhGbDIrYjZlbDdHLy92M1VJQ0hy'
    b'ZWk1WFlSOGJEdHd4bTFsbjMwClpGS1YvMS9EK20yV0d3ZFBOeEhFVC9JeE9Xd0tPOWJPdEhy'
    b'cEZXZUNraUNaOEp3NCtHRG4vZXVEbldIZkc5SjBqOUFkWnc4c1JXNUIKQ1R6ZFJIaGhXSnp4'
    b'V0NzdjA3MWE1ZU5NaDFkVytVOG0wRHU4Wm1laHBkdFRIN0s0REVtL3JrWnVRUW40SExaVllj'
    b'b2ExNmxsNWJMOApvakpjUHJvU09yMEJHbzBXN2YzckhpK3ZoSEkvS2NSRWJURkdha3ZCUXNP'
    b'dDUwTzZDQTB0eGc5YTFIN3RPeHZnSkRMQzZPWGhnaG12ClJHTDRnSEN3V0NSQ0FuMmcxeHNR'
    b'RnJVWXBXVlBaKzlWem5tdU1hUWpkM3lzMk53MWhQeW5kU290VTJGOHpHYjg5ZHNhbyttOEVy'
    b'OEsKUjA4bDRZdTlwNUdlbVZmdmVtZzBXb3lhK1RIdW4vdllPRm5zOXFsMU9ITGlLajc3K2lS'
    b'UzA3T2RHa3FPbjdmR2ZWVC8wZTJrYi93QwpKMUlWTTIzbUFWajdYSWdHV0dLa3ZwY3dOSUU2'
    b'Tm1PWkhOcFJwWHlOKzZseTVPWS9OZE9WcmVQSlBSOWdRTythUXl5eWIzL0cvWGZXCk83U3ln'
    b'Wjh1Um92Skw5ZjQrL0d6TnhFMTlTTUFGZE5mcngxYmpkejhFdkM1YkhSbzV3MXUrMWZ0V2cr'
    b'S0lvMW1XcTNXb250WU83RGEKVGpkR3Ayd1orcUhOdEJtZk1UVTlCeStOK3cveUNrckE0MWJN'
    b'YmE2RU1VT2VaMmFNeXR2aGxXWDdtdmJOcXE1bUpoSndFVDVrQ2NySwpWWEFSOFpCNFpHWGR6'
    b'UmliWmRGdmxJaDRpSnl3Q29WRlplQ3dLVncvdnNabUNCdHIvRkZiVUV4a2ZuVjQvZDl6L3RN'
    b'emFOdlNjVTVtCnBwL3FqY1c3a0ZkUXNjQlFXYmtLc3F5bmsreVRVMHgzVk1RUlhjQVU4Qnoz'
    b'cXhIeEllN2V5ZVN4dXlsUDF6U1hLUXBRVmw3eHd5a28KS3NPY0Q3NnN0ZXpoQTU1MmlrWU1E'
    b'TWZDTjRaWlBGK1JXNFRDb3JJbm5SME5Ybi8vQ3hpc0hGOXRZZERpYlUwK3ZsZktNTDZSQjhJ'
    b'TgpXaDBVKzQrUHZUbHg0WjFNNlhhZVU4SjQrcUw1VENGemNXQUdpNEtrZjNlSFZWUXlvQWNJ'
    b'bHVsWGQrR0srZUV4Uy9kU3FhSDl3NUNhCnNCa0xZb1ppMzdaNXVKUlV0MHlnTTRuSkpxZlhP'
    b'aXVFMVpWM0tqRklkdWJQekJUcGpnNU9CNk1sSlZ4OVlEYUJ3SGZ1Wk1kMFpBZ0MKdm5OZk1Y'
    b'bW9zTGdNbCt1WlJyYm93ejN3OG5UQityaXA0SEpZZHAzRDQ4d1FWbFhKalh2aW5FTW5icVVz'
    b'KzJ5WVUvbU1scVJTYTNEdwoyR1ZNSDkrbjVoQkwxeUM0ajRoRXpwRS83RnBKejNFRHplWTFI'
    b'b2ovczE1eGFhQmlnUUFXOVRURDV0Q3VkM0hsK2tQTVd0VHNFaVVvCnBwQzN6N0RDMERRU0pR'
    b'Q2dkN2RBbkR0b0pvVXNPdzlKQSsyWFFzYng5VUw0aWUyZzNDVW1qL2NjdFJ5SjF4N1lYUDc0'
    b'b2QyeFlrR1YKRkxMc1FveWFRYWVRd1psVHlLb24xNTQ1c0JRdnZkalJkSk4vODM1RmNtMXAv'
    b'VFpDWndwNENJdmZDbjZJNlZqeHFmTzNNWER5aDNaNwpHRnRXdlFwL09ybTJxaG8wdWRhc3p4'
    b'amV5UjhEKzFUMFh0MWRoZGozMmR4bnh0SGVXL205MlhFMVFlY0FoUDN5R1RoK3RrOHJaYmZ5'
    b'ClJKY2ovelVMb2s2bng4TFZ1KzM2TUQ3NGFCOSt2M0NuemhCdS8yZ203cC9iaU5lbjluL2Vw'
    b'aDdNQnZDN3dXRHdhTlNXa2NFZ2tITCsKRTZnMUZST3l0Rm9kZkx1Ly9jdzUvMTA1SFcrL0Zt'
    b'VzJjRTFPUGxMaXRrQng4SlQxQzZjekdHZ3hZVERhcm53TGxKdlk3R21mN0R5RwpkMWQrWi85'
    b'Zkp6MGh5NVFhZDBJV1VQdFVWUTZid3NWRFVvUjM4cmZjVTd0MUh4bmJma0R1OFl2UTVoZVo5'
    b'cHhkUlhBZEhBR2ZPWlBNCnRvYVZ1bno5SWZxTVhVbFBWVzFZTmQ1VVZXc244YmZ5a3VEOFQ4'
    b'dmg3MU43UzI3UTZsQ2NsQXpsWXhrMGlvcElEdFhDRlJ3L2J3akQKZzBCWXNUNVBXbVl1ZW8x'
    b'WllkTWVNalNFenQyeE1RdmorcmdwQ0F0dWpVdEpLZmpnN1pGWXV2NEhyUDdVOUVKVEhkcDY0'
    b'L2ozc1RhbAphOVZGajlLeU1YaktHanhJemFJaGJGenRBdkFtUVJEcUJvR3hxbjc3UGhaN0Rp'
    b'ZmdxLzFueko3VHlrdUNuNzU0RjkyNnRIWEkzU2RlCmU0Q3hzeitCVEZGQVErZ2N1b0NLK2RT'
    b'S0JvWFIyaVh4V0JTSlZZc200SjFaTDl2dEJXcTBPbXo0UEI3TE54Nm85K0MyTmFLWHhLdVQK'
    b'N0xva25rTVdDKzNjMFJkcllpZGhhUDh3bTNkQ05SZ01PSG95Q2JGcjl1TE8vUXdhUXVkVnd5'
    b'NFdXcHZNTGFNY0Z0SWFNeVpGWXRLSQpudkIwRjFsVmxqeTdBUHQvdm9SZGUvOW9rQlZyNldX'
    b'VTdTTG5XVVk1OGNnS3JQODhIai8rOHFmcGl4QUVRb044MGZOZkFRaHMyeEt0CnZDUndFVmRr'
    b'TEJVVWxpRmRsb2U3RDJXNGVPVWVidDFOTjVtT1JTOHczeVRVZUF2TVA3UDFoaXdmSDIwNTdM'
    b'Q3RONjdFcjBKSGV1dU4KcHFDRzMzcWpJVGNsNnRTaFlsTWljVEM5S1pFenlhazJKYXErWGR2'
    b'aDM2NWk5S3lQelo1UGI5ZldkTlFZMjdYVks5Rk9xOVhCVlN4QQpjWWtTeVNrWmlPd1pCRGFM'
    b'TWh1bXk1RG5JelZoTTJZdTJJSFNjaFYycnB1RmJsWG1aRmZYOGJNM0VYOHlDYU9IdkFBQVNF'
    b'M1B4dlQ1Cm4xbmN5TEpTOU82cUZub2JEYkNScGE1TVNjaSsrZm45T3pPVzlRanlZL1FucEZL'
    b'OVEyRUVBQ2FUZ1E0dnZXZmM0bmRJdjFDelcveHEKdFRxa3kzTHg2M2Z2QTZqWTR0ZmNqcXBB'
    b'eFhyaEEvdDB3dFVianhBVzBockh6OXlzRlVRYVFpZmE0dGRnUVBiaDA1R2EzdUdQMGo3Kwp3'
    b'dll0ZnVmTmlNSi92Nng5OC9NUnIyNDBibjYrL2J0VEZzL3ZGeEdDNEFBZjQyY3ZEeGZ3dUN5'
    b'em01OUhSWVppMEpRMVZUWS9IOUxzCklXeUttNThYbkUveTArWVgvL053OWM2NmIzNU9rVXc4'
    b'U3RpTXNLakZ5TWtydGt1Rm9zZjJ3cUk1SXlBU2N0RzZsVHYwZWdQS2xDcmMKZXlqSDlQbmJj'
    b'UHRlZXExbGRBcjB4YTI3YWRYKzVvT0ZiendmRUJyVUdxaGsyVkRKbnJSbzFjeW5NalVEMnNL'
    b'U0pudC9MRTgzbmZ2WQpmcThGcko3L3JVVVlPV3dXTmttandXUXlRRkVrcG8zdGhkZzFlM0Vn'
    b'L2svSXN3dU5XVHIyVU83TjdkaXgrM2NzWHJQUDVqSXFJWXdlCjI5dXVFNmdhMm53YVA4dHpv'
    b'VXlUVzUvMzJVVEZZTFBnT1RGcWErQ21SWE10dG93dFcwaHc0WkFVL2xXeWI0cUt5L0gxZ2JO'
    b'WXNHbzMKMUdyN2JKZjIweGZ2WXQ2eXIyMUtBM05XQ0MyWnovTFVUS2d5RlRBMHdIWnpUVUlF'
    b'QWZlaGZSS0QyMUs5cW5ac2FwanAvcjFDY0dwdgp4YTRHQlVWbENJeDhENHFjSXJ2V3BZMnZC'
    b'eDZsWlRjWkNQVnFEZFRWektjeVZmYTBoWHVVRG0xUktRMVpIZVhTT3p6ZG8wOUllTXNGCk1U'
    b'a21ZVHovMDNMNGVMa2lPU1VUdmJzRndpVmtkcU51VmRhNW95K1d6aCtEOGNPNjI1eDBZYTM1'
    b'ckJqV3lEVUNaelNmajJXT1daR1gKRm5nQnJjdmRoL2JwMTJaWnpLVm5ZQlFMZVlpSjdvOE4y'
    b'K09oMXh1d1lla1VIRGwrRFdjdkpac3RUQ0xtSTcrdzFHa2gxQllVUXkzUApnYXBLaS9iTU1F'
    b'ZEdGZ3owdm9DTktzckRWZWM1YnRETVdpTXdYQTdMYk9lRkpKbll1L1Z0akkvWjFDZ1E2c3FV'
    b'VUtYSkswSlNUOEpTCnlqUTVWSm5aRlovVHM4d3V2VXlya2R4RmtnbktRNktqM0Z4S0tZazRu'
    b'eFR5NUF3K040MHBGbHl1ZGREYlVpL2ExWVdQbC90MVFaOXUKZ1NndVUyTENzQmV4Y1VjODhn'
    b'cnEzbEtHQnZraGJ0NW9JNFFHalJicTNJSXFVWUduNXRNWUpWRGswZWJUeVVTS0JRYktWYXlt'
    b'SktKUwpVaUxPWWdxNENnYVBuY2JnODI1U2ZQWWw2TG1YMmtoZk16a1FhbE1FaHNsa29FdXdI'
    b'eWFQaWdDUHk4S1pINWRDbzlIaGc3WDc2d3hpCmlKOEg1a1VFWUtDQUNjMHZKM0hyZi9zYU5r'
    b'cEFxMDdETXBTN1JNTnU0VnJNRlBJTG1BS2VnaW5pUFdCdzJha2toMzJYd1dHZDhsOFMKSTRP'
    b'TkNWczJKVXBNSGhXQkpmTkdJYmlEajNHaDFvdFg3NlBYYUtuVlpiVFRhekJkVzRSSVhSbTky'
    b'S3N6bUUrS0JPVWkwcE91WWlYTAp3eVdQS2VEbE1uaWNUS2FBbDB3SnVOY1lGSG03dFQ3cnVq'
    b'VXhacHZyVUorc25WbVQrMkxIMmxuUTZmVFE2dlFJSFJTTCs0OHNiMXpaClhxL0dORzB4RFdF'
    b'RGkrVXUwVk9lRWhYbDZsSk1pdmtLQnAvM0R5bmlwekpGL0xzc3NlQktLNnI0Q2hFVDA2Zzdn'
    b'dFFyVVlMUDVTQkQKbm8vUVFiR1lPTHdINXM4Y2dybHhYOUVRT292NTVQTnVVbXpxcm9ITlRt'
    b'eTdaSFlXN2pxNXYxbXZMam5GUko5eEs1RmZXSXJ0MzUraQpJWFNFNldKUm9NUkNvL2treGNK'
    b'MEJvOHJZM0JacVpYbTAzL1puQ1JrUGdmMzZvalpnUURRM3FER05BME5vVFc5VDVhWFJ6a3BG'
    b'aFNUClFuNGVVOHhQWlhMWmFRU1hrMEx4MlpmSzlPNEpJZEtKeldKOHl1NnJXQWJyVlppbUtV'
    b'WlBmWG16aDdDcSthd3h6TUdtN3VxRW9vVDIKQzZjcjhKRCtVZG9WeGtvSUkvVGx6ZUxCRVN3'
    b'S0xBOVhEU2tSbGxNdXdxTHE1aE5zN3JtMmNiUCtlUjdNWjVPQk1VU3ZSclNtNkxtRAowS1Q1'
    b'RlBDU0dXeldBNUxIdXUydlYxd2dwRkk2RGNjWllHektFRm8wbjN6MkpiYWVlYm1sTkthTU5w'
    b'OU9EcU96UThoZ1VhQ3FtYytxClVRS0tUWjcyalp1VFFadlBKZ3hqSjcwYVU1MEF3a3J6V1Qx'
    b'S1VNVjhubk5rbElCV0k4TFlrQkRXQ0xKWEcrWXdCdGxwODltOFlPeXMKVjJHS0hYdkhqZzZ5'
    b'MDNvT1liUUZRbWNJc3RONmptQzBCR0Z0NXJNNVJRbG9PUkRHTUVLTDExMUpUVTl2endKUzFD'
    b'YWJLUlRJbUh4MgpDb1BQK1p2Z3NLNGJKT0tyQWZPaWkyanpTY3ZSK245NUVvSmNTaEVDTVFB'
    b'QUFDVjBSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3Ck1pMHlObFF4TnpvMU9Ub3lNeXN3'
    b'TURvd01OZ09TU1lBQUFBbGRFVllkR1JoZEdVNmJXOWthV1o1QURJd01qTXRNREl0TWpaVU1U'
    b'YzYKTlRrNk1qTXJNREE2TURDcFUvR2FBQUFBQUVsRlRrU3VRbUNDCiIKICAgICAgIGlkPSJp'
    b'bWFnZTEyMDEwIiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_OH')

US_OH = b64_US_OH
index.append("US_OH")
index.append("United States of America Ohio")
catalog["US_OH"] = US_OH
catalog["United States of America Ohio"] = US_OH
country["United States of America Ohio"] = ('US_OH', '', 1)
lookup["US_OH"] = ('US_OH', '', 'United States of America Ohio', 1)
lookup["Columbus United States of America Ohio"] = ('US_OH', '', 'United States of America Ohio', 1)
lookup["United States of America Ohio"] = ('US_OH', '', 'United States of America Ohio', 1)
details["US_OH"] = {"continent":"Americas","capital":"Columbus","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_OH"] = ('US_OH', 'United States of America Ohio', 1)
regional["United States of America Ohio"] = ('US_OH', 'United States of America Ohio', 1)
#----------------------------------------------------------------------
b64_US_OK = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjA3NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09rbGFob21hLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'MjA4MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEyMDc5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEyMDgzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBYQpNVWxFUVZS'
    b'NDJ1MTlhWGdjeFpuL1czMzM5TndhYVVhM05Mb2wyNUt4TVQ0eFlNRDJHa09BQUlGd1pnblpr'
    b'SWVGa0d4SUlKQ1FrUDhtCjdKOXNJQ3lRTENRYndBUURKa0N3amNIWTRJUFl3c2JXYlVuV1BS'
    b'b2RjNTk5ZCsrSEVaSXNqRGVQc1lNRi9mczBYVjFkWFYyL2Z1czkKdXVvZEJOODdCQVptTXpC'
    b'akNBd0tEUmdVR2pBb05DZzBZRkJvd0tEUWdFR2hRYUVCZzBJREJvVUd2andVNmhySTZjeFBG'
    b'QjgyK0p1RgpGS3FLcytWdVltZ25BRENEcnhCait3MEtjVmo2TDdPb3V5amNKYk5sMmNKTDRE'
    b'dWtrdzVMYWdmdnVoRFE4VjVFVFdYQ1IyM2hMaVRHCkM5cGZpbks1VEdKWTRiSy9lQlNpMmZT'
    b'eFNVcGg0eTFjNEUzWlZKWnRiNDBOcUxZaUxEanN3a2hJemJzWEZJbVVZaFc5ZjYwTEgzU0sK'
    b'QVJNbVlUalNjR3cwempObUpobmpPWUtPc3U0dSs3d2psVmRyWHlBdWlkblVXY3BrR251ZHBR'
    b'TTZueXRFeDFrcnErc2NZTWpLRGNsdApteTdzL0dPcGt6TG4yMG91elBNVWxoTDRoR2dxaWtZ'
    b'UW1LN3JtZzdkaDRkcU9uWmYzZmh1czJyZlVYbEx0R2lGSVlYLzhPNm1BNjZqCjk2b2l5cVdF'
    b'b0t3akt5Y2xMS3dwenZpRDM3NmdyS3JLOC9jMHdxZWxBenVPRU1PeER0VytaZUg5b3QwNy9X'
    b'eE91dXY2RXA4dm9yeVcKV2lSUmRrTVhubXFRSEFvZU5iRWh5V1pSRXp4aE0rZUgvQkpOWWpT'
    b'NXd1dXcyOWkvcXcwU0w2NTA1ellVeXJId25KYS8rSk5DM05PUQpPZVVWV3pkL2c3MzAzQnFL'
    b'RDJ3Y0xRZUVESXYwMUNQdHZSa1JwQlJJNFRxbTZ6cks0bVE3cDhYVHdjMXR4NjB2U2tvcUxS'
    b'MUhoUkRZCjRvdHJsOXgwenJLUlRTdTIzQVNLVkRTMjh5ODNtNHNLUEFEUVVGc0tNbTlZcEtk'
    b'SkVGa3BGTE5heG5RYzZZbDBpcUpBMHhRYmwvYUgKVXExK2U2bUxaY25wMVZzKzdKTjJkdnNB'
    b'M0xtMlR6WkdVOFM4YzBvRGZqKzE2MDgxaWY0YnZuTTFBSVRDMFN1ZUdoeW52WVk1YzNwNgpQ'
    b'UEJPN1VoamZXNnlEOGZIYVR4QjR2WndMTXl3N1RZekpVbnpOSFY2NVhkZVA1dzlsdVFZc3Vm'
    b'Z1lGbTFoenVXM2FIaDZPQ1dsdHlWCmxXZXZyT1BsVVZsVW83R0VwbWxmK2EvQlZtYXg0ZHFm'
    b'THBSRSt4UDYwTzYwNW1DSWErdXlMM0ZSTWtVQ0FrYlZmZmxaTnFzSkFMWTAKRGt4SUxJRURB'
    b'bFhYT1VFV1JIbDZPeC91UHRxMnVjVkxVeTJ0NDRzdXVIcjU2bVh4WU5RM1BQYlZwM3l0ekNJ'
    b'ak9uTzZZSTUwcnc5dAo5ZWJaTkVVN2lESC83WmQyOUVVVGtxWUpNa0ZpU1Y2NTg4M09Ybjlz'
    b'OTNEaXlFQVlBTTViTnpkSVlJTXBhZGwzenN1eW02WTNsWXJ6CkxrQmR2SEw3QXo4cUxjbS80'
    b'dHExdUFxL3YvdkIzbkZ0ZG8zSkxLTncvYUZmRkt3c1cxbmpFVzNtcytYVVNrSXF0SkFjUTdJ'
    b'NHlzM2gKTEF5dTArUmorM3d5UWxzNnhpYWlOSW9tZ1A1SjAvSzhkWFBqNVFXMy9PNlIwcklp'
    b'QUpBbG1TTnBLVW10YS83L29Hc0doYWNGN3BGOQoyVmF4c2lhMzNwdVZJd243Wlh3NElaVTR1'
    b'WDlkVWxCb3dvZDRyZHBscXNaVndjYWxaVzBvcmZrQ1NRQllkTTNDaG1zV2ZySzFvMzd4Cld6'
    b'LzZRVjZoQndCaXNlU1RqejNPcUtqRTR1WlZ2dUx3N3cwS1R6M28xT2lTcGtmbnI2NEZnRGNQ'
    b'REFZUWlWdE1QWnpsSFJIL2orNUUKVDFxVE9IWkJ2dFhOa1JoRklvQVVvRi92N05GMTNXNWxu'
    b'Rm5jVFA2R2hUV1gzK0QydUFBZ0VJeHNmUGIzdEpBZ01VelQ5ZEo1UmNXRApiODhpUVp3MVRv'
    b'VmpZRWR0b25IUnlnb0FLTXJpTGlxMWx5TU5va2tVVCtYcHl2ZFhsVmxrNlk4ZG9RRUpNSllp'
    b'VTd4Q1VUSkM4YkdZCk44ZENrZmowcHJwOXd0b3JiL1I0WEFBd05oWjg4K1ZucXdzWjFrd09O'
    b'Y1dqb2xDekxGdFBKYWlXblVObDZ3eW40bFNpYUhRLzdweXcKUnhpYTZQRkhCVTI5WldYWnBK'
    b'SmIwMUR3Vm5jNHpUS3FJT1d6UkwrcUl4M2F3K0xSYlowL3VYenVaRHU5SS9LNnEyL095WFlD'
    b'd09DUQpmL3ZyTDFRV21nQkExZlRCUkRTTE5YbUxIYjFIV0dva0NicDIvRzhneGtSNmtsSW9C'
    b'Q3RxY3ljUDg3UE1mMm9QZlh0ejExMnZ0eit5CnJUT2FFRzUvdFpXM21EQVN0eWRUSEUyUWtn'
    b'UXNLV3U2bjJFVEtlbDNiN1VEUU8rb3ZPYUs2elA4RGZ2SGRtM2VtT0VQQU1iSGswVVcKTzRt'
    b'SVpGcThhRTJkMTU1MmRiNXU2TUpUQjFYS1EyUDE4d29tQ3hpYStON2kvQ3hkVFdONEYwYmRz'
    b'OWN2WXpnaVNVUVNLWUNBcUZhYgpTY0R3aUtMaFp2YlYvUU9IVXZwd0dOWmRkVk5PVGhZQURQ'
    b'dkhkMjk5c1NTWG5yS1YzR1pGMVh6cENFMFJBRkRvelhZTFl3YUZwd3oyCjBVTTJ4OHdRZHFu'
    b'YitvdjFOVGVXV25OVHFTVzBta3VpQ2tXNDNLd3BEQnMybWRiTzhXQzhxQU1Bd0VmQnRNNVNP'
    b'ZVVMN1RZckFQaUcKeC9ac2ZiSEFkVXlrcHFjckVoSlRPYllKeFpucmRlVWxlZ3hkZU1xUUh6'
    b'eHN5N01mOTlTU1dzL0d6dENvVHVGeWVrekhlbElZVUFSSwpwSjlxakZzeGpLUFFLRUJTMFNt'
    b'Ty9jUG1kMGRDMFJVTDUrN2FzckhZVGMxb2h4ZGtKODN4K2tSQVBNdGxaa1NmSVlXbkJwUVVX'
    b'KytOClVoYjYrQ1kxaGg1YVhWR1VUaWs0amt3MEU0cmRYV04vZEcybGdMQW9RNjJ0emdaZHQ5'
    b'SU13bERYa0gvRE8rOTlzTzA0L0FIQVVHOU0KQlkwckppY25hazVPR0ZKNFNxd1kzM3JpdmNa'
    b'QjdNTEtUKzNxWUNpVmIyTXU4bkRCbUxBN2laN1lONFFRVWprV1orbVgyNEthMlZTWApuM2RR'
    b'aUNtNjZrL0c4bDBGQU1BTFNwS1hzNmROemh4RkJjVFVaY3VyTTRlNkRnUW9oaFIrNXM0cGZB'
    b'VXhXRlZnemFZRmt2eFVDclBNClZFZFUvTU93OUZlZWlEcHNhWlpOa1JURzByVXF4V2ZaZEJ4'
    b'REFFb2dTbUs2WkdKVVRkZDErTVcycmswSGg2WTNJaUNacGFpY2o0TUEKc3FMR1ZSVXBna0ho'
    b'WjBLWjJyWDFub2JhWW50UkRpN3o0cWRWeThzeTN6by90elFSWlFmSHFHNGZrMGhoREtraytS'
    b'WXBLY2tLd3RCSApZeU8xWnFMQncrRWNNemdXZi9TdDlyRFRKcWlhcHVtVGphQWtTbEZUaEFY'
    b'RFNWd1d5MGJlTmlqOFRGam9pT282cE5PQ3Q3dzRIVTZmCm9LYmJ5WVVrRk5TUldKYXZlSnhj'
    b'VXFveVdjdUI5dUlNaUlydTREaE0zOTBYQVlDK3NVUUh4Z0FBaVBMamI3VlA2VlFPYzltbTRu'
    b'QjUKYnB2VGJibmpIT2tLN1EyRHdwUEhVRWpRTksycXN0U1o0NHFQeGs5UTAySWlseGVhWFJ5'
    b'bCtZUFlRUENzTXU5b010bER5SDFDc2dESgpiRERTbUVhQ3J1dUthbVpJM0VScm90ekphMGw5'
    b'NnZFRnY4SXJVOHBQMTBIbU5idVZYVnB1TXN5WmswZUZteVJKSWlmSEtVdnluc1QvCm9aYldM'
    b'eXBaRDdEbGNIelBhT1Q5d1Q0QXlBN0xkMTFRSkNyS1E2MWhUSlJORHJjN2tlZ2NsWFNnVVRT'
    b'aDJjMFdOTUdacXVrbW5MUjUKbWNuV1JvT0piSXZGYkRIWGx4V3Q2SGgzTjczS29QQmswRE11'
    b'cDFKOGUzdFBUcllqbkJBa1NhVW8vQVQxZThQc2cvZmVSaEQ0bWp0KwpQS3p3RWJmNS9rUGpr'
    b'T0oxbWdKZGgxZ3FMc203RUVIYXNEeE05N00wSVUxOWpoaVc0OVVlMStTaDN4ZXhlNHZxNTFW'
    b'WnpKelY3QVBaCm1FaFBDbDE5c1UzLzgzSlpXV0ZwYVNGWFhOeHlhUEFFbFFlaTF1dHZ1b2tr'
    b'Q1lUUWR5OVo5WjhYbEp4UHlFUXFEU2FHNXZsdmxGcmQKU0V2UURDQ2s4bEo1TmdjSWNTVHE5'
    b'RVVlZTdQdDMxOXJFWFM1dW5LS3d1UllZc0dhQzNRZEtJb2NTWkdHTGp4SlJISVhYbmpwUllG'
    b'QQo1TUNCMWgxUlYxL3pzQ1NyeDYwNUVraldOaXdRQkJFQTN0ejhEcDFxUDlBVC9DQWcwQUEx'
    b'bXZqZGN3b1hWZVdFSlZWVFZNTE1GTXQ4ClgwSUNYYzgya2I5dUNSMktLendnaXNFeGJPclRm'
    b'anpBbjdQeUhJYW1rc20wcGlPRHdwT0VTTmtjTG9lM3RHRGpIMTQ2dXVKbllaNmMKUHNwVDhq'
    b'Y1kvV0NENy9FN0hvM0ZrbHMzYitlRVRwTEFsbFc3NTlqSUpFbDJzdWFIdTJLM3Y5b3FJaHgw'
    b'SGVKOFRGUkhCSlVLUkQ4YQpUK05tRm1kSUV3Yk9MRmJYSjN5TW9aRm9RYWtYd3pCZDF4R0NO'
    b'cjM4VEI2bE0veVRMM1o1N21BaWtVcWJYRzlIeThYb3VIMnNwYWdzClozb052ei9ldU1udlpp'
    b'd0prc2VJWVJjYnd6RUVBQWloczBxYzV4VllVQ2krdnNSNnZ0YzVIRTZtTlV3amNObGhsVFc0'
    b'b3lGblcwam0KUkVFQjVPVklqNG5vaWFRcTh1MEFzSDl2VCttNXErZlVsbzRId3JGNDhxbnVm'
    b'QUJrU09ISlFYTTVyUmlHUkJVQndFRDlOd2JhUTJsKwp5clFZQ3lRL2VObm5waTJEZXZTYWI5'
    b'Ymw1ekF6cm0vc0RtejNKWDU3WVBTWDdkRUJrMFZ6V2dESEhkRTRRNkRIR24wNWluem5mQStC'
    b'CjR6U08rUUQyK0pJQUVBeW5tb2ZvdmhRSkFEblpXWXFxbmNuOG5la1VvbVRnaFVlZjJmSDJy'
    b'bmM2VWdBQUpQdVI1OExkZjIzS25BMkUKMHU5dDZQZlExcjU0ZjFFNVRoSXpqZFdtQXdQcWta'
    b'RjZHNW1MYVFXUmlDYXBNQlNvVVlVa3dnVEFOS2YxbHZudVFDU3RNcFFneVIvSgpTQUg5cVJj'
    b'UHZ2REhENW9xYnhVVkpNdEtQSjU0Nm5ldkdhNzl5WVBpUTBRc0xvanljTmZJaEkwNi8vYVJV'
    b'ZjFJeDBna3htOTd0aWVmCnNROG4rMWQ1U0wwM09PUGEvVHM3NHdjSGJhRlVucFhoRVRaa3M0'
    b'bmpFZFZsNjJKTTlReGNKc1R6KzBiKzM0N2UveDZSZEVVNUZPQngKS3dlaTdFc3JZOWFHcUtl'
    b'aHhrUHBvRnVzNWc2bXhuRHRUeDZLeFgzZFhmOG1DT0t6L1UwZkN5YTI1YXo3eVczM0tMckR5'
    b'MlNOV2VKdQpYZXRLaWM1RnhUT3VUWGFOMTdJVUFJenM2ODJ0OEl5TWhxa3NteWVWL09mRlJi'
    b'NVd2elFjRGV1NGFpWndWUU5BS2t2amlpb0JTdEJNCnNQUm1RSmczMzk3WDJidmhoNzlvcXZ2'
    b'WkdVN2hHVzNPNkxKbzMvVUVick8vTkZKU3N2K1o5VzNQZDdqbUNoWlBUdWZ1YXBNOTZFeGUK'
    b'ZVYzdDRJRUJrYU9XcnAwejQxcFRvYU8vZVRpa2FQWTVlVG41OXZCWUxLNkJRdURiaHhJZHZO'
    b'cHN0MG5aTnRMTTRqU3BwVVV5SmNnNgphRFp6V3NRVFpUZUJydEhQMzlQelVaTmVVYlBYY2Vr'
    b'WnZrWHR6UDVlU0xJam5VTnR2MzAyc3VUcDlZbWVITlpjdCsrM09ScGZibUtiCmFhbUdGbE84'
    b'WEhiWlBPdnh0aFY2M05ZQmdKU1pXcjZ5QWdET0xuZUZJbW1XSWNkQ3FUZWEvRWRFRWFYNHVS'
    b'eldqcXp6S2EzWlJPa3AKQVhOYVNCM1B5SHJaNmxVTHpxcCs3S1ZEWi80aXRqUGJxY0NKOWJW'
    b'Q1YwRHR5em5QaHlocTZJQVhLYmd1LzZYcXEvUG1aTGUxUjZURwp3d3BIRnhWbmZkSmYxSFVJ'
    b'WVZCUTdiYlpUUUNBNDlqQnJ2SGY5Q1QyUmVXWW1jTm9pbFJVQWNORlRSL0JLUzJjeGtVS2M5'
    b'TDNYTEJzCmVEdzZqdVZlWm1xcVAzdnUvYnM1eVZwZ1VQZ1pJS1VLRzU5MG5yUHFzRkxCTzcy'
    b'NVBkdVRZdEpmdmZEaG04dnpiTlNUM0cwK1hyTTAKN1JuMlJ5cm41TTIwWmhGNDh1eTJhVnRo'
    b'U25KdEhsSHc0dG9TRytFKzRxdDMwcmV0cTh2aCtVTXhtV2ZPUmZSSW5jVjZRY084NXdZSwpk'
    b'VDVSMVA3eXJ1MS8yMS80ZGNBcHc1ejVMQ2FwQ1RteTl3YXp3YVRWdjMxZkFWSTNMZm4rWDY3'
    b'VHZNWHVuR3puYnhyM3RzMjc0Y1hhCnF4ZnRmMGg2Y2xmdGVSVlZOYmtuZWg5a2RVTkh5R2tp'
    b'Q1NRbWMxMG1WZXZmM0RvdUxCQ3dKRU44d0Zub0gzenQ4bkp2NGRybXd5OUsKRnlralJPM0Zx'
    b'MkdRZ3pNZVovWkVqN0IzWTk0dTA0SzZ0KytyVlNPdkxQMmg2SzdWZE8zQVI2MkNLRkdabkJZ'
    b'RTNiamtweS9XL0xqdApiLzV0VCs5cCttZ3dFeWNMaFZPRGc2RmdLRFgxUHBENGZSZVVWbHFJ'
    b'a1lRWXdzaGhqanRvZFhSalBUcnJKbTJtMWQ2SytqbVZzcXdVCjJ6UklCaEtDK05CT0hHWUR6'
    b'dlRsVC82R2Y2NSsrOGVWY3ZUbEZmY3J0bnhQc3JWaFR0bklpSFZ2WTlzaGR1bkhlaytiWXdr'
    b'dXUvWEcKNyszS1hkeTBvYTJ4aVNEU2tPU1pJb2NZNWN2bkYvRnBTZVlsVlZBU1BBd203Q2Fp'
    b'Q3Vqc0lheUM0QWNaNlNNQ0RraVM5bzU4OU9aQgpQMGtTci9kYWdIUDZneEJyV0cxUWVBcFE5'
    b'c0ZqZVVyaTlRdC9xVEUyQVBCZ0VSTmJoaUZNMGRCazNNc21EWCtsQnVXN0hhdXlCMS9OCitS'
    b'VUFjS1BOa281c3czOWJYUmg2enVmbGFVZUt5WTQ1Q3pSek5zY1ByeUgyMXRqRmg1TExGTFJD'
    b'Z0s4REFObTlpY1QzUFByOHE5ZXMKUGw4Z3JJQVI3MS93T013U25PazdtL0RFYU51U08zVnl3'
    b'bTFRUmY3eUNvbW15T2ZlSHp5c1ZHUUtINjQ1Y090VjUrSUVZY0g0MTBhTApBVUEydTExNGJJ'
    b'VVhDc3FMTjdPWHhPMWxnamxYcHpnQXVJWGIvc0F0eTVDbURCM3Q5RkVUbnlES3FXZ2ROcncv'
    b'RVp6dmREOGZYZ0E0Ck5TczJ4TXdHWFFnUXJQM0s5TkU4MStFckxIQmJyV1pSblZKVWJjTThB'
    b'Q0RRaXp3ZjU3U1ErZXNLK2grNnR1YVNCdnQ4ZnZlMGVJLzQKbFNWRldVNWJlVm5odGZVWWZK'
    b'eGJJYW5SRDk1MlBhSG9qL3gxNjZ6SU5UT2JLSnpaWFUyUlpEbVpUSW5UbGlxMVJqZ0FpTVlT'
    b'U1g2aQprRlNTOTk2NFZGSFZuR3puQXhkT1d3YU9FV2FPQ1FUQ0RydFZVZEVrV3phVU5KdVlT'
    b'd3BMaEN5VzZubkZvUEEwWWl5dThHbVI0MHk3CmcxTjU4QVpGS3dENGVnYkh4aU1UUXNpNi92'
    b'Mlpkem1PUlFpVFZIMmF3NjhpaEhRZERyZDAvcUIxM3FSOE84WmFmbi9md3k2S0Z2c0MKZG1V'
    b'dlNDbUR3dE9GUU4vd2V6djJDcUkwUGErUEh5L2M4ZTdlZ1phT3A1OThjOUlkdVdaVnRkTmgw'
    b'M1d0clQ4NlhRcjcvV0ZOMXhhZQpOYWNJcG5hOUVESC9MUS9lN2V2c0NaWGNpYk00YzhUWWEz'
    b'L2FvRXRxNDNNdkh6bnFBeTVyc2xBajJEZWYyWmdTSklxWWlxUnNldTlJCkxKYWtLSXBtcU9t'
    b'TzVzaG9LQktKdjdObEozUk5wYU8xeE1PdlBMVWhGT1hWM0lWaDZXd21kZ0NGT2cwS1R3dkd6'
    b'ZmxyN3JydDNjWmoKZC82UmpDMC83eHQzMzdwbzNaSXBieVRQVGhBWTZIcncyRlhnMi8rNHFi'
    b'ZWorOXhWUzAyZXFWQ09QMzhlN2JTNWwxOE1BR0xOelpLcAp3dGIvbUVIaGFVR0t5OS82NGh1'
    b'YnR4NmJnRk5JWEhuakZZRmc1TVA5clpObFEwR0JJSWs5Mi9kc1BSU2JYamZzbVhQMnNvVjJt'
    b'eVZnCnJaNHNWR01oaDkzeC9vN21qS2ltRi93MGFWc05zakFyeG1TVzVXQ1RMUG5MRnF5TWRz'
    b'bmQwMHM1NXhQLzloM3Z1WXY5c1NuajAyVWwKTUlRbEFxRVFYM1JNWFk3NnNMSFpiTE9PY2Nz'
    b'bkMzTm9aZHcvMGx0Ny9aVDNVWDZwSVlXblJ4ZGEzQnVlZVhsSHg0emtsTWhTNXYzbQo3ZGRG'
    b'bkJWVERtVUt4ZUxKUzIrOE11ZzVKbTlRTUtMS292amFtKzlQWDlSa0h1bnFpU1BSWGdhekVM'
    b'TXRqUjdDd09KS1dHWXVzL2luCnIxOUcwUlRLTHBrczZYcjJEMDBIbW45eTA5MDY2NXhlVXdQ'
    b'b2J6a3lGam9tMStobDM3OFZpdWJCN01Uc3k0UzRqMTJaTGx3eTA5a0kKUmlQUlJKQXVuQ3Fx'
    b'cU1aMFBjSjVBRDltT2YwSWsxZHg5cnhJOHBnSDM3SHowSE9SY3d3Sy8wR0lWRi8yeWNKWFgz'
    b'am5nU2ZlMXRrcApUNFBFS1dkT1Zpd3hjN04xdEhCWjR6TXZoSjNIckV2Ym5GNm8wVmFEd3M4'
    b'VDZiVGUxSHVNZ2l5dEtxay9hNDdyL0U4azRiTGtOdHp3Ck5UMjMraGd6dGZpODJmdnNzekN4'
    b'ODNHak5seEp5TE5JSTZmV1FSSGJmeGYzOXo4WFd5RFFXY2UrdEpqNHhpTWZsbjF6MW9XenYr'
    b'aFMKNktwU1RNZVlMV1JOUTNQUGVNUlNPYk9xcGc3Z3BiUG9XOUlYelMvOCt4SHI2VXVUQUov'
    b'TWtJNFJSNWJlKzBWNjBpOHNoVUdtaUdjZAo4Q1hBRjViQzN1cXY2b3pOb0hBV1EvOXlpQ0FZ'
    b'L3lKcVNPRm5RblVPVStkaE1BU0txcmVPQ3QxQkVRQnEzTXdjRHhNWDFHMmRDUUFvCnNKRkxT'
    b'amdBYVBMekhJV1Z1K2p4cFBKK1QzSjZPeFNPTHBzek1XZDJqQW10b3dJQWVDemtDaThIQUsr'
    b'MnhGUk5CNEFyNXRwd0RPMGYKU0E5R0pRRHdabEgxdVN5QkkwMkhqakdoZlV6SUZDNG9tRmdB'
    b'L2w1UE1wQlVBS0F5bTY3UG0zQlhkdmVtUmhNeUFOVG5zWlhaRTFIMQp5VnQ4aVNpa0NmU25y'
    b'eFZmMDJDZlh2alluc0NkcncxZk9kZjI4elc1N1dOQzNYOGN3VEgwMG8wbFM0bzVYMHh1ZUtU'
    b'elg1ZG5mMmVaCjY5M3V4QXdLei9XYVg3cWhKUFA3clNQeHRVLzNBa0JEUHBzcDVIN1VuTlow'
    b'QUhqK3VtS1d4SzUvWWVEUGg2UW5yaWo4NXVLczZSc3gKWGpnVStmcUdnWXNxTFU5ZE9SR2wr'
    b'OUdXa1YvdUdBT0FuNi9KdmJwK29xdHJuKzU5NjRnTUFJOWVscit5ekp3cFhQRmYzWHY2VWwr'
    b'dQppZlNxZW51R3Y3MzlxVDhmaXJTTkNnQnd4N0xzR3ZjeE82Mi92eko3U1RHbjZYRGpud2RD'
    b'NlUvTlM3aSt6Z29BR2VFNHY5eGlwditQCmg3cW8wdkt0SlZrWWdnTkQ2VDhmaWh6MHBRSGd1'
    b'dm1PRmFVVHkrOEZSUU9BSytmYU1tL2IybXJyWkdFR0RoWmZWc3BOM3ZUU3VzL1QKYnZwOEtK'
    b'empZUUZnTUNvdGY3ejd1ZzBEU3gvdjFuUkFDT2JsVGxFNE41ZDVjSFV1QUR5OGMyem4wZVFK'
    b'V3J1a3hnWUEvN2tyRUV3cApOSUZXVngwVDdiU3p1SVBGSFN3K0dZM0ozRDBwYW90LzIzM2Ro'
    b'b0hGajNYSEJUVXpOMllxZkRqRUowUnRRWUdwMEU2ZVgyNngwTmpSCm9PaVBUYjFEYTZ1dEJJ'
    b'WVNvdmJMSGVNQXNMN1crcVdqMEVwakFKRFJOQUFRRjlUTU8yNmhKMWFIMXJxWjV1OVYwd1Q2'
    b'Y0NqOXdMYlIKRXpSVjUyRzhXUlFBYk82SVo5VG5qQUVkZnFBdS9QTzU0Wi9QWllpSmg3VXlH'
    b'QUNFZVNXandCUk5qL0RxOUxzVEdHenVpQ0VFbDlUYQoxbFJaQU9DTnRqaEhZVFBrL3QzdXhP'
    b'dHRzWXhTbjlTTFh4WUtTUndCd0tRRmdHT0l4aEVBVENvblZkUFRzcGFac2xqeVJKMWNYMnNE'
    b'CmdLR28zRFlxYk9tSUE4QzZHaXMrVGN0RmVUWENxeEZlL1RpckRCQVlBZ0J0Mm4rSlpPakJz'
    b'S25EVGMweEFMaWt4cnFtMmdvQXJ6UkgKV1JKTmRuNU5sUlVBM3VxTTk0ZWxqQjJVNmNhWGlN'
    b'S0VxR1dNeHN4aHJvWElESHBTbkJqWHpvQlkvYXVPQ0srV3UraW5yeW84MFN4YQphd1VBRzRN'
    b'ZHVLdnl2Z3ZkQU9EaWlDWEZVOXNLODMvVzVyeS94WGwveTZReXk5d2x4NUtoRWxnU2M1cUk2'
    b'WGZuS0d6cmtYaGExaTZ1CnNsUmwwME5SZWQ5Z2F2Sk5XbDdLMlZrY0FMNTdiczZCdXlwenJT'
    b'UUFYRnIzdWMybG40OUYydVRuQWFEUVRtNy9WdGxBUkY1VVpBSUEKWFlmR29YUm1Wc3dJMXJj'
    b'M0RiMTRmY2xWOWZiYmUxeFBmQkQ4V0VleWsvYm54cWJvNGlJVEFNUkZ6Y0VTQUpDU05JN0NM'
    b'cTJ6N2ZoMAo5ZGswd2dPQWljVGV2NzJpS3lEVzV6RVpMdmNOcEJyeVdRREFFVXBKMnViMitG'
    b'WDFkZ0RZMUJMVmRaaVU3SXpBcFNTTnhKQ0RKWktpCjVtRHhwU1ZjbG9rNGdjMzFSYU53NCtI'
    b'b3RmTWRxNnNzcXlvc2s0Vy8yUjA0R2hSblZGdFhFNzVoZ2ZQWGwrYnZHNWl3Mm5QTXhGVWYK'
    b'bS9oT0U0NWpTRlQwNmw5MXBDUU5BSDU2c2VjbkYzdlcxMXBQUU9HMnpzVEd3OUZyR3V6TFM3'
    b'bmxIMXVoengrTTdCOU1aeWpNNEtXbQphT1pHTHpkRlB5bjNqKzhOL25Dekh3QVlBZ3YrYkE1'
    b'SFlmOVVZMzN1WVBnZlA1aWYyejlxSXdTTENrMmxUdHBFb1ppZ0hmU2wrOFBTCkoxMTdLNE92'
    b'cnJJQWdDOHFDNHBXN2pyR2FwQlZuY1JSakZmZjdwcklacDluSlRQbS90LzZVNW1Zd0tlNTln'
    b'MTViRlVPYmFid21LQTIKai9CZEFYSFN0VTlKMnBhT09FdGlsOVJhZFIxZWJZbHFPbngxbmgw'
    b'aDJEZVFXbHpNWlVSMktEcVJoMnBWaGNWcHdyc0Q0bUUvL3lXaQowSUFSSXpWZ1VHaFFhTUNn'
    b'MElCQm9RR0RRb05DQXdhRkJnd0tEUmdVR2hRYU9BUHd2OUFsbmFtRkhwWGNBQUFBSlhSRldI'
    b'UmtZWFJsCk9tTnlaV0YwWlFBeU1ESXpMVEF5TFRJMlZERTRPakU0T2pNNUt6QXdPakF3eUwv'
    b'YmZ3QUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0EKTWpBeU15MHdNaTB5TmxReE9Eb3hPRG96'
    b'T1Nzd01Eb3dNTG5pWThNQUFBQUFTVVZPUks1Q1lJST0KIgogICAgICAgaWQ9ImltYWdlMTIw'
    b'ODUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_OK')

US_OK = b64_US_OK
index.append("US_OK")
index.append("United States of America Oklahoma")
catalog["US_OK"] = US_OK
catalog["United States of America Oklahoma"] = US_OK
country["United States of America Oklahoma"] = ('US_OK', '', 1)
lookup["US_OK"] = ('US_OK', '', 'United States of America Oklahoma', 1)
lookup["Oklahoma City United States of America Oklahoma"] = ('US_OK', '', 'United States of America Oklahoma', 1)
lookup["United States of America Oklahoma"] = ('US_OK', '', 'United States of America Oklahoma', 1)
details["US_OK"] = {"continent":"Americas","capital":"Oklahoma City","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_OK"] = ('US_OK', 'United States of America Oklahoma', 1)
regional["United States of America Oklahoma"] = ('US_OK', 'United States of America Oklahoma', 1)
#----------------------------------------------------------------------
b64_US_OR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjEzNyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX09yZWdvbi5zdmcucG5nIgogICB4bWxuczppbmtzY2Fw'
    b'ZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAgeG1s'
    b'bnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3NvZGlw'
    b'b2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGlu'
    b'ayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpzdmc9'
    b'Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZzMTIx'
    b'NDEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxMjEzOSIK'
    b'ICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYiCiAg'
    b'ICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIiCiAg'
    b'ICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hlY2tl'
    b'cmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIKICAg'
    b'ICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMjE0MyI+CiAgICA8aW1hZ2UK'
    b'ICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNlcnZl'
    b'QXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9wdGlt'
    b'aXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2NCxp'
    b'VkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RCVFVF'
    b'QUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFBT3Bn'
    b'QUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQWkKa1VsRVFWUjQy'
    b'dTFkZDRBVjFmVStVMTd2WlYvZDN0aGxLMjJCQlhZQmFRS2lpRFdBaU8xbk4ycGlpOGJZaUJx'
    b'NzBVUU5BamFDS0NwSQo3N0Fzc0kyRjdiMjhmYjMzTW05bWZuOE1yQVJNWWhLanUrUjlmODJi'
    b'OXU3TU45Kzk1NXg3NzdrSVV2QUNKRENhZ1NaZVFZTENCQklVCkpwQ2dNRUZoQWdrS0UwaFFt'
    b'RUNDd2dTRkNZeG00SmZHWThoRmtReWR4K1lXR0d3aVpzL2lxVDA2WldENGhFNkQvRkJqeXZk'
    b'ZWkyRVUKU2FJSkN2Kzd3REJxWExadFdwSHh6UzhtWEh6ME55dVBQN1d5bXMwaUFlQ2RyOGZm'
    b'OStZY0FIam91cHFacFliaGM5YnZLcnlBUWhTbApYN3pqOEUzem0xWFNVSzlaZXRkcjgvYldw'
    b'UVBBK0Z6cmtFMWs4L0FURlA0SVNOZDRsODl0blZab25GWTRKT0xIQU9EZHIwdUpPSGIrCk9S'
    b'UEdXSjVkWFlVZ05QUHpucXNhUGorWWQvUk04ais5K2MwTG1uOTFmUTJ6bmFuMWZQYlV0clRy'
    b'N2dwRjhkL2Zmbmp1eEg2RFRWVFgKb2RuZmtQN2V0cElScnRFUlJDRWJKL1BUbk1WWjlxSk0r'
    b'NTdhakgzMWFiUEhEejUzeTFIbUtFVWhwM3RVT0VZVDhiKzVhdjZrUGdTaAp1NDJ5NWM4dnZu'
    b'ZnBxWlh6bXErZDJUNU00WmRIY2gvOTgwd0E4SWZaRi96ZDB1bWRBSEN5VGZmbmIwcWZXbFdk'
    b'cWZYTW5kai96YkhzCkdJRUJRSXJLbjZMeUw1M1JkZVcwcmtXUFhSTW5VUlpPdG4yMDltU3J0'
    b'clpEVjlPcWFlalNSR0xZL3pTRmJKeU14VEVBR0pkamZmRGEKdXVJc1czNnFpNFdUekZHRFRi'
    b'U3ZQaTFHblAzOFY3NndlSGR0aHNQTHUvZytxU29mUTFWdHUvYnRMY2pLZWMxWk9zL3dVUkdm'
    b'eU5SNQo5OVduWFh4aG1zWUxBRzl2R2YvWnZyRlR4cHIrYjBsanV0WUxBTEU0Q2dDLytVdEZy'
    b'MW42MW4zNzVrN3NYN1dnZWUzMllpS09wU1Q1Ck15L3ozSGhaR3dBUWNXekdmYitvYWRkZWdo'
    b'U0srTEVrU2VpQ25YWXYzeDlpQThBdEM1c2VXRmFicXZLM0RDaW4zN3NjQUVxeTdDdm0KdGd5'
    b'ZjZmWnphOXExN1lNS0FJZ1NaNHUzNldCZS9PL1VaaXljQWdDVFE4Z1FEd0FhZVhENDZMeUpm'
    b'Zk1tOXFHekhybjRRaTZiWlA0TwpBTHhCRGdDSStWRUFZRlJvZGdvM0hjaExVM3Rmdk9Od1Jm'
    b'SFEydTNGQUJDSzRCSWh1Zk5rWnFyYW02UDNpQVV4NWxaWFR1dStmbFliCmowdnNyc2xjdTZQ'
    b'by9LcWVqWlBaZWs4b2l2ZGJKQ09PUWh5amJsdDA1dnBaYlJ3MldkV1V2SDVuVWV1QUFnQ1dW'
    b'WFIrK09pT0MwNisKNWFXRjYzY1ZBc0FWNVYxRm1RNEFtSkp2MGlxQ1pxZkE1dUZ0T3BEWE1x'
    b'QmN2YUFwUSt2ZGRERHY3dGZuTVZkRno5VlVudTF2L0dIagpsR2MybEY5Y0RKSkVMdGhEVWNn'
    b'UEtUOFJSd0VBUTJrQVlMNFBBWmNBZ0ZqOHUzZWlrUVVBZ0tUTy9neEZXUkpoOU03WDVodHNJ'
    b'aHlqClVJUUdnRHVYTkw3NzRKNWhMcThvNzc3cXlhVU1pM01tREd6ODdWYUZPQXdBTlczYWhZ'
    b'OWU2L0p6QVdEZFl6djRIT0xkYjhZZmJreVoKTjdIdlZ6ZlVXRjJDbFdzVy85Uis0WnYzN1gv'
    b'M3dUMlZwWVlwWTAyL3VyN20xRi9XUDdIaStEKzlxalRiTm13UVhqbXRDd0Iybk1pNgo4Ymts'
    b'ejM5VXpueW5BdTUzYlYyVU9Fc2hueFAvZXpka0JLU1doUUJBSlFzRFFPdzhFWHg1SkRmN0Yz'
    b'ZDg3NFdoQ0FzQUJEd0NBTVNDCktBQ1FGQUlBMFJqS2ZHcWJuL242Z1dzYUFHRHJzWnh6Rk9J'
    b'QVVGNW94REVxVHFMTUgvM3ltam9BdU9lTnVjb2w5Ny83OWJqWjR3Y24KNTFzWS9hMTdkRHZE'
    b'SHdDVTVadWZYSGxzdUJtK2RtYkg3MVpWQVlCT0dad3pZV0Jha2ZGbmNPMW5GQnNBWUZ0MTFp'
    b'Ly9PT2Z6ZzNrTwpMMjkvZlJwanZxT3pIcEZkOFVCVHIzTDRKeU5CdVNpU3B2WUJnQy9JQm9D'
    b'clpuU2RmOE5BbUhtbnNmTW9QQ3VJUjkrYitjN1g0NzYzCkdKMURjZ0JZT0tXSGpaTlhUZThF'
    b'QUxOTE1IelVIMkwzbXFYZmUyRy9WUXdBWTlNY0FNQTBuemFQWVBnTFdEcWphMWxGSjRMUTcy'
    b'MHQKL2JycUhJVVJIQUEyUHJXMTRZUDF6QjRPSzU2VDdBNUY4ZmUvTFhINXVRKzlNM3ZxM1N1'
    b'cW12UUFVSmpwMENjRmFCcFordVRWdC8zaApjZ0JZVnRrNS9Qa0NRR1dwb1N6UC9ITkdaMXI2'
    b'bEFBZ0UwVStQNWg3dzdOTDBxNi84MlNiN2p0eEJEZ3g0c0phdWlUYnhoZ0NMMzQyCkJRQm1s'
    b'UTVLaGRIektHUmZJTGpvT1hObWQwMkd3OHZqc09MRDlzNHd0bFZuUlFtOE5Odm0rdmJOWjFa'
    b'WEFjREJodFFmVXY3dHg3TUIKNE5FYlR6YXRXN3VnckE4QVRyWnFBWUN4b1V3T0lVMGpBUERL'
    b'cHJMdmhCdGxNMUVDOUZ4VnpXWlJDRUw3UXh6RzhjaldlNWhXR1FCUwprdndBMEc4UmYzTXNl'
    b'LzJ1d25BVVQxSDVtYWREemwzK3F4dHFodDJobjRIQ3h6K29ORG1FMDR1TWJSdldQbmh0SFVW'
    b'ZjFDWmR0R2RjCmpnMEFhanMwNjNjVmtpVEt3c25GVTd2UFZ3d0FDTGpmbzhLMzd0L2J1bUd0'
    b'ZitjYmVhbnVDKzVwY1FudmVtMWVKSVl6YjJkZmZkb0gKMzViOGtQSi91aTkvZjBNYW0wVVdw'
    b'RHNSaE42NFAvOUVxMjY0TFZ5M3MrZ3YyNHNCWU4xajIzT1MzZWVyY09sVFN3dFgzOExzWVdo'
    b'bQptbFV1bTJ4YTk2SGxxei91ZkhrekFIRFk4ZUdxaGFLUWNCUUhBSms0QWdEb09kcVdUdTg2'
    b'MzM3K3FjMlpmb3VrOUxiVmYzcG85N0tLCnpsZnZQbkJGZWRlTnp5Nnh1Z1gvZ01LU0xCc0E0'
    b'Q2oxeElvVG9TZ3U0c2V1bXRIMXlkNkNzN1pvZ0R0c1U1d3paODRXcjZKa2lOa1EKOHFJWGwy'
    b'VDlyc0t2cTNLeTlXNWZpTjFwa0RNN2x6Ky9oTWNtTG5ZSHp6Tm5zTXNmdVhiaDVGNjFQTmpV'
    b'bTNTeTdheDd3RmlrY1JKNwo5TDJaY3lmMlR5OHlkbno4UWU2SzI3dU5NcWI1ek5SNU9neHl4'
    b'bWlLRVNoSm9uSnhHRUZvTVQ5cWRRczA4b0R6UE9kbnVDcGkzZ1p6CkZhUENBdzJwczhjUDNy'
    b'bmsxTS9wVkRpOHZHdWZ2bXI1bk5ZUGZyMXJacW5oODk5OVUvbkFMLzZCWlZpYWJXRWE5cko4'
    b'ODdCanp1UEUKbVMvVTVlTUJBUDg4Y3lZV1Iya2E2UnFTMWJacjZydTB0VzJhK2c3Tjk1YkVF'
    b'K0RVL2UwaHMxUHdUOHNmSjlHdDFka1g3Tnl3dTlEbwpFSFlZRko0QVorcmRLOTY0ZC8vbGsz'
    b'c1ovNEV4WjdhdCtkTHA0KzJyUy92ZGh1a2RnL0ttUG1WcHRtMVdxZUhBcWRUWFBwLzQ4cDJI'
    b'CmVreFNBSEI0K0FDZ2tnVUJnSVdUVEpQQlBDbWp3bGMvTDV0UmJKU0xJejhiaFZKaDlQVjc5'
    b'ei85NGZSUDk0M05UWEU5ZFZQMTlDTGoKK1NIakMxVElaWlA1YVM0QWFPNVRudXJTOUprbGp5'
    b'OC9JZUFTOHliMmYzTXNHd0FZZy92OGluVEFJbFlzdWQ4VDRQeVVubktQU2RwagpLbVcyclc3'
    b'QmpjOHRHVDcwNFk3aVVKUlZYbURNU1haZlA3djlzLzBGSFlQeTF6ZFAydkQ0OW05Zi9LTFhK'
    b'TTFQY3dMQTl1TlpBTkF4CkpBY0FuU0tvVXdaU2tudzRSb1dpdUMvRUhqWm4rc3lTamZ2emJw'
    b'cmY4ck5SK1BML0hWdzF2M25SbEo2cXB1UVp4VU1BWVBQd3p3OG4KVXRUZm5GK1lZV2NlbytM'
    b'KzVRd3JtVHJQaXJrdFY4M29aQ2pzR0ZTOHQ3V1VhWkRPcVJDTEJVWkVFT3VzVlZXYnNiczJB'
    b'd0RVc21CNQpvYW14V3dVQUgrOHB5TkI2SGw5K2NteTZBd0RlMjFyS2hHeU1kdUh4RnYzVUFt'
    b'UG5KKy9qS0EwQTFjMzZzeFVwNDlGUzZDdWJKcStjCjEvb2ZXalQvUG9XUHZUOHpXUlZZVU5a'
    b'NzFmUXVwZ2w1OUwyWi84REZMczJ4UlFuOHd4M0Z3NnA2NG9PS2ozWVhXczc1QUZWTmVzWWMK'
    b'LzdIQXdzbWJGelQzV3lTbnUxVS9icytEMVMzNDZtak84TTluTjB4NzY4dUpGelRHQUhEcnl3'
    b'djJ2N1pKcXdnd3BzUEQ3MTUydmxOQgpra2p6a0hMSGljeEZVM3YrazhJZy8rRm83b0owWjFH'
    b'V2pTVFJtamJ0Z0ZWOC9pR214MjY0bzQ3RGlrZUpuelFrKzhwZEIrNjZzdkg5CmJTVjJMMy9O'
    b'SjFOL0Z1RUt1TVNZVkJjTEk4LzBxcGlHRUFEMnZMSUpBRzVhczhqaUVwYmxtWis1cGNyaDRm'
    b'M2IwUmxrdEEvSVorSGsKN0hHREdubXdLTk5Ha05qSHV3dVpPSjlVR0RWKzhZN1ZMZGg4YU16'
    b'NTFjUGlxVDB6aWcxY05vbGoxUHBkaGJVaklFNzlId0pEVkplTgowcUlMZWNUcXk1dXVtOVYr'
    b'MjZJbWQ0REx4c255UXBOYUZ1Z3h5VngrWGtHR2c0VlRlbVdnZTBqVzNLZGk0Z1pMWjNRdG10'
    b'TERZWkdWCnBZT2hLR3Q4amkxZDY3TzRCSjRBZC9SU09GcFZXSnB0Mi9qVTFpK1BqRWxWK3pU'
    b'eVFJOVJKaGVIdFlxQTBTNGlLVlRFajVZWG1vd08KNGVaRGViZGNmdVpNYjFKQnV0TWI0UFNh'
    b'SlRoR0tjUmhzU0FXakxDN2pkS21YbFdPM3JXdlBuMXJkZFlGbmNrSkZmNFhhODc3cmo1MQo1'
    b'NUxHUUlROWIyTC9COStXbnU1UnVmdzhJWS9BTURwTDV6WFl4Q1NGOXBoa1BBNjVwemFEemFL'
    b'TURpRUxwN3VHWk9Fb2EvYjR3U09uClU3Wlc1K3c0a1JrSXM4V0M2T3h4Z3hwNUlFUHJNenBF'
    b'bzFHT28weUZDRUkvZUcyOVFoemlzT0laV3Ura1BJdGVHVERZUk1FSUt6L04KdWJjdVhTRU9q'
    b'MGwxbldqVkhXaEl5OUs1YjFuWXRLOCs3ZE85QlF2S2V2UFNYQ1ZadGkxSGN5Zm1XbFN5a05r'
    b'cFFGRTZUZTNiZENEUAo1ZWNoQ00xbHg5ZDhNclhiS0V1bzhMK0ZESzMzbWRWVk1sR0V6eVdV'
    b'a3JESklYVDd1ZTRBVnkwUDhUanhHSUVWWmppc2JvSFpLWnBSClBOUnBrRGYzSmRFMHdtWEhD'
    b'Uks3YmRFWnJTTDQxZEdjeXBJaHJTSm9kQWg5SVU3YmdOTGlFblFhNUlNMnFVWWU2RGJLSDdt'
    b'eFJpYU0Kbm16VDBUU1NVT0dQREswaStPaU5KNHF6YkMzOVNXSityTmNrb1dnRVFXZ2lqaFZu'
    b'Mml3dVFaVEFiNWpkbHFyMjlaaWtyZjBLcTB0dwo2NkttNVM4c1hsYlJzV2hLNzVZanVRU0pM'
    b'aW52anBOb2M1L1M2QkNoQ0sxVCtnODFwckl3aXNjaE1KU094YkU0aVdicjNVYTc4UEVQCktu'
    b'OWlGK2puaVpIK1pFaFIrUSsvK1Zselg5SysrdlNjWkRkSlFUaUd5MFVSa2tJQ1ljNjczNHl2'
    b'YmRkS2hlRitpMlJaWlVkbGlVRWwKRFgyeXQyQnZmVG9ISjdOMG5vOTJGK1NsT2htTjdxbE5Q'
    b'M3c2ZFZkTmhrUVFtWnh2dWFheTNlcm1pL2t4bDUrbkVJZWRQbDZVd05NMAp2a1JGK2lOREl3'
    b'L1d0V3NSaE5iSVE4RXdLMGJnc1RqV1o1WWViOUhidlh3K2x5aktkSlRsV2F4dVFiZEpabklJ'
    b'MHpVK2cwMDBvM2hvCnk1RXhZMUxjNVlYR3ppRkZZN2Y2NHoyRjN4ekxFZk5qeVVuK1hwT3Nx'
    b'VGZwcTZPNVpwZEl5Q2ZHNTFoY2ZsNjZ4bXQxQ1ZyN2xSYVgKa0FtN0p5clNIeGxpUVN3YVE0'
    b'ZXJPQUdYZVBLbWFxZVhGNHZqU1pJZ2dnQVJSM2ZWWkN5ZjIxclRwczNXZTBUOEtFbWhWcGNn'
    b'SjluMQo4THV6QzlJZGxhV0dxaVo5WFlmbVloY0N3eWdoajRnUjJIQVlKVUhoajJCL0Rwc1Y0'
    b'M090OTExZDM5aXRsZ2tqVGgvMzdTMFhEdXVXCmlTSWNWbnppR0t0S0Z2SUdPQ0orTEJaSHMv'
    b'VnVGa2FGb2l5M242dVJCMTErM3RFeitqaUppZm5SWTgzNkN5Smh6NncrYXZjSUpvODEKZFEz'
    b'Si92RFh5Y05qSHM4dlJvTENmd0U4VG56TmJZYy8ybE40cWtzOXZjajQxRTNITmgvTzB5djhq'
    b'TkUvdGNBNDNKMmJydllhN0dJKwpoNUNMSWdNMk1aOFRWMG1ET21YQTRoTDRRMnlYbnpjaDF5'
    b'SVJSQWVzWXFaSG1vaGpPRVloQ0IyTzRnSXVRZEZJS0lLUFRYZjk0cmtyCktvb05hUm92QzZk'
    b'ems1MVBmVGpEN3VHUHk3SGVOSy81aWI5VWpsaHBqdHkyTUU2aUdWcGYrNkFDQUZrNXIyWFRn'
    b'ZnlwWTQwMElBYWIKV0MwUHVmeTh6WWZHZkg0d2YzOTlldWVRWWt5eTY4Q3BOQnluMDlUZXA5'
    b'ZE4xeXFDdGUzYVlJVDl6YkZjajU5TFVzaUczVVU5Wmxrbwp3dXEzU0x1TnNrR2JtTU1pRzd2'
    b'VjFjM0pLU3IvVjBkekc3dFZHVnB2ZHJMSDZCQ3QzVkVzRTBYdnVPTDBOMVU1SWo0aEVVYVB0'
    b'K2hICnJBcEhMb1Z5VWVSb1U3TEx6MXR6KytIUDlvMDkyYWJyTnNtL3JzcEpVZmtuNXBvN2h1'
    b'UkprbkJGeVpCT0VUalJxdDNma0s2VWhIV0sKWUZWVHlzZS8rZmJUZlFWeEV1Tnh5R1NsUHhS'
    b'bHRRMG9sSkxJdUJ5YjBTNDJPNFdwYWwrblFhNlNoWFdLUUN5T05YUnFVdFQrV0J6TApTM1VI'
    b'STZ5cXB1UmJGelkxZHF0b0doSHpZM1VkbXJvT3JWd1VDY2NTS3Z4WHdPZkV0enkzWmRBbU1U'
    b'cUVDeWIzc1hEcWpzV25jWnpHClVMbzB4NjZTaGpDVUxraDNocU1zaDVjL0lkZGFtT0hvTk1o'
    b'M25NelNLd1B0QmtWeHBsMGpEeDV2MXFlcWZRQ0lYQnhCVVBDSDJEUWcKRnBld0tOUGVOcWhJ'
    b'Vi9zR2JXSXVtNVFJb3c0UEx6L2QzZFNiZEx4RmQyMWxoOVhON3h5U24rbFYzYkx3eks2YXpK'
    b'bWxocmNmMlB2Rgo0VHhpUk02UEdhRVVFaVJhMzZrZHNJakg1ZGpuVE94bllWU1BXYjU0U3Mv'
    b'YlgwMlFDcUtaT2s5MWkvNXdZOHFldW94WUhNdlFlZ2tTCm5UVnUwQmZpdVB5OE16MUpZMUxk'
    b'WnBld05OdmFaWlFuU2NPQkNCdEJ3Qi9pQ0xnRVRTTkZtWGFIVjhCbWtaRVlIbzZ5ZkNHMlBp'
    b'bFEKM2FUbnNjblRQYW9UcmJyN3I2NnZidEdYNVZtMDhzRGV1b3hRaEhYa1RLckpLUnlaS2h5'
    b'aDA2NXdqQnF3aW0wZS9wZ1U1NTJ2em4vNAozZGxPTDFjbWl2QTV4QmZQZkYyUTdwQUlvalNO'
    b'ak11eDVhYzZwNHcxbld6VmhhT3NMSjFISm95VUY1b29DcWx1MHU5clNFOVcrbU54ClRNQ044'
    b'emx4aFRqTTQ1Qld0eUJPb2pRTmJCYUZvUlNPVXhnS0ZJV3NtdDkwNUV3eUFQRFlwQy9JbmpU'
    b'R01udmNRSjlGcXBFSGJCNysKZ0ZXTVkxU0N3bjhCOXk5cllJYjNhK1JCcDQ5YmttWExTM1Zt'
    b'YUwxbCtXWTJpN1M0Qk8vL2FoZWJSVGIxS1IrNnJ1WVBmeTNMMGJ1cwpic0hwSHBVM3lGSExn'
    b'bHFGUDBYbDB5b0NoeHBUVDNlcitKd1lueE9UaWlMQk1KNnRkL2RicExrcExrK0FnNklRaldG'
    b'U1lTUS96Zm5JCmU3Tmtvc2gxczlydldITGFHK1FSSk9vTHNmc3Q0bXk5RndDZVdISDgvbVVO'
    b'aWJid1g0RGR3MnZzVnJ0OHZJb1NRNzlaK3RvOUI5MSsKcm9CSGJENlVkN3BialNMd3piRmNx'
    b'MHVBb3ZSYld5WmthcjE5RnVueU9TMzlGcW1RUndpNDhjc245M1lhNUFhYk9EZkZ6ZWNTRGk4'
    b'LwpRckRrb3NpUVE3ejlSRmJua0x5eFN5VVd4T1NpaUVRUXpkSjdUcmJwOGxKY3BUbTJUUWZ5'
    b'eG1WYk1ZejZkRitCUkJDenVnUnFXYkJ0ClVHR3dpOW9INVM0L0w2SENId3FyV3pCa0Z3RUFU'
    b'U09SR0g3d1ZLckx6NHNScUpCSFZEZnJlMHpTSVp0SUxJak9uOVJIeERFT216VFkKUkswRFNV'
    b'NHZMMHZuRVhCalhEYlpZWkNMK0ZHdFBDRGl4L2pjZUpyYTIyV1VOWFNxNjk5ZmIvajgzVjEv'
    b'Mk56VW14U0o0VW5Ta0NmQQpJVW1rdzZDWWtHdVpVV1NNeGJGWUhGOVcwYUVRaDZOeGpDQXhB'
    b'RERZeE9lUGNrNjQ5djhjcjl4MUlCUmgvM2JkOURXM0g3RzRoSjRBCjUrbFZWV2FYME9ibUl3'
    b'Z3RGVVJ0SGo2RzBSL3VLUElGdVZmUGFNOUo5dWlVQVFHWHlFMXg5WmlrV1RxUDA4ZDc2OHNK'
    b'VlUzSmJqOVgKeEk4UmNWVElJMWJOYjFvK3Q1WDVpN2UzVEdqdFYzUWJaZDFHR1ljZDU3SGpi'
    b'OTIvVHlLTWZyQ3RSQ0VKcjl0Wi9QQjFOWjhmekJQeApZN3RyTTU1WlhjWG5FTC8rODZ3RWhU'
    b'OFUrcVFBQUJqdHdqVzNIM2w2M1RRaWpqSEJzNVorWmJiZUxSZUZuWDVldjFraUVVUXZtTGpF'
    b'CmpNbThkMmxEajBtcWtZZHNibjVlcW5QYjhXeURWWXpqRkRPamlnbVlvU2hkVVR3a0VVUlRW'
    b'TDZtdmlTU1JBc3o3QWhDWjJvOVVtRzAKdmxQVDNKZkU1OFFDWVhaMWkzNjRQQ1BSOUJ1WmxZ'
    b'UFJMdFFxZ3N4R210b240Qkp5Y1VUSUkrSWtXdGVoMGNnRGhSbk9rdW5kYmorWAp4eUhOVGtH'
    b'VzNwMlM1Q2NwbE1jbGhtemkzOTE4N01pWjVQcE9UVVh4b0lnZld6S3RDMFhoUkl1V0lER1NS'
    b'UFBTbkZhWGdPbHJITEtMCjJDenl5WlhWQ05DLy9YREcxUlVkSnFlNHh5UWpLV1RKdEs3MlFj'
    b'WDI0NWtBUUZISUR4bmhuNkR3T3l5cjZMeHQ4ZWtsVDF6ZE5TVEwKMG5tYStwSzBpZ0NQUXdU'
    b'Q3JDUnBLQy9WamFGVWE3OGlFc05iQitRWkdtOXR1M1o0T0tGY0ZEblltUHJKbm9LYkZ6UVZa'
    b'OW5aT05rNQpKQ01KZEg1Wm56Zkl4VkJhTFFzR3dpdzJUbUVZMVcyVUtjVmhBWTlBZ0hZSHVB'
    b'Z0NFa0ZrY3I2em9WTkRVb2hHSHJDNkJTeWMvUERSCkhXdTNGMzl4ZUV5Q3doK0tJMmVTajdm'
    b'cWlEaldNcEIwN2N5TzNiVVp6THk5Z25RbmowT1FGTkkyb0JpMGlRRkFJdytRRkNyaXg1aTUK'
    b'YlFEZzhuT1Bua25SS1FPWFRSZzQxYVdhWG1RME80VVR4bGo2TFJLdDNDa1hSeG82MVNrcXY5'
    b'a2xTSmNIc25TZXVnNk5UdUUvMWFXMgp1Zm45RmttU0pNeGhrYjRRKytDcDFJVlRlcG13K0sw'
    b'dlg4N01RRXRRK01PZENuNjIzczFVcE15RWR3WXQvWW9MenJTNHZxZDlldWVyCmNWdlhiQkZ3'
    b'Q1UvZ096Y2dTUm9hc29tWW1VUkowdENnVlN3V3hFZ1N4VkJhTElodE81NlRsK3BpNDVSY0hE'
    b'Yll4VXBKR0VYcFlJUjEKTHVCSGREdEc2TENvRWVvWHNuSHlxeGUrOGdVNXJRUEs2VVhHNm1Z'
    b'OVNaMFZnVXdVdVgzeDZVQ0lNM3ZDWUV1ZmNsS2UyUnZncHFyOAorYW5PS1FWbWlTQXE0TVc1'
    b'YlBKTWp5b1FabmNiWlZhWHdCZmkxSGRxdWV4NHQxSG1EWElHN2VJK3N4UkI2TzBuc2xvSGxD'
    b'NGZ0MjFBCjhkTEd5UlBIV0VxemJRQ0lRaHcrMXBKY2xtYyszcUx2dDBpdW50SDUwcDJIUDk1'
    b'VFFGRWpVWWdqdDc5UXhJL1JOQklJczJZVUQ0a0YKVVdiR0Z3QmdHTFg5eFM4bjVGcU1EbUVr'
    b'aW9zRk1iZWZxNVlIQVFCREtUNG5uaVFOUlFsOC9PMnIxdHgrdUgxUThmQjF0UTJkNnJKOApj'
    b'OXVBSWwzajVYSGlPMDltNXFhNCtzeVM4a0pqVzc5eVhJNzFqUzhtUFBMZXJDWGwzVHhPUEZQ'
    b'bjRlQ2swU0ZjVnRteCtMRnJZbkZNCnlDTVFoQjZ1cUJNcS9NRkJCd1FtNVp0dGJrR3ZXWExU'
    b'dkpZRHA4Nm0vN2xwWHN2OVZ6ZDRBMndFUVdTaUNBMlFxdmJ4T1hHdElpZ1YKUnBsSndoU0ZI'
    b'RDJUNGcreFpjS0lOOGdkc29zUE5hYWFIRUlVQVl0TDJENG9QOTJqSnVMWW9WTnBBMWJKbVY2'
    b'Vk44aWRXV3FZT01iaQo5blBUMUQ2clcxalRwcFVLbzd0ck0zaWMrS1E4eTZCVkVoK3BhYnhH'
    b'Ym5ZeEVULzY1d2QzUzRWUm1rYU1EbUdLeXMvc3IrdlFUcmw3CnhUdGZqMCtTTUlFVlZDcU1j'
    b'amxuMHlpWUhFS3JXOURjcDBRUVdpa0psK2JZVHZlb2hMd1lrMlRQNWVjTjJNUlNZVlFsRFRw'
    b'OVBKMHkKb0JDSDR5UmExNkV0eXJSUExUQVZaOXEzVldmSFNYUlNudm1qM1lVQUlCVkczM3Rv'
    b'dDRnZkhiRXZhdVNxTUJMRDMvbDZmQ2lLMHpUUwpPYVQ0L2UySHU0enlGSlYvYklZakdzUGJC'
    b'aFJmSGhrekpzWEZaWk02WmFESEtJMFJtTVBMczdxRk5nL1A1dUh2cWMyY042bXZiVkNwClZR'
    b'UmRQaDVOSXpKUlpOM080bU5OeVZNTGpLZTZOSGtwVHB1Ymp5QWdFMFkzSDhvNzJhYnJNY2xD'
    b'VVpiVkpiQjcrQlBHV0QvYlB4WUEKd2pIOGoxK05EOGRZSTNiNHpNaWxrS1lSQklIVmx6ZmpH'
    b'TlZubHFaci9UMUdLWXBBbkVLUE5lc3JTNGJVOGxBNGluKzZmMnlQU1phbAo5OHgrNk1ZNGlh'
    b'N2RVVUxFTVp0YnVPVklicGJlWTNZS003V2VVSlJGMFloYUZncEY4VkNFbmFYM2RCcmtXbVdR'
    b'cGxFT2l5UXB0S29wCkdVV2cxeXpaY1NMTDdoRmNYZEg1K2NGOHU0Yy9QdGM2ZjFJLzA0T2ZV'
    b'T0cvYVczTkxEWEVTYXpESUQvZG8vcmR6VlhyZGhWTkt6QTYKZlR5elV5amtFWEp4ZUhxUlVT'
    b'YUtxR1doR0lITFJCRXVtNVNMSWthbkNFTnBqU3hVWG1DVWlxSktTVmdqRDU3dVVkVzA2UlpQ'
    b'N2NsSgpkbzFOYy9hYUpKRVlLemZWM2RxdkJJQ3g2UTRNcFV1emJSU0ZsR1RaUHorVUJ3Q1Q4'
    b'ODA2WlhBa0Q1eUIwVEtPbE1uQ01MM0lXSlJwCis5TTM0eENFbnB4dkxzaHcyTjM4U0F6YlU1'
    b'ZkJ4c25iRjUvdUdwTGhPRFdjQWd4RmFXYXlPSmNkRi9PajdnQ1hNVW1ZQUNtWEZmOWsKMzFn'
    b'SlB6YTEwSWlqTko5TFdGeUNRNDBwYTI0Lzh2eEg1Y0VJYTdSa0N4NEZvN25UMUw0MzdqMVEz'
    b'YXh2RzFRc21Od1hqNk1tcHpBYwpaZGs5L0xaQmhVUVFLOHF5aS9peEFhdmtXSFB5ekZLREw4'
    b'aVJDS1BKU2Y0ZEo3TjQ3SGdraG1zVkFZTmRnZ0RrcHJodExrR2F4ditYCmI0dUZQSUxOb29v'
    b'eTdTZ0twN3RWM1VhWnk4Kzc4YkwyUTZkUyt5MFNsVFQwemkvM05YYXJSdjUwdFZGQUlSSEg5'
    b'RW1CZzQycE5JMVUKTlNVL3NlSjRqMUUrWUJYenVmR0hycXZkVlpOMXFrdTkrdkxtSkVrb1hl'
    b'T1RDS0o4RG9HaE5JcUNrRWV3Y0NwVDU3RjdCUUp1REVWcApJWS93QnJuUkdLYVNoWE5TM0pQ'
    b'R1dOYnZLb29SK0YxWG5UclpwczNVZW1OeDlGQmpLbVBGcEd0OFIwNm5FaU5laUtObVFMNU9H'
    b'Vmc0CnBYZlRnVHdpanExOVpNZVRheXY2ekpMQ0RNZjRYS3VRRitzWWxHZm92Rjhlem1YeWl3'
    b'SkFSY25RK3cvdmFoMVFzREJLSW96NGd0eUgKM3AzVmFaQXo2VkpaTEdwS3Zzbmg0NldwZmJF'
    b'NGRyQWhWU01QWm1nOW4rd3RFUEZqMTgxcTMza3ljemliMmdqSHFNa01MK0FTbGNXRApnVEFy'
    b'RXNQdWVXUGVDN2NlS2M2MEJ5T3N1bllOTTRwaWExVTJ3eCtLMG15Y25EZXhqeUFSTVQ4cTRN'
    b'VXdGQ2JtbVlNUnRsb1dYSFA3CmtmbGxmV1BUblBzYjB0ZzQxZENwUHRXbG1waG5TVkg3bUZS'
    b'aWdUQnJWdW5nK1huRUVpcjhjWXRMVHlzMDFiUnBFSVIrODc3OW4rNHIKdURpVE9vNVJ5eW83'
    b'TngzSXkwMXhQWC9yVWJVczZBbHc3bjF6WGppS3YzRGJrYzJIOGk3STg3eHFmclBiejkxYW5Z'
    b'MWpWRm1ldVhwawoyNStqc2kwOEgzd08rZW1UMjVyN2t2b3MwaDBuczFiT2E4bExkZFYzbnMy'
    b'K0poVkdyeWp2eVU5elRTOGFFdktJREsxdlFWbXZrRWR3CldKVFpLVnc4cFNkT29rZlBwRGk4'
    b'WjlNSWNkbmswNnVPTlhScjl0Um1BRUI1b2VuVnV3OXMzRDkyZE9WTkdIMFpMNWp4bkZNTFRE'
    b'SmgKWkd0MTl1eHhnNHVtZGorellib3Z5T2F3NGc5ZlgzdThSUzhWUmtNUmZQSlkwNUx5Ymk2'
    b'YmRQcTQrcVJBUEk2K3RISHlWMGR6bWZSVApFOFpZcnAvVi9zcGZ5MndlL3BMeWJuZUFlN3hG'
    b'QitlU1BDZFUrRjhFUlNNVWpjd3FIVlJLdzdYdDJqNkxwSzVkKzlDMXRTSitySFZBCk9XUVhO'
    b'L2NwaTdQc1pmbm1nblFIQzZjb0NsRktJdGw2OXdmYlMxN2RWQmFKNFZ3MitlZ3ZUdXFWd2Vj'
    b'K21ocU1zQUZnem9SK0lZOW8KNkZKVG8yZUsvU2hXNFFVMnpoTXJqbS9ZWGRocGtNK1pNRENq'
    b'MlBESjNvS3VJUmtBbEdiYkhycXVkbnJSRUFzalExRldUWnYyL3JmbgplQUtjNjJlM3p5Z2Fl'
    b'blhUcEY2ek5EZkZkZE84bGhjL204SWtmaDJsR04xck5nVWpySEFNajBSeEFCaTBpWjc5cUh6'
    b'Rm5OWWJMMnRkCnQ3TzRzVnQxMDVwRlhEYVpKQTM1UW14ZmtMMXdTdStTOHU2ZEp6UHZlV011'
    b'aytnM0VzV2pCRGFxK1lOTElBY2JneXVuZFQrMi9NVHMKQjI4Z1NRVEg2T1Z6VzlMVXZqMTFH'
    b'Y2RidEFqQTFaV2RzMG9IZDV6SSt2WkVKb2JRT0VidmYvMnZMMzAyZVRodmVvTENFVkdqTXFK'
    b'OAplbFcxeTg5NWU4c0VOazR1S091YmxHY09oTmtIVHFYV2Qyb29DcmwzYVlOY0hINTJ3N1Ro'
    b'OHkrQlp4L0ZhZlF1Q01JeG5nQ3pMb3RZCkVIdnB6c1ByZHhZZFBKVlcwNjROUlZodlA3Q3Zi'
    b'VUJoY1FsNlRWS1RRelI4L2lXQVMyVDl3bUV3bzBsRi9GaHpiNUxkeTN2aHRxTTAKRFUrdW5k'
    b'SFVxekk3aFNOMi9FdWlJdjI3R01rRDZSTXEvRUc0dE1samtGakxOMEZoQW9tSzlOOURwdGFU'
    b'cWZPYUhFSW1FL2ZaaDhHbwpva3k3UDhTK0lLZm94REdXNGNXaDNBSE9CZXVWRkdVNnRISy95'
    b'U2xxN2xNbUtQenBzSEplNjlNM1Y2M2ZWWGpMU3d1WlBha3EzNDZYCnZtQVdpempRa0hyTjAw'
    b'dVpjRGFLMGp0ZTJxeVVuRjJFN2xCanl1d0hiMlMybFpMd3g3LzVkdjZrUHVibnR1cXM2NSs1'
    b'YW9RczcvcS8KYU00OGY5dlJKR2xvOGVQTHh1ZGFuMTFkOWNDeWVtYkp5c0owaDFJU1B0eVlz'
    b'dkhBV0RpMzNpaURQejIwZS82a3ZrLzNqcTF1MFMrYQowbnRGZWMrdmJ6ajUzRWZsQ1FwL0hr'
    b'aUZVVStBYzdneE5SRG1BSUNJZjNZdHBNclNRUUNJVXlnQzlPN2FqT0VGV1ZrNHVhUzhwNmxY'
    b'CnlTd1FzV0ZYa1gvbjY4dm50Q1lvL05td3B6Wjk4ZFJ1eTFkLzVMSklBTmpma003czc3ZElm'
    b'VUgyWmVNSExocy9FSXJpZDc4Ky82UGQKQlFCQVVxakR5OHZVZWFjVkdwdjZrcFpWZENBSW5a'
    b'UHNadUhrNkFyY1hEb1VYbFBaRGdBSVFrZmpLQitqbGxWMDdEeVp5YlJ3SmJmZQpNbWRpdjlr'
    b'cGVIcFY5ZnNQNzZwdDE3UU5LQ2dLZWZTOXlyV1A3RHI2OXFmTUhZZzR4c0pKSGlkQjRjK0I4'
    b'Z0pqUmNuUXh2MzVxMzYvCmlBWjQrLzU5ZHl3Ky9mZ0hsWFlQSHdBR3JHSm1TV3hma0h2a3JV'
    b'K3ZxZXhnYXN0UDloYlVkV2l1bk5iTlpwRlZUY2xMWjNUZXU3UWgKSGg5bGp0WWw0aGVxNVNF'
    b'QU9OYWNIQ2RSa2tRUG5rcERVWnBab3hrQUxwL2N5MlRDVUVwQ0FEQzhqQ3VDMEc0Lzk2V05r'
    b'NS83cVB6bwptZVRaNHdiTlRtRW9Pc28rNjB0RWhXZDZraWdLZVdaMVZaSWtGSW5oZDEvVjRB'
    b'dXllMDFTQUpnN3NYLzdpMS9VZDJpYSs1VkxwM2RTCkZMTHQzR3pUZTY0NjlmbzlCdzQycHB6'
    b'cFNhb29HUnFiN25qOC9jcFI5K3lqdGJPcEpOdWVtK0txNjlEc3EwOEhBTGVmNndueUxpL3IK'
    b'blROeFlNNkVBWnBHYm41eE1lT3E5NXFrVGIxSk04Y056cC9VN3dud2Z2bkh5NWcyRWdBaU1U'
    b'eEY1WnRaYXFnb0djSXcrb1dQeTEvKwphOW01NVFWSERTNnBuZ3FwTURvaDF4S24wTHAyemNY'
    b'ZHVjT3paQzdHK1FrelJoMHU4YzZtL3dVa3d0d0pDaE5JVUpoQWdzSUVoUWtrCktFd2dRV0VD'
    b'Q1FvVEZDWXdxdkgvbzc5cFRqTXJQM2NBQUFBbGRFVllkR1JoZEdVNlkzSmxZWFJsQURJd01q'
    b'TXRNREl0TWpaVU1UZzYKTURnNk5UWXJNREE2TURBNUZuM1JBQUFBSlhSRldIUmtZWFJsT20x'
    b'dlpHbG1lUUF5TURJekxUQXlMVEkyVkRFNE9qQTRPalUyS3pBdwpPakF3U0V2RmJRQUFBQUJK'
    b'UlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTEyMTQ1IiAvPgogIDwvZz4KPC9zdmc+'
    b'Cg==', 'US_OR')

US_OR = b64_US_OR
index.append("US_OR")
index.append("United States of America Oregon")
catalog["US_OR"] = US_OR
catalog["United States of America Oregon"] = US_OR
country["United States of America Oregon"] = ('US_OR', '', 1)
lookup["US_OR"] = ('US_OR', '', 'United States of America Oregon', 1)
lookup["Salem United States of America Oregon"] = ('US_OR', '', 'United States of America Oregon', 1)
lookup["United States of America Oregon"] = ('US_OR', '', 'United States of America Oregon', 1)
details["US_OR"] = {"continent":"Americas","capital":"Salem","currency":"","web":"","lang":"","tz":"-08:00","altname":""}
regional["US_OR"] = ('US_OR', 'United States of America Oregon', 1)
regional["United States of America Oregon"] = ('US_OR', 'United States of America Oregon', 1)
#----------------------------------------------------------------------
b64_US_PA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjQwNyIKICAgd2lkdGg9'
    b'IjEzNyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxMzcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1Blbm5zeWx2YW5pYS5zdmcucG5nIgogICB4bWxuczpp'
    b'bmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIK'
    b'ICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFRE'
    b'L3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5'
    b'OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxu'
    b'czpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJk'
    b'ZWZzMTI0MTEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcx'
    b'MjQwOSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9'
    b'IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'Y2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXll'
    b'ciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxMjQxMyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxMzciCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSWtBQUFCa0NBSUFBQUE5bklUQ0FBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQW4KVUVs'
    b'RVFWUjQydTJkZDVoYzFYMzN6KzB6ZDNxZjJkMlo3YjJvN2tvcnJUcVNFRVVJUkcvR3hnWmpF'
    b'eWY0dFIwNzcycy9kbUxzeE4zWQpUbUk3QnROTURLRVprSkFBTlZSV1pYc3ZNN3M3dmZkNzUv'
    b'YnovckVFWE1qN0Jod0I4alBmUDNmbitaMXo3K2VlYzM1dDVpTDBxbytECnNqNlNRc3Uzb015'
    b'bXJES2JNcHV5eW16S2JNb3FzeW1yektiTXBxd3ltektic3Nwc3lpcXpLYk1wcTh5bXpLYXNN'
    b'cHV5eW16S2JNb3EKczNrWHFUQmVpK1YwcWpLYmo1NHF0YWx2N25yendQZjNmZjJlWFNvQyt3'
    b'dGpneEd1VlpmV2pEWE11Q0Z6V0NTc0NxN0w4THJ4aEtlMQpXbmZmM1hlZkd4eGI4bzJabURj'
    b'aGhCSmhMYStiRDBFUVFYSjVrVXFjUUtBRUFCQ0JQczVhQ29XQ0pFdXEzSERVSDFlbno2anpB'
    b'MzhCCmJQQkxic1lDWnRIUklKRXBHWFZuaFZJcDQ0MjlSczJkUC9MTWlMZUVpMGxSQXVFRXJF'
    b'VEdaRnduMEUxbE5oK29KTktPWXJpS2xMajQKSE1kRGx4V0VmVWRDRUtBOG1jeENtd2t3SlZC'
    b'Z1lJWG1YSmpYaUZSbCtiejVBSVVnYWlGZzFyQU1DNHc2UUJHQXdBR09BYTFLdGhtQgpRUWNN'
    b'T2tEZ0FBQkZJNGRLaUYzQnRXVTJIK0JpRjlOR0lxbWxnU3dERkFOYUdrZ0tZRXFnd0FKSkFv'
    b'SUkxQlJRVXdCQWllRENIR3FGCmx5YWVTNUlOVUVTaXRJaGpJSndBR0Fwd0hPQVlnQkRNQjBB'
    b'NkQ0b2x0R1RvRVppOENoY3dSRlFKZmdFMXliaSt6T1lEUVlOcGtjeTQKSWtNZU1lYnpQSUJB'
    b'cndFNEJsZ084QUtBRUZJd1Y3SnRsMFFGRlRJNmxXUUFmaDVxUmN4Y1p2TmZxcmJTMXRYaWFX'
    b'K29tbHVLYXRRVQpBRUJSNFBzNmNqQmFXSUFTVjNMc3dTeE5FbGZNcGhrVkJhMG1JTW5Bb0FW'
    b'UUVValdKNmpyT0UycndzUkVRVmI0UEVBd21YaHZlQWdjClc1NWhSMk1WUlJJRmh2dkxZZE5j'
    b'NjhybTJhNW05NzE3VjIxWTBVamxSdSs2YnNmVStjT1l3Zk9Qbjd2bTNJUS9WeXk5ejJ3TnpP'
    b'QmkKaXRHdWhvUk8wZFdUWWpTVExocTF3R29DdEFxWTlFQ3JWbEEyTEhKY3did0RpQVZFeUl1'
    b'NlZnV2ozOU1vZDE2enFhZmRuY3F6MjJyNAorMjdkWmFPRkZSMXRLMXM4TTR0UlVaSXZZUjk2'
    b'YzNmTDNyNldYTlI3L09qci8vSzlYNU1rbWNsa2VLNDBORFRrZEM0T25ZRUdIUTBpCnFmZG5Y'
    b'TVJNUU1ZQlJyM2xXQnRYR3BVb2pzRUNBd0FDWXF5dDBwakhVSjRXUTJqMEpkNjJTVFowby9K'
    b'N2ZnNDBhZ0pMamZjNk04OCsKZXhoQzViSEhIbXR0YlkxRUlwKzYvUk5PVjhWU2xuamtoUk84'
    b'SUYxNjYrYXVhemFlZSsyM3J4NThKWjFPYVRTYWJEWnJ0OXVESTJPNQpZc0VmQ25tOTN2M1hY'
    b'UmRPRmJNRjl2MUVPWWhXSlN4eG10YTNUaUJjYTZCbEhZM3hpRUdTOFp4aFd4R3JRZGl3SWdx'
    b'S0F2RlNXTkIzCndQZm9EcXhxcmRteXB2SEgzL25HOE5DUUlrbmV5U21Od1pETDVXaWFIaHNa'
    b'REN4Nk8rcXNhbFBWdkQ5MmliRzVibWUzbHAzdjd6OGoKaWlLTzQ1SWtxZFZxTFU2c0xQQllX'
    b'eE9sVW0zZHVyVzF0ZjN3MmZrU0w3eXZaQk9oRUhvY3cyeFdkZU9xMXRyU3kwNmpiQ0ZTSnJY'
    b'WQoyVUJRalZ0UUhFY0lVeGFyNGEyYlJYMEhRTjV6SnBRa3NHczJWRWNqb1Z3dTUzRTZlNHRp'
    b'c2NMT01JeE9wMk1ZaG1FWW44OTMyN1U3CldGbTFGRTVlU214NFFkTEprYW1wS1ZFVXpXWnpQ'
    b'QjdYYXJVZ0VLcEJjSE5yczg1aEh4Z1ltSmtZMnJYV3M2Rm41Ym1KNFBzWVluZmoKM0hldkd6'
    b'RElTeG9hcXpObnErcmNKTFBZM1NSQ2d0YW9VWGRUelNkYUR0QVlQNTcwdlBmb0Z2bktYZHVh'
    b'aklWbm4vNzNTQ1N5ZHUxYQpEQUJqSUJwbEdVV25TU2FURlJVVkhNZXhMRnRmVjNkeUtwMTdY'
    b'MHYvUTJPanBWVTFCajZYeTZuVjZsUXFSUkFFeDNIK1FnNXBxdGZNCkwrcDhmZ0ZGWlMxOTlt'
    b'eC9wVlV6R1FVUXZqZUhyZFVTV3VmeU5qbzRQY1V4b1dteG1DekZGMXhtbU1yREtoTlBzWXZt'
    b'L0ZtUkYybFMKR1lsWDhqTDVub3kzTjFRVjVvK2RPbmtTd3pDU0Z5eGpzNlprWnNabEhvOUhj'
    b'UnpIY1Z4UkZKVktwVktwR2hzYmpvNmxKRm01bE5nNApyVVphQ0FVQ0FSekhNNWtNUlZGMnU1'
    b'MGdpRXcrdDZpSWt4S0hwTEw1UWw1bnMra05sdWtFOHA2TU54Z2pqM3pzYkdzVmY3QmY0Z1RR'
    b'ClZvZHJySzVWZGFJM2pMUldveWFuczdrSzBxUjBabHplM0tsYzNocDhkY29qUWVLL2I5OWkx'
    b'QXF4aVV3bXd5V1N1a2hpV2t0RlRMcDQKUG1jd0dFd21FOHV5UE0rcjFXb0lvY0ZvbkloQ1di'
    b'bWsyQmkwZEpkSDdmZjdCVUZ3T3AwY3g2RW9hcmZiRTRrRWhtSGZmK2hmZTFwYgo5WHE5ZSsy'
    b'MlZ5Y0ZYaEQvbTJaZG1zeGRhMGYvZXZzMGdVcUh6MG8yRXhwSVVkNm1iMHVidiszVlhvT3Z1'
    b'eit2N1lvMlBqQ3YyKzhTCkJock1xWmRPU1d1YWxHWjdOcFNoVWlYZGYzT1VaS2JRdG1iVDVY'
    b'MWRCa0ZZczJOWDc1VjdEaDk2RlVYUm1wb2FobUVnaEJVVkZhVlMKQ2NNd3JVWTdueUhmWjVU'
    b'MllmblF2bUQ4TTFkdmV1bWxseUNFWFYxZDBXaVU1M21Ed2REVTFCU05Sci8wK2Z1N1Zib2xK'
    b'dCsyazdoaApSKy9qQjg3L3ZpZEtFdmg5Ti9UWlZIdzhrME1vaTRLcGlpVWhrc2dRY3VLK2p0'
    b'L1pkRUlvb1F4TksxTkx5czJYRVY3VERaYTFld0VBCktrdGxJUm5YdXJlaktFcXFUY09KVDk2'
    b'bSsrSkxwNlJ4bit5MnhSNjVNL25sNTFjdmlUMGtnVHR0Um9yQUxTWnR0VTJEQWZuVmM0dEQK'
    b'VTR0LzhNQ2lxTm1neVJWU3lYQ0V6ZVpPL2U0Wm85RllVVkdCSUVnK241ZGx1YU9qNDlDaFF4'
    b'UkY3ZHA3MDh2ZmYrblNpMjlRVXFQVgpha09oRUVtU3BWTEphclV1TGk1V1ZsWmFyVmFibWpa'
    b'RTA0c2NPL0xrWXliVFMxLy95bGRmSEN2Mmo4d3ZoK0pmdWEzbjlaZWZZQmdtCkdBeEdvMUdT'
    b'SkRzN094Y1dGdHBiYTQ0cUZreFlva2drbG9icHZESWZWRFI5MjloY2hqYVlBQUN4K1dtc3Ra'
    b'TTJtT0xlR1oxclkyUlcKeFpTNDU0NUxLeHZSWTBQeWpxYlNxZG01ZUR4dVVubE9uVHJGc3F6'
    b'VmFuVTZuU3ZhMnlzM2RiNzg1dGp5dE5kMTFWL2JZLy9hLy81UwpQcDgzcSttcmpIYVAyMDJR'
    b'cEN6TG9WQklwOVBsOC9sVUtzVXdqTXZsOGdXaWwyUmV3R3AzeEx5RGlxS2tVcWtWSzFaTVRV'
    b'MXBOQm9JCm9hSW9qanliWnhuRlpUZWJ6ZnU3MXlrbnprUmgvTExMdHM4RmtwL2Z2K0puMy8r'
    b'SFFxRVFpOFZ1dk9PZTZ1YXVocVpXcDFXOXJvVk4KSmxKVkx2M3VOZGt3Vjd1bGsyT2c0ZlF3'
    b'UTZ5NFpXSHd2S21xV2hJRWIvK2JURHJoYUdpSnprL2I2NXJHRHI2ZzhNVjc5MksxTGxSRAo0'
    b'MGRHNkxuWjJkb0tVT1JWZXFPMXJySEY3WGFmUG5VeUhBNHpzWmtOVzNiT0J4SjM3ZDNvaEQ3'
    b'MjBkOVF6UTBDaEZxVFVTOUlpcUt3Ck9Gb3NGa1ZSVENhVEd6ZHVuSjZlanNmalhWMWRQc1lT'
    b'aktVdlBUYVJSSFozZDNVeW1SUUVZWG1QamthamhVTEJRcWtxOGlVL2tFbWIKZGJPOXdqMDUv'
    b'eXlwbkQ1ekp1d2R1V3BqNDg5Ky9EMlh5eVZKMHFmKyt2ODg5T0xrZEpncnNLbS8yM2xVNGFK'
    b'Yk90a2FlL0hYL3JzMAorMyt5SUxVaGF6L0xBVnVOWHIrMVo3VnZicTRKNWI1NngzNDdUWjBi'
    b'SFRmUWFzcGtRZHYybTJwYTVxYUM0WTRIRnhkU08ydkhydGtvCktFSUdwYWxEaXcyK25DcFFw'
    b'Rys3ZXVPaWQ0N25lZS9JaVMvZWM4TXpEMy8vNE1HRE5SdldiUm56R1RmMitDSmhJeTlhVUR5'
    b'cEl1S0oKaENSSnpjM044WGdjQU9Cd09HcnI2dDZjS1Y2ODVNMUY3QmRJWll0WFgzdGpvVkRB'
    b'TUN3ZWozZDNkMHVTNUhBNG5Ea0drMlhQdXJXNwplRVN6R0h4Q2k4M096OXRzdGtRaThac25u'
    b'Nmlzckl4RUlodjZOdjNnNlF2TGp2VnRhNllKVUlJS01PandsMHIzTmR6NEJRVEZnTHV2ClFw'
    b'SFdyOTl5eTQ1Tk4yNWFaN1pZNjJzOEpwTUpwVlJiVyt1K2Y4ZmUrUFJvY0d3SWE5aWp1KzAv'
    b'MVBXYlhIZjg2Z0xicHlLQklNSjkKSGZPZjZCNEVBSlI0NGVDRWFEU1pPSTdETU96dnYvcTM4'
    b'WGpjNlhRKys4YnJyOVc3UEsrZjN0ZmNKclEwYUV1Y09aRXhtODBzeS9iMAo5TEFzSzBsU05w'
    b'dmRzZWRhcHNSZnhFUGg0cG5XYVZUSGhnTGYrZjZQRkVWaFdYWmtaT1QyMjI5SC9DRlNraEJh'
    b'dmZMY2VNUmllQjRWCklyR1kwV2prT0U0VVJRQkFMcGNEQUZBVmF3VHhMZStnMnBnL015N3Y3'
    b'TUVmSFY3cjJ2MXBBQUNUU1ZWR3B2ZXZhWjlLNU9PSnVNL24KaXdUOHo1ODQ4Nm12ZmV1NXcw'
    b'ZDhQUHJwQjM5Z3JXMXkyR3dnRlg3SGRienltK04rYXY5VzR2QjVxZDZjZTN0eHI5cXdPeGFM'
    b'S1lvQwpBR0JabG1FWWc4RndmSFQ0VUlzYkMwWjc1NEpwQk9vSW9yRG8zNzkvLy9Ianh4bUcw'
    b'ZXYxdDl4MmV5eC9jZE9kRjNGUDR3WHB6SWczCmtoRTJkSGNHRitkS3BaTEw1VEpsOHcwUWwy'
    b'dmR3dzZqTjVNeW04MG1rNG1tYWF2VnFsS3Bsbk1oZi9XRi8vM0l3Y25sUldOV0ZXNWUKTmNX'
    b'V2xHb25lakM2bDVCUkpoem1VOG5UcDg4TUx3VVlCZHk4ZVYxVlplVi92SEc4QURIdjdMU21w'
    b'bW5xL0duU1VaVkx4aXR0NXVLUwpMeG1LRjBLaDVPeDBNUklOenMrc3IwM1BCNVhWOVlJdlFZ'
    b'ZUxKZ0JBT0ErNzNDcXZkMzU1cDZxcXFxcW9xS0JwbXRacVp4V0JyM0t0ClJFZ3ludFpVdXZU'
    b'MXRaT1RrNHFpN0x2aGRsRlg5NTJIRDBKNEVkbGM5RjZPMDhQenA0ZkJ0azEzTWJNSExSWUx2'
    b'V3Y3VHg5NWhKN0oKMXRmWDE5VFVJQWd5TlRYbDgvbnE2dW9xS3l0cG1xWW9pbFJwZTFjMm5C'
    b'cWFneER1YlowckZpV3JBY2tXWUNhdm9pTmdKcEM2ZW1OVAozTHppdGFQRHF2elFaVS85RzRL'
    b'aXZNQWpLQ1pMVW5wMkhJRks2TXhSQk1BeEREUFpLbHMyM2FIWFVFbUpsR1FGTTYvWHFMMHVL'
    b'K3FQCnlmOXIrL2d0VDFaRGdKcjBtdXV2L05UVTVJVEpaSEk2bmVsMCt2ejU4KzN0N1hhN1BS'
    b'NlBCd3U1RTJHZlRxZlp2bWFsU3FYU2FyVmIKOW4vbVgxNitJTW56RnltcythQnJhNHVocEw2'
    b'eTliYjlWL3o4Wno5Q0VLU3VyZzdETUpQSnRMaTRpR0ZZUHA5UEpCSXFsY3BrTXNteQpmUExZ'
    b'NGZqYzJhL2NlejJwTlhiYlRwdlZSUldGQkJJZ3c2a0RCY1NpNFZrbWJxQllveFl4V2F4Nk5l'
    b'R3dXMG0xdnNaZERTaXpWbTkxCk9hdXlBbVcxdVd6MmlxU29XMHdxQ0pRaWlleUVOeHdKUjI5'
    b'Yk01a3BRRUVFTmhPYTA5OTAyNWJxODYvKyt1eXBZeDZQeDJBd0pCSUoKcjlkTFVaVFZhb1VR'
    b'Mm13MlFSQ01SbU1nR0ZScE5QZmUvOEJZZ243MmpSRkpWaFFJTC9aTlF6NnczMC9iczJsRlEr'
    b'eGNBUVhIUm9ZZApEb2ZWYWhVRUladk41dk41bjgvSDg3d29pZ1JCS0lvaVNSS0tvaTZYcTZt'
    b'NXhXSFA3YW9kVTFQSWJFeDk0MlZwbStuUHVpTUxJVVFOCnRmMFRVbzZCT3F2NzJUTU44L1B6'
    b'Q3dzTEtJcFNGQ1hMTXMvek9JNXJ0ZHFhbWhxdFZsdGZYODh3VER3ZTkvdjkyMWF0cVhCN2Zu'
    b'R0IKemIvZmV1Q0h1YWNoQ0xKeFZhUERZamc1T0J0TDVkNytlNzNiZnUyR3FvUFBQcDVCMFQw'
    b'TGNXTG54cWdrS0lxU3orY2xTVnFPRzFBVQpYZHZkMDc1NkE4UTFKWmxVQWVia29XZkd4MFly'
    b'OXF3V0pKRElLZzREckhaQzZxMWFHdmpOUVFBVnNMTVgyUDkvVmVZSkh4aWFBVFFKCnJ0c0J4'
    b'dWNRZ3g1RTAxQkZBcGRSUEhyMHFNbGszbi9qclJTdHhZSENsWXBIajd4UkxCWmxXZVk0VHF2'
    b'VkxpMHRtYzFtZ2lDdTJMekYKZmZERWdXci9ydFoyckdMdHM0Y0hmeisvcWRlcVBTN0xZaWha'
    b'WkxtUDZMcjV4ajA3VHh4NEtwbE1ydS90dlJEWERVejRkUnIxZmRkMQpIMzN4MS9Qejh4YUx4'
    b'V0t4TkNORTY5QjBmMWREQ0VxS29pU1R5VVFpVVN3VzkxMS95Nm1RTHAwcnZtM3QwMWMwUFB5'
    b'ejczN21VN3V1CnFqL3d3NmY1KzY4anovbXdMOXllWC80dmhPRDRBSmp3Z1NGZkxhM1JrZktz'
    b'bXVRNEFSUVl3UElBUUdBemc5NHU4TXhySUo0RzEyNEgKMFNRd2FNQzJ0YlJGaGYzb2FiNnZD'
    b'K2RSMTMzZmpuenNnVzg5ZW1EazdVSDNiZWs0LzhxL0JnSUJ2Vjd2Y3JrTUJnTkZVYlZxVGVl'
    b'cAo0Wm5PeGtHQkNZZkRBSURkVjF6dExUbE9EM3NCQUR2V3QzYWE4d01YenJlMWR5eHl6a05u'
    b'Smo5eTU4Mm10YzMrZ1pjWEZ4YzVqcHVkCm1WblhWb0hwS201WW8vbmxUNzhMQUhDNzNUUk5B'
    b'd0F5S0VnM1ZDZVRTWmtrNHZGNE5Cb2xDT0xtdXg5NGNZajVvMWhoVldmN3dKdXYKOUd6YVl5'
    b'TkdQRFpsekt0VVdkR3BlU1NWZ3pXVkVFRkF0UXNZUGJmYVcvOTIzU3JuclgySGRxMEhtMWFC'
    b'SFQzZzV0MmdieldZV2dDLwpQUXdJSE9RWlVDaUNXeTRIdlowb1Y5TEZrdUpTREs1b3BDN0V0'
    b'bzFNTEtrOTYvMi9WeG1iWG9yWGRteFlVV2VhbTUwcEZvczBUWk1rCktZVmo4cnJWTTJJSlFa'
    b'QmxyM0pvNEVJcE92WHBPNitONXFRdVUrclFxd2Q1bnZkNXZXdWFuVXM1blAwZkNucit4K0ti'
    b'OWhwYk5CcmwKT0E1QkVGbVdUeHc3c3RYRGdhZWU2MW5iYmJGWUVBUUJBQkFFNFhRNmk0b3M2'
    b'alNaVENZWURLNVlzWEwxMWZjL2Njei9wOUYxa1pkSgprcFE0NmI2bnR3cVlXVlpBTmkrTitZ'
    b'RHluK3RtVnZ6bWRPNG1sMFZvSkI5TUkvdEQyaGRLRFdHa0t4a3lITW5wSGl3aG5RLzkvVmFT'
    b'ClFQZnZBSTk5RTZnSlhDNXAyQ0ozZEZDNmNnUCsyTWlXWUpMUTYvWEJQMmxZR0owTm5rMDZQ'
    b'dmxYWDhaeDNPdjFNZ3lUTmV1WE9NWmkKc1N4L2dLS29tcHFhK3ByYStPTVAzN3VyK28zWFgr'
    b'TTRybGdzY2h4MzZ0U2I2MWMwZkxUV0RZb2llN2V0T25QMEFFM1RMcGZycGpzKwpoYU5LLzlt'
    b'elRwUFpGb3lSN2MzTFpYYWJ6YmFja09aNTN1ZnpRUWhwV3IxaFhmZjVtZmk3RmxGQWJnRkYw'
    b'ZW1zdVg5ZVcwMzdOM1RnCkZUYXlvWm96NlFITDQra01Rd25IVzQxUFNUSW5TYnlTZjEyTVA4'
    b'cEZIb2E1VjlqMGNFdXRDSVhRN2w3bHFqNFJRNEZhQmQ4NEIwYm0KWUdzTkppbll1ZncxL3Fr'
    b'QkZFVlZ6dlpFT3Y5SFF5c0szTjdUbElrSGdzR2dLSW9HZzBHU0pBaWh3V0JnR0FaQkVIZFZs'
    b'WHZTaTFZNApYam5mNzNLNTl0OTRTelFTWWxsV3JWYmJhbGRPK2NJZkZWOEFSWkZ2ZmVieTU1'
    b'LzRNYy96ZXIzZTcvZEhZa25FdFM1eDdKaTN5OVdRCnpSdEhwdEllcDlGb0RJVkNpcUl3RERN'
    b'N080dWlLSTdqUE04ZlAvQmJxMmw5TWxQNEk3UDFGZHBGU1Vxbk00S2dUU0syeDJkMlArVkYK'
    b'bnZyWWtjY09tcCtiUUJFRUFjRDduNS9WQVBBSENVY0VCVkNDa3FnUXFCcEYxQnl2NEpMMDVY'
    b'M0tHd3Yxci9tUXRHZ3h1TEYwS2xYZgowQkNSMzZWTFpuZGYxNjhlZXBDaUtJSWdXSmIxZXIx'
    b'V3F6V2RUaSs3bHh6SE9XWVhjUXdid1FFQUlLcGVqUkZVTXBuRWNUd2VqNjhvCmpGKzFxZVBs'
    b'TjhjL0VteStjZStlcHgvNWNUYWJwU2hLVVJRTXd6SnhQK215eFdLeFVDaEVOZFdhWXltTkRQ'
    b'MSsvL0oyTnpvNmFyUFoKRkVVcGxVcTVYTTVtc3htMDZqOWxReURLNHVKaWE4Y0tHQ3NpbEo1'
    b'SDlMd0VseEw0clp0THowZzZMMEZ0VU1GdUsxNWdsQmNUVWdySAp1bEQ1YXBlU0xDb3Y1L0VR'
    b'eEpyVnluNjlCQW4wOFFBU1JiQ3ZXOUlxQ3IrUVhnMFFCS0pwVXlSWVo3TWRPM3IwaHZ0M3pT'
    b'ejhjWjdmCmF0UXVsMnR4SE5kb05DekxUazlQVzYxV3M5bWNUQ2FOR0o1RmtXUmRWU1RnRDRm'
    b'RERYWGs1TWdGUlZFb2lpSko4c1R4WTZ2WEZDN3IKWGZINm1Za1ArYnpaczZucmpSY2VZUmlH'
    b'WlZsRlVVUlJMQmFMQUtlWEltbWRUaGVQeDZ0a29FcGxzb3EwZk9Rc0xDendQSzhvU2lhVAow'
    b'ZWwweTRGRlBGMzRVOHV2WFFoY3ZtZVAyclZDVWVKQWtRRUFianA0Y3BoSEVOQ21sMXdpZUhn'
    b'UC9ybGVaS3VGdjB6aUNFSCs2UmJzCmlpWkNrK0wzRVFJbUtsOXJnTGV1VVdHaDB1V1EwL0hp'
    b'bmdhbHMwYTZ2dms4Z0FyRTVKVHUvT3AxbTlhdDczM2ozUHlmRGgxTDVkVnEKTllJZ2FyVzZV'
    b'Q2lvMVdwSmt2TDUvSEtjUU9xMDFrVGFSR3VTeWFSV3ExMElKV1JaS1pWS2lxSUlncUFveXZq'
    b'WW1CdGRxbktZUCtSMQowK0dtWHprZDUzbGVvOUVzNXdvOUhrOEdjWndlbk4zYXV3RkxaNVN4'
    b'NmZDS0ZpR2JXZDdORW9tRTNXNnZxYW16MmdxaFlOQnV0K01FCndXUzRkNjJjeHRUMjR1eXdn'
    b'aVlSM295cXpZR1MrNWtGMDMyRmd4b280emh5OEN5TFNmQS9EdWVMSklZMnEvL2hGeW11S01z'
    b'S1ZDeUsKeWtNZFBNbjh5czlEQ1BKR3NxWVN5VExJajE0MmxTQU9FQVVSTVVXVC91M1pzSmJ1'
    b'U2lleTcxcmR3RERNWnJPRncyRzlYbzhnQ0lJZwprdlRXN2djSllxRFN1ckoveUtUVDFiWjJ2'
    b'cjdBV3R6Tk9INUtFQVMxV2kyS29paUtnd01YOWx4NXp5K2ZQZkZocnB0U0pzUnhIRTNUCnNp'
    b'eExrdVNwcnZhczNYZHFaRkZXbElyT25icElZcW0xTHBsT2FiWGFlRHhPa3RRTm4zM1F0ZUh1'
    b'SWJiaGlscyt4M0VjQUNEZzk5L2UKYS9qa2RYME5Ic2NmbUlhUUtYRnlLUWhCR2lDOHJCNEVB'
    b'TFk3b3JFTWpDd0lITXYxTDBsdkRyRHpmb0dxbzNrTWRUYlRGWGE4dTBNdApWTk1NaWhZQVVt'
    b'SEhOVFJDdXRXU0FrZ2NIbGpvZnNXN1dpRnpVSnNEQlRMSHBTS0psSUlzL2Y2WVdscDErYWF1'
    b'bmUyYTVUT2Y1L25OCk4zMnhZc05kRDN6dGUrdlg5M0ljdDF4TnlQUGNPYnQrbFlnVTZCWUF3'
    b'RmdZZnVhQnI1UktKWTdqQ0lMUWFyV3BWRXFMc2grbW40YWkKU0JXVmlrUWlDSUtJb3JoNTYy'
    b'Vm5rL2JCNmVCeWVyOGtLaHlleXVTeU9JNHZWOW9iTjE3L3d2SHBWTFlJQUZqVlhIWGh6VmR0'
    b'TnBzawpTZk96VTZkZmY5Nmd4SGV0Y2JkMGRFNzVZc3RwQnBsYlFtbE1Sb0tvSHBYU2ZneDMz'
    b'dFkyT0RKVHVtNDFrcy9MNnp1MU4vUnBOcStsClV6bGxHQkozTldPZjNLT3JyU0ptT1hTU1Fl'
    b'NXJSeTliclc2dUpjTXA4VllINHczSU42K1BzQVhHbTNFb3Rsa1EwcU5BcjlnV0VVbU4KeUFZ'
    b'QXdQNGRLOVpWOGtSdWV1elV5ek9UWXhxTmhpQ0lSQ0xSMHIzcitQbnBDek54d3RxNHVkTTFP'
    b'RGhvTkJveERCc2FIMi9aZWRuaAo4VHdBSUJCTm41dU8zWEhueDhSY09KZkxMYmRMMnN6YWtZ'
    b'RHc0YkNwZEpodXVyeEhLVVFXRm55S291QTRYcmRxKytteGQ3b0E3OW03ClpucjBMSVpoeTA3'
    b'QnRiZmMvZVFiNzJ6dWM4SFUxZnV1TTd2YmFwcTYzQjQzVGVIejgzUHo4M1BCNmZPMzNIVEQw'
    b'R3dFQUlEaVJ0azAKRHpBVzBTZ1lXUWNsekVhSjEvUVVFQUFPUjBpL2pNY3k4bUFTSG1lSUhJ'
    b'b09oWldEcDRwUFQ0RUJBWmN3WkQ0TVR2dXhRd3ZJTUl0OAp2SWwvNUJWQlEwcEhsdHF6dkFx'
    b'Q09DTG9GVElLYUI3TE5DTW85c1U3dGp6M3kyOU9UWTR2TEN5WVRLYTFQZXZybWpwY25ycmV6'
    b'VHRmCjdsOVliZ1BLRmRpbXRrNWF5Zmw4UGdCQU5wdmxlRTR4MUhPOENBQVFSUG5jK09JVnZm'
    b'VmpveU1rU2JJc3UycjFXbFRqQ01Vekh6UWIKbDgzNHhkczNuVDMwVkgvL21WUXF0YmE3cDNQ'
    b'VE5ZKytPcjZjbkVVUTVBdTM5aDU1OFZFSVlTUVNzVHVjOTMvK0t5VmU3SitLL1Y1MQpSNXhj'
    b'aU0vNFV4T0w2Y2tRRnhHTXUvYnNXOU5lZS9MRVVVTEs3ZHk1ZldRMkJCQVVjQ2cwUkFFcUlV'
    b'Q0xJdm9HbzlKdWovL2JTOEk5CmZlRGxCZlFRVlB0aVVwTEU5VkMrVTVkdlVndnRaaUhKd2dS'
    b'QmlveXdRR0U4cHR5cXp5Y0NZb21IUnJ2ajFZVXUyVFJBUnp4Q0tZSG8KRUR5M0dpREVsKy9h'
    b'ZHVyQUV6TXpNK3ZXOSs2NThaN3BvdjNjQWo4YUtJMzYyWUg1ek8vM1o0M1BoM2RkZmdVbFpa'
    b'YnpiR05qWTUrKwo4N3BoWC9idC9qUkZiZHQzMmRyeDBaRlVLcFhMWmt4bzlxdWZ2NmQvYk9u'
    b'OWxVZmZKNXNpeXgwNk0rdHBYcDMwWG1ocWJsNEE3U2VHCmw5N09tanV0aHZUa0laWmxFNG5F'
    b'Mm5VYnA0VUdtOFdrSjhTVEUrL2UxbTBsNG4wZVg0djJaSGZWbUtRUWlXVGVOemxBT1pwejVD'
    b'aUMKWVZCa2xGUUI4WWdLQ1BrQ2JUYU4xR2pMUDM1UStQb3U2TW55ZDFXWHJIbkpLU2gzZEFt'
    b'ZFZjQ3RnMDVjMFdURmI2OHRvZDdpdlkyOApWcFNlUEN4Ky9ST3FBMU4xczBrelpacThmbXd4'
    b'S0dEckJQc2lTZXpxNnpuMCtEL2xNc2sxSzV0NHJmM1Yvc1ZNOGYvVkNDZ3BjRk5uCmhjdlRN'
    b'RFJ3enVQeEhEN3c0ajAzN3g3dzVaZXZQWkxJbnAvTDNYemovdW1oVTVJa2VkYmY5S01uaitT'
    b'WjBvZHczcGdOMm8xOWZSY2kKZERUNUI5NU9pUlAxWWlBWURQWnQzWGwwa2M0V1dFK2xvOGFN'
    b'SEJuNTQwaWlSaGU2ZTgyRisvb205M1NtSks2WXpHUFZWZlNtRlhpagpNMTluU1EvT3Q4bjZB'
    b'TFRrWUVwQURBU2l3NlJBZkN5eGJtZDdxdEpZZXVLUXdCWWtTWVpXVWdKNTdsY3ZDeFZXOU55'
    b'a1BEQXFyblhLCjZSekVST1hvZVNtV1ZtNi9uUHJGbVk1RC9ncEZnb0l1UFk1MklnUlcwa1R6'
    b'dUs3VlFleG9YcnAxUzJ4clczUjczZXhudHN5dmRBWUoKV0ZyS0dDVDRMazdzMXU1V0Rjcisv'
    b'TFhRN2Z2M0RKNDlZYlZhSXlFL2FXMTVHNENpd01IcDhPMjMzNzV6UzgrTHB4WnlmMFpCNGM5'
    b'aQpFMDFtUitZVGY1cmFneERXRzdsU3FXVHR1SHhxSVFvQUlBaThvNUk4TzVkN08yK0dRZjYy'
    b'emd2L2RQMVVKbDJBQVB6MGtPM2hzVzJICmZlMUh2TFVIcG12T0JpbzMxUVdyZGNueHBUV0FB'
    b'VWlEREJnZW9BaUk0Z0JURGVXUUhqZTFxWTF2cjBVZ0JEZ0dBQUI2R3VFRU1PcVYKTytzd0hF'
    b'TXdERkFFMHR1Qk43cUpaNlpXSFZsb2tWMWp0b2pBNWdFa2ltSnpwaWcyT2tudGwvc081Qmp1'
    b'eVhOMXo0eTNIaHh6VGkyQgpla3V5MnhOdk4va2dRUDA1TXdCLzBBKzhwN2NCUW5CcVBETGtU'
    b'ZTNmMlRONC9vd2dDTHp1clZQbjdjc2ZtQW9jR1E2WE9BSCtHU1c0CmkxV1QxdXYxc2l5ajZG'
    b'djJmWUU0M21melZGaW52Q0VBZ0JZdi90Mk9zMWV0eW1RS3NMMFduZlJqUnhPYkljQUFBRllp'
    b'Z1JORWxEWCsKOE1UYUgxNTU4Tm5KOXBMWUFHZGNzbjVCNFFLSVUwUXlXQnBML3VONXQwcDAz'
    b'N3dpWDJ2TjE1aHlqWTVTSWdzaktlWHlkWGlKQnpVdQp0Q1NnLzNLODdxY1hxaEtjQWFBRVZD'
    b'ZWdrcnMySERwUGFFY3FiR0JwSFlMUUg5OXljblFCL0tCL093L1Z5L05jQ3RTa0M4Yy9lMWxV'
    b'ClF3aGZ1MkwwUWlENjRHdmRlZUdkYjd2WjlOUmdrRjFlSDBNeGxkbHNsbVdaNGQrOVovalA3'
    b'Sk8rS0d3MGFxcXBzWEYwWkFUQ3QxYkoKMXJVTnZDQlYyQXhUM2xCRmZ2RnoxMCt2cXl2a0dE'
    b'QXdJMjlaaVF1U1hFL1BMN0oxRDJ3OHZic2puc3pDYng5c0dNbXZ4bFMwa1N5VwpPSTNpbmdh'
    b'cUxNaEF5TE03cW81YkxPanpGWUNkUXg0SnE5R3hGbFN5WVhMZW9CWmJiQmw1R0J1TFdtUVpR'
    b'WWdVSzlrUmdHRzZzYzArCjZVaXJGbVJzVDdoYXJrbU9oa2tseG1ad0RWV3RqVDA5MmlwQ1ls'
    b'ZjFpRVlsdnpaZlY1U05MTFNrODVGZFBYaW1BTGMweG1zc1I3LzAKZlBkU3dmNVdZMWZFdTVS'
    b'K2F5bE1la005VlZXaFlORHRzc3dzUkM2TkhpaGFUUzA3bzJzOEpJRmpBSUNPT2xkbmU2c0to'
    b'enZpbzcrTgpEdW1lVmJ4aFBKT0hsVFowSVU3ODVHaFRSSEQzVmZ1dTdVNUVzNmpEakRUYmN6'
    b'WXlyc2FFT0c4QlVJRklHcG10d1l0ZEdOSkFxb2srCmozSzlrSFMzQ0pEbDVjcEJXVGNwWTVx'
    b'MFlEa2Rhamdicm1VZ3pucThqS1VBc0t4VWNScm1ORmcyWXByd1FTVEpkTTM4WmlzZFYxa3cK'
    b'VFNVQ1JUMHQ4ekxaNXhpNnQyL216cDc1bjExL1VvUG1TRDdVMTRVZkdaQ01XaVFRaDA0ZCsv'
    b'QWRwMXJWVTdoVXdsQzBvYlo2MDZxRwp0NDhXVVJRNWpxdXZzbDBhdlJ3MFZycWo4eVJsYmx6'
    b'MGhTNmNPNzF6ejVXVHZwaWFWbFU2TE9GWGY3QXY0WFh5S0pjWHhtZUk3L3BXCjVYbkNxZWQ4'
    b'YWRORXNtcFRqVjhXK09tNFZZUGxERnIwMnBYQlg1NXFXc3JiQVlKQUpZZko3WWlpUjNqamJG'
    b'UTlYaWhVMFVJM3pyRUMKSDQzTGtNaENPb0Z3UmdTb0lKS1hQUU13eWVNTXBrY1htRGdMVGFC'
    b'RUk1Mkt0S2h6SUFrN25sdUJLR1lBQUVUd0huZTR3UmpSNHhtegpWcGtNa0pzN3hOa2dQSjFZ'
    b'Yyt4c3Vxc2VGbGw1WUo2SXBwU0pFY08rL3REZWJIQUpnTHNmdU52ajBELzI4bmtBUUV0ZFJZ'
    b'V2FpY1VpCmJVM1djVC8vUnlmVFI1R05ReFgvMHM3SmhTQnpmalJEcVZRR1VtUzRiTFAyYkN2'
    b'NnhDMjdFcG9lMk8rVDV4TktMYXQwRmRpSDJSWFAKelhmT3BoMEFnQXB0cXRXUitzNnhiaG5n'
    b'NFJ6OTJQbkc4VlR0VzBZNU5ZS3FBQUFJaWdHU3lwUGttQ2lkeGFtNFhvMW9NQUFBVUlreQpD'
    b'QUJlVU14elNpb0hHV2lOQ2Z0QzByaDFNMEtnZVJwWnNPZ1Fta0tBR3ZBYUJIbHJKNStONlM1'
    b'ckN2UzJTQTR6OXNNM212WjBaVTdQCmFtWnl0YlZPaUtESXowOTNIQSswbHM3a1cwZVRVNkxV'
    b'U0tQMGF2YkV5S3lmcy9hUExRSUFQcjEzNVV2UFBiV3FRZjdpN3JPQm1Pek4KT2ovNmZUYXd4'
    b'ejd4dDd1blRGcjAyQ2hCRXVDcWRVSTZEelVxSU1xb25vYjVBdnpkQTBxdmpMOHBpODJVNFVI'
    b'SFNyL1dCUURRNE13Mwp0cisya0xFOE1yRENvMDNPWlJ4dWJTekJXeGpGQUFDd01ORzFiSklR'
    b'MlZFTDA5Wk1FTGlhazBoZVF1ZmlaTENFQWpVdmx5SkF3NEs4CkJpTWFFRDBMZFVXQUNpQmxR'
    b'WmthQktYK3E3a1NvRlJuaUllS2hsV3V5RU8zVGx6M2s1VUxwYmUyTEFRcTE0ZjZtL0tCQ2dT'
    b'bFBjRHgKU2FUQ0F3QUVUNXlwK08xZ3RiMW1ZM0xndHh4WGt2bjBrUjhxbjN1cTg5aFM4eVhR'
    b'QTdXdjd2UTlXNE1RZ3VHQVRvUHpMcE9nVm1FSApSMHg5aldtRmwrWFhrZHBCNGpGSnZBc25m'
    b'aVZ5YlRqNW9xM3JsTGtSQUZDbFRkNjVlcmpOa1lsbG9MdENNK2pGMnlzTC9xUmFsS0ZECksy'
    b'U2ZVMjlkNGpnVStlY21ZOER1N0tzTjNMa2xCd0FZOUZFdm5EY2RYbWdyS3FRQ0oxdHR5djUy'
    b'dGtKZm1GakNWUlJxMEdIcGt1YkUKTWVyYUpJdEkvQ0JLSGpSNFVMMnhRbGRZVngwMVVDeU9v'
    b'NzZFNmd0WEJIOTUxUG52VTczTFd4TXFDOWNIVDdtWnVBQmhBMEZwMTR2ZAo5NkRmZmM1NGRY'
    b'ZXVzUklDQUU1TVcyWURGRVdDanFxTXc4anUvOVZ1RHVndkFUWUFRaHdXVVNpaEtQTDVMUmVT'
    b'SmVPTDQ5V054bGloCmlGMDNNcXZtZVNlQy9rNVhOU21XcWd2aFd3aEtBR0JDWC9Xb3FUR3R0'
    b'Z0FBcXZXSmRwdGZoK1NaVE5HbUF4Q0JvejZKMUtvWjBmeUoKNmN4NnFUU3FTSzlxSFpsZTYv'
    b'VXJmWnZhdU9GNWFEZkNERWMvOEd6dmF0ZlNnL3Q5aTFHbHlvNmVtdFU5UDJDZlRSalhvSUh1'
    b'MGJnZQpRaTJ0RHQ0TTI2dExzZ0lsR2FBb01Pc1FrdzQ1T1dkOGNianFkTGhaQVNnQW9LSVky'
    b'UnNiUnJsY0hrSWJiUjZtakRjWC9ISUxmRE91Cm5iQlhWZGJJZDI5YXFqU0xydzZwSyszVVlv'
    b'ajdTZi82QXZ5ZmR3YyttTjVCdVB3dzNobnEzMXNNQVFBRUNMOWxhaGkzZGJhR3ovK28KRkRz'
    b'Z2xIb3d2SUFnWHRvMnJqS0hTSzFLRWJ1S3NkdTRwQXJDQW9MK2piVnowbFFIQUxDeXlhK0h6'
    b'MFFGOWtxYy9MbU8zbnhmZGk1dAovZmJ4YlMybXdNOXVIWHpvQmZ6dmJoWWZPMjQ2RTZ5OXJH'
    b'bnBxcTc0N3dhTi9hK1liNHd2ek11U0J5TWZjcTd1eVMvdHB2SmhQY2pnCldGVENpMXJibEdT'
    b'WWx5c0FnQ3F4VkNNVXV2T0JtbUtFaGJJTUFhUnRQM2QxYjRzTjNsVktsUUJNQWVERVZaOTFi'
    b'eTVRdEZzVHFkQVgKejBSYUw0M2V3ZitTakNSNE10NXRZdUVhTnY0Tlk4TXRiR3lyeU93dHBT'
    b'YWdQRlcxN3EvaUUzK1Q4OVZCK1NWSnFDckcycGo0b2lMdgp4c2xscDJjY3hiOW5hcDR4MVMy'
    b'YlN0TFdiem5YM2g4NmUxSVcrbktGbWVmdzF5VVRJRkdOR2xBNE5CSjVIS1VPVE5Vc3NEVkZG'
    b'aUpzCkl2bzZ2Q0xtblZhVVZUajFROGRLdjdFbVlIRG5FaFAzQnhaMWdEc3FpVkdZN2tJUUxV'
    b'QkVGSlVWbVFUSWFWbnN3Z2thUVFjMGpoZWMKcTIvS3pON1BaeVl4NmdSdCtYZjd5bHVpQTUr'
    b'UFhQaG5TOU1TY0M4eEYvZStmVkE5dDFCeHNna1dJL0lxTTRCS2JTRzBtbzBkMFZSbQpkQzRB'
    b'Z0xZWTNaNWJXRk9JOUNMZ2tDd0NBSzdIU1FXQVJ5bmpiNnh0Ulkzamo0eFZGQ05makE1Q2tU'
    b'MGdDWjhqNmFkbzYxeXR1dEs4CkdGSHFWbGw5cC8zVlV0UzF2aERjemtRbkpKNEFRSU1TdjdH'
    b'MmpWcGIza2xibEpKcmtyUE5iS0paRVJZVUdRTWdCQlUzaXRVZ2FBSEEKV1VMN3B0N2p0Ylhw'
    b'aEVKdjFqZW9jU1kxRG9Bc3g0TFF5Q1R6YXBPQ1h2VEhHdmtRM3ljTkpRN0IzL2x0WjRMTHQr'
    b'VVhhMFFXS0ZJVwpWNCtyakNtREI2RHYvdDF6SFplN090emZ3dVdhVWV4eGlmODRRWjBGR0ll'
    b'cnpFRFdpQ1ViQUFjazRXOUlkYjhzWlFuNkYvYXVxTjc5CkxoT1FCV01oVWl2bUhTTEh5aUxF'
    b'cVFKT2VnbGRVZThHS1BiN3UvR0hJdVRTZmRjM2xNWE8yTWlWaGFCWkVUWml4QStGa2cxQjkr'
    b'TGsKY1ZuY2k1TW5aZEdERVErcmJTZnNIVHhsdkJRdkVMblUzOE9POHJtdTdOTHFVcnl1bExN'
    b'aVNnT0NqVU1ZSU5TRGxIbEFWNWszdUMvZApTN3ZrMmJ3amtWWHhPWUNnUElKQmxlay9ONlZM'
    b'V0RqNGl4RkJjd1FOL29KVWZvOUhtVTFaWlRabE5tV1YyWlRabEZWbVUxYVpUWmxOCldXVTJa'
    b'VFpsbGRtVVZXWlRabE5XbVUyWlRWbGxObVdWMlpUWmxIV3g5SDhCOFV0NTl1Rk9rdGNBQUFB'
    b'bGRFVllkR1JoZEdVNlkzSmwKWVhSbEFESXdNak10TURJdE1qWlVNVGc2TURZNk5UQXJNREE2'
    b'TURCRUQzaFlBQUFBSlhSRldIUmtZWFJsT20xdlpHbG1lUUF5TURJegpMVEF5TFRJMlZERTRP'
    b'akEyT2pVd0t6QXdPakF3TlZMQTVBQUFBQUJKUlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJp'
    b'bWFnZTEyNDE1IiAvPgogIDwvZz4KPC9zdmc+Cg==', 'US_PA')

US_PA = b64_US_PA
index.append("US_PA")
index.append("United States of America Pennsylvania")
catalog["US_PA"] = US_PA
catalog["United States of America Pennsylvania"] = US_PA
country["United States of America Pennsylvania"] = ('US_PA', '', 1)
lookup["US_PA"] = ('US_PA', '', 'United States of America Pennsylvania', 1)
lookup["Harrisburg United States of America Pennsylvania"] = ('US_PA', '', 'United States of America Pennsylvania', 1)
lookup["United States of America Pennsylvania"] = ('US_PA', '', 'United States of America Pennsylvania', 1)
details["US_PA"] = {"continent":"Americas","capital":"Harrisburg","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_PA"] = ('US_PA', 'United States of America Pennsylvania', 1)
regional["United States of America Pennsylvania"] = ('US_PA', 'United States of America Pennsylvania', 1)
#----------------------------------------------------------------------
b64_US_PR = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxMjc2NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1B1ZXJ0b19SaWNvLnN2Zy5wbmciCiAgIHhtbG5zOmlu'
    b'a3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgog'
    b'ICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQv'
    b'c29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5'
    b'L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5z'
    b'OnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRl'
    b'ZnMxMjc3MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzEy'
    b'NzY5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2'
    b'NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0i'
    b'MiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2Vj'
    b'aGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVy'
    b'IgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzEyNzczIj4KICAgIDxp'
    b'bWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJl'
    b'c2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6'
    b'b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFz'
    b'ZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FNQUFBQlRoVG5DQUFBQUJH'
    b'ZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRB'
    b'QUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQ09sQk1WRVUvTzdER0RTanVBQUFBVVBBRgpUdXRm'
    b'TUpEYkJoTVJTdCtHSTJqckFRTW1ROG1zRmtOSE9Lak9DeUFHVHVwbkxZamlCQXdZU05pUElH'
    b'RHNBUUl4UUwrNEVqY0JVTzlQCk5hRFNDUndKVGVkM0tIam5Bd2diUjlXV0hWZzlQTFBDRHl3'
    b'Q1QrNVhNNWpaQnhVUFMrRi9KWERvQWdZalJNeW9HRWZIRFNqZ0JRNFMKU3Q0dVFjSzBFenJQ'
    b'Q2g4SlZ2RjNvdmZ5OXY3Ly8vOGJZL0todnZuKy92ODFkUFBHMlB3QlVmQmRrUFhuNy80TFdQ'
    b'Ri9wL2YzK3Y4awphZktxeGZwQ2ZmVFIzL3dFVS9CbWx2YnE4ZjRSWFBHUXMvajcvUDhuYS9L'
    b'MXpQdEVmL1RXNC8wRlUvQnVtL2J4OWY0VVh2SDgvZjhpClovSURVdkF5Y3ZQQzFmdUVxL2cv'
    b'ZS9STWhQVGY2ZjJTdFBrS1YvSHo5LzRxYmZMazdQMGNZL0o5cHZjNGR2TTJkZlBIMmZ6UTMv'
    b'eUwKci9nQ1VmRG83LzRoWi9MNCt2OTJvZmNqUk0yZkcxREoydnlGcS9nL083SEZEaW5aNWYw'
    b'RVQreHduZmNzYnZQcUFRUWVaZkxGMS93bApROHFyRjBUYjV2MjgwZnNhWXZJT1d2R2t3ZnFB'
    b'cVBqaEJBMWVrZlk2ZVBNWFNOak8zZndRVy9Fd1FNQzNFemo5L3YvUkNoMUZmL1RtCjd2N00z'
    b'UHdsYWZJWllmRzcwUHVNc1BnR1ZQQmNqL1d2eVBwc212YjErUDYvMC90Vml2VVdYL0dudy9x'
    b'bXd2ck4zZnhsbGZZSVZmQzQKenZ0UGh2WDYvUDhTWFBHaXYvcVJ0UGxma2ZidTgvN3A4UDVL'
    b'Zy9Sdm5QZjUrLyt5eXZvTVdQRklnZlEwZFBQYTV2Mlh1UGtOV2ZGWQpqUFUzZHZQSTJmd2da'
    b'dkxnNnYzRDF2dmM1LzIyemZ2UzRQelFDaDRRUytERERpc0tUZVpGT2FyS0RDV0ZhMWdlQUFB'
    b'QUFXSkxSMFF4CjJkc2RjZ0FBQUFkMFNVMUZCK2NJR1FjckRrNXpGS1VBQUFNRlNVUkJWR2pl'
    b'N2R0blZ4TkJGQWJneUl1Q0NzU0NnQTE3VjhncW1OaEEKVUVDSUFrWk5iTEdCWXU4ZEVSdFdz'
    b'SXRkc2ZmZTIzOHp6Wk9BWm5keVpIYmZuSlA3SlNmWkw4L0p6dDY5TTNQSFpPb1FSeGdteEhm'
    b'cwp4TWdDRWhJN003S0FMbDBwV1VCU01pVUxLZVp1akN5Z2U0K2VqQ3dndFJjbEMybnBHWXdz'
    b'b0hlZnZvd3NvRjkvU2hhUU9ZQ1NoWUdECkJqT3lnQ0ZEaHpHeWdPRWpLRm1BYVNRbEMvSG1V'
    b'WXdzWUxSUkpZODZDeGd6bHBMbEtYbkdVYktRbFcxUjlBNEJGakIrUWc0akM4aWQKU01tQzFU'
    b'YUprUVZNbmpLVmtRVk15Nk5rQWZuVEtWa29LSnpCeUFKbUZoVXpzb0NTV1pRc29MU01rZ1g3'
    b'N0RtTUxLQzhxTUl3VnVWYwpsWXVPZVVheDVpOVEvY2VjTG1OWVpRdlY3K1NpN01VR3NKWW9T'
    b'NjBhUTh3dHFlUlJZeTFUbE9XYVkzL0ZTcjFacXhTbFN2dVpyTGF0CjFwVzF4blBaWlJVcWVX'
    b'cDBaSzMxWG5jSVpiRjE2L1diWW16d3NqWUtwdGRObTNWaXVYM1AyQmJSdEwrMVhYY2R3ck8y'
    b'K2UveWR1SDMKVVVMaURrbXNuWlhCMk9WblZZWDhWSzRCMjcxSERpdDNyOXJqc1crLzloUThX'
    b'Y3BOckQwUUZsVmNWeTF3SjFQTUI2V01yZm93cnpuWApJY0VoZHJnOWRoMytIdklsUi82bHlq'
    b'c3FYb3NkYTVEeEpOcnJqcmRGV1FvanFoSFQway9JU0JBblQ3VlduVDZEQ0ZrWlV2SldZMU1J'
    b'Ckt1ZnN1Y2hVcVEyeTB1bjVVSlk3SXBTa0llK0xDNkgzOEdJRUtGa0p3bDhOWHdwbFhSWlhT'
    b'VXFuZ2JqU2FzUlhOQXVpWkwxOC9zUlYKditmYWRmL25EWU5mMVlHNDZWdkR0ZGhRNEU5aHR6'
    b'Z0ttOXZCWkZYcVRXRjM3bEtVZ1MyZXJIQXZrS3lhdmVzejl4bUtadnNENWVHago0R0x1NHlm'
    b'S1UxWFVNMzJtR00rVnBzYlE3eTllMXRRU1RNaGV0YTJzWHJlOENhdDYrMDZ2NmV0N29aOE1t'
    b'K3hyaGpGTEkxcmgvRUMzCkdnZzRQc1lXS2FONVNkZjVpWEc3NEhOc2N5V2F0Nkx5djhTMk9h'
    b'TjRVNWh6QzUyeTRZQ3lQU05MV3ZueVA2eWtyN0ZHcVNodUsrTnMKd3FOc1dhUnM4UHpHMkE3'
    b'TDJUeWMrVDNXbUM3RytzSFl4czk1NklIeWlBamxnUnJPNDBlR2RDNXJzU2lQdGxFZUJPUThO'
    b'dm56Vnh4aAovQWFOQU90U09TU0JqZ0FBQUNWMFJWaDBaR0YwWlRwamNtVmhkR1VBTWpBeU15'
    b'MHdPQzB5TlZRd056bzBNem94TkNzd01Eb3dNSXhZCmNiSUFBQUFsZEVWWWRHUmhkR1U2Ylc5'
    b'a2FXWjVBREl3TWpNdE1EZ3RNalZVTURjNk5ETTZNVFFyTURBNk1ERDlCY2tPQUFBQUFFbEYK'
    b'VGtTdVFtQ0MKIgogICAgICAgaWQ9ImltYWdlMTI3NzUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_PR')

US_PR = b64_US_PR
index.append("US_PR")
index.append("United States of America Puerto Rico")
catalog["US_PR"] = US_PR
catalog["United States of America Puerto Rico"] = US_PR
country["United States of America Puerto Rico"] = ('US_PR', '', 1)
lookup["US_PR"] = ('US_PR', '', 'United States of America Puerto Rico', 1)
lookup["San Juan United States of America Puerto Rico"] = ('US_PR', '', 'United States of America Puerto Rico', 1)
lookup["United States of America Puerto Rico"] = ('US_PR', '', 'United States of America Puerto Rico', 1)
details["US_PR"] = {"continent":"Americas","capital":"San Juan","currency":"","web":"","lang":"","tz":"-04:00","altname":""}
regional["US_PR"] = ('US_PR', 'United States of America Puerto Rico', 1)
regional["United States of America Puerto Rico"] = ('US_PR', 'United States of America Puerto Rico', 1)
#----------------------------------------------------------------------
b64_US_RI = EmbeddedSvgImage(
    b'PHN2ZyBoZWlnaHQ9IjU4MCIgd2lkdGg9IjY2MCIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cu'
    b'dzMub3JnLzE5OTkveGxpbmsiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+'
    b'CiAgPGRlZnM+CiAgICA8cGF0aCBpZD0iYSIgdHJhbnNmb3JtPSJtYXRyaXgoNDAgMCAwIDQw'
    b'IDAgLTIwNSkiIGQ9Ik0wLTEgLjU4Nzc5LjgwOTAyLS45NTEwNi0uMzA5MDJILjk1MTA2TC0u'
    b'NTg3NzkuODA5MDJ6Ii8+CiAgPC9kZWZzPgogIDxwYXRoIHN0eWxlPSJmaWxsOiNmZmYiIGQ9'
    b'Ik0wIDBoNjYwdjU4MEgweiIvPgogIDxnIHN0eWxlPSJmaWxsOiNmZWM1MDA7c3Ryb2tlLXdp'
    b'ZHRoOjEuNSI+CiAgICA8cGF0aCBzdHlsZT0ic3Ryb2tlOiNmZWM1MDAiIGQ9Ik0zMjUuNzgg'
    b'MTg1LjUycy0xLjA2IDExOC4yMi0xLjA2IDEyNi44MmMwIDguNiAwIDIwLjQyLTkuNSAxOC4y'
    b'Ny05LjQ4LTIuMTUtMjEuMDktMi4xNS0zNy45Ny0xMy45Ny0xNi44Ny0xMS44Mi0xNi44Ny0x'
    b'My45Ny0xNi44Ny0xMy45N2wxNS44Mi01LjM4cy0xNS44Mi0zLjIyLTI2LjM3LTEwLjc0Yy0x'
    b'MC41NS03LjUzLTE4Ljk5LTEzLjk4LTE4Ljk5LTEzLjk4cy0xLjA1IDE2LjEzIDQuMjIgMjcu'
    b'OTVjNS4yOCAxMS44MiAxNS44MiAyMi41NyAxNS44MiAyMi41N3YtMTMuOTdzMTQuNzcgMTMu'
    b'OTcgMjAuMDUgMTcuMmM1LjI3IDMuMjIgMjYuMzcgMTEuODIgMzQuOCAxNy4yIDguNDQgNS4z'
    b'NiAyMy45MDQyOSAyMC40MSAyMy45MDQyOSAyMC40MXMxNi4xODU3MS0xNy4yIDI2LjczNTcx'
    b'LTIxLjVjMTAuNTUtNC4zIDI0LjI2LTEwLjc0IDMwLjU5LTE1LjA0IDYuMzMtNC4zIDIzLjIt'
    b'MjAuNDIgMjMuMi0yMC40MnYxOC4yN3MxMS42LTEzLjk3IDE0Ljc3LTIzLjY1YzMuMTctOS42'
    b'NyA0LjIyLTI2Ljg3IDQuMjItMjYuODdzLTguNDQgNi40NS0xNS44MiA5LjY4Yy03LjM5IDMu'
    b'MjItMjguNDggMTEuODItMjguNDggMTEuODJsMTYuODcgNC4zcy0yNy40MiAyMS41LTM2Ljkx'
    b'IDI1LjhjLTE3LjI4NjQxIDguMzExMTgtMjkuNTQgNi40NC0yOS41NC00LjNzMS4wNi0xMzYu'
    b'NSAxLjA2LTEzNi41em0xLjA1LTM5Ljc3aDcuMzh2MzIuMjRoLTcuMzh6Ii8+CiAgICA8cGF0'
    b'aCBzdHlsZT0ic3Ryb2tlOiNmZmYiIGQ9Ik0yNzQuMSAxNzhzMjkuNTMtNi40NSA1Ni45NS02'
    b'LjQ1IDU1LjkgNi40NCA1NS45IDYuNDR2MTEuODNzLTM3Ljk3IDUuMzctNjAuMTIgNS4zNy01'
    b'Mi43MzgyMi02LjQ1LTUyLjczODIyLTYuNDV6Ii8+CiAgICA8cGF0aCBzdHlsZT0iZmlsbC1y'
    b'dWxlOmV2ZW5vZGQ7c3Ryb2tlOiNmZmYiIGQ9Ik0zNDcuOTE5OTUgMTcyLjA4YzAtNC45LTEu'
    b'ODktOS4zMzI1LTQuOTQ1LTEyLjU0LTEuNTI3NS0xLjYwMzc1LTMuMzQ2MjUtMi45MDEyNS01'
    b'LjM2NTYzLTMuNzk3ODEtMS4wMDk2OC0uNDQ4MjgtLjgzMDc5LS42MTkzNi0xLjkyOTQ2LS44'
    b'NTUzNGwuMDMyMyA2LjE0MjQ2YzEuMzI0MjMuNjUzMTMgMS42MzIyMSAxLjMwMzE5IDIuNjM0'
    b'MSAyLjQ3MDY5IDIuMDAzNzQgMi4zMzUgMy4yNDM3NCA1LjU2IDMuMjQzNzQgOS4xMiAwIDcu'
    b'MTItNC45NiAxMS43MzIxLTExLjA3IDExLjczMjFzLTExLjA3LTQuNjEyMS0xMS4wNy0xMS43'
    b'MzIxYzAtMy41NiAxLjI0LTYuNzg1IDMuMjQzNzUtOS4xMiAxLjAwMTg4LTEuMTY3NSAxLjMw'
    b'OTg3LTEuODE3NTYgMi42MzQwOS0yLjQ3MDY5bC4wMzIzLTYuMTQyNDZjLTEuMDk4NjcuMjM1'
    b'OTgtLjkxOTc4LjQwNzA2LTEuOTI5NDYuODU1MzQtMi4wMTkzOC44OTY1Ni0zLjgzODEzIDIu'
    b'MTk0MDYtNS4zNjU2MyAzLjc5NzgxLTMuMDU1IDMuMjA3NS00Ljk0NSA3LjY0LTQuOTQ1IDEy'
    b'LjU0IDAgOS44IDguMDMxOSAxNy43NCAxNy4zOTk5NSAxNy43NHMxNy4zOTk5NS03Ljk0IDE3'
    b'LjM5OTk1LTE3Ljc0eiIvPgogIDwvZz4KICA8ZyBzdHlsZT0iZmlsbDojMDAzMjcxO3N0cm9r'
    b'ZTojZmZmO3N0cm9rZS1saW5lam9pbjpyb3VuZCI+CiAgICA8cGF0aCBkPSJNMjMyLjM3IDM3'
    b'OC4zN3MxNC4wMSAxMi44IDI3LjcyIDE0LjYyYzEzLjcxIDEuODMgMzUuMyA4LjI3IDM1LjMg'
    b'OC4yN3MuNTcgMTkuNzItLjEgMjEuNDNjLS42NyAxLjcxLTEuMSAyLjE2LTMuMDcgMi4yMy02'
    b'LjM5LjIzLTIxLjk1LjI1LTM4Ljg4LTMuNjktMjIuMTMtNS4xNS00My44NC0xOC40Ny00My44'
    b'NC0xOC40NyA1LjA2LTIuMDggMTcuMy0zLjkxIDI1LjItNS44N3pNNDI3LjYzIDM3OC4zN3Mt'
    b'MTQuMDEgMTIuOC0yNy43MiAxNC42MmMtMTMuNzEgMS44My0zNS4zIDguMjctMzUuMyA4LjI3'
    b'cy0uNTcgMTkuNzIuMSAyMS40M2MuNjcgMS43MSAxLjEgMi4xNiAzLjA3IDIuMjMgNi4zOS4y'
    b'MyAyMS45NS4yNSAzOC44OC0zLjY5IDIyLjEzLTUuMTUgNDMuODQtMTguNDcgNDMuODQtMTgu'
    b'NDctNS4wNi0yLjA4LTE3LjMtMy45MS0yNS4yLTUuODd6Ii8+CiAgICA8cGF0aCBkPSJNMjc3'
    b'LjI2IDQwNy45OWMtMi40NC0uNzYtMy44Ni44My0zLjg2Ljgzdi0zNC4xNnMxLjQ4LTEuMzQg'
    b'NC4wNi0uMjFjOS4xIDMuOTcgMzIuNTYgMTIuMDIgNTIuNTQgMTIuMDIgMTkuOTggMCA0My40'
    b'NC04LjA1IDUyLjU0LTEyLjAyIDIuNTgtMS4xMyA0LjA2LjIgNC4wNi4ydjM0LjE3cy0xLjQy'
    b'LTEuNi0zLjg2LS44M2MtOS43IDMuMDEtMzUuMDYgMTAuNS01Mi43NCAxMC41UzI4Ni45NiA0'
    b'MTEgMjc3LjI2IDQwOHoiLz4KICAgIDxwYXRoIGQ9Ik0zODYuNiA0MDguODJjMS41IDQtMjIu'
    b'MTggNy43LTIxLjg5IDEzLjg3TTI3My40IDQwOC44MmMtMS41IDQgMjIuMTggNy43IDIxLjg5'
    b'IDEzLjg3IiBzdHlsZT0iZmlsbDojMDAzMjcxO3N0cm9rZTojZmZmO3N0cm9rZS1saW5lam9p'
    b'bjpyb3VuZCIvPgogIDwvZz4KICA8ZyB0cmFuc2Zvcm09InRyYW5zbGF0ZSgzMzAgMjkwKSIg'
    b'c3R5bGU9ImZpbGw6I2ZlYzUwMCI+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNhIi8+CiAgICA8'
    b'ZyBpZD0iYiI+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI2EiIHRyYW5zZm9ybT0icm90YXRl'
    b'KDI3LjY5KSIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiNhIiB0cmFuc2Zvcm09InJvdGF0'
    b'ZSg1NS4zOCkiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjYSIgdHJhbnNmb3JtPSJyb3Rh'
    b'dGUoODMuMDgpIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI2EiIHRyYW5zZm9ybT0icm90'
    b'YXRlKDExMC43NykiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjYSIgdHJhbnNmb3JtPSJy'
    b'b3RhdGUoMTM4LjQ2KSIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiNhIiB0cmFuc2Zvcm09'
    b'InJvdGF0ZSgxNjYuMTUpIi8+CiAgICA8L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiNiIiB0'
    b'cmFuc2Zvcm09InNjYWxlKC0xIDEpIi8+CiAgPC9nPgogIDxwYXRoIHN0eWxlPSJmaWxsOiNm'
    b'ZWM1MDAiIGQ9Ik0zNjMuMjQ3NjkgMzg1LjIyMDc5YzUuNjM3NC0xLjUzNDc5IDExLjIyNDA1'
    b'LTMuMjU4NzcgMTYuNzg5MTMtNS4wNDA1Ni4wNzUgMS43MjUuMTM0NDUgMy40NTQ1MS4xNzgz'
    b'NiA1LjE4ODU0LTMuNTM2MTIgMS4wODg2Ny03LjA2ODU1IDIuMTY2NS0xMC42MDU4OSAzLjE5'
    b'NjA4LjAwOSAxLjI3NjM5LjAxNTMgMi41NTM3OS4wMTc3IDMuODMyMiAzLjI5MzAzLS45NDY3'
    b'OCA2LjU4NjM1LTEuOTMwMTcgOS44ODc3LTIuOTE3MjMuMDE4MiAxLjY2MDUzLjAyMyAzLjMy'
    b'NDk2LjAxNDMgNC45OTMzLTMuMzEyNDMuOTU1MDYtNi42MTI4NSAxLjkxNzUyLTkuOTEwMTEg'
    b'Mi44NTA0OS0uMDA4IDEuNTg4ODctLjAyMTcgMy4xNzkzLS4wNDA2IDQuNzcxMjcgMy42NDkx'
    b'OC0xLjAxNjMgNy4zMDE4LTIuMDU5MzIgMTAuOTcxNDMtMy4wNzM1NC0uMDQwNSAxLjg2NTg2'
    b'LS4wOTg4IDMuNzM2OTItLjE3NDk0IDUuNjEzMTUtNS43NDcwOCAxLjUxMzg1LTExLjQ2MDM4'
    b'IDMuMTQ1MjUtMTcuMiA0LjY1MTQuMDg1NC04LjAzODYxLjEwOTc0LTE2LjA2MDMxLjA3Mjkt'
    b'MjQuMDY1MXptLTI1Ljk5NTIgNS4xMjgxNGMzLjYwNTI5LS4zMzE0NyA3LjE5MzM3LS44NzQx'
    b'OSAxMC43NTg1Mi0xLjU1MjMxIDIuMzMzMDMtLjQ0Mzc3IDQuMDY0MTYtLjE5MDg2IDUuMjEy'
    b'OS44MzM5Mi40MTMyOS4zNjQ5NC43NTEzMS44MTQ0IDEuMDE0ODkgMS4zNDk4Mi40NzUzLjk2'
    b'MDAxLjcxMTQxIDIuMTk2NDQuNzA5MSAzLjcxMTgzLS4wMDIgMS40OTE1Ni0uMjQyMjggMi44'
    b'Mzk3LS43MTk3OSA0LjAzOTExLS4yOTU1Ny43NDkxMS0uNjgzMzcgMS40NDA0NC0xLjE2Mzg4'
    b'IDIuMDcxMTQtMS4yMzY3MyAxLjYzMzQzLTMuMTQyNTYgMi43Mjg5Ny01LjcxOTc5IDMuMTg0'
    b'MjYtMS4xNjc4Ny4yMDYzMS0yLjMzOTk2LjM5NjUzLTMuNTE1OTEuNTY4NjEtLjAxMjQgMi45'
    b'NTc2My0uMDM5MSA1LjkxNzE2LS4wODAxIDguODc4NTktMi4xNjA1My4zMDM0Ny00LjMyOTY5'
    b'LjU0MzgzLTYuNTA0NzYuNzEwOTEuMTA2MTEtNy45NDMzNC4xMDkwNS0xNS44NzUzMS4wMDkt'
    b'MjMuNzk1ODh6bTYuNTgzNDcgOS4zNjM4NmMuNTI2NDktLjA3ODcgMS4wNTIyLS4xNjEwMiAx'
    b'LjU3NzEtLjI0NjcyIDEuMjM3OC0uMjAyMSAyLjEwNTc5LS42MDcyMiAyLjYwMzE2LTEuMTg4'
    b'NjIuNDk4MTMtLjU5MzIzLjc0NjQ2LTEuMjc5ODMuNzQ0NzMtMi4wNTI5OC0uMDAyLS43NTIw'
    b'Ni0uMjIwMDEtMS4zNDcyNC0uNjU1Ny0xLjc4ODUtLjQzNjcxLS40NDIzMS0xLjI1MjI4LS41'
    b'NDkxOC0yLjQ1NTcxLS4zNDYxNy0uNjEwNzcuMTAzMDItMS4yMjI0Ni4yMDE1Ni0xLjgzNTA0'
    b'LjI5NTI2LjAxMjMgMS43NzUyMy4wMTk1IDMuNTUxMTQuMDIxNSA1LjMyNzczem0tMzYuOTI5'
    b'My4xMTY5MmMtLjAxOTYtMy45MDA0OS45MTYxMS02LjcxNTM0IDIuODA5NDgtOC41MDM1NiAx'
    b'LjkwMTk3LTEuNzk2MzcgNC41Mzc2MS0yLjM2NDM0IDcuOTQ5MDQtMS44OTYxOCAzLjQ5MDQy'
    b'LjQ3OSA2LjE4OTMgMS43NDMxMSA4LjA5Njg4IDMuOTYxNjUgMS45MDc4MiAyLjIwODAzIDIu'
    b'ODc5NjggNS4xNjg2MiAyLjg4MTMgOC45ODM5OS4wMDEgMi43NjkxOC0uNDI0NTIgNS4wNDAw'
    b'My0xLjI2NTI1IDYuNzkyMjctLjgzMDIzIDEuNzM5OTMtMi4wMzI2OCAzLjA3MTc1LTMuNTk1'
    b'IDMuOTUxMjYtMS41NTI5OS44Njk1NC0zLjQ4NjU3IDEuMTg3MjYtNS43OTg4MS44OTczNS0y'
    b'LjM0NzQzLS4yOTQzMS00LjMwMDI2LTEuMDM1NTktNS44NDU0NC0yLjE1NTU5LTEuNTM4MzUt'
    b'MS4xMjAyNC0yLjc5MzE5LTIuNzE3MzYtMy43NTk1OS00Ljc2NTExLS45NjYzMi0yLjA0NzU1'
    b'LTEuNDU4NjEtNC40Nzg4Mi0xLjQ3MjYxLTcuMjY2MDh6bTYuNDAxOSAxLjI4Mzk0Yy4wMDkg'
    b'Mi40MDAzNy40MTAzMSA0LjE5NDg5IDEuMTk0ODkgNS4zNjQ5OS43OTQwOSAxLjE3MTYzIDEu'
    b'ODY2ODIgMS44NTcwMyAzLjIxNzE2IDIuMDMxNTIgMS4zODg4OC4xNzk0NyAyLjQ2NTM4LS4y'
    b'MTkwNCAzLjIyNjA2LTEuMTY2MzguNzYxMzItLjk0ODE1IDEuMTM5MzEtMi43NTM5NCAxLjEz'
    b'NTYyLTUuNDA1MjctLjAwMy0yLjIzMzQ3LS40MDY0NS0zLjg5NC0xLjIxMTc2LTUuMDAyNC0u'
    b'Nzk1NjUtMS4xMTgxNC0xLjg3NjM0LTEuNzU2OTYtMy4yNDIxMy0xLjk0MTM1LTEuMzA4NDUt'
    b'LjE3NjY0LTIuMzU1ODYuMTgzMDctMy4xNDYwMiAxLjEwNTMtLjc4OTE4LjkyMTEtMS4xODI4'
    b'MSAyLjU4OTE3LTEuMTczODIgNS4wMTM1OXptLTM0LjE4NjEtMjEuMzIzNzNjMi4wNTIyMi43'
    b'MzYyOCA0LjExMzc2IDEuNDQ3NTEgNi4xODQzOSAyLjEzMTIxLS4wNjY0IDIuNzg3OTgtLjEw'
    b'NzY5IDUuNTg2My0uMTIzOSA4LjM5NDk2IDIuMzAzMTYuNzI4OTQgNC42MDgyNiAxLjQzMjg2'
    b'IDYuOTE1MzMgMi4xMDQ5OC0uMDAyLTIuNzkzNi4wMDctNS41ODA0NC4wMjg4LTguMzYwNSAy'
    b'LjA5OTUyLjYyMzMyIDQuMjA4MDEgMS4yMTYxNCA2LjMyNTI4IDEuNzc1OTUtLjAwNCA3Ljk0'
    b'NDYxLjAzODggMTUuOTIxNzQuMTI5MjMgMjMuOTMxNC0yLjEyMDg2LS41NDM1My00LjIzNzIt'
    b'MS4xMTYyMS02LjM0OTQ0LTEuNzA3NzItLjA1My0zLjI1ODMzLS4wOTAzLTYuNTA3NjItLjEx'
    b'MTg5LTkuNzQ3ODUtMi4zMTE1NC0uNjYzOTktNC42MjI5Mi0xLjM1NjQtNi45MzQzNC0yLjA2'
    b'ODAyLjAyMiAzLjI2MzQyLjA3NzUgNi41NDA2Ni4xNjY0OCA5LjgzMTcyLTIuMDk0NTUtLjYx'
    b'NzU2LTQuMTg1NDgtMS4yNDI2NS02LjI3MzE4LTEuODY1MS0uMzQxMjEtOC4yNTU0NS0uMzI2'
    b'NzgtMTYuMzk1NzkuMDQzMy0yNC40MjEwM3oiLz4KPC9zdmc+Cg==', 'US_RI')

US_RI = b64_US_RI
index.append("US_RI")
index.append("United States of America Rhode Island")
catalog["US_RI"] = US_RI
catalog["United States of America Rhode Island"] = US_RI
country["United States of America Rhode Island"] = ('US_RI', '', 1)
lookup["US_RI"] = ('US_RI', '', 'United States of America Rhode Island', 1)
lookup["Providence United States of America Rhode Island"] = ('US_RI', '', 'United States of America Rhode Island', 1)
lookup["United States of America Rhode Island"] = ('US_RI', '', 'United States of America Rhode Island', 1)
details["US_RI"] = {"continent":"Americas","capital":"Providence","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_RI"] = ('US_RI', 'United States of America Rhode Island', 1)
regional["United States of America Rhode Island"] = ('US_RI', 'United States of America Rhode Island', 1)
#----------------------------------------------------------------------
b64_US_SC = EmbeddedSvgImage(
    b'PHN2ZyB3aWR0aD0iNzUwIiBoZWlnaHQ9IjUwMCIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSIgeG1s'
    b'bnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8cmVjdCBzdHlsZT0ib3BhY2l0'
    b'eToxO2ZpbGw6IzA0MWU0MjtmaWxsLXJ1bGU6bm9uemVybztzdHJva2U6bm9uZTtzdHJva2Ut'
    b'd2lkdGg6MTtzdHJva2UtbGluZWNhcDpidXR0O3N0cm9rZS1saW5lam9pbjptaXRlcjtzdHJv'
    b'a2UtbWl0ZXJsaW1pdDo0O3N0cm9rZS1kYXNoYXJyYXk6bm9uZTtzdHJva2UtZGFzaG9mZnNl'
    b'dDowO2ZpbGwtb3BhY2l0eToxIiB4PSItMzc1IiB5PSItMjUwIiByeD0iMCIgcnk9IjAiIHdp'
    b'ZHRoPSI3NTAiIGhlaWdodD0iNTAwIiB0cmFuc2Zvcm09Im1hdHJpeCgxLjAwMDY3IDAgMCAx'
    b'LjAwMSAzNzUuMjUgMjUwLjI1KSIvPgogIDxwYXRoIHN0eWxlPSJzdHJva2U6bm9uZTtzdHJv'
    b'a2Utd2lkdGg6MTtzdHJva2UtZGFzaGFycmF5Om5vbmU7c3Ryb2tlLWxpbmVjYXA6YnV0dDtz'
    b'dHJva2UtZGFzaG9mZnNldDowO3N0cm9rZS1saW5lam9pbjptaXRlcjtzdHJva2UtbWl0ZXJs'
    b'aW1pdDo0O2ZpbGw6I2ZmZjtmaWxsLXJ1bGU6ZXZlbm9kZDtvcGFjaXR5OjEiIGQ9Ik00MS41'
    b'MjAyOTQgOTMuMzQ1NjA0QzIwLjM3MjMyMyAxNjMuODQ3MzIgMTA1LjQwNTgyIDIyMC44MTM3'
    b'NCAxNjMuMzI3ODggMTY5LjY5ODU2YzYwLjc0NDAzLTYzLjc4MTc4LTcuMDQ0MzctMTQ5Ljky'
    b'NzE0NS03Ny40NDA3OTctMTIyLjQyODIwOSA1MS4zNzg1MzctOC44MzQxNDkgODIuMDAzNTI3'
    b'IDUwLjUzMDE1NyA0Ny40NTUyODcgODcuNTcxOTc5LTMzLjM3MDY2MSAzNC4wODg3MS05NC4y'
    b'MjYxMTcgMTEuNjg3NTktOTEuODIyMDc2LTQxLjQ5NjcyNnpNNDEyLjU2MzE2IDg0LjYwNTIx'
    b'MmMtMi42OTUxMyAxLjI1MjczNi00LjY4NTUxIDQuODk4MTcyLTUuODIyNjEgNy43NzUxMjQt'
    b'Mi42OTg1MyA4LjAzMTc0NC01LjQ3MzYxIDE2LjA0NjcyNC04LjE4NTcgMjQuMDY0MjI0LTEu'
    b'NDE1MzcgMy42MDU2MS0yLjc4MTI1IDcuMjc0Mi00LjIwNjg4IDEwLjg1MTUxLTIuNjE2NDUt'
    b'LjM1MjkzIDEuMDMyNDYtNC44MjI5Ni44MzEwOS02LjczNTYuODY0NzctMy45MjYxMSAyLjc4'
    b'NjU2LTcuNzYzOTIgMi45NTEzNy0xMS43NzA2Ni0uNjU3NzUtMy4wMDAzLjA2Njc2LTYuODk0'
    b'MDQtMS40MjI5OC05LjMzNTYwNC0yLjIyMzAyIDUuMTI5NzU0LTUuMDM5NDUgMTAuMDQzNjA0'
    b'LTYuOTUyNiAxNS4yODk0MjQtMS40Mzg3MiA2LjI5NDYyLTMuMzcwMTYgMTIuNDc3MjItNC4x'
    b'NzcxMSAxOC45MDAxNC0uNDgyMTMgMy4zMjQ4OS0xLjA2NjUyIDYuNjAzMzktMi4xNDYzIDku'
    b'NzkxMTQtMi42NjIyNi0uMjQ4NC0xLjk1OTEzLTQuOTQwMTYtMy41MjUwMS02Ljg3NDM4LTEu'
    b'NDIxMDMtNC41MTg3Mi00LjI4MjM1LTguNDI4NTMtNi4zNTAzNS0xMi42NzAyMi0xLjA1Njc0'
    b'LTEuMDUwNTQtMy40ODUxOC04LjQzNjU0LTMuNDQxMzQtNC4zMjA1LS4yMzc2NCAyLjk3Mzk1'
    b'LS40NDIyMyA1Ljk1MDY0LS43MTQzNCA4LjkyMTczLTUuOTE2Ni0xMS4wNTczLTExLjg1MTEy'
    b'LTIyLjEwNTAxLTE3Ljc3NDc0LTMzLjE1ODU1OS40ODIgMy41OTA3MjktLjAxNTAxIDcuNDYx'
    b'MjM5IDEuMjg5ODUgMTAuODUzNjA5IDIuODczMTEgNi4xOTM1NyA1LjQ5ODIzIDEyLjQ5OTAy'
    b'IDguMjQyNDQgMTguNzUtMS40NDQwMyAxLjM2NjU4LTEuNzM0OS0uODkyMDMtMi40NTY0OC0x'
    b'LjgxMDAzLTUuNDczMTItOS42NjMwMS0xMC45NDYyMy0xOS4zMjYwMy0xNi40MTkzNS0yOC45'
    b'ODkwNDktMi4yMTA0OSAxLjU1Mjk3OS0uNjcxMjYgNC40MTU3NDQtLjk1NjExIDYuNjU0ODU5'
    b'LjkwMjcyIDMuMTM5NDIgMi45ODMyMyA1Ljk1MDY0IDQuMzk5OTYgOC45MjQxNSAyLjU5MDI1'
    b'IDQuODQ2MzEgNS4yNTI2MyA5LjY2OTI2IDcuOTEzMTEgMTQuNDY1MDMtMS45MDY4OSAyLjEw'
    b'MTk4LTIuOTQ0NzMtMy44NDk5OC00LjMwOTk4LTUuMTkwODUtNC45NDkzNy04LjU4NTctOS44'
    b'NDcyOS0xNy4yMDI3NC0xNC45NDMzOC0yNS43MDI2MDItMi4yMzI5My43NzE2MzYtMi45MjM2'
    b'NyAyLjQwNzI5Mi0yLjU0ODIzIDQuNTcxMzU0LS4zNjkyOSAyLjE2Nzg1OC41Mjg3MiA0LjAx'
    b'MTk1OCAxLjc4MzA5IDUuNzU0MzI4IDMuODI5MzkgNi42Mjc4MSA3LjY5NDc4IDEzLjIzNDc5'
    b'IDExLjU1NTgzIDE5Ljg0NDItMS4zMDg0MSAxLjUxOS0xLjcwODMtLjY5OTYyLTIuNDcwNjIt'
    b'MS41ODc3NS02LjIxMjk1LTkuODMxNDktMTIuNDI1OTEtMTkuNjYyOTgtMTguNjM4ODYtMjku'
    b'NDk0NDY0LTEuNTExOTUtLjY4MDEzNS0zLjY0OTctMi40OTQ1ODMtMy4xNjYxLjUxODE5MS0u'
    b'NzE4NTggMy43NzE0MDggMy4zODAwNyA2LjQwODA2MiA0LjcyMDM1IDkuNjcwMDgzIDUuNTI2'
    b'MyA4LjU0OTczIDExLjIyMDczIDE3LjE0NjE4IDE2LjcyMzg2IDI1LjYxMjktMS4xNTIxMiAx'
    b'LjU1MjY5LTEuNjgwMzUtLjQzMDE3LTIuNDIzMzktMS4yODI3My0zLjQ5MTctNC45NTIwMy02'
    b'Ljk4MzQtOS45MDQwNy0xMC40NzUxLTE0Ljg1NjExLTEuMzAzNjEtLjMzOTIxLTIuOTc4NzEt'
    b'MS4xODYxMi0yLjQ4NjM3LjkyOTA5LS4wODY0NyAxLjM0Mjk4LS40NDQ0OCAyLjc1OTM3LjY5'
    b'NTUxIDMuNzcwNzcgNS41ODU1MyA4LjM4Mjk2IDExLjI3NTc0IDE2LjcyMzQgMTYuNzk2NDUg'
    b'MjUuMTMyNjUgMS43OTExMiAzLjY2MzU5IDMuNDIzMjkgNy40Mzc1NyA1LjMxMjM5IDExLjAz'
    b'MzEyIDMuMTg5NTkgMy4yODI0OCA2LjM3OTE3IDYuNTY0OTcgOS41Njg3NiA5Ljg0NzQ1LTIu'
    b'Mjg5NTYgMS44NDM0OS00LjYwOTM0LTQuMDA4MTctNi44ODk2OC01LjA2NTAxLTIuNDE1MjEt'
    b'Mi43MTgzOS01LjY2MzUxLTQuODkwOTQtNy4wMjczNS04LjM3MTUzLTEuNjU2NjMtMi41ODk4'
    b'NS0yLjYwNzM0LTUuNjgyMjctNS4xNjMyMy03LjU3NjQ1LTIuODMwODEtMi4xMjQxMy01LjAw'
    b'NjE2LTUuOTkzMjMtOC4yODk3MS02Ljk1NDcxLTEuMDYxMSAyLjM0MDQ2LS4xOTU1MyA3LjYw'
    b'NTQ3IDIuOTgzNTIgOS40MTQwNi4zMTY4NS44NzI2NiA0Ljc3NDUxIDMuODc0OCAyLjMyNzQ0'
    b'IDMuMjU5MDUtNC43OTk2NS0uNTI3MTItOS4zMDc2MS0yLjIwNjQ1LTEzLjgwNTA4LTMuODY0'
    b'MzgtMi43MTc2NyAyLjYwNzAyIDYuNDg4MzMgNC42OTM4OSAxLjMyMTMxIDUuNzU3MTMtMy43'
    b'MzczNS4wNTA5Ny02LjYxOTk1LTMuMzM3NzQtMTAuMDM1NjYtNC41OTMxMi04LjUxNDI0LTQu'
    b'NjU1NzQtMTcuMjM3NDUtOC45NDM5OC0yNS45NDMyOS0xMy4yMTMyOS0xLjgwNzM1LS41NDUy'
    b'My0zLjYxNDcxLTEuMDkwNDctNS40MjIwNi0xLjYzNTctLjUwMjg1IDMuMTUyOTIgNC40MjM1'
    b'MiA0LjA0MjQ0IDYuMDYwNDQgNi4yNzIwOCA2LjYwNDM1IDMuNTY2MjEgMTMuMzcwNjMgNi45'
    b'NDU0NyAxOS45ODgyMiAxMC41Mjc0MS0uMjExOTIgMS45ODkxOC0yLjAwNzE2LjQ4NTExLTMu'
    b'MjA3NjcuMjkzMTctMTIuMzg1MDYtMy45ODgyNS0yNC43NzAxMS03Ljk3NjQ5LTM3LjE1NTE3'
    b'LTExLjk2NDczLTIuMDgwMjktLjQ5NzM1LTEuNzE3NjcuNTk0NDEtLjg3NTkgMS45OTc4Ni4y'
    b'MDczOCAxLjYyMjg5IDEuODE5ODQgMS43MDM3NCAzLjA3ODQ1IDIuMTcyOTIgOS43MjIwNCAz'
    b'LjI2MjMxIDE5LjQzNTI5IDYuNTUyMjQgMjkuMTYyOCA5Ljc5NzM0LjM4MzAxIDEuNTMyNTEu'
    b'NzA0MTcgMy4wODA1NSAxLjAzODE3IDQuNjI0NTgtMi4yMDk4Mi0xLjgyMDQ0LTQuMzg4MDkt'
    b'My45MDIwOS03LjQxNTE1LTQuMDk4OTItNi4zMzItMS41NjgzMS0xMi44NTY3Ni0uMjM4NzMt'
    b'MTkuMjc2My0uMTY1NDctMy40MjU2NC0uODIxMDItMy44Njk2OSAxLjk0NDAyLS40NTgyOSAy'
    b'LjUzNDExIDIuNzQxNSAyLjEzMDM2IDYuMjc1NTkuOTM0MTcgOS40NjI1IDEuMTAzNCA1LjE4'
    b'MzA5LS4xNTQ5OSAxMC4zNjU4Ni0uMzIwOTYgMTUuNTQ3OTgtLjUwNTY3LjkxNzY0IDIuOTUy'
    b'OTUtNS4wNjAzMS45NzY2Ny01LjI4NzA1IDMuMzc0NzQtLjU5NzY1IDIuODQ3NSA0Ljc3NTg0'
    b'IDIuODQ4MDcgNi43MTUyNiAyLjI2NTc4IDIuOTY0MjQuMDQ5NjUgNS4wMTg2NC00LjM0Mzk2'
    b'IDcuNTM3ODItMy41OTU2NC0uNjU4MzUgMi44MTgxNC01LjYwNjQ4IDMuNDQ3NzMtNi4xNjc4'
    b'OSA2LjM2MzQ1LS4zNzI1MyAyLjkyMDkxIDUuNTg4MjkgMi4wNjEwNiA3LjMwMjg1LjgxMzMy'
    b'IDEuOTg5NC0xLjY1MjgyIDUuNDE0MzctNC4xNDg0NyA1LjU5NzQyLjI3OTE5LjU3ODk0IDQu'
    b'MDAwOTQgNS44NjkyOSAyLjQ1MTg1IDguNzQ1OCAzLjgwNjYzIDUuMTI3MDcuNzgxODcgMTAu'
    b'Mzc2NjkgMS4xMDY0NyAxNS40NTcwNyAxLjk0NjIzIDQuODYwMjMgMi4yMDU3NCA5LjczNjk3'
    b'IDQuMzk0NzYgMTQuNTg2OTggNi42MTA4Mi0uOTk3NDggMi43NTIyOC01LjI3MjM4LTEuNDIw'
    b'NTMtNy40ODc0Mi0xLjI1ODM5LTMuNjcwNDgtMS4wMjQ0NC03LjA1MTU4LTMuMTA3OS0xMC45'
    b'NDk5NC0zLjE0NjI5LTMuMzcwODItLjYxODc5LTYuNzU1ODItLjU0NjkyLTEwLjEzOTAyLS4x'
    b'NTMxNi0xMC4yNDgzNC44NTYzLTIwLjUxNzIzIDEuNTUwNzctMzAuNzUyNzYgMi41MDgwNS05'
    b'LjUyNjM4IDEuNjA4NzItMTkuMDc2MzcgMy4xNDk1My0yOC42MDA4MSA0LjcyMzg2LTIuNDE5'
    b'NDkuNzUxMzQtNy42ODAyMSAyLjE2OTE4LTIuNjQyNjIgMy4xNDU5OCAxMC44MTUwOS0uNTA3'
    b'NzEgMjEuNjA3OTktMS40MTc4MiAzMi40MDM1Mi0yLjIzMzY1Ljc4MDM5IDEuODg4MDgtMS41'
    b'MzkxNCAxLjI0MzY1LTIuNzAwNzEgMS41NDUyMy04Ljk3ODEyLjkxMTEtMTcuOTU2MjMgMS44'
    b'MjIyLTI2LjkzNDM1IDIuNzMzMy0yLjc2Mzc0IDIuMDQzODEtNi40NTI2NyAzLjE2ODYzLTcu'
    b'OTU5MzEgNi41MTIxNi40MzI5NyA0Ljc1OTY3IDYuMzkxNDMuNDA2OTUgOS4zNDM1NC43MjM1'
    b'OCA3Ljc2ODQ5LTEuMzA2MTEgMTUuNTA2ODEtMi41NDI2MyAyMi45OTcwNi00LjkzOTE4IDIu'
    b'MjMxNTQuMTc4MjkgNy44MTAzLTMuODA2NzQgOC4xNDgwNy0uOTQzNzktOC40NjkzNCAyLjYx'
    b'MjY2LTE2Ljk1OTg1IDUuMjYxMTYtMjUuNTAwODYgNy42Mjg0NS0xLjgxODUxLjQyNDg4LTMu'
    b'NjM3MDEuODQ5NzctNS40NTU1MiAxLjI3NDY1LS41MzA5MSA0LjM3MTY2IDYuMDgxMTYgMS44'
    b'MjE5MyA4Ljc3NzI3IDIuNTE2NzggNS45MjcxMy0xLjM4NjA0IDExLjU3NTU2LTMuNzc3NjMg'
    b'MTcuNDMzODYtNS40MzkwNyAzLjEyMzc0LS4yNTY4OCA3Ljg1NTgxLTMuOTE4NjIgMTAuMTE5'
    b'MjQtMi40MTQ5MS0yLjAxMDk4IDIuMDUzNDUtNi42ODIwMiAzLjEzNjczLTkuNjAyMzggNC44'
    b'MzU4Ni02LjAyNzA4IDIuNjM2NTktMTIuMTM5MzggNS4wNTgwOS0xOC4wMTM2NCA4LjA1MTY4'
    b'LTMuODY5MDkgMy45MTk5OCA0LjExMTA1IDMuNTYwMTQgNi4wNzA1MiAxLjUzMDQ0IDYuMjc1'
    b'ODItMi44Nzg2OCAxMi40NzM4NS01LjkxNzkyIDE4LjY1NjgzLTkuMDE3ODYgMS41MTU2NSAx'
    b'LjI1MzU1LS43MTI3NCAxLjg1Mjk0LTEuNTAyMTkgMi43MTMyNy0zLjUwMjcyIDIuNzQxNzMt'
    b'Ni45MTk0NyA1LjU3ODEyLTEwLjgyNTM2IDcuNzM0NDYtMS41MTI3MiAxLjIxNTEtMy45ODY5'
    b'MyAxLjYzOTQ2LTQuMjgzMTkgMy44NjY0NSAzLjQzMTEyIDEuOTUxMDMgNi43MDkxNC0uNDE1'
    b'MDUgOS43ODM5OC0xLjk1MDUxIDguMDM3OTUtNS4yMDM5OSAxNi4xNjg1Ni0xMC4yOTQyMSAy'
    b'NC4zNDk4My0xNS4yNTc5NiAzLjUzNzM4LTEuNTg0MTggNy4xNjYyNS0yLjk1NTkyIDEwLjc1'
    b'OTIzLTQuNDA0MzcgMS4zODg0IDEuMzg1NzctLjg4MDUxIDEuODA2NjMtMS43NDA4OSAyLjYx'
    b'OTg2LTMuOTQ4MDQgMi42NDE5OS03LjkxMDkzIDUuMjY1ODgtMTEuODQ5NzIgNy45MTkxNS00'
    b'LjMwNjAxIDQuNDUzNzctOC4yMDQ2MSA5LjM1MTc2LTEzLjI4OTU3IDEyLjk2Njc4LTIuMzcx'
    b'MzcgMS45ODM1NC00Ljc5MTcyIDMuNzY5NTQtNi42NjU4OCA1Ljk1NjczLTMuNzE4MTggMy43'
    b'Mzk5OS03LjU2ODQzIDcuMzQ2OTctMTEuMjUyNiAxMS4xMjA1NC0xLjE0OTM0IDMuODExOTIt'
    b'My41OTg2NiA3LjM5NTI0LTMuMzI3OTEgMTEuNDg0NzMuMDQ3MDYgNC40MDMxMi0uNDUzMzQg'
    b'OC44NTQ1LS4wMzg0NiAxMy4yMjc3Ny40NTE4NiAxLjgxNzEgMS41MDA0MiA1Ljk2MDQ2IDEu'
    b'ODU1NDcgMS44MTg1LjE5OTY4LTEuODkzODIgMS41MDY4My04LjQyNDEgMi45MDk1Ni0zLjg0'
    b'MTg3Ljc3MTA2IDEuNzE0MTggMS41MjkzNSA2Ljg4MTc3IDIuNDQyOTMgNS45ODUzOSAxLjMz'
    b'ODMxLTIuNjUyMiAxLjU4NjEzLTYuMzcyNzIgMy43NDAyLTguMzgzIDEuOTE4ODQgMS4xMTk4'
    b'MiAzLjQzNTIzIDMuODgyOTYgNS4yNjM2LjcwNDAyIDIuMzIwMTktMi43MDE0MiAxLjk3NjM3'
    b'LTYuNzYxNzMgMy4xMzA3OS0xMC4wNTA3OS45OTQ4LTQuMjY3NzIgMS45OTI3Ny04LjUzNDY4'
    b'IDIuOTk0MDQtMTIuODAwODggMS44MTgxMi0uNTI2MjggMS4zODc2NCAxLjY3NTUyIDEuODQw'
    b'NjQgMi44MDU0NS41ODE5MyAyLjYzMDI5IDEuMTYzODUgNS4yNjA1NyAxLjc0NTc3IDcuODkw'
    b'ODYgMy45NjkwNS0xLjcyMDA4IDIuMzQ4Ni03LjA4NTEgMy42MjgyNi0xMC40Nzk0MS4yNTQx'
    b'OS0yLjU0MzUzIDEuMDYzMDgtOS4yNDE0NCAzLjc5NDgzLTQuMTI4OTQgMS42MDQ4OSAzLjg0'
    b'ODU1IDYuMDUxMDktLjU4ODExIDUuOTE1ODMtMy4zODY2Mi45MDc2Ny00LjQzNDYxIDEuNzc2'
    b'NzYtOC44NzcyMiAyLjcwNTU0LTEzLjMwNzQ2IDEuMTkwOTMgMi4xMjI0MiAyLjQzMjkyIDQu'
    b'MjE1NTggMy42NDkzMyA2LjMyMzQgNC4xNDQxOC0uMTkyMTUgNS41Njk4OS00LjM0ODUzIDgu'
    b'MjU4MzQtNi44MTIzNyAyLjQxNTY3LTIuNTA3OTQgNC41NzAyMy01LjQxMzk0IDcuMjUxMzEt'
    b'Ny41OTYxOCAzLjA1NTA5LTEuNTc0NTcgNS45MTc3Mi0zLjY3ODI2IDkuMDYwNC01LjAzMzU2'
    b'IDMuMDY2MDYgMi44MzQyOS0xLjU2MTM5IDYuNjYwNjYtMy4zMDMyNyA5LjA5MTg2LTMuODg3'
    b'NTIgNC44MDMxMS04LjY4NTg5IDguNzU5NjQtMTIuNzU1OTIgMTMuNDEwMDgtMS42MDY1MiAx'
    b'Ljg1NDM2LTQuMTE5ODcgMy40MTA5My0zLjQ0NTg0IDYuMTcwOTIgMi4wNDIxNi45MTA0OCA0'
    b'LjE3MjAxIDEuNzM3OSA2LjIyOTAyIDIuNjYxMDMtMy4xMDY2NSAxLjU1NzM4LTYuNDQ1NzIg'
    b'Mi44OTY1Ni05LjMxMjA4IDQuNzgxODgtMi43NzU2IDIuNDAwOTYtNS43NzE5OCA0LjUzMi04'
    b'LjY4Mjg4IDYuNzYzODQtLjc4NTkxIDIuMTEyMy0xLjI5MzY2IDQuNDk3NTIgMS44MzEwNSAz'
    b'LjYxOTIxIDIuMjMxMDEtLjM4NDE3IDguMjM4NDIuNTY5NiAzLjUxNzEgMi43NjcxMi00LjQz'
    b'NzQ0IDIuOTAwMzQtOS41NzUzMyA0LjcxMDY1LTEzLjk2ODEyIDcuNTgxNzktMS4yMTY0NSAx'
    b'LjYyNDEtNC40ODE3NiA0LjE3MzA0LS41MDMzNiA0LjA1ODMxIDIuNjU3MTUtLjM4MjE5IDYu'
    b'NjM0NzgtNC40MzEyOSA4LjYwODg5LTIuMzgxMzgtMi43OTI5NSAzLjA4NjE3LTYuNDEyNzYg'
    b'Ni4wNjQwMi05LjQ2OTM5IDkuMTQ3My0xLjU1NjUzIDEuMjA0NTUtNS4wMDkxIDQuNTU0MDMt'
    b'Mi45NjU0MiA1LjQ5NTQyIDQuODQyOC0yLjMxNTI5IDguMjQ1MjgtNi42NjY4NyAxMi4zNzA4'
    b'NS05Ljk4MjUgMS40NDk4My0yLjMwMjk5IDUuMzM0NzUtNC4zNDg5NSA0LjEwNDY1LjE0MDgt'
    b'NC43ODk4MyA1Ljk2MzMyLTkuNDE5OTUgMTIuMDk2MTYtMTQuMzQ4NCAxNy45MDMzNS40OTYz'
    b'MyA1LjgzMTkgNC4yNDYzMS0xLjY3MzY4IDYuMDkzNTUtMy4yMzg1NiAyLjg4MDctMy40MDA1'
    b'IDUuNTU4NzctNy4wNDQxNCA5LjMyNDItOS41MzA1OCAxLjMwNzE2LS4yODM5NSA0Ljc1NDQ3'
    b'LTUuMTk1NDkgNC45MzY2OS0zLjE4NzY1LS4wODc4NSAxLjY2OTc4LjQyNzc3IDMuNTMzNzUt'
    b'Ljk5MTI1IDQuODMzMjgtMi45NzgyNyA0LjAxNDYxLTQuOTY4ODkgOC42MDY5My03LjQwODQ5'
    b'IDEyLjk0ODE3LS40MDI4OCAxLjg3NDAyLS44MjAyMiA3LjI1ODg5IDEuODg3NTggNC43MTg5'
    b'NiAzLjIyMzc5LTYuMDEyMTkgNy4xNTcyMi0xMS42MzQ5NCA5LjY5NTM2LTE4LjAwMTE5IDIu'
    b'NjAxNjItNS40NjAzIDQuMzU3MDMtMTEuMzIxMTkgNi41Mzc4Ni0xNi45MTkxMSAxLjgzNTI4'
    b'LTIuNzM4OTMgMi43MzIzMy0xLjgxMDU3IDIuNDc2NjcgMS4wNTI1LjI5NjE4IDIuNjYyOTUu'
    b'MTgzNjEgOC4zNjAzIDIuMDIyMDcgOC43NjI5MyAzLjM0MTg2LTcuNjM1MDYgNy41MzY2LTE0'
    b'Ljg1NTY2IDExLjA5OTQzLTIyLjM3NzEzIDEuMjMzMTUtMy42Njk3OCAyLjY5ODMzLTcuMjc0'
    b'MTUgNC4yMjE0Ni0xMC44NDQzNCAxLjkxOTQ2LS4yMDExOCAxLjAzNzc0IDEuODgyNTUgMS4y'
    b'MjY5MyAzLjA5Mjc1LS4xMjkwOSAyLjQyNzguMjU3MDIgNC45Mzk5Mi0uMTg4OSA3LjMxNTg4'
    b'LTIuMDcwNDQgNS45NDQ5Ni0zLjYyMjc5IDEyLjA3NjQzLTYuNTA5OSAxNy43MDQyMy0xLjc1'
    b'MDQ5IDMuNjE4OTUtNC4yMjQwNiA2Ljg4MDQ5LTUuOTE2NTUgMTAuNTE5NjktMS42OTYyNiAy'
    b'LjIwOTI0LTEuMDY2NzMgMi4yMjU3Ljg0NDUuOTI3MDQgMy4zODAxNS0xLjU0NzY0IDUuNjQ5'
    b'ODMtNC40NDk1MiA3Ljk5MzU2LTcuMjEwNiAzLjY4NjQ1LTIuOTU2MzYuOTQ5NDMgMy43NjYx'
    b'Mi4wOTk3NyA1LjE5MjA2LTIuMDA1MDIgNS42ODQwNS0zLjMwMjQ3IDExLjY0Nzk0LTUuNTcx'
    b'NjQgMTcuMjYxOC0uMDI4MjYgMS43MDExNi0uNjE4MTkgNS42MTE5OSAxLjU0OTI0IDIuNjE4'
    b'MDMgNC4wNjg0Mi0zLjE4MDcyIDUuNTQ5MzktOC4yNzYwOSA3Ljk4MzA2LTEyLjYyMjIyIDEu'
    b'NDc1NjcgMi4xNTYxOCA0LjI1MjAxIDMuNDAyMDIgNS41OTY4OC43NDM0OC0uMjI1ODctMy4z'
    b'NTc2Ni0xLjc3NDM4LTYuODM3NjMtLjI2MjYyLTEwLjA4OTY1IDEuNDkyODMtNS4zNzg5MyAy'
    b'LjcxODk3LTEwLjg1OTQzIDMuNTYwOTgtMTYuMzcyNzYuNDA1MTYtMy4zNTIyOC42MzEwNi02'
    b'Ljc0MTkxIDEuMDQ2MDMtMTAuMDgyMjUgMS44NjU0My0uOTYwNjYgMS4wNzY5NiAyLjAwMDE2'
    b'IDEuMjI2OTMgMy4xMjQyMXY3LjY2NjQ4YzEuODI3MDUuMjAwNzcgNS4xODAzNS0zLjAzNzIg'
    b'Ni4xMzQ2NS0uOTEyMzMtMS44NDQyOCAxLjU3OTk3LTQuNjYwNjMgMi41NTgyLTYuMzMwNjUg'
    b'NC4yNzY3Mi0uMDcwOTkgMi4xMzk4Ny0uMTQxOTggNC4yNzk3My0uMjEyOTcgNi40MTk1OSAy'
    b'LjI3NTU5LTEuMzg0MjMgNC41NTExNy0yLjc2ODQ2IDYuODI2NzYtNC4xNTI2OSAxLjYxMzY1'
    b'IDEuMTM1MDItLjUyNTEgMS45MjA0Ni0xLjI1NjgzIDIuODU4NzQtMS44NjcxMyAxLjc0MjE0'
    b'LTMuNzM0MjYgMy40ODQyNy01LjYwMTM5IDUuMjI2NDEtLjAzMTQ2IDEuNTEwMDctLjA2Mjky'
    b'IDMuMDIwMTMtLjA5NDM4IDQuNTMwMiAxLjU4MTk0LS40OTcyMSAzLjE3NjE1LS45NTk2OSA0'
    b'Ljc1MDQyLTEuNDc4NiAxLjI5NzU3IDEuNDc3Mi0uOTQwODkgMS44MTAxMy0xLjg2ODg5IDIu'
    b'NTgwMTktMS4wNDk3NC45NzQ4NS0zLjQwODk5IDEuMTQyNDctMy4wNjgyNiAyLjk3NTY5LS4x'
    b'MTg5OCA0LjYwOTIyLS4yODc5IDkuMjE1NjctLjQ3MzkzIDEzLjgyMzMxLjgzMTY3LTEuNjQ3'
    b'MjEgMy43NjY3NC01LjYxMzA5IDMuMzM3NTYtNS44MzgyNS0uOTYxODUgMS44ODI5NC00LjQ2'
    b'MzA5IDIuMDA5MTItMi4wNzkxNy4wNDk2Ni45OTEwNC0xLjIwMzg1IDYuMzkzMjUtNS4wNDkx'
    b'OSA0LjQ4NTUxLTEuMjA2NjMtMS44NTkzNSAyLjY4MTYxLTMuNDc1MDEgNi4yNTE1My01LjQy'
    b'NzAyIDguNDU0MjUtLjU1NTIxLS4wNTM4OS0xLjIyMTQgMy44ODc4NC40NjEzIDMuMTA5MjUg'
    b'MS4zOTY4Ny45NTA0OSA1LjcwNzU0IDEuMzgzODcgMi43MzA0NyAzLjAzODM0LTEuMjc0MjMg'
    b'MS4yNzkxMi0yLjg2OTI3IDIuNDE3MjMtMy45NDkwOCAzLjc4MTguMDg4MzUgMy44NTc0Ni0u'
    b'ODgzODkgMTAuMjgyMjQtLjEyOTAzIDEyLjUyMjY3IDEuMTM3OTYtMS41OTk0MSA0Ljg4MzA2'
    b'LTQuNDg3NTcgNC4wOTcwMS01LjI0MzA1LTEuNTc5NDkuNzU0NjItNi4zOTI2Mi4zOTQ5NS0z'
    b'LjAyNDE5LS44MzAzNyAyLjA1MTkyLS43Nzc1MyA3Ljc4NDIzLS45OTcyNSA0LjEyMTIyIDIu'
    b'MjMzNjQtMS45NTE4OCAzLjQ3ODkxLTYuNTk4NjggNC41NzM1OS01LjcyMTU5IDguMzc5MDUu'
    b'MDE3ODkgMi44MDc5NS0xLjEzMjE5IDQuNTIyODkgMi4zMDQyNSA0LjAwOTIgMy45MzMzNS0u'
    b'MzQ0MzUgNC4yMDcxOSAzLjQ4ODQ4LjY2MTgzIDQuNTM2NzEtMi40MzgwOCAxLjQyMjgtNC41'
    b'Njg4OCAxLjMyOTg2LTMuMDk2IDQuNTYyMDQuNzU5NCAyLjEyMzgyIDYuMDA0MDYgMy41NTcz'
    b'OSA0LjY4NzUgNS43NTcxMy0uMTk2MzUtMi40ODExMS0uNzUzODQuOTU3MTUtMi4xMTEzMy0x'
    b'LjUzMjAzLTEuNjcwMjUtMS4zMzIwNy0zLjgyMDQzLTQuNDk4ODEtMy4xMTQwMy0uMjk4My0u'
    b'MzA2OTIgOC4wMTM4OS0uNjI0IDE2LjAyNzM5LS45NDA3NCAyNC4wNDA5IDEuNjUzNDQtLjUw'
    b'NjAzIDQuNTg1NSAxLjgxMDA2IDQuNjE0NTEgMi44ODI5Ny0xLjcwNDU1IDEuNTgwODMtNS43'
    b'NzQzLTUuMzIzNTktNC43MTU4MS4xNDM5LjA1Njk2IDIuNDYyNTItLjU5MDg5IDcuMDEzNTEt'
    b'LjA4OTUzIDguMTYwMDQuODIwNC0uNjkwMzcgMi4xMjI3OCAxLjI4MzM0IDMuMTI5NzQgMS42'
    b'MjQxIDEuMTQ5MTMuNzk0NjggMi4yOTgyNyAxLjU4OTM2IDMuNDQ3NDEgMi4zODQwNC0uNjMz'
    b'MTIgMS45NTMwMi0xLjk4MDk0LS4wNjAyMS0zLjA1OTQ3LS41NzktMS4yNjYyNS0uODc2NjMt'
    b'Mi41MzI1LTEuNzUzMjctMy43OTg3NS0yLjYyOTkuMjk3MDMgMy4yNTg0Mi0xLjEzNDE5IDku'
    b'MjUyNTMuMTc3NDMgMTAuOTM3OTIgMS40OTUxNiAxLjEwMTkxIDUuNDAwOSA0LjI3MDc5IDUu'
    b'MzA0ODYgNi4wNDIwNC0xLjkzMzA3LjUxNjIxLTQuNzI0NS01LjI1MTQyLTUuOTQxMzctNC45'
    b'MjIxOC0uMTg4MTMgNC44NjI2Ni0uMzYyMzkgOS43MjU4NS0uNTQ3NjMgMTQuNTg4NjIgMi4w'
    b'MzAxNi42ODEwMSA2LjE0MTcgMy4zMjM5NyA3LjIxMzUxIDQuOTg4MjYtMS44MzM3OCAxLjU1'
    b'NDIzLTUuNzA2MDgtNC4yMTY5My03LjI5MzI4LTMuNDgzOTYtLjI4Nzk5IDMuOTI4NDItLjA1'
    b'MTggNy45NDM4NS0uNjE0NTMgMTEuODI2MjUtLjc0NDYgMi44MjMwMiA3LjAzMTk3IDIuMTI2'
    b'MzcgNS4zNTAzNCA1LjAxMDQ3LTIuODY4NDUtLjk0NTY0LTYuODQ4NjctNS4wNDkxOS02Ljg3'
    b'MTUzLjI1Mzg5LS42MTI1NiA0LjIyNjg3LTQuNDYwOSA4LjU0MzgyLTEuNDY1MyAxMi41NTAy'
    b'MiAxLjE1Mjc4IDMuMjUyNTkgNC44NDczMSA0LjYzODI1IDcuNjEzMjYgNi4yOTE5NSAzLjI2'
    b'NjctLjUxNTM1IDYuNDAyNjctMi4xMzAyMyA5LjgwNDU4LTIuMjU3MzkgNS4wMTQxNi0uNzc3'
    b'MDggMTAuMTE0MDktMS4wNTY2NCAxNS4xMTE1Mi0xLjg2Mzg0IDIuMTExODMtMS41NDAwNyA0'
    b'LjcyODk3LTIuOTkyMjYgMS41NDU2MS00Ljk2NzM2LTIuNTM0MjgtMy4xMTA3Mi0xLjkzMTk3'
    b'LTcuNTQ0NTctMy40MDE3My0xMS4wNzcxLS4wMDM0OS0yLjg3NTAxLS41OTQ0MS00LjEyNDY5'
    b'LTMuMTIzNjEtMi4wNDg4NC0xLjk4Mjc5LjM5MjU5LTUuMDY0NTkgNC42MjA4Mi02LjE4ODQ3'
    b'IDEuOTg1OTIgMi45NjI2NS0xLjQzMzk0IDUuNjUxMjgtMy4yOTg2NSA4LjY1MTQyLTQuNjg3'
    b'NS0uMzU0NzktMy43NjI0Ni0xLjA4MTc4LTcuNTAzOTYtMS4wMDY3MS0xMS4yOTQwNC0yLjM3'
    b'MDI0IDEuNTI4OS01Ljg3MDg4IDQuNzA3NDItOC4xNDYyNiA0LjI2ODU5LjkyNzg3LTIuMTE3'
    b'MDIgNS40NjA2NC0zLjA0ODQ5IDcuMzkxMjMtNS4yNzUzMSAxLjQwMzIyLS4wMTg4OS40ODYy'
    b'Ny0yLjAwOTIzLjcyNTE4LTMuMTg1My0uMDMyLTMuMjc5NjctLjA2Mzk5LTYuNTU5MzUtLjA5'
    b'NTk5LTkuODM5MDItMi4xOTU2OSAyLjQ3ODU2LTQuODI0MzcgNC4yNDYxMy04LjE0ODA3IDQu'
    b'NzgxODgtMi40NzIxNi0yLjE2MTI4IDMuNzczNDQtMS4zODI1MSA0LjU4MDIyLTMuMjIyNjUg'
    b'MS40OTQ1Mi0xLjY4ODg3IDQuMjU3NzMtMi43NDA1MyAzLjUxNzQ0LTUuMzgwNS0uMDI1MTQt'
    b'Mi44OTk5LS4wNTAyOC01Ljc5OTgxLS4wNzU0Mi04LjY5OTcxLTEuOTMyMDYgMS4yODI1OC01'
    b'LjQ3MjE4IDUuODg0MTEtNy4zMzgwNiAzLjk3ODA0IDIuMDE3NjMtMS43OTc2OSA2LjM4NDg0'
    b'LTMuNTE3MzcgNy4yOTk3LTYuMjA2NjEtLjAzOTY1LTMuNzY2MzctLjA3OTI5LTcuNTMyNzQt'
    b'LjExODk0LTExLjI5OTExLTIuMDgyNjcgMi43ODIzOS00LjkyNTE4IDQuNjg4MS04LjI4ODg4'
    b'IDUuNTY1MTEtMS42NTA4IDEuODMxMjItNS4wMTg5NS4yMDQ4OS0xLjY2MjItLjcxMTM2IDMu'
    b'Mjc1MTItMS4wODU4IDYuNTgyMzgtMi4yNzIgOC42MTkxOS01LjI0ODkyIDEuODUxMjMtLjk5'
    b'MjA0IDEuMjI4OTgtMi43NTUwNCAxLjI5NTQ3LTQuNTgxNjEtLjAyOTgxLTIuNjgyNTItLjA1'
    b'OTYxLTUuMzY1MDMtLjA4OTQyLTguMDQ3NTUtMy45MTE4MiAzLjQ2ODQ0LTcuNDQ1MzYgNy4z'
    b'MTM1OS0xMS4zMjU1MSAxMC44MjIxNS0yLjA0Mjk0LTIuMTU1OTcgMy43OTYwMi00LjAyNjM5'
    b'IDQuNjI0NTktNi4xNjYxMSAxLjkzMTA5LTIuMzE0MjMgNS4yMDYxNS00LjU1MTMgNi42OTY0'
    b'NC02LjU0MDI1LS4wMjk5Ni0yLjkyNjg4LS4wNTk5My01Ljg1Mzc2LS4wODk5LTguNzgwNjQt'
    b'MS40OTA3OSAxLjM3OTA1LTMuOTA1MjkgMy4xMjcyLS44NDk0MSAxLjQ3ODYxIDEuMzY3OTkg'
    b'MS41NDAwNy0xLjAzMzQ0IDEuNjk2NzUtMi4wMzk3MiAyLjM2NTQ2LTEuMzg1MzEuNjQ5NDkt'
    b'Mi43NzUzMiAxLjI4OTI2LTQuMTU3ODUgMS45NDQ1Mi0xLjQ0NjIzLTIuNzE1NjkgNC42Nzk4'
    b'OS00LjA0Njg3IDUuOTAxMzctNi40MzYgMS42NTMzOC40MDU4IDEuMDQwNTItMS4xNTE2MiAx'
    b'LjExNTcxLTIuNzU5NzctLjAyMTUtMi4wNDE3MS0uMDQyOTktNC4wODM0MS0uMDY0NDgtNi4x'
    b'MjUxMi0yLjA0MzY1IDMuNzIxMTItNi4xMTYyNCAxLjU2MzM3LTkuMzY2MDIuODg3NzUtMi40'
    b'MDAyNC0uMTk2Mi0uMTQxNTQtLjkyODI1Ljg1NTU0LTEuNTIxNTcgMi41NzQ2Ny0xLjM4MjY4'
    b'IDUuMTQ5MzMtMi43NjUzNyA3LjcyMzk5LTQuMTQ4MDYgMS40NTE3NiAxLjQ2NTE4LS45NDMx'
    b'NyAxLjc0MzIxLTEuOTEzNzEgMi40NjA4My0xLjUyMjM0LjgwNTE0LTMuMDQ0NjcgMS42MTAy'
    b'OS00LjU2NyAyLjQxNTQzIDIuODU0MDMgMS41OTkwMiA2LjM1NDIyLjU3NTY3IDcuMjI5NjQt'
    b'Mi4xOTcxMy4wMDgwMS00LjkwMzcxLS4xMzM2Ny05LjcyMzAxLS4zNzE0Mi0xNC42MzM4Mi0y'
    b'LjI1NTkzIDIuMjY2ODEtMy41NTA5MiA0Ljc0NjE3LTYuMzU0ODYgNS43NTcxMyAxLjMxMTU5'
    b'LS42MDYzOCA2LjcxOTk3LjE4MDkxIDMuMDgzMDUgMS4xMzI1NS0yLjA4NTk5LjQxNjgtOS4w'
    b'NTAyOS42ODI0Mi00LjE3Njc2LTEuOTc1MDIgMi40ODg3Mi0uOTc3NTYgNC4xMDUwMi0yLjc5'
    b'NTE2IDUuNjg3NzQtNC44ODM1NCAxLjg4MTgtMS4wODM5NSAxLjg2Mzk2LTEuODE4NTkgMS42'
    b'MDkyMi00LjAzMzY2LS4xMjc3My0zLjAxNzc1LS4yNTU0Ny02LjAzNTUtLjM4MzItOS4wNTMy'
    b'NS0xLjE0MjAyIDEuNDA0NDctNi4wMDcxNSA1LjI0ODkxLTQuNzY2MjMgNS4yNDUyNiAxLjQ1'
    b'NjQ3LS45MTc3NiA3LjE2NDg5LTEuMTg0MDcgMy43NzA4Ny40NjM4NC0yLjE3NjYyLS4xMzc4'
    b'Mi02Ljg4MTk2IDIuODkzNzQtNy42NTYwNy4yMzY3OSAzLjAzMzA3LTEuNzQxNiA1LjI2Mjgz'
    b'LTQuNDYwNjggNy43OTU3OS02Ljg1ODE3IDEuNDgzMzIuMTkwMzMuNTA1NTYtMS45OTA0NS42'
    b'OTIyMS0zLjMzODQ3LS4zNjQ5OC05LjA1OTE3LS43Mjk5Ny0xOC4xMTgzNS0xLjA5NDk2LTI3'
    b'LjE3NzUyLTEuNDI0NzUgMS4yNjUxOS03LjM5MTQ2IDYuMDg2NS01LjIxMDE0IDEuMzAwNzIg'
    b'MS40NjI1NC0xLjY3NjA4IDIuOTUyOTEtNC42MDgxIDQuNTc3MjItNS4xNzgwOSAxLjA2Mjk1'
    b'LS41NDU1My4wOTI1Ny0yLjUyMzc2LjM0MDQ5LTMuNjQzNTcuMjQ1MjctMi43NzMwNS0xLjQ0'
    b'NTgyLTUuMTM0ODktMi4yNzI5NS03LjY4MDItLjA1NzUxLTEuMDQtMi4wMDcwNi0yLjg1Nzc0'
    b'LS4zNDk0My0zLjE2NTczIDEuODA0NjggMS41MzI2OCAyLjY1ODYgNS42OTQ3MSA0LjEyMTM0'
    b'IDguMTU3NjggMi4yMjM3NiA1LjE0NzYxIDQuNzYzNTEgMTAuMTgyMiA2LjcyMTMyIDE1LjQz'
    b'MTUgMS4wODIwNSA0LjM2Nzk5IDIuMjM0MjUgOC43MjE3MiAyLjM5MDk0IDEzLjI0NDU1IDEu'
    b'MTEwNjQtLjQwNDgxIDMuMTgzMTEuMjY1MjYgMy4xMDYzNS0xLjQ2NjU0LjI1OTI3LTEuNzAz'
    b'ODcgMS40OTAwMi0zLjQ2MDUuNDA4OTYtNS4wOTE1OS00Ljg3MjE5LTEzLjI1OTE2LTEwLjQx'
    b'MjY3LTI2LjI1Mzc3LTE1LjU2NDM5LTM5LjQwNDU0IDEuMjIyMi0xLjI2ODkyIDEuNjI2NTIu'
    b'NDYxNDQgMi4xMDU5NiAxLjQ5MTc3IDIuOTk2NzggNS45NzQwOCA0Ljk1NDE2IDEyLjM5OTU5'
    b'IDcuNDUwOTkgMTguNTk1NDIgMi41MzM5NyA2LjcxODEyIDUuMTk4OTUgMTMuMzk4MTcgOC4y'
    b'NDkyNiAxOS44OTgxMyA0LjY5Mzg4LTIuNzMwODEuODEyMjUtNy42MjExMS4xNDk0Mi0xMS41'
    b'OTQxMy0yLjE5MzYtNy4yNjY0OC01LjE1OTMyLTE0LjI3Njg5LTcuNzAxMzItMjEuNDI3ODIt'
    b'Ljc1NDUyLTEuMjcwODMtMi40MDM2OS0xLjg2NzExLTMuNTAxMjUtMi44NzkzLTEuNjE2MS0x'
    b'LjE5MTgyLTMuMjcyODgtMi4zOTk1My00Ljg2NTQ3LTMuNTgwNzEgMS4zMjQyMy0yLjUwMDE4'
    b'IDQuMjYzMTIgMS44OTUxNiA2LjI5NDUyIDIuMTEyMzQgMy40OTM3NyAzLjY4MTQxIDQuMzU0'
    b'MzQtMS45NzY4OCA3LjQ1NDIzLTIuNjI3MTQuODY5MDIgMy4xOTAwNS01LjAyMzY5IDUuNzcx'
    b'NjMtMS44ODYgOS40NTU1OSAyLjI2MTIzIDcuNzE0MDEgNC4yOTAwMyAxNS41MDYwMSA3LjI4'
    b'NDkyIDIyLjk3ODE0LjQ5NiAxLjM0Njc1Ljk5NjgzIDIuNjkxNzIgMS40ODk5MSA0LjAzOTU0'
    b'LTEuMDEzMTEgMS40NTYyOC40Mjk2MSA3LjY4ODQ1IDIuNDk0OTkgNi4wODE1NC43MDgwNC0z'
    b'LjM2NDE0IDIuODU5NTYtNi42OTM5NCAxLjAzMjA2LTEwLjA5NDM2LTIuNjgyMTEtMTAuMjUx'
    b'MTktNi4zNjQzNy0yMC4yMDkwNC05LjQ2Mzc2LTMwLjMzOTA3LjA0MDgtMy42OTIxNyAyLjM0'
    b'NzE5IDEuNTczNjYgMi42MDQ1MiAzLjE2MDc1IDMuNTYzMjQgOS42NzY5NCA3LjQxODIgMTku'
    b'MjY0OTUgMTAuNTY3OTMgMjkuMDgzMzQtLjY2OTQ3IDIuODg0MDYtLjY0ODI5IDguOTgzNiAz'
    b'LjExNDUxIDUuNTM2OTEuMTY4Ny0zLjg1MDU0LjQ2OTI4LTcuNzkzNzgtMS4xMzI1NS0xMS40'
    b'MTk4OC0zLjI1Nzc3LTguNjY5ODctNS44NDcyOS0xNy41OTM2MS04Ljc0NTgtMjYuMzk0NzIt'
    b'MS42NTU2IDEuODAwOTQtNC43NjkzOS4wNzYwOC01LjI1Mjk3LTEuOTEyNzMuNTU1ODUtNC4z'
    b'NzMxNS0zLjA1NDc2LTQuMjUwNzktNi4zMTU4NC0zLjk3MDI0LTEuNDI2NDktLjEzODkxIDIu'
    b'NDg5NTgtMi4xODI2OCAyLjk0ODg0LTIuOTI1NzUgMS43NjE1Ny0uOTY4NDcgNS41MTYyMS0z'
    b'LjkzMTg2IDEuODk1NjQtNC43MjY3OS0xLjE1NjYzLS41MzEyOS0yLjMwNzI1LTEuMDc1NzUt'
    b'My40Njg2My0xLjU5NjYyIDEuNzI3NjgtMi45NzM1IDMuNTE3NzItNS44OTIyNCA1LjgwNjcz'
    b'LTguNDgwMTcgMS40MTAxOS0yLjU3MDgxLjMzODgtNy4xODMxMy0yLjM5Njc5LTguNzUwNjkt'
    b'MS45ODQzOS0xLjA5MDMzLTEuNzYwOTctMy42MDQxMi0yLjU0NTgtNS40NjY4OC0xLjAzNTU2'
    b'LTEuMDk3LjAwMzM1LTMuMjEwNTMuODI5MTItMS42MjAzMS41MTU3IDEuNzcyMTIgMS4wMzE0'
    b'IDMuNTQ0MjUgMS41NDcxIDUuMzE2MzcgMi45ODc5OSAxLjYwMzI3IDQuMzc0ODggNC4yMzQ0'
    b'NiA0LjMwNTcgNy41NTE1NCAxLjM2Mjk1IDMuMDk2MTQtMi4yMjg3NyA0Ljk3NDE2LTMuNTUz'
    b'NTkgNy4zMTc3Ny0uNzg5NDMgMS4xNDc5My0xLjQ1NTY1IDIuMzg0OS0yLjE5OTI2IDMuNTY2'
    b'MSAxLjY2MzQ3Ljc4Mzg4IDMuMzYyMTQgMS40OTY2OCA1LjAwMjEgMi4zMjgwMi4zNDQyIDMu'
    b'MTI2MTgtNS4wNTEyOCA1LjE5MzE5LTQuNjU2MDQgNi4yNjA0OCA1LjIzNjg4LTEuNDA1NDMg'
    b'Mi4wNTc5MSA1Ljg5MzE5IDYuMDEwNzIgNi40OTEzOCAxLjM0MzMxLS4wMTMwNiAyLjUxMTM0'
    b'LTEuMzQ5MTEgMy43ODI4LTEuOTA0NSAyLjI2ODMyLjQyODc1LS45NTE4IDEuNDg1NTItLjQx'
    b'Nzk5IDIuNDk5MTUgNC4yMjY2OCAxMS40OTMwMSA4LjU2NzI1IDIyLjk5NTU0IDEyLjU4MzM2'
    b'IDM0LjUzNTItLjM4Mjk3IDQuMTc1MiAzLjU5NDYyIDQuNzIwMTkgNi4wNzE3MyA2LjQ0OTI0'
    b'LjM0MzI1IDIuMjI1ODMgMS40MDgwNSA2LjQ1MjkzIDMuNzU2NDYgNS41NDUxNy4xMDA4Mi01'
    b'Ljk1NDUxLjQ3NDA4LTExLjk0MzYzLjQ5MDYtMTcuODc3MzguMzM5OTUtMi4wMzI4MS0zLjEx'
    b'Mzc5LTYuOTU4OTYtLjI4MzE0LTcuMjA0MjggMS41ODk0MyA0LjY1NjEgMy42OTMyNyA5LjE5'
    b'NTQ1IDQuNzg0NTQgMTMuOTg3ODYuNzY4ODIgMy4xMTI5OS0uNzYzMzIgOC4xNzAwOSAzLjcw'
    b'MTQ4IDguNjMzMTUgMS45NzAyNS44MDExNC40NDUzNS02LjM1MzcxIDIuNTU2MzUtNC40MDU4'
    b'M2wzLjQ5MjAzIDIuNzY4NDZjNC43MjQ5NS4xMTMzOCAxLjIxMTg2LTUuMDY3NSAxLjI4OTg1'
    b'LTcuNzA3NjMtMS40ODYzMi0zLjY5NDQ5LTIuODk2NS03LjQzNDA0LTQuMzcyOTEtMTEuMTM2'
    b'NzUgMi4xOTk3OC0uOTEwMTgtMS4xODE3OC4zMjIwOS0uNTQ0NzItMi4wMzcyNC0uNTA3OS0z'
    b'LjY1MzE3LTIuODc1MDItNi40MDA2OC00Ljk5NDMtOS4yNTY3MS0uODk4NzItMS45MzU1NC0u'
    b'ODM4NDctNC4yMjgyNi0yLjUxNzItMS40NzkyMi0xLjk5NzM0IDEuNjU0MDUtMS4xMTc0OSA0'
    b'LjM4MjM4LjI4NDA2IDYuMTI2MzMgMi4yNzgzMiAzLjUyNzE3IDIuMDUzMDQgOC4xODgxMyA0'
    b'Ljg5ODc4IDExLjM3Njk5IDEuMjUxNjQgMi4wNTQ0IDIuOTMxMDcgNC4xMjYzNiAyLjQ5NTg3'
    b'IDYuNjc0NjYuMTExNDUgMS4xNzMzMy4yMDQ0IDMuNTA1NS0xLjI1ODM5IDIuMzc2MjMtLjE5'
    b'NTQyLTEuOTkwNjEuNTM0NjctNC4xNDM3MS0uNjk3MzItNS43MjU0Ny0xLjUwODU0LTIuOTY2'
    b'MjgtMy42NzM1OS00LjgxNzM3LTQuMjczMzItOC4xNDk5NS0uNjU0MDQtMy4zNTA3My0yLjUy'
    b'Mjc1LTYuMjE0OTEtMy45MzI0Ny05LjI0OTE2LjMxNTgxLS43MzY1LTQuNzAwODEuNDA0MTMt'
    b'NC4zMTE2Ni0xLjE2NDAxIDEuMzg3NTgtLjE5NDcyIDEuMTQxNjItLjgwNjA3IDMuNDkzNzEt'
    b'LjI4MzE0IDEuNzgwNTEtMS41MDU2MSAxLjc2MzI1LTQuMzQxNzUuNTY2MjgtNi4yMjkwMi0y'
    b'LjM2MjczLTUuMjk0NTgtNi4wMDE4OC05LjkzNTg1LTguNjUxNDMtMTUuMDY5MjEtLjY2ODIt'
    b'My4zNTAyOC42NjI4Mi03LjQ3NDk4LTIuNTQ5OTctOS44MDk0Ny0zLjMxOTg3LTMuMjMyNzct'
    b'NC45OTk3MS03LjU5MzIzLTYuODU2NDktMTEuNzQwNDUtMi4xMzMwMy0yLjk3MjczLTUuNjA1'
    b'OC00LjcyNDA5LTguMDg1MTUtNy40MjQ1LTEuMzQ5OTMuNDI3NDQtNi40MzkxOC41ODYxLTMu'
    b'OTEyMDUtLjkzODE0IDMuNDgyNDgtMS4zOTI5MSA1Ljg3ODU3LjU5NDQ0IDguMDk2MTkgMi45'
    b'NTE1NyAyLjUyNzEgMS45NjQ2OSA1LjIxMDg2IDMuOTk2NjQgNi4wNTc2NCA3LjIyMzM3IDEu'
    b'NTc2MDUgMy43Njc0MiAzLjYyNzYxIDcuMjUyNDkgNi41NDcyNiAxMC4xNDMxOCAyLjU3MjQz'
    b'IDIuNDE1MzcgMS4yNDM4OCA2LjI3NjQgMS45Mjk1IDkuMzc0MjIgMy4xNjYyOSA1Ljc0MzQ1'
    b'IDcuNDAxNjkgMTAuOTg2NjMgOS41MzIzIDE3LjIzOTkzLS40NjAzOCAyLjczNDk1Ljc1NTYt'
    b'Ljg3NTIxIDIuMDU0NTMtLjU1NjQxLS4xMjMyMS0zLjA5NzEuOTU1MzYtNy4yODQ1OS0xLjA0'
    b'NzgyLTEwLjE3MTM2LTIuMDkxNDktMy44ODgzMi00LjUyNjc5LTcuNjM3MDEtNi40MTc3OS0x'
    b'MS42MDg2NC0xLjMxNjAyLTIuODM0NzktMi45MjY2Ny02LjM4MDExLTQuMzkzNjctOS40NzM4'
    b'OC0xLjUzOTk5LTMuNTc1MjktMy43Nzc1Ny02Ljc4NDUtNS44OTM2Ni0xMC4wMzExNSAyLjEw'
    b'OTMtMi4yMDYzNiAzLjIwODA1IDQuMTQ5MjEgNC44NDQ4IDUuMjUzNzcgMy42ODQyMiA2LjUx'
    b'Njc2IDYuMDAyNzEgMTMuNzE1OTUgMTAuMDMwMTQgMjAuMDQ5MTUgMS4xNzUwNyAyLjc4MDI0'
    b'IDMuNjY1OTkgNS4yMTg4OCA0LjE5MjU3IDguMTc5NDIuNDA0OTMgMS43NzAxMi0uNzAyNDIg'
    b'Ny41MDMyOC43MzQxOSA3LjAyNzg1LjcxNzM3LTEuMzgxNzggMS40NDcyMy0yLjc1NzE4IDIu'
    b'MTU3MTktNC4xNDI3NCAxLjE0Nzk1LS41NDQyOCAzLjQxOTc3LS4xOTcyOCAzLjY5NTczLTEu'
    b'NDUzODYuMzk3NzEtMy44NjM3NS0zLjQ5MzIyLTYuNjc2NTEtMy44ODQ0OC0xMC40NjkzOC0x'
    b'LjA5OTU3LTUuMTczNjEtMy4xNzMxLTEwLjA2NjM1LTUuNzQ1OC0xNC42NjkzMy0yLjc2MDkt'
    b'Ni4wNjA5My02LjgxMzQ2LTExLjQ0NDMyLTguOTk4NC0xNy43NzEyMi0uNTc4MzUtMy42OTA2'
    b'NyAyLjQxNDY0IDEuMDIxMSAyLjQ3NzMxIDIuNzQzODggMi4xMjQ3NSA0LjgzNDc4IDUuMjI3'
    b'NDIgOS4xNzgxNyA3LjQyMjA5IDEzLjk5ODI2IDIuMDkwOTYgMy45MjEwNCA0LjA5MDI2IDcu'
    b'ODc1MjggNS4yMzk1IDEyLjE5MzE3Ljc4Njg1IDQuMDYwMjggMi40NjIxNCA3LjgxMzggNC41'
    b'NzU5MyAxMS4zNzAxNy4zNjMxNiAxLjYyMjY1LS4wNDc3NSAyLjg4NzEyIDEuMzM1NDkgMy4w'
    b'MzQ1NS42MzkyMyAxLjQ5MTA3LTIuNDY2MTEuNzM2NDktMS4yMzg1IDMuMDIwNjcuMzUzNTQg'
    b'MS40MzAxNy0uMzcxMTUgNi44MzIyMi0xLjQ0Mjc4IDMuNzU3OTYuMDk0MS0yLjUzNTI2IDEu'
    b'Mjg4OTQtNi42NTc5OS0yLjMzMjY2LTQuNzE2NTctLjk2NDcxLjgzNTYzLTEuMzMzNDYgMi40'
    b'Mjk3MS0yLjA3NDUyIDMuNTQ5OTctLjYxMDIyIDEuNTIzMTctMi44OTA1MSAxLjQxNTcxLTEu'
    b'MzM3ODkgMy41NzcxOSAyLjAzMDc5IDMuMDI0NzUgNC43MzM2NyA1LjcxNjYzIDUuMjY0ODcg'
    b'OS40ODI0NS40MzA3MiAzLjM1ODIyIDMuMjIgNS42MzI3NyA0LjkwNzY4IDguNTM0NDkgMS44'
    b'Mjk5OSAxLjg4MDExIDMuOTc1NjIgNy42MzcwNyA1LjgxMTEyIDYuNjAzNi44MjAyOC0zLjU3'
    b'NDgzLTIuMzE5NDEtNS45NjAyNi0zLjQ2NzU4LTkuMDY2MTEtMi40NTU4Ny01LjI1MzU1LTQu'
    b'Njg0MzUtMTAuNjEzMi03LjAyOTY3LTE1LjkxNzg4IDEuOTA2MTggMS4zNzQ5NCA0LjMzNTA5'
    b'IDIuMTc1OTQgNS40MjE4NiA0LjQzMTk4IDQuMzYzNSA1LjgxMjE1IDguNjUzNjYgMTEuNjgz'
    b'NDkgMTMuMTM5MzggMTcuNDAxMDcgNC42OTkwNCAyLjI1NjY5IDEuODEzMzEtMy42MDA2Mi4z'
    b'Nzc1Mi01LjQ0MjUzLTMuNTgzNzEtNy4yMzIzNC04LjQ5MDA3LTEzLjcwMjA1LTEyLjcyNDEz'
    b'LTIwLjU2MTYxLS45MTk3MS0uOTM4MDUtMy44NjA3OC01LjUwMTctMS4xMTQzOC00LjA5Njc4'
    b'IDQuODMzMDUgNS45NjQ4NSA5LjY2NjExIDExLjkyOTcgMTQuNDk5MTYgMTcuODk0NTUgMS42'
    b'MzMyIDEuMTE1NjIgNC41ODIwMyAyLjA0NDk0IDMuNjAwODUtLjczMzUtNC4xNDQ4Mi03LjU2'
    b'ODcxLTkuNDIxNzMtMTQuNDQwNjctMTQuMDM2Ni0yMS43MjkzMS00LjgyNDgzLTYuODYzNDEt'
    b'OC45MjM1My0xNC4yMDAxLTEzLjI1MzQzLTIxLjM5MjA2IDIuMjc4NDYtMS44NDM4MSA1LjI2'
    b'ODM5IDIuNzg1NDQgNy44MDc3NyAzLjM5MDg2IDQuMDYxNzggMi4yMTg1MSA3LjY4MjA3IDUu'
    b'MDUyNCAxMS4wMDc1IDguMjU1MjkgNS42MDQ0MSA0Ljg3MzI0IDEwLjk5MTc1IDEwLjAzMDM2'
    b'IDE2LjgxNTQgMTQuNjMxNjggMi45MDI0OSAxLjU4OTY3IDUuMTY1NTkgNC4zNjY2OCA4LjI4'
    b'NzEyIDUuNDAyMTIuMDUxNzgtMS4wNDg0NC0zLjE5MTg1LTQuOTg2MDMtMS44MjkwOS00Ljk2'
    b'MDYgMy4yNzEyNy45MjE1NiA2LjM2Mzk4IDIuMjgwMDEgOS4zODU3NCAzLjc5MDgxIDIuMDI0'
    b'NzMuOTk2NjIgOC4zNTkyNiAzLjM3OTQ4IDUuMTg0NTQtLjc0OTI1LTEuMDA5NjgtMi4wNjU1'
    b'MS01LjgyMTYtMy4xODM5My01LjAzNjEzLTUuNDI1MDEuODkzMzctLjQ4MDQ1IDIuMzQzMzgg'
    b'MS4wMjg0NSAzLjQ1MTAyIDEuMzEzMzUgMi41NDE5OSAxLjUyODE4IDUuMzk5NjkgMi4yMjE0'
    b'MSA4LjMxNzQ5IDIuNjMzMDUgNC4yNjUwOC0uMTkwOTQgMS41ODUxNS00LjYzMjY2LTEuMjk1'
    b'NTYtNC42NjE3My02LjYxMTQzLTMuNTIxOC0xMy4xNzExMy03LjE0NzQ3LTE5Ljc1MS0xMC43'
    b'MjIwOCAxLjM2NDI5LTIuNzYyOTUgNS44MjcxOCAxLjYyMzcyIDguMzk5NzUgMS40Nzg2MSAx'
    b'LjUwMzMzLS40NzI5IDcuMDI1NDcuNjYyNCA1LjA5Mjc0LTEuOTQ0MjgtLjgxNzYyLTEuMDAx'
    b'NjYtMi41MDg1OS0xLjAzNTEyLTMuNjc5NjMtMS42NDQ5OC05LjAxNTQzLTMuMjY1NDQtMTgu'
    b'MDQ4Mi02LjQ5MDQyLTI3LjA1Mjc5LTkuNzgxMTMtMy44NDE5OS0yLjU4Nzc5LTcuNzQ3NjEt'
    b'NS4wOTY1My0xMS42MDg2NC03LjY0NDcxLjU5MDI5LTIuMzY1ODEgNC40NjEyNy42ODIzNyA2'
    b'LjM4NjMyLjQ0MDQ0IDMuMzcyODUuODgxMjUgNi43NjMwOCAxLjYwOTAzIDEwLjI2NzA2IDEu'
    b'NTY2NyAyLjI1MDQ2LjA2MTk4IDYuOTY5NDcuNjM0MiA3Ljc4ODM0LjI1OTczLTEuNDkwNDIt'
    b'LjgwNDQ4LTguMDY1NzUtMi43MDc1LTQuMzEyMTEtMy43MzMwNiAxLjg4MzEtLjExNjA0IDcu'
    b'ODAwNzUtLjIzNDg1IDIuNzU1OS0uNDIyNjUtMy41Nzg2OC0uMzcxNy03LjMxNzg5LS4yNDM5'
    b'MS0xMC43NzM1Mi0xLjE5NDIxLjQ0MTg5LTEuMjc4NTIgMi4yMzAyNS0uNzk2ODcgNC41NjQ4'
    b'Ni0uNTQ4NjYgMi41NDg4Ni44NzM3NyA3LjcxMjI1LS42MjM0OCA4LjcwODY5IDEuNTE0NzYg'
    b'Mi41Mjk4Ny44MDk4OSA2Ljk3MzU2LS4yMzAzOCAxMC4yMjk3NS0uMDMzMzcgNC41MDU2Ni0u'
    b'Mzk2MTMgOS40NjIzOS4yMjU2IDEzLjY4MzI5LS44ODcwOCAxLjQ3MTkyLTIuMjkyNDkgNS44'
    b'NzMyNy0zLjAzNTk5IDUuNzkyNTgtNi4wMTA5OC0uMjkzNTktMi43NjA4Mi0uMzI1NjEtNS42'
    b'MDY1Ni0uNzc5MzQtOC4zMTUzOC0uOTM3MzQtMS4wMjM2Ni0xLjEzNTg2LTMuMTA0NjItMi43'
    b'MjM2Ni0zLjE5NzM5LTQuMjU0NzMtLjY5ODE2LTguMzIzNTUtMS44Njc3MS0xMi4zNTc4OC0z'
    b'LjMxNjc5LTguMzk2NDQtLjIwNDc2LTE2LjgyNjcxLS4xMjkyMS0yNS4xOTkyNC0uNjI5MTkt'
    b'Mi43MTM0OS0uMTc2NjEtNS45NDMzIDIuMjgwNDYtOS4wNjA0MSAyLjEwNzgtNC44MTU2LjQ4'
    b'Mzk5LTkuNzM0NTEuMDg2MjUtMTQuNDA1MTkgMS41NzUxNy0xLjgwMDc4IDEuMzk2MTktNC4z'
    b'MDQ3OC0uNjE4MDgtMS40MTkwNS0uOTc3NDMgMy42MDc1OS0uOTU0ODUgNy4yNTc2Mi0xLjYw'
    b'ODA0IDExLjAwMTg4LTEuNTUxMjMgMy44MDY3OC0uMTIxNjcgNy42MzQ0My0uNDA1ODEgMTEu'
    b'MTYzNTctMS45NjQ0NiAyLjE2NDA2LTEuNDY3OTggMi42NDI4NSAxLjAyNTgzIDMuMDY2NzYt'
    b'MS42OTYzNiAxLjk3OTk2LS43NTA2OSA4LjMxODIxLS4yMTkzNSA2LjgyNTI2LTIuMzA2ODMt'
    b'Ny44MjA0Mi4yNjU0MS0xNS42NDU2LjM1OTk3LTIzLjQ2ODk2LjUwMzM2LTIuODEzNzMtLjI3'
    b'ODMzLTYuNDAyMDIgMS40NjA0Ni05LjE4NjI0IDIuNzk5OTEtMy4yNjMwMyAxLjMxOTQ5LS41'
    b'NzA5My0xLjk4ODU1IDEuNDQ3MTQtMi4wNzYzNCAzLjQ2MzY5LTIuMDUzOTcgNy43NzI5LTEu'
    b'NTQ0NzEgMTEuMTM2NzUtMy43NzUxNyA1LjI1NzU0LTIuNDQ5OTIgMTAuMTk3NjktNS41NTAz'
    b'NCAxNS4zMjA4OS04LjI0MjQ1IDEuMzMwOTgtMS4xNzc5NSA1LjAzNS0zLjAxNDEyIDEuMTE2'
    b'MDYtMy4zOTUyMi0zLjA3NDY0LS43MDg5OS02LjM2MTY5IDEuMDYyMTEtOS41NDcyNyAxLjA5'
    b'ODY2LTQuMjAwNTkuNzQyMDUuMDA0NzYtMi45MTg3MiAxLjU4Mzk4LTMuNjI0MjEgNC45MDU3'
    b'OS0yLjUyMjA4IDkuNzA2LTUuMjgwMDMgMTQuMzk3NTYtOC4yMDQ2NSAxLjQ4ODUzLTEuMTM1'
    b'OTggNS44ODEyMy0xLjkxMDgxIDQuNDY3MjgtMy44MDY2My0zLjk3NzIyIDEuMzI4MzMtNy45'
    b'MTQ1NyAzLjIyOTQxLTExLjk4NjE1IDQuMzQxNDUtMS4zNzY3MS4zMjgyLTcuNjIzMTMgMS4x'
    b'MDAyMi00LjUzNzkyLTEuMzM1MDEgNS45OTY4MS0zLjk2MDUxIDExLjg5OTM2LTguMDY2Njgg'
    b'MTcuODQ1MzgtMTIuMDk4MyAxLjk4MDk3LTIuNjYwOTMuNTQ1ODUtMi43MjkxNy0xLjgzMTQ4'
    b'LTEuNjQyNzgtMi43NTMzNy44MzgxMS00LjgwNTQ4IDMuMDg5MTctNy4zNzAwNyA0LjM5ODEt'
    b'Ljg4MDM3IDEuNTQzMjctNS44MTQyMiAyLjg1MDA2LTMuMTk0NTUuMTc2MjQgMi42NTYxOC0y'
    b'LjMwODI4IDUuMjUxMjQtNC42OTM5NiA4LjAyMzItNi44NjQwMiAxLjQwMTA4LTEuOTUwNzQg'
    b'Mi44Mzc5My02LjU5NjM2LS45Njc5NS00LjQwNzUtMi40NTI2NSAxLjI5MTYxLTUuNjA2ODYg'
    b'MS40ODQxLTcuMzE2MTQgMy44Njk3MS0zLjAyIDMuMTM5My02LjA5NzM0IDYuMjU2MTktOS4w'
    b'ODE2OCA5LjQwOTQzLTIuMTgxNzMtMi4wNDU4NCAzLjQ2MTI3LTQuMzAyMSA0LjE1NjQ2LTYu'
    b'NDY4NTUgMi40NTExNy0yLjgwNzAyIDUuMDMyMTItNS41MzYyOSA3LjIzMTk2LTguNTM3NzQu'
    b'NDY1MTItMi40NjEyOS41NzI4NS00LjE5NDI3LTEuOTI1MjQtMi40NzkyNy0xLjIxNDM3LjUy'
    b'MjMxLTIuNDI4NzUgMS4wNDQ2My0zLjY0MzEzIDEuNTY2OTQuMzY1MzEgMi41Mzg4Ni01LjAy'
    b'Mjc5IDUuMTkwMjctNi43MzIzOCA3LjcwNzYzLTIuODkzOSAyLjQ3MDE3LTYuODI5MDEgMy41'
    b'MDc4My05LjM3NSA2LjQ0OTI1LTIuMDM0NDMtMi4xNzE4MyAzLjU2My0zLjgyMDc5IDUuMDAy'
    b'MDktNS4wOTY0OCA0LjA2OTQ5LTEuOTgwMTIgNi44MjIzNS01LjcwOTU2IDEwLjA5ODU4LTgu'
    b'NzE0MzUtMy41ODUyOS43MjczLTcuNzE2MDQuNTc5MzMtOS44MTU0NCA0LjE1MjY5LTUuNDI3'
    b'OTYgNS4xNTk0Ni0xMC43MTAwNSAxMC41MDA0Ni0xNi4yNjQ2OCAxNS41MDk2NS02Ljc3MjQz'
    b'IDQuNjk2MDEtMTMuNjU1MTEgOS4yOTgwMS0yMC42MDYxMiAxMy42ODQ5OC0zLjE3OTA4IDEu'
    b'MjgwNC03LjY5NzMxLjIyODA5LTkuMjAzMSA0LjA2MjA5LTIuNjU1NTYgMy43MzUxLTUuODAw'
    b'ODIgNy4wNzY1LTguNzYwNDEgMTAuNTY2NjggMy4xODE2Ny0uNzAwNjEgNi4yMDI5OS4wMjY0'
    b'MiA5LjA3NjIgMS40MzY5NSAyLjc2MTYxLjk2NjI1IDUuMTA4NzggMi44NzU1NyA3Ljc1NDc2'
    b'IDQuMDY4NTEtLjU5MDIxIDIuNjI5MDktNC4yMTcwNyA0LjYyMjA1LTcuMDcyMTUgNC4xMzk3'
    b'Mi0xLjc5Mzc4LS4wNDg5My0zLjQxMDk4LTEuMjYxNTEtNS4xMzQyMy0xLjc4MDI0LjE3MDY0'
    b'LTIuMDY4NDcgMS45MjUwNC0uMzk5NDMgMy4wOTYxNS0uMTA2OSAyLjI5OTU4IDEuMjQ1MTUg'
    b'NS40MTkyMS43NTk4NiA3LjExMzU0LTEuMjgwNS0uODg0MS0xLjgxNTQ1LTUuNTc1NTQtMy42'
    b'NDg5Mi04LjI5ODU2LTQuNjYzMTctMi40NzEyNS0xLjQ4NTA3LTUuMzAyOTItLjQ2MzEtNy45'
    b'ODI4Ni0uNDMwMTQtMy4xNzAwOC43MTk1NC44ODUxOC0yLjA4ODU1IDEuMzUzNDYtMy4xODU1'
    b'NSAzLjUwODQyLTMuOTQyOTkgNi44NjUzNS04LjAwODgzIDkuOTA5MTMtMTIuMzI0MS0uMjIx'
    b'MDktMy4xODUyNCAzLjMxMTA5LTUuNDM1NjQgNC40ODY0Ny04LjM3NDU1IDMuNDYxMDUtNS4w'
    b'OTk5NiA1LjI0NzM1LTExLjExMDg0IDcuOTAxNTUtMTYuNjUyNDEgMS4xMjk1OC0yLjMxMTc2'
    b'LjU0Njk0LTUuMDEyMzUuODQwNzgtNy41MTM4OC0uMDg0MzgtMS4zNTczNi4zOTY2My0yLjgz'
    b'Njc0LS4wNzg2NC00LjEwOTc0LTIuNDYzMSA0LjUzMTU3LTQuOTk2NTEgOS4wNTg5OS03LjM2'
    b'MTU3IDEzLjYyMjA2LTIuOTE0NC4xNjgzMi0uMzAwNDQtNC40NTA0MS41Mzk3Mi01LjY0OTcy'
    b'IDIuMjM5ODgtNC41MjcxMyA0Ljc2NjM4LTguOTc3MjYgNi44NjAyNC0xMy41Mzg5My4wNjA2'
    b'MS0xLjkwOTE2LjEyMTIyLTMuODE4MzEuMTgxODMtNS43Mjc0Ni0xLjg4NjY0LTEuNjQwMzgt'
    b'Mi44MzcyMyAzLjk1NTk0LTQuMzM1NDEgNS4yNjcyNC0zLjI3ODk1IDUuNDU5NTItNi4zMDcy'
    b'IDExLjEwMDU4LTkuNzI1NjUgMTYuNDU3NjUtLjMzNTQzIDEuODExMzUtMy45NTY2NyAzLjEy'
    b'NzM5LTIuNTA0OC41NjE3OCA0Ljg4NTEzLTguOTg2MTQgOS45MDA4Mi0xNy45Mzk1NyAxNC45'
    b'MTE3OS0yNi44MzE0MjEgMi4wMTM1Ny0zLjU3MDYwMiAxLjM2NzE0LTcuNzM5NjMgMS42NTQw'
    b'Ny0xMS42NTcwMDctMS45MzA1Ny0zLjA1MDU2MS0zLjI3ODA3IDEuNjQxOTkyLTQuODI0NTkg'
    b'Mi44NTM5NjMtMS45Nzg1OCAyLjQ1NzUzOC0yLjcwNjUzIDUuNjg0ODU5LTQuMjI2NTIgOC40'
    b'NDUwNTUtMi40NjYwNiA1LjM1NTM3LTUuMDIyOTUgMTAuNjc2NDktNy41MjgxNyAxNi4wMDgw'
    b'My0yLjgwMjkxLTEuMTU0ODQgMS42MTcyMS01LjM0MDgzIDEuNjU0NDQtNy42OTUgMi40MDMw'
    b'NC02LjIwOTI2IDQuNzk0MTktMTIuNDIzMTExIDcuMTg1NzUtMTguNjM2Nzk2LTEuMTk4MzUt'
    b'Mi40OTIyMDctMy44ODg4OCA0LjA4NDAxMi01LjE1OTQgNS41OTk4MzItMi4yODE5OCA1LjA5'
    b'ODg0OC00LjkzMTIxIDEwLjAyNTAzNC03LjQ1NTk1IDE1LjAwNjI5NC0yLjY5OTQ2LTEuMTc2'
    b'NDggMS42NDY4MS01LjMyMjAzIDEuNTI5MTEtNy41NzkgMS4zMDY5My0zLjc3NDAyOCAzLjAy'
    b'Njg5LTcuNTEyMDA1IDQuMjkwOTQtMTEuMjMzOTIxLS4xOTAwMS0xLjQwNDk3MyAxLjgwMDY2'
    b'LTUuMDU3MDg5LjAzMTQ2LTUuMTI3OTM3em0xNy4zMDI4NSA2Ny43MDEzMzhjLjYyMTI2IDIu'
    b'NDgyNDktMy4xMTg0NiAzLjYxMzkyLTQuNjU2MDQgNS41MzY5Mi0xLjkzMzA0LjcyMTQ0LTgu'
    b'ODQ0NzUgMi40MTc4My01Ljg2OTU5IDMuOTcyMTcgMS45NjY0Ni0xLjA0MTk3IDMuOTM3NDIt'
    b'Mi4wNzU0OSA1LjkwMTA1LTMuMTIyNzYgMi41MTI2NSAyLjM4NDkzIDYuMzE0MzUgNC45Mzc2'
    b'NCA2LjAxNzMyIDguNTc5ODctMi4zODgwMS41OTg5Mi0xLjM2ODc1LTQuNjc5NDYtNC4yMTE0'
    b'Ny01LjE3MDQtMS4zMTA0Ni0yLjI2NjY3LTIuOTY4MDktMS42ODgwNC00LjczMjQxLS40NDA3'
    b'Mi0xLjQwMjM4Ljc1NTgxLTIuODMzNzIgMS40NTkyNC00LjIxNDggMi4yNTM1Ni0yLjM0NzEz'
    b'LTMuMjA1NTEuMjU0MTYtNS43OTU5OCAzLjYzMTA3LTYuMTc4NDYgMy4zNDkxMS0uNTIyNzcg'
    b'NS4yOTk0Ni0zLjQwODU3IDcuODIwMjctNS4zMzU4bC4wNjkzLS4wNTcwOC4yNDUzLS4wMzcz'
    b'em0xNy44MDYyMSA2LjkyMTE0Yy4yMzIzMSAyLjgwMTc2LTQuNjk0OTEgMS41Nzk4NC02LjAy'
    b'MzA1IDMuOTQzNDItMi4xNDkzMSAxLjAzOTI0LTQuMzIzNDggNC4yMzE4LTYuMjQyOSA0LjIw'
    b'NDY2LTIuMTE5Mi0uNDEyOTUgMi41NDY3My0yLjQ1OTkzIDMuMjkwMDMtMy42MTIzOCAyLjY4'
    b'NTc4LTIuMTUyODYgNS40Mjc1Mi00LjEzNjM4IDguOTc1OTItNC41MzU3em0yMi44Mzk3NiAx'
    b'MC45NDc5OWMtLjU0NDg4LjUyMTI5LS4xNjI1NC40MTc0NyAwIDB6bS02NC41MjM5MSAyLjcz'
    b'N2MyLjkxOTU2IDEuMDk4MTkgNi4wMzA5NSAxLjc5NjA2IDguNTAzMDUgMy44MTQwMyAzLjE5'
    b'MzkgMS4xMzAwMyAzLjM0NTA2IDQuNzgyODIgNC4yNzIwMyA3LjU0MDgzLjA4OTYgMS43NzY2'
    b'My0xLjQ0NTg3IDcuNDMwMzctMy4wNTcwMiA2LjIyMDc3LjY1MDc5LTIuNjA2MDcgMi45NjI1'
    b'LTUuODE3NDIgMS4wMDk3MS04Ljc5ODM3LS4yNTc0OS0zLjI3NjgxLTMuNjU5NTItNC4xODc0'
    b'Mi01Ljk2MzEtNS43NjcyNi0xLjczNTA0LS42MTUzMy0zLjQ3MDA3LTEuMjMwNjYtNS4yMDUx'
    b'LTEuODQ1OTkuMTQ2ODEtLjM4OC4yOTM2Mi0uNzc2MDEuNDQwNDMtMS4xNjQwMXptODIuMjM1'
    b'NzQuMzE0NmM1LjkzMDY0LjI0MjkxIDExLjkxMDg2LjUwMjA5IDE3LjgwNjIxIDEuMDY5NjMu'
    b'NjU2OTguNjk0MzQtMS4xODQ1OS43MzYxMi0uOTEyMzQgMS4xMDEwOS03LjYzNzQ2LS4zNDc3'
    b'OS0xNS4yNzQwNy0xLjI3NjI3LTIyLjkxOTc2LS42NDMyMy0zLjU3OTctLjQ2MDI1LTYuNzA2'
    b'MTcgMi4yNzQyMi0xMC4zMzEzMiAxLjUwMjMyLTEuOTMxOTguMzc4MTMtNi4zNzk3Mi0uNjUz'
    b'NjQtMy4zMzY1OC0xLjQ1NjgzIDMuNDcyMjMuMzg5MDUgNy4wMDczMy40MzEzNyAxMC4yNDcw'
    b'My0xLjA1NzQyIDMuMDY5NTUtLjU1ODg0IDYuMzIwODItLjE4NTQyIDkuNDQ2NzYtLjUxNTU2'
    b'em0tOS4xMjMzMiA0Ljk3MDYzYzYuMTI2OC44NzIzNSAxMi4yODA1MyAxLjQxNTgzIDE4LjQ3'
    b'Mzc3IDEuMzQxMzkgMy45MDI2NC4yMTgzNCA4LjQ2Nzc1LS4xNzIxIDExLjk3Mzc5LjQ1MDA4'
    b'LS41ODI2OCAyLjU5ODYzLTYuMDMyNTcuMDkxNzctOC4zNjEyMi44NjgwMy02Ljg3ODMxLS4w'
    b'ODE4MS0xMy43NzAzNS0uMDgwNzktMjAuNTc2MjgtMS4yMTIzNS0xLjMxNzIuMDM3Mi0xLjcy'
    b'NTQ1LS4xNzAyMi0xLjUxMDA2LTEuNDQ3MTV6bTYuNjM4IDYuODU4MjJjMi41MjEwMSAyLjYy'
    b'NjI4IDYuMTI5NzggMy4wOTg5NiA5Ljc1ODI1IDIuNTA5NjEgNC4yNjg5Mi0uMjc2MzQgOC42'
    b'NDI4NS44Nzk5MSAxMi43ODM3NS0uNzA5NzIgMy42MDA1Ny0uMzM0OTMtLjI2MjQgMi4wMjY0'
    b'MS0yLjE0NzUgMS43OTE2MS00LjE4NDI5Ljg3ODM3LTguNDYwNjYtLjI4MzA0LTEyLjY4Njg3'
    b'LjI0NjU5LTMuMzc2MTQgMS4xOTQ1NS02LjE0MjU2LTEuNjUxNTQtOC41NjYyMi0yLjI4NDk3'
    b'LTEuODEyODUgMS4wNzA5Mi0zLjgwNDI1IDEuMzAzMzQtNS44NTIwMyAxLjE1MjQyaC04Ljgz'
    b'MDQ5Yy0uNTk2MDItMS45NjI1IDEuNjY1MDktMS4wNjc4OSAyLjg0MTA3LTEuMjU4MzkgMi45'
    b'NDIxOC0uMDIxMTcgNS44OTQ3Ny4wNDIyMSA4LjgzMDQ5LS4wMzE0NiAxLjI3NTMzLS40OTg4'
    b'OSAyLjUxNTUtMS4xNTgzNyAzLjg2OTU1LTEuNDE1Njl6bS0xMjAuMjcwNTUgMy45OTUzOWMz'
    b'LjA2NjA3IDEuMjYyMTQtMi40OTIgNC4yOTgwNy0xLjU4Njc0IDYuMjk0NTYuMTM2NTcgMi4w'
    b'OTQ0My4zODM1OCAzLjU4MjUyIDEuMzY2NTIuNjg5NS40NDk4OC0xLjM1MzEzLjg2NTk2LTIu'
    b'NzE3NzEgMS4zNTI3Ny00LjA1ODMgMS4yMzkxIDIuMDQ0MjQgMi44NjgyNiAzLjE4ODI0IDUu'
    b'MjIyMzEgMy4yMDg4OSAxLjAwNjIgMS43MjU5NiAxLjQ4NzgxIDUuNjM3MTUgMi41NDczNyAy'
    b'LjAyMzgyLjk2OTcyLTEuODY1MDUgMS43MTkxMS00LjAxOTY1IDMuMTE1MzktNS41NDczMSAy'
    b'LjI2OTU5IDEuMjk2MzItLjMxNDIzIDUuOTExMDUuMzQ2MDUgOC4yNzM5MS0uMTg2NjggMy43'
    b'MjQxNy42MDQ3OCA3LjQ1MTIxLjA3NzYxIDExLjE4NDUyLjMyNTc5IDIuMjIyNjgtMS44NjY5'
    b'IDcuODc5NjYgMi4wODQxOCA1LjE4MjQ4IDEuMzYzOTQtLjY0ODc4IDEuNTQyODUtMi41NzEx'
    b'MiAyLjM3ODc4LTMuNzg3MzQgMS41MTI5My0yLjkyNzYyLjk1Mzg0LTYuNDkzODYgMS45NDAx'
    b'NC05LjU5MDk5IDIuOTMxOC0uNzUxNTkuMjY5OTEgOC4xNDUzMiAzLjA5ODQ2IDUuMzIyNzQu'
    b'ODI0NzgtMy4wMTA2Ni0xLjQwNTktNS41NDY4Ny0xLjY1MTMyLTguODc3Njl2LTUuOTE0NDNj'
    b'MS45NjI1LS41OTYwMiAxLjA2Nzg5IDEuNjY1MDkgMS4yNTgzOSAyLjg0MTA3LS4xNDQ0OSAy'
    b'LjM3MDYyLjEwNDQ5IDQuNzI3NjUgMS4xMzI1NSA2LjkxMTQ1IDMuMjMyIDEuNzQ0NDQgMi43'
    b'MTI4Ny00LjI2NTk4IDUuMjg1MjQtNS40NzM5OSAyLjgwMDMxLTEuMTE5MjYgMS4yMjczOS02'
    b'Ljk1OTE0IDQuMDU4My02LjMyMzQxLS4yNjMzMiAzLjU5OTAzLTIuMjY3NTYgNi41NzYwMi00'
    b'Ljc1MDQyIDkuMDI4OTQtMS4wMTcyNiAxLjcxNTE2LTEuNDkwNjkgNS44NTM2My00LjQwNDM2'
    b'IDQuMTg0MTUgMi4xMTM2NCAyLjE2NzU3LS4yODU0MyA2LjcxNDc0LTIuODk0MjkgNS45NDU4'
    b'OS0uNTc2ODYtMS45MjY1MS0uNjIyOTUtNC4xODIxOC0uOTMwMzItLjg4ODM5LS4wOTEyMiAy'
    b'Ljc0Nzk0LTIuMDEyNjggNC45MjI1Ni0zLjAwMjE1IDcuNDAwNTUtMi4zNzU1OCAxLjMwNDQ1'
    b'LTYuNjQ3NTYgMi43MzM2Mi01LjA4NTQtMS42ODU3Mi4yODk3My00LjczNDg3LjYzMzQtOS40'
    b'NzQxNC4wNTE4NC0xNC4yMDE0NC0uMDU1MjctMS41NTI5Ni43OTA1OC02LjQzNzE1LjAxOTQ2'
    b'LTUuNDc2NzMtMS4wOTE2MSAyLjIwODc1LTIuMTM1NTMgNC40NTczMS0zLjIyODM1IDYuNjcy'
    b'Mi0xLjM1MjE4LTIuMDIzNjQtLjgxNDAxLTYuODAxMS00LjAxNjkyLTYuMzE2ODItMS43NzYx'
    b'NC0uMzUyODktMi40MDM1Mi0yLjQ3MzAxLTIuODQxMy40MDIzOS0uNzg2NTEuODUwMTctMS43'
    b'NjM2NyA1LjYwMzExLTMuMTc3NDMgMy40NjA1Ny0uMzQ0NjItMi42MTQ5OC0uMTI4MzMtNi42'
    b'NzU1Ny0zLjExNDUyLTMuNDkyMDMtLjU0ODcxLTIuMTI1MjQtMS4wNjc4Mi00LjI1ODAxLTEu'
    b'NjA0NDQtNi4zODYzMyAxLjc2MDItMS4wNjgxOCAxLjQ0ODIzIDEuMzQwOTYgMS45MTU5OSAy'
    b'LjQ0MTY0LS4xMDExIDMuNjEzMTIgMy43NjMzOC4wOTE5MyA0LjIxODY1LTEuNzgwOTguMjcw'
    b'NTYtLjU1NjgyLjU0MzM1LTEuMTEyNTQuODE3OTYtMS42NjczN3ptNDkuMzI4ODYgMTUuOTUw'
    b'MDhjMy4zNTMxMiA2Ljc5NTMzIDYuOTA3NDIgMTMuNTExOTkgMTAuNTA3NTUgMjAuMTk3MTUg'
    b'MS45NDQyNCA0Ljc0Mzc1IDQuMjkyOTQgOS4zNzYzMSA1LjExMjExIDE0LjQ4MTk0LS43Njg2'
    b'OSAyLjQyNDExIDQuOTQ2MjQgNS43MTMxNyAyLjE1NTA4IDYuMzQ0NC0zLjA4MTc3LTIuNDA4'
    b'MjMtMy4zOTk0LTYuMjMzNy00LjI0NzA2LTkuNzUyNTEtMi4wMTMwNi02LjI3ODE2LTQuOTE1'
    b'MTktMTIuMjYzMjYtOC4xMzY2MS0xOC4wMTgxMi0yLjMyMjY5LTQuMTMxMjYtNC4yOTUzNS04'
    b'LjQyNTU0LTYuNDYwNy0xMi42MjM2Ni4zNTY1NC0uMjA5NzMuNzEzMDktLjQxOTQ3IDEuMDY5'
    b'NjMtLjYyOTJ6bS02Ljg1ODIyIDcuNDI0NWMzLjIwNTg1LjM2NzMxLTIuOTEzMDIgMy43MDI1'
    b'MiAxLjA3NDAyIDQuMDc4MTcgMi4wNjQ5My4zMzg1NSAxLjUzMjMzIDMuMjU3OTUgMy40MDMz'
    b'OCAzLjc0ODg4IDQuNzA5NDYuMjY5MDktLjUwOTg5IDYuOTY4NzkgNC4zMzEzMiA1Ljk4Mzc3'
    b'IDIuMzIzNTMgMS44MjkwOC0uMTE5MTggNi41NjM1MSAzLjUyMzQ5IDcuNzcwNTYgMy4wMjc0'
    b'MyAxLjQ1NTQxIDIuMTY5MjYgNS4wNDM2MSAzLjU4NDMxIDcuNTMwMTkuMzM2NDYgMS45MDYx'
    b'NCAxLjQyNzYgMS42MTg3NiAyLjc0MzMxLjY3ODY5Ljk3ODk4LS42NDg0MSAyLjkzNzE3LTEu'
    b'NjU5IDIuNTY4NTEuMTMwNzktMS43MDY3Ny44NDg4OS0zLjQxNTQyIDEuNjk0MDMtNS4xMjA5'
    b'NiAyLjU0NTM5LTEuMzU5Mi0yLjYzMzU1LTIuNTY5NzctNS4zNDgwOS0yLjg2Mjg0LTguMzM2'
    b'ODMtMi42NjU5Ny0yLjAwNTM1LTUuMDgxNTItNC4yMzU5OS00LjY2Mzc4LTcuODk5NjguNjMz'
    b'NDktMi44MDk1Ni00LjcxODg0LjA1MjE0LTMuMzA1ODctMy40ODQzOSAxLjg1NDM2LTMuNTkz'
    b'NzItMi4yOTU3My0zLjEzMTM3LTMuMTUyNDItNS41NDMzNy0uMjM2OS0yLjQxOTM4LTMuODY1'
    b'NDctMi4wMjQzMy00LjA3Mjk4LTQuMTUwNTguNTk2NjUtMS4wNTA3NiAxLjM0ODc4LTIuMDAz'
    b'MzEgMS45NTA1MS0zLjA1MTU5em0tMTkuMjIxOSAzNC43MDAwOGMtLjUyNjI4IDEuNTY0NTYt'
    b'NS41NjEwMyA2LjI2MzI5LTEuODM4MjYgMy4yOTM4NSAxLjkyNTYzLTEuMTY0OTggMi4yMDA1'
    b'NC0uNDA3MzYgMS44NTI0MS0yLjk4OTdsLS4wMTAxNi0uMjE4My0uMDAzOTktLjA4NTg1em0t'
    b'Ljc1NTAzIDExLjE2ODIxYzMuNjM4NzcuNjE5NjItNC41MjQ2MSA0LjEyMTUzLTIuNzcxNjMg'
    b'NC4yMDk1OSAxLjA2ODEzLS43NzU1MSAzLjM1MDI5LS42NzY0MSAyLjE2NTExLjY2OTM3LTEu'
    b'NzY5My41NDQ0LTMuNTM4NjEgMS4wODg4LTUuMzA3OTEgMS42MzMyLTEuMzE4NTUtMi44MjUx'
    b'NyA0LjQ3ODk5LTQuMjM0NzIgNS44NTE1MS02LjQ0OTI0bC4wNjI5Mi0uMDYyOTJ6bS4zNzc1'
    b'MSAxMi4wNDkwOGMyLjk4NzM0LjA5MjY3LTEuNjM2MTUgMy4xMTEwNS0yLjQ4NTMyIDQuNDA0'
    b'MzYtMy4yNTkxNyAyLjY0OTUyIDMuODc1NDUtMi42MjY5OCAzLjMwMzI4LS4wMDY3LTEuMzY1'
    b'MDcuOTU3OTUtNi4zMjA2OSA0LjA3NTM3LTguMDMzMDQgMi4zNDk5MiAyLjE0MzAyLTIuNDM5'
    b'MTMgNS4yMTUwNC00LjAzMTQ2IDcuMjE1MDgtNi43NDc1OHptLTE3LjkzMjA0IDEwLjc5MDY4'
    b'Yy0uMTY1NjEgMi4yOTkxMy0uNjA0NjEgNS4xODk4IDEuNjA2OTkgMi4zMzEwMiAyLjQ2MDQy'
    b'LTEuNTEwMTYtLjI1Nzg1LTEuNDQyNzMtMS42MDY5OS0yLjMzMTAyem0tMS4wNjk2NCAyNy44'
    b'NDE4N2MtLjA1MzY4IDIuMTYtLjg2OTQ2IDUuNTk2NzggMS45ODE5NyAyLjg5NDI5IDIuMTEx'
    b'MzctLjkxODAxIDMuNjkxNDMtMi41NzU4LjI5NTM4LTIuNTQ2OTgtLjc1Nzc1LS4xMjMxOC0x'
    b'LjUyMDAxLS4yMjk1OS0yLjI3NzM1LS4zNDczMXptLS41MzQ4MSAyMy41OTQ3OWMxLjg5ODE5'
    b'IDEuMTU3NzMgNi43NDcwNSAxLjQ0NzMgNi42MjQxNyAzLjYxMDA1LTEuMzU4ODktLjIxMTMy'
    b'LTYuMzg0NTUtMS4zNjk3OS02LjYyNDE3LTMuMDA3Mjl2LS42MDI3NnptLTguNjUxNDMgNzku'
    b'NDk4NzRjLTcuNDMwNjkuMjA0NjctMTQuODg2NDItLjAzNTQ4LTIyLjMwNDk1LjIyMDIyLTMu'
    b'MjA1NzQgMi4wNDMzNi02LjkxMDYzIDMuMzg1NzMtOS40MTg0OSA2LjM0MjI4LTEuODk3NTcg'
    b'Mi42NjcyOCAzLjE4NzA2IDQuOTUxODEgNS44MDA2MiA0LjM1NDAzIDEuMzE3NTcuODc1MTMg'
    b'Ni4wMjE5OC0uODM3MDggNS4yMjIzMiAxLjYzNTkxLTEuMjMxMTkgMy41NzA1Mi01LjI0Njc0'
    b'IDQuMTk3OTUtNy44OTYzOSA2LjM1NDg2LTEuNjM0NDkgMy4zOTQ1NyAyLjI0NDM1IDcuNjEx'
    b'MjMgNS4xNTkzOSA0LjM3MjkxIDEuNzI3NjktMS42NDEwNCAzLjIxODQ3LTEuODI5NzIgNC40'
    b'NDI0LjE5NTMzIDIuMDIyNTkgMS41ODU4NS0xLjQxNzA0IDUuODU1MjEgMy4wMTM1NiA1LjYy'
    b'NDcyIDIuODk0NDQtMS40NTc5NiA1LjQ3NzItNC4wMDQ2IDguMTk1NzEtNS45MzUwNiAxLjgw'
    b'MzgxLTIuMzA2MDIgNC43MjMyNC00Ljg2OTk5IDUuODY2NzktLjUxNDE5IDIuNjQ4NzkgMi4y'
    b'NjU0IDUuOTcxMzUgMS43MDI2MyA5LjEzNjU1IDEuNDkzMzcgMy44ODc3My0uMTMyOTUgOC4x'
    b'NjgwNy0uNjU0ODMgMTAuNDAyNDMtNC4zMTczOSAzLjYzNDA2LTEuNzM2MTggNy4wOTg1OSAx'
    b'LjgwODk3IDguOTMxMDggNC42NTM5MyAyLjQ1MzUyIDEuNjExNDggNi41NDUwMyAxLjgyNDM1'
    b'IDUuMjk0MjQtMi4yNTc4My0uOTYzNzgtMi42NzEzMi0uMTMwMTYtNS40OTU2NiAzLjA4MDgy'
    b'LTMuNzc0NDIgMy41MTc0MS42NzE1OSA2LjI0Njg5IDMuMzM1NzEgOS42MjA5IDQuMjY1MjYt'
    b'LjIwNDIzLTIuNTY0ODEtLjIzOTQ0LTcuMzk1NTkgMy4zMjA2Ny00LjExMzE3IDMuMDAxNDgg'
    b'Mi4xNzQ1OCA2LjEzNjU3IDQuMjgzNyA5Ljc2NjU4IDUuMjQ1NzIuMTI5NTItMS41MTUyMS0u'
    b'MjY5OTMtMy4xNzI1Ni4yMjAyMi00LjU5MzEyIDIuMzMyODktMi4zOTgwOSA3LjAwMDY4IDQu'
    b'NjM2OTYgNS45NzczNS0uNzIzNTcuNDg2MTItMS44NDAwMy0yLjAzMzktNS45MDgzNy41MzQ4'
    b'MS01LjYzMTMgMy41NDU4MyAxLjQ5NTY3IDcuMjg3NTEgMi41Mjk1OCAxMS4wNzM4MyAzLjIw'
    b'ODktMi41MDY2Mi00LjE2ODMtNi45ODItNi40NTc4NC0xMC43OTA2OS05LjI0OTE2LTMuNjc3'
    b'NTgtMS41MzA3OC03LjU2NDQzLTIuNzQ0NzEtMTEuNTg3ODMtMi42Njg1Ni00LjM0MTk3LS4z'
    b'OTU4NS04Ljc5MDIxLS4yMTQ4NS0xMy4wNzQ3LS44NTA2LTEuODM0ODMtMS4zMzMyMS0xLjUz'
    b'MjI5LS4xNDI4OS0xLjE5NzM3LjI0NzM0LTIuNTYxNDggMy42NzEzNS03LjEzNzggMi45NjAz'
    b'Ny0xMS4wMTI2MiAzLjY1MzU0LTUuNDEzNzYuNTE3NDctMTAuODgzMDcgMS4wNTg4NC0xNi4w'
    b'MTEyOSAyLjk4NDQ3LTMuNTQ0MjIuNDYxMTEtNi42Nzk4Mi0yLjY2NTU2LTkuMjQ1NDYtNC44'
    b'NDYwNC0xLjEyNzQ2LTEuNTYyMTQtMS42NjE1NC0zLjYxNDQ4LTIuNTIwNDgtNS4zNzgzOHoi'
    b'Lz4KPC9zdmc+Cg==', 'US_SC')

US_SC = b64_US_SC
index.append("US_SC")
index.append("United States of America South Carolina")
catalog["US_SC"] = US_SC
catalog["United States of America South Carolina"] = US_SC
country["United States of America South Carolina"] = ('US_SC', '', 1)
lookup["US_SC"] = ('US_SC', '', 'United States of America South Carolina', 1)
lookup["Columbia United States of America South Carolina"] = ('US_SC', '', 'United States of America South Carolina', 1)
lookup["United States of America South Carolina"] = ('US_SC', '', 'United States of America South Carolina', 1)
details["US_SC"] = {"continent":"Americas","capital":"Columbia","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_SC"] = ('US_SC', 'United States of America South Carolina', 1)
regional["United States of America South Carolina"] = ('US_SC', 'United States of America South Carolina', 1)
#----------------------------------------------------------------------
b64_US_SD = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNDExNyIKICAgd2lkdGg9'
    b'IjE2MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1NvdXRoX0Rha290YS5zdmcucG5nIgogICB4bWxuczpp'
    b'bmtzY2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIK'
    b'ICAgeG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFRE'
    b'L3NvZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5'
    b'OS94bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxu'
    b'czpzdmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJk'
    b'ZWZzMTQxMjEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcx'
    b'NDExOSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2'
    b'NjYiCiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9'
    b'IjIiCiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdl'
    b'Y2hlY2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXll'
    b'ciIKICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNDEyMyI+CiAgICA8'
    b'aW1hZ2UKICAgICAgIHdpZHRoPSIxNjAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHBy'
    b'ZXNlcnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5n'
    b'Om9wdGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jh'
    b'c2U2NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBS0FBQUFCa0NBSUFBQUNPMUt6WUFBQUFC'
    b'R2RCVFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRU'
    b'QUFBT3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQW8KRFVs'
    b'RVFWUjQydTE5ZDN4VTFkYjJQdE43NzVsSk11bUZkRklKUkhwSEFlbE4xT3RWVWJDZ0tPQUZ4'
    b'RUt4SUZ4RnhBSXFGaEFCcVFFRApFZ0xwdlNlVHpDU1p5ZlJNN3pQbmZIOE1ScVRvdmUrOXYv'
    b'Y05uL1A4TmJQUFB1ZnMzMzdPMm52dHRkWmVHd0xydndNaC9QOExWS2dMClFnU0hFQ0k0aEJE'
    b'QklZUUlEaUZFY0FnaGdrTUlFUndpT0lRUXdTR0VDQTRoUkhBSUlZTC94NGloYUo2SktyNjFa'
    b'RXZDRDZhWmoybW0KL2YzU21EZXptVDNENVh5Q0JZZnlod2dlNlNDaXZRQ0FOeEsvWHhWK0ZR'
    b'REF3dHAzSkgrRGdRTERGVWhvNzQvcW5KVEx1Mzh4SlAyUQo4ejRhZ2dFQVpMU25jdHltMWdu'
    b'clF3U1BVS0FoZUFhLy9rVHV1L1hqWDRFZ0JJLzJUZVkyWTFFQk5BU1RVTjVrbW5LNEpobmpO'
    b'bm5KCmVpL3RuNzFUdzRrR1B0NENBTmlXZUt6V0hCVkIwZ2MvQlR6S1YxbTBPWXFzQ3hFOEls'
    b'REE3cEpQZWZiYjBYdkphSGZXbGJjUkJLbzAKeGM0UHE3VE1YSDBvYzcvQlI4MWx5bjZUWUpU'
    b'WDRjY0RBQmhZWndCQjJmeUVkTHJpOFlqTDY1b2ZzZmhKNFNRakFHQytxSXFQTjZ0Ywp6SVZo'
    b'NVFmU0Q0NmlEZHpYL1lPNWY1dis5OGlmOVY3YUw0YWtXZVViQkFUenQ2UDNCaEFVQUtCcUtK'
    b'cUE4c1grdkVkbUYzeVFjaWlICktmdEVNZkZYQ2ZiRVVEUkx4TmVYUzhwKzBTYzVBb1FENlov'
    b'Q0FIb3o2VHNJQUNsSjErdmdQU1c5WlBHVE9pYzkzK2ZrL3JOM2FvZE4KRkpMZy8yMWdVUUVB'
    b'QUF5Z3ZTbUhmREM2eVJyK3N6N0Y0aWZORDZzRUFQUzdPR28zSTRha0JRQlVtV05TYmhIQnE0'
    b'WkVEQVRQRlZYWApteU1YMWF4YkdGYk93Vmx6cnI1NVZwT2g4OUNrWkYwS3ZUK1gyYTEwc1gw'
    b'd3BxaHN5N0hCUEQrQ1RxQU9iazg4K21MTUdRN09kdC8xCkZYVGZoZXlzamI0d2x0VytvUHA1'
    b'RklTVWozdXQxSmp3VXN0eUFNQ20rQk5UdUUxRlpWc0FBTytPK3VxS1B2bU1OaE9IOGdjUVZG'
    b'Q3kKNy9XdCtHQTBBT0MxK0I5OU1GcENNckt3OWljYkh6Zk9lRnhTL0pIYXpjaGpkZjg4NW8z'
    b'amc3bmVBR1lTcjNuY3RhMERMdmI5cEtDQQpnb2Z2TDRJMUhzYWUxQzlyek5FeWg2REJFdmxK'
    b'K3NIRC9VVldQNm5ISVhnNTlxZEQvUSs0WWR4RlhWcVhRd2dBQ0NBb0JFQi84RFQ0ClYrNUxq'
    b'WWxsUXdrNGxQKzhOa1BoNU0wVlZRKzQySzAyeWFtOGQ3N3VIN3UyYWZWcFRWWXlWWlZNVTVi'
    b'b1I0V0c2UDgrOGxqZHF5TisKaVNacis1eWNOenZuN2t2OUFvL3kxWmlqdXV6Q0FsWVhBR0RR'
    b'ell5NCtLSEpSLzVQM25KU25WMW5rUUlBRGlvbXBETVVGSXc3a3k3ZgpKNS8yNjNDSGtOQWVB'
    b'TUFDVVFVRjR3NFIvRi9EenVSdmptVHRXeVFxYjVydzhnckp0WGRsTTMwSStsak9ucjJwaHho'
    b'WXg4Ky9paFNNClFILzhuQlI2djVUMEw2MS9QcEpQMmRTMjJCWEFEYmpZMmZRZUFNQm9SdTlT'
    b'eWZYdlZma0FnQW5jMXBJeGI3RHZoeW41UHBpRDArbUsKYy9rN0VrcmV0L3FJYzRTMTM0N2Vt'
    b'M0o1dHg5R2JZdy9hZlJRL2ltZnBuWXo3cnA4TW5pb1hYYmhyWVUvNUx4djhaTWVxL3Y3cllX'
    b'WgpkRGtDUWZYbXlMdStmUnluL1ZqMit3TXVUaEpWdWEzajRaM2RjNEkyc3FieEw4dWR2Q2sz'
    b'TnFwY3JOQXk2VDlDQk1sZzhOQ3NQaUlBCjRDZDExbzJodUluYzVvT0tpVTgyUFA0SGQwM2hO'
    b'cTBNTHkyNCtyckdjNVArVWJTQnVjSXFCRUE3dStZTUV5OGw2YzRXN056Wk5lZGUKQkpjYUVx'
    b'VVg5K1d4WkgxT1RvK0REd0FRRVV3WEM5NzZjbUNjekM3WU0rcndndXJuUTBQMGY0VHJ4bmd4'
    b'eWZoRVpFblF6Q1FtR1B1YwozRCs5SzR2Wkt5WHB6dVh2b0dKY3daTFhFNCtpSUFRTndSdmpU'
    b'Z1pMT0RqYmhZSzNCWGp6clhicG15TWJoQXovZGdid2wvWEpRWFpaCk9IdHh3VnRWcHVpbkd4'
    b'OTdSelpyYWUzYTBCejhQOFIwZnNQWi9KMFBDbXNNWHVxSzJtZmVIZlhWbGNMWEd5ZHNxRERG'
    b'WHRTbDNsYjUKdSt3UEVxaUR0NWJrTUdRQWdBeUc0bFRlTzNpVUw0WGUvNkNnSm5ocHVlUmFQ'
    b'R1dRaVBhZXl0MGRSMUVEQUhJWXZ5TTRsZGIvUmNiSApkMjNWSitrSFZTN1d5dG8xd2ZuZUI2'
    b'TWhDTW1reTFHM2ZCQ2hJZnJQa2NPVUhVZy8rRmJYUTYwMjhhcndxMVdtbU1TUzl5WnhteFZP'
    b'CjdpK0dwRHZySjFPVmRRKzhzcVZqd1h1eW1RRUVGVTQwOFBEVzRLWHhuTmJQTXo5R0Evd1F5'
    b'UEVERmdBQUE0WmVpU2xtRXd3RjdLNWcKbldpeWxvV3pEM2twQkpUdkh3bkhYNG85WFRVVWZk'
    b'ZUdQZCs4Y3NoTDhjSVlBRUEyczJkaFdQa0NVWVdZT0xTK1pmbWVuaGtoZ3Y5VgpQQlp4NVlC'
    b'aVVxMDU2a0wrMnppVW40cHhwMXplZmFpLzZGNzFyVDRpRWUzZGxYeGttYmpzMGJvbm95ZzZB'
    b'SUFXbW81d1Y2S28yZU5qCjZRQmd5MXY3c2xNaTVVcERmbnBVRWsxQkpxSjBWQzlzcTBMcER2'
    b'T2dpOW5NSG91UDlIbkd4NGxVRlFEQTRpZmQ5VVZCSzhlcThLdGIKRW81TFNicURpb25ybWg4'
    b'NW1QSEpYVCs3RU1IM1JLa3g4WXVNL1p2amYzeWpjOTdPcmptMTQxK1ZrblRLZSt1cnczeWsw'
    b'ZnV1Rk81UwpNdmNPOGxRQ3Z2RFU1VWFOWGhVYjZmdjZwOHJYbnByeHdvNGZzQmgwZm5yVSs0'
    b'ZExabzlQUFhhaDl0SDVCV0wrcDM0bTZuM0t6eEdXCmRTUzBKZmdjbTUvNEI4Mzd4WkJzYmla'
    b'UDVUWGkwZjdISXk4ZjdoL1hZSWtNTFpQK1BTUlRsVzRZRzBQUlRPTTFQc0JweS83bFRUK0MK'
    b'dnFraDg1cGNBZHoxb2ZqaGhlKzNvL2N1RnQ4SXdHZ05jeCthdjZpa1FtYTJ1WjVZV0hqa2RK'
    b'WEo2cXh2RzZCUkNOSGhYQ0llNi9MNApTQVNjMWU1T1N4RDNEdWlOWm9mVDdRVUFQTHQ4UEJh'
    b'TnVGVmZDazNQbzFDQlR4VVQvdGJ3UlBEaE9KUi9NcS9aQjZOdm0vdHhLSDk1CjBXdHNyQzI1'
    b'NUYxSEFCK1M0SDhQclRZeEZlUGFuL2FweVVlWlVmN0tNTHNBQUN3cVVGeXcxZUNsbnRlbUgx'
    b'UGxYZENsVy8xRUU3ckkKSmYyeXBkZnVVUGZ0LzY1MDJhd2NyODhmRjhtdmJKS3ZmM1F5ajAw'
    b'TkJHQU1CZ1VBOFB0aE5CcGx0aml6a2lVblN4cFh6eTJZOHRqZQpONStqdmZyZXlZekVnb0lV'
    b'R1hsZ3BjVlB3cU44VTNoTnN3UjFjMFhWWEp5MXNIVGJiUzJrWU54U2ttNWx6Wm9SeXk2NEg1'
    b'ME5RZEhSClR2ODdBK3NJL3RWNWFBYnFSa25TMmlPbnE5TVRKZCtkcTJIU1NNdG01WkNJT0FB'
    b'UW85a2hFYktVR2hNT2k5SG9MUjZ2UDFMTU5wb2QKRWdIRFpIVXhhRVEwQ21WenVGRW8xSjdE'
    b'SmV0V1RqaGYycnA2WHA2cTdUMlI0MDBhOXVZU1MrMW1pSXYzMzJZcGd5RGs4WWpMQjMvMQpS'
    b'WTVNM0gvT0JnQkFBRUVsMFZScDlMN2czeUgyZXpqK0tpNkwrdjM1V3J2VFF5TGdIcG1iRHlP'
    b'd3crSHhldUVPdWViaTlUYVQxWm1SCktPbFM2T1JLWTdpSVZkZldYOTRnaHlCb1VHdkc0N0Fv'
    b'Q0NJUjhSQUtuQzl0VFkwUHUzQ3RIVVhLWkhHVGFaNHp3VmNjN2k4NnA4MjQKVXp6cXpGRWp2'
    b'Sy91UzRLREhDOFIzd0FBS09rSExialpweTQzNG5HWVpiTnoySFJ5YXJ6SWJIWFd0QTIwOTJx'
    b'WWRCSUtCVTNJalUrSgpDM041ZkxHUnZQUkVDUWFEVG93U0prUUpEQ2E3UHdDYnJJNGhpeE1B'
    b'SkVMRW1USW02WWZpT3JYZTR2VUZ4bzE3U09lU0JEbmUwTHBNCjhTOVlWMElFLzlmUTUrUStH'
    b'MVZzb20reVVwYThkNmpFNXd1WXJFNDJuVUlnNHJvVnV0TGFIanFWbEJ3anpFeVN4RVh5YUJR'
    b'aWlZQ2oKVTRoRVBCYVB3MUJJZURJUng2QVNveVJjSEJadHNqcDViRnBaWFErVlFyRFozZE1L'
    b'azh3MkZ3R1AzZjNaeFpWTEhqVllnY1BhdUs3NQprVDkyTzRibTRQK3NsUkR5VmVhSFVXU2R6'
    b'VSt3K0VsbUw5bm1KOHlNeEhEU3ZscS82OFEvWDF2MC9Ocy9QTDIwU01pbU9qMytLNVdkCk9h'
    b'bVJDVkVDRFBxUDdIUUlnZ0FBQWdIWTd2SzYzYjZ5K3A0aHN6MDlRWUpDUVNJZTQxUko0N1Zh'
    b'V1c1cTVPd0pLVzdaRTJVcUd3UHIKcEdHZE5MU0xqbk0ybUNPWDF6NXpyeWVQNDdUVDBLNHoy'
    b'c3dRd2JlTUpCQThISGVCZ2hBMjFxYjMwbTZ0a0VidnF5N2FHQXpXQVFENApBcmloQkhsMW0x'
    b'RS9aTDllMS9QVzh3L1NLSVRLSmtWa0dMdXhRemxuUXVxZkQvSUIyT1h4a1lrNENJSThYci9U'
    b'NVMydDZWYnBMRGtwCmtWSXhLeEJBRHArc21EOGw0M0psNTlUOGNHRnZEQWJsRGQ3b2diRVpW'
    b'M2EwMjhKdSt3UUJBR1BaSFFvSE41dlo4MXowK2JIWHRvNkUKamgwUnRtZ2UzcXFiL3NSWFdS'
    b'OCtLS3dob0h3RnJNN2lncmR1cTlOb2lkalZQV2Y0cjU3N2NaL0dXMVlyVStzdDI1K2JUU1Jn'
    b'ajErcwp4NkJSeFdWdGNaRzhQMzJqMGV4d2UzMGtBcTV2Y0FpR0VWbS9ua2tuNWFSR1hxbnNE'
    b'QmN5aTh2YVBUNy9rcG1qRDN4L0xUTkpjdktLClRNZitjUGplelcyTGJtTVhBSEE2ZDFjK3Ez'
    b'c0t0MmxWZU9rNWJVWXFyUytNT0JRaStDWU1YdXJjcWhkTlB2S0hxWi9yWmp6eFdjYUIKRStx'
    b'Y082dHQ3NXpYYWhNREFCeUltQ3hlcUZBWkIzV1dpZm54RUlDb1pNS3kyVGxrRW43QnRNeUVL'
    b'TUVmdjg1cWQwTVE4UG9DSnFzegpNb3lOUWtISk1VSzN4MGVuRU5jL09rbWhNbnA5ZmhxWmdF'
    b'YWpVdVBEVEZabmwwSkhsaXh4d0VJQVFMMDVjay9QOUR1ZmVjMll1RUJVCmNXd3diNEdvUWtR'
    b'dzlUbTU4MFZWSVNYcjEra1FRSDFPN25sdCtwN2VHYVhHaExYUnhXdWJWeHU4MURzMFozU3RP'
    b'V3AxeEM5RC9FK3YKTk1KVENwT3VWbmVQejQ3M0IyQVduZXgwZTVzNlZUZ3Nta2tqb1ZBM0Zh'
    b'SXVoZlo4YWR1QXhqU29NdzlaSEFROE5oQUk0SEVZanpmQQpwSkV3R0pUUEg5Q2JiRmE3bTBZ'
    b'aDRuRVlNWitwMWx1bWowc200TEVCR0JGdzZMMERoaWxqRWk5WGRvVkg1UlBzSjJaWGJoaDAz'
    b'OFZpCnF2WXdkeVVmc2ZoSWk4VGx6MFJkYkxhR1g5Q2xkLzgrM0NCa3lRSXdBZ1VRVkpkTmVO'
    b'ZG9aQmJPenNBNW1xMlI0cVJKSlVmT0hUcFIKdm1YTlRMUE42WEI3NjlzSDluNTV1YWExMytQ'
    b'MTB5bUVPQ21mdzZCMEtyUTkvZnJoMjhkbXhaUisvU0tDSUJBRXNSa1lBTUNKbnh1awpZWnlN'
    b'SkFrV2czYTVmVmE3QzBGQVVvelE3ZkVydFdhejFjSG4wQ2NYSkx6NjNpbVZ6cHlmT2x0dGpv'
    b'Z2lhWTBlU3IrTGMxdmJlaDA4CnRaczVVMUQvWXN1SzcxUUZXamM5cEVYZlJDUkpQNE5mTDNN'
    b'SVpBNUJuNU9EZ1FJU2tsRm12em5NWnRMbDR6anRPY3llYkVaUERFVUQKQU5BUTExRVRkMVky'
    b'S3BKaWhCcUQxVGhrWnpQSmJDYlo3UW5valpieUpvVkNhYXhxVmd5b1RRd2FrVWtqUlV1NEJy'
    b'TWRBTERqaFlkNApiQm9laDJIU1NHVzFzczkvdlBIRmorVUFBQ3FaOFB5cUNZdG5aRWVJV0FF'
    b'WWhtR2tyVWVkbng0VjFMUlZXclBlWkI4VksxTHJMYmpCCmZ3amNId0lBdEc1NnRTVzZ4aFIx'
    b'U1o5Nnd4aDNVMWFnQUFuakRVYWVoR3pSdjRHUHR5d0lxNGdoYThURUlTK01rVHQ1SzJyWERG'
    b'LzEKQWZUNm1ETy9VMWk0eTA2Vk5OVzI5dGUzRHdBSXFtL3JuMW1VQWtFSUVZOGpFTERoUWhZ'
    b'QmgrR3lLRE9LUnBWV3k4eFdKNTFLbkRjNQpYY1Jqd0RCQ0pHQWIycFdWVGZMeUJubCtSclRQ'
    b'SHhpYkZhdlVtSjVjWE1TZ0VpMTJGdzZMZG52OGVXblNRQUEybWgwUUJBRUllTHorCktZL3RU'
    b'WWtMMjdoaU9SajRFQURBSjFobUVlcEdVUWUrVXhZTXQyc3F2K21acUF2VGI3d2EvTXZBT3RB'
    b'UWJMeGpvdm5MRVZ4cGlobGYKOWc4TUZIRE1YbFZVdGlXTU1DUjMvS1lHTjF2Q0M2OXRPNS8v'
    b'OW5EQUJrU01VbXByUlR3NmcwcXFhT3hoTThoV3U2dTBwdHZoOHNaRwo4SnE3Vk5FUzdwVENK'
    b'QndHSFNGaUpzY0lSOFdLd3ZnTUdFWTY1QnI5a0NOYXpESmJuYk1mU0NFUnNmbHBVb21BS1Zj'
    b'WjNCNmZGUVVFCkhKckQ1YUZSaUJBRU5YZXJSRnk2eGVhc2IxY1Y1Y1RFUy9teEVWeUlHSE5y'
    b'dzZaWHZISnJ4RjJIVFRTYTBYc2cvV0E4VloxQVZ2RUoKbHUyZDgvN1J2dkN2UGtUalVUNFBq'
    b'STBtYTh2R2JSR2V2M3VnREF0blA1WDdUaUc3dytCUFlSWTIrQU93ckYvdmNMZ0hEUlkrbTM3'
    b'ZworOUtKK1FtNUtaRkh6bFRucFVtOVBuOTkrMEJaYlkrUVI5dnh3dHd3UHFPNHJNM3A5dnA4'
    b'QWJHQXFkU1labzlQOWZyOFdDeWFpTWY2CkEzQndLSllyaloxeTdla3JUZWV2dGVhbFNaZk16'
    b'STZONUgxNXNtTFRrOU85UG45NWcveWhpV24rQUd3cFMyVmpXaS9yaytkV3JiOXQKTkVaRHNH'
    b'UDJxaS82SG1peWhuZmFSUjAyMGFDYkdacURRVVhSNWlpeVR1K2hjZkhXdlQzVDZpM1NzNW83'
    b'emZxQWdQSjlsZlhQc2JFNQovSXk5d1pLcVpvWFdZUFVIWUttWTgvT045c29tUlc1cXBNZnJi'
    b'K3BTTVdta3ZEVHBpenVQang0bDhmcGdCcFVZZ0JHejFmbkV3ckZ6Cko2ZVJDTGhXbVJvQUFN'
    b'Tkl2M3BvVUdjaDRERWNKb1hOSU91TXR1NCtIWTFDWk5GSUtwMTVhbUZTWENSZmE3VHkyVGV0'
    b'THRxNk5kZGsKdFN0cW4zSEQyRHNiMlRKeC9kTHF0VTNXOEpBdCtqZWMwMlpjMFNkM09ZUURU'
    b'azR5VFJsR01KMjltNUV2aXF3YngrbUlGRStsY0c1ZQpMYXZyQ1JleUdGVFMvbSt2Q3JuMGg2'
    b'ZG1YcnplUHJrZ2NXeFdqTTVvTTVnZDZRbGlyeTh3b0RITkxFcVpNeUUxSnpYUzVmRXBsTWFh'
    b'CjFuNE9rd3dBOFBvQ2FRbGhLWEZoZUJ6VzRmVElsY2JMbFowUFRrempzNmtlcjUvRHBQWVBE'
    b'c242OVI1ZlFDSzRLWXQyczBwanFHNngKU1lhamNXOUZ0ME1vc3d1Y0FUeWZZUGxieE9WdGlj'
    b'ZStIaGo3VjUrRGJYNUNneVd5d3g1R1JIc3gwTTJ0WUxlcDJhL0duWHcwNGhjTQpGTkJnMXdN'
    b'QUxsNXZuekltOFdSSjQ1RFozcTgyYWZRV05vUGNLZGZhSE83TEZaMUpNY0twaFVrdXQ0K0F4'
    b'NTc0dVdGQVk4cE9pUkR4CkdIZ2N1cjVkT2V1QkZLUFpZYkk0ekZhWDErZi81a3cxRENOeXBV'
    b'SEFwVitwN01SaTBCZXZ0K3VIN0hnY1JqOWtrd2laTm9jbkxvSlgKa0I1MStrclR0TEhKQU1l'
    b'Wkk2eWRJNno5V1oveVN1dVMydCs3QzBzTkNYTUV0U3NqU3FkeUc0MCs2b2FXcFNFdEd2UlBm'
    b'V2JZZFE4QQorRjZWdjdoNlhmQjNCTW13TWU1RWtOcGZMVy9rOXcrWGJObDM1ck0zVmp3ME1U'
    b'VkJLdEFhYlVreEFqR2ZlYTFHMXRTcDJyVitYbVFZCnU2eFdSaVVUVXVKRVgveDRRNjIzWkNS'
    b'S21ycFV4eS9XZlgrdTl0ejQxS3prY0NJQmEzTzRVMkpGTUl3b1ZBWTBHcVhSVzlMaXhYMkQK'
    b'UXljdU5XU25ST0F3Nkk1ZWJYUTRkMUNuTlpnY1l6S2pIMy90NjZMczJIZWVFZ2NiTW9uYlhG'
    b'M1VjbGFYc2FWdFFYQTdFd0RnaTh5UAp4M05iWCsrWXY2dHJ6cTdrSTE4T2pBc1JERHdCVE5x'
    b'MVhUTUZkUlMwdTJ3b0lSamdIZ1FGN1NhaXZTZ0EzMW8vTDAyNithbnAyU2tSCnBUV3k5dzZW'
    b'eEVSd2FSU0MzdzhqQ0pLWkZONHAxNzY0Ni9qeTJUa3p4bzI2VXRtSnhhSWhDT3FRYTJFRUdU'
    b'YzZidVdEZWQrY3FiNVIKMy92eTQxUEVmRVp0U3orSFNlRXd5Zm9oUjdpUUtSVnpXbVdENllr'
    b'enFwc1ZlQnhHcmpLVVZuY3JWTVpINXVYSFMvbGIxOHhpTThnNApyT0VXQXh4d0JYRFd3Rytx'
    b'MWxsdFJpcTliMHY4RCtXbU9ETGFFOVFmLytvRXUyR3NCOGFZZkdRT3p1YUJzWGlVYi9oU3Ew'
    b'MjhzbmJOCnJ1NDVMOGYrdEV4Y2hvSVFBRHR5VTZYNTZWRXdqRWlFekhHall6TVNKVFFLL3J0'
    b'ek5SQUVKVVVMeVVSYzBlalljMWRiT25vMUFBQ24KeSt2ekJiWi9kTFlvT3k0bk5iSk5wbmww'
    b'ZmdHSmdFTVE4TjI1bWtrRmlTZzBsSkVvb1ZFSWFyMjFzVU9abHliRllOQUtsWEZNWnZTMApz'
    b'Y25qYytNVktxTktheWJnc1U4dEdRY0EwUFFjRDFyY2pxdHpON1V1N25iOHp1NTlaS0R3eUVC'
    b'aENyMS9zZWhHR3IxUE1mWFplNjBMCi9rb1NER1B4S0grUFErQU5ZQ3crNHBDWGNydHFhcFdz'
    b'ckYzem5tem10b1JqT1d3RENnVjFLYlJNR3Rsa2NlcE50cTQrYlUxTFgxT24KaXMwZ0w1dWRv'
    b'OVNhcTFzVTBSS3UxeGZvVW1oMVJ0dktoM0xMYW52cTJ2b1h6eHdkRzhFYnNqZzhYbitYUWhz'
    b'bDRjaVZCaGhCL0FIWQpZSEl3YUVRU0VlZjEraVZDNXRFTHRXZXZ0bWdNMWh2MXZkZHFaVWZm'
    b'Lzl0dnJmSHF2MVdPMmRyeGNOZmQ3TXdmcEJ3Nm9peXNNc1UwClc4STNkeXpLcE10RFF6U1lk'
    b'SDJ6emtNYlhscmN5NUhlWmhQYkF3VEkyV2l4dVhaOWVvbkRKRWVFc2JvVTJpT25xemhNaWtK'
    b'bHZGNW4KYStwVUdjME9FaEduMHBxNUxDcUhRV21UcVQ4OWRqMHpLZnlKaFdPNUxLclJiSXVM'
    b'NUtGUUtJbVE2ZmZETUlKNHZENkh5OE5uMDNaOQpkckdsZTNEVlEza0NIdTNqclV1L08xZkRa'
    b'bEJXUFpSSEpHQU5KbnV3RGNjdTFJM2pOckp4dHJ2dVp3UUFUT0UxZmQ0Ly91WUFqa0MxCkl5'
    b'Qmk2LzZJNktCZzNNZHkzcC9HYXpUNFUzQlpsUWVQWGNkaDBUdzJiZVdHUTNnY2hvREh1Tnkr'
    b'dVpQUzQ2VjhrOVg1NE1RMEFZZlcKSmxOSGhyRmpJbmdyTnh3cXJlbCtlR3JtSTNQenBHS08x'
    b'ZTRXY21rMmg0ZEt4dmNORHNuNjlOVXRpcGF1UVI2Ym1wc3E1YklvYkFabApWS3dJUVJDbDF1'
    b'ejNCNXh1cjRoSC8vWnNEUjZINGJGcDA2aXIySmoyS2xQTTdJcVhkUjdhbllZT0RCUVljTEZs'
    b'RG9ITUxqaW5UVCt0CnlRcDVrLzRFQXJ6NWJNSE80SERId1RScjNVNkZ5cGdhSDFhWUdmMzVt'
    b'eXRnQkNuTWpDWVNjRmdNdXJKSkxnM2owQ2o0QVkzWjVmRjUKdkg0RVFiNTU1OUVBREZjMzkz'
    b'R1lGQjZMeXFBU01XaTBYR2w4NS9OTFBmMTZ2Y20rWUdybStrY25aeWFGZjNPMktrck1UWXdX'
    b'K1B5Qgo4b1plQWg2THgyRTY1TnBvQ2ZlcHhlTmFaV29HQmMzV3RRTUFjcGl5OG5HYnA5M1ll'
    b'T3NjTENFYWRSN2FwT3VibzhuYUdMSW1scUpoCjRld2hDZjRUUkpPMUYvTGZEdnFSZ3RDRVZ3'
    b'b2tPUUFBczgzbGRIbUZYQm9FUVRBTWx6ZkltN3RVNTBwYmMxSWl0VWFyYnNpbU5WZ1AKdmIw'
    b'cVhNanlCd0lmZlZ2NnlkRnJrV0ZzdGM0U0djWWVQU3Jpb2NucGFwMFpoOFVreDRqUWFOU2hF'
    b'K1dIVHBRYnpRNHVrL0xtY3cvbQpwRWJJbFVhbDFnekR5THpKNlRkZjNWOHVHUGpOdTZCMTAy'
    b'ZFdiQmdlaDJQSm11V1NhMXM2Rm9TOFNYOENITW9mM0w0SEFPRGhMVjhwCngyWXplN0xwUFh5'
    b'Q0JRQUE5RWQ4d3F4MWJ4MXRhRmUrL2NLRC9rQ0F6Nlo1dkg0V25SUjBNWTNOaXFGVGlVSXVI'
    b'WitDV2ZUQ3A5SXcKem5Pckp0UzI5aEh4T0M2VHVtWnBFUTZMeVVtSk5Gb2NFU0xPeVpLR1l4'
    b'ZnFybFIyRXZCWWpkNDZmVnl5ckY4L3FEZTd2V0tmTDZEUwptaWZreGk5NThUUDlrSDNwck93'
    b'WkVWLzlhckVTVkp1aXEwM1I4QzBoTVRJbi80ditCeUFJUVpBUkZIODVnaVNZZ1hYTUYxVXRs'
    b'MXpECm8vd0ZwYS9mV1VGQ05HWXplemJIblpMazEraE43ck5YbXkxMjE5Tkxpc2hFdk1IcytP'
    b'RkM3YWc0MGFiM1QwbkZuREdaMGRFUzdvNkQKeFZReVBqTXBQRXJDYWVoUXpwdWNsaElyaGhI'
    b'RTV2Q2NLbWxnMEVoUkVrNlhRb3RHb2Q0L1hOS2wwTDI0ZWhLRmhGZnJMZjNxSVJHWApvVkFa'
    b'bVRUaVY3dFc3emhZak1XZ24xaVFOMWlSdGFGOWNiVXArazVWSHdVaGx3cmVFQkZNaGRlMnZS'
    b'Yi9vOXJOZks5bjVwMVd1YitvCkJEL0FhWHMyNnNKMGZrT2RSU29pbUdBRUlxQjhkMXJ6QjF4'
    b'c0JzNlJUT3N6R29xSjVFa3QzWU9QUFR6RzVmYnhXTlRLSm5uUGdMNisKZlNBdlRXb3cyMTF1'
    b'NzZVYjdSRmhyRWdSV3lKa3JwNVhBRUVBQlVGdXI4L3A4bjN4NC9VQWpCdzZXZjd4MXFWN0Rs'
    b'L2Urc3lzUGE4dQpPRlpjMTl5bGF1NVNUUm1UbEpNUzJTcFRFL0NZMTU2ZVFjQmpOejgxNC9T'
    b'VkpyL2hUQXBkWWZjUjdtUVhBRENlMDBwQ2UwZGRmdWRFCjdydENnZ2tEd1ZZL2NiOThjb2hn'
    b'QUFBUUVreFZwcGhQK2ladVN6aFdyRTE3cVhYWlhYMDFHQ2p3V2ZvQkhNcFAwejd2VCsvKzlJ'
    b'MFYKR0RUcXUzTzE5ZTBETUl5a0pZakhac1VreDRqc1RnK0ZoSE43L0U2MzkveTExdUt5dHFv'
    b'bVJiaUloVWFoeEFLR2Zzait3OFY2THBNUwpHOEdESUtnd0s5cm1jQis3VUZ0YUk2TlJDSkZo'
    b'N0tvbVJYZWZqa0VsSmtUeHIxYkw4RGhzYkFSdmZFNHNybkVhQ29WOG1uRWc0OHJPCk81c25K'
    b'ZXNNUHVxelVSZHltZDJwVjNhdmxaNGZJV254UmtUUVhZczFQSmNsMjVIMDdiN2VhUmYxcVNt'
    b'MC9nSldWLzJ2QnQ1aHZCUjcKWmxWNEtRQUFCOW1IdkZJNlArdlpONzd2NmRjeHFLVHhlWEVS'
    b'SXBaYWJ6MVgyaEl1WW4xL3JrYXVNaHdycmljVGNTVVZIZUVpVnBTRQpBOE93WEdVTUJPRElN'
    b'TTR2VlYxQ0hqMWN3TExZWFpWTmNyWEJTcU1RQ1hoc2JxbzBOVjZjbFJ3ZUx4V2tKa2dxRytW'
    b'ZWY4Qmdzck84CnAxaWVvd0FBRHQ2R0FzaGx3KzI1MEFaZHpHZWx4Zk5FVlV0cjFrYVFESzhu'
    b'SHR2YXNTRGtELzROSjNQZkdVVWJVTHVaZWk4MW1hcU0KbzZoenI3NVJaZm90Z2lLT29tNFl2'
    b'eUdZRVJvQTRJZHhocmplaWhhRHllSU1GekVaVk5MNlhjZGwvWG9hbWNEblVDTkU3SlE0VVVP'
    b'NwowdTMxWWRCb0xBWWRHOEV6bXUzUjRkejJIazNmb0hIUmpORUVIT2E5UXlWNEhHYnVwSFN2'
    b'THpBcVZwUWFId1lBb0ZPSlZjMktsTmd3CkhCYTk3cTJqWWdIem1VV1puRzRwNXRlTTRYNEVu'
    b'WDkxZTgwOWpCZ1lLSEMrWU1jeFZkNG5JMlBYNFFoU3NyS1pQY3ZFWll2RGJ0Z0QKaEcrVVl6'
    b'NVJUQnJlMGgvY3VwSks2N2NHaUZZZjBlb25XbnlrTVdHa2lKeWpUWjJEQlJsUkFJREdqb0hE'
    b'UDFVbVJRazdlalZPdHpjcgpPYnlsYTlEdDlUZDFLUE16b2o0NVdwYVZIRTRoNGNmbnhqVjJx'
    b'TmF1R0Q4cVZnUUF3R0hSRUFSNWZmN3pwYTNOWFlNbXE5UHQ5ZWFsClNkMGUvOEpwV1hRcTBX'
    b'UjE2T29XbnUyRHFCZzNBK2Vnb1YwMHJLdlh3VnRSdDJaRWFjc2puV0FhMXRVODRhWFRtc3dq'
    b'QTRVRExzNDgKVVpVemdQdDJZTXk5OWxhaklYaHcycE13KzFsVzBsYWQwYmI3ODB0VlRZcU5m'
    b'NS8rdzhXNkxyazJOVDRzSnB4WDJTU1BqZUJoTWVnSgplUWxrSWk0N0pjTHI4NnUwWmp3T2Ez'
    b'ZTZZOEo1WHA4ZmpVWXBOYWJ1UG4xbWtvVERwQXhaSElFQXNtblBxWGdwWDJPd3Z2bmNuS0hX'
    b'ClRXVExQdDY1VDl6LzEzNmgrMTZDZ3l2SWxaTFNUeklPVnBtaUVRU2lZbHhqcjIyN0s4Y1R1'
    b'SzBsWTdZREFKVDAvWFRwNnNvbStjNkQKeFQvdSs3dGFiejFlWEpzV0wwbE5DT013S1NnSXNq'
    b'cmNIQ1lGQUJBSXdEQ0NPRnhlV1o4dUxwSkhJdUlSQklFQVpMVFlHVlNpem1oMwpPRDFDSHAx'
    b'T0paYldkRmMxS2VaUHpjU1pqb1pabmdZQXpLbDQ2VjVHeDhjaXJudzlVT2dacWZTUElFTUhn'
    b'a0JpNHREKzlNOFdWai8zCmt6b0xBUEJqN3Jzcndrcy92dHRpWTc2b012aERiSGxLMmVzZE4v'
    b'cHBtOE5OSlJOd1dFeHJqd2FDb0RhNU9qNlM3M0I1c1JpMFZNd2UKc2pqSFpFUXJOU1lCbDVh'
    b'VkhQN1ZUNVZoUEFhTlRLeHFrZU93R0FJZVc1UWRteEI5MCs0NGJuUnNicXBVMzdrL3pIb3p6'
    b'OW1Dc0lxNwpFcnhFZlAxSjZhVXZCOGJSc0s2UkZoRTlFaTFaU1ZSbHMxVVNaQmNBME8va1JK'
    b'TDBkMVpEUWNoYzRXODdmMmpHVjNvYnpCUHoxZ01BCmVnYjBGQkorMlp4Y01aOXhyVloyOW1y'
    b'enorVWRSRHpXNGZJUjhkajBSSEdmYXNqdThpZzFKaUlCRnh2QkhaOFRueG92aWhDeFRSWW4K'
    b'aDBraEVYQUFBS3ZkcVdyZHlYYnNBYitPSGJNRmRiZmExNExnNEd6dmpQcDYrbzFYbjRnb3lX'
    b'VjFyNnhkdzhiWi9zOERvVWMwd2RXbQo2Rml5Sm9YZTMyWVZMNWRjKzF2azVZblhOOGRSMUQw'
    b'Ty9xMUp2UXZaSFVLQzJld2pYOUtubkZGbkhoL00zWjc0L1NQK3lZTVJSOWdNCjF2YTFjN2dz'
    b'Q2dBZ01VcjQ1T0tpektSd0FDQ0FBSjNaVHFjUTh0S2tlRHdXQlZCOERqbEN4RG56Uy9QUkMz'
    b'VWZiMTNxZEh0TkZpZUoKZ0ZPcGVzajl5MHA3cVU4M0hpaGdkUzRRVlR3Y1Zpa2ltQ2J6bW04'
    b'TDk5eWVlTlR1SjlDd3pvM3hKd3BLdCtleHVvOW03NG01OU1GdAozMEdJNE45ZzhwR2ZhVnBk'
    b'VnJnRkJTRU9QLzZSMnFmWU9QdkZncmRXMUs0NXBSNDlYSTJBOHMycTJIQkpsekxjbFRTc2l3'
    b'bmZvUGRFCnFSbnZFc1NyZzRWZEN1Mll6T2ltVHFXQVE1OHlKdkd0QXhlYU8xV2JuNXJ1OHdV'
    b'Mjdqa1ZJV0xOSHA5Mi9HSTlBTUR0OFNsVXhtZ3gKUTlXMFcyUjlHWUlBSFZNQUkxQ1pNYUhN'
    b'bVBCOHk2b0NWaWZwMXhYYU1GNXJYMGpCdUsrTjNYcHNNRS9ycHAvTDMvRmErOElSeGU1SQpk'
    b'RFo4cXh4VHJFdUxJQmxhckpJbkl5L3RHblZrYmRNanQ3SUxBTGd6VjJVd0hRNEtoWVJaWDNB'
    b'MmIybWo3V1h3SnlYSENDc2E1V2dVCktqOWRDZ0RvN3ROQkVEQlpuRVFDRm9OR2VieCtBTUNT'
    b'bWRtOUEvcjYxazQrc1lIUS9Ed0hZdzltYWhqT3J3TUFDREo5NitzbTg1b1AKWlg3VVpoUFBx'
    b'WGpwRytXWWo5TS83Wm15dHRrU2Z2amV1ZmorMHBhczIrQUs0RFJ1eGlPU3E3dVN2NWxidGY2'
    b'WUtnOEE4RkxzYVRiTwozbVcvK3hrb2o0VmZpYUZvQVFBeXUyQmh6Yk9YRmJxbktQT3N1a295'
    b'bFFtam1FcWQwMkJ5cGlWS1JGdzZuME1Md0VoQ3RDQXhpdDNYCjErMDFscWJnM2syRk5qNTlJ'
    b'MjZYYk5ab2hqeTREMHJucFgvZU4vNnU3eHJENmp3eWV0K0xMU3NtY2x2dGZzSUpkYzZuaWdr'
    b'OHZQVzEKOWtYbS95emYvRjlDZ29leFNGeitXc2VpUzdvVUxDcndZZXJuRDRtcTUxVytFRXZX'
    b'M0Jibk5pekJmZ1M5cTJ2MjY1M3pQVENXamJNaApDTVNEU29DeFJBekFhVTFXdjVzelUyS0lJ'
    b'bkdCR21CZ2Zkc2d4UWY1bDRxdkF4d0FDQUFBMUpxbC9TN09tTkp0TDhTYzNacndBeDNqCnZH'
    b'dXJKRVRqNmZ4ZHI3UXVQYVVldlRIMjVLSE0vVTlLZjE1VXZlNzU1cFVqc3h0SGJqcmhpN3JV'
    b'QmFLS0luYmJoZnkzeHJMYjg2NisKTVZOUVh6OWhBeDE3bDY3dmQ3SHpyMjdmMUw0NHVCNDFl'
    b'cW5COU00QWdDcFR6SkxxdFcvS3BqTlJEVUxvZ2hDNndFSFZ2U1diL2tqZAowOFhhdEdBZGpZ'
    b'Y1IzUExyUjlDN3V1ZWtYTjU5TDB1azBzMzZzSGZxcnVRajV3dDJWRnVpdzRyM2F6ejBOYjgv'
    b'SVRGRThMK0VQVDB6CktrMHgzMmJ2VmJ1WkJhWGJ4N0E2MTBXZGh4R1UxVS9Fb2Z6UTcvTXpM'
    b'NmxaZXhzbDFlWm9BRUNuWFRTemZJTWpnSmZaQlVjR0NtL2EKdlRXakd5eVJQaGk5c09hNVlL'
    b'TDMyKzd0Y2ZCWDF6MTFhd2tCNWRzOTZtdlo1SFhGK1c4ZEg4elozTDVvTEt1OVdKdXFkalBt'
    b'VmI3NApTdXZTRU1IL05nSUlhbjNMY3RHRmo1ZlhQcE5BVlgyYy91bldqb2VETy8rUFpPM2JG'
    b'SGZpTmlQSjdTc3VjN1RlUzV0VjhmSndLb2p0Cm5mUDhDQnBCb0cwZE45VU9xNDg0OWNiR2Jv'
    b'ZWdhaWptanh0eklPTmdGRW0zck9iWkptdkVsY0x0cHpWWlMycldIc3JjUDR0Zk44Sk4KbGZk'
    b'QklqUXhjYWlrOEkwM08rZktuVHcyM3A1TzY1c3ByRi9UK05qeG5QY1FBTFhZSk9CdUtjbzhN'
    b'UFpJZjJHclRYTExHb3dTU1RiSQpuYng5dmRPR0M1MEJmTEV1VGVOaEtPOXgzSlVBYjNiRDJH'
    b'OUg3NXRadnFITkpyNm9TODFtOW82aURyd3JtMzNaa0Z4cGl2VWhtQkRCCi94RThNTWJncFgw'
    b'b256cGZWRFdXM1RGTFVEL2x4cVpneW9lUDB6OWJLS3BvdG9hcjdraU1vbkV6MUo3YjNiSE5s'
    b'dkJ5VTV6Tzg3c0UKR2tZdjlWN3NmcC85d2J1anZ2NUlNZlh4eUNzdFZrbndjK0hoclduMC9x'
    b'T3FmS1dMUGNMWkJmZkZvUndlR1B0WjMzZ0FRQUpsTUpNdQpYMW43ZEtNbElrZ2hGMmU5ckUv'
    b'K1B2c0RBZDc4cnp4Szd1UTFXLzU4ODI0dVV4Yk0rMDdGdUx3SVptM1UrVzBkOC9lbmZUYUxY'
    b'NWZECmxLMlJGaDhiekFQM0NlNm4wMGUvVitYWFdhUW4xZG5Cdjd1VHYvNUprN1dwZmZHV2pn'
    b'VzNacFArSDROUHNDUlRsYTRBOXNhNGY4aWQKdk1MU2JaV21HTDJYOW56ME9lbWxmVGhVWUYv'
    b'YUZ3aUFkblE5ZUd0cWpoR08rekpmTkFEZ0FVN2IyZnlkU1NYdjlqbHZ6MmcwaWR1OAplOVNS'
    b'NjBOeHBZYkUwNW9zVndEM3g0OGF4Mm0zK29nTmxzaHB2TWJEV1I4S0x4eW9MTnBrOHBMWmVQ'
    b'dU96Z2RuQzJ1NWVPc05ZL3oyCnpubjNZMGZkcndkRWI0Zzc5VTczckR2WkJRQVVzanVIdk9R'
    b'V3ErVEZtTE9uY25kSGtBemE2VThFTnkxK2xQWlpJYnNqbmE2b2VXQ2oKZDg2eWh2RWJ4TVNo'
    b'NWVLeXA2U1hBQURYaCtLWVdFY0dYYjZ0L2VFRTZ1QlJaZjVMc2Fmem1kMWIyeGM4SG5rNWVC'
    b'NThpT0QvSlN5bwplbjduTGFrcmIwVUJxMVB1NUIxVDVSM3FMeElUaDVoWU93UHJEQnBBSm5K'
    b'Ym1GakhwcmdUVncySnBOTmZmcU1jRTA4WkxOYWx6aEhXCkhzOTViMkRxR2orQ25zcHJPcVBO'
    b'MUxnWk5qK2h3aFFySUpoYnJKS1V5N3YvNEl6YTBCejgzNGZkVDdqN3FnQ0NjNWt5QXRyWFBm'
    b'azUKSE1yL1lNVkxES3pUN0x0NUpnc0Q2ekQ3eVBVVzZhdHhKeE9wcW1acitJQ0xYV3VXY25D'
    b'MlptdjR1dVpIRm9SVlBDU29mcXZyb2EwZApENzg3NnF1VXk3dGY3NWp2Q09CQjREN3RwL3RX'
    b'Z3UrRlViUUJITm8vK2ZxbTZJdDd5V2lQMnMyZ1lsekJNM0lnQ0tGalhSWWY2ZTN1CkJ5ZGQz'
    b'M3hCbDU1Qmw1L0wzMkgya1N0Tk1TWWZXZWxpRld0VDgxbGRWSXpybkRhajhObzJQNEkyakRB'
    b'SC9sK2RZRFNBOS9WTTg4QlkKRXNZREFERDZxR28zVTBBd3A5TDZaL0hyVUFEdWNmQVhpaXBl'
    b'aXo5K3haQjBRcDBUbkZtTHRXa1BjTm9BQUcwMmNlelBId1EvQ09OOQpUdTM5clVYL0tVaG96'
    b'eUp4K1hmS0FsY0F0eVhoaDBmQ3I4SUk5R2JuM00vN3gxTXc3djFwbnhXd09uc2MvSDkwTEt3'
    b'WWlxVmlYRzRZCk54SzJFb1VJRHVHdlBVU0hFQ0k0UkhBSUlZSkRDQkVjUW9qZ0VFSUVoeEFp'
    b'T0lRUXdTR0NRd2dSSEVLSTRCQkdIdjRmcXlxejJ2ZDQKQktrQUFBQWxkRVZZZEdSaGRHVTZZ'
    b'M0psWVhSbEFESXdNak10TURJdE1qWlVNVGc2TWpJNk5Ua3JNREE2TURDQUVDUXdBQUFBSlhS'
    b'RgpXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEF5TFRJMlZERTRPakl5T2pVNUt6QXdPakF3'
    b'OFUyY2pBQUFBQUJKUlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTE0MTI1IiAvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'US_SD')

US_SD = b64_US_SD
index.append("US_SD")
index.append("United States of America South Dakota")
catalog["US_SD"] = US_SD
catalog["United States of America South Dakota"] = US_SD
country["United States of America South Dakota"] = ('US_SD', '', 1)
lookup["US_SD"] = ('US_SD', '', 'United States of America South Dakota', 1)
lookup["Pierre United States of America South Dakota"] = ('US_SD', '', 'United States of America South Dakota', 1)
lookup["United States of America South Dakota"] = ('US_SD', '', 'United States of America South Dakota', 1)
details["US_SD"] = {"continent":"Americas","capital":"Pierre","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_SD"] = ('US_SD', 'United States of America South Dakota', 1)
regional["United States of America South Dakota"] = ('US_SD', 'United States of America South Dakota', 1)
#----------------------------------------------------------------------
b64_US_TN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iMTAwMCIgaGVpZ2h0PSI2MDAi'
    b'IHZpZXdCb3g9IjAsMCAyNDAsMTQ0Ij48cGF0aCBmaWxsPSIjYzAwIiBkPSJNMCAwaDI0MHYx'
    b'NDRIMHoiLz48cGF0aCBmaWxsPSIjZmZmIiBkPSJNMjIyIDBoMTh2MTQ0SDIyMnoiLz48cGF0'
    b'aCBmaWxsPSIjMDAyZDY1IiBkPSJNMjI1IDBoMTV2MTQ0SDIyNXoiLz48cGF0aCBmaWxsPSIj'
    b'MDAyZDY1IiBkPSJNMjI1IDBoMTV2MTQ0SDIyNXoiLz48ZyB0cmFuc2Zvcm09InRyYW5zbGF0'
    b'ZSgxMTEsNzIpIj48Y2lyY2xlIHI9IjM5IiBmaWxsPSIjZmZmIi8+PGNpcmNsZSByPSIzNiIg'
    b'ZmlsbD0iIzAwMmQ2NSIvPjxnIGlkPSJzIiB0cmFuc2Zvcm09InJvdGF0ZSgxOCkgdHJhbnNs'
    b'YXRlKDAsMTguNSkiIGZpbGw9IiNmZmYiPjxnIGlkPSJjIj48cGF0aCBpZD0idCIgZD0iTSAw'
    b'LC0xNyBWIDAgSCA4LjUiIHRyYW5zZm9ybT0icm90YXRlKDE4IDAsLTE3KSIvPjx1c2UgeGxp'
    b'bms6aHJlZj0iI3QiIHRyYW5zZm9ybT0ic2NhbGUoLTEsMSkiLz48L2c+PHVzZSB4bGluazpo'
    b'cmVmPSIjYyIgdHJhbnNmb3JtPSJyb3RhdGUoNzIpIi8+PHVzZSB4bGluazpocmVmPSIjYyIg'
    b'dHJhbnNmb3JtPSJyb3RhdGUoMTQ0KSIvPjx1c2UgeGxpbms6aHJlZj0iI2MiIHRyYW5zZm9y'
    b'bT0icm90YXRlKDIxNikiLz48dXNlIHhsaW5rOmhyZWY9IiNjIiB0cmFuc2Zvcm09InJvdGF0'
    b'ZSgyODgpIi8+PC9nPjx1c2UgeGxpbms6aHJlZj0iI3MiIHRyYW5zZm9ybT0icm90YXRlKDEy'
    b'MCkiLz48dXNlIHhsaW5rOmhyZWY9IiNzIiB0cmFuc2Zvcm09InJvdGF0ZSgyNDApIi8+PC9n'
    b'Pjwvc3ZnPg==', 'US_TN')

US_TN = b64_US_TN
index.append("US_TN")
index.append("United States of America Tennessee")
catalog["US_TN"] = US_TN
catalog["United States of America Tennessee"] = US_TN
country["United States of America Tennessee"] = ('US_TN', '', 1)
lookup["US_TN"] = ('US_TN', '', 'United States of America Tennessee', 1)
lookup["Nashville United States of America Tennessee"] = ('US_TN', '', 'United States of America Tennessee', 1)
lookup["United States of America Tennessee"] = ('US_TN', '', 'United States of America Tennessee', 1)
details["US_TN"] = {"continent":"Americas","capital":"Nashville","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_TN"] = ('US_TN', 'United States of America Tennessee', 1)
regional["United States of America Tennessee"] = ('US_TN', 'United States of America Tennessee', 1)
#----------------------------------------------------------------------
b64_US_TX = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iMTA4MCIgaGVpZ2h0PSI3MjAi'
    b'PjxwYXRoIGZpbGw9IiNiZjBkM2UiIGQ9Ik0wIDBoMTA4MHY3MjBIMCIvPjxwYXRoIGZpbGw9'
    b'IiNmZmYiIGQ9Ik0wIDBoMTA4MHYzNjBIMCIvPjxwYXRoIGZpbGw9IiMwMDIwNWIiIGQ9Ik0w'
    b'IDBoMzYwdjcyMEgwIi8+PGcgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTgwLDM2MCkiIGZpbGw9'
    b'IiNmZmYiPjxnIGlkPSJjIj48cGF0aCBpZD0idCIgZD0iTTAsLTEzNXYxMzVoNjcuNSIgdHJh'
    b'bnNmb3JtPSJyb3RhdGUoMTggMCwtMTM1KSIvPjx1c2UgeGxpbms6aHJlZj0iI3QiIHRyYW5z'
    b'Zm9ybT0ic2NhbGUoLTEsMSkiLz48L2c+PHVzZSB4bGluazpocmVmPSIjYyIgdHJhbnNmb3Jt'
    b'PSJyb3RhdGUoNzIpIi8+PHVzZSB4bGluazpocmVmPSIjYyIgdHJhbnNmb3JtPSJyb3RhdGUo'
    b'MTQ0KSIvPjx1c2UgeGxpbms6aHJlZj0iI2MiIHRyYW5zZm9ybT0icm90YXRlKDIxNikiLz48'
    b'dXNlIHhsaW5rOmhyZWY9IiNjIiB0cmFuc2Zvcm09InJvdGF0ZSgyODgpIi8+PC9nPjwvc3Zn'
    b'Pg==', 'US_TX')

US_TX = b64_US_TX
index.append("US_TX")
index.append("United States of America Texas")
catalog["US_TX"] = US_TX
catalog["United States of America Texas"] = US_TX
country["United States of America Texas"] = ('US_TX', '', 1)
lookup["US_TX"] = ('US_TX', '', 'United States of America Texas', 1)
lookup["Austin United States of America Texas"] = ('US_TX', '', 'United States of America Texas', 1)
lookup["United States of America Texas"] = ('US_TX', '', 'United States of America Texas', 1)
details["US_TX"] = {"continent":"Americas","capital":"Austin","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_TX"] = ('US_TX', 'United States of America Texas', 1)
regional["United States of America Texas"] = ('US_TX', 'United States of America Texas', 1)
#----------------------------------------------------------------------
b64_US_UM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXVzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2JkM2Q0NCIgZD0i'
    b'TTAgMGg2NDB2NDgwSDAiLz4KICA8cGF0aCBzdHJva2U9IiNmZmYiIHN0cm9rZS13aWR0aD0i'
    b'MzciIGQ9Ik0wIDU1LjNoNjQwTTAgMTI5aDY0ME0wIDIwM2g2NDBNMCAyNzdoNjQwTTAgMzUx'
    b'aDY0ME0wIDQyNWg2NDAiLz4KICA8cGF0aCBmaWxsPSIjMTkyZjVkIiBkPSJNMCAwaDM2NC44'
    b'djI1OC41SDAiLz4KICA8bWFya2VyIGlkPSJ1cy1hIiBtYXJrZXJIZWlnaHQ9IjMwIiBtYXJr'
    b'ZXJXaWR0aD0iMzAiPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTE0IDAgOSAyN0wwIDEw'
    b'aDI4TDUgMjd6Ii8+CiAgPC9tYXJrZXI+CiAgPHBhdGggZmlsbD0ibm9uZSIgbWFya2VyLW1p'
    b'ZD0idXJsKCN1cy1hKSIgZD0ibTAgMCAxNiAxMWg2MSA2MSA2MSA2MSA2MEw0NyAzN2g2MSA2'
    b'MSA2MCA2MUwxNiA2M2g2MSA2MSA2MSA2MSA2MEw0NyA4OWg2MSA2MSA2MCA2MUwxNiAxMTVo'
    b'NjEgNjEgNjEgNjEgNjBMNDcgMTQxaDYxIDYxIDYwIDYxTDE2IDE2Nmg2MSA2MSA2MSA2MSA2'
    b'MEw0NyAxOTJoNjEgNjEgNjAgNjFMMTYgMjE4aDYxIDYxIDYxIDYxIDYwTDAgMCIvPgo8L3N2'
    b'Zz4K', 'US_UM')

US_UM = b64_US_UM
index.append("US_UM")
index.append("United States of America Outlying Islands")
catalog["US_UM"] = US_UM
catalog["United States of America Outlying Islands"] = US_UM
country["United States of America Outlying Islands"] = ('US_UM', '', 1)
lookup["US_UM"] = ('US_UM', '', 'United States of America Outlying Islands', 1)
lookup["Washington DC United States of America Outlying Islands"] = ('US_UM', '', 'United States of America Outlying Islands', 1)
lookup["United States of America Outlying Islands"] = ('US_UM', '', 'United States of America Outlying Islands', 1)
details["US_UM"] = {"continent":"Americas","capital":"Washington DC","currency":"","web":"","lang":"","tz":"+12:00","altname":""}
regional["US_UM"] = ('US_UM', 'United States of America Outlying Islands', 1)
regional["United States of America Outlying Islands"] = ('US_UM', 'United States of America Outlying Islands', 1)
#----------------------------------------------------------------------
b64_US_UT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjA4MiIKICAgd2lkdGg9'
    b'IjE2MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1V0YWguc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2NhcGU9'
    b'Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHhtbG5z'
    b'OnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2RpcG9k'
    b'aS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsi'
    b'CiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3ZnPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczE2MDg2'
    b'IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTYwODQiCiAg'
    b'ICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2IgogICAg'
    b'IGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgogICAg'
    b'IGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNrZXJi'
    b'b2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAgICAg'
    b'aW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTYwODgiPgogICAgPGltYWdlCiAg'
    b'ICAgICB3aWR0aD0iMTYwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2ZUFz'
    b'cGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRpbWl6'
    b'ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQsaVZC'
    b'T1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtBQUFBQmtDQUlBQUFDTzFLellBQUFBQkdkQlRVRUFB'
    b'TEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9wZ0FB'
    b'QTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFuCkMwbEVRVlI0MnUx'
    b'OWQzeFVWZHIvdWZmT3pKM2VTMlltbWZSSklTR1FBcUdHYmdSUjdMQldGTmUrdW5aZDE5ZjJx'
    b'cTlyV1JYc3JJQ3MKMkdBUlJTQ1VVQVFUUWdMcGJWSm1ra3p2OWZiNyt3TVdkMTFJME4vdUpw'
    b'cDhQM3lHRDh5NTk1VHZQTTk1enZPYzh4d0lLcndMVE9EWApDM2hpQ0NZSW5zQUV3Uk9ZSUhn'
    b'Q0V3UlBZSUxnQ1V3UVBJRUpnaWNJL3BWQ3hLTkZQSHBjZFpuenEreFZ0aVplbkJyTzBjWnpr'
    b'cUptCmJWd25KVVE4V2lFa3p4WUl4TGt4QW5HRmVWMXVZYWRUM09rV05saWwzUjdocjI4b29G'
    b'K05xMUl0SWk4cDlNelA4Yy9QOFFzNGRKMU4KMXU0VWRibEVYVzdob0o4Zkk1QTRBUWNUWEFD'
    b'QVhFQ0tVRWJJcFpPVldJNHVidGJHY3BOaVphWlFuRVNxdTVUVm5jcHZXalMrS0hlQwo0REVC'
    b'bE1Nc0svVGVNTjIrS05kM3VGdXhyMTFWM2Exc0doSXpEUFRUNWlxWUxUSkU1K2Y0RitYNTVt'
    b'UUY5cmFyUHE3VjcyelJFaFEwClFmRG9RQzRnNzVrM2NPOThXNStQdjduVzhHbWQzaHY3OTRp'
    b'ZFJreXNMSFZlUDgyUnBrNjhlY0MwOXFBcGhIRW1DUDd2UVNVbUgxelkKZjhmY3dYMGR5aGQz'
    b'Wlp3Y2xQeUhLaXBPQ1Q5UjJUcy9KL0QyNFpUWDk2ZjVZNXdKZ3YvVHpRVzN6Qng2NGJMdXFq'
    b'YlZDN3N6MnAyaQovMEtsay9UUkp5N3VYWmpqZjN5N2VVT05nV1VuQ1A3UFlMSXg4czZxZGhG'
    b'SzMvMXA3dEVleFgrNTlqbFp3WFVyMjBJSjdwMWI4bHJzCjRsL0tvQ0dRcnV3WDBkQTc1d3hz'
    b'dXJubDNjTXBhelpQc3ZvRi8vMEcyUHo4RDQ4bXl3VGtYMjVvRFNXNDlUYnBoQVQvZXlEaDAr'
    b'OWQKMXpZMU9iUnlmVkhqZjJ5NnZYRGs2Mk9mclduc2RBclhiSjUwZXQwMVFmRFBoMG1KN2Jx'
    b'bnZ0NG12V3RMZmhSSEx2UXhQQWpDZlh6YwpMWUx4Q01VbDFGT0JNT21IYjFrRzlkWG44MXdD'
    b'Q01jWlpCRG51eUV0SzgwQXFQekNmM1B2ckdvdFNvNWUvRmJ4WUpBL1FmRFBSRjVTCmJQZTk5'
    b'Wi9VSlQyKzNYeGhUN0FnYkRYZzdZV1N4Q1NkSkZrbWdBQWdhV1pubCtjUXJ4Snd6MWhrcU8v'
    b'RWcrYVFSb1NlZlN5TWswM08KY0hPUVowSE1qQ1FkUUJma3dYMTBTZis5ODYwWHYxWGNiSmVN'
    b'MlRFY3UzUHd0TlJ3MVgzMXozK2I4VkpWeGdWNUtzSTlreE5IVmlhSApGNmNLb3dUVjZvNDAy'
    b'SU1EUVN4ZEtjclRpS3R0VWVidlFweERuSnlUSW1wMWg5ODgxanNVeG80UEJ0cmRFYVdRdHlC'
    b'Vk5GY1pnbnd0CnpnUk44MVFBR3NIRmNiUkhqbFBJK2h0YkQzVXI3R05WanNjb3dmbjYySjdm'
    b'MWQvL2VlNUhOY2FSdFZEY01TVnhhSFY2TEZ2SmEzTkYKQmtQeEF6M2U2NmVrMkNNNEI0R3N3'
    b'WGkyV256UUZpRWxaMzRvaWtSM1dSSi9XNHY5eWdKRGpLQ3ZMalFlNlBWZGJOWjFlcUtIK255'
    b'egpVbVJMRFRqcmJSbUl3aXhmTlh6VmRWYVpQY2pmZEhQTHptYU5OOHFiSVBpQ2tDekg5dDFY'
    b'Ly9MZTlQWEhSbUtYSWRYK210V0dnVks5CllKL0ZVOVh0dmlMZjBPU000QlFUSitsVHpqQVhn'
    b'aGdXU3BieDkzWllRY0lqalZ0d2IzczQ2SnFkcW1oMWhYdjhzYnFoUUpNOTdJcmgKcmU0SXlr'
    b'RTZQQkZQak9qMnhXYWJaSE5VWWErOTNRdmtaM1g3T2RGc0YwZHh6dnZYdFcwN3BRMk5QWnRy'
    b'ekJFc0ZWQUhINmpiWEtkLwp1U3A5aEtJeHgzU3krdFo4dnNVZnJiSjR3aGpsVDVDK0JOSHFq'
    b'aGlsQXBTRGhERnlacW9TZ1NGWERCOE1SRk1GZUtrV1F1a29RVk5jCkJKSUp1RG94R2llWUlv'
    b'TlVJMFFIUXZFRm1XcUtBVTNPRUVreCszczlPTVZjazYrU3gzc3NBWXdSSkEzVGtCTldxVXhB'
    b'UG45cHorYmoKQm9LQ0p3Z2VEaHR2YWhrTTh1Ly9JbmVFZGdmYnI1UTBseWRMUGo0NTBHQVBZ'
    b'aFRyakdDWDVldjljUkpGWUgrY3NBYmpCTTNVMjRNcgo4dlU3MnB3VXkwN1dTeHNkb1JLajNC'
    b'WERMYjdZMGh6ZHhvWUJEZ3oxK0dNaG5McllyRHRpOVljd01veFRKcmxnYVk3dU82dS9QeERQ'
    b'ClZvc1dKZUhkdHQ2WXdEU004WFd3U3prN0szQkpvV2ZiU2QwRXdlZkZYWE1IVmt4MXIzaTNl'
    b'SGc1a1BxUDMyNXlJekRZMmVseVJyRXIKQ3d6Mk1FYlFiS2NuV21xVTUyZ2xxWEloRElPTGMz'
    b'UWRuaWpOZ0RoRk15d0lKaWk5RkQzUTQ1WHl1VUdNOUNXSVFKeDRZSFlXUVRNMwpUVFVOaEJO'
    b'THpib09iMlJXcWxMSzV4d2ZEQVlUcENkT05OaURDWktacm9PYkxXMUFtZ2JnOHlyaHFqYjFV'
    b'MHQ3U1JvZVV6NlFNVVR3ClpHTms0ODB0eTlZVkR3U0d0VWp0UjY1TERscDhzYTB0ZG4rQ0lH'
    b'bldFeWNxczdWNVdqRkdNZk16TmIzK2VKcFNTTklzemJBWXhUUTYKUWdvQkwwTXBDbUlFeTRC'
    b'Y25YVFo2cnVPZi8rOW1NdHhSZkdCY0lLSElBMzJFQmVHRC9iNUJrT0pQSTNFbnlEbXBxdFZR'
    b'cDZjejUxaApVamJZUTBOaExFOEIwOEdlcUNBVklPYzJwZ2dhUHRxck9HMXdlY2FNd1RWV0NJ'
    b'WWdzUFczamU4ZlNkbmVxQjJ1dWU3YUFwN2p1TTNqCmpST1YyVm8rbDdNMFI1ZWhFRFk3dzY0'
    b'WTBld0tIK24zaHpDcWRzRGY2WTI2b3ZnbE9UcUxMeGJDeVA1QVhDbEVmUWtpYzlyY1diTm4K'
    b'L1czN2RwMFl6VkNLWWdRZHdTbUZnSGQ4S0lBaVNMRkJiZzlqM2I2WVAwNFNOSHR0b2JITEc1'
    b'MmJybElMZVFtS3ZqcFAzZHA5S2k3TwpCUEM1dzByT01Nb3kwQU9MclJzdXdQZ2ZYd1N2bVRr'
    b'NE56dHc2K1lDaGozdjZoUHlOYTlLalF2NC9GSXRYeTdnQ3JpYytSbnFKbWU0ClppQVF4cWta'
    b'SnVVa3JTUkpoUEk0U0VXNldzemp4RVhxZ0ZBalZhb2hMa3JTTk0wVlBQRG9ZN2ZjY2t0dFRl'
    b'MlJ3MGVpQkJYQnFUakoKWURSOTVTUURENEdubXhSWmFsR2NvQ3R6dEFOQmJEQ1NrUEU1Zm93'
    b'MHlRUWQzdWlDVEUyVEt6dzNSVkpuNldKbDV2T3Rrby8zeSs2ZApiOE1JNU5UZ21QQitqSWtB'
    b'cDBwTS91OEt5NVh2RlpIMGowY05BdUJNZEM3dUxoZlowNlRTWGxmQUZhZG1wU3EzTkEybXln'
    b'VTFBNEVGCm1Xb2hGNG5nVkZHU2xNK0IvYTR3UVRNaG1iR2pyaTRhalo0NmVUSW5OMWV2MS8r'
    b'd0RFdE9ycGhYOGNxZlh0bXpaODhkMDlMRVBNNlgKTFVPQkJKbWxFaDBmQ09va0tBZUdwWHhr'
    b'c2toYTFlMEpZdVJBTUxFOEw4a2R4VEdLNXNCUUJqZlk3V2tBMnBKejlvVmlvTjk5bHZ2NQpi'
    b'WTFmTldrQ2NlNkVCQU1Bd0pPVnZkNG83NDNxMUgvOWFvWWgvTndTUy9PUU1OQys4N1ppM2Q0'
    b'ZTMvdzBtUzJFK2VMRUVhdS9MeEJYCkNMaEdLZCtrRU5yRDJGQUk0M09ScWRQSisxYnpLeWJG'
    b'MXI3M2NZS1dSYUpZYjIrdjErTkp6empqNkJDSlJHKys4ZVlubjN3aTVDSUIKakJ3TUoyeEJM'
    b'TVJQNi9BVE5xOG5UU0hjYS9IcXhIeTlCRTFYQ0ZFT3d1Y2dqWTVRaXpzaTVuSythQm55SjBn'
    b'MjVsU3B0Yzh2ZFVmagozSUVJK3FNMlcvMkM0dFJJYmxLc3VsTTVRVENROGFtUFY3ZXMyVHpK'
    b'SFRtSFlUSVVRUitlWjN2dVNzdjh5ZHB1TzlQVzV5Rm9wdE1iCnFSMEtJeHp1NzJlbXVhSUVU'
    b'alBOenJBUFJ4b2lVaHp4ZnY2Y1p0K0pSSytEWEwyRXBiM1ZRdDJzUzYrNitTeTdPSTYzdHJZ'
    b'ZU9uaG8Kb0tzOVJTWlFDdEZVdWNDUmdHTEp5d2haSGlsT2J3OUJnVGdXQ1B0akJPMk5FeG94'
    b'YjZaSjFlekYwaFZDYXlCMjM2d3NCbVdmLzYzNQozZDg2cFJ6cWYvWm5zT0FjdXJyTklYNW5W'
    b'ZnY3UjVJeENobnZCRCs4dUQ5T0l1c09tYzdyS3VxaHI1L3BOeVZSQzhySnVVWHFmZ2ZVCk9v'
    b'VG42TlVZVGlyNGtEMk1OL3NvcTJTbVJ6R1RrbVpHUXFGaVUvaktaL0dHWGg0UmoxZE9GM1ky'
    b'VjJlVS9aYkw1WjBsdUwyOXZlYjcKbXE2T0RnQWdQZ2MrNVl4NDFQUFBoSkk0QWlCTUFvcmNo'
    b'Q2pONWZjNGZDNmxBSFZGY1FYS21XR1NzeUxtN3V0azkxN1B5VThqQUFBMwp2SzN2ajUvYmwr'
    b'bU44cWFuaFkwSy9EdUxZbHdUek9Pd242NXB1dk9UZkVjWVBWOFpaOStwNlVuU3ZPeW8xU2JX'
    b'SitFQVUxbjZvMW8rCjY0c2wycnhFSjc4RVQ2b0EvRFBqU1BHTm54MGltYVRaVVZIaDBYNXRW'
    b'WFczeGpScjBkTHJUbi9Mc3V6ZXZYdGZmZVhWYjcvOVZpbmsKSVJDa2wvRGIrTk9CTk8xZmpC'
    b'TUJrSnVCUURYazZCOElodk0xNGhnTlYwN1h6Q3JEL0FGVUppT08xaXJlMmQ0ZGwrYWRyOWs5'
    b'SHVHYgoxM1M4ZVRDVlpxRHhTL0JsUlo0Q2ZmUzVYWm5uTFVIRnA4QmRJb0xKVHVlck5OaDNo'
    b'K1VSUDNuTUd1dDJSUVlvUlZCZkNVUUdBRUVBCjh3TUlrZENEMDlPUm9haVk0VW9CQUlBcmNz'
    b'Y2x4NnVydUZ4dVFVRUJRUkRyMXExYis5YmFtcG9hQkFJcjh2WGZXWDM5TVJnWUs4NmEKeEdi'
    b'aG9Kb2I4bUZDUUVZQUFFQ2dBY3A4QnNDRExwdWZZaXZOU285WG1HT08rd084TFYrUlFxNm9L'
    b'd1FEVkhiT2hqdEM2TFdsVGtjUQo3WFNKeGkvQi8zdFo5NDRtN2ZGKzJYbEx1RTljWXhaWVBL'
    b'U09ML1Q3aFM0N0ZRdlJjNmFxand3SlhhckZaMzBPVWs3MCtybHlYMytmClAwNldpY01YNWJn'
    b'dm14bE9RZ1pvdjlXZzEzNnpZK3ZldmJ1UDd2OUV3UnNTSUQ2S3dvd3A1alpQSURuWmtLU1I2'
    b'dUNleXlzRW1XSi8KU3R3Ukl1bHdBbG1ZQjdnUTdpWmtBRUFBUW9ESXdGZWwvM0VSUXZneGtt'
    b'QVRoTkRTaTV4cUNVN1ZDUTliK21uWmVXUFZRaTV6U1pINwppL3FrY2JwTVVvcW9SYm0rMi8r'
    b'YWY5NFNMS01ockNhaGNTQUE5dFNSdVVycUUyYlczRXh1bHV2Z28wdGtUOVFUenRnWmdzTkFz'
    b'L21RClY4VXpGSXI4NVZscytkelpRVWRreGpWVGpVOU5Eb1RDV2VuSmcwTnVjN2JwN0liSTFv'
    b'NWVyVnFPNHhST2tBS0VhVDlZNWRIRXBaTXQKM3g1MHRnWDQrMXRpVVY3S0Q2czRQdmxDMlNB'
    b'YndLekdtWi9XNHcrb3VkL3YzeVhuY1NGQVQxVnphb2dRNEozN0I3cmxSTkx6bDNXcgp4T1Fv'
    b'bnBNWVRRbStwc1FwNGRNZkhFMCtyMmNqT2poYmk4TXNaUlREZlJFbVV5WGE3VGMwT2lBWG1w'
    b'eEg5bGFtK3h0RDhpRE81VUpFCm1kSlNtczc1M1h6WEl3OWZNWFhaRXhGM0NJL0dHUXl6dHph'
    b'bDV4UWFNd3QwK2hRT1Q4cEZ6L3d4R0ZObENoMlB3Kzgrdk05U2Z4eGkKWVE1TG1lZXNYSEY5'
    b'WllteGM2QjNLQzhaOWdWRENWYWlFeEV2bG5Zdy91aDZ6eVF2TjcyaEgxdVlKeDNzYk03WGly'
    b'djhlSXBDZG1JbwpERVQ2YzdZL1JpQVZXWUVFZ1RRTlNjWWp3YjlmYUszcGxYL2ZKejl2Q1cv'
    b'OVpabWlIajllcUVZN0E3aktZRHJnRVBwam9LUWdmVmN2Clc4SjFMRXJ4ZDBUbHQ4MzN2Zi9T'
    b'dlMxZC9sbmxWM2ZVMjN0UDFkSUVsanlwaUNPU0JwMzJuaE5IVzQ4ZDRxc05iMjg3OGFlUDlu'
    b'M3cKNWRIdkczdFZVclQzeUk1algyNktoa055dGRaZ25zeUJ3R0JuaTYyOVI2SW9ZZ1RpTzI2'
    b'cXZIM2V3TmMxMUhOVE9raGYvQ05mWGxKTwp5WUVUVnBxRkRGcWV0ZTJrUWNycjhVYW5Kdkcv'
    b'NjdHVDh2T2FXZ1laVVpvVzJ0R2tIWThxdWlJcjhNYisxR0VLQ0hHbmtXOXFaeUdTCmhaVUN0'
    b'Sk9UemlMd2paWEYyL2JXTFo0MjVkMDI5ZzdRK2xSQnk0cGJya2FObFMrOFZIbjJ3WGdzTnRU'
    b'UkhPMXM0Z3VGc1hnaUVmUzgKOGJzMUhodzVHc21OQW42c1pSOVc5V3BSWGxxU3ljU1hLa2tN'
    b'Z3hneWJjYkMrZVl6TWNwWnAvK0tabXhhdHJxamtkM2t5NCtKc2l4VwpaMDZHVVNybVJ4Rncx'
    b'RUdxUkFURk1EQUEyWExrRkVPZUw4cDBvRXR4VjRWdFBNN0JXZHE0aEU4MkRyT0RuSXhtS2dV'
    b'd0JCREFPREQ0Cnl3SGhGYk16TWNLeXZib3hpakVINjN1WGxKZDgyTXIrWlY0M21uN2JqMzha'
    b'SWxGMlNYbDJTZm5wZnc1MGQ3ais4cG52NE5lclpjZFkKaGs2d3ZJZzhkOUd0OTVtbmxQSUY1'
    b'OTlpTFo1Y3NtVG1DOGQ4NHRRcEFZZTNmU0FxUUhFQXdPd0NIZENXTlhrYloraFFnZ0VtdGZ4'
    b'VQowQU5FaG5PK28yRkFLdUhUbVpwNHp5aWRUUjAxRmIwbzE2ZVJrSnRyRGVlZGdHTkRVMlI0'
    b'dWhRZURPTlJsdHZNSzB2VlNkTk5oa0ZYCk1OdWt4VWkydnQxZU5pV25vc2l2elY0QjRPRWlq'
    b'QktGcW5CYVdiSzVNTXlSSi9TbFUyWlgvTzZwSjVQVE0xQVVIYjZSYlBqWUtiZHUKejNHblBV'
    b'RE9MczdzSGZSZE9xK3d1Mjh3RGl1Q2d5ZlRwQnlGV01oRHVDZmNEQkNlV3dtekxEUS9KK0FN'
    b'b1cwTzhmZ2krTXFwN2lpTwo3R2xUbjkvQ0dpclhVRFJEVXd6YkdlRUZSVmswbGZDRXlFQTR6'
    b'dWR4U0lxT0pvZ09XeWpFbW91bE8rU3BTLy9KdWtrUUJFa2RPOVgzCnlvWjloK3N0RGwvNHF3'
    b'Tk51bVNETFNGd3hybnBlZm5lUU96Mlp6N2hjSkMxV3c1NUE3RkNzeEdHZit5T1lKeGZQTGZa'
    b'L3RiWGdRakcKTWl5YnBKWU91b0lBZ0U2YmYxR1pxZE9MZFBjMlpXblZHZ0Y4MkVFQThYbE54'
    b'V2xwSVFHWE9UeEtMcTFSMjBCazFrVzczTU41QUZnNgpyaExBRE1SeHg2Z1dObXRXb2Q0YllS'
    b'QVloaUNJb2htM1B5SVI4UUVBZStxRDcrMlRBUCtCc3c5K3VmZmttdi9adkhGSHpjN0RMUndP'
    b'Cjh0THZWeHc3MlJ0TEVCQ0FsRkxSbkpMTUE3VmRGYVhaRmFYWkpFbkx4SUlkMVUxSFQvYnNQ'
    b'TnppQzhaK3FKNU9iUDVpMjVidktBNFgKaFNCSUl1S2Y2aHhNU1ZJTU9BTjVtUVlKbnd1RWVp'
    b'YjlNbXNvSWVOU0VFc04wNUV1bDhpc2k0M1dPSThhd1RtNmVLZHIyR21KSnZnSQppQkJnYjlo'
    b'SW9scVZGQlVLQkVJQlZ5MFhwUnRWT3BXa2NsYStTaTY2ZE1HVWVxdlkwdkx0NlljU0ZGN2Zh'
    b'cHVhbHhLS1lsOGZiT1lnCjhMUHZmbnZSckh4em1yYWgzWGJ4blB6K0lWL2w3UHdFUmt6SzBq'
    b'ZDJEbDFiV1RLck9GT2pFTCsyYWYvbW5jZlpzeXRsZjFXRGM1SkMKcVNuSk4rV202NllWcEty'
    b'bDRzd1VOUUxEQ3FuQTdnMEJBQUJmMmVDaElRQkVuT0dHc2NNcHpOSEd4NTJSbFNURlI5Z3Nq'
    b'cUFJb094eApsbFVWQUFDYzNuQXdraGgwQllWODNxREx3a0hnTDZvYU9BaTg0YXVhSkNsY1hl'
    b'L01tc3NDQUhYNGJMZGVOWFB0WHc5VnpzNWZkWEZwCnNrN081ZndRenhuNC9tOVhDSTVrbHR3'
    b'djFzaCtzN1NzUEljZmlRd1c1eVh2K3E3dFR3OWVVWnozZzNNajRLanZkQXBPdE5vNENFelIK'
    b'VExmVlRkRk1JQnlQWTBSajV4QUg0Sm5KaXA3QmdGOVIvbjVERlFibkROTVBSNWl2aytMalRv'
    b'TEZmSHI0czBZUUlzQW91amFhQkFDVQpuNlpxdG5oV3I1Z0JBTGpqbWprY0JINzBsaVVJREQ5'
    b'MDh5S1V4M0dHcUVnQ0JhUWZBQ0RsQ210OURZL2RYRkU1S3ovTm9PUnlFSVpsCldocS82OTcx'
    b'OXFsWGwrQW5YbEp4aHdKVmovZHNXaE54MnBMMDZRSC80TUxwdVhkZU82YzRMeVZHWWxFaWNi'
    b'cjJRYWZINVk4QUFPNjcKZnI1WWlLNWVNY09na1YxelViRldLYWtvemRacGRhVTVhZ0FBNEVt'
    b'N3BJc29rV0dZamtRd1JNSWZ0ZFErbzNZMmlWaTdWLzN3L0hEaQp2Q29FQ2x0aHpFRnJ5d0VB'
    b'MXk0MGYxSGR6VEFzQXNNMHc4QXd4RERzNmMvVC8vUHU2dmlOcS8vb0RuTlFGTzIwOXBRWGxi'
    b'YTF0OGxrCnNnU0dZU2piOU9semkxSVRrWUVlQklFQkMwTWNubENYd1pmS0JMT2VnYVdLUm50'
    b'M2Y4QytNTFhrMGFNZmZMajBrZE8xbi96bTFpdi8KTEIzMDBUK3E3dXpudkNMZGdaUE9DK21w'
    b'WEVDNi8zU1FkOC9pY1NUQlFoNk5RR3dNRzA2Q1dXbnFhWFlCQUhaWFlIbEZZVkdPY2NXQwp5'
    b'Ym5wdWlzWFRjMDJhWCt6dE15a1YxNS95VFNkU29MQUZJd3FZQmpXcVpWejhHMnNwMG12MTBN'
    b'UWxFWFZLbkdxVkdnTDJYb1lGdUlnCkFNQVFBSGpNYTJjUW9hdnEyYjZnNDZHdjM3ZzRZN3Jk'
    b'NVppTUpzZGlaNndoZ1ZETWdaSGYzN2dBZ2VHSGIxN01RZUNIYmxwMCtwUEgKNVR5eWVuRjlo'
    b'ek0zVlhVaG5ZMWdIQVJpQlZ4NkhFbXdrRWRIWHQvUHUyY3h6WTRjS3kwMjZ6cjduVEhpdkNV'
    b'NUVMWGwzdkFWdDM2Qwo0N2pWYXMxaWpudVZpMlV5dWR2cmNRUmNuRjMzOCtrSWdDR1ZraWRY'
    b'Q3ZBNFRUQ2dQYVpKUm5uYXN1VjlWc2RYWXMxdGs1ZXEramR5CnNxOXZId3FtcGFmeFVYNnM3'
    b'ZGxGVDFQSE8vM0ROT3phaGRtZjdlKytnSlVvUzZ6ZEs3NS9ZWUljaGQwZG8yTmt4UW1FWmlF'
    b'Um54NUcKUmYvZzh6SksycXorZTFiTi9IRGJzVFZYekZ5LzdkZ3RsOC9jOE5YM04xMWF2bkZI'
    b'elkzTHArOC9laUlyR1FBQVVCUTFHQXoyd0R3eQpGbzlHWTRmZExWSzN4VXhHaERKVXJ4ZEJM'
    b'QjBONDRrRUpFdEpvNE5EQnFQUVdmdFhsSnRrUS9JNytpMXp1UUtyeXd0SmhUaWcrUUNJCkZP'
    b'bFRVanM1Z2d3QUFBeEJGTTN3VVU0MGpzc2xRbTh3cWxWS1hMNnd3eE82a001SytCVE5RcVBD'
    b'N21oYTBURUNrYUFYUlBCQ1YwK1EKRjltNG94YkR5WTA3YWpHQzJyaWpKbzZSbTc2dVRlRGtw'
    b'cTlyRjA3UjVHYWY4VE1rRWdsL3dLOVJxUm5BeG1yM1RwTExSQ3FKV0FRUAo5ZnREQVl3Z2FJ'
    b'Rkk0Qmc4b1pFS1kyUnlTcjYrcjYzLytmTGYxUFYzK3cwcmhTeTd0K25RNm5tWEF3Q0F0TFE0'
    b'NWZzTjFkR3p1Mk5aCkZrRFFtYy8yWG1jcUwzRUxHaHpTWi9jNGdpTVJURWRHTHd2VHFGblJF'
    b'WXdqUmtlZWxpUWlmbEdINWIyK3JqYzVWcTBFanNRd2xtV2oKY2J5aU5BdUI0ZGxUTTdrY3BD'
    b'ek56MVBOQkFERTQzRWVqMWVvSmZYOXIxWDNOeGdYWDQyRzJoQ0U5ZHVERk1NbUpZdXo4dFVH'
    b'a3lRdApVeWtWY29KdXB6Zk1TMTk4UzhmK3JWcUs4dmg5YXQvdWk3T24yTzEyQUFBUTVSYWxl'
    b'QVFJdFhoR0xrVXhpOHB6YVpyQkNZb2dLWm9rCjdoRjd0em83cnV5d1haWWh2Z0FKcGlNWU11'
    b'NElkb1pRb3d3YldUOG5pV1F1UDVkbDgyUHhJeDgvOUtUU0oyQUpBRUFnSEk4bGNIOG8KamtD'
    b'RVNUSUFwRk1CQUY2djF4OE9oZENVaUt6b2hwbkxtMW9hZG56Yk1qZ1FrV2lreXBLTExJUVFn'
    b'VUhkZC8weU9kK1lLalVaRWFxLwo2cXZuN25IMGUxNGVQT0tKdWtGc1NNMUw0RGdlaThVQWdE'
    b'TFRjeWRsYUJ5ZU1NMHdUbStZWmhnQXdHOFVrVTl2TGJzcXg2UklFQUNBClRFQ08yQVdEREhk'
    b'R1J1MGt5Nmlwamk2M0lFY1hPOUExd3M1aGd4QVdBeGdBUUtjbkN4aHFUV2Zmc2lUVkc5cmtU'
    b'enVIQUFBdEZudHgKbG54S0xoZEFIQUNBSWtuOVZkZlIxNy9kc2pCcGl0SzVjWERYcmpSVjFr'
    b'RUxlNlExR0dXM1RpNmRIZTZvaXlYZ1hYczlZUnoyaHJtawp4Q0JSVHZHZk9ua2tHUDVEL2xV'
    b'MjRTb3V3ODNNUEJPOVZ4bEtKcG1hUDlodEF3RFV0OW15aE5qendEZXp5eGtWWEJUT09yTUhs'
    b'TStNCnJJUnlkTEZPcDNqOEVld1NtNU5HOXRDU0xFUURsZ01nSUpkQkNNS3diSXJULzRlYlZs'
    b'Um9qQzkvc0x2UHoyZ1VZcFB4ekhKRndoTXkKTFBOSzViMTlRY2RCMnltTkx4d2htYisvU2Qx'
    b'd3VBT0NwRHkrRHZmSEFRQWNIZytTMExiMk9qSExsMG1ZVitxL0tNa3F1S2YwQ2tmVQpweGVy'
    b'QUFCQW1KR3FPQW9Ba0NERW1xdG4zRGc3VjNIdDcyRUFBUVJDMVdkcVpNRElxd0N6THRibEVv'
    b'NDdnanRjd3RVemd5TVg4NUplCklab1VKMkFPUjIzUXR3dFJiWUxrNnJXM1g3c3NiL2Z1SmlS'
    b'NGdwOGtGZndROWJ1eDhLSWdGbjJuWWZ1ZXZycUhIcjB6Ylg5TGE4TXgKejIrWEYrdk1CNndO'
    b'UElSYlpzaWxhV1pGenV6M1RuNDl4NFgwVTRjT0pVTzlpS1BIZHFRcE1XQUpEdDB4OWJJekJF'
    b'TmNQb3pkcFF4ZgpGSEl1ZSt3OURNTjZZRWpGQUVTbDRPUEU2ZXA4UEhSa0NkYkdSbkYzOUtq'
    b'TndmVTJhWmtwQ01NajVBVzBlMEtFVGcwQTRNUmpLSXF5CjJha0FBQlluQVFCeUZMMmlyZWRT'
    b'Q21PWWZ3cm15UG5penk5LzV1SHBxL2dJTDhpaEVabGtWMDl0WDhqQmhUbFRkRm1kM29FdDdm'
    b'djMKOWRjTE9MelBlby9BS0Ura1ZCckU2aXR6SzZicDg2NmJ0TGhBOC9mTUFpd2xaOEFUbmQz'
    b'Nk9BRkJFQjVQOEJnMmdVQ1NnbHcyRkFVQQpVSUJ0aVRFakxvTEwwc0tqZUdKNDFDUzR4eU9N'
    b'WU53cHhrakR3SENkcDJqR201Rm02ck96UFRZQUFMZWlERFJacUFFSEFJQ1RsUWJBCmQ2cHd4'
    b'TzZNSnY5THVvY25aOTNRN09tOTIzSlVsajNsZW5YcTdWTXVqVlBZVGtzTnlaQXJ6TE5sUEpI'
    b'Um9ENWx0Z2d1bWIxeDhzVk4KN3Q1Y2xZblArV2RUS040amlBb0FBRWhXR2dSQnZyWk9NWUJj'
    b'UmViTXpIVHYrNThBQUJ3cDJ1MXR2dUc3T2RVVWptQklyMWN3N2lRWQpBSEN3V3pFL3h6OWlz'
    b'U3F4aG9DQXRzL1JkN1RHZU5NMUlhbVFxR3NFQU1pV0xjQTRzS0twZmY5eE8yQi9iTTEyMjl3'
    b'SDk5cjJybm90CnE2K2tCQzk3NnFVOUw3OTJaQkpSdUp4L01YVlN0VEovUWJ3WHZjOTAwMUxE'
    b'N0ZjMjdKK2l5L294dXdENGhvNGJ1eU1BQU42UzJRQUEKdkxZUkFDQzg0WEtHWWNoRHh3RUEx'
    b'cUxDYUh5RU1OSENuTUMrRHRVb0R2Sm9FbHpkcVZ5WU96TEI3OWJhTGRNS0VRQUZQdmxHWWRR'
    b'VAoxeStYMTdYYWF1cU5oZm1ocTVhby9SSDFnSkVhMnZMamRYWU03N1o2VUlSYjEySzl0cktr'
    b'dkNpOWNuYis4b3JDZHo0N2ZLTFZhbmVIClhaN0lyc090Vy9lZWJPODVWOHdBRzZpcGNTVi8z'
    b'K3pKTktTdlhra1NCTEZ0ajNPcTJYek5wWjFmN05CYVhUNjE3RTNmeUl1ZkJUbSsKNmk3bE9D'
    b'WDRteGJ0bkt6QWlMRlNpbWJlbFpnQ0NvbjhxLzA5VlFmekg3bkxYMTdvWGJ1QlpkbXNQOXpy'
    b'THNqSTJkYXdkL3RoMXIzagpINThTb054WUFtZi9PZmZ2NFhwTDc2QTNtc0RYYlRrRUFOQW9K'
    b'U2xKNXpKL2NQdkpQVThtL2RWSENuaUtGeDRXU2lXZEgvNlZINDBuCnYvcGtMQkRFWDExUFE5'
    b'REJpam5ITEo3aFc2NlZFRE16Zzd2UHZ5M3BWMDZ3UDhhcGFsTmZXK0lhc2VTMlJ1ZmY1aStr'
    b'dWR6STAyL0UKL2NHc3RjOUQvbERUNis5TDFLcTBEYStHczVJejM3QWMzckk3ZFBKK0VHazgv'
    b'VWgycWxZa1FGZi84ZU1iTDUwT0FOQXFKVXFac1BwNAoxODYzN3pyNGw5L2JISDZEUmxZK09Y'
    b'MWFZVnBlNWo4Y0xXRXcxdm41a1MvL2lMd1dFZ1ZpdkxWUG1lYk9HS2h0U0t6L1V2VEdVOXJj'
    b'CjdPWkhYOVFNZUk0dm1mWEFkeU0zK3pkbGpsMnQ2dEc5L21HVXp5YVJOSFIzeGVBd2h4dCsw'
    b'T2Uyc0haUmFXRkxxK3RZbmVicVplcXIKbHZWdS9qSWVpNlhNbXFhOG90TGg5YkQ3ZTU5ejVP'
    b'L1pzMUZEZkcyUWhoRmgyc1VWcFNzV0ZKWGttd0FBb1FoR015eEdrSEtKc0w3TgpwcEtMYnJx'
    b'MFBNMm9rb2o0czZabUFqSUEvRlhPOWszck43M3p3QWVlUlNFMWgyTDE2Ly9QT0szRTJkclIr'
    b'ZUpibVM4L25qeHoydkduClhqWjhYblZzYWNYTkxTUkpqZXppV0x1eTQ2M3ExSEY5K0t6WEsz'
    b'cjZFa3QxbDlJUlFpK0U0M0I1VVpIZkdkbTZTMUF4UGYrV1ZZTU4KVFMwTkozT21sNHJLcHoz'
    b'WDRad1QzaW9LeDUrdDFyMjFNMkJwL05Rc2FWREk1QUExQUFCZ0dEclJhcTF0N0hkNFExS3hR'
    b'SytSWmFkcQpBUUNXbmc2bTcvOCsvM3pkL1I4RVgvZ3Nrb2M1NXdsczc0YVRGajc5YUhaK1p2'
    b'T1JvN2E5aDh1ZmYweWtVWjk4K0ZsMDk5RWRsWXZ2CnJnMWNDTHVscWFIYlp3L2Q4MW5ldUQ0'
    b'K1NqTVFEMkd1S1hGKzNuQkJSL0NhN0pHdllNV2tnbVJ5dzVab05KSjN3OVdwaFpNU09IbkwK'
    b'STJzWFJiZmkvb1FxUmRTTlRQbnd6bVVsVGI0QnIzRmJqemRvMlpDZExCSEtNODFwMnJLQzFC'
    b'VUxpckpTMU5rbUxZY2M2UHorMWFvVApvVVIzVW80RlhYN0p2QTVja0N1MG9PRm9BWGZ3amFy'
    b'ZXZJTEpPZmtaNWdWekJ3NGVhM253dVpCQS9KZ2c5YU9UTHZiQ2N2cXZXOVd4CjlhVHVVUGY0'
    b'UGdBT0FHaTBTMTYvcXVQYlZvMzd3anp5Q1lMNjJocmRpNnF6aE1EejdlNVFJUENIVGZzcTQ5'
    b'dXdRRUthSnQvZ25mZlUKa2p3VkI1YS91cEdOUnlaWHpwYzBFdHY2dlVwOHF5R3RYS0ZRd1RD'
    b'RThoQmk4Tk5QdnUxU2RvZ3lCV0xwcVdiTjE0ZUp5ZG16cHFScwo2bEhyeFhaZUpGYUlPdC9l'
    b'YjhsVnEwK3UvY0RUNzNvcEpuK3h5VC9vdjlETmtmbjYyRE9YOU56d1VTRSsycGtOUjU5Z25J'
    b'SWxBdnF5CklzL1duNUlFTUlxUjMvU0V0bGlKVG4vZ0NtWVhGc1NrYWZJTjNyblBxRmh4ZlNz'
    b'Nk9aZjN6YUZZa29vM0tWdjJ3dnR5dnVpK0ppTmgKZTYrNElCOXdwTDFISDEveTVORGRBcDUy'
    b'M1JhaU1Jc0p4NFNkL2Zqc3FYQm43NXpCbnM4RTA5UmlKeThheTBNY214cURMelV4SDNjRwpy'
    b'YjZmdHJGNTdjcjJuUzNxUGFOcVA0KytGWDBXcisxTFhXRDJ6YzBLL05RSHMrU0ptMFFIc1JB'
    b'bVRaTnY5QzE0aHAvSStMd0s0ZjlkCkUzQTVMRVVEQUJBQWFCYTYvUythbDE5N3NyZjZsbWtQ'
    b'Unh3aGxITTZUa0F4RVBkTXNCWkNlYnFqcCs2em5hcmxYUjdXYUFERFZqSzEKNVNyM1QyM1Yv'
    b'QnovM0t6Z240YzlWemUrQ0E3RXVZOXZONjliMWM1RmZzS1ZOV1k1OWtoYTgyblovV045L2tk'
    b'L3VsY1NTNXptNmUvcQpDUUgwUDFsRGoyODFUbjVVOWsvcHEyZ2F3SDhubU1zRkFLQ0J5S2FY'
    b'Ym4ybnB5U3MwUUNXWFNucnVNamt2L0JXY1dEMnoxZDNQdkszCjdERnluY05ZeVgyN29jWVFq'
    b'SFB2VzJDOXdQSzVpc1REcWMxNG1KU215Uit0TWR0QzBOVVBmT2pUYTNFWVFGd3VRSGs0RENB'
    b'T2g2Vi8KYk83K2FHOFVTMUVRajhNQVFIQTRBT1V4QUlRekRLc2UrVXV2UGZUa3NZeVFXZ3NZ'
    b'c0VMWXVTelZjNEVOZTNDUk5SRG5iRDV1R0NNRApPNGFTa2RaWlpldHZhTjNUcG5hRlIxZ3k1'
    b'Y2pqRDVsYXNDZ3BTcFUvVW1OMko3Z0FnQ0YzY0t1RFRMcDJjV3FPUWNqbGVUTDFkRVl5Cmlu'
    b'RFJnM1h4ekpUZGtNenErRUVRaFh6ZXpla2lmbjBiTnRsTTUyVzQ4MUs1QWo0dnpYakVsSFpI'
    b'RTliUVBnQUFvRm5vOEpCOGRnN0IKajhlek9UNUtLT3dKanhEV0xVNEp2M2RkMjFYdlQvRkV4'
    b'a295MGpHVXZickZMbjdpcSt3djFqUktCZFR3SlZHV3hHS2tLRlh4YUkzWgo4dythTUpZZ0h0'
    b'cldkUE51VzZNM1R1LytqaXFmMFNwUk84b0x6dmNlVjI2cWMzSmhhUEswU0hXTmwrSGM5VTMz'
    b'Nmk5YjNmN0lEd1lnCkRmL2grNHl3V2dzQm9JZkN3N2RLak5KL3ZhWHBrYitaMnh5aXNUT3FZ'
    b'eXRmZEwxTk9pTXp0SFNTWjl1cDRTeHFGODQzR1Rsdk5hZDQKempYUHVmMlJ6NDczdThwS3U0'
    b'WUNUNncvaU0yYVdWbzV0YXJkOHlNSlhyMTYwUlp4eXQzdkhyQzdRd05aZVE5L2ZxSnY2Qnl4'
    b'djlOeQpiRTRHNjd0TncremloaUN3OGNhV3dTRC9qMTluZ2JHRU1YZXRqb1JQSDN1NGR1dEo3'
    b'ZFBmL050R1NxK1J3UkEwNUE3K0k4RnBSbFZiCmorUGZWY1d6eXkwcml0d3ovelQ5SjF6dU5O'
    b'NVU5R2xFTUtUeXJaS2JwanZ1bS85dlNHMGhFdkFldTNXSk54QzFlMEltdlJLQllRQ0EKUVNP'
    b'amFLYWp6L21IMnlyL2NGc2xCUDMvdWhMdm5ETnc4d3o3Slc4WGp6VjJ3ZGk4NG4wb2lDNWRW'
    b'M3p3Z1RwUGxQZEozYy9QSW9iQQo4UDg5Y1BuaUdia3ZyYTk2OGY3TGxES1JSTVRmZWFqNWlr'
    b'VlRaUkwrLzc2L08wV3ZhR2diNENEd2hmaVd6NGZycGptZVh0NVQ4VnFaCnpUOFdyMDZDd1po'
    b'RXUxTjB5ZHRUWDcrNjQrNktnWi85RXBwaE5tei8va2g5RHdEQTVRMGJ0WEtidzUrZHF0MjI3'
    b'NlJlTFZQTHhVdm4KRktRWlZZK3Mvdm5uL3U2WlozdnRxczVMM3A3YTRSU056WkVjb3dRREFP'
    b'cjZaZk5lSzN0NGNkK0xLN3ArOWtzcVNyTVBuK2dHQVB4bQoyYlRIWHQ5ZWxKUDg1NDhQWkpv'
    b'MGtUaDJzbVBBRTRnRXczR0orR2RLM3FOTCtoOWQwcmZvenlWMXc2UmluTENpaDRFM3l2dXlR'
    b'ZmZzCjhwN1pXWUc5N2VxZmNTVlJIQ01hMmdiaUdKR2lWOTZ3ZlByK21nNlhQM0wzeW9yT1B2'
    b'ZUdyMnAySG1wQmVaejEyNDVSTlBPVFhpc1YKVUJ0dWJGbVk2NXYvK2pTTFJ3akdNSDRaMTh1'
    b'K3M2cTFORFd5Y3Yza1V3T2pmeEhDMU9USXA3YzFOZzJKMTJ3cUNHRmovZEwzWDhBRgowUVFG'
    b'Ynp1bEl5aDQwODB0REF2VldXVU1Pem9oZEM3Q1ByVEkrdjcxYmM5OGsvbjRkak5Pd1dETTQ1'
    b'ZDB4WHVCSWZyMnFuYTVnTHpuCjA3ei9mdHFwaXV6QXVwVnQzaGp2cmkzNVk4cFg5WXVYNExO'
    b'd1IzZ2Jhb3dKQW5udnVyYmkxRWlIVS9UZnVYK3F3QkI5NCtxT0J4ZGIKbjk2WitlRFczTEhq'
    b'Wi82MUVYd2Fwd1lsNjQ4WmM1TmliNjlxbjVZYXNuaUVqakQ2SDZxcnhCUmVlMjNIMDhzc3U5'
    b'clVOM3hVZUx4ZgpEbjVwK0NXcDZCOUJ4cWZ1bVdmNzNRS2IxU2ZZZkZ6LzZZa2s5NzlKdHJR'
    b'U1lsV3A4N3BwRHBNeThVWjE2cnBES1JlU2lXQ0M0UDhJCmVCeDI2U1RQRGRNZFMvSzkzL1Vv'
    b'OW5jb0QzUW9UdzFKbUorNGx4R0cyYW5Ka1FWbS84SmMzNnlzNEo1VzFjZTFobDF0R29LQ2Z0'
    b'SGoKODRzbitDeVVJbXBaZ1h0QmpuKysyUzlHcWVOV2VhZEwyT1VVZGJtRlF5RitGRU9pT0hK'
    b'Nmw0VmNRSXBSV3N5bmpUTE1ySTNuSk1WeQprdUpscG1BRTQxWjNLdzUwcUhhMnFNZkNwV1VU'
    b'Qko4WFdkcDRjVXJZckkzbkprWE4yb1JXZ2t2NHRGeEFuZzRyc0N3SUpyZ1JESEZICjBFNlhz'
    b'Tk1sNm5JTDYyM1Nuckh0c3ZoNTRJQmZJeXh1b2NWOURyWkVQQm9BRUNNUU1HN0FBZU1KNDRy'
    b'YU03WUZtTUFFd1JPWUlIZ0MKRXdSUFlJTGdDVXdRUElFSmdpY3dRZkQ0d2Y4RGxPT21VUER3'
    b'K1RRQUFBQWxkRVZZZEdSaGRHVTZZM0psWVhSbEFESXdNak10TURjdApNREpVTWpFNk1UZzZN'
    b'RGdyTURBNk1EQWxOS25oQUFBQUpYUkZXSFJrWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEEzTFRB'
    b'eVZESXhPakU0Ck9qQTRLekF3T2pBd1ZHa1JYUUFBQUFCSlJVNUVya0pnZ2c9PQoiCiAgICAg'
    b'ICBpZD0iaW1hZ2UxNjA5MCIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_UT')

US_UT = b64_US_UT
index.append("US_UT")
index.append("United States of America Utah")
catalog["US_UT"] = US_UT
catalog["United States of America Utah"] = US_UT
country["United States of America Utah"] = ('US_UT', '', 1)
lookup["US_UT"] = ('US_UT', '', 'United States of America Utah', 1)
lookup["Salt Lake City United States of America Utah"] = ('US_UT', '', 'United States of America Utah', 1)
lookup["United States of America Utah"] = ('US_UT', '', 'United States of America Utah', 1)
details["US_UT"] = {"continent":"Americas","capital":"Salt Lake City","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["US_UT"] = ('US_UT', 'United States of America Utah', 1)
regional["United States of America Utah"] = ('US_UT', 'United States of America Utah', 1)
#----------------------------------------------------------------------
b64_US_VA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjI3NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1ZpcmdpbmlhLnN2Zy5wbmciCiAgIHhtbG5zOmlua3Nj'
    b'YXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9uYW1lc3BhY2VzL2lua3NjYXBlIgogICB4'
    b'bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2RpLnNvdXJjZWZvcmdlLm5ldC9EVEQvc29k'
    b'aXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hs'
    b'aW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2'
    b'Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMx'
    b'NjI4MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3CiAgICAgaWQ9Im5hbWVkdmlldzE2Mjc5'
    b'IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAgICBib3JkZXJjb2xvcj0iIzY2NjY2NiIK'
    b'ICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAgaW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIK'
    b'ICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4wIgogICAgIGlua3NjYXBlOnBhZ2VjaGVj'
    b'a2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtzY2FwZTpncm91cG1vZGU9ImxheWVyIgog'
    b'ICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAgICBpZD0iZzE2MjgzIj4KICAgIDxpbWFn'
    b'ZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhlaWdodD0iMTAwIgogICAgICAgcHJlc2Vy'
    b'dmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0'
    b'aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJlZj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0'
    b'LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFBQUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJU'
    b'VUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpnQUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFP'
    b'cGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFBL3dEL0FQK2d2YWVUQUFBbApsRWxFUVZS'
    b'NDJ1MmRkMkJVVmRyL3o3MTM1dDdwdldRbWt6THB2UUVKSlpTQU5DRUJBUlZGd0tDSVluZlZk'
    b'ZGRYMSs3aTZxNnVvb0tnCklsZ1FwUGNXa2xDU0FPbTlUS1lrTTVOcG1YcW4zWHZuL1FObDEr'
    b'M2crL3NCeTN6L21tVHV1Zk9jODVubjNQT2NNK2M1RU1oOEVVUjEKTXd1T05rRVVZVlJSaEZG'
    b'RkVVWVJSaFZGR0ZVVVlWUlJoRkdFVVVVUlJoVkZHRlVVWVJSaFZEZXZhUDlObFltTDRhY2xT'
    b'dElTeFFsSwpnWkRINUxCUU5ndWxxSWpQSC9MNXczWW5yaDBlN2RYYXV6WFdFYnMzaXZCR1VV'
    b'YVM5TFlKeVdYRlNWUEhKWW9GTEFCQUlCQVlNaGo4Ck9PN3orYnplRVJxTnBwUXd1VHdlbHl1'
    b'UGpTMkZFUVFBWUxKNnF1bzFwK28xSitzMDJ1SFJtN29Gb0p0MHZWQWg1ZDQxSjJkNVJlR1kK'
    b'YkdVZ0VHaThkT2xDZlgxbmU3dE9xeldaVEpGSTVQSmxrUWdscENOTzRzYy82WFI2ZkVLQ09p'
    b'bXBvTEN3ZVB6NHRQUjBHSVl2ZFJpMwo3bXY2NW1DcjFlR0xJdnovb2J6MG1OK3NubkxuN0p4'
    b'Z01IRGkyTEg5ZS9jMlhyd1lEb2NCQUJnRG15d1YyMkxFd2hnNXhrRGxEUmZvCmcrR1dKQzZE'
    b'SjFUNWd6MTBORUFFeHVpc3JWQ2dKUkFBQUFnRWdxbGxaZVVMRjQ0ZE55NU1VRi91YVhwbmM2'
    b'M0c0SWdpL0grbDNEVDUKRzAvT0xKK1dyaGtZK0hMejVtTkhqdmo5ZmlhVE9hbTBWSldXY2Vo'
    b'OHZTb2hadjZScWdFbkppcE5aUk9Pa1FhTEg2TzVWMWJrbkRvbQowZUp0UWJvem1SVXJSSWdX'
    b'cTNaZW52cDBrNTZpZHBBaEhobFdLQlJMN3I1NzZiMzNNdG1jYncrMnZ2emh5WnVvZDBXQWRN'
    b'cU5ieVdMClFYOXh6YlN0Nis2RVEvYTNYM3Z0OTIrOW1XVFVZa3JWZzQ4OU9xOHdRMEdGaW1m'
    b'TTZuY01pT1ZJNnZnSkxzY2dPbXdOT2oxMkJKQTAKbUhXdU82eVNNZ3NWd29nVDlmbE0vb0F4'
    b'UVJUcmNQck5sTFZBS3M4cTRNa1Z3T2M5ZnZUbzk5OTk1OGZ4dXhhV1BibGlNcDJHbkc4eApr'
    b'Q1FWUmZoL29ObWxxU2MyVjA0Ym8vendUMzk4NWFXWEJqV2F4YW1Lb21HZ1hqZ2o4dFcyMGFQ'
    b'dHcyYjdjQVpiSk9OT3lKclEySFFCCjhqbUJPd1J6bUxnbHdPWlFTb1RBRFQ0UGwwTUhvUmd6'
    b'enZVQ0JJT1lBbGI2YjllVzM3Mml5OVVEQmFtS0dOWGttZE90VG5mTHlXTmIKdnQzT1liTWVm'
    b'YURpenRrNTlhMURSb3NuaXZBWEdJZkF2MXRidHZIVmhYVm5xaDVkczhiVjJEaUp5WitTbXA2'
    b'b0ZMWmFuRFM5empoRQpCbUk0d3VjV0hlNDVHcytKUi92MHdxK1BCYlJCS0RsT05LVUkwZzN3'
    b'WGFBblZSd1R6d0x4TXQrZ3g0eFRoRHFtN0sxWFRaOXVON1gyCnNrdHkwcFZKNSt6VmduUDkr'
    b'TUZ1b2ROZGxLR1FqZUNiYTA2ZFAzTm0xbTFUbmw0MVBSU216alhwbzgvQ2E1Rll3TnIxNTN0'
    b'TGNoWHYKdlBYV2p1M2I0OFNDUlJ5TU9lb3pLOFVBRHdRQWhnSkd6dUk1alh4bnA2VnpjZlpp'
    b'djlFNzlQRW1ra0tnRE5YWVpjc1pHSUppRElGUQpRb1NETG9lZHllWHI5WHE3elhaNXNCclo4'
    b'elZ2SUFEZE16dm52cVh2SFhoUFJmS0t0NXpXZVRHckFFMk9CSFI4d1E3TEVJcWlMNzM2CjZy'
    b'enk4cDNIT2xhOHNOTWZDRWU5OENxa2xIR1BiNnBVU2VDSEtpdHJxcXZ6SjB4Ni9IK2VEZVNt'
    b'Ry9oMFJuTWZIa2FUbE96aXdlR2UKcHRiK1FYTjIwbVFSVTVTVG5USDdxY2ZMMXE3T0xwM1lk'
    b'ZjZRUXFFdzlqVlBuREVQZHp1N3FyNlpzZWgrRmgzUUE5YUtwZmZUU0I5bgozS1Nlc01YWTFx'
    b'RW9Lc2xOeWR2UnV5OXI1ajBoK3dCS0JJekpzYWhVa09NTXljT2hMdzhmTkZ0dEQxVXVualVw'
    b'ZGZlSnpodVQ0bzJJCk1DTkpXdjNWZ3dqaGZHREZpa0d6UlpoZmxKWVN4eElJcHhWTmRILytw'
    b'YnVQSUlyanRGT1NHaWpjbUoveC9NdnJaczZZZWZId0ZoQWgKTHg3N05uZmk3TnBkbjJZVXow'
    b'akpIUmYwNHhpYjcvZTVYQ1A2dEtJcExXZVBkRGFjakVzdjZtdzRPZlgySlJOdlgraUJ2QXl1'
    b'dE8xaQpLd293cmJrcHB0NU1qUUxZaGJOZ3YzTjhVcnhhaGJENWgwK2M2dXJzWExGc1VYbFox'
    b'cDZUWFY0OEZKMGovVGRTeVhsSE5xNGNIZEhlCnYyeVozVzYvYjgyeWpIUytGdTNhMy9MdEM1'
    b'dGZxSGI2OVN0eW5kbEtycFA5M012ckZ4U00wYldlUVdpMDdMR2xZZDhveXBNQkFKZzgKa1Zu'
    b'VGhxSllSODF1REdNUXdRREs1QUFBSEJiVHZNb1hqbjd4Tm9TZ2REbzZhck02ZGUyVEprOSs1'
    b'TkZIVjgycjlFZUV4OHBsOXJKawo5bDNUMlFOdXhtbTljUHJNdlBLNVkrZmNmcXE2NXFIS3lz'
    b'UVk1ckZOOXd0NXpDakNmL1A4TzdhNU11UzFQTEo2ZFNxRG5DemxBa0ZvCkxKMjl5S1dZaFN1'
    b'VGlRUmsyaXd4cW5yaXJpZEw0aFFnSEp3d2UwbC9VeTBBSUsxb3FsSFR4V0d6ZG05OFhaVTl3'
    b'ZTJ3SGQreFdhQk0KaFdFb0VNQUJ4c2Q5M2xIbnFDeFdyVXpKb1lKZUFFREgyZjA1cGZNQkFI'
    b'YUw4Y0RIdi8zNGxVK1dGRmQyeFVJSHFVWnZIRE0wNGp2YgowMnZBQnpQR2pVc3Z5R3hxYW5w'
    b'ODdkclVPUDZoRFN0WURIcTBJLzNIb3RPUUl4dFhLb1hRNnNwS1ArNjQwNCt5WXhMRjNmMUVW'
    b'WnVuCjFlcnBOS1lzbmhQRFlVbUFWU2lSQ2lSeUlvZ3JFOU1HMit2WlFybElxbWkvZUhicUhR'
    b'OHFVZ3BhemVGTHd5R01MMSs0K0c0TVk4aGoKRTVPekN1a29Xamh4Qm9JZ0NSbEZmSWt5QXNI'
    b'SHYvMXd6dktuVGRyK1haKy95MmF6aTZiT3owclBtak51anZHaU1WU1loRktCSVk1OQptREla'
    b'UFYweFNmTFlPRlhEaWZPOVBUMFBWQzVOVFpUc1BOWVJSZmdQOVBiVHN4Wk9UMTIxZkxuZWI4'
    b'aU9GM0pNZ0V3UnV4eEJRaXBoClo2aUlXUk5LeThwbXpKeXBTc21wK3ZZRENrYkNvVkI4YW5h'
    b'UUJEMnRGek1LU2dvbXpXS3lXTHZxTmUwMnN1WHdOaXpzc1ZxdGZENmYKeitmL3JOdUJZYTVB'
    b'aERFWXl0UkN1OVhjY0dwZnhjcW5tbXYyRjkrMkNBQkFSK21scFpNdE9tdlMrRW1URkJuMFQw'
    b'NXlMN201RG1JMApFOHMxZTl1N2VrYzgzaldWaXkxMjc4WDI0U2pDbjJudTVMVDFMNVcvK3RK'
    b'THRXZXFWWW04bGN1ZmJUZHBlTGhIWnJYelJsd2RBblROCmIzNnJWcXNCQUF3V08yL3l2UDdt'
    b'TStFd2tad3pGcUl6R3hzdUJFS2grRVIxYTJkM2h3dnJPL25ONHl1V0tCUUtGRVViR3h1WkRJ'
    b'WlUKSnZ2N1QrUUpSQ0tKUEh2c1pCUmp0Snc3UG1aYStaVzNNck95ZERxZHplZW5hNXFUTEQ3'
    b'Y0ZHVDN1cVRKb3ZnaGNsdHpYVVptNXVwbApNdy9WOUpxc25pakNuMXFUZ3gzYlZIbjZ4T0ZQ'
    b'MW4rMGdNdWZxRWNIYTg2aE1RekVIdkc0S0xPYys4SzJiVktwOUMvQkxBU2w1STFYClp4WkNN'
    b'RHpVMnliR0tJUFJuRjB3WnRUcGJ0T1lZTHQyU3NuWUlaT3B0ZW1TbUVVekdJMkZSV1AvMVhB'
    b'QWh0TUtKNk1ZQmtIUWxYOG0KcXRWdWw2dHIxT2x5ajhnSUhQTkJ0QVFwT3VqVkM0ampwMnJt'
    b'VjVUUG5acnoyWTZMRkJXSkRtY0FBT0ROSjJkaVNHamRXMi9ST1R3bwpSa1pXakhQT0g0ZDFt'
    b'eFFGV2Z5SGx6NzJ6VmFCVVBnUFRFZVFVQ2dFY0lkNXhIelp6ekpTa3pKamhWYW5zM2RBYzJi'
    b'L2QxbFNiRnhtClluNW0ycjgxZ01zWC9EVy95eW91S2VGeG1QSEdnQnVubVNMaFhydVRwSU9r'
    b'dVdOZEh2ZWJyNzZhblNKN1l2bUVxQmNDQUVCUmxuTGoKcXd2ZWV1MjF4cVpHUmxiK21EdkhG'
    b'MDJhaFlCSTdObFdyZGRYL3RUajhRa0ovNnpzWUU4SDViSWVQWEprd3B4RkVxa01ncURNQkhs'
    b'dQpSdXJYV3piQmhQK2VKUXQ0VEVhdllTUWxNL2Z5OVg3YzZYWTVXU3pPZjJwYjZiU3pBUnRM'
    b'REJUanMxQ0RIcEp4RWEyYmtaMVlmNlkrClBTUGoza1ZUdjlyWDdQRUZiM1V2ZlB2cFdTMU5q'
    b'WWYyN2FtTWw0K2pVMGEzc2QvU2J3bFFaMlVNWHRtRWxOVFVmMUUyN0IwbFlCb2QKamlESWp4'
    b'WEJjYnkzbzhXcjYzaTQ4ajZYMjlmUTBaZGJWSEw1TGQxZzkzdlBQN25oL1ZldXlyeFZ6L3ph'
    b'bHB3Zk5KbGN4aEEwcjB3SgorWE84QVlGUXVPN05OMUVrOHRJalpiZDZSMXFZcVpnNU1mbkRQ'
    b'NzZYUllQR1drTkpXbnVjT081YzQvbWE4eGVJTWVQWHZ2VHl2eWhMCmtpU0pPeEVHaHlSSk9v'
    b'cVJKRmxYZGJSaTJlcjNQLzE4eXJTcEVBUnpXQXlyellHeGYvUTVoOTBHOElCQ2tYVjFrOGdR'
    b'ZFArcVZZNFIKTXhHQWxNbHAyZXZldGszTG5yMW9pY2xrMnZYREQ2c1dGY1VyQkxjMHdwZlhU'
    b'bTl2YmFYNjJtSVF2aFVtQ1U4Z1FaRkFoWWpTd29JWApuLzNWdnk1cjBBNHFSVndhblVZUWhN'
    b'TnU2NjQ3R1hLT3BCUk01TW5qWWhPU0dCaHFkN29TbFJKYloxMTNVNTNINDNZN0F5TFNsNWxm'
    b'CmVMVkc4dmw4a0YzQVN4YmpKTDU5MSs2QU4rUU9CaFVLeFJlYk5vRUk5ZlRLaWJjdXdzUllZ'
    b'VVZaeG1jYk5nakNnQW5SWFNUQ3lGTG8KZnZOblJHZE9VU2hrY3ZtL0xoNzJlMkVZOXJtZHdS'
    b'Q0J1ZlFLTHMxZ3NralUyWGlRbEVqa1hEWXpSaXJPVEUyS0VmTmk2QUY5WTAxdgp5d1VjNVdi'
    b'bDVWK0RxWSsrOGE0alU5MnJHYlFGN0JRWnlPeHBtcEtRWURhWkR1N2YvK0NTc1J3V2Vvc2lY'
    b'RjVSWUxmYmFxcXJSU0lPCnlzU2NxWEplNThDb0tXQktSaGJjc2ZEZmQzRXdEQUJROHBrb0hh'
    b'RW9xbTNRclBIUnVIeVIzV1k5MUdVbktZcE9vOUVRNVBMRnNXSk8KeEdJQUhBR1B4N3NHVXlF'
    b'SW1yLzB2ak4xZlpUTUwyV3pjbHEwb0tHZncrWHUzcm1UdzBMdnVDM3JGa1c0Ykg3K3dmMzdL'
    b'WkpNVy9tUQpSOEpBblBnd2dabG15Yk01MlJpRy9kdmlJbm5zb05YYnBSOEpVUkFrVDV1NjRG'
    b'NU9qQnFDb2J4cDVjMERwcXAydytYTFBENjhmMmdFCkFPQXphVU8wYTNlWHNlUEdwY3VrYW5Z'
    b'UzZ2UVk0QWprUXlZV0ZEUTFOdXEwMnVVVkJiY2l3cUlzWmJwYWNtRHYzbFEycmVzUG4zQ3AK'
    b'SUphZGVlZit6U004NnRrSG4vMVA3aUFTaXd2TDVrOWRlQjhFUVNscEdRUkJCRWdZQWxCOGZG'
    b'SkNabUh0Q0hxcFIyZDN1dXNhMjV5QQplL0pDVnhqSDVWSkpSMVBETmR0Y2Z0djBJQWpFRnhV'
    b'REprSkJWSXBDbk05RUR4MDRNR044c2t6RXZ1VVEzalloZWNSczd1M3FTSEZoCmhjODk3SlB4'
    b'bmFmcTMvbjA1V0p4aVVRc3VhcGJSVUFFUVJDdHpzQ1hLZ0VFQkVKaGlBU3loTFFMd1lRZlRs'
    b'NElScENpQ1pQRnlrUU8KbXh1clVvb29WM2RiODdYWlhEWjllbmR6dS9ITkwwZnk4NWh5V0hL'
    b'cUppM0lycTJ1aG1Hb3JDVHBsa05ZVnBMVVVGZkhSV2hGLy9PWQpSMERQU2s3UFJpTUZUdjYw'
    b'a3FsWGZhOElSS1BSektNZUJHV0d3MkdMZFdSUU56aHMwUEhpczBZekY3WHdTb2VNSTA3VFVC'
    b'RGpoRkVXCkU2TUhSczNYWmpPZFRtY0kyT21FMTMrOEN4Y3lyQUVLNXFDZG5aMGV0L3VXUTBp'
    b'bklhVkZDUTMxOVQ0SUJoSm1YbnJlSGs5YkU0UG0KOStIamlvdXZmckFCSUFpU2kva09oN1A1'
    b'N1BHbXN5ZTlRejI2M3JiMk0vdDVQSjdYNXlNQlpMVDErNlc4ZEpVRUFJRHl4TmRzK2V6cwoy'
    b'VnV6a1pnOExnZUcvQXdFQ0RoQ0pITHA0c1hwdHhyQzVIZ1JoNFcydDdWSjRoUE5icys2SSt0'
    b'U1plbThva0k0UDVmQllGeDFIV0FZCkFKQ3FUa2pHN0JDRGk4cVRraWZNVVdjV3VRbXMrdEJP'
    b'cDJtQUlvSkUyRW1HR1h3TU5yc0R5Wmw1MTJ6NTBvWDNNRExTYmVNeWczNFMKbXBFbjhUdHlB'
    b'ZHJhMHBJU0w3cGVvY1gxUVppZUtLRkkwcURYMnlsd3NhY3pSNUt2cnVrdG5UTlBmSlZQd1o4'
    b'US9qaERmZGZDY3JFaQpJU3UzTUQwMVhTSlRNcGhNVVVwZXJEcTU3Y0kybFJKVnlxdzlBd04w'
    b'Y2Z4L010ejlaK0x4ZU9sSTZqbHZmOEFadUwzeUtlYWFlME1vCnBSMGNoQ0FvSlY1OEt5RlVT'
    b'NGFHaDBPaGtGSXFwR2drcThmTzdMSU45ZlZLL21wRjZUOFVTWkl3QkY5NUxlSXdKWElWaThP'
    b'bm95Zy8KTGswaDRBTUlhdThOMWRXTVNzUmpZSlNUblA1TFl6ZzVYMTVza1l3K1dCQWZFMDhY'
    b'UzBaaTRyV0RnNWNyZFYwYTgvcHNUbE9yaEVONgpmU1FTa2NValBJTE5QVmRqSVNpOHAzZnFy'
    b'Tm5YZ1BES2F3UkJ1Rnd1ZzhVQkFQQWxNY045Zld5WVRFd3J4SU9XbWJNd0drWEtjLzRQCkpz'
    b'UDY3YU0yak1za3VHOXNmeU1HU3lIRU1uUHpKUUJBVXB6b0Z2SkNIaHR6dTkwa1JjV2Y2djNk'
    b'NDc4UzRVUUFnVUJLb2tPcnVSWXYKUlA1U0N5Nzd4L2lNUmtmOVh2ZVFRWXZBY0UvbmhVNk44'
    b'ZE1qalNFSSsrWEc1OGZIMGRJeWRScGI4MUR6Z043cUpxbGdNQmdLaFhocwo3QlpDeUdWanVN'
    b'K0h3TERBSC83MHRzVTJIb2N6VmlYK2FwZXR2Zk1hRUNJdzhwYy93NEcveEJvMGVuN0pWTndm'
    b'eUp5MmJBQk5WNVhkCnYvRmczWld0aDljc0RwZHpiMWJpdk9QTnhWWlpYQndTeDRZQkFMalB4'
    b'NzJsRUhKWUtJN2pKRVJ4eENqTlJXZ1pMS0ZHMStkSHloNVkKZGJXM29panFyOWZidlI0dkFJ'
    b'QWt3Z0FBSnBzM2FEUjVQRzVXVExJMGZaeEFJdWZGNTJ6Y2Vld1hHaytHZ3BhT0poNU1zRTVw'
    b'ckQ2cgpVTVlFQVBoOFBpNzdWaHFSL2hqT1FWRG5tRGlWaFBSNXZjTUJHam9qankrNWx1RU04'
    b'dE5jTmtWUlRwOC9Fb2tFZko0d1FUQVlqQmlKCnRLKzc5Y2VQODVpelRmdVRxS0ZmYUhidnpt'
    b'L05uYjBzR0FSY1pKd3NidFE0ZkxrdXQxWmM2TVZETERZYlVNQXQ0eFp2L3JnZzZCZGsKSjZJ'
    b'aVVTQVF1S1lSNlkvTlp4NnhrSFFtU1lTREJESFEyNmxXS21GQWtRUUJBZUFZN2lNdWZaMmJy'
    b'aTdLVlBkMHRQNFM0NlUrcDYrNgpxMDNFcG5FZ3NxNDk0L3dRQUlERlpudDhvVnNJb2NjWFpM'
    b'UFpDQVFUZWt2ZFhZOVpaMDZUMkkzaHZkVSszMVh2ZGljSUF2N0pDeDF1Ckw2Q2hBRVRJTU9G'
    b'd09qM3UwVkdYeTJrZFB2bk5CNDdlQy9FcEdXd1dHNEZodjhQOGk3NS9ZbEV1Um9aREVDTlZT'
    b'dDk3QVNJd0FBQ2IKemI1ZVA2SzVQZ2pkdmlDWHh3TUFqQitoekNGbzBveloxTEtsSEE0NDlN'
    b'bEhWKzJGQkVHbi9SZ2FoUWlLQ0pPUlNBU2lDTWhqNWpJWQppTjh4dHlEaDNWK3RldmVGUjBR'
    b'TWVpQVFBZ0I0Y1A4dk1aNDU0VGJMM0JJYWpmRDVQQllLYTArbE14Z01PcDN1dms0SXIwOWNP'
    b'RGcwCk9uOWlGZ0JnVkdzTGpKTVBoQXdjcVd6czExdk9uYmpxc1VhWUlNZ0kxVnA3SkJBbTR6'
    b'TUtLOGRGYXB2cXNpSzI2ZmwwVGZ1V0o1NzQKeSs1SkZwdk5ZS0FBZ0pnWXhTOHgzbCsxVDli'
    b'aVpPWUlmQTVDWERsZGQrWllRbUlpQU9CNjVWbTRQbDdZTTJoVHhzYWlLTnFmb3A1eAo3LzAx'
    b'N1RYZEJ0TzZ6UnM5eE5YZHgyNjMxWit0WnFCMENUMm9ZaEgyN3ZOS0NYOTJuaXBaeXBMd3Vh'
    b'a3B5VC83dG1Lc24xNWQrNzRXCmJXOTNRc3VvUnNJcGZ2YUZCQ21HZjM3TU5lQklWS3N2Vitw'
    b'V1FxaTF3VENja0pob3RGaE16LzhocXlIUTdldXkyRDJ0ZlgxWHJubjEKK2FlNzJ4ci9zZWVG'
    b'dzdxK3J0YmFvME9YVHRCRExnaUNBUUFFUlFsWnRKR0JOaHFMbDZCU0JBbUtLL3paNy9EcG5K'
    b'ODJWOERYanJEeApoNjk3MlBTVTN6eFFYRkRjT3kzRGtjU0F3eUJSclk1RUl2MTYreTNVa1E3'
    b'b0hWNDhsRmRRc0h2SDltUTZWM2RXSngyMWkrZGx3b2U2Ci9Eak9aTEVpa1loUnB6RjNYaENJ'
    b'cERHeGNYOXhna0dOZDhRQTRUWWhpeWFoZ3o1clFDbmdtbUVZQUtBWnRxYkZ5ZUdBeStmMUNH'
    b'a0EKUmVrdzlyTkFMVDQ1ZmJpcFNzcG5JL1IvdWhpaUcyZ3pEcHluZ3BhK3ZwSENiSFp6bDRl'
    b'SlVrRWs5cjZIWHJ3Y050VHJMS0ZGdDR2RAp2dWUyUGtlTnd2U0pjeUhObDNuNStYMDYrL1hh'
    b'UFhwOXZEQk1rR2NhZGNVbEpSd1lhbFd4a3JDd3VOZk5haHlJN2JYWDF0UmVEck9VCmNRbjZR'
    b'ZDNtVjM4OTJOc2RDQVRPVlIwL2UraDdVdDhvQWs0aGl3WUFpQUFRSmlNQUFqQ0N0UFFaWkNJ'
    b'ZUFFREFvanNzSmdDQVhDVDQKbTRrWUZvdEZ3blNmUDhqL1J6L3Z2eXhWWWhZV2JDMVdYTHFq'
    b'ZUNoZjBybXdhQ2liMzV5YnpMa1M5bGtaYkx0UHQ3TmpKeThncGdJaQovN0FPUVpEQ01XTk8x'
    b'V3ZBZGRKMUMrMnI2alhqU2tya0xKcG1CQThvVVFnR1dYMFdSd2djT25QNDhnVXJIbm44MEtH'
    b'alVDUzg1WlZuCmZ2M2c4dWJxNDJvUnhzRG9ZWkswT2p4MUxUMm56amQ3M0c0eVFnS0sxQnF0'
    b'QWpZVEFPREVnelVuYW4vTWlmQVRRcjEyY01Sc3VqeDgKZFhqOVl2RS9YUlZDRUFRVzVPdmRx'
    b'aEFqMVVwbEEzWlNoSk1zejFyeVk5RGlkQVNZWmtycW1VWExqb25ReE9yVXJ1Ym0zTHc4RG9k'
    b'VApWVDk0dlZyeXVxWFJPMzZ1Zjkydlp0UGlVdEsxdWdGTEdKWXcvRGdPb2JBUk1icmRiaDZQ'
    b'cDA1T1Rjbk1zam50YWFvWWQyUFRBQXd1CjlDY3pHY3d3b0lrVjhYT21MWEs3WGE3T1dyTmox'
    b'QnNreGt3Y0d3RlUvOURJcFliMmdGYWdNenNTRmVJd1FlbzF2ZGErUmg0R0QxaGMKUjAyT21C'
    b'aHBsbHI1MVo4M2hlekFIblJrNUdRdXVLOWNQOURqOFhnU1VqSTRIQTRBUUoyNzJLSlBIc0ZI'
    b'Z3dFUEdVRm9NcEZDcWJwcwo4OXZMNy9KTllOOURtOGo5YkpkbHhvU3hTNmZ2R3gyZFVsbEpr'
    b'bFJWZythV1E5alVaZXJXV0N2dVdQekRCMjgvUklPYVVZNlJ3NXYzCjRpT0RsNzcvNU10UGZ2'
    b'M0Vyd0VBWThwbTcxei8zcUtGYzRaeDh1SG5YNDVWLzJ5RWFlanI1TEl3alE2WFNHUk1Calpz'
    b'TTUwLzJ5SHIKTFk3aFloWnJJRkVCbXVwYXRPYmp4Ym1xWGl1NTYvMHpZb1prOXZNc2txSm1U'
    b'b3B2YWpXMmJoeld0Z3hHc0NBdGFNdFBrbmRXdFhjYQpiQlYzclJSSnBIekI5TDgzK01qaDNV'
    b'VTl2cXpzTWZTamU3cUNVS0pjZW1EdlhnaUNicDgzNzJTZDVqcW00THVlYzZUYjlyZmNQbStl'
    b'Ck5nQWZ6a2xKbURHT0djUnJmdituN0swRzkvYkR1QThIQUV5YmRYdGkvaGhUbVBucStpLyto'
    b'aDhBNE95aHZRUVowVnRIWVJpbUlyREoKYkk5M0Z3YzRPTzd5Mnd4QkFFRFFUUTYwRFJ6WTNu'
    b'cnNrMVlSSmdvU3dlL2VQTC9oclpyYUV3WWlDTENFU01tc1JBSGtUcFR5ZWd4VwpwOGV2RXJE'
    b'N0cyditlZ0h5aWlLUnlNRnZOM2loaVBaa0hkc1Y5aE4wOWRUSko0OGZIenR1bkRJMmR1dSs1'
    b'dXZZak5jWFlUTmZJSnd4CmMyWjFZN3YrNEdsRUZDdFlXWkVyQzZaWXd1dWZlUm9BSUJTSjN2'
    b'eG8wNTByVnNNdzdIYTdYUzdYbGJMbmFtdEdCbm8vK1dCRDlyakoKa1FnUUsxUm1pMmtvYkhE'
    b'NTNIUUU5UXlTSVlLNDFIMGVSREJYWnhBUGVXQUlnV0ZZUkJlTjlucXJ2bWc2L1A3RjBFaWtP'
    b'RGVlUmFONApiRVpiajJiZEI1OTgvZDBPazlIMHpiYXRmMjlxYlhNdEZQWnhZU2dTQ284RzZL'
    b'd3hzclB2dnNFT0J4YmZkWmNYRCswKzBYbUxJdFFaCm5YdFBkVDI0WmcxSkVESTd5WUNRMkt5'
    b'c3lJdlBtRXFGZnNJL05QVGprb0xET2xKN2RNOXJMNzN3L1laMTUzWnZmdVR1QmQ5OS9NNzYK'
    b'Rng3SFJOS1NPZk5RRFBNVFZIcEdCc3FVQ0JRc2FWQnVNOXZzQm51dnpnd0J5bS90Z3lHSWlY'
    b'Qk1mck1KTitsOWVqSkMraEFmR29zTQo2eXlkZlU0K2o3dTNxcjZuNVVKdWdrekd3ejdidGdP'
    b'Q0lnQUFzOUhRMlh6aGlxbWZILzZjbnBIQndpSk1KcjFIU0lzMUcrMDlkbFN1Cm5EMTM3bWM3'
    b'THZyOG9Wc1VJUURnOVUrcTB0TFRTNmROODlGSWcwSTZPR1FXcXVPWkMyWWt5UlRmZmJFWkFO'
    b'RGQzbHgvK0d1WHg3ZjIKOGFkWkl0WHgyZ3M4RnFQalRFMStkanFUeThxZFBKT0MwYVNpeVFD'
    b'QXNCZjNkVU51bmhOUndjTWhqY3ZwaHhIRVp0ZU1valpuZUJRQwpJQUlpWVRoRWk2R25acWNt'
    b'Q0pOVlk0VGZyRDkxdE0ya00xcUhMWTVCazcxOTJNbmw4Wll0dng4QTBGeGZyVzgvZDNMWDV3'
    b'Q0Evb0YrCmcxOWZlZStUakdjZkpFVVlPeGp1OVVBMU5IejFtalVFR1hudnl6UFh0dzJ2OHk1'
    b'ZnM4MDd2aUIrNXRTeG4reisrbUlFVmNZbnRodk8KeGJCanBPdDNtMW9HaDBYTXNIOVVQOUM5'
    b'Wk5XVEI3ZDlNTDNpN3RzWDM4T1h4dlRvOVFpRytjUFVncVVyK3Z2NkloU0ZZUmdGVTRlMgpW'
    b'TEU5WEQrSnh5aGkwMHBFQnFPWjlEZ1ZHWWtPaDkvbngva2kxbjJQVDAwcDRGTjZIb3ZpZVJC'
    b'Y1hNQjY4WGUvbXpWL1FVcG1qdGxzCm9URlliN3p6UjRGQXVHMzltMlh6N29Zd2JtdHJhMkh4'
    b'cERmZWYxM3M5Z1hmLzZheHZrbWdqbHY1MVpZM3RtL2x5MkplZnUyMXpidWEKdmp2VWVuMFJY'
    b'djgwZXJscDhzWWZIdjM5NjY5dC9XRjN4c1FKZVJPa0ZoTTZaKzgrdllYcFU3UEwvL1JPUWtM'
    b'Y25rM3JDa3RuK3p3dQpvVnlWbmpzR0FORFNlREVRQ0pSTUxHMXNiRFRwZExzUEhxeGNmdWNQ'
    b'WCszbEI1UmNIamNvdEM2cm1EaGdENmJtRktvU0VrbVNQSEZnCmx4d055SVM4U0NUUzNEUFVj'
    b'U3hreDZ4clgxbVRrSkQ0TjhPV1V3ZDI1QlFWNy92OHZZb0hYeUJDL3BOVloxMmpnL0xQRHZm'
    b'N1Vlc00KVmQ3NS92YlNndVBWdGVzM2JDZ1lPejV6L2dmREkrNWIyZ3NCQUJhN1R5eGdQVnk1'
    b'NE1ET0hVRzcxU3ZGTVZ3VWlKTVhEbXB0RVZwago5UkZoV3BvOFRtMDNEVVlBUk1Hb1lhQkRw'
    b'VTZMVVNoVmNmRUhEaHhvYkd5TWtjc0JGY3FWTWN2R3A2c3loVmtsaVFhTDVZdnY5eGJuCnBS'
    b'S3VFY3RnbDFYYnBSYWhiQ2JtQ3dSN2pFNHZnYUFDN2dQUFZTcVVQMXV5Q0lWQ2tVakU3L01N'
    b'NndlTFo1VDN0bDRZc25oSXQ3MnoKNFJ6Z0MrTldWMHd2djhOMjROQ093WUhwczJhdGZ2amhG'
    b'LzU0N1BpNWZuQzlkVU1rTFRuWHJGOXo5NFRNakpUZE8zOVFEcmlTRFhZNQpCVWRLczNHTGhX'
    b'Vnl0dW8xTTVldEhHaS9OSDdtd3FTMFRJVE80UEw0VnlaVGFBaE5JaGFwMVVrbnFrNERDQW9H'
    b'ZzhmUFhteTRlT254ClpSWEpDaEVIUTlnb1lyZVBldnpFc0IrQ1JPckpzK1puRjR3cG1GakFa'
    b'UDBzbTFwZlo3UFg3Znp6U3crSGZDNWRYMGRtMFdTYk82ZzcKdEozY2NxSnBwbGhXT090aXY5'
    b'N3BDKzVyYVVBNDNBOCsvbmhneVBQZ1M3dXBTQ1NLRUFBQWdpR3lxY3YwdTZjV3U1M084MDJO'
    b'ZHhNUgpNT3d3ZFJsOHFiS0FmYlRvOXJrTnZiM0ZVMmMxbkQ0VXAwNlRTT1VOcC9idTM3MGpK'
    b'U05YcVl4bE1EQ1NJUElLaS93ay9NeExiNTV2CjZSRktZMTU1OVhXZVRBbVlJck03akFOR0FH'
    b'RW1GNHpQSFROZXFZejkrMDhQaFlLNHorZDFPelhkN1dPbnpDWUJOT2ZPQjQ0dnZudFkKeUVv'
    b'NlVOMFpoTFdGZEFZWk1lbmQyc1pMeGhITG56NzZLRUdkVXI1MjZ3MlNNUGdHU2luNzFsTXpm'
    b'M1gvaEpYMzNxdnBhbDJSRWdmagpBUXVFWUY2Y3FVcEFQUzUzakhqQ3lrZW1USnMyMk5kbEht'
    b'aW5NVG1SU0tTenRiSGkzb2ZjWGp3eE1SRUFRRkdVeFdLSmlZbTVpdkdVCjBTQVVTZDU3b1ZJ'
    b'Vm42VFQ5RC94K2lkdWwydi9pMDh4R2h6VTFMaFFqY2FsbHVudlVFMVBubjVxMTZtelZWVnIx'
    b'cTU5OUlrbjFyeXkKZCtQM0YyNlFkcnVCTWlHKy9PSEp1bGJqeHhzM1NsWHF6UU1qZ1NXTDZS'
    b'YWNVaVJLWnBhWkIzMkJDL3FqYjc3eTRYdnZFdUhnc01rVQpuNXg1NGZUQnVKU3NjQ2cwM0hN'
    b'SkFFQ0V3ekFNLzRmOGhyUjlBMTFOQUlETmYvaXRwck54eHNMS3pIRmx6Ny83Rlk3N2QvNndP'
    b'OGJxCkhLWlJ0QmF0bnNlTWZmeE9QK252cmU4NlcxVTFkOTY4Ung1NzdKc0RMVGNPUDNDakpY'
    b'Ym1jeG5WWHowb1pJWlczSE9QSDhlWDBtQy8KalozOHg0ZjlhT2hpdDlPbTE4dGs4bmdNcVNp'
    b'dm9FTGV1bU83eXU1WVdYMTBEd2NPVXdpV25GVmdOUS9UR2F5ODRpazBHcDB2RVA3TgpVRk03'
    b'MEd2VTllZU1tVmg3ZEkrMnU1a25GSzk0NHVWUC8vQTdKT3pPbXpRSGdXbjFuMzdNNlRPU01n'
    b'RWNLM1VFS1NhVGcrUms3ZGFmClRFUGpxM1ljbjFoYSt0R25uNTV0TXN4NWFFc2dTTnc0alha'
    b'alpRVU9ob2o5cDd0WDNUbHg3cHdaeDQ0Y01maWRFd20yVGtUYUdJRU8KZDIxQ2ZHeGFxbVFV'
    b'SFQxMjZWajcxd2NLeXhkS1JaS1FINzk0dnBvTSthY3ZYTkZ3YXQrbzFjTGg4ay92MjRheStW'
    b'dlh2MjNXOW1VVwpqdTl1YTlyMXhmcyt0NVBENSsvYnVuN1dvdnY4VHZPSWJkVFExMDRBMnFx'
    b'blg2bHQ2WHJsdzArdGZpb21qRGhZbU0xZ0ZNZkkxVFh0CmtVc3R3T285ZHFGendxUkpmL3J3'
    b'dzE2ZGM4NURXMjYweE1BM1hHSm5qeTk0cUtaMzFWMmxpeGFWSHp4WjNlY3owUlFxVks3T0ZD'
    b'UzYKUE5hRTJJUmtXYktjSnhuN3plbWo1MnAzZWk1TkxwNjE2TzRIaDNXYXBJejhya3UxeTU5'
    b'OFZkL2RyQjh5VHArM3VLSHFJTWJpNUkwcgpsY2dWZEJxZHhjUkt5dVlQOWJhb3M4ZWlUQjZQ'
    b'eDVXbkZBempvMS92M1hhcHBWT1pralJ6NXVTRStkTmhoNTVzTWk3ZXN1RlQvOFVUCnBMTlo2'
    b'NXc3Zi81N0gzelFxM1BPWHYybGJSUUhONWh1eE56Y2RpZSsvWERib2psRksxZmNkYnFwK2VU'
    b'NWhrdWRtcWxGNDYzRHdiaEwKZmVIMndXa0w3dmJ0K041bW8wdW5GMjF0Kys3QytRdXhza3dX'
    b'aTVXYVBVWWlrL2QxTklWSmtKU1cxVngzbXM4WG9HeStXQ3AzdVZ3bQpYVjlLZGhHTnlXbm9h'
    b'dHpUZnJUejIrMWQrMDUweGJwSFlJdUhaNVd6bUtwRVpUZ1M5dXc1Tml6RnZyVlY5NThiZFBX'
    b'N1Y2MWUvZUxMCkw1OXRNc3hadmNYbXZPSDRnUnY1a0FNaGovbkRCL2RNR1p2dzRmdnZmLzda'
    b'WjB5QnNJTE5HRE1jN0NVaUlScktMVlZ4ejJwWWE1ZWEKZi9pT05rcDRNWXg3LzFMRHQ5dlpL'
    b'U21paVJNakhudXdwU054OXR5TTRtS2pRV3MzbVVTeDhVTkRReDI2OW81d0YwSkQwbnY4dWZX'
    b'ago0ZG5qbDd6OWVudjltWnFHVXdKVjZxbkdicGpQWVFaeFJ0QlhjN2lLeitPLy92dmZUNTAy'
    b'YmZ2aHR2dC8rOE1OOWZ5NzBiM3dzZ0pCCll0dUJGZ2hBenoxMlQyRlJZY1BacytlSGgza0pU'
    b'SmFRUmxBaHV3c2ZpdVdRdWtHUE1Sd0kwUjJaRW5NYVZCaVhCaDg4NTdkWWhVRWIKVkt1MU1N'
    b'SkQzMjhKZjNrOGxLb0lDWm5kZTNZaGRlMnhKdWpYejc4WC9PWjdqWTBXRkZPYTlSOEc5cHlV'
    b'dHVnaVo1cmhPSW1acEdtcQpxM3ZidWllVlRsNi9ZVU5xZXVhejd4eCs3ZzlIaUJ2NDVKK2I0'
    b'Tml0MnlZa2YvN21JcGtBKzN6VHBzMGJOK1pqWUVxQXppS1JBSmZtCkZqRkRSV05MRmk0Z3dr'
    b'U2R2cTdIM0ZXK28ydlVEaEZqVmI2THc1eDBEdFRsTTNCaDZwbXk1cGE2OFlQMDNHNExIZ0Zt'
    b'QmtaSU9ENDgKb0FpQUlXdVFSdEVBUXJKeUZhZURQcDFXSzVYSm5ucm1tZktGQ3pzSExQYzl2'
    b'Nk9weTNTRHQ4OU5jR2FUWm1oMHcvWUxFUUEvL3REaQo4b3J5QVpkM2UxOW5IeFlZakZYSkJR'
    b'ejRhQWNCaHdaZ3V0RWNDRGlEcmFrSWdId2hnOXNwWWZ1ZFlVY0twM1lxUWZQUkYwMVpjK2RE'
    b'CmE4OHovVDBpbGdZT2lqeCtVVWE4UU1VWENNRndtdXhzMkgzZW9LUFRhQTgvOXRoYjY5YXBV'
    b'elBlMmxDOS9OYzdoNjczRlBaL2lSZGUKVVZheTdJMG5iMXN3UFhOa3hMejF5eThQN052bkhI'
    b'WE1GbUNVRDJzc0hsT1ltbno3NU1MT3p6ZjU2L3Npay9JRHpSMlFDM0pPVGNxYQpVVmJmZE5F'
    b'VFJCZ285dnBqVHgxNGVMV3ZBNDkvWlhYN1I1dlFnQjhoNEhvYWppU3E3MXk2ZE5IaXhUQ04v'
    b'dlgrbHBjL1BHa3d1MjZXClpybjVqcURNVHBIOTlxR3BkODNOalZEazJkcmFBL3YyMWRXY2R2'
    b'cjhNQVNKTWVoMml1VkRHSXdsYzFpNGc5M1FwUEdTbXRLU1pKbWkKUTJkQXFUREhicHJVYkdx'
    b'bmgwNlFQZ0JBWEh6OHRPblR5eXNxTXJLeUFrSGlpOTJONzJ5dXZlbk9oYjFaRDRJVjhabExa'
    b'dWVzcUNpWQpWSlJBa1dSbloyZERYVjFuUjRkT3E5VU9EZ2FEd1N1VE1uKzllVE9HejFXbzR0'
    b'U1pXZm1GaFNYanh5dGpZd0VBbHcrQy9mcEF5dzBZCjgvMDNJN3lpdEVUSmpQRkpaU1ZKWmNW'
    b'SkVpSHI4bVMzMVdMeCtYeCt2OS9qZGlNMEdwdk41bks1WEI1UElCQmNMbVcwZUU3V0RaeXEK'
    b'MTV3OFAzQVQ5Wm4vblFqL1dyRnlYbnFpSkMxUkVxL2dpd1FzRGd2bHNGQ0tpbmp4a0JjUE9W'
    b'eTRkdGpaTTJqckhyVGVwQ2N2Ly9jagp2RFVGUjVzZ2lqQ3FLTUtvb2dpakNLT0tJb3dxaWpD'
    b'cUtNSW93cWlpQ0tPS0lvd3FpakNLTUtxYlYvOExydTdnRTBpUFQ1b0FBQUFsCmRFVllkR1Jo'
    b'ZEdVNlkzSmxZWFJsQURJd01qTXRNRGt0TVRWVU1qQTZOREk2TWpVck1EQTZNREJUQncveUFB'
    b'QUFKWFJGV0hSa1lYUmwKT20xdlpHbG1lUUF5TURJekxUQTVMVEUxVkRJd09qUXlPakkxS3pB'
    b'd09qQXdJbHEzVGdBQUFBQkpSVTVFcmtKZ2dnPT0KIgogICAgICAgaWQ9ImltYWdlMTYyODUi'
    b'IC8+CiAgPC9nPgo8L3N2Zz4K', 'US_VA')

US_VA = b64_US_VA
index.append("US_VA")
index.append("United States of America Virginia")
catalog["US_VA"] = US_VA
catalog["United States of America Virginia"] = US_VA
country["United States of America Virginia"] = ('US_VA', '', 1)
lookup["US_VA"] = ('US_VA', '', 'United States of America Virginia', 1)
lookup["Richmond United States of America Virginia"] = ('US_VA', '', 'United States of America Virginia', 1)
lookup["United States of America Virginia"] = ('US_VA', '', 'United States of America Virginia', 1)
details["US_VA"] = {"continent":"Americas","capital":"Richmond","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_VA"] = ('US_VA', 'United States of America Virginia', 1)
regional["United States of America Virginia"] = ('US_VA', 'United States of America Virginia', 1)
#----------------------------------------------------------------------
b64_US_VI = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNTU1NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX3RoZV9Vbml0ZWRfU3RhdGVzX1Zpcmdpbl9Jc2xhbmRz'
    b'LnN2Zy5wbmciCiAgIHhtbG5zOmlua3NjYXBlPSJodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy9u'
    b'YW1lc3BhY2VzL2lua3NjYXBlIgogICB4bWxuczpzb2RpcG9kaT0iaHR0cDovL3NvZGlwb2Rp'
    b'LnNvdXJjZWZvcmdlLm5ldC9EVEQvc29kaXBvZGktMC5kdGQiCiAgIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIgogICB4bWxucz0iaHR0cDovL3d3dy53My5v'
    b'cmcvMjAwMC9zdmciCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmci'
    b'PgogIDxkZWZzCiAgICAgaWQ9ImRlZnMxNTU2MSIgLz4KICA8c29kaXBvZGk6bmFtZWR2aWV3'
    b'CiAgICAgaWQ9Im5hbWVkdmlldzE1NTU5IgogICAgIHBhZ2Vjb2xvcj0iI2ZmZmZmZiIKICAg'
    b'ICBib3JkZXJjb2xvcj0iIzY2NjY2NiIKICAgICBib3JkZXJvcGFjaXR5PSIxLjAiCiAgICAg'
    b'aW5rc2NhcGU6cGFnZXNoYWRvdz0iMiIKICAgICBpbmtzY2FwZTpwYWdlb3BhY2l0eT0iMC4w'
    b'IgogICAgIGlua3NjYXBlOnBhZ2VjaGVja2VyYm9hcmQ9IjAiIC8+CiAgPGcKICAgICBpbmtz'
    b'Y2FwZTpncm91cG1vZGU9ImxheWVyIgogICAgIGlua3NjYXBlOmxhYmVsPSJJbWFnZSIKICAg'
    b'ICBpZD0iZzE1NTYzIj4KICAgIDxpbWFnZQogICAgICAgd2lkdGg9IjE1MCIKICAgICAgIGhl'
    b'aWdodD0iMTAwIgogICAgICAgcHJlc2VydmVBc3BlY3RSYXRpbz0ibm9uZSIKICAgICAgIHN0'
    b'eWxlPSJpbWFnZS1yZW5kZXJpbmc6b3B0aW1pemVRdWFsaXR5IgogICAgICAgeGxpbms6aHJl'
    b'Zj0iZGF0YTppbWFnZS9wbmc7YmFzZTY0LGlWQk9SdzBLR2dvQUFBQU5TVWhFVWdBQUFKWUFB'
    b'QUJrQ0FJQUFBRHJPVjZuQUFBQUJHZEJUVUVBQUxHUEMveGhCUUFBQUNCalNGSk4KQUFCNkpn'
    b'QUFnSVFBQVBvQUFBQ0E2QUFBZFRBQUFPcGdBQUE2bUFBQUYzQ2N1bEU4QUFBQUJtSkxSMFFB'
    b'L3dEL0FQK2d2YWVUQUFBdQowVWxFUVZSNDJ1MWRkM3dWMWJaZU0zTjZQK205OXdZSklZU1dV'
    b'QU9FM2dXUkxpZ29JZ3FvV0hqZWEwWEZDeXFDS0NBZ1ZWcm9MWVFTCmtoRFNFMUpJcnllbjl6'
    b'Sm5adDRmSjRZUUFnTFM3bnRadi93eGs3Tm5acy8rOWxyclcydVhRU2lLZ203NWJ4YTB1d202'
    b'SWV5V2JnaTcKcFJ2Q2JnaTdwUnZDYnVtR3NGdTZJZXlHc0Z1NklleVc1eWkwdnkxeFpPOFBx'
    b'dHBqSklrZ2JHOUg3NEZKbzZjekdJd1gvSzJ1cEI2dgpLVTJqZ2Q2Q0V3aU41K3JiZC9pb0tm'
    b'OFZlRml0MW5Pbi9teStuUXJtR2hwR01wMkdUcCt6K3NHWElIK2JJLzN0aXhIVEU0MjJZN25h'
    b'Cm1sb29JTmloL2hGSkF4TkhvT2lMcU1SbmovMW1yLzh0eFB0TzNXb2x4Tm5pd01YdmJHS3oy'
    b'UzhtY2hSRlhiK1dXcHA3RWpYY1NnaFQKT3R1M3FkYVJkUHFVTjA4eW1jeC9CT0hXTDVKbkpP'
    b'bzYvYk9tMlpwWllZZHdBNTI5K3d3ZVB2NEZhUnE5WHYvTHV0bTR0bnpKWkhHbgpuOHc0dWV0'
    b'cTBMSTF2NzFReUpuTjVyU0xKeHB2WHlNTkZiMThwWUVlOUU0RkRsNWx6WHo3QkoxTy8wY1Fu'
    b'a25aeVpCdGpRdnV1cGhNCmhWOHQ0Vmhvdml4aGFPS0k2VzV1SHMrK0lRaUMyTC96TzZ1MnJM'
    b'eWljczR3NDRVczFheGtwOHA2WS9ZdEhZWWlrNFk0Mkl4RlpTTWgKRTYwY01uekNjMGV1dFZX'
    b'U2VtYWZVVkdNV2FyNmgraWM3YnRHcUtBU3BLeVo0NmErOWs4TktRQ3MrK3hkdGpZbE1vQVRH'
    b'OGEvWHhrTApUbVdVVUJLOUM3RDlYSHppRWdZbmN6aWNaOU1pV3plc0hCTjZuYzlGelRpNTQ1'
    b'akVYa1MvZVV0SGtkUVh5M3hWV3V1M3Z6ZXNlTVZECkxLQUJ3TDdNb1BsdmIzMHVzSmxNcGl1'
    b'WFRqZFdaWUN4MnA3WjJDOENXSXo3dXFIQzIvcmNVcjBVU2ZqNHN5MVBnTTRBZ0t1emFPSmcK'
    b'NTlJYXc4NFRyUXc2a2hBamRIWG96R2dZZENTaEJ3TFFDdEFxVlY0NXV1bEhJM2hpWEM4SHQ0'
    b'ajQvc1B0N2UyZm5nclNqYmxNQnFMUwpXaTA0dVdDaVMwNnBUcTBqSWdPNHUwNjJFaVExZTZ5'
    b'ekRUOEF3Q3oxQkVGZ0dQWnNZRk9yMWRldm5wZlU1NUhHZWdaUkh4OXM2TmVUCi9vQkFRS2JD'
    b'TDJhcExGWXFLcEE3ZTR6VG9VTG5oM25LUTJsaFlVRzJKUFB0dnVFSUFPQlc2a3F1dWtXR1Uw'
    b'QUZlYk43aGZBZnpHbjIKbnBicVRHQ3cwSERNSXpKKzZxQmhFOFZpOFJOc3BycTZ1cTgvbXRs'
    b'L3lFc1luV2xuNzFSN096ZVlueG9kUUcwNUxGczAwYUZUNGFzRgplUGlZQXg0ZVQ5SGFhN1hh'
    b'MUxOSENqTVBncm1LenlJd2xKZzcxdm1CUkFieXkzVWxWVVlLS0VjeEl5RkdZTlBPZ2tvSzhm'
    b'c2t2dit3Ckp3TWhBSnhKMmRWYXVtTjRUd09mZTZjTFY5UVpzMHQwRkFWc0pob2J6dk4wN2t5'
    b'Y0t1cU1TcTAxTHJ6Ti9HcjF4TlZpVEVONFlGei8Kb0tnaGNYMFMvcmxDYUxWYXM4bmc0SGlu'
    b'bWJiOVo2ay85N3JCakF5TTVuWXEzTkJxYnVKL01uaG84cE9GalNUSm5PeU00cHd6cEtHSwpD'
    b'L1g5d3kwaWZwdmVsOVlZZEFiaVhnZlVKTFhjS05ZYVRDUUE5QWppaFBuZHFhckJSSjdQb1hP'
    b'OVh4bzNkZkVUMDBLYi9MRjlnNzdxCkp3UVFCaDBaMEZQZ2JIL0hsaHJOWk00dGJXMnp4WWFJ'
    b'bndjck1vRExZcUFYc2xROWdyZ09vaTdjZFdXREpiZEdTREY5bWNMZ2hPRlQKM04wOW4xU0R2'
    b'djlHY255Z2RGanZya255Z2Z5QmMxLy83SWs4U0NKcFNUdDN3S0M0UlJtcmVuaXBncjBaWFZL'
    b'RUUxY1VFNGZZVzNDcQpxRkpmVVdla0tLQW9jSGRpeElieE9hdzdGa3l1eGkvZjFCak5KSVlD'
    b'NlR4ejRaS1BIcklhandEaHBRc3B6cG92dkp4cFpweThscWRwCmtlRW9DdUgrbk1nQWJpZkxV'
    b'TlZnTEx4dE1PTWticVZhRmZpS1dlNFB1SzJOQnpVYmZPakM4Q0dqWnYxRExLK21uV0kzL1R2'
    b'RSs3N0sKdmVleWVON0tRLzlFKzF0YkplZFA3RFFwQ2h3WTFmMGpxUWV3RWdEWWRMQ0p6Y0RZ'
    b'TEpST1F5TDhPUUdlbkU1K3A3ckpsRjJzdzYwVQpuNHNOamhYeU9KaGNiUzAwTHhrOVlkYVRo'
    b'NUNpcUIrL2ZtTjBSSjZUR092SW5Zb3JEVFk2MHl1VTUrM0s2blJWZWEwaHZVQWI0c09PCmp4'
    b'VDhUV0tDb0s0V2dzVG96UkJGSm8yZDQrVGs4aGp0dTMzRDBxbXhoUThvSUZjVDE2VlRwODll'
    b'L3FoM1ZpamtaNDV1TnlvTDdPblYKQ1ZFVWc0NDh1SHh1bVM2L1hOOHJsTmVwaXdOQVk2czVx'
    b'MGhuTkpNQUVPTExqZzdtSVgvZFRLa2hEMllIdi9IZVpocU45dVFodEtGNAphTStQbXZxVEk2'
    b'TFZRdDVkSFJtM1V0a2wycG9tTXdBd0dYZjFPSktFejMrdDgzRm5ZaWpLWmFOUlFWeWZlNUMy'
    b'aWM1QThEZ1licVZTCjh6RTVIaElVUFQ1aDhLaUhyNTdCWURqMDA4U0ovWXozamYyTnhKNExa'
    b'RkUxOHZWUEp4NmVWV1drcHhabEhSUlNKVU5qY0NZZHRWV3kKeTVJTnJlYThNcjFXVDVBVVZW'
    b'cGwrR2lSdHcxcG0yVXFxRENZTENRQXVEc3g0aUw0bmRSWFp5RE81UERwVHNPbXoxN3hTR2t2'
    b'NURFbQpJVm9zbHVPSGZtdXR1VXczNW8wWktMNzNmV3gyLzNhZGtRSkFBR3FhekFzbU90c0w2'
    b'YlpHTEt6UTF6U2JSWHpheUg2ZEcvRlN0cnFtCjJUUjVpSU9OTkZVMVdhK1d1L2NkK1hiUG1I'
    b'NFBVN0hONjkrZDFDT2pvNE81Vi9aZmRaait4cTZIakZsdkZlZGRQUEpsdkYrOXpUSWIKVE9U'
    b'Qjh6SVhCMFpTdktoVHlZczNWSzBLM01PSjBUT1laMnNRZzRuOC9vL0dBQThXQUZBZCtNRzl2'
    b'ZXJzZFpXS0NuWHlHVGh1Nm1JVwppL1dvY0NDUFBZODA5ZndKdnVTVDIvVW1uWUVBZ0RBL2Rs'
    b'VGdIWVBRVWZMTGRRUUpNU0c4aDhyekV0VDJGTW5vQVhidG9lZVpiRnJRCjRIVVJrYjBlbkZy'
    b'N2VQVnJ3OEp1Si9Tay8wMy93Nmx0bDN6ZWVQL1h2MDNXVjFlV1h6djArc1QrZUpzaFZlTUh6'
    b'c3Ztam5ObTBoOUsKUlNycWpLMEtTLytld2k1L0xhblM1NWNiS0FxNGJEUTZoSHZMK3Rxa2Fm'
    b'TWZENGpIaDFBdWw1M1o5dEw0ZmhiYmFYR2x2dkMyZ2FJQQpRU0RBazlVem1FZkQ3dUI1NnBw'
    b'U1p5U1MrNHU1N0s1TjBNbHJ5dVQrZDVSeTJ6SEp2SEYzNG9ROTE0TVh2dlBMZyt1ejY5ZXZQ'
    b'TkhqCnNjSEkzOWJjYUNaM3BubE1udmU1bDdmZkE0cjkrdjJiTDhYbDMvR3lLWkxabzUzYkxk'
    b'eXBhOHBSL2JzMnhXYWNQSFZWaWFJd0x2Rk8KUW9NZ3FjSUtmV21Oa1NRQlJTSEVoOTBqcUsz'
    b'SG43K0p4WXpmNXVubDgzaEEwT0J4eGQ3ZUlhRC8rN3RUL3pPbHY0SkpSOFA5dWVIKwozUFlP'
    b'ZUNSVmJpVW9BR0RTMFhCLzlvaStZcU9aMkpFaXFaZVl3LzI1VERycTdrU1A4T2NLZURRQWtN'
    b'Z3RETnBkVGM5alk3YmVZQk02CjBmRGd5aHplKzNNRVB5WFE0NkgwZzgxRUZ5VTFmZnJ2bHhh'
    b'dS9EMHdLT1MrVFdPdDczaktZZDdsb2NRQ3JLckI2T2ZCdGhuRGdncDkKWTZzRnQxSzNxdlFD'
    b'UG0zeEpGY2VCN014Y3h0dFFSR0lET1JPVDNMc2FLaHdLM1VvWFJBUXQraXg4ZnRIRUFKQVhO'
    b'K2hrVDM3SGRpNQpEbGRrRFFwWHVQdzFSQkxveFE3MFlyZDN5YUxiK29QbnBRUUp1QlcrZU5Q'
    b'WDFpVWxjcHdnNy9nRHdkM2tpTHpiTmxDVUZRQ1VTdVc5CkhLU21waVkvK3pKZnR6Y3dyQXY4'
    b'VXE3b2pHYVlPdlF1QzYvVkUyOXZOSzM1OXkvM3cwK2xVb2xFSXFDc2QxZnByakoyQXBwS1Iv'
    b'd1YKMm9PbkM3TjNPSitHSVFDT1AreHJPbjVGZ2FMZzY4NUs2aXRtTTlHdWNtbldpNFZDUk5C'
    b'cjZ0TFZmRDcvbjZEd2p5QUVBRGFiUFh2Ugp4MWFyOWNMWkkyblo2WktheXlFZWxyaHdYbnQ2'
    b'Z2tsSGU0WHllNFh5QVdEdkdhbEtheFh4YVJpS3VEbmVjVVYrSHV4em1jM2hmcHgyCk0wc1Ew'
    b'TEhSU2N3QkFONy84S3U2QnRXZ2hLaTVyMHh4Y25KcTB3YXg2SGJKSllZRjd4dDJweE9vZGRi'
    b'Zmpoc3U1ek9LbW9Nb3dIYWQKcnh3UVlWbzRsbTBucEFNQW40dXRXOEkrZVhGdlJGVE0zV0dE'
    b'NHZkZGY2WmV6dU54ME4yL2J5UnBEZ0NhRGltWURqbHJDM2toUy8zYQpGRmZiS1orTHRTZXQ5'
    b'RVpDeUtQTkdPbllSU0pKVDJRVmEwdnFNQ2VmUkdmdlBpKy9QZm1KREo0alQzWlp6UGF2Umc2'
    b'SlV0OG8xcWwxClZwSUVEQVYvVDFhNGZ4c1RJMG5ZZTBiSzQ2RDllZ2c2cFd4a0t2eGFubWI4'
    b'SUh2YjhjMWJ1aEY5eGUyaDBuWFp0S216bHIyeC9IOE8KbkdxbUtJTFAwdnA2Q0x3OUhWeWN4'
    b'VUlCeDJyUnFxb09DRGhXQzQ0MEsyajFNbnBsTTA5dDlVWVFXZ2M5SnZpMGVuOG50YWNqN3Va'
    b'ZwpaV0NrMFlJdzNTZHgrWTVxamJGRm9xaXRsMVhYcTlWR0hvTFFraFB0dG0zNVBPWFF0bEQ2'
    b'VmxmN05telM4OVd1amt4Zk41YU5PWHU1Ck1HeFd0RjJVR3V1MWZJMWNqYzhjNlVTbklUYnFW'
    b'RktscjZnekVTUUZBQUllTFRhVWU3bUkvY3FxQzA5d3RKd0dUMVNNcUQ4ZHkydVAKRmtnU3Fo'
    b'cU5aOUtWWmd0SlVvQWl3R2FpUEE3MjZlYmEvdEZDT2czQnJWUmNPTi9YbmFWUTQxNnViU25X'
    b'YTNtYVlYMUU3ZFRqd0kzQQpaUjhzdmRQcEVFeG5GaFZXUW1HbEFrQUJBQlJoQnFRbmd0N1ZK'
    b'enB4WXdUQmRJUlBmalBrTi84Rktta0ZxZ2JCbXR1TEFJZzZYalZtCjR0eU5YMlpOaXkza2Mx'
    b'RUFpSXNRSEw0b3QwSG80a0RYbTBoYklKaWVwOEV3QkxkU0dRV2E1SUYyUWk3dDhFVlptd3Vu'
    b'b1dGKzdFbEQKN1RFVWFjOS9xcXcrVDNhMnd4T0djTkdLRFh1MmYyT1NYb3Z6ay9wNzBGRVVB'
    b'anpaQVo3c2pnNDh0MVEzSnNFaHFlOWRvVldBSjJmSApjVWwwTUE4QXpCYXkzYUtldk1GYnN1'
    b'cm5CK2ZERUl6NU9QWUhwVDM0OVJFRVdicnFoOSsvblRodGdBb0FhTmdkaTNXaldEZHpsQ01B'
    b'CmVEZ3hweVcxMlV3Zk42YkJTSXdhSU80eTZxaHR3YStYMjlQRWNhK3ZldS9KdHZrVGhoRERz'
    b'RmtMVmxNVWxYNzF3c0dDeTdMR1lqdGEKcVpjelBUS1FhME9GVGtQaUl2aS9IMitWS25GSDhS'
    b'MjlRVkdJaitUZnFqYUUrdDRWZEx1S2paZFRUK3ZVRWxWelZrVkJNVUFQZVBwUwpmU3R0Mi9y'
    b'NWZPZGVqcTcrRGp4OTUxOGJUUkVCbkhiRmF2ZStSWldHaFJOY092ckxnZ3A5YlpOWllnNXc4'
    b'ZXJoRmRCbjNxcmtwekhiCkNIbXFTMFIzL3ZMWnBQQXp0YzJtL0hLRDBVelk0Z1N4Z0I3aXpj'
    b'NHQwOVUwbVlLOE9WNHVESHNSM2NXZVVWcGpDUEhoQUVEYVRiV2YKQjZ0OTZLcXV4U3ppWVFJ'
    b'ZTdaMk5oc001c2M4QXdoRmhPWnRXc3ZSR29sV0oyeXluTGJUUEtOTFpnbGRiVlZzVkZwa0ty'
    b'MnV4bE5VWQozSjJZOFpIOHNscWpWSW5ickRHTGdVWUdjSHpkMlllS0VtY3YvdGZUcXkzdHFi'
    b'YkYwT1JYZG0yNy9QSmc2SmorVm1tdHhaVjZzNFdrCjA1RUJQUVgxRXRQdE9xT0xQYU5GaG92'
    b'NUZtZDdSa0tNOEhTNnNoMUNMeGNtUEEvaHNqSGZEb21JN0Z2NkVYMUZ0bVRtN1hwVGlBK24K'
    b'cXNIRTUySjlvL2lOcldiY1NsVTJtS0tEdVRiU2UyZHM2d3B6d01TWG5tbzlueTZFYnU1ZUV4'
    b'WnUzNy8vVzVvNXYwK2cxc09KQVFBaQpQczJXZHRweFhJSmhTUHRvWjc4ZWdtM0hXaFpOY2tV'
    b'UXVGL2k0emxLZTE1MDcxbnBqQkdPQUJBZkpiRFJUZ3FnVXhUUklyZGtsdkdNCjlJZ1JNNWQ3'
    b'ZVBvODFZb2h6MmF0dmRGb1RMOXkvdURPcjJQOVpBZ0NGQVY4THVZZ3BGL0pVL3Q3c01jbTJO'
    b'bXljUktGNVV5NmlzbEEKWEIwWUNUR2RzNHZQMkpCMittZG1rYWFteVd6QnFjUmVBaThYbG8x'
    b'dm43eXF1Rld0SHhBdFZHb0pqYzVxTTZIWmxlTHhNOTRka0RpQwp5K1UrZzlyU252WUR6cWFl'
    b'U3hvOG5NMW1EMDBhMjFDVk5USWdsY2RCYmZTNnNkVThvSWVnVG1JNWNFNkdvWkJicXVzZHda'
    b'K1c1TUJpCm9QdlBTbDgwTGF4dE1rOVBjaVJJS3VXeTRzZDl6YkZoZklvQ0swa05pQmJhQ1do'
    b'UmYvRTFrNFdreEgxR0pFOTZaaFhyQWtLejJieGoKMTU0RGwyNXdmU1B2cUpHaU5ZQ2gvM1RO'
    b'cW81ejBZcUxpei80L0R2U013cGp0TGtycTluSWs1Wi91R0pwUkVRRUFGUldWYTNhK1dGcQo5'
    b'dVhQMy8wVVFaQ1hGMzd5KzJhQ2Jjcm9IMmEwRjlKdGViajREaG1zU1VNY09nYjdYYzdZZUM2'
    b'aTFsbk5PQVVBR0lwTUdHUnZ0cEJUCmgzZWVXNlhTV3E4Vk05Vm83OW12Zi81NFR6R2J6UnMz'
    b'YlQ2ZFY4WHphcy84VVlhUzlMZm16UmcxYXVUOTJPeDlEZW5oTXhkbW5XbzEKMkxYWjhWbVc5'
    b'Ti8vdFFLNVp6REphRFFtcnY3eGhrTi8yK2tRUmRycGRlKzB6ejdldEdQemI4cDlZQ1pmc3B2'
    b'd3pxdkwyL0pNV3UzVgp0TlBTaGlJU1Y2bVVNbm5ERFg5M0drVlJWWTJteFpOZGJSTUdLUXBT'
    b'TGl0TVpnSkZrU25ESEo2aklUMldKamVaU1RvTkhUZkl6aFpJCjZBekVqL3ViZk54WUtJTFVO'
    b'T004cHhnSEJ5ZVVJYkp6Q1IwNGVMUlFLUHlIVC8veTV4M3YxN2tCaXdjQS9pMVpWOWZPY1Br'
    b'cm0vaG8KaG5UaWlLRXhKOWRkaFRZSWVWd3UwdFZnSUp2Tlp2NDFSUUF4cUtmRkJYV2NQUzVS'
    b'UzFFNkNuVDA4SzNqcjBobk9qazY3ZHEvWjN6eQptRkZqcGdKTUJZRGZmLzVrM3VBNm15TWtT'
    b'T3JFRldXcjB0STdqTmNqaURjdTBRNEFNZ28wV2NWYTJ4dzRwY1ppTlQwTEE2dlFtQUZZCkFG'
    b'QjRXOC9uME1ZbHRxRlMxV0E4bmE1MGMyU3VtT1ZoUzZHUkpCekk4NXI3eHJvSDNLMHRhZjdR'
    b'TW5sb3YwL1dYN1c0aEFDQUo0ZDYKTUg1LzR3c0grb2l1cWtsQVVRQW9sUnE2TEtOVUttL3JN'
    b'UkFCQUFRb0MrZE9YbllYd0RRV2tBQUlXTHpKbllmL2VHZlI4b3p5elB5YQpnbldydnZqTENo'
    b'RHR3NG9ZaWtTSGNDMDRwN0hWYkZORWlvTDRLRUZta1diM3FWWWZWMmEvV084bHE1WUJ3SGN6'
    b'bDdvMTZlUVlNZWEzCno3eTl2WGQ5OFIvYW1Sd0FzSTZJbWZYK1c3VzF0Y2ZucjdFbnNDWjMz'
    b'b3JkUHdMQXRpVnJ2RXBhVldBTi9PYU5xTmhleHpidjRPNjUKQ2dEeVlSSFRQbnhMcFZJZGVu'
    b'bWx0eDRxWEZpdjdkMElBRGN2YnJoUlVsVmVhL1IyWVE3dUxiUjFMd3hGdEFZaW9aZVF5OExv'
    b'ZncyTgpvU2pRMEFmeHdiemlXei92MlBQejE1OCtBc1Bzb0N0ZHFzMGpRTGg0eXNoTlg1eFV1'
    b'VVFCUUw2QlUxTlg1K1BsMWFuTUx3ZE90RGlHCjI0NWpuWmxNSnBNa3ljTENRZzhQRDN0Nys4'
    b'a2pKeHo2K1FSNFl3Z05iVkExNm5TNllrVTVBcFRGWXJFbDZlTVRwdS82TTZ0ZmtMSzYKeWR6'
    b'WWF2RjBaZzZLRldhWGFBK2NrMTNKVVgyendwK0JJbjBpQkgwaUJBRFFrbzRrSmlZQ3dBVVhy'
    b'OUFtU1MxaWpvdUxDd2tKS2ZqegpqTU9aV2dDUUJZVWtKaWFXbHBZMklVSnZZTjV5ZHJHVlQz'
    b'TndDUVNqREN4UmtUMFNFeE9MejF3V1F6NEFOSHQ0SlNZbVNxWFNYS1lnCldFL2hBb0d0ZkYz'
    b'T2o3M0QrTDA3VFA1Yy9uVmxRaStSR1NkbkpUdGR6VlZmeWRVNDI5T0R2TmhadHdXOVJrNitY'
    b'd05XMWRUTi91SG8KeXoyRG5xck5lRkMreDl2VHN5ZXpiVTJUMGlWaSs3R0w5NVpKcjVZQmd3'
    b'MEFpRUUxSXNvWEFGQVVYZlRWRzhsZlRKbjQ3clR5Nm9xUgpib05KUFFFQUJFbHMvbU9yenN1'
    b'a0ZHaXlibWJaTGc4S2paeTdNdVZJVWI4UVgvN3NNVTZEZXdzUkJLWW5PVTRkN2pBMXlWR2lz'
    b'TmlzCldSdmZJWXpQaHJ5UTFyWUhGVlRvQVVDdXhrY24yRThkN2pBcjJRa0FCa1FMWjQ5eGln'
    b'N21IOGpwK2RKYngzcEU5d1dBQTRlUGRicEoKczBReTlZc2RGYWp6MklUWTV3WWhBUFIyNTdV'
    b'TmxLRllScTJpMDY4R2d5RlgwV1pHL0pURjA4Y010eDNIUjhTQkw5YmtxL2ozaFcvaQpvK0lp'
    b'RkFFVVFSSWtVYTlxUU9rb3lzWWs4anN1amNsa2VydngzUjN2NUVFS0t2UUVTUTNvS2J5U285'
    b'bDFzdlhBV2FsQ2pRTUFqMkZTCnE5VlBHejhjeDFGS2I2TXRCODlKZDUxc1BYbFZPVHhlQkFC'
    b'NVpYY1c2VG5aMGZ3OUJiWnBWRGlPZi9qMUJyTERpS0pDcVpxdzl0Y2MKOTJFKzF0YlFrT0Ru'
    b'Q2VHaWljT0YwaExiY2E2R0pwWEpPdjc2KytHVGRYWnRWclNYRTZOOTl0WHJVMTlsMUtFQVFM'
    b'Z2pHMUkyZmYzTwo1K0pxcnBVazZDZ0RBRUJGUllWRTNNaSswVTZHWS90UFBwK0R0bWRFUzZz'
    b'TkdJclljalN6a3AzV3Z1Wno4WVo2MzFscGRWM0xqYXpyClR4dkM0cUxDbXRxR2ZXZWx4Njhv'
    b'UGw3c1BTdlphY3pBTmk1YTEyS3VxR3RUME9zbEVCSXpwbzFEYnRtdERrZ3dtODF0RVloR00r'
    b'NjkKNzdOY0VnRWd3STc5TVA3c0tVSVk0TzhYUlcvcitLM09QYllkUHR2eDE0dTNHb0hOQndB'
    b'dzZZYUYzNW1GSFJJWU1pZG1CaUloQVVEdQpvLzMzcGk4bnhZeXZiYTRUc1FVQTRBL2VnUUdC'
    b'MncvOW5ua3owMVkrTERMYXU5L24rN043YkV4eHVKcXJ0ZzNmNkF4RTJrMjFqVElNCmpSTk5U'
    b'M0pjTXRXMXBpTDNhVU9ZbTMzMXplbk8wNU1jUncrd3N6WCs5VUt0VElVRHdMaEUrN0phNDlj'
    b'SHVQdHVSQXJDUDRtTEgyU0wKa1hZWHlRbU9uY2xrc2tWWms5Nzc3cHJyTUVCUUFBZ1FQL1VF'
    b'NzkrUGZmUjI1NEZOWFdpTWE1V3RIUTFPcnF4dGRvbVByR0RtMktTTwpWeTJjUHUvZFBtK0lL'
    b'amlFaWJoT3k3bFprdE5TMlZoZlcwZXFyR05qay9jYzJWdUFscDVOditOY2U4YjBtN2RzNDl0'
    b'cjkyaVJjSlhXCjJpTEhmemtpU3g1Z0J3QmFQWkZacExVVkl3eTFUejBYcUtxMEVjN2lTbjFq'
    b'cXdVQVJ2WVY3emd1cjIvRnRYcWkyZUQzN3FmNzVyLzEKWTF6Zm9iYnk3LzFuVzVsamJ4eWxt'
    b'MHdtaThVeWNlVlhGeDJHQUlvQkFPaVY4U0hlengvQ2hlT0c4RnRMMjNxb2t0Sm8ycWFUN0Q5'
    b'Kwp0cExmWnVWN09kSTY1UVByNit0N2hrUWRYL2ZuTXQ5WG82MWh4Wlp5dEI4bnF6azNVT2Z0'
    b'N2U2NTRjWVdpeXRsSVMwZC9ZZk5MeTVkCjgwZStlVmtsYlpWVHdMaG1PUUVBZWhPVlg5WG1L'
    b'VTNxaW5aNzlWU0lERWthVmVXMjQ2eFN4R0lGQUpBb3JZNStvNXE0SDJiclhsKzAKZWkrZmYy'
    b'ZGxRWDFqWTBvVEFqUzZCYUhwZExvWjczOTlScFFBdExiSTJGbFpQaUlodnVQOWo1NDhvOVZx'
    b'bjNXT05EUTRLSkoyTk4xVwpZNGVvblVmUExuMWxDZ0NjenEraStMRUFBR2JENEpET0MxODhQ'
    b'RHdHang4eWVPaXdNTC9RTlhOWFc2ejR5bzN2TjhiSkk5Q3dvNWRQCmtHNG9vYkgwaklnOGxw'
    b'SXlZZno0VGlnbWozc0pBR0RVeEF0bmorV1hsWEQ0TG9zL0dId2daU3NOeGQwalFpNWVUSDE2'
    b'RUY2L2Z0MHQKYk1xaGdncUN3bDVlUHI4d0wrTldlWVBJMGUrMWQ2WjA2ZEpXLzdpbjNya2ZB'
    b'SmlCWGxwZVRxTXpleXB1NUFsNkFFY0lBTDVzb2oybwpWNnBVYjN5OVJkcFFQejU1eEhOSWM4'
    b'ZTY4ZEpORkNBSU1EbVhTb3VXQXBBa21kdHFCaGNBQUM5cDN1ejNGdDBibnlhTkdIblljdnBZ'
    b'CnlSbmtDb1FpQVJ2ZlhUOWovVnl0cTg1a05RS0FyOHh6WXZLRThiTW54Y2IyOG5EdmVzM20w'
    b'S1J4QU9Oc3gzTmYvNWROUzFhL3MrVHAKN2Mxdy9NamV0Zi8rcG4ySENTOGYvd2NVemlrc1Bx'
    b'TVJnaE1DQUNTTjRlTHNzdS9MMFc5L3RTblB3TEdyVEZQNEp3YmF0Zkc3UFNubgpQanVaVjAx'
    b'M1BibGs4SE13cEFBd04za0FWMWJSWmt0bHVNbGtPbmtoclpUdGEvdFBqRDNXNVV6SXQrY3Zj'
    b'Nm9WMFhnTXpKdHh5Nmw2Cnc4NGZnL2orSlpKU0NvQlZRL3ZtcmMvckcrbzFyc1l0Qng1aEY0'
    b'cWpCN2JHdUJjK0pWdEtXSWtlTG9VSGRuMy9rT1UvM3A2aWNJcjQKU3hjWWFyMnhWU283V21P'
    b'Mmw5N2FOaU0ycWpFMTJJbW5WS25tcnQydzhKS3kySFZBQXIwbE1iNzM4NEV3T2pJeUF0cUlU'
    b'SlU0ZlArSgo4MGN5aWdtaEd3Q0F4WmdZMVBVcU1qYWIvZDBiWHpxVTg2MDZIR05oYVhqR3Jj'
    b'eWlCcGFrdkx3c3hqNFN4ZEFsM3k4Mys1Sk5tdWFICnJHdERYUTFJRDQ3dGl5a3M4cWNCb2Nx'
    b'cVNlNURPQkJuQ2d1eS8xNWZMNlJkSWp0UUZScERZekIrdE9tUGF1ZlkwUTZHY1NPSDdYbDMK'
    b'R2hPbEJyeTNaUWYwTWdnOUdacVdoVU9qbncrZGFWTTE1emFiUUhGRVp3dXFjaVVtMjZtYk5I'
    b'L2VwUHV1SHdzT0NEN3l6ZjczUXBlTgpSNUo2VW1GVUJCTzFveW44RFdLdTZLdHQzOG9EZEVD'
    b'QmlDbHNhV241MndySXBLMUh0citWRkdOQ0VBZ1lSRWtZeEJNZVRxSVJqdkVrCmhpSURJNnpY'
    b'ajY5dGJQZ2I2bnZtY3NZd3ZqcTY0VHhRSkthb0J4cXpwcTd4cElUbUpzbGJ1MkN5WEtGY3Qr'
    b'ZjB4K1djRXJlQnRpUnoKYjlPdFNhT0dQazhJWjQvc3o1SlYybzZ2VnNxS01iYzJMaXFHQncr'
    b'djBPbjBxZU1tZjdCazFlYVBmL2hxMGxwK0U1dHV4OUNaOVEyNgpaZ0JnVjlPV3ozcGo4ODVm'
    b'YnVRK3FPTXJsZkk5UHkxS2lwTFlUdCtZSzh6MnRUN1pocmptYlgxL1dSdjFHQkloTzdWelNX'
    b'UDlnMURjCitEK3JqM3o2bXFOSXdKRFhmdWpXMUVlUnNmZFNUb05qajdFZVNGNXhXZHlLRGR1'
    b'cGFLT3dMVlpHRGFxWjhjRlBLY1ovMkZINytOaVkKaU8zbnM4RWZBR285QjdSRjlMaDVvUCtE'
    b'aGtKZVdUeUg1eVZrTXBoR3M5Rm9NWWs0d2pES1AwdFJVR1dvSVNrQ3BNU2JRNWU0dWJvVgpT'
    b'MHRWcHpXOW8yUHZNMWlqL1AwLzgrY01VZXcrcFd6ZlBXTEJXOHlmUHRCTWVFS3RrSTlvWGw3'
    b'QWIyL2hTOW5xY1luWW56dVdURnl3CnhjWDF2cXZNTFJiTGJSWHVnelIrOU02S2liZktodjU0'
    b'MmJQNXh0cFBaOXFKUlFWVmpidUtNbTY3dFMyTDdLa3BXRHpqM2VjV0Y3WkwKTDVlL1puaXky'
    b'OGlMc3lSdndlUUhyY0pkOStsWFZkS2E2NXpjUEhGcG1YTk5KajgvazE5Z2FURFhJODBxWEJO'
    b'TStFMU9uclR5eS9lcgpIUnRiREsxZDNvR2lxTzBiM3B3M1RKRmRvazNzSmF5c056YkxMQUFR'
    b'MTRQck00UlZWM1A3bnpkQlUyTzlReXh0VkNJWEFCUnF2S1JLClA2S3Y2RXF1NXBYQjJyMmJs'
    b'MXV0OTFYM2E1blp0VHlmUURzR2htR2Y3a2lSTzRWUDhHRzRPRHN4R0l4eGcrSklHaFBSeVlH'
    b'aXdHS2MKRU9IODlEYTdlUVFJWnc2Tll5cHE3Z28yeEpTZG5kMERMbkZ4ZHRtMC9EOCt0YTdX'
    b'T3JPbHljaStqWW5WQW9ZM0U5d3hvNWZWV2VpVQpjdVo0bWpVRDVkQklpaVJKTWpXMWM4eDMv'
    b'UENPTWRGVkdJcGN6bEhmTE5IVnRWaGNIUmdrQ1ZvOXNmWWQ4YTMwbjFRcTVUL0t4UmlOCmw0'
    b'NSs5djNIRG5vamdWc3BPeUZkclNQT1pxaHlTblVVQlZQN052MjVlK1A5cmoyZFZVU0kzQVBG'
    b'ckt6Y2dsU3prMTl6NXRyWFpnQkEKcTFTMjRLZVVha0h3Tk90Tlg4bU5VUG5OZCtkTmY1N1pt'
    b'WFlaR044N0RHL295TUg3ZVAzOVZFRS9IOTk5WCsvODgvV2R1MTdlY3VHYgprMmUvUGJiSVp6'
    b'YTlCVUhwcU42c3o2OG94T3pwQU9ETWRxeXFydHEwWjNPbnkxdktqcnJhMDB3V2NuaThlRVJm'
    b'c1cwQTlzOExNdHRDCmszbEoybTBiM3V5VTRubDRvU2hxODdkTFp3OXFNd0Q3ejBrQm9HK1VZ'
    b'R3lDM2NoK1lxT1pFUEV4YmRNNWd1aWFPcFhMVFloV2xoRGwKLzYvZHA1VWl2eWtoUWp1eDJH'
    b'UXlUZnRrVTY1anYxSDZqTjNyUHB3WEtScmx5M3VxMnd3K3dndzJCRUVpbkxudGFXYWV0R3o2'
    b'SzRQKwo5aXFMeGZMNStpL0Y5bUtaUnQ1NHNFV3VWNGpaUW9jYWZvTklVYVdvRTdHRndBUjZI'
    b'YkpnOXR3ZjkyeFdjdS9hY3JHbXBzYlBvUm1BCndXS2dNU0c4ZW9uWnRnWU10MUlDTHEzb3Rq'
    b'NGlnTnZIdTNyOXNacnhRR0h3YUdTQkFyaVJmM051UE1XZ1l5VlZlbjlQTnZMWEhaUmEKYS9z'
    b'dUZOSGVzb0s4bTlHOTR1NkZ2MXhwY2JOVzBHa3hxYmhia0NUanc1VkxLSXFhLzhuM2FRNEpz'
    b'WkpMZTlZdHh6RHNnMFd6REFiRApvM1lzcXNQSms5UkNBTUROcHZaakZtV2gwLzgrRGM5Z01F'
    b'U080dDFOaDg0eXJ4YmIzMjd4VXR4eXJHNzFVRnNMalZLeE11TjZCcjBKCldUYnd0YlNzSzll'
    b'Sm15YkNkSmNLTnRVNWk5czBMTzJtMnJac09LOU1oeUR3NjVFV0RodjdJODFPSTE3U2M3RGRz'
    b'V0N6Q1I0aHpMQUMKbGVKakNodkV3cnlYNzBwelpMUG9PMCswc3BqSTVSdzFBTkF4NUhSNm0z'
    b'MTJjNkExTlZUZWU0ZWlrbHRWbUdNZ0h6YWN5TlR6M1Y2SwpjdUh6K2U5OHZla0FFaFVzemQ2'
    b'eitoVUJudzhBR0lZOTZnclE0NWR2V0lSdEhLck9pRWlrMGljRFlWMWQzY3NMWHF1cXFoN1ll'
    b'c24yCkY0cXBweTljK3RPbW4rWHl2d20wbDg5L2MybllBdWRxRVZWbHhhdk1XQjFsWWxob2tX'
    b'eWFtSzRLTlNhSyswWUZSdXdxM1U4NW9FS20KRUFCcWF0czhyazZyNVA2MWZVVkRxeGxGNEh5'
    b'bXlveVR2dTdNc0dEM1hPWDQrYXYrTkJqMWM0YktrMmVRcDRKTnJZcUhtaHlsMCtsTworWm42'
    b'VDhOZkgydVN0dFF1ZXU5Z3NYNmFuNCtYanhzTFJlQmFubHFqSjVTYU5oYkRabUY2WFJmanpF'
    b'Y3VaWmtjL0ducWxpdW9iNlEwCjg3MzUwMzdlZS9RWGlaMkRvWEhEelA0QnZqNlBZUkp4SEYr'
    b'M2ZzUHVvNmNHYW0vYUd0a04wVStjdlRnakkrTUpHRkl2TDYvZHYvNzgKZU1aYW85SE1tVEpy'
    b'enBSWlVxblVhcld5V0t6aTBwS2ZEbTJwY0s2ak83TUlBM254K2lWd3gwZ0xFZXZSczdhdWRz'
    b'SGJyMTQ0ZEE0QQpXcHNxZWdmUXRYcENyYmVXMXhqc0JIVGJSUDFySlRSZTBNclpDYU4wT20z'
    b'cXlhMDlwbUJNQnZiclZydGwzK1hjekxyTUZUd296cWtvCks4cXJTZDJ3MVM0OVh5TlY0cG1w'
    b'dTBlT256dDl6b3FjN0xqR3JFK0hSSnNBNE9JTlZVV3Q0WGE5MGRtT3dlZGlKcDNrM3Z2Y2F0'
    b'VUMKWWFrelVHWm44Y3NoM3FtWk9XdXZ5NERHLzZpUFE5TEErTWRyS0RxZHZ2THRaU3ZmZm1x'
    b'KzhQRnpqd1F4OTlXNW8wYVBicEZMR3BSTgp6ZG9XTTJrV2NQaU02NFIxQ0hhek9VL0k1Q01Z'
    b'NmxJakdqdzU0Ylh2MzJMNjh3QkFvMUhYRi85Wnc3SCtmS0Q1bXhWK0h5M3lsaXB3CkFMRGdW'
    b'Qk0rWUc3Q0tKMU91KzM3aFIvTlpyejliZVg4OFM0WHNsUWZ6T0VjUDdUYXdPeDNQLzUrNGV3'
    b'UkZwV3piaW50WElZcTNKLzkKL3NicXJSOEg3ZnRwd2RURlcySmlCNVFWamRBWkR2RTRXSVEv'
    b'cDM5UEFaT09ydm1oWnVZb0owWE5DWm4wZFFkSHAwNWNobDJUVWhXYQpHS082T1dyQWhDa2JU'
    b'OHY0Z2NzZEc1ZTh2QWllclR5THpiWEZZdkdZQ2VPK1NkMndXMy80TWp1cndxbXV6a1ZTNUhS'
    b'YjcydWxyS1RLClU1K1NlWXFRNHo0TWp6WEhQMVA0NjhRc0VRQ3MrMndsYVZWSjVKYTRDSDVE'
    b'cS9tRGpkWE5jZ3NBbkwxSkgvL1NjclZhdGZtck9iTVQKbTQ2bHlaZTk1RlowVzU5UnFIWVUw'
    b'L2tNMWNTb3E1a2VsaGJXWFRSVlJpY3ZlNVBKa1ZrZUlpV2RoaFRkMWwvSVZIMzZ1dmVCODlK'
    b'WApCaXYzL0xTZ3VhbGh3dlFsWjNMNEFHQTBrNnZXVjkydU0vWUk0dXFNVnF0Wis4WC92TldS'
    b'WkRTM3RGUmF1U2hGVWhocldnLzNlUnNPClZ6aEVUN1Rtcm52blZYam1ncTFkdS9ZWlBDWXNL'
    b'TlNUNVY2UWthZkY5Q2dEeFdVbVpoT05DUXljUzJBc0d1V0pzaHRwZXRLazh6RlIKY3V1TXlD'
    b'bTRSczdVbkp5VnhIQjNZaDQ4SnlWSThISmg5ZThwTEtzbk5aekprZEg5dDZ5YnR6Qkpjdmlp'
    b'UEM2U0grek5BUVJxbWl4UwpwYVZIRUxkQllwazZqWjlQdDF5K0pSMDNaeVpCa091L1h5Y1lB'
    b'aDk4d0N1dTF2V0o1Sis2cXRRYmlkNFIvQjVCUEdjN3h1RlUrWnlSCnRKMzdVM3Yxbnl4Umdy'
    b'd3hKOVRIWnIySjdCTGRqSkZPZlNLNEZJRzM2dTI4ZmR1bUUyNC9lT0p3ZnIwMWVHQnZiVjZk'
    b'VkpudU5HaXcKSXUzUVZ5c2ZmdU8wSnlqSXMveUtLSTdqWjFQUDFUWFhCM3NIM2lqSmthcGxW'
    b'eTZtVVVPWUJHVmwzelNRaUpHRDhJSmR3bGlVSmRTNQplc2JRTzd0QjNDd2p6dVd5RU1vOGZQ'
    b'SUhBd2NsLzdodTJkU1ltNWR6TkY0dWpIQi83dTE2WTlGdHc0VEI5cC85V3VmcXdPQ3lzZWxK'
    b'CmpzMHlTMUdsd1VDNkVDVHFhU2Zsc1pCUVg4NitzMUlhaG1TWDZMNTQwK2QwdXRMRGlSRVJ3'
    b'SzJzTnhaVUdNWWsyRzIvSFBUV21xMDMKTWk2ZFB2Q1owV2dhRlVmMkNyNER5ZUVyNXR3Njc2'
    b'RHdXTEdBditmVWhXc3RvQW9jMlZ1Ym4rNDdNVUthY2VaL0ZyaTVPTVB6a0djSwpvVjZ2dDFn'
    b'c3AxTFAvSDdsRDdtWEZtVmdsSlhrRkVrV0J0T0c5ZURaWWo2RkdzZXRGSnVKMm5ZVnlpb2x5'
    b'K1JoL1pNV2Vmc0dLUlF5Ckh4Ky9QLy9ZR003ZHExS2JGR3ByWWkraFZrOGNPQytiUDk0NVBW'
    b'OU5wNk44RHZiNXIvWGZ2TzJyTjVJU0JSNGZ5UWVBeW5xalVtc04KOUdJdi9iSnkxUndQRElV'
    b'V09UNDBUclQ3Vk92SWZtSjdJVDJyV0V0UmxKOEg5MnJUNkZrTFA1REpaQmFMU2FXUVhUNjl4'
    b'WmRmTkNBUwpBRUJuSUhSR2drRkRSSHc2aW9MZVNGek1NWHllRTZHMTczTmcwYURZcUFoNFR2'
    b'S01ER2tiQmFpb21EeG55aVZ6cHRXWHNtcHdVVE12CldNSmRGR1VBd2hybXgya244VHdPeG1T'
    b'Z1dhWFVwZkxRb0FGclJrOWE3T3ppeG1ReVJTS3hWQ3FwU1A4eTBzZDZQa3MxZnBBOVJjRnYK'
    b'UnlYenh6czN5eXpsdGFhaGNhTGI5Y2IrUFlWNVpmcExONVU2QTlrcmxBY0FKNitwTXdvMWFo'
    b'MHhiYmhEaXh6dkV5a29yelVpQUFPagpSVHRTSkwxQytSN096Q3M1bWhBZlZtdHpEY2Rwb0p1'
    b'N0I1OHZjSFJ5aWUwM211TEhIYjFZcTFaS0F6MFFIZ2Rqc3pCYnlNK2dvMDBTCjB3Zy9tUU1s'
    b'bURsOU5qdy9lYWJmQ29rSUQ4OU96ZnJsNWU4WGlHZDhrL2pweVM4UDlmV2hsOVZxQnNVS2ox'
    b'NjZLN2c4Y0UzczFQcy8KaTk3ZEV0WGpydUdMbEgzZmo0a3ovWGxCTmozSkVRQ09wTXJISmRw'
    b'aEtITHFtbkxpRUh1OWthaHFNTWVFOE55ZEdCTUhPNVRVV0Fzcgo5QlYxeHB1bDVubmpuTzBF'
    b'OUJBZmprSnRWYWp4a2YzRXFkbHFrcUplR3VGNDhMd1VBS1lPZHpoMFVaNFVTMTVJK2FIakV3'
    b'T0R3eGUvCjgxUEFrSjkzcDkyMUd1M0VWVVZjQksrc1d1ZkJxb0xuS3MvaGN5L3h2ZU1YejM1'
    b'MWFPSVFBTEFhNm4xY1dVZFM1Y1BqNzZSYmpXYVMKNDVvVUhoblRoZEhBNi9WR1FzQ2xzUmlv'
    b'Ukc3Qk1NVGRpV2tERWdBT25KZE5IZTVBVVhDcjJoam14L1gxNEZ0SlNxSEJBN3o1M3E2cwpa'
    b'cGtGdDFLVGh6b2NUcFVEd0xUaERnZlB5K3lFZEpHQVh0TnNvbUdJdXhPeldXYkI4UHA3bnhz'
    b'UUZPb1JQczAybS9TVHZmaVZZdlB3ClB1SWpsK1NSQVJ6RTBpaVJTUDUvUWRneEdTaFI0TDV1'
    b'VElvQ0Rndk5LamZNM0NsZnNMVWxzd1FHRE9sNktOQUN3cFFyOGhIOVJBQncKK3JweWJJS2RU'
    b'SVZqR0RqWk1XNVZHNEs4V0hRYWNpNVROYktmMkl5VGprSWtPcGpYSjBMZzZZUXExUGk0Ukx0'
    b'VDF4UW9DcjFDZVRkSwp0QUllVFN5ZzFVdk1TZkdpaTFscUFCZ1dKenFmcVRKYXU5NjlPR0hJ'
    b'bU14UzF0NnIrUHF5bU1rSHdoRUVNQlR4YzJmWFMvRG4reEdyCjV3a2hrOGwwRHBxZ015RzJM'
    b'VnkyM3pTMFJMaFdCcnRzdTBhNHVYVTkwRHB6MGRkMTJpQW1IVlZxckE0aU9vTEE4U3VLTVFQ'
    b'dEFTQTkKWDlPdmh4QUFtcVJtTjBkR2NhV2hkMWpiZk01K2tjeThjcjJJVDFOcENaS0Vuc0c4'
    b'd2dvRFJjR0l2dUx6bVNvQThITm5OYlNhVVJSYQp6WDR6WHZ1dXkwZnplRHc1N3YvZUNRY3la'
    b'b0tZVFZnSkNrWEFaQUcyeTlBbis5bUcveVlJQVdEeEcyc2EwWm5WTW51RGlmU2lVYmpTCmhQ'
    b'SVlEWjZzOUJ2cFhaYm5jcmw5RXlmZkxMTWVTNU1QN3lOdVZWaWM3UmdvQ3RjTE5BT2pCUUNR'
    b'VWFqcEY4VUhnTm9tYy92MjBRNGkKZXFzQ0I0Q2hjY0xVYkJVQWpPZ3Jzb0VYNE1tcWJqUWw5'
    b'aEtlU1ZjV1Z1S1JzYU9GUWxHbmg1SWsyWGZlYXBmNTYxWmZac3NpWG9MYQpuSmtlK1JRRjlV'
    b'cHhybnJpdXgrcyszL25DenZKMUZlV3YvbkpuK21LVnlmTjJ1R3Y4UUlBeWd2NzE2NnY3amRH'
    b'a3p4aGpqam1CNG0xCko0T09wTjFzMjYydG9zNFU1TTBCZ1BMYXRnT2RrYUIzMk9QVXRuV3h6'
    b'ZHQxUEJqUVU1aFJxRVVRMENCUmpORDFFMTlhMnVseGFyWDYKMjYyN3Nwd1NKRHd2cmRnWFVC'
    b'UnJMRW1lOGwyNjR0V0ZxL2JQbUx2cW1YMTc1c1dGRUFBY0haM0hUNWtUM1N2dXJjbExrQllD'
    b'QU9SKwoydFhmckxsZitjZ2VNYkh4STJ0YkNJS2s2RFNrdXRFVTRNa0VBSU9KdEcybkFRQjY0'
    b'MTN4cmhsdmEyZ2VHOU1iQ1FDSUNlSG1sdWtRCkJCQUVXaFRXa0tpRW1OajRld1Baa1N1L1cz'
    b'T3Vpcng5QXhwTHdUc0thZ3VJUVF2M1hpMGFQMldPbTd2SGk5QjZMOVlIQ0FmMEdSQUoKb1VB'
    b'QlFrTXpxYncvRHUrNVg4bXhrK2Mxc2xmSVRjNEFrRm1rN1JzbEJJQzBtK3BCdmRxbTArSGtY'
    b'YTlHSVcyblErTkVGN0xVQUJBUgp3QzJ0TmdLQXl1SllScnd4ZWVhYjk5clBHV3ZXWjdnT3d5'
    b'TkhRSThSMENNSkNzNUN6R2pBYUJrVmpTOU9vNzF3MzVEOGRPbEg3Qm9hCkFDQU8yT2EwN1ZY'
    b'Vjk0MjZobythYk9jUzFwWmtRZ0FBVkZwcisvNVpOT3l1ZENXRDNxYUZmQzVtTUJFZHJ4TFlC'
    b'eVNQbjNudkRNRWwKLzlwd2doTUhIZTlEWXdLQ2dyeXUwVWlkdTVyWkRXSFg0dXJpT2paNEpL'
    b'R3pBb0FwZ0ZpOWZzMERDbythdW5wdlpwaFUxOFd3T0liZAo5V29kOTNxLzQrZE0vSDJaSVVN'
    b'bnJMejNwMiszN2Z0ZDYwbXk3cjZ6ZXlnMGwwRjFuaXg0WkdWdC9RdlNZalI0OFdURndyZTBQ'
    b'K2dBCnAvZ2MvckRGUXg1UTB0M0RlOEhiUC8vMncycVN2STRUWk1ldlFIVGFhS2ZqcWIyUUxs'
    b'Zmo5a0s2d0RWKy92SU45OTUyLzhuem4rZVoKalBiM2JITmdVSUZXQnE0Qll1bXQ4VXNuZFVO'
    b'NC85UTdncXg5ODhPSEx6OWh4c28vdG4xZ01HaTl1QjMyRGtVNkVVV1ViTnQvQllROApkR2Vh'
    b'bTRPOWFQeXNMdlF2dTZCbzljbFNoZE05bjhXUTFvREZDR1lqdUljRnlxNjV1cnAyUS9qRXhN'
    b'N2VZZkc3VzNRNjNZbk5vd0VvCkFMaFNBR3l1UGNDZEhUSllYT0c1SEdwRUxBRUFSaXRuM3JL'
    b'TmJtNXU5OTVLSXBVdTJucTJ4cWx2Ri9yWFhBRmlGeEM3QWtDUVBldkYKZWYzL085KzE1L0Y0'
    b'YWpTbW9SVy9Wa1NvV0dNWm5MdXkwaGhEakxsTVM4MmxtbVY0bFNhaVMveU1SdU9VRDMvSXRi'
    b'OW41Z3R1aG9KegpFRGtNV212QTBSY0lhNlNyNk1WNWNScjhINUtGYjMxN0plMk1YN2hmVW1E'
    b'd2J6K3NwcWo2ZHBwSjBOekhUM3U5cGpxcHVyTDB0WGU3ClhtZTc2ODhVc1ZnMFZKK3RzUkRs'
    b'RnI3YUpSd0FnQ0loYlRzTW1nK1ZOOEEvRmdDNHN2THhzeEplSUwvekxJZDhuNlhVMTFWZlB6'
    b'aC8KZER3QkFKZnlVZDhCNjhNaUgyRjUzN2dQTnFTd2VnT0FPSHVma2k2QXdINVFkZzJpa3dF'
    b'Z3N2bEt3YVpWM1liMHFZdW5sNjkzL0pwOQo2VzRIcnJzS1FsWThFbjRBNE1GbkFJQy81SWFY'
    b'SFJmQ2h5R25OL0R0MnZiOWZhRWM0ZjgxUTlwSit2UWIxcWZmc01lNzFrdkVkaWd1CittU28z'
    b'NHFEaWw2Ni9PRXpSd2I1K1MyN1hxOFRlSVE0Y3JzaC9DK1FRYkhoTkhwWmJIamcxMVppN3RS'
    b'eHR0ek50YUwxdjB2MG81TjcKdkZCVi9UL3JDNStHbU0zbUlWUG1YRDZ5KzdtUFRuUkQrUGlp'
    b'MSt1ZnphYnAzUkQrUHhLMHV3bTZJZXlXYmdpN3BSdkNiZ2k3cFJ2QwpidW1Hc0Z1NklleUdz'
    b'RnYrbStWL0FWbzFHZFZobm9FTkFBQUFKWFJGV0hSa1lYUmxPbU55WldGMFpRQXlNREl6TFRB'
    b'MUxUSTRWREF4Ck9qQXhPalUzS3pBd09qQXdFMUxMMFFBQUFDVjBSVmgwWkdGMFpUcHRiMlJw'
    b'Wm5rQU1qQXlNeTB3TlMweU9GUXdNVG93TVRvMU55c3cKTURvd01HSVBjMjBBQUFBQVNVVk9S'
    b'SzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxNTU2NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_VI')

US_VI = b64_US_VI
index.append("US_VI")
index.append("United States of America Virgin Islands")
catalog["US_VI"] = US_VI
catalog["United States of America Virgin Islands"] = US_VI
country["United States of America Virgin Islands"] = ('US_VI', '', 1)
lookup["US_VI"] = ('US_VI', '', 'United States of America Virgin Islands', 1)
lookup["Charlotte Amalie United States of America Virgin Islands"] = ('US_VI', '', 'United States of America Virgin Islands', 1)
lookup["United States of America Virgin Islands"] = ('US_VI', '', 'United States of America Virgin Islands', 1)
details["US_VI"] = {"continent":"Americas","capital":"Charlotte Amalie","currency":"","web":"","lang":"","tz":"-04:00","altname":""}
regional["US_VI"] = ('US_VI', 'United States of America Virgin Islands', 1)
regional["United States of America Virgin Islands"] = ('US_VI', 'United States of America Virgin Islands', 1)
#----------------------------------------------------------------------
b64_US_VT = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjIxNyIKICAgd2lkdGg9'
    b'IjE2NyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjcgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1Zlcm1vbnQuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczE2'
    b'MjIxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTYyMTki'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTYyMjMiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMTY3IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtjQUFBQmtDQUlBQUFCc0NMZWhBQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFhCkEwbEVRVlI0'
    b'MnUyZGFaQWMxMzNZLysrOVBtZW01NTdaMmZ0ZUxKWTRGZ1FQa0tCSWloU3AyNDRrcG5Jb2ll'
    b'Tll0bU9sb2lTMktxV3EKeEtWeUpSK1N5Z2M3SDFLVnhJNWRGYmtpeVhKa1N6RVpVcUpBa3lK'
    b'QkVBU3dXR0NCWFFCN3orek9mZlJNMzkzdnZYd0FUWWdTYlgwSQpKTlpnKzFmL0Q5MVR2VDA3'
    b'NzlmdnZmOTdmU0U0K1dzUWNzREFZUkdFMWtOQzZ5R2g5WkRRZWtob1BTUzBIaEphRHdtdGg0'
    b'VFdRMExyCklhSDFrTkI2U0dnOUpMUWVFbHIvcWN4a2ZBQUFUbSt2RXVhRzF1OTlEcVVOQUg1'
    b'L1hyKzllaXpkUEdnbElCeW9YeXVDLzRrai9POCsKa3BvWkRqUkp1Zkk5bXBTOVJDb09uWU5s'
    b'SFIyb0s2ZytQbFVYMWJqbDhjRVVlWEpCMGlUYTdBYS8rVTF1Y3ptczYvY3NaN2FUTGhOdgpM'
    b'My90UEovTitQLytGd0tKZXpZY0xPc0hxMTkzbVNoalQwVEI3VlV0S0srWC9mbmtnZXZYRDF3'
    b'MjUzUGhxYkVHQUl5UXlsZWVHOW9vCld4bkJHREp1WUJZY25FSWdNSFR5NFB6YUJ3dWR4VEYw'
    b'YWs0dWJwYS9KRjFmM3U2V2lzMjMzMTc1WjhQbUJUYmlZam0wZmcvU3NHV0YKVU5GcUR1MWUr'
    b'blNlelB1bTEyay9NeHk5Wkd1WHhQa3dtN3MzaVZxMWtWTHg3d3kwNHBNcUFHQ1pISlBKR1VO'
    b'NlU3d3Z6T0h2VGZKZQorVjhvNTQ5cVlvUWh0MGRKVEJRUXl1Y2pwZjE4RVErRTF1OU4yaVN6'
    b'V292Y0tQT1VyUXVCL2V6RGVVRkNBRERXcVVBYVF1djNhUFpPCnBEL09QUU1BR2FmKzFmaVNL'
    b'Z0VBVUk4UzNUeG8xZy9lUER4bnYyeSt0ZmhYbWwzRFY2a1hqdGZ2Y1Q3Vk92ZFVqcjY3cXFi'
    b'ays1TDQKaEhuOVFCWENBUnE1alppM0NxSk4wRzc2dzdIZnV4eTg0Q3g4dHhJNDA0R3pFRi9l'
    b'RG9Za3BEcFZuY2xBcE5ENnZZTktlMGxaYUFTUgpsdU1lbjVlWHRteXNES3lWdkpFaFVSS2Ry'
    b'VlpVa2xTZEVpYW85M3hSSEt4emJnSm1uQ1BLRVJ4czdvVWNmbGp0UGo1UTN1OHByemJICmYv'
    b'UnpHZE94cUhtckYzLzNreThmdjRvNFgrN21EMmZORjI5bDRwTC96SFR6ZkRFMmwzVXc5My92'
    b'OGtHWnE3a1hXdmpmZlBEbVp4YmIKQ1dKOXZ6Z0VnQURnOUVqakgwOWYvL1Q0emhkTzEzV0hy'
    b'RFcxMjF0T3hJMWZlVksvZjZCTGRlZWpNN1hIeG5TbkVSc1VHb3NqM1NzbApaYm1UdjczWkY0'
    b'K3VmbWI0NXRNalpSUUVXMmJpOWo0VkZQemJSNjh2SkRzWGF5a09LTFQrd1haUi9JbnNUazZq'
    b'b2dpUGp6Wk9wQnRqClN1ZS8vMnJOYmxrVFE5Z1ArR3NieWMxZUhBTi9ibnJuRStON3RUbzF6'
    b'ZmwwZkR5VGFnb2tKZ24zcFRTUTVKYmp5bTlVY3JkMUhzdDMKUzJYMnNaUE9aMCtaUnNOZTAx'
    b'T3pXdnQwZXZmUjRlYnhFZnZ0VGJVWlJNTisvWU5rU21sOTZjaktjNTlTQUlCenVMRHNLVEtj'
    b'UEM2TApJbnpqeit4Q0hoTTFVcmRWd2UxdTN2SUsrYm54VVJRRWM2bGtnVklxRUFJQWhuRzUz'
    b'akwzS3B0S2pPODVhaUloV0pWMlF4NTRlbWovCjFBUHl4aTVyNldnZ1RiTXBiRnE4MXFULzli'
    b'WGNkeXVId243OWcrU1QrYlg1YVJLTDRuSWxxTFhvK0FoNTlRMXZjb3lhcHFoR1R6WDEKSnVw'
    b'WUdHTWk1azgvZGpTdTNlbmpQU2ZvdVZZdW9TVWppOGtCbUQ3MHlINXBxUkRzTnBwNkxLRk1S'
    b'YkhQcy9tc2VXdlR6OFRSM0xSQQpDS0FtVXhSaE1kUDZpd3BqL1R6VjBkL1c1MlBOWXhOQlBp'
    b'ZTZIanUvNU8yVmcwT3owZW41anhRcjYzc1ZkdlRFMFovb2YvbTdTNy8vCjJ2bHNSUDNVOFVP'
    b'NVpPeDJzemM1ZnovQS9iUHZ0SUhRYkZTZlAvT1daVXFpNEFna1FCaU9IcFpjbHk5T3U4L1d0'
    b'MStzVFlYV1B4Z08KeFJxUG41SVZHVXA3ZEsrS1V0bWgrT0RKL09CSXJlVE5MNDZLRWZqcnNx'
    b'NlhMdDU0OGZwbVZwWDJkZjNMdjNBNkZubWY2eWtHeGdaawo1YjU2ZGM5eDJKblhiMnBSVGpD'
    b'TWp3b3pVMlRxY2gwZ3RQN0JwQ1RzUTNPVzQ3TFgzazVLcFBmQTZZZEdaaGJlR2N2TnpiOVRZ'
    b'ZTlzCmZJY2ZYRnovdzljdTkyemJRMmlVK3R1ZDFvbnM0UHQrUlc1aU9qY3hEUWlPUHZMSTh0'
    b'bFg2ODNpMG9wL2VCYkZFaElHenZvMmsrOWoKNnlmaWxjZm1uVnlHekoxWXlJOU5Dd0w1c1lQ'
    b'aWZlR2NYNjgxaTdySktDZXE2dnQwWWxnVEkrKy83YnU3RWlQU0k1OThabU41YVg1YwpxNjVm'
    b'K3ZYUCtNOXYxYTRaL1hwV3ZvOUhiZzlscTAvTVc3WURwYjNleU1JaFFVSkVoRHNod1h0Vy95'
    b'cit3emZPZm1lcDJMVmRUaW5DClJKVEZtOXY3VHVBZW1jdTk3L1kvdXAvczZHQThFKy9zck15'
    b'T3M3V1N2RlJOaG5YOTUwMWE4UVFCYkp1NXRpMUhFVUkvdmFJRHdPZWUKbnYyZloxWVJ3Z2hq'
    b'UmdQWHRKWXM2N2YrNFVPQ2l2NjZqdVJIV2ZyK3kxUERYck9GMDdMVHYwWFh4OE1QemVzVTh1'
    b'VENGWm83L0NBVwpGU1RJZDRLOGJ5aUE1WGcwK3RuVGM1eFJBR0NVdGp6NnNhT0RzcXErNTgv'
    b'ZkNRVUpDaUx2Q1labDArS0d3V0xjRHExL0FOd3dNOXU3CndST1BDS1hWRzBEa0h3bmxuUkIr'
    b'TE9RL2ZuN2wyYTgrLzlKYVhZeEVNQ0hBK1ZCTVhDNzFYcjlTK1RHN2lDanZlK2pNUFhMNits'
    b'WjAKYkZSSUN3WUdGcmJ3UDI5ZWJzMDhWK3FsUmJ1MDNVU0NjdnZEdFUzYUNkSnh4Y2xyZGtR'
    b'T0JBRUhBZk04Q2xqZ2pENXljbDcrMWdYRAp0RGxqakZJaWlyb1BmdGU1dExyLzlNT0g4cm5F'
    b'MzlURUl3Q0E2c2IyQXd0V3U0UDNJTmUvRXpYOWFwMGc5dm5KVzgyS003ZUlqMmZHCldqcmNL'
    b'b2tHREpMb3FCQ1RXd0Q3alo3djJnTG1rcUtLc3VwNWpOSEFOL2QvK1JQci8vbWJQMkFjQURo'
    b'QzRMaUJDYkM4V1NzMm5JSEIKT3ptNTQ5TFZqVUIzRXBoMlB2U0E4bTdTY092cXBxM1JzUkg4'
    b'cmRYaGNMeitjMkptMGg4YkNqam5pWEx0bjMrc1ZhbEN1Y3JhUkxITAo5Mk5aa1FBZzREeHdB'
    b'RUFHVVpJRkFBQUtnUlVneG9vN3QzWkxteSsrdVo3V3RGYlBvQndBSXhkQVE2QXF5dVJvQVJF'
    b'WkFLcFZ1MVFWCksrMTRORFdKWkdDY3ZYSnU2ZUZGTVJhVEFXQjBNaDlVOTcvN1BmdmpRMXQv'
    b'd3VZS285Z3doTTBpL3BGSnY5RDZYVVVTWVdIV3JWUmEKd09IMG1HbFpQSzZoL1FxVnRBWjR3'
    b'RHpuemdqN0p4eWN1L2pxMTE3K1g2cWtkczJ1RzdnY09NSVlPQVN1YTJ0YXh5TnZMbnVGakt6'
    b'cgpISkZoVElTSUROeDZKMS9Ed3NLcmIrNW1rNTJGdzFwZ3RHdDFlbUpCUER4blp5L3N2RmlM'
    b'RmlZaWlVUmk2U29KeCtzL0V4SUp5S2E2CmpNRmVxUmxFazJQRVNhaHM2UnJPUC94RlRGTGdC'
    b'K0FINEFYdkxOd0pIL3hBa3lOV1QyL3F6WHF6d2lrRERpeWdtQkJDQk03NVlDUlgKcVRtMW1q'
    b'T2VQNFFvKzRrOUJDS08rbTU2YzRPVlZzNVc5aHF6MDBKRVJiczkrZXlXYjl0ZU5zM3JMZFh6'
    b'VVZqWDd6NTZsMXVXSjhzQwpwYlRTODFkNjlQRFQ4RHYvV3ZtamwxZjBiaFFUMUc3WFhjZUt4'
    b'OU1BZ0RFR1FBUDVzVjZ2clNpUm50NThZLzJDNy9wcU9tMTNPcHhTClFJajZIakErcnVVYVRu'
    b'ZnI2aHUvOWNsZksyMnRnZ0FkcDhNeDgxeFhrSVdtMjNTb201QVNJaE9Bb0VqK0NjMXBqQXo1'
    b'NTFmNEs3Vm8KcjlkTXBVaWwzQ3BrdFhWVER1djYzU1NWWUdQRFFUWUROSEE2N1haWE4xT1p6'
    b'QzhlZGgrL0g1a0dQN2RLeW9EVzlKdGQzaldSMlF5YQpMck5xWHJVVk5QZGEyNXpSdkp6VkpQ'
    b'WCs0Y01YZDFjczJ5U2l3Q2pER0ltUlNPQjVYZGRNaU1wVVByL2F2SEdydTlHVnUxM1NiWnIx'
    b'CkhoZ3RzMkcwMnFBUW85YzJaYmZkcUl6eGkxLzVSMTZ2eDAyRFhpcWg5WnFGTWFhVVJXTHBX'
    b'a01JNi9wZDdkRWx4TnhidVVJS0liNVIKdFNqbE02ejc3QVArMmZPZUpNR0F1UEg2R3BOR2N5'
    b'NXlpQ2dFdHRmMjZzd0x4TGpLT1creTFrYjNwb2JWOVdMSkY3a2dTN2JlNVl4eApCSUhqcUxH'
    b'SWhJVzZhelNianN4aFptaUFObnBJVXdMRHhTSkJBc1lpUVFnQndXNmxvOFlFcjlMWTNNR1Q0'
    b'OEpiVy9LWm14M1RkQm5qCmcwTVoxNVZtSnRubURtWXNyT3QzaVdRQ1pxWndxZGlRWmRIb09a'
    b'aGdPWjdqeGNiSkk4THlpdDkxeUo0NmdoU1ppSUt2VzV4eE1SNmgKbG9zQWtZZ2M5T3hlby9Q'
    b'Qzh0SjJzKzVUeGlsRkNDTUVDR0hPT1Fzb0ppZ3FDU09SeUlNbjdrdW00MWdVQUNIbWVDQVFK'
    b'R0JxK3dCQQpaSUZhWHBUWUp4T1ZyUjI2dlJzTXBiakw0MHU3eHVoWUxwMk9SUlZ6YWtLc3R3'
    b'VExScUgxdTRQam9ObkpBQ0VvNzdkak1ZWEQ4Qk5xCmFTTGhkTHJzMExTNHMrMmtFOHFlcVNC'
    b'SjRBSDFtejNxZUVKVUFZUjR3QUxkVXJLYTJ6TU1QM0F0MjdOTVJnTUVpSE11eUZJeXFxYXkK'
    b'YWVLeXVtbEt1aDJOUnZ5T0tTWlVyMlZZV3pYYWRZQXhCTUFwNTVSNUlBL1J5c3c0c214K3BS'
    b'cjUxcmFhVHFucHRGYXI2N2J0SmhLUgpWa2Z1R3FIMXV3UmpvTVdJcWppQ2dBbkJMVjFSTzgy'
    b'dUlFWjRNRklnblM2TEloUHE5WW9WZGFzNjh5bG56S3QzQWVOQXQ3RXNYbHhkCkwzWjAxM1lR'
    b'UmdDQU1jR0NBTUNKS0RvKzdSbUdBMXpnSEhPSWVJZ25JcTd0TTBBNEtuTUUxUFlEbjFKUlVG'
    b'bFB0UFVCYUdleXdyVzEKWUMvQVozZlEwSEM4Vm0xMzJxYXFTaE1UK1hxVHRQVSttTERybXdS'
    b'a1pZMTg1UEZNcDlkcnRsRzdiUys3Ym5Oc1dHdlVDcnMrcFRBegp4cTVCWEIwVUZSckhLazV3'
    b'c1VzQ1FBQWdBUWVwalFTVFNsRkJJRVJ2ZVF3UVVBb1lBWUFnU1lIcktJZ21zeXFYVU9hcEZD'
    b'TDRuZm9BCklvRHk3ajh3YjFpUjY5dEg1c1ROS3Y3VHVyelRZNW9XdHl4V3EzVXdKaGpqV3Ew'
    b'cktka3doNytiUkZRQXdJTjVxZGxSZERPUllIdFoKcmZCUFRqVWNoMCtPQytVcTNjRUpMNThp'
    b'TW40ME5mbmxUMzUrZld1cnhXMkVFTUpvWkNvOXZ6ZzhNcFpxVk0xZTF3RUFoSEdNNEZ4Twpw'
    b'WXdxaW93RmZQL3A4YWxqZ3dnamhPQjIvSGo5Y054ZmY4SmUzd3BpRWlVdGRzTVI3VUIyL1VS'
    b'aElEbzhIRThtWXFLU0tSYUpZYUd3CnJ0K2xZNVB3UjA3cWxtRXhLczVOb3VGQmJlY1ZxYTRM'
    b'QzNQaUgvNXYvK29OOTNPZlVJdE43S29FQUJpbk81c2JHVUU4SkdVZUh6KysKVXRtNmJPOXl4'
    b'aTlkMmd0Y1R4V3hJQXVEWXluMi9TdUxuMzBxMWpNZHlxN1cvTzBiOVFlSDQxaDRiL3ZNNzB6'
    b'eTVRUTBPRUFvaFpWVgo3N0VIWXYvdFc0ZE4yb3dsTXJocmpZd1B4cU44YllOVUd2MXhQcVkv'
    b'ckd0UlNNVGxyYzM5d0tleG1DSXJabXc2azFXTi8vaVNYRTZPCnAwbm4vRklsc1BhbDNLanJr'
    b'S3JmZXd0dHRhazdwdzFvbkJ5T0Rkd01TaUNnWi83MmdtMzRMS0RScE1JQi92TE1Ta3lUdEhv'
    b'M2VtN3oKT1BHU3g2YlI1UjNaUnpUdzNXTkRwQkMvTTdmTEFRQU9FWE43TjFpNkZ1aERoUmRh'
    b'U1RtcGpHZGdaS1JkcjlGdXE2eTNvSkNOcmQzSwpoTmJ2R3FZRm5vOG1KdkkzMXZZOEw0aEVG'
    b'VzBndG4xaGQ2M2xGd3FHMHh3OE9sdnhkSGVoZkxOMDVKanJPdGVETFRsSDlFcGJHcHdxClhk'
    b'dFJSMFhGRlQ2VVhjeE5wMTdidVZnU1d3RGdlSDRzcWFDOGFtVkZaY3VZM0tJQVZMZDZIYU9E'
    b'a2E5T0xyN25zTE42anc5M3o1LzMKOVd6dWo4NDJ4aWV3RmdrNGQwdWx4dlpXaFJBaWlHUjZl'
    b'cENRTktWOTBNTDNSNHZrQitpTnQ0WDlxcGpOSlNsam51dkhOY1YwTFVHSwpsVnVUZXB1cVVi'
    b'UzVHMFI2M1l4ZVo0ajd3UFN1cjBmNGJtMGZ4K1dJU2dhRUdHMGFxOHZYMHA0Y1VZa3NJSmx5'
    b'NHJqSlJ5WkgvK1d6ClNqcGVyTzgxdTYyNjNrakdFaGg0UkJYZWpaemJlY0pheTJoOHM4aEsw'
    b'U0hmRHlSSnNpMlhCcnpkTWp5WENnSVpHY2xHMUJqdWs1bjQKdnNuaG15MmgyVW9jUGF4T1RW'
    b'bU5GcjYyVkdOZ05lcnpUODNVSmlJNzhTajYySWNWVXhBVG51a3FNVE1XcFl3YnNubEYzaFN5'
    b'S0FMRQpWTXpXalhhbjNiRTFycXBrOStKdURKSFNoZUxnc1FJQUNCTUpoamlhSFl3Ynp1NFBW'
    b'Mk0xcHFwM3pxRUZadVN0czcyaG1CeFJjTkRCCkR6dzRXNjZBSU9LZTBXNDJlNGlnbVpuQnFj'
    b'bkJQMzFlb24xeWNVM2YzT2VHTVV4UDBreUNMNjhLdGcyaUNBOGU5UVhSL1pYczllR2sKWDYw'
    b'enorTlBucGJiT2l2WCtXNWlsRDU4NUhZZVRpbjNQT1phd1NuM2NDb1NPNzl6aFI0REFLQk93'
    b'SHdxYWpJSDJQb3ZyK1ovOFZoMApKS212bGExeUozMW9SQjdVQUVCcHR3YUw2ODFiblk4L0tk'
    b'WnEvbENCdkhRTy9hZS9ITHhVcm1leXlVUmNGRVYvY0NDU1NzVUNMdjd3Cm5ORHVvTkQ2WFVN'
    b'VTRmRlRnZTgyVE5OTnA1TzN0cU5qdzN5b0FCaWhpY2FOS2JVN25LS0xSNlJPRHlJeVJ3aDI5'
    b'dGlOMUF3K2VValgKdldiYnN5M3FlbFJBa0pPbHdtd1UvZFNHbUFNSFNGV0tjK1ZyM1U0QUFL'
    b'S0lrbkhNT0h6alpmaEdQZEV4cklXRnNYUktNMjNXMVhWSgp4Tmxjb3RFaVoxNFh3aGIrcmpF'
    b'NXhseXJWdHByR29ZZGlVZ1pyZDNyeFZvUzl0eGd3NDZyVVdJWEcva3NQWE5EcVpQVVJ3dmxa'
    b'QlMwCjNTSi9kQ0ZTaUF3V0l1ODdFbnV2NVovSUpPcTlnWnNyY2hKV2J2RnptNUV2L1MwM29Q'
    b'ektMWDZ0Slcxc1YxT3BxR1U2MlV5OFdxNDIKbTczUnNhenZCN20wZ0RHRVoxL3U0bmdkaGd1'
    b'ZVpibUtJdS91MUhxR28zZXNSc01FSG5EZ0t6c081a1J2MDJWaHBpMm5PbHZHa1RIUAo3UG5l'
    b'WmkyUklOQzFncVZia2ZsaFNjVGk3UkN3OE83eWUwTlpXUXNNMzM3anVubCtmU1RoT3k1L2VT'
    b'UFJuSmxkdWxKZldtZi9welh6CnlvMDl6am5HT0p1Tlc3WnovWHBSbHNYQXA2N25Dd0p1NlhK'
    b'NDl1VXVqdHpRb1ZrNWs1RXJsYmJuK25ySDVBdzZabzR5Ti9EY3V1NjEKbE1JVzF0SkRtV1Bk'
    b'RzNuU3pTV2gzZ0Z1dW55djZ0d29EMElIbDZxNDNiVXNpQTNIUmVrZDk3ZE5nMjVhbHpaaWU3'
    b'dkMwa3Fpc1c4MgozZkwxNXVLbzF6T1lGc09HaVhReDl1WWVmZmw2cDlYcnliS294U09KWktS'
    b'Ujd6YnEzVmFyWjVpT0lCRGI5aVJSWUtDMTJxSDF1NWpECnQzbFNvMXFVQkN5cWFqTkVIaE9s'
    b'YUx1YjFMczJOenFXTnp4M0tLTEt3dG82bW84MDRqSDBlaWxmcWZuM1R3YlRJeWlYUmxIdVJI'
    b'cnQKVkhPdmU3VWtKNk9pS2ptclJYVXdpVisvZ0Y2L3NKaHF5bnJuMkFSelBkN2I3eFdTOU8w'
    b'cmRMZ2c5QXlLWmZHcWthWkV5R1JUbFYzRwpnYmswMVdpQ3FoSzlxd2NCQlFCQklKbHNmSGdv'
    b'dTN4ZDl2dmhNZk45OXF5S1hJYmZOODhJdEd1MXp2WldOWmxLVUR4blZ0dXo4KzdjCndwRHZC'
    b'VHRGVTk4bEtXUmRibVgreDBmUEYzSjR1eGhZRm56a2Naa0RVaFdRWlZScDhOVWlQall2dm5F'
    b'VkRjdTl1V25SODNoaGdQeloKODFhdFFXY25SZFBpYlZmOFptbmg0ZUgyK1Y1T2luWUxBNmxL'
    b'dFhQcHpTMWJPRFE3clV5TUNUVHcxUWhwMVZ2dHRxSEZWZGVQR1U1aQpmYk0vNWovNjZXckpR'
    b'cDQvK29EbDJIcXAxSEFjTHdpWWFWcUZQSjFaeUkrTnh4RkNyaHZZdGxHenM2djFlQURDNlVJ'
    b'dHFWSXRLZjcrCnhaRjAwQndhSUowdWIzVllwVUlKcFZldlduT0ROQkpCQURBeEpseFk4aWps'
    b'NlJUZTNLR1Q0OEo2US8zNnpjbnplOGw4cmxldFZNY24KOHV2cjVZSFIyV1JTbmhoMlNydjd0'
    b'VnFEQlVFMHFnckswRTRwdXI0ZDdZdTJ2Uit0QTlCNnRkb3hUZHUyUE5mMWJjZk5adVBsdmNy'
    b'dQpUcTNic3lobDFVcDc0WEJxWTVzQXdKbGlZYldzbkYyUC90SkRkZWI2K1F3WkdTTGJ1OEdS'
    b'dzJMZ1F4QndoTkRNbExoOHpSc2JFWGIzCnFFQmdxeXd3U2Q1c3FuOXdjOTcwUlVDUTBzcU83'
    b'VWlpTUQ0eHNGMkV1TnE0ZEdtOVd1MzB1bFo1djcyOVhaMmNpSHArdE5ucHAvdGcKK3NtNllh'
    b'SHBTV0paaGl5SmtpVDZBVTJsWXB4eHgvRVdUMHdORFdVTXcxNWJLMXFHSVluRWRvQWh1ZXpF'
    b'eGpQK2h3YktrU2gyUFo1TgprKzNkZ0RFZ0FqeTRLRzl1QjNxWEV3TFZKaWd5YnZmZ2pYTCtk'
    b'MWVPL2JBeWFQb2lCbWN3dFZYZTMvZjlnREhXMGYxR3ZXbFp2dS9aCnZoOHd4a1dSeEdKcUto'
    b'WHpnbmlqMVU5UE1PaXpmajJpd3NsanV0VnJFd0VMaE95WFc1NFhSQ0x5UUQ3Wk52S201Y1dq'
    b'bmlTNld4dmIKZHMrUnJWUkh1dzhRbWRhNkxVZDhkcVEwckxrRHN2SGtDZTc1M0hINTRBRFoy'
    b'RVBmUDhkLzBKNjJxVmkyb2k2SUFDQXdLNk5mVTBmRgptdGtEZ0VJaGxjbkVnYWhiNjl2ZHJx'
    b'VnBTcnR0cEROYVJGWDhJSWhHRkM3TWJlejAwelhtZlhiSGsyWERteGNTQTNuTmRlRFlmSHQ0'
    b'Ck9GT3JkU0txSEl2SExxOEpoNlpwTHNVcUZVUFh6V2hVamFYaTRzNVpJenE3QVFYSmQxKzRx'
    b'a2t1UkJtODhHbzNGd3VJZ0F3WGJyYTAKQmxkN01UR1E0NEF3cG41V3Y5d1R1NlkyNGdSdU9o'
    b'MGpoR2p4V0dFdzlmYjVtNjEyRHpqUFp1T2NjMFdXWkVVOFBqL3BCWkV6UHlUOQpWWXo5ZDNk'
    b'alFHR3ZqQUZnZlRjNU11Um5jNXJyd2VVVjllRVR2dSsxMWpkYWdrQW1Kd3VVc1doaWVML0lU'
    b'eFV2enpQMDBFRG0xQmQrCnlYNys1Znh6ZjY5M2NWa1pId24wSGlCRVRWT0l4ZmJPWGR4RzNT'
    b'TEZyMnpmV2xPazZQVHBUSHozNW8wNnArcnh4ZG5kY3BwdWJWcVcKaHhGaW5NY1QwY21wd1Vx'
    b'NUZVOUVMRnY0NFZ2RTc3ZVhndlh4bmN5N2UyUjNqMGlHdnRBcFBpenhSVjJibko2SWowNTBk'
    b'a3V0Wm9NTwpENzU1YlZVcmIvME9sd1ovOVI5UXkwb09EOUZjaGdjQnMrem1YM3hQR2h5SW5U'
    b'akdISWU1N3V3WFBwLzQrcmRQSmhPUFg3MzZYY3M0CjU2NUUxbnBIUUlqMUF1MzFqV1Jqa3li'
    b'RW5LYVNFK05yNVNvQ3RMeWFNSzFZeXNTVkd2TDgvaXU2L242MjVNam1ENzZLNEtOZitWY2sK'
    b'Rm1HMjQ3YzdZaXBwYit3SXlYajB2bm5tT0sxbTg2WGYvbmVhcHJtSy9OMmVaUkpjVWRJQUFz'
    b'RWk1YmV2ZjBCcHZ4MzNyTk95b0hhTgphVTdXTk9udi84WS9KWUpnWEY2UkJ2TGFnOGZsMGVI'
    b'bWQxNVVaNmN1ZnVlRlB5bVd6azlQM2Fvbm9aL3AyN3JPQXVDMGs1MnZseTR4Cng2bDkvNVdT'
    b'YlhVTGFkYzJFNGhZVi9UcGVsVzR2cTZLMGhYcXhuVmY2K0ttSUt3UHpLU052WlkycmNkbUFJ'
    b'QlFNNk5mYmlzbzJWRlAKdCtzYzBKOHorN2UvK0c4aVl5UE1kYjM5aWp3MXZ2MzFiM1BiVVFL'
    b'cW4zMTc4YmxQVi8vZ2E5L2U5a0R4QUdIQS9WcDZmVlhYT1UzcwpYeHB4ZTRReno3ZFNZbFNn'
    b'YnNicERSQlNZT2ovU2tyd3VhZUdDajRBY01ZOXc5MTZ1MGYzdXRuQVRiTWdSdjBTRWQ2YWVJ'
    b'd0VuWHhuCldhVFVsRE5ScDlhS3p4bVJpWWR1ZmU4MDVZNGdvb0dNcHhoZEFsWlUwZ1ZrU2lT'
    b'QVZIR2RaWnZyditHWUZKTkwxSE5FcFNaRmJPcTEKRU5hSVpETzZOZklnbGVPaDlaK0ZjcTVV'
    b'bDBmTnBpYkhtRytManE0UUtjL28wMEZRNFJRRG1KeC9JenNSLy9EOTZTU3JOL0YyRVR2dQor'
    b'KzlKY2N1cWVVWHpBaU15MFlxLzU1bndtTUJBaGcwUFFrUjFBY2lORFZTdGk0aDZqMTcvOHlj'
    b'QlJ3R0xnRFlFNFFhQWhUampuS2daClBiRDJCS2s3Y2dvRUpiVCtNeEVQdmlXNVBjM3R1a3Jj'
    b'VUZQRXR6V2ptdlR0TkEwUVp6ZXlNNGI2Tjcra2k2ZDZxN0xiYUNXT0JFU2EKTDUxdHhsTFY5'
    b'TW1mZHYwZ245eTdNT0I3dWh5dHk3RjJKRXVsR0dJMDM5NDA1WmdoYVNERitxdTFQMWh2QUhs'
    b'Zm8rK1V3MEZDZ0lQTwpRWHdIRElhUTBIcElhRDBrdEI0U1dnOEpyWWVFMWtOQzZ5R2g5WkRR'
    b'ZWtob1BTUzBIaEphRHdtdGgvei84UDhBSnplbVlxV1ZQUFFBCkFBQWxkRVZZZEdSaGRHVTZZ'
    b'M0psWVhSbEFESXdNak10TURJdE1qWlVNVGM2TlRZNk5ERXJNREE2TURCNDlRb0ZBQUFBSlhS'
    b'RldIUmsKWVhSbE9tMXZaR2xtZVFBeU1ESXpMVEF5TFRJMlZERTNPalUyT2pReEt6QXdPakF3'
    b'Q2FpeXVRQUFBQUJKUlU1RXJrSmdnZz09CiIKICAgICAgIGlkPSJpbWFnZTE2MjI1IiAvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'US_VT')

US_VT = b64_US_VT
index.append("US_VT")
index.append("United States of America Vermont")
catalog["US_VT"] = US_VT
catalog["United States of America Vermont"] = US_VT
country["United States of America Vermont"] = ('US_VT', '', 1)
lookup["US_VT"] = ('US_VT', '', 'United States of America Vermont', 1)
lookup["Montpelier United States of America Vermont"] = ('US_VT', '', 'United States of America Vermont', 1)
lookup["United States of America Vermont"] = ('US_VT', '', 'United States of America Vermont', 1)
details["US_VT"] = {"continent":"Americas","capital":"Montpelier","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_VT"] = ('US_VT', 'United States of America Vermont', 1)
regional["United States of America Vermont"] = ('US_VT', 'United States of America Vermont', 1)
#----------------------------------------------------------------------
b64_US_WA = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjUxNyIKICAgd2lkdGg9'
    b'IjE2OCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNjggMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1dhc2hpbmd0b24uc3ZnLnBuZyIKICAgeG1sbnM6aW5r'
    b'c2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAg'
    b'IHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9z'
    b'b2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkv'
    b'eGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6'
    b'c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVm'
    b'czE2NTIxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTY1'
    b'MTkiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2'
    b'IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIy'
    b'IgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNo'
    b'ZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIi'
    b'CiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTY1MjMiPgogICAgPGlt'
    b'YWdlCiAgICAgICB3aWR0aD0iMTY4IgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVz'
    b'ZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpv'
    b'cHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNl'
    b'NjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUtnQUFBQmtDQUlBQUFDZEErd3NBQUFBQkdk'
    b'QlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFB'
    b'QU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFmCjcwbEVR'
    b'VlI0MnUyZGQzeFVSZGZIejl5NnZXUjNVMGxJSVFtaGhZUWVlaEZCQkVFRUZCU1JJZ2lpdm9E'
    b'Q0kzWUVCUlZSVVJRRUVVVXMKRkVHa2lTQVFoSkNFVU5JSTZUM1pKTnYzN3Q3Ni9oRWVFQjVB'
    b'ZWNyN0pqejMrMWMrZTNmbTVzNXY1OHlaTTJmbUluaHpFc2o4OTRISgpUU0FMTHlNTEx5TUxM'
    b'eU1MTHlNTEx5TUxMeU1MTHlNTEx5TUxMeU1MTHlNTEx5TUxMeU1MTHlNTEwvT2ZoUGd2ZWxa'
    b'T2dFWVgyRHpnClpZSGpnZVVCQUJRVVVEaW9hVERyd0tBQ2hHVGg3d3FhM0ZCY0Q4VjFVTkVJ'
    b'ZGk5STBtMGJBd09MSGlJdEVCTUlrWUdnSUdYaFd4c3UKQnM2WFExWUoxRGtBZ0ZTUnNSMDFI'
    b'V0kwM2RwaGZlTWhRSWRwVkVpbndRUkJjbm9rcDFzc3QwcXArZEs1UWlHM3dGK2RkbGs2VlFB'
    b'NApCckhCa0JRSjhXRkEzSVVESXJyYlVxOXE3WEFzRjNJcVFaUk00ZXFKOTJtbURjRzdKVkE0'
    b'ZnUwcmdnQk9qK2h3aWNGbVhFRWpQeXZSCjFEVUw3L2FLQjlLNHp3L3lSNC9ZV1E4SFNncDZ4'
    b'MEpLSENncFdmZ1dTYjBERGw2QWdtcU13TzhkYVh6dFVicG54eXUybXVPbG4zNWoKSkFtMGFr'
    b'U1RLS2VRMjMzRSs4eWpPb1NnZnpmNm1SVk5YeXczaXlLcytjcVpHRTkxYkVjR20zRUFZRG5w'
    b'bThQKzVWdVl3Z3NPb0FubwpIUXNET3dCMWw5aElISVowYXZVUHdmSncrQ0xzUElNN1BaTW1X'
    b'bjc1eURoN3RDSXM4Rm9mUDVIcDE2clI4QlJsalZXd0JPQkRleXVPCm5QRXRucUVuY0pSMjBW'
    b'OVJ3L2RMVmhSWDh2R1I1TnB0cnFndzR1Qkp4dTZVUWl4NHp3N2tNdzhwaC9SVlo1Umk5YjlY'
    b'UUZZWkdGUVEKcUplbmN5MkE4a2I0OEFDY3lPL2EyMWl5UDJ6YlVwV2ZsZEt6L1gvOFNvOU85'
    b'TFo5bnRIejZyWWY4aVpFa3pTRm1wMzMwRUE4STVzMQo2TEFEcVV5SEdESStpaFFFcVcrU0lq'
    b'R2UrdUdnNTBBcTgrSFh6dG9HWVVCWDh1SVgrajNyUTQwYWdHMi93OVpVWUZoWitQOC9KSURV'
    b'CmZOaDRSQW44OWs5Q3M5WnJLVUw2ZUpzcnI1aEx2OGorMFg5WEtkRDRlOVEvcnd1S0NTY1lu'
    b'eVNLNEdXa3FqcGgyYWYyR2VNMUN4N1gKN3pucUJZQ3lhajR5akVBSU9zZFMrU1djbjRWbUo2'
    b'QzVrdEY5cWRwOWxsblRBK0ZTTlh4OEVNb2JaVlAvLzRFZ3d2YlRjTEtnZlpMKwp3cGFBNUhq'
    b'UzdoTGRYbW5kdDY3RTlsUm9JR0V5WUZkZE5vUmd3M1lYeTRGT2czV0twWm9jWXFkWVNxZkJl'
    b'blNpTlNyTTVoU0R6YmpKCmdIK3h5NjJrVWQ5a3hZNUQzc1I0cXJDY256VkJxMVplNnhzNGpr'
    b'YW5rTDJTVlRzUGVmalRSV0JVUTdCQmR1Nytid2YxYjA1Q1llM2oKajFrMnZhRDIrc1I1Ynph'
    b'OU5Gc2YyNWI4K1Jpei9aQm4zRENWeXlPTkdxZzBhSzh6YVN3bkZaVHlaeTc2R3B6STZzQW9R'
    b'Z3d4U2xGaApSSmQ0TWp5WUFBQS9LOW1jNHFKM21wYk9OcGdOV0U0Uk42aUg0aVorWkpQUWJZ'
    b'YTk4cklMUm5hRmxIaForUDhyMVRjZmc0ckd4YzhHCnZqMUxtWm5EUm9UZ29nVFByR2o2WnBV'
    b'RngySDhzL1V2UDJVNGt1YWJQRW9kYk1ZRkFiWWRaRFlmeE1vYktaYlFRbUNFMUxZTGJqRGoK'
    b'R3EzSWNZTFRqdGNWUW5VQk9PcTE0TzRWenkrWVRNZEhrWG5GM05hOTd1ZWYwT3YvOE5QNStp'
    b'ZDNSYTNRb3hNMXJJL1N3MGg5WnRzdQpaanBoV0djWTFFRVcvajl2NGJlbXd1V2FkMTRPWGpS'
    b'SjBXQVRYbHhqdjMrUVVrR2p3aksrdmtsNGVZN2g4eDJ1M29sMFlqeFZXY3ZQCmZsZk1xVmFn'
    b'eEdHNjBWT3BvTkEvOFJsRXdaTjFpdjNwRTBWVDZSUDNDczlPVnBIRXRmbjkxcjJlazFtK1Qx'
    b'NDJXWnVFckh4MmVJcVMKNDZVK1R6a3lmN2ZEMkI3UVBWcDI3djZUL0pnT0JUVUw1Z1V0bXFT'
    b'NFhNYXQzT2g4YVk3aGsyMnVBRDAyOXhGdGcwMDRtZVdiUFZFYgpiTVlIUGMzMi9wdTU5TUZQ'
    b'TFI4ZE5zOWM4cWVxQXdEQ2NFMjNmZ0d2ZmFOY2MyS0Q4NUdFS2V6Ym03MVhuY1NNSFArYUpR'
    b'RUFVRkxGCkYxZndvZ2dJUWVwYWZidE9XdGlUQWZuVnN2RC9NZEtMSUt0MDBrVHplMDhwU3ly'
    b'NXhhdHRmNXVsVjlEd3hYTHo4czhjV1huczhtZU4KQTdvcmxxemp1czhqclZQV2g3eTdVeFgv'
    b'ejdpdUNNTjFqenhuL0RoMVU5UFlUcE05NXkreEFOQ3JNNDBRVk5jTEMxWTJQWGlQeXVrUgpG'
    b'NjZ5S1dpVS9yblJGS3FFN2FmQjVwR0YvdzlRNTRCOVdXM2p0Vjh0VlVzU2JQN1J2WEtCOFlt'
    b'bERSU0pRaXo0dUtHcWhHaFNrcURiCmRQOFB2bkhCYTM5UnhmM0w0eTVDK3NlWFVNdjJqVjJ1'
    b'WGJISk8zNjQ2c2RmdmV0L2NHMTYwNHhqNkltbERXT0hxbjQ0NkRGb3NST2YKR25HUTROdmZR'
    b'UkRsNmR5L2UyamZmSXdTK1hOYlRVWWRqaEFZdEZoa0dObXJDLzMwbTAxQlpuenNVTlhsQ3JI'
    b'UFBCR2YrN0YrMkxoYgpyYTRTQ0hYU0tmb0ZLQ2VINlorTE5qMGNwdTlsVk1hb0tWR0NXajkv'
    b'ODU2aFZLbEdQSnArcE9DM2ZRV3Z6ZFlNN0tISXltT1h2Ry9yCkdFTlJKTHBjeHNlMUphUGJF'
    b'Rm9UZFhDUEZSQ0M2RURadWZ2M2NTSWZEcDVmKzJiSXZISDBEVmUyN2ZNTVQxRmVLaGZIdjBF'
    b'RUxkOUcKbW9OdThad3dObGo3UklRaGhMNHUyQzVKa3NmanFheXNMR2VsMDVSeGY0T1B2OFhT'
    b'TGJQekUwdm1GNzk4clBsdXY3ZGRCT0gyU3YyUwo2ZklhUHJidGxSV0I1Qm4yckhRbnpCOEJa'
    b'cTBzL0w4RHB4Zlc3STl0cnlyWUZuRFQ2NWZLaE1FTDhhQjNkaEs2bTRkVE1BU3Z0alBkClox'
    b'WklQZy92OHhJa0RRU0psQm9KWVR6UEV3UmhzOW1hNWNmQzJpNnJGZXB1MGZ1WkExK0ZuZjd3'
    b'd0lkYVhwRCs2UEEzVTFyTng0eXEKRVNNc01HMmdiT3IvSFJ3NGo2cWFmbHR2MGFpUUtBS0JY'
    b'OWZpYnEvVWE0NW9YdjR0R1dDK1ZRVXJJcFVEM0NWUVh3Yk9SdGJlSURvYQpjSGVUMUZpTmZH'
    b'Nk9aVW0xamlCSm85RW9TZEtuNzZ6ODI2RHVKaEsvNEVmLzJQSEpkb21OMWJienY1d2ZPNGor'
    b'eDdzWXRGZ0RTNTc1CnBRNGlMV0RVeU03ZHY0YUxnYXpTL29PTm5XS0lyWHZkRzdhN3ZMN3JG'
    b'Qm55TEsrZSt3NWxDYjVWQlErWnlNR2VNbHJrY0J4SENDa28KaWlMSksyYmViU2NheW9YeVBJ'
    b'SWdBQ0FzTEd6V3JGbTgxeE5lbHJNd0VMOXAwNmdtTHo1U0UvM2pFZStOTVFBSnltdjR0MmNw'
    b'YVEwSgp2K1hKWHYyL1BycGZBa0g4K0JtVnpTbUdCeE1tQTU1NjFuZjE0cXRmaUxYUkk3VmRl'
    b'OTJxdEo3MXo0RnFKSWtBd1BPQ0lBZzh6MS92CnVTUFIxZVNxTFBKNnZZSWdPQnlPSFR0Mm5E'
    b'cDFLZ256anc2Z2IxcW40Wld2RjMySzJaelhPZkJ2YlhCczJ1bFdLOUgwaHcxUVhOZnkKbDNC'
    b'YXR2QzhDRmtsWFhycU83VWpqcVQ1TnZ6ZzJuWFlxMVppb2dnQTRQU0lHL1pUZ1RNVzM2YUNh'
    b'YzVzaW1PdXVQUUVqdU00UXRjOQpzaWlLdkNDNDZtdWNUaWRCRUczYXRJbU5qUjAyYkpqZGJp'
    b'OWU4eHBabEhNVHQ0Z2cxRFBlbkxuc3lxeWQ1YVE1cnpjR20vRkpJOVdNClQxbytRNG1ST0tR'
    b'WHltUDh2MEJlSldTVnZyUEFrTmlPNkJCRFRocXAxcXF4ajc5eGx0WHcvWklWRHl3RjV1RzM2'
    b'TkR3VzVXbWZPN1IKanNLUUFEMUlraVJKR0lhSm9vaGZiOEpabnZkNG1XcWJHMmtNYXJVYUlS'
    b'UWJHeHNTRWxKZFhkMG1OUFR5M3UxVWdJVXgzamhEdzBPagpLdmJ2SDlMZXJWTmpFeGRZMjRZ'
    b'U2JZS0lkelk1REZvc0tZSGFmeDVWWlZtaFR4emdtTnpqL3lteXltZ05PWEVJN2ZOTG4zM3Yr'
    b'bmliCkt5bUIrbnlaZVdSL3BkMGxYcXpWYWJ2MnZFM3BwUHhUZW9wUUtSUWtTUklFd1hJOGhs'
    b'MzN2QnpISXdDYjArWGhoSjA3ZHdMQW1UTm4KS2lvcXpwMDd0MmZQbmc4KytFQncyTWFLalZo'
    b'VC9UOVdycGo3N25PckdRV05kcThOZkhLQ2R1dGV6enVMQWpxMkl3SGdoVWswc0R6awpWY21t'
    b'L3ArMTgwVzEvZnJyYUFwOXU5L1Rzek1kWk1MbUwyL2llYWxMSFBYa2FxU1p2T2oyRlFTTGpO'
    b'bGdFRVd4T2VHR0lvbG13ODRMCkFnQUlnaWhJSXN0eFByL2Z3Zmg2OXV5Wm41K2ZsSlJVV2xx'
    b'YWxwWVdFeE96YU5HaXVYUG5VcEtvZGpYZHhKeUV4VlR3SWVVMWZIRWwKUC9WdkRRL2RxeXF1'
    b'NUhiODRpMnY0Y2YwcHlnMUNaZGFkUFMrQmFjT1ZqUUNKMHdhUUFDQVhvTWxKVkJKQ2RTWXdh'
    b'b0RxY3lZd2FwVAp1Vmp3dkg2M0thMjVmSzVqZ05icDhmZ3IyYmpJaU9iaEhDSEU4N3lmWmMv'
    b'bFhXNncyUWYzNnFhaUtZZlRMUkZhbG1XenNyS0Nnb0k0Cmpnc0lDRkNyMVEwTkRXVmxaU0Vo'
    b'SWVnVytmWDQ4T252YjEzKy9pTGQ5aldXd0FBY0FFWVB1bktwUTJmTnVleDZrQUNRTFB5ZFVs'
    b'SUgKQ0VhblVBQ1FudTIzMm9UQlBSVkZGWHo3S0hMLzc1ellydC90ZHIxd2JPZlNDMkY5azJZ'
    b'dVdweGJXQm9URWJabDVhdGQ0dHZaWGU1SApuMzgxTXp1L2E0ZTQ4M21YTzhlMysrREY1eHFk'
    b'cm5KN25ZRVZRa05ERHg4K1BHYk1HTDFldjNyMTZzek16SlNVbEtTVXZzN29tLy9DClZJUEgv'
    b'ZkxNS2dEWThJTzdYUVFoaUdEUVlub3QxamVKSHQyWFBIZmFCbFpIaTgzTWJNR212ckpKSDZS'
    b'c3puUisvV2tEU2FDTk85d0IKZWl3dWt0eHdnTlRkTytFMlJkczBWTVJhQWlxcmE2eE45aDBm'
    b'dmZYYTB6UC81KzAxa2lSbDVWNDZuMy81cllWem41OHg1ZENtRDAwRwovWE52clZFckZTVHZi'
    b'N0phUlZHa2FicTR1RGc5UFQweE1YSEFnQUhUcGszTEtDaVd5RnRtMUl2NjRLbzZZYzRrN1lS'
    b'NzFTd25mYnZmClU5OG9BTUM0UGtUekk4aGovSjNUNElxSXVKTDJSQkxvaVhHYXR4Y1llM2Ft'
    b'QVNDM0RLbmp1OXltYUt6SHluRmNsNDRkbjM1MHd1WmQKUHk5KzkrT1hucHFPRUtxeE52VHMw'
    b'dEhuOS8rV2RuYkk0L1BNUm4yUFRoMWNidS9RSGwwOWpiVVdpOFZrTW1rMG1xbFRwODZhTmN0'
    b'bQpzNTA3ZDY1L1hCUzJhc0V0NzlTaDc0RlVCaUZZdnQ2Kzl6ZnZ5Z1hHY2NOVUFOQStpZ1NF'
    b'b01FbGovRjM3dG5aUFFsUk40L0NlaVNsCmxyamxmNjZwTFVzeGE2MjhPL05pN296eFk4WU9I'
    b'UmdhWkNaeEhBRENnNFBIM1ROdzhxamhvaVROZjNSQzJvV2NoSmlvbVBDd3FqcnIKMTk5dGow'
    b'dnFpV0ZZYlcxdGRuYjJ4bzBiaHcwYnhqQk1kWFYxVzdYQ2xuN0UwV1BJVFliNXZnOGUzTFp0'
    b'eG5nTUFINTRQL0RxNEtOVQpJRTBBN1c3QndyZlVIdS93Z0NoMWlickp2K2R3aXp4dHVFM1Jm'
    b'b1EvUUsvTHlNaG9janEwYW1WMGVLaUNvZ1JCa0NUcC9LV0MrTWkyClpkVTFCSTZiallZaHZi'
    b'cEZ0d2tWQk5ITk1BU0I3ZG05VzZGUTJPMTJobUVDQXdQTHk4c0hEUnFVa0pCZ05CcWpXY2RO'
    b'NzZXSWlDNnQKeHdBZ01aN2F0czl6cVlSYi9wbWpzSndEZ09Bd0dteHVXZmc3eE04RFFNZ2Y5'
    b'QzJ1NUZQUCtsaE9TczltSVN6dWxnRXBld09XbTdscQoxYXIwOVBUS3F1cm1tUnNBVUJRRkFJ'
    b'elBqK01vMEdScUR0YXFsRXFFa0ovalB0bTZ3K1p3c3h5WG1abHBNcGt3REZ1eVpJblJhTnkw'
    b'CmFkUGh3NGV0Vm12eDhWL1I1WXMzdlNNTFZ5SzdrMGFvMy83Y01XK3k5bElKRHdCYURRWStU'
    b'amIxZHlvOEJ3Qm0zYlVQb3NLSVBVZTgKTWVGa1pRT0c2d051R2EwVCtGN0p5WjkvOG5GQVFJ'
    b'RFQ1Zkg1L1NSQlNKS0VFRUlJelp3d3h1NTBxNVhYTXFaNW5zOHRMRDV6TWNmcgpZNHFLaXVM'
    b'aTRwWXVYUm9SRVJFZEhYM2d3SUhtMkQ2R1lZRmhiVUxDYjU1T0tRQUdBSUlBb2lUVldBV25X'
    b'MnkwQ3dDZ1ZXTndpK1ZkCnVjZmZHcFlIQUowS1ZkY0xxV2Q5MWZXQzNTVjJpaVZWQ21SMUlG'
    b'eDd5emtTWXdyKzhWeHVXRmlZMiszZWQraVFLQUVBZUgwK1FSUTUKanZlejNKNWZUeFNXVjE3'
    b'UlRCRGRYbDl1WVNtTzQwb0ZiVFFhT1k0TENnckt5OHY3K2VlZnZWNnYzKy9ITUF6RDhZREZx'
    b'MENodnJudwpFZzRBbmVQSVZSdWRiLzJQc2I1SkdOQmRBUUJhTmJweTlvTGM0KzhBSEFNQVB5'
    b'YzUzT0kzUDN0MGFzemhGb3NyK0o4K0NWUXJRTFQ3CmJsUDBmTGZoa2JVMWpYdDNLbWxLUVpF'
    b'SUlZNFh0dTdaOC9FMzI5Vks1Y0NleVNhRFhoQkVqdWM4ak0vRE1LSWtsbGJXQ0tLb1VxbU8K'
    b'SHo5ZVgxOS9mVmlYNi9UU2UzVEhicmZzT2tnQ1FBNlhOTHl2b2xNc1NSS293U1lBZ0orRmxy'
    b'eXh2cVVLVDVNQTBPaENnM3NRSDcxbwphdDdkbmx2RVVTUUtOUXBDZ2VNMlJVV2x1aXBsSkgz'
    b'eVdGVmhnWnZ4S1dqYXFOUE9mbmpjNCtOR0tXZ0tBUHdzNi9KNjFFcWxKSUhQCngrWVVGVk1r'
    b'VVdOdHJLbXBZUmltT2I0clNSSkprcDFIUHVDSmlGVU12djkyUDFFa0FHRFZWajRqbTMzcEE3'
    b'dkpnTEdjdEgxTm9OTXQKQWtYS3d0K3A4QVFBV0owU1JWNlpJVjBxNGVZdmIveDZwU1VoQ3Bm'
    b'MmxQN0pRQkVhcFhydm0xNlp2elhhblFFNmJlclo4MmN1NUJJNApMb3BTaU1VVVpBNklEQThq'
    b'Q1lMeCtidytYM1plRVk2VEJFbVdscGE2WEs3SXlFaVdaVGtNRDNsc0hqWnk0cCttenhFU0Iw'
    b'RDI3NllZClBVaTE1NmgzekdCVmZna0hBRzZ2Q0RRaEMzK0hhQlFBY0tsS0FnQmVrRlp2ZGg0'
    b'KzdkdjJyZ1VCeEVlUnFLbnlUeXRBR043WVkyaGgKeWNHMklZRXBYVHNMZ21ReTZDSkNneStW'
    b'bGdjYURUcTFpc1FKVVlKREo4K3dQTnRvc3pFTTQvVjYxV3AxVkZUVTc3Ly8zdUhoSi9DUgpF'
    b'Ly8wTG9MSGJWUnlBUEQrbDA2YVFqYW5HQlpJK0ZnSkFLeFdEclJxV2ZnN1JFV0RpcnBZTEFE'
    b'QXUxODRuVzV4M0ZBVjQ1T3E2d1ZMCkFFNkwzcjlZVFFsaGtDUVFCS0ZmdHk1MnB4dERLTDV0'
    b'aEU2akVrVVJBS3JyNjQra1pSU1VWZm81cnRtMmp4dzVzcW1wU1JSRmdtZWwKdjFBL2szYjR2'
    b'Z1FBZ0FlR3FQUmE3SElaZHpMTHA2QlJuMFM2cVlhQnJzR3k4SGVPV1ZkYzVnUFFMcG1wQndD'
    b'N1N6eWZ6K1lVY24yNgowbTFNZ3FPMmtnNXU4NmQxL0tpTEdWUlhGaFVZZ0FQb3RXcFJsQUNC'
    b'eStzRkNaeHViOXE1bkxNNWw1eHVEOGZ6SkVrKytPQ0RGRVZWClZWVnhITWM3SGZoZm1SUmw3'
    b'bjNnVVlYUEw2VmQ4RTkvVUJNVFRneFBVWHA5VW5rTkw3RGlkZk5SZVRyM1Z3blMxNVV6L3I5'
    b'M1BJTVcKVTlDb29Jd0RnT0ZKdlBQVTBiOVNoMHR2WG1GWG44b3ZKZ2tDSWFTZ0tSTEhtK3l1'
    b'bktLU2ZjZFBydHIwdGQzbDRuaWVwdWw3N3JrSApJVlJmWDE5V1ZnWUFCVWNQQ2o5cytITlRY'
    b'MVdZbkVEbkZuRU90emh0YWNQNFordW52OVRBY2xMcUJiNzVFZVFlZitkRVdvVDBvcFBuCi9i'
    b'MDcweDl0ZFU0ZnA4RnhtUGVJTml1UGZmNFJjdDJzSFREdXNiOVNUVkZZKzVmdGx0QlhscmMx'
    b'YW1ycnJSRWhRWmRLS3k1ZUtpd3AKcjJqK2dzbGs2dEtsaThGZ0FJQ1NraEpCRUFEQTQzWm5m'
    b'ZlJXWFBaWjNTdHJBYjk1NTJkcnE5cnEzRGl1TXhtd1pyTUVBTHVQZUFQMAoyTFlUUE9BWWhK'
    b'dGs0ZStjbUNCQXNPMjRNTGc3c2hqeDB4ZjhwOC83ZXlmU0Z3dTRwQVFxVE9Wa3JiVzN5YXB1'
    b'UnVMNWRqVUZLU1oxCnUvblB2dnJDOHhrWkdUZDhRYXZWZHUzYTFXdzI0empPODN4WldSbkhY'
    b'WXV6Rmh3OUdNWE9DbGkrQVdFMzBaN2R0dUw1UnlrQVdQYXAKL2FIaDZ1RXBTZ3lEQjRhb0FP'
    b'QlV1Z2NpVEMzNWlLd1diT28xQ2dqVTd6M0tJQVFZQm9kTytuS0x1UHBHTVNXSkJvQ2xVOFNH'
    b'alN2LwozRStvdkx6dGtmdUdoSm1UMnNlZk9ISGlzY2V1R1ltMmJkdjI3dDNiYURSYXJWYTFX'
    b'cTNUNmJLenMvK3hob3EwVk9mU0dTSjM0MmxICmtpREE1WXdodlJTU0JCKzlhT3JabWQ1K3lM'
    b'Tmx0L3RpQVZ0UXl0bXFHWWhwdVo0ZHRQU1RMYnRFMVA1eThVS0JybE1zMmJVOTFiVTkKbFhy'
    b'V2w1SE42alhZMlA3VTR2WG5lS2VOMEJsdlU0RlhnajE3OW1SbVpoNDZkT2owNmROYnRteEpU'
    b'RXhjdVhLbFVxbHNIczVwbWphWgpUSklrWldkbjUrYm1Db0pBMDdUZmYrWFFyR1l6Y1BuazhR'
    b'NnZQS2w2L1RPZ3JtWGFlNzk4NDdtSEFDSDRicjhuSThkZlhTOWdHTVJGCmtwUHZWei81bmhj'
    b'QW9GTjRTMjdhbHAxbG14UUZHSHI3ZTY1N1J6b21uRGllNFh0dnMvTzVxYnJxZWdFQTNwNGwx'
    b'bi93NHUwcjRCSCsKMVZkZmtTU3BVQ2dZaGdHQWhRc1h2di8rK3k2WGkyRVlpcUlHRHg0OFpj'
    b'b1VoOE9SbVprcENNSUxMN3d3ZVBEZ2E3N2IzeGYzY2s4ZQo1MWM4Sy8xOU00Ymdka0hHdnBr'
    b'UHFoR0M4QkFpSW9SNGRhN2h5eFdXUlUvb2NRenQyTytHQ0hNTDN6clpzb1hYS1NFcWNPZGV1'
    b'NGVSCkRwNWtRZ054a3dGcnRJdW56dnZLYS9oeEEvQklMcytUZCs0MkZZVHduc0xDd21QSGpo'
    b'MDdkaXd0TGEzNXd5bFRwdVRrNUt4WXNlTHIKcjc5ZXZuejUwS0ZEYzNKeTNHNzMvZmZmLzlW'
    b'WFh4MDRjT0JxY1pLOEZuTTlkK1NRdEdxQkpBb0E0SDUzOXJyblNRRFlzTjJWbWVOLwo1RDQx'
    b'eTBuVGxqYUlvdlQ5RWIrem5vR2tTR2padFBoTmsxcUZjS1pZVU5KVFJ5cFBYMkNMeXZsZVhl'
    b'aWtCRG95akFDQUIxTEVOVXQvClVRK2JnTWliUjhYajhzKzRxOHBLU2tyc2R2dXBVNmNtVEpp'
    b'ZzBXaWFmYnIrL2Z0MzdOZ3hPRGpZNi9WKytlV1hzMmZQM3JWcmw5VnEKdlJMNFF3Z0FtdU04'
    b'VjZrcExBaXFMZlY3R3J2WTlpMmFxdDU5eEh2ZkFKV1hrZVl2YjVyNmdHWm9iNFhaaUk5NjN1'
    b'SHdZZkJnejVhOAptd0phd2Q2NWRzSFFKdUNqTFE0RmhYcDFwdjgyU3g4WlJrUzF1ZUthbUkz'
    b'NGgvUEY2amRtMy93OGNvNUZ0anFFa05mckJRQzMyKzEwCk9tK003Q0prc1ZoME90MnVYYnRz'
    b'TnRzTmwzUzZHeU13NXc3OFpOL3kvbGZMTkRWVzRmUUZQK09UN2h1Zy9PNDl5ODdEbmpaQnhO'
    b'NlQKYkhtK0MvckZBNG0zOEhadERVZWhET25rdGZtZlcrc05DOEt2U243RnRaWmcvRUJzVnAr'
    b'cTJ2ZHUzRnlodUhoYWVtMjJSaEl6TWpLYQpWMW9YTGx5b1Vxa2tTUUtBcSs1YmJtN3VoQWtU'
    b'M0c3M3BVdVhibEJka3FUbTNmTi8vTnhnMUovWXFHNCtmNlZQSXIzMkd5Y0FLR2pVClBvcmtC'
    b'V242bXc3UUtLQm51NWJmcUsxQitMZ1FhQis2Zmt0amZzbDFlUTE1eGR5OE54c3ZGckJ2UEFG'
    b'RDlXZnIxcjU4NVpIcUtoVWYKTHMxWU9QMXM2bkdLb2x3dUYwM1RLMWFzbURWcmxsS3B0Tmxz'
    b'VFUxTlJVVkZMcGRyOGVMRk0yZk92SERoZ3QxdXYrR2VlcjArT2pxYQpaZGsvN3E0MUdBMTcx'
    b'Mm9pUW9odjkza0FZRWd2eFl0UDZ0ZHNjVzdjNFJyV1IvbnlSc1phN29FUlhWdkZDZGV0NVBD'
    b'alVja1NRbU9YCk9xK091YndnUmJjaEZzL1FsOWNJK1NYYzVpWG9mdDJKNm1WUGtkK3RLNXMv'
    b'NmZTUFAxQVVKVWxTYzlMVnhvMGJYM2poQmEvWHExUXEKRVVKR28vSElrU00rbjIvTGxpM054'
    b'ajh3TVBCcVJ3OFBEd2NBbTgxV1hGeDg5WE1BQ0Fndzd2NVExN2NybVpucjMzblltNUhqMTJt'
    b'dwppd1hjYzFOMUM2ZnBDeXVFZHo1cmdpZ0xKTFp0RlMzYVNnNC9VbEpBNFkycFpZMENkVjl2'
    b'MHVZVU4rNXdaK1d4V1hucy9oTU1RVURICkdPcUJmcGl6cXZISXJnc2VsMHV2MTN1OVhyUFpi'
    b'TEZZUm93WThmVFRUek1NWXpLWkNJSm83dlFFUVpTV2xxNWZ2NzYrdnQ3dGRudTkKWG83akZB'
    b'ckZxRkdqRkFwRmM3aGVyVlo3UEI1QkVDaUtDZ295SGQrczdwYUFBVUJZRURGNmtHckphbHRZ'
    b'RVBGYnVxOXpISVhqa0RTdAp5V0huNGJFQm9LWmJoZkN0NTdpelB2SFFQdlNUejYwSDBsZ2NB'
    b'MG1DeHgvUUhFM3pMWm1wbi9XUTlwVzE5dFN6dnRkbndQNFBrVG5FCllMSllmRDVmdjM3OXpw'
    b'OC9QMkxFQ0lxaWREb2R4M0hvNzRudnljbkpHUmtaa2lUaE9BNEFTcVV5T1RtNVk4ZU91M2Z2'
    b'UG43OGVQTjMKUEI0UHgzRWhJU0Y5ZTRjWC82eGtHUDc3QTU0NXJ6Zm1sM0M4SUgyeDNMejZT'
    b'K2ZBSGdxREZwdTh6RjFWNklZeDNWckZzVWV0VFhnRQpNTDZYcEZPT21XOHRyUlVmRzZONWJF'
    b'bkR5b1hHNUE1VWZnbm5aY1JlWGVnVG1iNzR0bGpSVGp3bDJkMG1xcTNMN2ZiNWZIMzY5QUdB'
    b'CjV1Z056L09TSkdtMVdwL1BWMWhZMkJ5b0h6aHc0S2hSbzF3dVYyWm01blVoWTQwbVBDTGsw'
    b'NWZVUjlZSk5JWFNMdmduamxDL05FZi8KNUt1TmpCOWVYV3VmKzRnMnBTdjk2aGZlSFRzYW9W'
    b'czBkSTJFMWtPck90bFNTY0hVZ1p5SStreXpPdHpTWjYrWjJrV1F2Q0M5OUlHdApaMmNheDlE'
    b'Nkg5ejdUakFJd2JwRlV2WTJTZkJmRkhCWStkN3Fzckt5a3lkUE1nelRQQzl2L3FPc3JNeGtN'
    b'aVVsSmJWcDArYkxMNys4CmZQbnkxZnVvVktyZ1lNdnpNODBsZThua0JOL0tqUTVSaFAwbkdB'
    b'Qm9FMFE4TkZ6RitNUzNGeGdIOVZCczJzKytzZG9LMFlFd3VodTAKS2xyYmVmVnFHaUl0M0pu'
    b'aXpRZjlUOXl2Q3RDakY5NnpQVFJjZlc4LzVjSjNtcnAxb0tlTzBRZ0N6RnZXWkRMaXI4eWlu'
    b'M3FRVHoxNQo1bzNWM3gwOWZ1cDhkcTZTb2dpQzREaXVxS2hvOSs3ZGRYVjF6UW1XMWRYVkFL'
    b'QlFLdlVHWFh5N2dBMnZLZFl0VlVhRzhEU0ZhQXFWClZRdUo4VlI1RGYvcmFkL0E3b3JDY3E1'
    b'dmtnSWhXTGZiUCtmRk9nZzJ3T09EZ01KYmwvQ3Q4N3o2b2pyNEpsV2h3STl2dENUSEVaVjEK'
    b'ZkdFNXYzR0hhK3NxaXlCS0hxODBkMW5qMWxXV1A1WVFCRGg4MnI5NVB5cTNxcjArbk9lQjhi'
    b'SUN6MG1TU09BUW9JZGVIYmovbVVKRgpoMStiaVJXV2N3OHZzczZacUIwL1hKMmU3Uitlb3Z6'
    b'NUdGUFhLSXdackRRYjhWZS9ZTjU0cng1Q2pUQzExVGgwclY5NEFLaTJ3WmZICmNZRmY5N3Bs'
    b'MXYzMG1ZditScnVZR0UrVlZQRy9uZkVONnFub20zUVRNVmp1V3RydURlUVVjbTFEY1kzcXVy'
    b'SHZoNE1lQWtkYjlyZ3QKUnZ5TitZYm1QZHMrdnpUeGRjOVB1eHVnWFRCTTd0dEszMHZWYWw5'
    b'Tm9sVkNoelpTWWQxUFB6WmtWaEh6eHlzVG9zbUNVcjZnbER1Vwo0Wjg5VVZOZXd3Zm9yek8v'
    b'ZTQ1NlAvdmVmVzlmNWVZZjNWbDViSWdGVDg5bTg0cTRpbHJocDkrOE1lSGthNTg0UmcxUS9m'
    b'R1lIRWtDCmd3NmJOMW5yOWtvbVBXWTI0dm1sZlBLMHBzelREdWdSQXhONnQvelE3RjNoM04y'
    b'QVNRTnpoa0dmdUwyN0c0SkgxdS80emQrdEkvWEkKS1BYc2labzMxam5haHQ3WUVZTk1lTGNP'
    b'Rk9PWGZ2bWRNUmt3dDFmY2M5UWJIb3czMklUcWVnRWgrTWZYVndXWjhNKzN1eDB1YWNyOQo2'
    b'dWh3NG9VTnZrNFAxdFpVK1dGQ2IzaWdld3RmaHJsTGUveVYzeTBHY1NFUWJQRG4xbjYveTNZ'
    b'Z0d4dlFpZWpabWI0blJZbGpONXIwClhZZTlBN29ybERTcWJ4SVBuMks2ZDZUVlN2VDlRYS9Q'
    b'THkyY3B0OXpsR2tYVG1wVTJCK1hBOVJLN0w0QlNpV050aDMyRDVuYjlPc3YKTmlrcUVCN3RE'
    b'MUdCME1xNUs5NmEycUVOUERjUytyVlBPMmxQR0ZQVmM2NHJxK0RHL2NuRmxmeSs0NHlDUW1r'
    b'WC9MMjYwQy9OTVJSVgpjQmNMdUhXdm1DZ1NHWFZZZmpIblo2V1VydlFOTHVHbW4zMmhvNjFU'
    b'bnF1eHVRRW1wY0MwZ1dEUzNBVnRkbmU5VzlidWhSUDVrRmtNCnZCQVNvNTArVnYzc1dOSVNj'
    b'R1VZRmtXdzJnU0xFVCtReWxBa0RPMnR6TXBqUzZyNHJ1MnBtSENpZVJYZzZnQ2ZsYys5K1Iy'
    b'My81Q0QKc2Z2Qm9JTCs3YUZiTkJENFhkTlVkOTFMaFFIQXhVQkdNWnd2Z3dZWElCUVVxZTdY'
    b'VXpXcEg5WXRqb2dNSmJCYjJEakdKeFdVY2I5ZQprSGFlNExLeVhONG0vNVczRGlSRlFlZndW'
    b'ajJjLzljSWY1WHlSc2l2Z3FJNnFMR0JLQUVBUm1DR1lLVmFTNmlVbUZxRlJBbTVYQUxqCkZa'
    b'eDJ6dDNvZytaa0RwcUF5RUNJQ1lKTzRhQlQzcTF0UThCZFRJUUpJa3dBQUQ0T0tocWh3U2xh'
    b'WFUwMlQ1UFREdzA4Y0R4Z0dGQUUKMERRRTZxR0RGc3hhQ05SRHFCRXdCSGM3QlB3M29DQWhO'
    b'aGhpZzBIbXJ2THFaV1RoWldUaFpXVGhaV1RoWldUaFplRmxaT0ZsWk9GbApaT0ZsWk9GbFpP'
    b'RmxaT0ZsWk9GbFpPRmxaT0ZsV2hqL0M1cndoU0ErV2N3REFBQUFKWFJGV0hSa1lYUmxPbU55'
    b'WldGMFpRQXlNREl6CkxUQTVMVEUzVkRBek9qSTJPalF3S3pBd09qQXcvUXJPNndBQUFDVjBS'
    b'VmgwWkdGMFpUcHRiMlJwWm5rQU1qQXlNeTB3T1MweE4xUXcKTXpveU5qbzBNQ3N3TURvd01J'
    b'eFhkbGNBQUFBQVNVVk9SSzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxNjUyNSIgLz4KICA8'
    b'L2c+Cjwvc3ZnPgo=', 'US_WA')

US_WA = b64_US_WA
index.append("US_WA")
index.append("United States of America Washington")
catalog["US_WA"] = US_WA
catalog["United States of America Washington"] = US_WA
country["United States of America Washington"] = ('US_WA', '', 1)
lookup["US_WA"] = ('US_WA', '', 'United States of America Washington', 1)
lookup["Olympia United States of America Washington"] = ('US_WA', '', 'United States of America Washington', 1)
lookup["United States of America Washington"] = ('US_WA', '', 'United States of America Washington', 1)
details["US_WA"] = {"continent":"Americas","capital":"Olympia","currency":"","web":"","lang":"","tz":"-08:00","altname":""}
regional["US_WA"] = ('US_WA', 'United States of America Washington', 1)
regional["United States of America Washington"] = ('US_WA', 'United States of America Washington', 1)
#----------------------------------------------------------------------
b64_US_WI = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjc1NyIKICAgd2lkdGg9'
    b'IjE1MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1dpc2NvbnNpbi5zdmcucG5nIgogICB4bWxuczppbmtz'
    b'Y2FwZT0iaHR0cDovL3d3dy5pbmtzY2FwZS5vcmcvbmFtZXNwYWNlcy9pbmtzY2FwZSIKICAg'
    b'eG1sbnM6c29kaXBvZGk9Imh0dHA6Ly9zb2RpcG9kaS5zb3VyY2Vmb3JnZS5uZXQvRFREL3Nv'
    b'ZGlwb2RpLTAuZHRkIgogICB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94'
    b'bGluayIKICAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIgogICB4bWxuczpz'
    b'dmc9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4KICA8ZGVmcwogICAgIGlkPSJkZWZz'
    b'MTY3NjEiIC8+CiAgPHNvZGlwb2RpOm5hbWVkdmlldwogICAgIGlkPSJuYW1lZHZpZXcxNjc1'
    b'OSIKICAgICBwYWdlY29sb3I9IiNmZmZmZmYiCiAgICAgYm9yZGVyY29sb3I9IiM2NjY2NjYi'
    b'CiAgICAgYm9yZGVyb3BhY2l0eT0iMS4wIgogICAgIGlua3NjYXBlOnBhZ2VzaGFkb3c9IjIi'
    b'CiAgICAgaW5rc2NhcGU6cGFnZW9wYWNpdHk9IjAuMCIKICAgICBpbmtzY2FwZTpwYWdlY2hl'
    b'Y2tlcmJvYXJkPSIwIiAvPgogIDxnCiAgICAgaW5rc2NhcGU6Z3JvdXBtb2RlPSJsYXllciIK'
    b'ICAgICBpbmtzY2FwZTpsYWJlbD0iSW1hZ2UiCiAgICAgaWQ9ImcxNjc2MyI+CiAgICA8aW1h'
    b'Z2UKICAgICAgIHdpZHRoPSIxNTAiCiAgICAgICBoZWlnaHQ9IjEwMCIKICAgICAgIHByZXNl'
    b'cnZlQXNwZWN0UmF0aW89Im5vbmUiCiAgICAgICBzdHlsZT0iaW1hZ2UtcmVuZGVyaW5nOm9w'
    b'dGltaXplUXVhbGl0eSIKICAgICAgIHhsaW5rOmhyZWY9ImRhdGE6aW1hZ2UvcG5nO2Jhc2U2'
    b'NCxpVkJPUncwS0dnb0FBQUFOU1VoRVVnQUFBSllBQUFCa0NBSUFBQURyT1Y2bkFBQUFCR2RC'
    b'VFVFQUFMR1BDL3hoQlFBQUFDQmpTRkpOCkFBQjZKZ0FBZ0lRQUFQb0FBQUNBNkFBQWRUQUFB'
    b'T3BnQUFBNm1BQUFGM0NjdWxFOEFBQUFCbUpMUjBRQS93RC9BUCtndmFlVEFBQWYKMmtsRVFW'
    b'UjQydTE5ZDJCVVZkcitlOXYwbWN4a0puWFNHMGtJZ1lUUUNiMktOQlVVcGRsQWRDMzQ3YmU3'
    b'bG5VWFYwVmRWMytmcnE1dApzWUJZQUVGQWxBNEJBa2xJU0NPOXQra2wwK2UyOC8xeFkwQVVm'
    b'L3V4cmt2WWVmNjZjKzY1OTg0NXozMmY4Nzd2bkRrSGc2d1hJSVNoCkREelVCU0VLUXdoUkdF'
    b'S0l3aENGSVF4dGtML1lrOUlUdzIrWm5RRUE3Kytzc2puOTh5YW5qTXlNQklCelZYMG55N3FH'
    b'cCtsdW5wYm0KOHREZm5tNWJ2endQQUhZY3JDKy9hQVNBdkt5bys1ZU5TdEtIMlp6Ky9TZGFk'
    b'aHhzNEhrazNGTXFJVGZja1Q5MVRBSkMwTnhwMzdhMwp0cXJSUFBoRWpVcnk0SXI4Y2JteE9J'
    b'NVZOcGpmM0Y1dXNIaUVVeHZYakJWUk9BRFVObHUvUHRrQ0FQblowYk1uSmxuc3ZpMWZWZ09B'
    b'ClFpYTZmOW1vaVhsNmlZaXNhYks4OGNsNTRkcmw4N0x5czZNUlFrKzhkbUwwOE9oWkU1S0VH'
    b'NzYzbzhyZTd3ZUFCMWZrSytXaXZjZWEKNjl0c054cUZXclgweGNlbkE4Q3A4cDdpQ3oyUHJ4'
    b'MDdlMkl5QUd6YlYzdXlyR3ZXaE9RWEg1OWVVdDFYMTJyOTdYM2pBYUNoM1ZaKwowYmhxVWM1'
    b'SG14ZGkyTUJOVmk3TXVXbEt6Wm9uOWdPQVVpNDYrZkhLdkt5b3dVZHNYRDMydm1jT2ZMaTdH'
    b'Z0JTNHRWRkg2L1VSeW1GClV3dW1wajI0SW4vbTNkc3YxSnNBWU5PdkNwVnlFUUMwOXpnUEZM'
    b'VWdCQlB6OUM4K1ByMm15YkxseTJxVlFsejJ4ZHFNcEhEaDJwdW4KcFcxWWtUZnU5bythT3V3'
    b'M1RVbGRzMlFFUXZERWF5Y21qb29UV2dRQVRsZnduUzh1QU1DVDZ5YnFvNVJkQnRjdlJ1RXZK'
    b'NlFkdlU3aApJRm9uQjREc1ZKM3djVml5ZHJDd283Zi9lMThPeHpadm5JWmg0QXN3SDM5VjAy'
    b'dHlBOERxeFNOUzR6VkNad244blN6cjJuV29rZU1RClFXQnZQRFZiNEdiTGN3c0UvcjQ1MWJy'
    b'N1NCUFBJNDFLOHNtZkY1UEU5NXFjSEtjZWt4Tjd4VmU5NzdhUkFuK25LM29Pbm00REFMVlMK'
    b'OHRqcU1UL1J1dVh6czI3OHNkQms4L29Dak1DV1dpblJSeW45QVJZQWhpV0ZEMUxZM3VPOC9K'
    b'Sm9uVnlnNGMzdDVXdWUySC92N3c4SQo1WmtwV2d5RHRVdHpBYUNoelRicm5rOXZlK3pMNTk4'
    b'NUl3amcyQkd4SXpJaXBvNUpFRXo4cHZWZjNQTElybGMrS0FHQXJCVHR6TytrCkR3Q01WaThB'
    b'TEorWGVjVlhMUmdlQXdCQm1wdDU5L1o1Nno2dmFiSUFRR2F5OW1ydDRuazB0U0FoU2l1L3dT'
    b'bEVhTURJb3JUeTdEUWQKQUh4ZDFNSnl2RW9oam9sUVJFY29BS0M5OTNzVWN0ekFtRGRuVWtw'
    b'YWd1Ymc2VFlzZXpPV3ZmbnJreTFKZXJYQStwZEhHbG1PQjRDLwpiaStmZmUrbnMrLzl0S2JK'
    b'TFBBSEFPOStVWG5Gd2RTQ2hNSDc3enJVQUFETDVtVU5DclVBNFlaaUViRm15UWlDd0hLWHZJ'
    b'OWxiNTV4CjkvWWZiWmZSNmoxem9ZY2dzRnZuREx2eFBWS0J3bWlkWW5pYURnQktxdzNOblE0'
    b'QUdKWWNIaU5RMk5OL3hRdGUyMndCZ0pIRElodSsKWG4vaW83dnVYcHBMa1RnQXhFY1BESEl0'
    b'blE3aHdHTDNIVG5iY2VSc2g5bnVTOWFyaGNLTExWYmhvTFhiSVdoQVNyeDY4UDVIem5ZNApY'
    b'SUdFR05YNGtmckxuM3YwWE1jQThadm1keHgrNkgrZW5IMzVWVC9Fam04YkJFL254cWRRME1u'
    b'b0NMa3dFRlkxbW1xYXpBQXdMRW43Cm8wSUtBUGM4OVhXZjJRTUFCSUZOSFpPdzVma0ZSVnRY'
    b'aWtXRVZFSUpGUVJpcm9CTU9uRFc2NmNIQ3owK0JnQVVNbXF3aEdINXI0NDIKL2JEM3QrMnIz'
    b'YmF2RmlFQWdMaG81U01yQytyM3I1dGZtSHExZHUwNjNNRHpxSEIwdlBBaS9pZFlvVnl3d3Fv'
    b'R3MyQmt3OU4xRVJvWgp4NkV1Zyt1S1M4cHFEU2x6M2xyenhQNkRwOXVFUGgwL1VuL25ndUUr'
    b'L3dCell0R1BPTldEWjJXU1M0UUo1QWxFWGpLZ2d3MEFzR3h1CkpnYlk1UUsrNnJmN1JpNTkv'
    b'L1Z0NTAwMkx3Q0lLT0tWMzh5NFdydjZ6SjdpeWw0Y3gyNmJrM21qVzJHdlV4RFM3RlNkd2VJ'
    b'WjFNbkoKK2ZFNGp2VlozRFREWGVIT0xKdWJ1V2g2K3Y0VExmUFdmVDV2M1dkQytlamgwWU5r'
    b'cDM0bmNmb281Yks1bWN2bVp1cWpsRzNmV2JQdwpyZ2llcDBCblcvZjNERjNRVW4yVWNsSisz'
    b'R0RoM01rcHkrWm1LbVNpUjE4NG5EYjM3ZUlMUFlJTExaV1FWOWZTK24rWFgvcHZzRUo5CnBG'
    b'SWZwUlJpY01IWkd6a3M4b2NESVFDa3hHdStlRzNwRjY4dFhUd2pIUUFxNjAyRHA3b00vWUxB'
    b'M2pKN0dFRmdBTEIrZVo1UU9TTXAKL0dSWmwxQnQzZkk4NFdEOWR3Y255am92ZndUTmNJS1cz'
    b'and0YmJEd21RMlR2bmh0NmJ1YjVtTVllSHgwUzVmai85dTBYWWNiZVI1TgpIS1VQRDVQZXNO'
    b'bVpRWktFSHE5cU1BTkFXNC9URjJBRSsvamhRRmhaYnhMT3Z2SDBuR2xqRThibERnUndSZWU3'
    b'RVlJUDkxUS91VzVpClRuckUwUzEzMnB6K3hUTXlBTURwRHBSVTlma0N6UEdTenVuakVsY3R5'
    b'b2tJbHdXQzdLTHA2UUJRMTJvZGRGVUdzZk5RNDlxbHVYTHAKSmNrdHJ1eWRtQmVYa3g1eGF1'
    b'c3FvOVc3ZEZhR0lPbENGUFNqNkRXNWl5dDdKK2ZIL1lTbDNnaFdhTy8zdXp4QjRiaXEwUVFB'
    b'UEk4RwpuY1lySWdyQlZYbm1qVk1BSUpkU3F4ZVBFSklBKzArMDdEelVBQUNiM3owclpPQ21q'
    b'a2tRYkpGaCtmVi8rRlp3Y083OS9ZRnVvd3NBCjVrMU9XVEl6QThjeG05Ti8xMy92SFF4VUJu'
    b'RzR1TjNwRGx4ZTh0cEhwWUtKVDhxUHUzWE9NQnpIM0Y3NjRlY08vWFRyQkMyOWtYT2sKQW43'
    b'OTUyUGhZUklBT0ZFNm9IWFB2MzBtTTBVTEFBZFB0d05BbDhIMTB2dm5BRUJ3VnYveVFVbE5r'
    b'M25aM0N4OWxNSm85WDVUMUxyegpVSVBnMTNoOGRPR3FyUSt1R0QyMUlKN2pVVU9iN2VPdmFn'
    b'YlRXdTA5enR6RmY5K3dJbS84U0QyT1lSZnFUVzk5V2k3RThnRHdoNytlCkVsRjRRNXROME5K'
    b'MXozd2poQTBXdTA5d1QvSnYzYkxoanZ5YzlBaVN4S3Nielc5dUx4ZjhtZ05GclVhckZ5RUVB'
    b'TVdWUGI5NzlialoKNWhQdStkbUJ1a0VUdkZ6ei85WEFRaE12aGpwQ1B6YUZLQXdoUkdFSUlR'
    b'cERGSVl3eEVIZWdHM2kvT0hpWHFVU1V5bEZFVkVLVmJqRwo3WEIyZFZqdFRzTGxSZ3lsQjF3'
    b'Y292QjZCTWJhVTJNZEVSR0tjSjNLNHhDUklvbkhhYUVvWlh2VnViak1rUWtKeXV5Uk9vVmFa'
    b'emQwClc4Mlc3bTYzMFp0eVkzQkpRTVRNRzRGQW5sazRSMUs0YUVuRnQ1OUlWV3BTTEdXRGdi'
    b'RElXSlUyTWl3aUJzZHhKaGowMkMwQm54c0EKVkdyVjdOdHZiNnM0NG1FaVFsWjRIUUN4OGVx'
    b'TzVCU055K2JITUR4djlpM1JTY1BxUzRzWUpPdHNOWnZOblM0UEpwWlFVVnFVa0t3agpSUVRQ'
    b'c1VranhuZ2Mxb2h3cEZTMXRYUXJlV3BvRXptVXN6T2NQeVdzTXFzZ1R5SlR4R2VPdEhTM01z'
    b'YnlmTld4RjcrSWNjcm1BMGI4CkdOOThvZWI5R1pQQ1QzVm1GU3pld0hPczNkQnQ2ZWs2ZTdM'
    b'ZXltYUhoUFNYdHorNjMwTkVhWUt4YVprZXA4M3ZjVHVzbGhwallxY3QKaWllMVYzbGpNWVF4'
    b'UG1rMjRDVEhJYms2dk9MSTNzYnFlbytiWmtBRHVDaGtoYjgwSk1GS3RZcWdHV1FQNklGU0Er'
    b'Y0ZRZ0hZZDVFUwo0bExDTGNNVFNBbzhKbU52RUttYTdBa3VOZ3hZRjJBVThBRWwzcDZjSEla'
    b'ajBOSnM4NGpHaG9UMHVnbDFNWFpTSmg1R21aVmlKak5OCmJ6S1o3QTVIdUVhei84QzNNbmxZ'
    b'Q3p1SHhhNDZ3NFhFV0E0SWhMQlFhUCt2Z2d3M3FhRWFhUHRWYTdEdWFQK2UrV1BJNmVPU00x'
    b'SmkKQW9GQVdscXFTcWt5bWMxclZ0MWxzeHJqcEswL2NmODRhWlZlMWt5eDNZQ1kwRmo0ODN1'
    b'ZVN1ZDJHZHVnVWJLNHJ3NzNYR1FrbVpjMAo4OUk3S1phS3VQYjY0cXFxYW5WWW1Gd3VPMWww'
    b'V3FWVUJ1bGdkM2ZQMUNtVDY1bzZaRklKQkxwcC9BZU9LR1BQVmxYSEpNWDRUQ1VlCm13SGth'
    b'U0VyL0RtaG9UcUJzY2VxeGZmTkhqWXVTZXBsZFlEOWVFUms1a2MwQlNZbHBJN0t6YzJoS09w'
    b'Q1ZZM1Q1YW10cmV2ck0xUlUKMWJrdERaTXllWWxNYzZXRUluZWF0c0htb250YjYybS9UNDUx'
    b'WTdhaklTdjgrY0E0Nk9aM1NKNys5YjJMMjdwTkRBOTE5Q3lBSHgreApwaWVleVk1b0NBdFA2'
    b'T3F6OXJTZkUybXpESHhTY25qL3BFbVQydDA2dDJSc1dYdTRqMU5lbVJ2QXhHNHZscVBwbVpH'
    b'WFhKaWJmT1IwCkphOHBCRW9kb3ZEbitwcFNwSmtRSFM1bFhKMlByRm1NWWVqYmk3SWZqL3dB'
    b'Z2l5VkZkVmJib2p2YytFUllpUERCbjBva3VadzBuZSsKM3F3bmNMYmZKL3Z4REErSVoyVzY3'
    b'MW84ZmM3ay9LMG5QVzVxZUNnNzgvUDZ6aUtWVXJUdjJMa0orVm0xelozQWE0R2dmclNpd1JO'
    b'NQpwRGJPeUVkamZFQVgxallwMjNXNDNsL21tRlVPVVdGaXQ0Tk51UHFvSXY3OGNQM3krWk05'
    b'dmtCZklBNGtvUVRieitmSnhDdjZ4bVh3Cjk5eDEzK3FWeDIwTzE4UTV0NldOZHIvNlNiT0RU'
    b'd1RhUWhtMk1wZ2FWTGtRTm5LMDR2TXBXV2FXOWwzc1BPcnM5NXY2K1BjYStNeWsKc3BucTgw'
    b'a3hCTTFSR28zaXZST2ovTEt4NEN3SFR3TUFncmc3QVJmb1FyZzgwZTBMdEhYMHp2QWNQMG5N'
    b'NVNoZFNFai9lZkRaaVJhUgp2M0o0WnJMZjNUOWh3Z1FtNEwzWTByWDM4QW0zc1pxV1pDc2My'
    b'eHUzYyt0dURrU0pHcXRMaXVJMHp1b21uMWlFL1dhVitPbDc1WGZPCmsrSVliUHVUZWt3MjFX'
    b'UGlQem5nUlJ4dE5ac2krS0kvM3RuNXlrT01UdVlzdXNDQUxCRnNKOGIzSDV6Q08yVldqM3R2'
    b'K1ZNUnNhdngKSHN4VmZZR0k1ZkhyMmg2djk5QStqT3E3NTlFbFJ6NStUUk9sUDdkM1c1aEtH'
    b'ZVNRMjJITm4zMnIyMkZycXJ6dzJ4WDBpdzhQK0NaMgpGLy9uajcyM3paU016cUtDTk5xMm41'
    b'bFhTTDZ6eS9mc0F3b0FRQWk2ak55SCsveEJCdjMrUG9WVWpBR0ExNCtTbDdpc3ZzaXhoT3Z3'
    b'CnNJazc3TDFqNUJvZEtWSVNaR1BBWTJmcDh3SG1TZG1TNjlsMXY5NkRDcTNLRy9SNStpMkcz'
    b'dWJhdUdHNXp6Ly9YTURyQmdDcFFwV1MKT3dab3g4Nmp3WGUvSEpqSkdhN0NOLzlLT1RxTFFn'
    b'aldQY0UxdG5PLzJuUnBqdStUYjdGLy9DRDhEK3NVTHp5a0ZQamplTmo0cXB1aAo2VlJrbGVP'
    b'RWkyTUNpRzhQZXBVRUNRQ0greTB5bkx3M1hDZjFkNFRpd210SHp0alJQcGZENDdBbTU0N3pl'
    b'MXliTmoyNzhPYWJZMUt6CkRhMzFBYStISUNrSHluaC9qejlBZjIrTzltc2YwRDRVYkdraVgv'
    b'aXZTNW5yTlF2Rklod3ZydVQ4UWJUMmQzNlBEMzI0ejk5aFVmaFEKYkxaRTZXQVpGOGZpQURL'
    b'Y0FBQUVjTERmWE9TMkdwbkFKUGE2cHZDNmRtY296Qk1abTF4MjRGT0hxY2ZVMGNTeHpOcFZL'
    b'emRzMkRCbQp5aXhTTExaMHR5Ums1OXNOWFNTSmYza3N5Tk9rVW9iSlpVZ2tSb2VMT1RZbzN2'
    b'azN3aGNZb05ZWFFKa0ozS3VQMnRjL3pYRW8rTUFLCnNVS0c3VG9hY0hwRmtiUXRWaFo1Mm1P'
    b'djh2WEhVdEl3Z2dLQXJxRFB4QWJMdk01b1NyS01JbzRnOW1xWmhKQVYvaFJVVXIrdjM4NEUK'
    b'L0lqbk8yckxaQ3JONHNXTE96czdwVGd2a1N1N0c2cmRka3RDZHI1RVNwVlVzeC91NXc4V002'
    b'OS9KdnZMeDVUZGhldXpZc0lVR01zaApta0VBNEhEeDN4VFRJZ3FUeURpR3diVGhDQ0VJTXNo'
    b'b3RDZUpwWHRjRGpzbS9jVFc0K05aQ3NNZExIUGU1K1FRT3VxeTlER0JWSkZJCjRxNEplYVRY'
    b'bEZTVGUyTmpaZVdIZHRKQlArUDNSeWFrVFI0ek1qczdXeUdYVmRhM3VsMCtsMDlpYkRpVGxZ'
    b'amRQa2V5Yko2aXV6OXkKNXZMbllwTkhPZTN0QlptZUN2dktHdHRjVWoyeHFDNnV2Y3Q4dUpU'
    b'NGNIZndvVHR3YlNUeC9vbHBSbXVncHRISzgzRFI0bmRHTGdhZQpocUE1VmFvWUpRdVRFOFFJ'
    b'V2RoeHQ3WFc3NTZwaW5BRHIyY3Q1eVVqUWtMNmYzZVhjWktsQXlRbHdqQ01Jb0gzOU96Y3Vm'
    b'UHdvYThSCjRoMm1IaDVoYlBRZEdtMnhRblkwTlk1SWpLRnpFczFZOTMvcEVNck56ZktwbGhH'
    b'RTB1L3hNSFJRcmtpcWFaNmNQanErOWNDWFlXR1cKZkVYQVFHU0xJMmJRektQVEM4UjEzdW1n'
    b'R2trRys0Q0JOSkhNekFTdGJIQ3J0ZWVFeXdyU3VJL0FXYmJuelZtcm53YzZOQlplUTJhVQp4'
    b'UWhTRlBCNU1BeUxpbzJpV1dybnpwMkxwb2dxRzN3V0U2bUl5U1ZkSmI5ZWZQS2QzVXhhUENH'
    b'aXNOdW1Zd0RzVzErbnB1WGRhN1hhCmQzeTVpME5NbE1yZGJGRE1tVEx1d1FjZk12UTBmbHY4'
    b'N1pvRitETEplMDE5eWxsalJSakEwcnlhcnhwaldFTGxZcGxTcjlQRUJQc1kKdjRmaktBd0hk'
    b'UUdtTWhFNFRtaEhnQ0ZFNGY4ZE5nZldYSEZhcDAvdWJhckJLYkZXRTFaeHRyT3BxU2tRQ096'
    b'WXNXTjNVZnZxa2FWMgpGeHFlVElxb2daUjN0NG5ESXU3czd1N2V0S1hOaTgwQ0FEQUJBTlRz'
    b'cDNsNGVjYnNwVXp6NGFod0xDb2NaU1M0ZUZyMHlsYnYwdW4yCkduTjNLNk0yTXNHWERNMFJp'
    b'Y05vUC9JNHpEekhBRWIydXVVQTBHYTVmcWNyWHRmdURJRXpQTWZlOHZpTE9FRklLY1ZMei85'
    b'SnE5V3kKTER0dDJyUUpFeWJRU0JWRTB0T1Y5S3h4bHlLSEU3V3hKU1dseUZlakRaaUdjZlVa'
    b'YkYwbTN6Q01xeCtHV251YWRoY1hGenY0MFlPVgp4K1ZRWjZ0cGh4dnY4V1hLb0Jzd0RNTndm'
    b'VnJXbVBuTHRESHhDQUE0SDR1a1JvdkQ3RmVIZ29wckFZM0NqSzFOTFNjT1JNZkdmN1o5CmEy'
    b'NXVMZ0RZYkRZTXd6SXlNdXhPM21tenQzUnpCOC9TNTJxK1crSWlNdmU5RDkvYi9OOFRQcDQz'
    b'TjFhcEJwNEhoRENTUUFEN3hHWVgKcnVoMHBFMWJkMlR3RVNJS005a1lPZDlHMDBaS0pCWkpa'
    b'TFRmNnpCMmt5SXhUcEE4WUNPVFNLVmNxcUw2WFJBV292QWFORUkwZWRLTQpsemRNMnAranlz'
    b'M054VEFNQUVwS1NwWXNXUklURXlORFhYR1JtRUtHSGZ6cnBkOXYvMzQ0YUxmYmpkNGtLa3dH'
    b'QURDNHJoT0NJSjZZCms1TmpidDJ6K2Qzd3dmcVAvY1ZWMGNpbGFudHJUZjJwZVpONkdpcmJh'
    b'MHJIM0xTQ0ZJbDVqZ1ZjRktmRlhCNWZWa3l3eEJBUzBtdkMKL0lrcDRYSkNKaVk3T3dkV3F1'
    b'anE2aklhamJHeHNZaUthalpycDQwZVVORnp0ZWpPUDBxaVpNMnZ2LzY2V0JIUGVMd0RGR0tZ'
    b'OE1mdQo5bDdtcTYrK3V0aG9YUEhTNk1Gc3pvTEpFcThQeXJyU09OcmZWVmZ1ZFRrNGh1Rlp4'
    b'dDdYQ1FBZ2ppeHRkRC94eW9jVlhjclFXSGlOCjJITzg5ZHZTMXZlMmJuVzVYQUNBRUFvR2c5'
    b'SFIwUVJCU0VTWW1EZVB5aGdRa3R3MDZIUHB5OXRpQy9LeU5tM2F0SzJuK0V6SGVZL0wKaFJC'
    b'cWN4ajJHQ3ZXUC9EUWxDbFQ2dHZjNlpuNWE1OGRXT0NtSUl0a09TNEtPeHNNK0hDQ1JBZ2h3'
    b'QjJtWGpyZ0J3d0RTdHZuaXo5VQpFV1NvNkJDRjE0anFtdE1ybjcvWTFXdnU3dTRXS1BSNFBB'
    b'Q0FZVmk4RG1PWllHb2N5Zk93cDRqODlZdk0rUGphb3RKdXJlY0Z1OTJtCnpSbC9YQ0o2eFhC'
    b'MHEvL01sdDZkNCs1N0lDMHREZlcrOU81ajdjV25qejEyeDRBVmFsUzR3Y3FuNll5VVNPeDEy'
    b'Z2xTcklqT29mMWUKWlhna0JnQ0lVWUhKSjBvSnBibXZIU0x3QUU1eG1PTGl4WXNBRUF3R0xS'
    b'WUx3ekFBRUI4bDUzZ2dTWGovSzlucGkrUGlVeE5mM0NnOQorZ1kyWllURGN2YW1xdkpqV2ww'
    b'RXJrcWRmdXRqMGVsTFgzN3BoYTB2WnE5YjZNVngwS3JKc2RrVUFDQUVMQWYyZmw1RVFWaEVE'
    b'SWJqCnVEU1dSNFRkMkszUHlNRkpDZ2k1aEhld1pIaUl3bXVIVEl5QTh5cmxPRUVRQUdBd0dK'
    b'cWEyd1NMeEFpUlhJb1pyVHhDSHF2RG9ZdkkKRDlJSUlmajdtZUZiem1WdXZKUEpEajlLZ1Bm'
    b'WWdYZXp3dysvZHQrRktDM2w4cUwzOS9panRCU093MWRuNUVmUG95NGpKNU5nL2lDeQpHN3A1'
    b'bmtQS0xEYm9BUUNaU2lOVmFJQjFrN3pyT3A4RWRiMVQ2R1ZFWXN5bGxnZFRVbElBNFBNZHUv'
    b'R3duQU1IRGlDRXVpdzhBdUprCkJiMytGbnp5OEZwOVRPSnJPM1BmM1VjZWJjcDNLS2EvdkM5'
    b'cHlVVHIwcndUcWZKdjE5L3NTRThnT3B6cFQzeVE3Zy95T0U3VXRuSmwKcHVWcGVyNjhuaG1Y'
    b'UTdWMGN3anhBTUJpR2hEcC9PNStwNmtYSVFRWVFYQmVJR1FoQ3E4ZEhKTEVLZ3dFOGhNRVlU'
    b'YWIrMHhPc1ZSZQpVRkRBODd6SjRuSUg1WjhmQ2hpcy9LcjUyTnRidDkxLzUvMVM1UjF2M0Qy'
    b'bTdkekJqblpUV3k4cnVleVBMak96YTNpRSs5aHdTei8xCndjbHhpZVRIU2JIRUY0Y0RNZ2x1'
    b'OTRweERBZkFRSmJpUlhxZnk5RlFjaXdRNUlGU2s4QmViYlpqaU1KL0NIWkdMNkhyNkNDTllW'
    b'aGsKWkNUTmNQRmFsSlNVUkJDRWg1SE5Ic09QSDBIZCtoc0h4OE96NjJ4M1BiWkpINlg5NCt2'
    b'YnFzNGN5WTNwemN2NFh1dnloMkhQclc0UQpLZEx6Q3FZR3JLWDNMK0wyRlFXUGxBYm5UNVlp'
    b'Y2Z3amp6d3NFWXVCa0FEalhMQmd3ZE5QUDgycHhnSG5Fd1E4Uk9FLzQ4OUV1SU9xClZ0ZHdr'
    b'aVFCSUQ0MllsUk9ha1JFaE5QcDlISHlyZnU4bzdNbDllM2MxSFYybW9HWEhqUjl1dXRQeXdw'
    b'TGFqOE4rL0pQTlBXRHZJVTIKRE4rOHRrN3Qvc3ZjOGN6eld6ekxuM0JPSFJQK3pMNEZQQlU1'
    b'WWNJRWloSUJBQ0EwYjk2OHVybzZrQ1VCYlNlSTYzMHU0dlUrQ1pFSAp5aXhhUU9PWVFxRUFB'
    b'SlZTYXJQYmNSeXZxS2dRZ2FzZ0cvdm9STUxESzR3ZFBkN0MrMnhKTWVTSU5QTFFXVzlDTk41'
    b'akppZVB1aVNqCnRuNit2cDN0TXZKbU8xZlZ6QjQ0RTB5Tkk1NjhXNzd0VEtxRnpRYkNZTEZZ'
    b'Q0xFS0FBQUY5WHI5NFdObklPWmh0ZmNzRGRJUWhmOFUKQWtoTklSdVFtcGFXbHNMQ3dzcnFP'
    b'cHBtL0g2L1dDd08rcjBJUVdaRXo1OU9Qa0w0R2grOTgyUkxWeUFoaHZFSDBiNVR0RVJFUC9X'
    b'VwpaOVpZa1MrQXBxMnord0xJWU9VV1Q1TUVncWlxTzMzeHRMYmRGNGFYSGhuTFVURUFBTGpN'
    b'WURERXhpVTdneUFoT1FEd1FCd0FIb05hCmc3Z1NFSXZUQnVSdFJackNxMDBoRHducFZZRkVV'
    b'VFFWQjRTMHA2Y0hBQ1pQeUxkWnJUNmZUNkZRNE1odnR2TTV5WFFXdVkwVHhiMWEKK3NqZTd2'
    b'di81K1M4ejgrbHhrZUxkallzamRRcFB0anJmL2RMWDNxaXFETTRadTBpMmJ2SDhpNVdLR01o'
    b'V0hNaHdvcFBIT0FQQUNnVgpTWkxON1FZQVNJaEFKcE5KVGZaTmlTa21wWnhPeXhkR0hrMlNk'
    b'NkN3Y2RjaGYwUEFDdE5sUlJ2bm5QdlZ4ek55YzFjRHdKVEN5ZnYyCmZ1WHorUm9hR2pSaE1w'
    b'TU5Dckt4bS9MTkM3RzMrNnhBNEZ5WWd1aXNGNWVjUjRtcWhqWnIrSklaRE0yZ21rNkZXYlRn'
    b'dWFLWnVLTFgKZ0R4R2k0c2psRGpxNXlFQ0FJQ25VOVdHMWxhY0NYb0FvTHZQR2hVVjVlUENp'
    b'bHBqazhtTEpPOHNOY3dGVWdIWHExdHp2Yy9tbG9HbApNTDFWeEp1Y1B1VlRUejMxelRmZmxE'
    b'WDRYM3R6NjJkYjMrTDhWZ2FUenh6TnVyMjhRb3JIUkdBZUh4cWRSWUdIOENhenYxL2s5bnNk'
    b'CmJpL0lwTVRJVlBaRTZ5Z0owNU5NVk9vMW1ENDZuQUsvaWplNGFBbUhLeUk4bjJXbGhPODkz'
    b'b0pVZVNDSlljVnByV1VmeWtUSVJTc1gKajZwSjFsTmxwb25YY3hjTmdUOXFqMUFkWFRpeTFt'
    b'aWhYVjRVNUdVY3BpeElzYnA5V0hzZjM5N0x4SVRUYVhHa1RvMkpLS3ozbk5UTQpCeE9qeUU4'
    b'aW1Tbm53b0t1WUtVRVFKN1d3YzBIakZCNXp1aFFCODY3R0R5S1l2c1lYT3ZFd3Z1VnMxWEIw'
    b'K1BpNjhMVXFtRXg5bS9QClM5MGVVSkJXQWdKekppcjdmZFRiNTI1aFJmcVFPL05Qb2NZMXMr'
    b'YlVaVkxCT01MRTIzSVNQRDZ0WkcvM1BXMFgzNHZVMENJS2w0aVEKc1kzRU1jcmJTN0hEck9W'
    b'Y3Ywd1QyUEdFVWl4dXV1Y3YvZWZ0TjZVbWtBUWZtNTArNWxScDNlVHhjODVWdE9TbFJ1eXBz'
    b'bmhFbzVUUwo2aW5EdWk0MDhlVzJSU0JOQUk0QnpsOTJrZ0pDQ3RmOUtoaERjT2tnUXNZaTBZ'
    b'SGFyQ2taSGJlazdmVEV5b3RyL0NQVGVSekQ5a3FkClRDQnZTa0xsazVhRTk4UjlUZ0tVTWt3'
    b'cXdhUmlNdHAvREhXYU9HQ3JlcG8xeUgvaHFGa0dnZmF5cmlscVQzSm1HTTR6N3gzTHlORDEK'
    b'REt4YmdsRkFVa09tUDRiZXVqTVlXZWNvNlBabEZ0ZkNqSXk2eGo3MVJlZEVpNkZYS1dHa2to'
    b'U3preXpNQ1dUTmRJVExPTGVWSzI5ZwpTbXZaaTViaGNYRVJmcEV1Wi9TSVdoTTF2akN2MGlB'
    b'YU95bTN4a1JwVkFFcFpqM2NPS3FkbVYzdm1nU2tZdWk5MGtOMzZTQWtqa1orCnl5T0xlbHVO'
    b'c25aaVZWZXZhOFdrdHVydXlHU3RiZFpZN1BGZGZnTFNieXJ3cE9pSjZtcVQwbW1VK3cwK1E0'
    b'Y09tYjE5SFJISTVETjAKYXNtKzIrZTVXVjVjWWhoTjQ5RkR0QitHL0xvek1xN2xqbEVublAy'
    b'QkFDc2FycmVFcS9BT0kybnBCNTB5d0lBaVFlZkhBUFBRVWsrQQo2cld3a1dGY3VKcXdPY0h1'
    b'eHVRU3lNdmdkcFNrbDFqbURORjFuMjRRQ2dkQjBSMDNwKzZUaTVrekRkcDJjZzN3RE9BVVFm'
    b'Y0NZSndvCkJqZ2ZZR1FxZkxaOGlyT3RoLzY4WVNXSWRJQlROMEREYjVURkxBRjRRdDNneU9W'
    b'WmYxZWdnTVhWUWlZRkVTcEVLQUV3d0VXQWtXcFoKMEIrRWZWMXJnQXE3UGxNdC85RlcrQitM'
    b'ME5yY0lRcERDRkVZUW9qQ0VJVWhESEVNeWVYVm8zWHkxWXRIWUJqc09kcmMyRzRqQ2Z6bQph'
    b'V2tMcDZmRlJha0NORnZmYXZ0a2Y2MndQK2tnaHFmcGhIMUNPUTRKZTl3TEdEc2lkc0lvdlZZ'
    b'dHRUcDhSZWU3S3h0TVE2NDNobDVRCk1Uay9idnNyaStPalZRQ3c3TEhkZTQ4M0gzci9qc0dO'
    b'N0FWd0hGcjUyNzJmSGFnYmFDUUdwN2F1RW5icnBSbE9QUEpsQUlqU3l2Zi8KYlZsQlRzemxG'
    b'eDQ4M2JiazRWMkJJQnNTMG44Vk5tK2NkbXJiS29FL0FRdW5wd244blN6cnlydGx5OW9uOTNN'
    b'Y0lnanNxZldYZnFlOQpiVTdtNWJzdEMzanUwYWtDZjE4ZGEzN3cyWU1WZFVZQW1EczVaZTJT'
    b'RVVPclQ0WVloZW1KNFFEUTNIbHBZV2VkZW1DcTlmLzd1S3l5CndmVFJuaHBoaTFtdGVtRG1t'
    b'VmhFdlBqNGRBQVE5bllkaExCMWFaRG1ibjk4OTk4K3E3ai9tVzh1ZjBTSXduOFZ1bzJ1MWIv'
    b'Yjk3dFgKVHd5V2xOVU8vSFV6TlVFREFCSXhHUnVwQklEejM1VS9mRmRCU3J6NlJHbFhjV1hQ'
    b'NWJkcTZiUUxHa3ZnT0FBUStNQ1U3WDlrLyt3UQpoZGVPalM4ZTJicTM5dktTaWpyak0yOFUr'
    b'UUxNNW8zVDlyNTVXOFd1ZTZKMThwb215Mys5ZkF3QWRCcnBVdzlNQklEZnYzN3lpbHU5Ci9Q'
    b'ZHpWb2RmUkJHNzM3aDE0NXF4VzU1ZkFBQlZqZWJ0WDE4TVVmaExnK1g0SU0xUkpMNXdlbnBX'
    b'aWhZQUVtTlZPZWs2QUhqbXdjbHEKcGVUZzZiYlRGVDFYWE5YVWFYOTN4d1dPUTNNbUpiLzYy'
    b'NWs1NlJFSXdmbWYzUGs4Uk9HL0JGa3AyaGNlbTZaUlNVNlZkNmZQZTN2ZQp1cy85QVZhbEVE'
    b'Lzc4SlMwQk0wRHQrY0R3SjZqVGFPSFIydFVFZ0RBTUd6MDhPZ29yWHpESGZsUHJwdElFTmp1'
    b'STAxMy9XYnY0ZUoyCkRJTjdieDE1OTlMY1VGejRpMkprWnBSdzhQN09xcFl1UjB1WDQ4eUZu'
    b'bGtUa2pKVHRObXBPb3JFQWVCdmY1ZzNXSjhpOGZNNzduNzgKcGFPVDh1SUFBQ0ZZKytSK2x5'
    b'ZDRwcUtuNDhpREFEQTJOK2FkTHk2RXJQRGZBRUU1eFNJaVBWRWpoSVkvWFY4bUpRVjNSaTZs'
    b'QUVBaApvNzd6WU1tUUZmNmlLRHJmRlFpeUVqSDU2N3ZIVHhnVkZ4dWhTSXdOQTREanBaMTdq'
    b'emRqMlpzSGF4NTRaL244d3RUQjBGNm5rYzR2ClRBV0F2Vy9ldHY5a3k3SzVXVUsxeXZvaGxx'
    b'QVo4bGJZWi9hcy90MCtwenVBWVRBNVB5NGxYaTI0cWV1K2kvT3Voai8vdlVSSXdoWGsKeFB6'
    b'eG9jTGhhVG9BT0ZmVis3ZlBLb1pXRHd6SlgrMGp3Mlc1d3lJQm9MclJiTGI3QUVBcEZ5MmFu'
    b'cDRTcis1M0I4OVY5WlhXOVAzdwpxcnlzS0sxYXl2UG9XTW5BRWpZaWlsaTVjUGlzQ2NscWxi'
    b'alA3Tmwvb3VYcmt5ME15NGNvRENFa3BDR0VLQXhSR0VLSXdoQkNGSWJ3CmorTi9BWHhIeXBN'
    b'SmY1Ym1BQUFBSlhSRldIUmtZWFJsT21OeVpXRjBaUUF5TURJekxUQXlMVEkyVkRFM09qVTFP'
    b'akUwS3pBd09qQXcKaVJxUXhRQUFBQ1YwUlZoMFpHRjBaVHB0YjJScFpua0FNakF5TXkwd01p'
    b'MHlObFF4TnpvMU5Ub3hOQ3N3TURvd01QaEhLSGtBQUFBQQpTVVZPUks1Q1lJST0KIgogICAg'
    b'ICAgaWQ9ImltYWdlMTY3NjUiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_WI')

US_WI = b64_US_WI
index.append("US_WI")
index.append("United States of America Wisconsin")
catalog["US_WI"] = US_WI
catalog["United States of America Wisconsin"] = US_WI
country["United States of America Wisconsin"] = ('US_WI', '', 1)
lookup["US_WI"] = ('US_WI', '', 'United States of America Wisconsin', 1)
lookup["Madison United States of America Wisconsin"] = ('US_WI', '', 'United States of America Wisconsin', 1)
lookup["United States of America Wisconsin"] = ('US_WI', '', 'United States of America Wisconsin', 1)
details["US_WI"] = {"continent":"Americas","capital":"Madison","currency":"","web":"","lang":"","tz":"-06:00","altname":""}
regional["US_WI"] = ('US_WI', 'United States of America Wisconsin', 1)
regional["United States of America Wisconsin"] = ('US_WI', 'United States of America Wisconsin', 1)
#----------------------------------------------------------------------
b64_US_WV = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjc0MiIKICAgd2lkdGg9'
    b'IjE5MCIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxOTAgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1dlc3RfVmlyZ2luaWEuc3ZnLnBuZyIKICAgeG1sbnM6'
    b'aW5rc2NhcGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUi'
    b'CiAgIHhtbG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RU'
    b'RC9zb2RpcG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5'
    b'OTkveGxpbmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1s'
    b'bnM6c3ZnPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0i'
    b'ZGVmczE2NzQ2IiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3'
    b'MTY3NDQiCiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2'
    b'NjY2IgogICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93'
    b'PSIyIgogICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFn'
    b'ZWNoZWNrZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5'
    b'ZXIiCiAgICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTY3NDgiPgogICAg'
    b'PGltYWdlCiAgICAgICB3aWR0aD0iMTkwIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBw'
    b'cmVzZXJ2ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmlu'
    b'ZzpvcHRpbWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZzti'
    b'YXNlNjQsaVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUw0QUFBQmtDQUlBQUFDM3N4MkRBQUFB'
    b'QkdkQlRVRUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFk'
    b'VEFBQU9wZ0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUF2Ckpr'
    b'bEVRVlI0MnUyOWQ0QVVSUnIzLzNTYW5wNmNkemF6Z1YwMndiSXNHVW1TSmFnb2ltTGlEQmd3'
    b'bktnbm50NXhoak9kT1dGV0JBTXEKRWhUSmVZRmRkdG5JNWh3bTU5eXBmbi9BQ2FMeTN2dit2'
    b'RHZYbTg5LzAxMWRWVlAxN2FmcXFkU1liT1JORUNmTy96MTR2QWppeEtVVApKeTZkT0hIcHhJ'
    b'bExKMDZjdUhUaXhLVVQ1NzhMZVNGWjRSZ0dXTHlNL3BkQmdFUVIvVjlMNStUWFQyV25KY1NM'
    b'NzMrWmZwc25aKzc5CjhRWXJUcnl2RXljdW5UaHg2Y1NKU3lkT25MaDA0dnhiSWVORmNCNmlL'
    b'UHE4WHIvTndjWllBR0Jrak5Ka1VHczA4WktKUytjTWZjMXQKNGZhK2FKY2wyajBRN1hNSURr'
    b'L0U3dWJjUGpMTVVxd2dPY2NleDVBWWxWT2tRaVl4YUFpalZtcldrU2FkTENOSmttNVdacWNs'
    b'WnFUSApwZk03SitEMjl1OHY5MWMyaGhvNlFxYzZaVll2RGhnQTFBaGVoOGpPb0V4ZGdwOEZz'
    b'VTd3ejZQTTMzRlduOGo1Z0ZzcVNkM0VEdVR5CkNyZVhqZmFLd3dqbFpOTFFKSVl5Y1RrQUNJ'
    b'Q3FrblhLNGh4bFNhNnlKQzl4ZEpGY3BZeExaOURRc2Y4WW5hQlB6aHY2MDFzOHgzVWUKcXZD'
    b'VjFmckthcmdUTFpJb055QkdVM0NHQk9HbGFFY1VpWXNsU1oreWZWZFNLUUJnd0NTZmNuMGRR'
    b'aWlLQkNWR09sQnNBcVdMZ3NpQwpPSXN5U3dCYkUybGNSQ1VCd1BwWXo1M1NySTlpUFhwY01x'
    b'VTNmS2lyYWVJMm5SS2pXaG1TR3A2cG1WcHFuRE0rZmRUd244MnR0YlZECkNNZVNSK1RGcGZQ'
    b'ZnhHdTFWLy9wWldIVFlmZm96Q3QzZjNEdXJlN2oxUU5mNy9GdVBzUU1lTnJGMERIZW5ZWXpY'
    b'N0w5Q3lXSktUaFQKeFh0VGNkbEVVdmNKMjBzQ2RsQndGSkVxRXk3MUlUNmJVSlFMbmhXU3pD'
    b'WWhtQUJNTHE2WVNabGVpN2JkU21jd0dKNkEwd0JBQUw2WgpHNWhPR2JleWxzTUFORWE4RnV0'
    b'WUtrbmQ0YlZsSGg2WWViekYvOHo2eHJ4VTNheXhodG5qTXlhV1l0alpxY0M5MXo5c2JyQTB6'
    b'aW9wCmZ2YVBoc3kwdUlmMVg2QjlUMW41bEZ2aDY4TU9JYXFyNk9nK1hnMEE3Z0ZyOVlzZjda'
    b'eDhZL3ZNdTBOdmJ0N1RmVW9FT002N1dvWEEKUmFTQnh2QmF3UzhDR0hDNld3eEpNRUlFSk1m'
    b'SUZaTE0wNTJiVkV4YVNtcXljSGtocWRMZzFGN2V2b2UzNytjY09ZVENMc2IwR0gwNgphU1ZH'
    b'V3NWb0FpNVY0V1NYR0s3ZzNCTkovVHV4emt1cEpETkc3K0J0eDNqM250cUs4TXRmZGM5Yjlm'
    b'M1lhNnRlK05CcnN3TkFkM20xCm9XSEFqVmh5NThtcVdYZTE3andVdHpyL2FlbzNiTFg4OFJW'
    b'Sm1IVWgxb0RUQklLcTU5L3IwUm5DV3c2alVIUS9aKzhXd3pkS2hteGkKQjBRRTEwalNIbzgw'
    b'UmtFMFl2UkVRdGNpK0ljUnFteGNzVDdXYzcwa0xRb2lqbUVzRHF5YXVVSldMRlhJU2tnQ1Y4'
    b'bFdNYVU0Z1hQaAo4RVNlcFJFbStFSlgrUko5M3FBeUtzeWhUQVNHZXhGYlJLaVA4ZTV4bEE0'
    b'QnlEQ2lVdkJZeElnTnNmT29oRGRpdlVXRXVveDM1ZFo3Cm1iLzJIMzkrZzJMaFJMdlhvd1Zj'
    b'Q1pRWGNScTdyMnZabXRCVHR4YmZ2Q1F1bmY4RUFzOVhQTFUyK05KR2lrY0FFRUlDQUNCQW1o'
    b'MDEKVHBIZndQWmtFNG9tTVZoS2FDUVlyc0xJNzNockxxa3NKTlhsdkhzYVpld1ZJMG00Tml5'
    b'akZveWJMczFJWk5LVHBPbUp6SkJFZFhhNgpMc0g0ZjB3ZElUVFEycEhhMWh0cTZZbTI5dzl0'
    b'N2hwYjIrNExCakNBRGl4NFF2QVVFMm9MSDYzZ1BhV0U3bE8yZHdhVnNKVzFqQ1ExCm05eHQ4'
    b'OWVIMUJqaFJDd0dXQVFKR295aW9weHIxUnRIMm5wSHI3bExRdE54NmZ3YnNiZDExZDN6SEhH'
    b'by9vZDhxekJTaFpHbmZhVkQKZ2xPQmtTV2tkanpvMzRpMVR5SU5Pb3hlS2MwNndqc1hVSW1j'
    b'VWtxWERwczJ0a0E5dWlCcFhMRk1xUkFFM3RyMVBRb2R3a1ZMek1MMQpPd3RvM1h4RFl2SHBt'
    b'SjBEUjNGY3FqT1BQSk4wZndYdi9SN2pHakNnWlNtSnNtR1RFNGNzdzNFOEVncjNINjhKVkRV'
    b'bG5td09IMitJCjJKeEpPSE9NZDQ4bXRaK3l2VFl4T3BiU2ZjTDJIT0ZkODZoRUhEQURSdk9B'
    b'ZnVnb0VDTGkzdGh5c0txNThKVUh6Y095QjFGZFlCZlkKd2xmenpkOS9PK3QxZ2w1ZjNkL2ZE'
    b'YTdiU1FXajU5MXlJVmFQU1FDQUI3U2JzeDNpWFN2cHJNL1p2dHVrbVYxaUtEVXRUVGQ5akdi'
    b'YQpxUFJaRTJWS3hROVAyWHAyQ2YwUEpTaFBpU0xnLzZ6SkdFYzYrRVg2M09jVnFzUytFNHNC'
    b'WjFKS1BnbDRlOXd0cTB5U2J5V2tjTWJ5CmlVRGdZQW1Na0tRK2IwcTU2SWM0MlZpc2M4OVIx'
    b'ODVqdnUrT2NoWkhqZUE3d3J2SGtOcnZXQ3NMNGl1eUVXZEVpV0lHN0h3Ync4cHAKMVMzemg2'
    b'KzZTZlpiY3U4dnNGNW4wRmdkaFVhdEdKN3QxNVhCVDZRRE9jbGltd05IUUFJbUFpaUFWR0hV'
    b'YlNuRjZrc256MWc0SlhQeQpHQncvM3hzWWFOK2s4dDBZUmJHT0FTbWpuMDFJaHlHTUZxTk5H'
    b'dGljd254bGFlaHE0UmZseUhlSUlsUWRmaW1SV3A4aXJ3dXpqSnUvCkRLaWhPRVFFdGlucTJh'
    b'RlYxRkMyUlZiaFUzUDY3TlBSU21nNmQ5NVVtRGMxOW5TMDg3dUQ2azM3eHU2b3FBaGFuNVVW'
    b'UGhscE9qTmUKUUFDV2xnU2Rydk95Sk9ya2RJS2VPVWZjY2F2enF3N3JlYndIWnR5bWFMV2U3'
    b'ZnJNS0I3MzN0K3FuM3MvOHNabVVrUUlnQy9OVHJ4aApmdGJsTTMrcEdoQkNBMGVMSkJUZTdK'
    b'eFZOUFlldFM3MWgxdU8vbkxvWDZxVDlYZWpWM1NSK3ptQmpxaldKS1A3WGVFTVBHV0RJV25r'
    b'CjJYRUJWMmQ5K1d2RGpOOUdPWFhLK09PL2xHRlg3MERYcDkvWlA5L2xhZTVNd2htZXdqV3Jy'
    b'OCs1Ym43RnpXdUkvWFZuYldweCtzWGIKMzJMa3N0K2FQaTVnZFFncWNlUXZQWGI3MVROMDZ0'
    b'L1FTNEFRS3J2amNmcHc0K21mVWJOYTk2ZGxZNSs1WHlxWHBWMDhucHd5UWh5WgpaYnI3eXRM'
    b'SDdqQVY1MUcwNUtjeERMUnVDRFROZHZua1N1RUxoRW1UaWw1VzY0YWNHMEN1U3ZiWXFwUkVR'
    b'MHd5Z3czVmlaZ09aL0lVCmFKOFB1OXc4OU9aelEwcGxXcFVtRlhrL1FKemRHNVFIbXhlRmhh'
    b'RUs3YkR6VXBTcGxVa1RTN0p1V1N3Ylh5UWRYNWo4cCt1SFhUYUwKbHN2VHJwaHA1OEtoaGc2'
    b'UzVRRkFZdlhaZk82MDJaTitjMFB3b2VpcjYzY08rbTd5eWRjK3diNDZFbE14MGluRjJxa2xR'
    b'NitlZDY1ZApTUnMvTW0zOFNJVFFoYnl6U0hPUzJtME5mdUtHSlZLK1J2SnppL1p4K1NScktN'
    b'YVlMeEhjZithRW9NSjhsYld6a2xDTi8xbWJIZVhVCk1Yb0I3WHZYclBFTWhKcC9jZlFNeDdP'
    b'bWpUdDNZSkNrcUhGclZucHZ2NnJyaTUyZWcxWGN3VnJ4dmUxMUkzS0ticmc4M21EOXlrUWoK'
    b'a1IybFN4T3ZuWnQ3ODJLMXlYQ3VLWHA3NjVlM0xid3lFQXA5c1A5Yk5VSGZNR2ZSTDBYaXNE'
    b'VEpMU1ZlcmpocGJObUZrK3RwMjZrSgozSVFRNFZldlM4MmFjdUhBQTBlTEZWUzdtSGxLYzA3'
    b'YmR4NGZmYi9aeTBkdm1uYUpTcTVZdTJYanJRdXVPRmRKSG91dC9lTXRsaTkyCnpUcjhNYzFJ'
    b'NDkza1h4T2YxVkh5NFpyVTBTUE91LzcwMXgrL2ZHaWJScU5ldmZsRFN6UlF1ZXJGQzBRUzZu'
    b'OUJKeFVST2U3L21GeGEKOXF5KzZnV0F5MzVKTnp6UGsrU1owa1BNT0RuWjFOdjF2RWIzOGk5'
    b'Rk9IWllZY2x6OTc2eWIvTlRsOTYwWnQ5R0Z4dGVmY1VOUDl6VgpKaWFVUG5STDM0eHhJWi92'
    b'TnlXZEN6Qm8ram9LclZxZGJENnY2OU14MEh2OXU4OEdoZGpXNmpLdnh6dTNZUFJkODY3ODBU'
    b'aFF6NDVBCjYvS0lrRVRTNXQ3cVA2YlNId1JqV2pydFRhbE05eU96TVRDZ1ZKN3ZFbVBTSWta'
    b'N2tVVDZvK3NPMjhDbnI5eno1YWNmdExVMDVRMHYKbFVob0FCRHdETjY5UVVjZDYrMzN5blFY'
    b'T2Z1K0M3YmRHb1ZNbWZKc1I4cWcwVlUybjZwc2JkaGFYeEVXMkdOdHA2NG9tYVJUcXMrMQpQ'
    b'YXFrQkVieDIvS3dMdERYR2NSeldHOXUrbXo5NFYyUmNCaEVqTGY3YUlVOFUydDhiT043SjF1'
    b'YWZnakRlWGNZcGVYSWNvK3ZwakJOCittNlVZeUthRjlYNnN5TnY1ZVhsMTExM1hWNU8xcWNm'
    b'ci9WNnZlZkdyOVNrSzlSSlA3TGV2WjFyWDN3MExFbVhhMU5VcGt5RjRveXEKdEthQ2dPSTVs'
    b'cGVrU2w1elZ4WGlqbFZHYVRucjNuVzJsOWJTOU5qRzl6STFKcWxDd1RzOElHTFJjSGhEMmE0'
    b'M04zMDJlTXQvTUhsWQo1L0hPa1IyZmxlOExoME1ZVFVrb0NZdUVDa3NueS9OM3oxNGNDMWtj'
    b'TFU4RysxNE54b3lJNjlITCszQ0lPR0xUUlBPcjVpSHp6NDJFCm9xaVVsSlE1OHk3NTZKUFB4'
    b'bzBiWnpRYUwramlZVE12V2ZMVk45OXUvVzVYM2NsakNLZExTa3JPR0F6RFNBODN5dWZ1MWRC'
    b'TlN0cnIKQ0tZR3VheVk3WFcvcXhhWDVobDA1aWUzYmRqVWNKem5PSnFXaWlRZ2ptKzI5eXZV'
    b'cW9VbEUzL0wrdmlkZUZqbm9aRXlEcDhIQVdBNApIaE5aRU5Db2pHR2YzcnFhOVRlTHZWY2tN'
    b'djFBZzB6WXd3OXBkVVM3YUhsS2lqN042bks0ZkY2OVduUDIxY0d4Y01DMVlNR2xib2NsClB6'
    b'Ly93aW1lWG1aNjFaSWx0OXh5UzNQVHFZN083blB2SnFUTmdyUlpMbnRuSUdZVlZObzB6MGlT'
    b'UUFBN1hjMWZTeksrMlhETDZpVnYKUFhHaXBTRUtPRTVRU0FTYno2T1JNSU8zL0FlbGREb0gr'
    b'aVNVUkM5WGdZQXdFU0Vra2dqTkxDajl3OFJaSnJYU2RmSVBKa1cvTTFyQwp5YThWRkV5NktR'
    b'a2dDUUMybHg5ZWQyREhleXNmK1NHZUUwZjMxQjc0TE5UdmVPSHRqMVRGNUliWHVtZGNlYThw'
    b'SWZFQ1NlOTk4clhRClJ6dTJMaW9nQW81Q0I5TjdlVzlxNm8rOEtyMHBBeUFEQUxyOEw1S0VJ'
    b'QWw5cEpmVld0di9ZQzdkLzZlcGk5NG5tWjJuVGdoSXhFUVIKUkV5dlZQVTc3REUybHBtY091'
    b'aHFZVkQyZFpvR2V1NWQvMXBSMGhDRVkwZ1FwVHp3TWE3SzBTTlZ5QjBkNzVvVXAvd1JsVFJq'
    b'WFVyZQpuZW41eTM5NDZ2bnZOeW9vaXBHZThWOU9sTzJ6MUh5VnJNTWxOVjdTNDB0TE1ZYWRI'
    b'VWUrL3dnQTJ0dmJmemJkN3U3dTVKRUZDcXUvCnFEK3E2NDhtWFRXdHY3WDk2TkdqRG9manA0'
    b'R0hGSzVJeWJ1VFN2c3dGR1BNaWlwYis4ZFNoYnpTMWNQSEJKcERTQlFSaGhVbFpkeTMKNGZY'
    b'bWdaN0JXQXVEVWpyVmZlM2JtcXN3SERkcHRJU2NCbDY0ZXR5MHc2ditNYXRrUEFTMkFFQ0lX'
    b'cXpXWjUzN2lEZmdqOGFpVjAwNQpNOW5rOTNxYkRtOVF5L0N1UGpzVEJFT3lzdGZxNld6dmk3'
    b'bmEzbnJyTFpJa0t5b3F6a3ZVWXJFa0pTV0ZQVDRNUUorYmxZdHJXMCtVCmQ1ZnRIenJFMk5m'
    b'WDkwdFoxWnJ5L2RoQ0FJREExbGtsNHcvZi80K2w0NmZpQWlKa3RGR2pKWEJpYTFQbHliNzJ1'
    b'SFQrUXpSYmVvVmcKNU92cXNtdEhUNXVVbnZmdThsVWNJSnFpQUFDNFRnREFGVlBQZTJURHZ1'
    b'OXprdFA5NFZDTVpRR2d1YkxDOGttZGUxc2Z6Z25SeVZwNQppVTdrQlZLaXJHeHlWaDgvOFBi'
    b'YmF5bUtjcmwrTkVNcDhId2dFTmkrZm1NVVJMN1BDamFmZWxNNUc0YXZQM205Y3YrWEZ5cGl4'
    b'UlFBCndMaE9BSkJLSkN3UzMxbCsvNlFoK2RlVVR0MVVXeVlFd3MyVzNuaGY1eitFVENxRlVI'
    b'UnZVL1hsSXlZVVorVGM4UDV6UzhaUE54dE4KQUFBWUF3Q0FoUE1ldVhIbUF2L1d6eDdaK0c2'
    b'eVJsK1NXOUJuYlIxK1I4SG5HNm95dGVteUJIMVc0ZFRhblZ1a2F0bW9UQU9uS21ZNQpzYU42'
    b'Zi8ydTNsZzBqQVNPbHFta2hwU2dwMnZ1WmRldi9PVGx3N2MrN3R0YXBvc2lZSWhGOTYya0ZE'
    b'S3IxWHFCM0dJZ25oNG1Bb0FFCmcxR21rTi93M25NcnB5OFVjR3hQZlRXRVkzS0dpVXZuUDhT'
    b'OHZOTDNqKzN1YzlxMkh0alZRM0VpUTgwcktEM2pQOU5GQUcyWTY2bnUKWUczNnlLZC9lR1JM'
    b'K2NGTk5VZGpPS3pac3E2WWtrK1FXM2NmckN1Y3Q2aXRxU25XNGV2MWxIVTJOT1ducXJlM2Q1'
    b'aVlTZ2wrUm5rOAp3a21wSEhBSzcyeDJ1VjFWNVZXSlEwY1VMNXNENVkyZWNGQTFkcFRLcUFl'
    b'QWpJeU1YK3pSVjk3SDhOK0RIRVQ2ekFhSk9mbWw2MDhlCmZQWFk5alJPMHNzSGNhTjZidDZv'
    b'ZUlQMUgyTCt1TWx6TW91UUlGaWpRZDdoRzI1SXZYejh0Tk8zSkFrcndxek1wR2pEd250L0NO'
    b'L1cKMy9QK3dlM3JsajlvWXBRSkFwbkpXNy9mVXduR0VkYU8ya241WktiU0tRM1dqYzNWOVE0'
    b'NEF0NEFqbmdBUU5vc1hqdVVTY3lqREVNcAo0MUJjcHBmTEZXYkN2NzZDUDJvUk45Nzl0NXZt'
    b'L0xWaXdaazF4UnMyYkhqa2tVZFlsdjNKT0JBaUlydU04czVnVkNsTnVPWDB4Y3ZHClR5MDJw'
    b'dkZPdnkwYVFvSXdPNk53d2JncGNlbjg1M2podXJ2a0NvVWdpbXF6OGUwYi8zaDZPaWtXRFlx'
    b'aFNnZC9iWHQwdGE3d214OEMKVjdRMXZyRHN6cE5sQjY1TnlsMDJZV2J5OEhsOXVhVnpGODZk'
    b'TWxMZmIvT21KZWsxT2sxNlJtcWlXWCs2dnBGRVJSRWdZVDFDME1FNQoyOE05MVp5bFdoSzFB'
    b'MEJVbEQ1MVBQbnJCaUtnTUFseTllbjRlM3A2UEI3UHlaTW56MitxTUV4YitGMTcrQ0VQdHBR'
    b'TEhPUFlLQUNRCkpMbjJ4ajlxekNaZUZHUUt4UXZYclJ5a1ZUQllwWk9abExwNDFDUmV6VHkv'
    b'K09iaTdOelRGMjJORHhxNTFlbXlkeExnMWFDNzhwK2UKMFlEQzZXbzRjcUE4Nk56bTdObFdj'
    b'YUN5L3VUODRST3d3SUJjSm9tRUkybXBDYlNFTk9rVlJyM0tIWXhGT0JGai9ieXpYUXc1T1ND'
    b'bApoaUhJa1B2RFBCT0pJaUpPOG1FUGNLRVBqdmc1amdlQUs2NjRZbUJnNE9ET3JkOTgrZG1w'
    b'VTZmT3pXZlFkU3lSZkRXVmZ0dkVQV1E1CjllanBpeU95Y3A1ZmZET3ZaaTR2bVpRMUNFZDBC'
    b'cmQwb3BGSWxqRnBRWDdwRGRNdnNkaXNqUjF0b1hDWTRGb0J3T0hYSzZRQnlya2kKNE8wSEFK'
    b'TXBZY3lrNmIwVTBkM2RjVjE2UGkxVGRHTWk3M1MwZm5DdzQ3VjYyb2RoT01ZRUlWenRFN3Np'
    b'akVMYURtUklRUFU4Q1FBUwpBZy9ZdW1ReHE0Z3dBWk1BUURiUkJVaUVrQTFFb1RPa2VPTE5q'
    b'ZHUyYlNzdkw5ZnI5ZG1Gb3hSSzFiN3RtOTU2K2RubTVpWUE4TG5hCkdjOUttU1RzOE9zQmdP'
    b'QmJRdUZ3WTBmYmdNMTYvYlI1Qy9KTHM0MkowVWdrUHByODcrVnZHOTRweWhnNnZXaFUwejgr'
    b'Q3ZiYm8vdXIKZEFteWl4UDEwOXB2T3M0NWhFaHMrZmhaVHl6NHF6TllUMlZPOHZYTzFEQXVh'
    b'OS9iU3MwYWdpQVNFc3hsUFMxNWVTTmU3YWdlZ2FnaApHdU5lenB1V2l0R1NpTlBoR2cvRExB'
    b'N1B0cXE2UG9POEp5MjUyT1Bzd2lVT0VRa1VpUUdtVFM4SUJvTUNUMGkxWm1IZzVEaWRwY0sr'
    b'CncyR1lBVTJmUThHeVY5N2Q4UEFzMkhhazUrSEhucDQ1Y3laSmtqTm16enRaZGNMdHNFSHVz'
    b'RUQvVzRsU256ZGlsbVR2ZFBwMnl3eGoKSGxqLytudGxPd21HSGtNYXI3YlF5TmEwNThIUHBk'
    b'Tkd5Wk5NK2F0dTNGdC9vcmFqOWJGcmJvbEw1OWZrbThhS3B3NThQZFRPUGJJNwpoSkFRQlpS'
    b'a2xYaFBkazdSRW1VelZKTnlpcDYrWm9WYW9RU1lDQUI5MXNWcWVBZEMrd0RXbkg3OHJxa0xY'
    b'OWl6YVVGMnNWMklkSFYwClRrbkxOSlVxVElTeHBia0hBRUJOOU9wUXgxQUQ3UXRoSWtvZ1FB'
    b'MjhQUVpHUWVUWkdCNnkwY0FpVHhjQTRCaVdoWGM0TUF4ME9UVHIKbXBzSGdRZzJlMHB4YjhQ'
    b'ZWNoblJXWDhrcC9paTBSTm5uT25yaFBhQkVxTDBWY21tSEREbEFNRFQxd3hyY1ZvUHRkUk4y'
    b'WE5LN2hZMQp1TVF1c3RJTjN3T0czMXE5dVNXQnpET2xQQWFEUXpxRHBzRzZaOW9pSkNJYnp0'
    b'V1lNSjlSMGJ0Z3hKRmNwUUtuR2hSQ2FWcjJxb3N2ClZ5dk9McXdoVG05YjRUclAvazhKbFdF'
    b'MGgwakVScUk3M1AwY3kvdERQQzhnU2lhTFJMbElOQVlnYWl3T1pUamN6NkxEUVZRamtuNk0K'
    b'SUlQOWZaMlZVYS9GNjNhSUVROEFOQXRFTjVVQzlocVFLTVl3SjBkbGEwUTJLb2xaSWRDL1pl'
    b'MGo3VWUzSHYxdWJTZ1VBZ0JCRUhDaApDd0F3V2VrUDJWREpGYXRtWGo0NkxmdVVYRlRnMU9F'
    b'Y2VjK0NFWDZqc3M2RTIzQVdJYmg3eXNKNGcvVnJnaEFTRWNyUkpyUUpsaGZHCkVjWW9TalpF'
    b'ZXpIMHRobUNFaW1jcXJ2Syt2UXJnUlUzWHZ6UEJSV2tEbGdBZEdiYlRYMW42L1Bmcko4emN0'
    b'ek94cXBqM1Nma0luSEkKMFhwMVFrMHdsQmtKaHJBRURVa1FpV3lNQ29CREtnc1NsRityeWZO'
    b'NWFJb1FCTlFjRUQyQWg0TjhEZ3AzeStTbk1sTWlBeFFBQWxsQwpFWHlqTXcrVEVoRUJwSDZC'
    b'RWtVMGV0SUlSc1o4OGM1ZmI3ajdHWlpsYVNvTUFCaDFkaUhIUjN1K1hmbkZtMUd2SC9LbGU3'
    b'SjRXb21sCkdXTDlJNUdEa2VJMG1hTXhJUXdRUXVldS80cEw1LzhYcTk1NThmVzYvU2dRQVlS'
    b'QUVKdzA1b280UUk2TEdJMHhFamxKWjZrTWRYMmQKRFcwdEJkazVBSUE0S3dBZzRreWRtVlRh'
    b'ZEZQaTFySy9MOC9xZW05U3RMVmJiT2srd0lVUUlwUUNra1JqWENBWUhwRExIVWE5MXVFVwpT'
    b'TktQRXphS1JvSTRoQlluYW9rNkQ5dWtZQTdKRFJHcFJLQUlPZVlPcU1mcXBGd3E3ZVk1WGtM'
    b'Z0VRNlg0bEd0U3I1L2IyVnlpbW5vCnNJenZ0bTJldi9BeUYyZFNneFhGdWs1bm83Rzl0YTYv'
    b'TTFkdGFzZXdFTStHSWx4RWhuc2lkcENLSUNLUngxcnNBM2Q4ODA1ZFc4dUwKdDkwZmI3QitI'
    b'WjVaZnZkemM1YmxKS1pnQ05GNnRjaUxXQ2dtUm1NZ2t5QmZKT2oyMVBsdE9Ra3BwM1hUVmZX'
    b'QTFQdG5BQURabWIwcApqZDN0VmEyYmIwcG9TbUxDZ2dqNVdiaGVqU1FFQ0lKUEZFR2paS0l4'
    b'WGhBUnhMaWVyRlNCSkpLc2RwdEczU0dWZjQ0VUFrSkZXc2swCm1hQ05STEs2K3pNcUdwTHQz'
    b'MkpDcEVEYTQzSDVFQkxDVWI2bnRkRm1EUVI5WGw0VVUxT05KK3A3MmhxcUFBQmtFd0ZBNHI2'
    b'L3AyWU4KQU9SbERSMXFTcTd6MjRKdUwvSkZRRVlKNFJnZWlvbThRT3ZVR0lLaDVwUm5aMS83'
    b'M0IvdWlUZFl2MTR1U1hMbEpVdFdYckprOFF1UApianQ1QkpmUlpvWFdqM0VCajQ5UU1raEJB'
    b'eXU4ZkhETDhvdm5VeFJGaUwxcWVkZ2JTVlJtbkhsM1czcTc1L0VuUnhlZ1lCanI2aGR0CkRn'
    b'eGhtRktCZkVIS2FGVDdnMUc3MDVzU2pvVWx0TFo3d0JnSXBDbXB5MktPN2lqNm50YTJobkdC'
    b'Z0FhUUd5aHVkaXBqOFVSYkxENkwKWlcrZkgwS1lMOWpiNVBmN0VBZ251dHU3UklKRlVMTzFj'
    b'clNPdFBRNkFSNlhKei9nN3oyZ1ZUZ2piRGNBY0J6M3lxR3RnQUZ1MW1MQgpxQmpoVkRxTlVp'
    b'UXNZVi9NRjV3M2N2eW0rNStNTytmL0Z2cHQxaDFkZFVoRXVFNCtOMjkwdTh0U0RwMlpTdjFY'
    b'ZC83VjdmWDIrVjMxCmJTMGo4d29NZWErNzdBc0R2RTNXZFllN3V5aDk1QXN5ZDh2OEtjS1FK'
    b'Q3dVZ2RvV1JFdkJGMFRmSHRQc090YWtTL1pvQ0F3aGtFakkKbkdBQUJBRUQ1QWx5Rm04MFhT'
    b'MjlMdUpCQXp6aUlWRVRkUUhyQnluTEMwcTFUTnE3UHFLVWY2TlNBa2U0YVlXbzBrQWlnRDgw'
    b'dEtzLwppOEZsTkZHNjhLNnV5dHRwMUJvaUgrTGtCbVBXWEFDb2IydjUrL3pyVTFVR25VWnp4'
    b'ZXRyMmdQTzBRa1ptUWJUKzQxSFJhZDNWM2RECnI5V1NhazZNUytmWHA2eTFubU5aWEMyL1kr'
    b'VDBaUk5tTEYvM1VxWkNMOGVvOU9TVUFCdlpzSDNYcDZ1ZUFBQkdybmZ6V0RJOFFrbEYKaEk3'
    b'WUIyN1M2TE13QWNyclVIb1NscHVCVzN6cWpVZTBueW96eGJta0ZVQmQzdWpOSG9JWjFRQkFS'
    b'VmlKMTY5azJUcVNVUElvMnhjTgpxWkRCem5XcnBEeW1PTWJRRHEwc3BGYkEyZlhjNHVreXhD'
    b'T3hzYzN0RTVOa0hJLzZmZUx5OFRubTRPMEFFT09PZWNYMVVrWURBQ1B6CkNwNTkvcytyTDc4'
    b'aFBUbEZUcEFaQ3AyZERUNCs1U2FhbHI1eFloZkhzbVV0OVZjTkh1a01wdEhrVFNmTDlMUU1S'
    b'V01jRWdvemhscmMKem5wSFg2NDU1WU05MjZZLy8wQVlQN1B2TXhMMlU1NUhLVkowY1JNdCtK'
    b'UG1sQkhqSnM1YS95MUJFRUNTRUlpUVYrek8vOEtmSmRJUwpJSEFnY04vNEFuM2ltWjJLSENN'
    b'SkpScXM2VWtVb2JxMWpMeW5VbjF2cGE1cTJKREtqSXlhSWFsZENhYVFXcEZDeXMrK2VaR1lz'
    b'cnVQClc3OXZUbU9UTkJLbENJeFY1L3pqaStOSjZSTXM4QmNYTzQ2bWVNenhaNDZMblJrRXgr'
    b'SGk1eDk0ZjllV25JVFVCbWRmbjh0ZVBIUVkKU1pJb0V0UFRzazNWWlJmZXZmcWJZdERzaUhC'
    b'NjNJa3FqVkdtUHR6ZFdHWHJWb3BrYlcrbjErOUZCUDVCM2NHSTFYWEQ1TG1UOG9ZRApnSzM5'
    b'RXhQeEdjdmh2UG1yeE14TEFVQW1rMVhXczV6dmtDakFHNmZTRHdaVHhuVTNEYW50TWxrZEJu'
    b'OTRsaVp0U2Q1RUE0c1Foa2RCCmpJa0NodENxM2I2UlBpS0UrTjFtc1RxVENVdUpkSmsyQTZn'
    b'Rm1veExrdk5TM1g2b1A1WFowcEhaYnpISWhiNlN3b0F6MkhMS05XSDIKRlkrLzlLNVVLc1V3'
    b'VEdXNktNam4wcEdQbExUYkdzaFY2WXNBb05kbStlN293ZTJXUmpIS1daME9rMW9MblBEa2dh'
    b'OEI0SjdKaXk0cgpHYStpWlhMbU4zUm93ZTloUjRSQnE1dWhIZWNKaHpDQ1FON3dzenUvaUxB'
    b'eG5DQjdXdHRFSEJtU3pNdW56dXNjNkt2dmJoOHAyUWswCnVDSkRVaEtMZm5qODN2dit0R1ox'
    b'N2ZwVDdpTWFKV0RRSzlkSGNoTkNVa1pqU05ndDhIc2I5dE04RzdGWmMyaEZTVm9JanNoSGV3'
    b'Z0EKa0dQa2VJL1lGY0tURTJ4bExiWitrbWhYTzhIVmh1TjRxREFUWWlsTUpNcHdVWUtoTXcz'
    b'TWZaOThzbkRSai9Zc0o2U083K3RPVE5SWQpJTFRyMjJQSitXbVpOMDZaKzlLK2I1dzJSdzhm'
    b'SUJqQ0h2QSs4LzBYeUJ2QzFMTENsUFFaSThjTm9rWmdrQzMxV2pqNm9xS2RYOWFKCjNYNi8v'
    b'L2E5bnNRUVVBSmFPMUZ4L2VKTC92TDFCNTlWSC83Z21uc2dlZ0pvd01rZjdaWm5HT2FwZjN3'
    b'MTh0RmJZL1gxNG9DNzI2VEIKczNTQTR4RXVDQUJBQUJBWXBDVlNNdVVKamhncDlnWXdvWXVJ'
    b'OUl0UkhVY3BmTExqUkg3UGtHQlFZQUVBSWhFZ2NBQkFvYWdvcDdQNQo2SHhMbDVvUVUxTlRm'
    b'cVpEUUpvQUxGaTBVb0FiUnYxOTVkWEZrKzZlZE1tSDc3MjM0a2lRSjZCZmhyMDFYWXNwcFlX'
    b'bXRBV2pMeHBjCmRURm9wSE9pdWFIQjJwT21Ocnh6M2IxTDNuMHFwN3k1MEVkd21JZ2g3QXF2'
    b'OHZWak94eCtUNUpVTlRWL0JHcTJBZ0NJd2ZOckVjYy8KdXVtQkxtdi9zNXZYbjZxcEMrNnB3'
    b'ZFJ5WWt3T0FCZ0p4aHptUnFyN2V6eld5aURUTjRUNlRCYnpzMUdUVEkxcFpBRUZVbmEwakRj'
    b'UwphYXBZdVRlRms2dnFLMCtDUHdJV2wwSGdwa3hLc3dhUWR2aVVrU1UvczlnUGlRRUF3SVcr'
    b'V2FWanRlc2w3eC9kYVZScGIvS3BwU2lNCjhURGNqMCt2RHpiUHpuMzN1bnVQTnRiMitKd0Y1'
    b'clRTM0lLNGRINU5VZ3lteTk1N3l1Rnlqa2pOdklaS1ZmUTFlRVZPaHBFUkpLUTEKMkMrMTJ0'
    b'ZE9WTjQ0ZXk0R2dPTWlBQ0MrLzZlUkZHZm5GbWZuemg4M3VicWpaZDJoSFI5OC9Ybk1IY0JV'
    b'TWx0L3IxMUMxUkVHb0FtZwpJUUNna0ZIaXZpcHJhQUJQTXltenpjNUV3eTRBQ0FOSWVGM01Q'
    b'eTdMSEkyd2hGcHh4MDMzYVpYTWdzdXUvTm1wQTU3blNXUUZBQXhFCmlxSnVuREw3OGMyZkxO'
    b'alRsdWFFa0NoSU1jS0RzWlA3NkZKSittM3JYNjdwYVRmbzlCVVB2UlMzT3I4eVpyMXh4ZGla'
    b'aisvZVdOM1cKakZuNE82TzRGY053REJpTTZJVllUYlorWWtIeHFnVkxHVm82RUZITHBGNmp5'
    b'bjMwd01lRnd5Y3J0VVBPaXlyczlpaWJMSCtadS9TdQoyWmQ3L2Y1RHJYV3ZiOXM0VU5QSVJX'
    b'T1lUb21uR0VBcUNjUllzbWdJZmFwYjczSVBDWHVHRHpVMkkvbisydDdyU3BPMVhGaHJUTW1Z'
    b'Ck92L1NHMVpLcGI5NEtvWGYzVnBmYzJDTUlRd0FBcVlqQ09MK0JVdjN0ZGJYMjA0YW5jNFVY'
    b'QUlBTENVbXhiRFhqeHlvVGlJeEpYUGIKMkptSkJsTmNPcjgrRHl5OHR0dGwzMUJ6K0tRMFZ0'
    b'N0RqckJSSVlGMUtJZ3ZTclZXTS9OaTZWU1psQUVBSkJrT2NKREFRWXAxZVJyKwpFY0FjZE9i'
    b'WCtzUXpQVkJyYlZQdEZROEdMSTRlcVREcHdWdExWLzFoZEg3UmxlT250dzMwSG1scnFPeHEz'
    b'bmVzTE56WVBpNC9WUzZFCkVqTjBHQjhaOEVRMU5EbEttM0h6c2dlVGRVejYwTUtrMUF0OVVz'
    b'VGV1NWZ2V1JhTUduU3FwV2VNRVYwRUFESXBzNngweXIzdGpSYUoKN3FvVEFVTlEwQWxNZVFL'
    b'Y3pHUW9tbDQ2Zk9KRGk1YkYrenIvRmlRVXRYalVwRjBOVmYyKzRFY1QxWk1iQXZQYnNhTlpS'
    b'SmRVeEdLeAorejU5TTBHam56OW1FaWhtQURvSUFCRFluSnplM0IxYUtnVHQrbjlHY25qMUM4'
    b'aGlyeFA4ZllFSTg5YzN3cDBEazE5L05OVmtUaldaCnB4V1BCb0JlcThVVDlBL1B6bzFGbzYy'
    b'blRwNDgrSjBwYldqeGhCa0o1cVIvTVorUmtCTkpacWJLUHU5d2ZBV245L2JJWndMQXR4V0gK'
    b'Ny8zc3pSakxkalBDa1N6cGtpWitTeFo1b0VDSm9weFJwbGs4NmlMSjZhMWtnNFRCZEF6bDNw'
    b'cUtLOTU1SXVqMFlrb20xNWpVNHJaSworN3hZb2k0Y2lRQ0ZvUWh2VktsUFBQV09naEw0bG1J'
    b'VjQ3TTRVS0lSYzZnUEphU2MvVXJEMXBrM0s0KzM5cU9vQll2Nk9IWUVxVTVjCmVkWEVwKzc3'
    b'ZjhpUHdQTTlWZlVTbWo3dld5RUlJV3ZQQWFOL2p0Mk5FdlNZTzJTUUY5YjVvM3pwNnB2dFBo'
    b'L0drTUFqbVZTS3JKNW8Kc2laSFoyNTJES0JBV0dIUWJyejV6eGNYai81TjZlUDM4TEZxbTl1'
    b'NTRwTlhnblkzcmxkaVVzbVVJZm1BWVdFWkVSWTVUQzVCckdBMAo2SjBvOXN6V0RVcDFZb0Mr'
    b'RXdDTU9zemxSVUt3RE1Nd1o3K2wvWEJGOVR0ZjZPWlBzdWxvNmN6U21TODlta2Rwdm1UN3Jh'
    b'OS9XYjloCjYrbFVtci9aWGZ2UnBsZ2tlb0djSUlUYTloMDk5c0J6M3hSYzJqM2puc1lwdCsv'
    b'NXkwdlZMMzk4Nk1aSHZpOWF2TzJldnlHRXhHQ1oKdzROTU9nd0Fvb28veXVUYVo3Wjk1aEJq'
    b'Sm9NZXNRSW1sNFJGUHN3UWdHR1QwL014cVFRM3FJTjI5KzBiWHJFNDdmRUc2MWRtN2I2dApQ'
    b'UkV2cmxVQ1JjNVBILzczYTIvZjBWN2JGWWhnQ0tGUWpKSExsNDI3V0FTMHBhcnNqcTZPOUp6'
    b'NzdiWGJUYktUYWlYbUM3d2VDaXpsClBZR1dQNzdJTlBVRFFBSkF5c3BsMmRQR0I5dDZMM25s'
    b'MDByV3hUenlac0xZNGUyZmZiZjVpWmZWT05YMDByclJMLzhwWS9LWWN6TWcKaW1MNy91UHVY'
    b'Y2U2dnowUTd1Zy93RHNLQ1pXZTBMSUNIM3poTXdLakFZQXp5Z3N2blJYeTk5T2h0YWNQN0xL'
    b'R0o1aEgzdG5TM2JtOQo1dGpkVXhhUUdQNzZnVzJ4WUFTVGtFaENwU2gxZjc5MmhlMWQvOWF1'
    b'V2x5cjdBbDczOTYzN1M5WExvOUw1OWRreThtakU1S3pKMllWClRNakltMU02QWNPdytRV2w3'
    b'd2E5a2hBWFlQQU1qV0ZhYnZHYzBSUHVuYlg0M3ZkZjJ2aW5wN3VJTldUa0RoM1RwNWYxV0J1'
    b'WENlUXoKUWpRbUF1QUFIRVhJRTQwQU1PNXZLd08xclIxN0R4eTFkVm1XM0t2c3NDY1FUQ3Nm'
    b'SUZ2YTdBdnVHTFhpNnF5VlN6dmUyQmpyc1hJRApEbWRYUDI5M254SUNKSVlGRVorUHE0eTUy'
    b'WTdNcE5qMzVScU1FakFReCtZbXpSaGo2KytrNVE4a3lHd0E0SXBrMnVWcmtpbjZrVS9mCjN2'
    b'M1E4eWtKaVRzcmozNWZVMzRLV1JRc3NHckYvSUpTcFVMeHhUMXJkbFFlTGV0c1BOeFd2Nlht'
    b'YUZ3NnZ5YUNJRHd3N2RLckxwNzMKSTNkZG9YMTh6cldWUGEyZmwrKzNCTHg1cVVNQ29kQlZi'
    b'ejlaYmVuK2NOZldQMjFmdCszNjF5Qnl0NDdwTWNzT2RqdFdGcXg3WGtMcAp2TjM5NnVURXhH'
    b'SFpBRUNRNU9oWEgvYlA3S3pxNzJ3NjFUQ0MwS1FVNXcvTHo5ejN5Y1pBTE56MDhsc1puMi9S'
    b'T1NNY0VqTUp1VVh3CnlZRXc0QktaUXA0NmUxTE9kUXV6WjB3TSt2dzlYKy9CQ1Z4Wm5Kc3lJ'
    b'cy9yYkltMFgyK1NWUU9BTTV4bGxiMDg3NzFYbjVubjI5N1gKTVBEMlU3c2ZlQzQzT1gwZzRB'
    b'R1duenRtYW1uYTBDZ2JBd0FNdythVVRwaFRPZ0VBUHQvem5TQUlCRUg4OWl0bGNFeC80amhl'
    b'bVBtagpqK3hGWTdFdFIvZFg5bmNFUWtGTDBETkNuN2JsVkxuTjVmaXN0a3lNY1FoUXJhVkxv'
    b'MHlhVXJyYWJ6OG9veHdhK1lBWTJ5a3FTN1BHCnpGRWxHQUFnRlBSRVFuNXRZcEo2YktGNHZF'
    b'bm1DV2ZnY21sdTJzeFBuMDhlbWltcDdwUUdJcEZRZUFkbld5aEp0RXBRV21sUjJ1V3oKUnR4'
    b'L3cwWFBQMVJ3OVh4OVZwclBZNk1rWlBMWWtjYmlZU3F6c2EvbGM4SzZUQy9yQUFCN3VGZzJk'
    b'TlBhWXlmMnR0UWdFVFVQOUZoQwpYcG1JdjdCbms1RmduR3hRVDh0N1BFNkppRTB1R0VtUlox'
    b'L2d3c3loUC8wc3dYK1IzK0dCY0ZLYXZ2K3laWmU4OW1panZVKzBlNC9oClhYSVhYdC9UaVFJ'
    b'UlFrNzN1QjBRWWVzR3VtU3FETGQ1UTYvbHNWVDVaaTB6d0FldjdxNjRuRW02bDhCRnJIZEJp'
    b'RFBMeDU1SUdWczgKYi84SFBkOGRqSHA4UXhaZERBRDVTK1psekoxYysrcjZ1bzgyTGVpVEFN'
    b'Q3dOYmVWM1BtalFaZFlMQkpzbkNJbC9iR01uV3dzR0xXOAptQ2pkU2pBSUllaUxYb1VuUDhZ'
    b'b2t1c3QzU2pDZHJ0dE9Fa0l3ZWlMZTc3bVdTNU1JTjd1MlljM0R6TW12M25qZll4VU9raXJZ'
    b'SkI5CkkrSTh5azdWekZuNzExZ2dCQUFvR0tGVkNpSVlLYkdLUlM3b3BkanVQRk9mRWc5U2FF'
    b'N204TnVIVTZNMXJ5bG9Qd0J3UE41c0hWNlkKVWgxbWxYNzZYbUJLZVRCTEpMUkNwVmVxak9j'
    b'NVUxMFZOVmlNUzU5VWltR1kzMnNMQnR3Y3g1SXdnRUxITmR6TGpDUlMxenNpUDdtVwp3QkVB'
    b'QktMYTVzZ2R6MVZ5Mjl0ckZCeVdFaERUVHRsVGVVbURIcXMwWTd5Q1lmMUJUTUVBQUsyVWI3'
    b'LzFMeE1MaW4vait2ZzlITG45CnMweklIL0hJMU12WDdQOVM1QVJNS2lsczhONWN3L0tDQUJp'
    b'V0p2THBqb0UzcG1zZ2h2VUYzSTJoaS9KemR2cHMvK0E5WDFLRUlNZE8KY2p3bWt3Ums2SEVJ'
    b'bjU2ZWdKZ2Q3dzBuWTh4SVdkS0R1c1RTMDcyUWpESEZUa3RaMzRuRkVLczF5UHNUcUg4dXhj'
    b'SUFKQkNKZ1lxbwp0am1CRXdoU2R6V2R0S3JpUkYxZjRCQWZESHRGZE0xQlg0cVhVMkJDUVpk'
    b'NERVRzhONEt2S3RBQUFFNFJxNmRjOXR2WHplOW5OUGxuCmVlaXk2MG96Y2ovY3Y3MnlwNjNF'
    b'NGNFNWtRTkJBRVFETnNRcnl1VHljVWxaenk1ZFVaU1ZBd0NuWEV1a01vK0szcStROGorTmlw'
    b'YUkKU1pKZWdGNXYzNGtPOXhNUy8rdUFFYXp5ZGszNGdTVEdDVDkzZmhKRFEzb1NGZ2hUYm41'
    b'R21GcVNscFIvMThMOHFZVWxEMjU0OCtoQQplNXJYVFlrUWdKZ1VNSW1JbGRoRjd5aHRTVnJt'
    b'VFZNdnViaDR6R0F2K2QvRHg2cHJlOW8zdDFiR0FtSE1LQmIxaUVnRUFpTTBPTUVoCklQcGNl'
    b'M2wyK211UHJDaWQ4ZWlTNWZuRkN3QVcrTnpkVnV0bkJOL09pUlFFdHFzWWY0QzhISk1Xa1pS'
    b'VzVLeFU0RFV0TXpEZ09wS3UKcXdTQU5uK0JXdWwwUjFJNHhlMkVKRUhnUEdMa3BFcjh4aGRO'
    b'UU14VVdvSjRQRnVac3pSVGt3d0FITWM5L3NYN2I1N1k3UThGRmJhQQpCdUVVVG5oRVRrUW9o'
    b'Z3Y3alVLNzA5SVg4NVZrNU1TbDgxOW1UOVd4RDh0MmI2dytMSG9DdUU3Vm02ZnZyZTR5STBx'
    b'SzRXRlJDRE9rCm1Ld0ROdWJyNm4vVzkrVzZpcjJyTDE1ODY0SWxhbDI2V3ZmUTZSZ2E5aTJX'
    b'cFR5V1lqNzc2WW4yNDAweDMxNko0cDluS05ORlZxK0oKWlM3SnlEdmI1RHY2VndUYlg4b3Jl'
    b'ZlBjekx5OTlZdS83L2xxd085R25oQ21VNHBKV3IvVUpvdndNb3dNZzlCTmNEMzVLWmpBUjYy'
    b'dQoxVnZYVmZWMjNEaCs1b3hSNCtMUytlK1FxRGZLcE5Kc1hZS0hVZmpDSVRZY3RwamxaZ3ZY'
    b'Q3pGU0tqbVlUaEFVZVdQQnVLSHBHWDBPCjY5cDkyKzcrNnUydGpaVXZYbnVubktLTk9qMUpr'
    b'dmxUdnp3OXZkVzJZNSszc1VVNUxEdHA5TE55clViZzJmN3FmUWlJckpLYmNYeEYKSkJCczJY'
    b'dllYOThvTlpzS2x5d3lKbzh4SkswSEFKN25IVzVYaUl2ZHYvN05uYWRPZ0NEZVBtMUJpakdo'
    b'cmJ2cnE1YUtiWm5FbEM2QgpqYkVHUk5rVFpHd2dTREpTZFZLaWhtYmtVc2FzMDhldHpuK04v'
    b'UFNzeTRvbmZINzhRRGdVQUpMQUdjbW5vOUMzSVpIVHl6Q05QR0IxCllqN2YrdnF5aVM3YlUw'
    b'dHZjMGRDbjljYzJWRmJNY3YxeUcyanByOTRlTnVJNU15WncwWmVOMmxXZ3Q1dzRMRm4wdXdC'
    b'RDBCYmtuSFUKZTgrYWgrVWtEUDhBeHltU2xEaTZlazdjZEQvWk5RQUFUWlJZY09WQ2g4ZTE3'
    b'dkRPblkwbmF3WTY3cDB3LzUycXZiMEQvUmhETHhrKwo4ZnBKc3g3K2JPMlJnWFl1RWptUVRW'
    b'ZE5Tc2E4SWNJWjhpc0lZR2lXWlIzaFNGQ3V1TFI0UW1IRzBFRmQrSVBiT2Q5NjdPRE42MTd3'
    b'CnNUR1EwNlF2eXVGSVN6S2VzRzlpZHVHSEsxYnZyajhSNEdLdWdOL2h0TnVEdm5BczZnZ0Y2'
    b'Z2E2VURpbU1HZ3p0UWwxZmUyQTRScTkKYnZubzZVbXZieG1pTi9Jc3EyanFDYWNtVEZqM3Ny'
    b'T3BUWldTeUVZaVRhdWZKVnQ3WXNPR3VCdWEzUXpaOTlEVjYrckx2QzQzSUxFdwpKYlBUWXc4'
    b'NlBSaERGeWFubTJSS2hwYWFGQnFUMGFSWHFwUVVQYU93OUthMVR4OXVyZFhLVkI0K1NvbUlW'
    b'OHNnSEZPVDlEdlgzN2Z3Ck4zK0s0Ty9XT1RlcTFCL2U4QUJHWUZ3by9PNngzWmVPbXZUR2dh'
    b'MmVEdC9zRVdQVEVoS1hKeXc0Ti9DSnhycW5OcTJ6aW4wQkNRUjkKL25vdVJxcVZRampxc2Rw'
    b'ZlBMaDFhQ1orZjZQRk1HMjg2cElaYlJ1K2ZHZlpMYVA3QW03RXUybkNIQlhwaVNWQ3FnazU3'
    b'Qi9rU1pvcgpkb20rRU03UWhFelc0T2dUUTFGR1Fxc1FtYWJRUFh6cGRXTUtocCtYeVRuRll3'
    b'KzMxS2FhekU5UFhiRHA1SkUvako0dVVjaVJnTFFLCnhXQTUxT0ozYUhWK3lyQ0hiM1JhYk5Y'
    b'UGZwaGlPcHZ6blpWSDM5aS85VkJQVXpBVVJvRXdScE9UaHc1Zk5HcGl2OE8ycnVhUVU0Z2kK'
    b'VndBd2tIRGlRaHNhN1JRUkk2R3Q3a1Jhb2VERktqNUlVS1Jhb3ptaTRMNUt3bGtLQndTWVht'
    b'a2dtR3VMSnFZbW1EZFhIam5ZV290aQpQS2FVS2VTeWk5S0dyWmc4Zjg3b0NXZGZYSWU5K01F'
    b'YnRRbUdscWMvSG5UNitOMWFuWitTck5BdW5YZlJEN3FKUktOM3Z2L0M1ODNsCm5Nc1BvU2lt'
    b'WWpSNjNSTUxycjkxN3VXaUtQYWNyTDFNMVBkYWVydGxIbFlxSWVVeTZMTktxOXN5dTkxZXBT'
    b'YW9rWWNEVVNMQ1o3R1kKaHlLTGhoY09UMDFnZlg0RndzMGFmWFpLT21NMnBvd2VlZGU4Szkv'
    b'OWZ0UHFyUi83Z29GQWovVTdsM2RuZDhQVkZXTmZXMzdmNlFXdgp5VWJUM1hPdjJOZFM5enNy'
    b'NnQrYmRKYVBuWEhGNUprLy9BeUVnNHVLSjZUb2pTZTZXeVBSNk5ERTFEL09XandzUGRObHM1'
    b'ZXQvUkErCjJpSVZrUXFnNkp3WUJBekRMaXE1NklFN0VvdnlCSjUzZEhUVlBma3FmYmd5OWRz'
    b'VDV5YmtBRUFBZGROTEp6NTh6ODF6THB1VU4rS0YKblYrMVducWxORDE2U002b2xPeGdPSFJh'
    b'T2dEdzRLWExNZzd1L0owVjllK3R3ZnJYT2ZETXErR2pWZXBoV1hSaUFzVklnNUVJQUNoMQpX'
    b'bDNwaU9TOG5QTUMyenE2YkVjcU9JZWJZMW1aU3NuNmcxR25POURjVG84WU52MkpoK0gzeS85'
    b'UWcvV3ZrN3YwVXZORC8rcHgxd21aClF4SXloL3owK2tCbjEvOXNBZUwvcy8vY25QWXJuSFdk'
    b'bERFa0xwMDRjZUxTaVJPWFRweTRkT0xFcFJNbnpyL2luRjl5MjNNU2lveVgKMGY4eXZDRDh2'
    b'MGlueithT2wxMmNlSU1WSnk2ZE9ISHB4SWxMSjA1Y09uSGl4S1VUSnk2ZE9MOVIvajh1QTVw'
    b'aVRUTGh2d0FBQUNWMApSVmgwWkdGMFpUcGpjbVZoZEdVQU1qQXlNeTB3T1Mwd09GUXhOVG96'
    b'TnpvME9Tc3dNRG93TUhKNHJSUUFBQUFsZEVWWWRHUmhkR1U2CmJXOWthV1o1QURJd01qTXRN'
    b'RGt0TURoVU1UVTZNemM2TkRrck1EQTZNREFESlJXb0FBQUFBRWxGVGtTdVFtQ0MKIgogICAg'
    b'ICAgaWQ9ImltYWdlMTY3NTAiIC8+CiAgPC9nPgo8L3N2Zz4K', 'US_WV')

US_WV = b64_US_WV
index.append("US_WV")
index.append("United States of America West Virginia")
catalog["US_WV"] = US_WV
catalog["United States of America West Virginia"] = US_WV
country["United States of America West Virginia"] = ('US_WV', '', 1)
lookup["US_WV"] = ('US_WV', '', 'United States of America West Virginia', 1)
lookup["Charleston United States of America West Virginia"] = ('US_WV', '', 'United States of America West Virginia', 1)
lookup["United States of America West Virginia"] = ('US_WV', '', 'United States of America West Virginia', 1)
details["US_WV"] = {"continent":"Americas","capital":"Charleston","currency":"","web":"","lang":"","tz":"-05:00","altname":""}
regional["US_WV"] = ('US_WV', 'United States of America West Virginia', 1)
regional["United States of America West Virginia"] = ('US_WV', 'United States of America West Virginia', 1)
#----------------------------------------------------------------------
b64_US_WY = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+'
    b'CjwhLS0gQ3JlYXRlZCB3aXRoIElua3NjYXBlIChodHRwOi8vd3d3Lmlua3NjYXBlLm9yZy8p'
    b'IC0tPgoKPHN2ZwogICB2ZXJzaW9uPSIxLjEiCiAgIGlkPSJzdmcxNjc4NyIKICAgd2lkdGg9'
    b'IjE0MyIKICAgaGVpZ2h0PSIxMDAiCiAgIHZpZXdCb3g9IjAgMCAxNDMgMTAwIgogICBzb2Rp'
    b'cG9kaTpkb2NuYW1lPSJGbGFnX29mX1d5b21pbmcuc3ZnLnBuZyIKICAgeG1sbnM6aW5rc2Nh'
    b'cGU9Imh0dHA6Ly93d3cuaW5rc2NhcGUub3JnL25hbWVzcGFjZXMvaW5rc2NhcGUiCiAgIHht'
    b'bG5zOnNvZGlwb2RpPSJodHRwOi8vc29kaXBvZGkuc291cmNlZm9yZ2UubmV0L0RURC9zb2Rp'
    b'cG9kaS0wLmR0ZCIKICAgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxp'
    b'bmsiCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgeG1sbnM6c3Zn'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgPGRlZnMKICAgICBpZD0iZGVmczE2'
    b'NzkxIiAvPgogIDxzb2RpcG9kaTpuYW1lZHZpZXcKICAgICBpZD0ibmFtZWR2aWV3MTY3ODki'
    b'CiAgICAgcGFnZWNvbG9yPSIjZmZmZmZmIgogICAgIGJvcmRlcmNvbG9yPSIjNjY2NjY2Igog'
    b'ICAgIGJvcmRlcm9wYWNpdHk9IjEuMCIKICAgICBpbmtzY2FwZTpwYWdlc2hhZG93PSIyIgog'
    b'ICAgIGlua3NjYXBlOnBhZ2VvcGFjaXR5PSIwLjAiCiAgICAgaW5rc2NhcGU6cGFnZWNoZWNr'
    b'ZXJib2FyZD0iMCIgLz4KICA8ZwogICAgIGlua3NjYXBlOmdyb3VwbW9kZT0ibGF5ZXIiCiAg'
    b'ICAgaW5rc2NhcGU6bGFiZWw9IkltYWdlIgogICAgIGlkPSJnMTY3OTMiPgogICAgPGltYWdl'
    b'CiAgICAgICB3aWR0aD0iMTQzIgogICAgICAgaGVpZ2h0PSIxMDAiCiAgICAgICBwcmVzZXJ2'
    b'ZUFzcGVjdFJhdGlvPSJub25lIgogICAgICAgc3R5bGU9ImltYWdlLXJlbmRlcmluZzpvcHRp'
    b'bWl6ZVF1YWxpdHkiCiAgICAgICB4bGluazpocmVmPSJkYXRhOmltYWdlL3BuZztiYXNlNjQs'
    b'aVZCT1J3MEtHZ29BQUFBTlNVaEVVZ0FBQUk4QUFBQmtDQUlBQUFBd2d2U0ZBQUFBQkdkQlRV'
    b'RUFBTEdQQy94aEJRQUFBQ0JqU0ZKTgpBQUI2SmdBQWdJUUFBUG9BQUFDQTZBQUFkVEFBQU9w'
    b'Z0FBQTZtQUFBRjNDY3VsRThBQUFBQm1KTFIwUUEvd0QvQVArZ3ZhZVRBQUFQCkNVbEVRVlI0'
    b'MnUyY2VWeFRWOXJIejgxR0ZrZ0NZVTFZd2lxSUxDSUNMcUJnVmJCU3ByNjF2cTFMZFdaOGJS'
    b'MjEwMzQ2ZGl4Tys1azYKZHVhZEdiV3Q3WFNtdGJWV0hZdStkUmVVaWlLTFFOaVhJRXNnTVVE'
    b'SXZ1KzVOM24vaVBWakZXTUxUb1Z5Zm4rZUhBN1BlYjZmZSs1egpudlBjZzF5bnBnS29LU0lj'
    b'ZEFHa0JRVnBRVnJRQlpBV0ZLUTE3VVVZc3pYbHdpZmtDQTcwenBPUzlmWkllK0VyUDVRV09a'
    b'eE5pUTZEClhudGljcm5nU3ZnelhRbnZTcVUxOFRwRTBFMC9qVEtTdVN3bWJmeTBtdm5pRlZz'
    b'K2duNzhhWFRsMEk1bEN4SmdUQWdqZUNoSUN3clMKZ3JTZ0lDMG9TQXZTZ29LMG9DQXRTQXNL'
    b'MG9LQ3RDQXRLRWdMeW9NSVUzMENKQ0loa09VREFGQnFqRmFiQTlLYWpJb0s4OS80N0x6SQpV'
    b'SmJaNHNBd1RHZXcyQnlvRDQxaXNkb3RWdnVJWEhlMXJtZFlxb0cwbnJBU29vTmZmK2twdWRv'
    b'Z1Z4dDRIU0lXMDd1dFowaW0xS09ZCms4V2t6VXVOSXVCeExoZlk5dUxpakpTSTNrR1p4ZVlJ'
    b'OFBVaGV4SE1WdnZsNnU2U3NpYW4wd1ZwL2NkRm8zaTk5WEkreFl0WVVkOWoKdGpxc05zZXZu'
    b'MXZRUFRCNjdFSkRIRGNRUlowWTVseWRuMWJKNnp0WDBVNGhFeFFhUXhETFo4ZjZQQy9Tblds'
    b'dUtNcmEra0xPQzI5OApNVVVmdXlrUVpRU3lmREtTdVVWTFVxcVB2YTdXbWpwN1I0YWxtdmQz'
    b'UGJmN2xZSnV3YWpEZ2NWSEJxT29FMEVBaVVpb3FPc0ZMcVQ0CjVZSVhucDZyTTFncUcvdDNm'
    b'M0JlcXRUZkhXM2huSmkyTThXcjg5UGdzL1dZaGNmajN0ajAxRHUvV1VraEV3ZkVpZytQWFIr'
    b'UmFYM3AKMU5YNWMzNzN0OU4wYjdMZWFKMFZ3Lzc3emxWOUlsbGVWdnk1aW5ZSGlrbGt1dFBs'
    b'YllteElaMTlrdmRlS3pwNDdQcmJIMTdZK2V0bApNZUVCN21GWlROckpBNXR2YmhqOHg0a2Js'
    b'YnkrRVprVzB2b1JTcDhWc2ZOWHkxSVRRcTAyeDVCVXcrOGY3UkZLaVFUODV0VUw1eVNHCkF3'
    b'QU1KdXVCSXhWWGFycFBIOXhTMXlhc2JSRkVzUDB5a3lQRFFuek5GcnN2ZzJvd1dWdTdoeGFr'
    b'UmRzZHFONW9WV3FNVmpzNkl6S3cKcldlb3BYdUlSdlh5T1ZIMWg2MHJtRDZVdS85MC91eW8r'
    b'Yk9qQUFDaUVWVnR5OEROMXNHYUZnRmZNSXBoVGtqcm9VOVA4WmFDUDJ4ZApRY0RmV1pPVDRq'
    b'Z3JjbWJkMTIzdlA4c0d4TW9yaDNaOGRMeFNyVGNWNWlabnBrUmVxZUczM1RJeTZiUmhxWVpD'
    b'SWZsNGt6bEJ6T3BtCndhd1l0bmhVODlwTGVaVzgvaTlPMTg2YkhiWHR4VVhiOXBTNGdHdi9t'
    b'ODg5YUFPWHcrSnlXR3NMTXdBQWVxTzFybTJ3cXFuL1ltVm4KUis4SWZHOTlUNGYyclB2ajlw'
    b'VjNVWTJwc2lxK1VtTmFsQkg3MGZGS2hkcnczTkxaLzdWc2RtZ1FjME5SbHRGczF4c3RjclVo'
    b'TnlNdQpPWTdkMEM3TVNvbnNFVXEzclYwRUFGaWNFZnZhUzB1Y21QTnFYUS9MbCtad1lOL2V2'
    b'T1haSHJvM2VmbkNtWHQvVzlSK2RyZnc2cDgrCkxINSs2ZndFeitaTkYxb2JpckkyUGp2UGN4'
    b'K24wMVZhMVNXUmEwbEV2RHRHaUFvTE9IK3RRNk0zbDFieEFYQkZoL2tielRhSlhDY1EKSzZ4'
    b'Mng4MldRYVBaaHFKM1ZyUFpDV0diVnMxdjRvdi84dnF6TXBYaHhLV21INzdRY1RtczdldHl5'
    b'ei9mSVNqZnMyM3RZZ1JCcGpXdApyUy9tUExKUFZaUEFnV0pVQ3VuSTJYck02VnhUTUlmWEtU'
    b'SlpiSWRPMWNwVkJyUFZMbGNidEFiTHNFeURJQWlSZ0pjb2RFYVREY1d3CjR4Y2F6MVcwQXdE'
    b'eXMyZG1wWER6Tmg2NGNMMERRVUJOODhDUHRUT0M3WGR3OTVvdjlxNmYxclRJSk9Jais5UzJE'
    b'cWkxcGxWTFp4Zm0KSm1mUGlhbHVGdGpzNk9DUWtrb2hHVXdXTHhJUncxeE1iNHJMQlRLVHVR'
    b'N1VxZEthTkhyejBmTzhDTGF2eVdKM0Q3SWtNMzVHWkpEVgo1dWpvSFduaTN4NmZ0UnVmblpl'
    b'VkVqbDlhZkU2Ulkvc016U3FscXIwL3lxcEhoQXJDbklTQTN5OW84TDgyWUZNUHdaMVFWcU1G'
    b'NUVnCmtxandCRnhWVTc4UGphelJtM1BTWTRyeWt0bUJqR3NOdlRnYzBzSVhBd0F5VTdnem8w'
    b'TzJyTWt1ekUzcUZjbkdiZkJiVy9Lbkw2MlAKamxkNlRnS2htTlBwZEQyOUtHbjNLd1hSNFFI'
    b'OUlqbVRUc1VoU0ZTWXY5V0czaHFRWnFkSGh3WXpXN3VIekJiN3FFS1hGTXRXYVUwWApLanY1'
    b'L1pKQVA1K1k4QUM2RDZXUzE0Y2d5SXlvb056TXVLalFBSmxTNzBDeDhSbGNrRE1yMko4K1RX'
    b'bDE5STRjdjhqejBNSHQyWXdrCmJsMmJNTmlmUGppc1JCRHdtejFmYS9UbTV3dlNDSGlrcExS'
    b'WnJUV2x6UXluZTFNR3hJcCtzVUtqTXdmNCtmU0o1Q254b1NqbXJPVDEKYVEwV0RIT0dCL3Vk'
    b'TEd1cDVQWDVNV2l5ZTFJYlAyNjdnOGNWNWlaUDN3aisyUGtHRDcrcWRTYVpTci95NVk4LytP'
    b'b2Fnb0RDM09UNgpkdEc3Mnd0TGIzUjlYZHJrd0p4R2k5MEY3Z1JyNVRkdnhYT0Q3QTVVb1Rh'
    b'UWlJUXJOZDFTcFg3bDRpUXZJZ0dQeHdIRXhlWDRGZVltCjRmR0lVbXNhbjdVbzVzek5qSnUr'
    b'dE5RNnM0ZGYvUmcwSElMUXFDU3R3ZXh5QVFJZUZ4ckVQSEsyUGpLVXRXaHVuRmlpc1R0UUZv'
    b'T0sKeCtPNEhMOUlqaitSaU1jd0o4T2JZakJiVStKRDJZR01ua0hwZHpzQjBOSTk5T2ErTXhx'
    b'ZHhkL2pGMjBlOU9XWnV2aW80T2xMaSt6bApLU3dNOXFlSEJEQitzU1IxeDdwY2pjN3N6bjA0'
    b'VUl4S0ptR1lNellpQU1PY09CeWkwWnNOSnFzdmcybzAyempCekp5NXNTanE5R1BRCndrUDh1'
    b'dnBIdzltK0FBRHhxSnJoUThuTG1tRnpvTUVCakhHWTZuSzU5aDIrU3FlUnB5OHRHb1hrT1Mv'
    b'RnBGUE5WcnZSYkJzY1VWcHQKRGpLSjhOUzhlTG8zcGI1ZHlPV3cxaGRsM1phbzB4TWp2S2xr'
    b'aGRvd3F0REZSUVlOaUJYSk16aEtqVUdsTlhHQ0dJa3hiS2ZUMVRNbwpYVFEzZGxDc2pJOE1H'
    b'bDl1b2xjbzZ4bVVUaVNrblBLMDdpWWRQQ3lHZlNKNVlXNHluVXErMXRDYmxoaHVOTnVHcE9x'
    b'ZVFhbkpZa014CkxDeUlXZDh1WlBpUWU0WHltNjJEY3FYZWowRU5DV0RjbG1nME9qTWVod0FB'
    b'NnRvSFdVenZxRkIvQWdISERtS096OVM2TmlFQW9Ka3YKbnI2MEdydEVub3Nwc2xJaVl5TUNo'
    b'NlFhaTgxUjFTakFJVWl3UDkzdXdLTEMvRWNWK3JJcVBqYzBnTVdraFlmNEVRbTQzTXk0RVpu'
    b'MgpSR2xUU0FEZFpMR05LclR1Q09UQ3RVNWVoL0N0QStkOHZNbHA4ZU84V2VKR1l4OEF3R0ox'
    b'VEY5YWVxUDE1T1ZtRHgxeTBtT0NXRDU3Ci8xbjIyYW1hSnI2NHBLeVpRaVlPaUpVQmZqN0Iv'
    b'dlRuODlQY0x5UytZRFFoT2xpak15TTRKRDB4QXNPY3dtRVZtVXl5MnRDZGZ6L2IKMlNlNUxW'
    b'RkxsWHAvcG5kMmVzejRUSzNrOVFFQXFHVFNFM1RYa3ovZjJuZjQ2dnBuTWgrV004WGpjVXNY'
    b'SkFpSGxYMGkrZHhaNGRWTgpncEJBT29WTVZHcU1CcU9WUnZXeTJSMTBiMG9FMjQ5RzhiclIx'
    b'SWVpVGhhVDFpZVNjNEtZQ0FDdHQ0YWErYUpsQzJZdVc1alEyajMwClRGNHlmbHd2TGVHdzhy'
    b'WkVUZllpVXNqRWFVMnJvM2ZrMG8ydWxZdVRIcHBCeUU2c2JPZ0RBRm0rTVBIVnZTV3o0dGdV'
    b'TWttcTBDOUkKaXc0TDhlMFdqUFlLWlFROHpvZEdWcXBObTFiTkl4THdHcjBadzV6Q0VaVkNZ'
    b'eXhha21xek8rcmJoQ0VCOUtYekU4Wm5aSFd6QUFEQQpDV0krMlNLNFNYRjJYTk1zOEVBTEFG'
    b'RDhjc0VmUDc3NCsvMW50cTNMYmU4WnRxUG9zRXpiMGkydXFPL1JHU3dPRkNNUWNGS2xmbFNo'
    b'CjIzZjRxa3ByWXRJcGVxTlZJdGZWdHd2Ly9Qb3Z1Z2RHdVJ5L056Y3ZIN2VGTGQxREFJRFFJ'
    b'R1pvc08vMGZXKzUxZFV2S2EvMWRFNUkKOXladldaT2RreDVUWHR0OXJhRzNjSEd5WEcxb2FC'
    b'ZXB0U1k4SGpjZ1ZyS1l0S29tQVlvNXFSUVNsVUtTcXd4Y0RrdW0wbnVSQ0x4TwpJWTFDMnJS'
    b'cXZpK2RPbTRMMjN1R0FRQTJPK3JIb0U1M1dwZHVkT1Z2UHZoTmVldURQL1hmbGg4NVcvL3B5'
    b'WnJHenR1cjg5UFpnY3prCkdaeXlhbjVkNitDMmRZdHJXd2VvWkpJM2pmVEppU3FueTBrZzRO'
    b'VTZzMFN1VzErVXlSZU1ibCs3ZVBtQ2hJZ1ExdTgzTDU4UkdlVEIKQUY2SHFQajljNzNDaCs2'
    b'bGhxUWFBSUJBckRDWWJOTjlKWFJuQ3JhK2V5SS9leWFONG5XMzhYOFBsUmUvZis3ZTA5NmM5'
    b'TmdsODJZSQpoMVFMNTBSL1czc3JLWTd6M3l2U1B6eDIvVnhGUjFJY1orK3JSWitkcW5sNjBV'
    b'S1Yxa1FtRVVka3VubXpvM2VzeS9VY0dweTYzUExTCnJpOHRWc2UrdzFkcmpyK1JQaXZpd1Q1'
    b'eWxRRUFvTlFZUHpoNkRkSzY0NUhQVHRYK2RrT2UxZWFvYmhhY3VOUjQrSFRkZlgycW12cTkK'
    b'U0lURDcyMzQvSnRhbGRhRXgrUCsrbmw1ejZDTUhjandZOUFPSEtuUUdTenVpQ0E1bnZNL3F4'
    b'ZHlIclVYL3VLYm01dmZQdVkrdUxIWgowYVBuRzhha2RUZGlmYkozbEUydWVzSlRsNXRUWm9U'
    b'K3N2Z3IwWWpxWVgyK3ZYbkxnV0p2YjMzYTZYVHhPa1V0ZlBIY0pLN05qdG9kCkdJbUFZL2hR'
    b'VWhOQ1VkUzE2YTBqRlhVOVljRytzUkdCY2R5Z3hOaVExUGpRKy9ZSlg1MnJ2NHZLcld2MXZX'
    b'UCtVNFkzUlcrMFBuSC8KVEM1YTllM0NaYi82QUgxVW9Vc3pYOHpsc0hBNEpDc2xjc3pUOTJh'
    b'K1dDQldDTVNLZXh1NUhOYVdOZGxiMW1TN3c0MlNzcVpmRmgrOQo3emkwcTEvUzFqT2NHaDk2'
    b'MzREc1FPYlFKQ2pHbmx5VjFVNm5DLzBCTlVuOXQrV2VPNHlaTEJhTnFIYnRQeHVSVi96T3dZ'
    b'dkh6dlBXCjcveHl6UHFuajQ5WFB0Z1lHY3FhRFA2WmtsOEVQVEpaNStFZ3htQ3l2dnVQU3g3'
    b'Kzl0OFhHLy82dTFYM2hmc0owY0dUWWVKVDh0dkkKS3pYZE9ldjJMWGp4YjlLSG5ObmpjT092'
    b'L1ROYjdhY3V0OXpYR0I4SmFZMVhEUjNDNm1iQnpkYkJYZnZQanRsaGdwV2FKV1ZOOTdXYwpy'
    b'V2lIdENhcWtyS21NUk4zRTZ5cWJlMGUrbjdhU2Z4MWFST2s5UmhlWUZkcXVoOXN2L1ZkT2NZ'
    b'NGg3VTU3ZzFBL3Z6cEZaZkxCV2s5CkJoMTlvR3JLNVhMdDJIdHlJbU5tcFVUaThUZzNvVkdG'
    b'N3N6VnRra3kyU2xQNjJKbHAwYi92Y0lwbzluV003Rm55MzF4dFB0ZFZWNTcKYS9KODBUWGxh'
    b'ZG5zNlA5ZGFYbU1BeUlJOG56K0hLWEd1Ty93VlFDQWNGZzVlU2I3YzdqZDVFWmovNzBiNXkz'
    b'di9Ic2lvMlVrY2FQRApBL1o4VW1veTJ3QUFrK283MTU4RHJYdkR3bzI3anB5NDFEaVIwZFk5'
    b'azJHMU9UNDdWVU1pRVFBQU1wVmg4c3lVOERPZ2xSVEhBUURZCkhlaW5KMnZxMjRVVEdZcnNS'
    b'VnhibUZIZkxyUllIWE5uUmJoekg1RFc0MVRSa2hRQXdPWHE3dTEvS3BuZ1VLdVdwdnJTcWFW'
    b'VlhSUXkKOGQwZGhlMDl3L2VsaGlHdENXbHVVb1E3Wlk1aTJNUkh5MHlPL0thODljQ1hGUW5S'
    b'SVYzOWt1TVhlSlBxSHBRcFQ2dWpkeVIwOFM0dgpFc0g4M1plUUU5R3I3OTNacUhYMmpTeGF2'
    b'Myt5VFhiSzA3TFowU2wwUFFtTUNhZVJJQzFJQ3dyU2dvSzBJQzBvU0FzSzBvSzBvQ0F0CktF'
    b'Z0wwb0tDdEtBZ0xVZ0w2aitqUjV4dnpVa01MLzNYTnVpbW4wYnV5Ky9IVDR2RnBCWGtKRUkv'
    b'd3BVUTZqR3RoRmF4QkV5QzY4K24KcmF4aXlaanR5SFZxS3ZRT1hBbWhJQzFJQ3dyU2dvSzBJ'
    b'QzJvcWFML0J5V2V4TVdIbnJEMUFBQUFKWFJGV0hSa1lYUmxPbU55WldGMApaUUF5TURJekxU'
    b'QXlMVEkyVkRFNE9qRTBPakkzS3pBd09qQXdUaFpBTWdBQUFDVjBSVmgwWkdGMFpUcHRiMlJw'
    b'Wm5rQU1qQXlNeTB3Ck1pMHlObFF4T0RveE5Eb3lOeXN3TURvd01EOUwrSTRBQUFBQVNVVk9S'
    b'SzVDWUlJPQoiCiAgICAgICBpZD0iaW1hZ2UxNjc5NSIgLz4KICA8L2c+Cjwvc3ZnPgo=', 'US_WY')

US_WY = b64_US_WY
index.append("US_WY")
index.append("United States of America Wyoming")
catalog["US_WY"] = US_WY
catalog["United States of America Wyoming"] = US_WY
country["United States of America Wyoming"] = ('US_WY', '', 1)
lookup["US_WY"] = ('US_WY', '', 'United States of America Wyoming', 1)
lookup["Cheyenne United States of America Wyoming"] = ('US_WY', '', 'United States of America Wyoming', 1)
lookup["United States of America Wyoming"] = ('US_WY', '', 'United States of America Wyoming', 1)
details["US_WY"] = {"continent":"Americas","capital":"Cheyenne","currency":"","web":"","lang":"","tz":"-07:00","altname":""}
regional["US_WY"] = ('US_WY', 'United States of America Wyoming', 1)
regional["United States of America Wyoming"] = ('US_WY', 'United States of America Wyoming', 1)
#----------------------------------------------------------------------
b64_UY = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy11eSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgw'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiMwMDM4YTgiIGQ9Ik0yNjYgNTMuM2gzNzR2NTMuNEgyNjZ6'
    b'bTAgMTA2LjdoMzc0djUzLjNIMjY2ek0wIDI2Ni43aDY0MFYzMjBIMHptMCAxMDYuNmg2NDB2'
    b'NTMuNEgweiIvPgogIDxnIGZpbGw9IiNmY2QxMTYiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLW1p'
    b'dGVybGltaXQ9IjIwIiBzdHJva2Utd2lkdGg9Ii42IiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgx'
    b'MzMuMyAxMzMuMykgc2NhbGUoMi45MzMzMykiPgogICAgPGcgaWQ9InV5LWMiPgogICAgICA8'
    b'ZyBpZD0idXktYiI+CiAgICAgICAgPGcgaWQ9InV5LWEiPgogICAgICAgICAgPHBhdGggc3Ry'
    b'b2tlLWxpbmVjYXA9InNxdWFyZSIgZD0ibS0yIDguOSAzIDQuNWMtMTIuNCA5LTQuOSAxNC4y'
    b'LTEzLjYgMTcgNS40LTUuMi0uOS01LjcgMy43LTE2LjgiLz4KICAgICAgICAgIDxwYXRoIGZp'
    b'bGw9Im5vbmUiIGQ9Ik0tNC4yIDEwLjJjLTYuOCAxMS4yLTIuNCAxNy40LTguNCAyMC4zIi8+'
    b'CiAgICAgICAgICA8cGF0aCBkPSJNMCAwaDZMMCAzMy02IDBoNnYzMyIvPgogICAgICAgIDwv'
    b'Zz4KICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiN1eS1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0'
    b'PSIxMDAlIiB0cmFuc2Zvcm09InJvdGF0ZSg0NSkiLz4KICAgICAgPC9nPgogICAgICA8dXNl'
    b'IHhsaW5rOmhyZWY9IiN1eS1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zv'
    b'cm09InJvdGF0ZSg5MCkiLz4KICAgIDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3V5LWMi'
    b'IHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ic2NhbGUoLTEpIi8+CiAg'
    b'ICA8Y2lyY2xlIHI9IjExIi8+CiAgPC9nPgogIDxnIHRyYW5zZm9ybT0idHJhbnNsYXRlKDEz'
    b'My4zIDEzMy4zKSBzY2FsZSguMjkzMzMpIj4KICAgIDxnIGlkPSJ1eS1kIj4KICAgICAgPHBh'
    b'dGggZD0iTTgxLTQ0Yy03IDgtMTEtNi0zNi02UzE2LTM1IDEyLTM4czIxLTIxIDI5LTIyIDMx'
    b'IDcgNDAgMTZtLTI5IDljNyA2IDEgMTktNiAxOVMyNi0yOCAzMi0zNiIvPgogICAgICA8cGF0'
    b'aCBkPSJNMTktMjZjMS0xMiAxMS0xNCAyNy0xNHMyMyAxMiAyOSAxNWMtNyAwLTEzLTEwLTI5'
    b'LTEwcy0xNiAwLTI3IDEwbTMgMmM0LTYgOSA2IDIwIDZzMTctMyAyNC04LTEwIDEyLTIxIDEy'
    b'LTI2LTYtMjMtMTAiLz4KICAgICAgPHBhdGggZD0iTTU2LTE3YzEzLTcgNS0xNyAwLTE5IDIg'
    b'MiAxMCAxMiAwIDE5TTAgNDNjNiAwIDgtMiAxNi0yczI3IDExIDM4IDdjLTIzIDktMTQgMy01'
    b'NCAzaC01bTYzIDZjLTQtNy0zLTUtMTEtMTYgOCA2IDEwIDkgMTEgMTZNMCA2N2MyNSAwIDIx'
    b'LTUgNTQtMTktMjQgMy0yOSAxMS01NCAxMWgtNW01LTI5YzcgMCA5LTUgMTctNXMxOSAzIDI0'
    b'IDdjMSAxLTMtOC0xMS05UzI1IDkgMTYgN2MwIDQgMyAzIDQgOSAwIDUtOSA1LTExIDAgMiA4'
    b'LTQgOC05IDgiLz4KICAgIDwvZz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3V5LWQiIHdpZHRo'
    b'PSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHRyYW5zZm9ybT0ic2NhbGUoLTEgMSkiLz4KICAgIDxw'
    b'YXRoIGQ9Ik0wIDc2Yy01IDAtMTggMyAwIDNzNS0zIDAtMyIvPgogIDwvZz4KPC9zdmc+Cg==', 'UY')

UY = b64_UY
index.append("UY")
index.append("URY")
index.append("Uruguay")
catalog["UY"] = UY
catalog["URY"] = UY
catalog["Uruguay"] = UY
country["Uruguay"] = ('UY', 'URY', 0)
lookup["UY"] = ('UY', 'URY', 'Uruguay', 0)
lookup["Montevideo Uruguay"] = ('UY', 'URY', 'Uruguay', 0)
lookup["URY"] = ('UY', 'URY', 'Uruguay', 0)
lookup["Uruguay"] = ('UY', 'URY', 'Uruguay', 0)
details["UY"] = {"continent":"Americas","capital":"Montevideo","currency":"Peso Uruguayo","web":".uy","lang":"es-UY","tz":"-03:00","altname":""}
#----------------------------------------------------------------------
b64_UZ = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy11eiIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiMxZWI1M2EiIGQ9Ik0wIDMyMGg2NDB2'
    b'MTYwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwOTliNSIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iI2NlMTEyNiIgZD0iTTAgMTUzLjZoNjQwdjE3Mi44SDB6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMTYzLjJoNjQwdjE1My42SDB6Ii8+CiAgPGNpcmNs'
    b'ZSBjeD0iMTM0LjQiIGN5PSI3Ni44IiByPSI1Ny42IiBmaWxsPSIjZmZmIi8+CiAgPGNpcmNs'
    b'ZSBjeD0iMTUzLjYiIGN5PSI3Ni44IiByPSI1Ny42IiBmaWxsPSIjMDA5OWI1Ii8+CiAgPGcg'
    b'ZmlsbD0iI2ZmZiIgdHJhbnNmb3JtPSJtYXRyaXgoMS45MiAwIDAgMS45MiAyNjEuMSAxMjIu'
    b'OSkiPgogICAgPGcgaWQ9InV6LWUiPgogICAgICA8ZyBpZD0idXotZCI+CiAgICAgICAgPGcg'
    b'aWQ9InV6LWMiPgogICAgICAgICAgPGcgaWQ9InV6LWIiPgogICAgICAgICAgICA8cGF0aCBp'
    b'ZD0idXotYSIgZD0iTTAtNi0xLjktLjMgMSAuNyIvPgogICAgICAgICAgICA8dXNlIHhsaW5r'
    b'OmhyZWY9IiN1ei1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InNj'
    b'YWxlKC0xIDEpIi8+CiAgICAgICAgICA8L2c+CiAgICAgICAgICA8dXNlIHhsaW5rOmhyZWY9'
    b'IiN1ei1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB0cmFuc2Zvcm09InJvdGF0ZSg3'
    b'MikiLz4KICAgICAgICA8L2c+CiAgICAgICAgPHVzZSB4bGluazpocmVmPSIjdXotYiIgd2lk'
    b'dGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJyb3RhdGUoLTcyKSIvPgogICAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI3V6LWMiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHRyYW5zZm9ybT0icm90YXRlKDE0NCkiLz4KICAgICAgPC9nPgogICAgICA8dXNlIHhsaW5r'
    b'OmhyZWY9IiN1ei1kIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB5PSItMjQiLz4KICAg'
    b'ICAgPHVzZSB4bGluazpocmVmPSIjdXotZCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIg'
    b'eT0iLTQ4Ii8+CiAgICA8L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN1ei1lIiB3aWR0aD0i'
    b'MTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIyNCIvPgogICAgPHVzZSB4bGluazpocmVmPSIjdXot'
    b'ZSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iNDgiLz4KICAgIDx1c2UgeGxpbms6'
    b'aHJlZj0iI3V6LWQiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii00OCIvPgogICAg'
    b'PHVzZSB4bGluazpocmVmPSIjdXotZCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0i'
    b'LTI0Ii8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN1ei1kIiB3aWR0aD0iMTAwJSIgaGVpZ2h0'
    b'PSIxMDAlIiB4PSItMjQiIHk9Ii0yNCIvPgogIDwvZz4KPC9zdmc+Cg==', 'UZ')

UZ = b64_UZ
index.append("UZ")
index.append("UZB")
index.append("Uzbekistan")
catalog["UZ"] = UZ
catalog["UZB"] = UZ
catalog["Uzbekistan"] = UZ
country["Uzbekistan"] = ('UZ', 'UZB', 0)
lookup["UZ"] = ('UZ', 'UZB', 'Uzbekistan', 0)
lookup["Tashkent Uzbekistan"] = ('UZ', 'UZB', 'Uzbekistan', 0)
lookup["UZB"] = ('UZ', 'UZB', 'Uzbekistan', 0)
lookup["Uzbekistan"] = ('UZ', 'UZB', 'Uzbekistan', 0)
details["UZ"] = {"continent":"Asia","capital":"Tashkent","currency":"Uzbekistan Sum","web":".uz","lang":"uz | ru | tg","tz":"+05:00","altname":""}
#----------------------------------------------------------------------
b64_VA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy12YSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0zMjAgMGgzMjB2NDgw'
    b'SDMyMHoiLz4KICA8cGF0aCBmaWxsPSIjZmZlMDAwIiBkPSJNMCAwaDMyMHY0ODBIMHoiLz4K'
    b'ICA8ZyBzdHJva2U9IiMwMDAiIHN0cm9rZS1saW5lam9pbj0icm91bmQiIHN0cm9rZS13aWR0'
    b'aD0iMy4yIj4KICAgIDxnIGZpbGw9IiNjZTlkMDkiIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIg'
    b'dHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTIzKSBzY2FsZSguMTkyKSI+CiAgICAgIDxnIGlkPSJ2'
    b'YS1hIj4KICAgICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJtMTc4MSA5OTAuMyAxNi4yIDMu'
    b'OCAyNS42IDQuMiAxMS44IDEuMy0yIDUwcy0yLjkgMzMtNy44IDQ4LjljLTMuNiAxMS43LTE1'
    b'LjcgMzMuMi0xNS43IDMzLjJsLTcuNyAxMS43LTQ1LjQtMzkuM3M3LjgtMTEgMTAuNi0xN2Mz'
    b'LjUtNy41IDcuNy0yMy44IDcuNy0yMy44bDQuNC0yNiAyLjQtMzIuN3ptLTU3IDE1MS41IDQx'
    b'LjQgMzZzLTguNCA3LjQtMTMuNCA5LjdhNzMuNiA3My42IDAgMCAxLTMxLjYgNy4zIDU4IDU4'
    b'IDAgMCAxLTIyLjMtNi4yYy0xNS43LTcuMi0zMy0xNC43LTQzLjItMjguNy0zLjYtNS01LTEx'
    b'LjYtNC45LTE3LjcuMi03IDYuMy0xOS45IDYuMy0xOS45czIuNCA4LjcgNS4xIDEyYTQ5LjIg'
    b'NDkuMiAwIDAgMCAxNy42IDEyLjQgNDIuNSA0Mi41IDAgMCAwIDM2LjIgMS4xYzMuMy0xLjMg'
    b'OC45LTYgOC45LTZ6Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTE2NTguNyA4'
    b'NzcuN3MzLjIgNi42IDQuMiAxMC4xYzEuOCA2IDMgMTIuMyAzIDE4LjZhNzguOCA3OC44IDAg'
    b'MCAxLTMuMiAxOC42IDE3MSAxNzEgMCAwIDEtMTAuMyAyNi4zYy0yLjYgNS40LTYgMTAuMy04'
    b'LjYgMTUuOC00LjEgOC43LTcgMTgtMTAuNiAyNi44LTMgNy41LTYuOSAxNC43LTkuMiAyMi40'
    b'LTMgMTAuMi00LjUgMjAuOS02IDMxLjRhMjMwIDIzMCAwIDAgMC0yLjMgMjcuNWMwIDExIC4z'
    b'IDIyIDIuMyAzMi42IDIgMTAuNiA1IDIxLjIgOS44IDMxYTc5LjEgNzkuMSAwIDAgMCAzMS44'
    b'IDM0LjhjNS41IDMuNCAxMS45IDUuMyAxOCA3LjggOC4zIDMuMyAyNS40IDkuMyAyNS40IDku'
    b'M3MtMjMuNi0xMS42LTMxLjgtMjEuNGE2OC40IDY4LjQgMCAwIDEtMTIuOC0yOC45IDExMi4z'
    b'IDExMi4zIDAgMCAxLTEuMi0zNi42IDE5NiAxOTYgMCAwIDEgOS4yLTM4LjNjNC4yLTEzLjIg'
    b'MTAtMjUuOSAxNS40LTM4LjYgMy45LTkuMyA4LjMtMTguMiAxMi0yNy41IDQuNS0xMSA4Ljgt'
    b'MjIgMTIuNC0zMy4yIDIuMS02LjkgNC44LTEzLjcgNS40LTIwLjlhNzYgNzYgMCAwIDAtMi4y'
    b'LTIzLjQgODkgODkgMCAwIDAtMTEuOC0zMC42IDQxLjEgNDEuMSAwIDAgMC0xNC44LTEzLjJj'
    b'LTUuNy0yLjktMTIuNS01LjQtMTguOS00LjEtMiAuNC01LjIgMy43LTUuMiAzLjd6Ii8+CiAg'
    b'ICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTE3MTEuNiA5NDUuNnM0LjQtMTggNS4yLTI3'
    b'LjJjLjYtNy45LjItMTUuOC0uNi0yMy43LTEtOC43LTEuNS0xNy44LTQuOS0yNS45YTY4LjMg'
    b'NjguMyAwIDAgMC0zOC4yLTM3IDkyLjIgOTIuMiAwIDAgMC0yOC00LjggMTMwIDEzMCAwIDAg'
    b'MC0zOCA0Yy00IDEuNC0xMS43IDUuNy0xMS43IDUuN2wzMCA0OXM5LjMtNS42IDE0LjUtN2E1'
    b'NC43IDU0LjcgMCAwIDEgMTctMS4yYzUuOC40IDExLjcgMSAxNyAzLjNhNTcgNTcgMCAwIDEg'
    b'MTcuNiAxMy4zIDczLjkgNzMuOSAwIDAgMSAxNSAyMmMzIDcuNSAzLjUgMTYgNC42IDI0LjIu'
    b'MyAxLjcuNSA1LjMuNSA1LjN6Ii8+CiAgICAgICAgPHBhdGggZD0iTTE3MTcgOTA2LjdzLTUu'
    b'My0xNi42LTEwLjMtMjMuNWE2My44IDYzLjggMCAwIDAtMjIuMy0xOS44Yy05LjQtNC43LTMx'
    b'LTYuMi0zMS02LjJsMTEuNCAyMS0yMC0uNC0xMC4zLTE3LjQtMTkuMyA4LjctOS41LTE1Ljcg'
    b'MjAuNC05LjQtOS40LTE1LjIgMjAuNC0yIDguOSAxNC43czE1LjkgMCAyMy42IDEuN2E1OC4y'
    b'IDU4LjIgMCAwIDEgMjcuNSAxNC40IDY4IDY4IDAgMCAxIDEyIDE0LjJjMyA1LjEgNi41IDE2'
    b'LjcgNi41IDE2Ljd6Ii8+CiAgICAgICAgPHBhdGggZD0ibTE1ODEuNyA4NDUgMzEuOCA0Ni43'
    b'bS0xOC01NC44LTE1IDguOC0xNC4zIDExIDMxIDQ3LjEgMTMuNy0xMC42IDE0LjEtOC4yem01'
    b'OC4zIDE5OSAxNy45LTM3IDE5LjEgNy43IDcuOC0xOS0xOS05IDkuOC0yMS4zLTE0LTYuMy0x'
    b'MC42IDIwLjUtMTkuMi04LTguNCAyMCAxOC42IDcuNy0xNy4yIDM2Ljd6bTE0My4yLTExLjEg'
    b'MTguMS0uNHYyMWwxNy42LjktMyAyMS40LTE2LjQtMXMtMi43IDEyLjUtNS4xIDE4LjRjLTIu'
    b'NSA2LjItOS43IDE3LjQtOS43IDE3LjRsLTE5LjQtNC44czctMTEgOS43LTE3YzIuNC01LjQg'
    b'NS43LTE2LjYgNS43LTE2LjZsLTIwLTIuNSAzLjUtMjAuMiAxOC4xIDEuMnoiLz4KICAgICAg'
    b'PC9nPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1hIiB3aWR0aD0iMTAwJSIgaGVpZ2h0'
    b'PSIxMDAlIiB0cmFuc2Zvcm09Im1hdHJpeCgtMSAwIDAgMSAzNzE3LjggMCkiLz4KICAgICAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgZD0ibTE3NTYuNyA3MzUuNi0yNy41IDI5LjQgMTcgNTEgOS42'
    b'IDM1LjgtMjcuNyAyNS44IDUwLjcgNzEtMTcuNCAxOS45YTEyLjIgMTIuMiAwIDAgMC0yLjEg'
    b'OC42Yy4zIDIuNyAxLjYgNS40IDMuNiA3LjMgNC41IDQuMSAxMS4zIDUuMSAxNy4zIDYuNyAy'
    b'MSA1LjYgNDIuOSA4IDY0LjYgOS43IDQuNy40IDE0IDAgMTQgMHM5LjQuNCAxNC4xIDBjMjEu'
    b'OC0xLjYgNDMuNi00LjEgNjQuNy05LjcgNi0xLjYgMTIuNy0yLjYgMTcuMy02LjdhMTIuMiAx'
    b'Mi4yIDAgMCAwIDEuNC0xNS45bC0xNi4zLTM2IDUxLjgtNTUuNC0xOS43LTE3LjktLjUtNDMu'
    b'MiAxNy01MS0yNS41LTI1LjctMjMtNjEuMnMtNC43LTE3LjEtOC44LTI1Yy0yLjQtNC42LTUu'
    b'OC04LjctOS4yLTEyLjgtNC00LjktOC05LjktMTIuOC0xMy45YTg1IDg1IDAgMCAwLTE0LjYt'
    b'OWMtNS41LTIuOS0xMS02LTE2LjktNy41LTYuMS0xLjUtMTktMS41LTE5LTEuNXMtMTIuNyAw'
    b'LTE4LjkgMS41Yy02IDEuNi0xMS40IDQuNi0xNi44IDcuNWE4NSA4NSAwIDAgMC0xNC42IDlj'
    b'LTQuOSA0LTguOSA5LTEyLjkgMTMuOS0zLjMgNC02LjcgOC4yLTkuMSAxMi45LTQuMSA3Ljgt'
    b'OC45IDI0LjktOC45IDI0Ljl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xOTYzLjMgOTMzLjFzLTMu'
    b'Mi0yLjgtNS00YTY0LjUgNjQuNSAwIDAgMC0xMi02Yy01LjUtMi4yLTExLjUtMy4zLTE3LjMt'
    b'NC43YTE5Ni44IDE5Ni44IDAgMCAwLTQ0LjMtNS43Yy04LjYgMC0yNS44IDEuMy0yNS44IDEu'
    b'M3MtMTcuMi0xLjMtMjUuOC0xLjNhMTk1LjIgMTk1LjIgMCAwIDAtNDQuMyA1LjdjLTUuOSAx'
    b'LjQtMTEuOCAyLjUtMTcuNCA0LjdhNjQuNSA2NC41IDAgMCAwLTEyIDZjLTEuNyAxLjItNSA0'
    b'LTUgNG0yMTguOC00Mi43cy01LjItNS4yLTguNi01LjlhOSA5IDAgMCAwLTYuNiAxLjUgMTMu'
    b'MSAxMy4xIDAgMCAwLTQgMTUuMmMuOCAyIDIgNC4zIDQuMSA1LjIgNC44IDEuOSAxNS40LTIg'
    b'MTUuNC0yem01LjEtMy42YzUuOC4yIDggMy4yIDkuNSA2LjVtLTI0My4yLTIuOS0uMyAxNHMx'
    b'MC41IDMuOSAxNS4zIDJjMi0uOSAzLjQtMy4xIDQuMi01LjJhMTMuMSAxMy4xIDAgMCAwLTQt'
    b'MTUuMiA4LjkgOC45IDAgMCAwLTYuNi0xLjVjLTMuNS43LTguNiA2LTguNiA2em0tNS4yLTMu'
    b'NmMtNS44LjItOCAzLjItOS40IDYuNW0xOTguMSAxLjQtOC40LTFtLTEzMCAxIDguNC0xbTc2'
    b'IC44Yy0yLjktLjQtNy42LTQuMi03LjYtNC4ybS0yMi44IDQuMmMyLjgtLjQgNy42LTQuMiA3'
    b'LjYtNC4ybTE0MS0xOS4zcy00LjMgMy4zLTcuNCAzLjhsLTEuMi43cy0yIDUuNy0zLjYgOC4y'
    b'YTQ0LjcgNDQuNyAwIDAgMS02LjUgNi4ycy00LjgtNC4xLTcuNy01Yy0yLS41LTQuMi0uNS02'
    b'IC4zYTExIDExIDAgMCAwLTQuOCA0LjNjLTEuNCAyLTIuNyA0LjYtMi42IDcgLjEgMyAzLjkg'
    b'OC4zIDMuOSA4LjNsLTIuNiA0LjUtMy43IDIuM2E5MC4zIDkwLjMgMCAwIDEtMTktNy41IDE4'
    b'LjkgMTguOSAwIDAgMS00LjQtOXM0LjUtMi43IDUuNi01YzEuMi0yLjUgMS42LTYgLjItOC40'
    b'LTEuNi0yLjYtNS4zLTQtOC40LTRhOC44IDguOCAwIDAgMC02LjMgMi43Yy0xLjYgMS44LTMg'
    b'NC41LTIuNSA3IC40IDIuNCA0LjcgNS43IDQuNyA1LjdzLTEuOCA0LjYtMy44IDUuNWMtNiAy'
    b'LjUtMTAgNC0xNS4zIDQuOGEzOSAzOSAwIDAgMS0xNi4zIDAgMTcgMTcgMCAwIDEtOS01LjVj'
    b'LS42LS45LS44LTMtLjgtM3M2LjUtMS43IDktMy43YzIuNi0yIDUuMy00LjYgNS45LTcuOC41'
    b'LTMuMi0xLjItNi42LTMtOS4yYTE4IDE4IDAgMCAwLTcuNi02Yy0xLjMtLjYtNC4zLS43LTQu'
    b'My0uN2wtMSAuOWExNC42IDE0LjYgMCAwIDEtNC43IDMuOGgtLjFsLS4yLjEtMS4xLjYtLjgu'
    b'MS0yLjQuOHMzLjggMS4yIDUgMi44Yy42LjkuOSAyIDEgMy4zbC4yIDJjMCAxLjItLjMgMi4z'
    b'LS43IDMuNGE5IDkgMCAwIDEtMS43IDMuNWMtLjQuNi0xIDEtMS42IDEuNCAwIDAgMCAwIDAg'
    b'MGwtLjIuMWMtMSAuNy0yLjIgMS4yLTMuMyAxLjUtMS40LjQtNC4yLjEtNC4zLjEgMCAwIDUu'
    b'NSAwIDcuNi0xLjZsLjItLjFhMTAuNyAxMC43IDAgMCAwIDMuOC03LjJ2LTNjLS4zLTEuNi0x'
    b'LTMuMi0yLjItNC4yLTIuNC0yLjEtOS4zLTIuNC05LjQtMi40LS4xIDAtNyAuMy05LjQgMi40'
    b'YTcuNiA3LjYgMCAwIDAtMi4zIDQuMnYzLjFsLjUgMi4zYy43IDIgMS44IDMuNyAzLjMgNC45'
    b'bC4yLjFjMi4yIDEuNiA3LjYgMS42IDcuNyAxLjYtLjEgMC0zIC4zLTQuMyAwLTEuMi0uNC0y'
    b'LjQtLjktMy40LTEuNmgtLjF2LS4xYy0uNy0uNC0xLjItLjgtMS43LTEuNGE5IDkgMCAwIDEt'
    b'MS43LTMuNWMtLjMtMS0uNi0yLjItLjctMy4zbC4yLTIuMWMuMi0xLjIuNS0yLjQgMS4xLTMu'
    b'MyAxLjEtMS42IDUtMi44IDUtMi44bC0yLjUtLjgtLjctLjEtMS4yLS42aC0uMWwtLjEtLjFh'
    b'MTUgMTUgMCAwIDEtNC44LTMuOGwtMS0uOXMtMyAwLTQuMi43YTE4IDE4IDAgMCAwLTcuNiA2'
    b'Yy0xLjggMi42LTMuNSA2LTMgOS4yLjUgMy4yIDMuMyA1LjggNS44IDcuOCAyLjYgMiA5IDMu'
    b'NyA5IDMuN3MtLjIgMi4xLS44IDNhMTcgMTcgMCAwIDEtOSA1LjUgMzkgMzkgMCAwIDEtMTYu'
    b'MyAwIDU5IDU5IDAgMCAxLTE1LjItNC44Yy0yLTEtMy45LTUuNS0zLjktNS41czQuNC0zLjMg'
    b'NC44LTUuOGMuNC0yLjQtMS01LTIuNi02LjlhOC44IDguOCAwIDAgMC02LjItMi44Yy0zLjEg'
    b'MC02LjggMS41LTguNCA0LjEtMS41IDIuNC0xIDUuOS4yIDguNCAxIDIuMyA1LjYgNSA1LjYg'
    b'NWExOC45IDE4LjkgMCAwIDEtNC41IDkgODguNSA4OC41IDAgMCAxLTE5IDcuNWwtMy42LTIu'
    b'My0yLjYtNC41czMuNy01LjIgMy44LTguMmMuMi0yLjUtMS4xLTUtMi41LTcuMWExMS4yIDEx'
    b'LjIgMCAwIDAtNC44LTQuM2MtMS44LS44LTQtLjgtNi0uMi0zIC44LTcuNyA0LjktNy43IDQu'
    b'OXMtNC44LTMuOC02LjUtNi4yYTQ4LjcgNDguNyAwIDAgMS0zLjctOC4ybC0xLjItLjdjLTMt'
    b'LjUtNy4zLTMuOC03LjMtMy44bC00LjQgMXMtNC4xIDIuMS00LjIgNGMwIDIuOCAzLjggNCA1'
    b'LjUgNiAxLjQgMS45IDIuOCAzLjcgNC4xIDUuNyAxLjIgMS44IDIuOSAzLjQgMy41IDUuNS42'
    b'IDIuMy0xIDUgMCA3LjIgMS4yIDIuNyAzLjcgNS40IDYuNyA2IDIuNi41IDcuNi0yLjYgNy42'
    b'LTIuNmwtLjIgMTkuOSAxMC4zIDkuMyA5LjcgMjAuMy0zLjggNS4yIDEuMSAxMGM3LjUtOS42'
    b'IDIwLjUtMTMuOCAzMi4yLTE3LjIgMTUuNy00LjUgNDQuNi00LjggNTgtNC43bDcuMy4xczQ0'
    b'LjMtMS40IDY1LjIgNC42YzExLjcgMy40IDI0LjcgNy42IDMyLjIgMTcuMmwxLjItMTAtMy45'
    b'LTUuMiA5LjctMjAuMyAxMC4zLTkuMy0uMS0xOS45czUgMy4xIDcuNiAyLjZjMy0uNiA1LjUt'
    b'My4zIDYuNy02IDEtMi4yLS43LTQuOSAwLTcuMi42LTIgMi4yLTMuNyAzLjQtNS41IDEuMy0y'
    b'IDIuNy0zLjggNC4yLTUuNiAxLjctMi4xIDUuNS0zLjMgNS40LTYgMC0yLTQuMS00LjItNC4x'
    b'LTQuMmwtNC41LTF6bS0xNDguNC0yLjZjMSAxIDMgMi44IDQuOCAzLjhsLjIuMWMuNS4zIDEu'
    b'Mi41IDIgLjcgMi44LjggNy44LjMgOCAuM2gwYy4xIDAgNS4xLjUgOC0uM2wyLS43LjItLjFj'
    b'MS43LTEgMy43LTIuOSA0LjgtMy44LjUtLjcgMS0xLjQgMS4zLTIuMiAxLjEtMi43IDEtNi4x'
    b'LS4yLTguNy0xLjYtMy01LjItNC41LTguMS02LjMtMi41LTEuNS04LTMuNy04LTMuN2E2OSA2'
    b'OSAwIDAgMC04IDMuN2MtMyAxLjgtNi42IDMuMy04LjEgNi4zLTEuMyAyLjYtMS40IDYtLjIg'
    b'OC43LjMuOC44IDEuNSAxLjMgMi4yeiIvPgogICAgICA8cGF0aCBkPSJNMTk4MC44IDgyOS44'
    b'cy0xMS01LTE2LjYtNi45Yy0xMC40LTMuMy0yMS4zLTUuMi0zMi03LjMtMTIuNS0yLjQtMjUu'
    b'Mi0zLTM3LjYtNi0zLjktLjgtNy41LTIuNy0xMS41LTMuNS01LjQtMS4xLTExLTIuOS0xNi40'
    b'LTEuNy0zIC42LTcuOCA0LjYtNy44IDQuNnMtNC45LTQtNy44LTQuNmMtNS40LTEuMi0xMS4x'
    b'LjYtMTYuNSAxLjctNCAuOC03LjYgMi43LTExLjQgMy42LTEyLjQgMi45LTI1LjIgMy41LTM3'
    b'LjcgNi0xMC43IDItMjEuNSAzLjktMzIgNy4yLTUuNiAxLjgtMTYuNSA2LjktMTYuNSA2Ljlt'
    b'MTk3LjQtNDUuMXM1LjQtMi45IDcuMy01YTkuNSA5LjUgMCAwIDAgMi43LTUuMyA5IDkgMCAw'
    b'IDAtMi4zLTYuNSA5IDkgMCAwIDAtNi4yLTIuMmMtMS45IDAtMy45LjYtNS4zIDEuOGE5LjEg'
    b'OS4xIDAgMCAwLTMgNS42Yy0uMyAxLjguNSAzLjcgMS4zIDUuM2EzMyAzMyAwIDAgMCA1LjUg'
    b'Ni4zem0tMTUxIDBzNC4xLTMuOCA1LjQtNi4zYTkuNCA5LjQgMCAwIDAgMS40LTUuMyA5LjEg'
    b'OS4xIDAgMCAwLTMtNS42IDguMiA4LjIgMCAwIDAtNS4zLTEuOCA5IDkgMCAwIDAtNi4zIDIu'
    b'MiA4LjcgOC43IDAgMCAwLTIuMiA2LjVjLjEgMiAxLjMgMy43IDIuNiA1LjIgMiAyLjIgNy4z'
    b'IDUgNy4zIDV6bS00MS4yIDE4LTExLjkgMTUuNnMwIDQgLjggNS44YTI0IDI0IDAgMCAwIDUu'
    b'OSA1LjdsLjggMjEuNC0xMS4zIDE5LjYtMSAuMiA3LjMgMy44IDEgLjFjNC40LS4zIDctNS4y'
    b'IDEwLjktNy40IDQuOC0yLjggMTAtNSAxNS4yLTcuMmEyMzkuOCAyMzkuOCAwIDAgMSA1MC0x'
    b'NS4xIDE0MS44IDE0MS44IDAgMCAxIDI5LjUtMS4yYzYuNi41IDE5LjQgMy40IDE5LjUgMy40'
    b'IDAgMCAxMi45LTMgMTkuNS0zLjRhMTQwLjcgMTQwLjcgMCAwIDEgNTcuOCA4LjMgMjM5Ljgg'
    b'MjM5LjggMCAwIDEgMzYuOSAxNS4yYzMuOCAyLjIgNi41IDcgMTAuOCA3LjRoMWw3LjMtNC0x'
    b'LS4xLTExLjMtMTkuNi45LTIxLjRzNC42LTMuMyA1LjgtNS43YzEtMS43LjgtNS44LjgtNS44'
    b'bC0xMS45LTE1LjZzLTYgNi05LjkgNy4zYy0yIC42LTQuNC42LTYuNSAwLTIuNS0uOC00LjQt'
    b'Mi45LTYuNS00LjVhODQgODQgMCAwIDEtMTIuOS0xMi4xIDcwLjIgNzAuMiAwIDAgMS01LjMt'
    b'OC43cy0xMi45IDEwLjEtMjAuNiAxMi4xYy03LjYgMi0xNiAxLjYtMjMuNS0uNi0xLjktLjYt'
    b'NS0zLTUtM2E0MiA0MiAwIDAgMC0yNi40LTggNDIgNDIgMCAwIDAtMjYuNCA4cy0zLjIgMi40'
    b'LTUgM2E0NC44IDQ0LjggMCAwIDEtMjMuNi42IDgyLjQgODIuNCAwIDAgMS0yMC42LTEyLjFz'
    b'LTMuMSA2LTUuMyA4LjdhODQgODQgMCAwIDEtMTIuOSAxMi4xYy0yIDEuNi00IDMuNy02LjUg'
    b'NC41LTIgLjYtNC40LjYtNi40IDBhMzcgMzcgMCAwIDEtMTAtNy4zeiIvPgogICAgICA8cGF0'
    b'aCBkPSJNMTk4NS45IDc5Ni40cy40LTUuNy0uMi04LjVhMjEgMjEgMCAwIDAtMy4xLTdjLTEu'
    b'NS0yLjMtNS43LTYtNS43LTZtLTEuNCAyNy44czMuNC4xIDQuOS0uNmMyLjYtMS4zIDYtNi4z'
    b'IDYtNi4zczYuNyA0LjYgMTAuNCA0YzEuOC0uMiAzLjItMS44IDQuMi0zLjRhOCA4IDAgMCAw'
    b'IDEuMi01LjdjLS4zLTEuNS0xLjYtMi42LTIuOC0zLjYtMi4zLTItNi40LTEuNy03LjktNC4y'
    b'LTEuMi0yLS41LTQuOS4yLTcuMSAxLjQtNC44IDQuNy04LjcgNy41LTEyLjggMS43LTIuNiA1'
    b'LjMtNC40IDUuNi03LjUuMi0xLjYtMi00LjYtMi00LjZzLTUuMi0uMS03LjcuNmMtNCAxLjIt'
    b'OC4zIDMtMTEuMiA2LjEtMi40IDIuNi0zIDYuNC00LjMgOS43LTEgMi41LTIuNSA3LjctMi41'
    b'IDcuN3MtNiAwLTguNyAxLjJhMTcuMSAxNy4xIDAgMCAwLTguNyA3LjdjLTEuMiAyLjctMSA2'
    b'LjIgMCA5IDEuMSAzIDMuNSA1LjMgNi4xIDcgMi45IDEuOCA5LjcgMi44IDkuNyAyLjh6TTE3'
    b'NDAuOCA3NzVzLTQuMSAzLjYtNS42IDUuOGEyMSAyMSAwIDAgMC0zLjIgNy4xYy0uNiAyLjgt'
    b'LjEgOC41LS4xIDguNW0tMTctNDUuNXMtMi4yIDMtMiA0LjZjLjQgMy4xIDQgNSA1LjcgNy41'
    b'IDIuNyA0LjEgNiA4IDcuNSAxMi44LjYgMi4yIDEuMyA1IC4xIDctMS40IDIuNi01LjYgMi40'
    b'LTcuOCA0LjMtMS4yIDEtMi41IDIuMS0yLjkgMy42YTggOCAwIDAgMCAxLjIgNS43YzEgMS42'
    b'IDIuNSAzLjIgNC4zIDMuNCAzLjYuNiAxMC4zLTQgMTAuMy00czMuNSA1IDYgNi4zYzEuNS43'
    b'IDUgLjYgNSAuNnM2LjgtMSA5LjctMi45YzIuNS0xLjYgNS00IDYtNi44IDEtMi45IDEuMy02'
    b'LjQgMC05LjFhMTYuOCAxNi44IDAgMCAwLTguNy03LjdjLTIuNi0xLjMtOC43LTEuMi04Ljct'
    b'MS4ycy0xLjQtNS4yLTIuNC03LjdjLTEuMy0zLjMtMi03LjEtNC40LTkuN2EyNC43IDI0Ljcg'
    b'MCAwIDAtMTEuMi02LjFjLTIuNS0uNy03LjctLjYtNy43LS42em0xMzUuNiAxNC4zIDguNC0y'
    b'LjQgOC4zIDIuNG0tMTQuNSAyMHMtNi41LTUuOC03LjctOS44YTggOCAwIDAgMSAuNC01LjVj'
    b'MS4yLTIuMiA1LjktNC43IDUuOS00LjdzLTcuMS0zLjQtOS02LjZhOC42IDguNiAwIDAgMS0u'
    b'NS02LjMgMTcgMTcgMCAwIDEgNS44LThjMy4yLTIuNyAxMS4zLTUuNCAxMS4zLTUuNHM4IDIu'
    b'NyAxMS4yIDUuM2ExNyAxNyAwIDAgMSA1LjkgOC4xYy41IDIgLjQgNC40LS42IDYuMy0xLjkg'
    b'My4yLTkgNi42LTkgNi42czQuOCAyLjUgNiA0LjdjLjggMS42LjkgMy43LjMgNS41LTEuMiA0'
    b'LTcuNyA5LjktNy43IDkuOWwtNi4xLjR6bTIyLjctMjYuOHMxMy40IDUuNyAxOCAxMS4xYzEu'
    b'MiAxLjUgMi4zIDMuNSAyLjIgNS41LS41IDctMTAuMyAxOC4yLTEwLjMgMTguMmwtMjAtOC4z'
    b'aC0xMi45bC0yMCA4LjNzLTkuOC0xMS4zLTEwLjItMTguMmMtLjItMiAxLTQgMi4yLTUuNSA0'
    b'LjUtNS40IDE4LTExLjEgMTgtMTEuMSIvPgogICAgICA8cGF0aCBkPSJtMTg0NC40IDY2OS4y'
    b'IDgtNi4yIDYuNS4yLTYuNi0uMnMtMy42LTIuNC00LjYtNC4yYTkgOSAwIDAgMS0xLTZjLjUt'
    b'Mi43IDItNS41IDQuNC02LjkgMi4zLTEuMyA3LjgtLjUgNy44LS41czUuNS0uOCA3LjcuNWMy'
    b'LjQgMS40IDMuOSA0LjIgNC41IDYuOC40IDIgMCA0LjMtMSA2LTEgMS45LTQuNiA0LjMtNC42'
    b'IDQuM2wtNi43LjIgNi41LS4yIDggNi4ybTUyLjcgNS4xLTIuNyA0LjdtMzIuNi0yMC03LjUg'
    b'MW04LjUgOC44LTExLjUuNm0tMS41LTEzLjhjMS41IDEgNC4yIDIuOSA0LjYgNC42YTEwIDEw'
    b'IDAgMCAxLTMuMSA5LjJjLTIuNCAyLTkuMyAxLjUtOS4zIDEuNW0tMTgxLjcgMzMuNiAxNy00'
    b'LjJjOC0yIDE2LTQuMiAyNC4yLTUuNyA5LjMtMS42IDE4LjctMi44IDI4LTMuNSAxMS44LS45'
    b'IDM1LjMtLjYgMzUuMy0uNnMyMy41LS4zIDM1LjIuNmM5LjQuNyAxOC43IDEuOSAyOCAzLjUg'
    b'OC4yIDEuNSAxNi4yIDMuOCAyNC4zIDUuN2wxNyA0LjJtLTE3MS42LTMwLjIgMi43IDQuN20t'
    b'MzIuNy0yMCA3LjUgMW0tOC41IDguOCAxMS41LjZtLTYuNCAxNnMxMi41LTMuMiAxOC44LTQu'
    b'NWM3LTEuNCAxNC0yLjggMjEtMy43IDgtMSAxNi4xLTEuNSAyNC4zLTIgOS42LS40IDI4Ljkt'
    b'LjMgMjguOS0uM3MxOS4yIDAgMjguOS40YTI4NC4yIDI4NC4yIDAgMCAxIDQ1LjIgNS42YzYu'
    b'MyAxLjMgMTguOSA0LjUgMTguOSA0LjVNMTc4MS42IDY3MXMtNi44LjUtOS4yLTEuNWMtMi41'
    b'LTItNC02LTMuMi05LjIuNy0yLjQgNS42LTUuMiA1LjYtNS4ybTYzLjEgNzRjLTEyIC44LTI0'
    b'IDEuNS0zNS44IDMuN2EyMjAuMiAyMjAuMiAwIDAgMC0zNi4yIDkuN2MtMTEuMSA0LTIyLjkg'
    b'MjIuNi0zMiAxNS4yLTItMS42LjctNSAxLjYtNy40YTQzIDQzIDAgMCAxIDcuOC0xMi42YzIu'
    b'NC0yLjcgOC0zIDguNS02LjYuNS0yLjYtMy40LTQtNC4zLTYuNmExNyAxNyAwIDAgMS0uNS0x'
    b'MGMxLjItNC4xIDYuNS02LjIgNy43LTEwLjMgMS0zLjYtMi41LTcuOC0uOS0xMS4yIDIuMi00'
    b'LjIgMTEuNC0yLjcgMTItNy40LjQtMi4zLTMuOC0zLTQuNS01LjEtLjYtMS42LjMtMy4zLjMt'
    b'NSAwLTIuMS40LTQuNS0uNi02LjUtLjktMS43LTMuNy0yLjEtNC4zLTRhNS41IDUuNSAwIDAg'
    b'MSAxLjEtNS40YzEtMSAzLjcuNCA0LjMtLjkgMS40LTIuNi0yLjUtNS4zLTMuNy04LTEuNC0z'
    b'LjItMy4yLTYuMy00LTkuNy0uNi0yLjctMy03LS42LTguMyAyLjgtMS42IDUuNSAzLjIgOCA1'
    b'LjEgMy40IDIuNSA3LjIgNC44IDkuNSA4LjMgMS43IDIuNS43IDYuNSAzIDguNiAyLjYgMi41'
    b'IDcuNy41IDEwLjQgMi45IDIuNCAyIDQuNSA1LjUgMy44IDguNS0uNyAzLTcuNiAyLjktNyA1'
    b'LjguOSAzLjQgNyAzLjIgMTAuNCAyLjUgMi0uMyAzLjUtMi4yIDUuMS0zLjQgMS40LTEgMi40'
    b'LTIuMiA0LTIuOCAxLjYtLjggNS4zLTEgNS4zLTFsLTIuMS0uNXMtMy4yLTIuNS0zLjUtNC4z'
    b'YTYgNiAwIDAgMSAxLjYtNSA3LjcgNy43IDAgMCAxIDUuNS0yLjJjMS43IDAgMy41LjcgNC42'
    b'IDEuOWE2LjMgNi4zIDAgMCAxIDEuNyA0LjggNiA2IDAgMCAxLTIuMyAzLjcgMTMgMTMgMCAw'
    b'IDEtNC42IDEuNWwyLjMuNiA2LjEgOC41IDI2LjYtMS41czMuMy0zLjMgMi42LTUuMmMtLjct'
    b'MS45LTIuNS0yLjYtNS43LTIuNS04LjUuNC0xMC4zLTYuOC0xMC0xMiAuMy00LjQgNS41LTcu'
    b'MyA5LjUtOSA0LTEuNSAxMC44IDMuNyAxMi42LS4xIDEuNS0zLjMtNS44LTUtNy04LjUtLjUt'
    b'MS41LS41LTMuNC4yLTQuOCAxLjgtMy42IDUuNy02IDkuNC03LjcgMS42LS43IDUtLjggNS0u'
    b'OHMzLjYuMSA1LjEuOGMzLjcgMS43IDcuNiA0LjEgOS40IDcuNy43IDEuNC43IDMuMy4yIDQu'
    b'OC0xLjEgMy41LTguNSA1LjItNyA4LjUgMS44IDMuOCA4LjctMS40IDEyLjYuMiA0IDEuNiA5'
    b'LjIgNC41IDkuNSA4LjkuMyA1LjItMS40IDEyLjQtMTAgMTItMy4yLS4xLTUgLjYtNS43IDIu'
    b'NS0uNiAxLjkgMi43IDUuMiAyLjcgNS4ybDI2LjUgMS41IDYuMS04LjUgMi4zLS42cy0zLjMt'
    b'LjUtNC41LTEuNWE2IDYgMCAwIDEtMi4zLTMuN2MtLjItMS43LjUtMy42IDEuNi00LjggMS4x'
    b'LTEuMiAzLTEuOSA0LjYtMS45IDIgMCA0LjEuNyA1LjUgMi4yIDEuMiAxLjIgMiAzLjIgMS42'
    b'IDUtLjMgMS44LTMuNSA0LjMtMy41IDQuM2wtMi4xLjVzMy43LjIgNS40IDFjMS41LjYgMi42'
    b'IDEuOSAzLjkgMi44IDEuNyAxLjIgMy4xIDMgNS4xIDMuNCAzLjUuNyA5LjYgMSAxMC4zLTIu'
    b'NS43LTMtNi4xLTIuOS02LjgtNS44LS43LTMgMS4zLTYuNSAzLjctOC41IDIuNy0yLjQgNy45'
    b'LS40IDEwLjUtMi45IDIuMi0yIDEuMy02IDMtOC42IDIuMy0zLjUgNi01LjggOS40LTguMyAy'
    b'LjUtMS45IDUuMy02LjcgOC01LjEgMi40IDEuNCAwIDUuNi0uNiA4LjMtLjggMy40LTIuNiA2'
    b'LjUtNCA5LjctMS4yIDIuNy01IDUuNC0zLjcgOCAuNyAxLjMgMy4zLS4yIDQuMy45YTUuNSA1'
    b'LjUgMCAwIDEgMS4xIDUuNGMtLjYgMS45LTMuNCAyLjMtNC4zIDQtMSAyLS41IDQuNC0uNSA2'
    b'LjYgMCAxLjYuOCAzLjMuMyA0LjktLjggMi4xLTUgMi44LTQuNiA1LjEuNyA0LjcgOS45IDMu'
    b'MiAxMiA3LjQgMS43IDMuNC0xLjkgNy42LS45IDExLjIgMS4yIDQuMSA2LjUgNi4yIDcuOCAx'
    b'MC4zIDEgMy4yLjQgNi44LS42IDEwLS44IDIuNS00LjcgNC00LjMgNi42LjYgMy42IDYuMiAz'
    b'LjkgOC42IDYuNiAzLjMgMy42IDUuOCA4IDcuNyAxMi42IDEgMi4zIDMuNyA1LjggMS43IDcu'
    b'NC05LjIgNy40LTIxLTExLjEtMzItMTUuMmEyMjAuMiAyMjAuMiAwIDAgMC03Mi0xMy40Yy03'
    b'LS40LTIxLS40LTIxLS40cy0xNCAwLTIxIC40em0zMS4xLTEzMy43LTEwLjEuMS0xMC4yLS4x'
    b'bTE3LTMzLjljMi42LTUuNi0yLTkuNy02LjgtMTMuOC00LjggNC05LjQgOC4yLTYuOCAxMy44'
    b'bTE0LjEgNDYuOGMzLjkuMiA4LjYgNC4yIDExLjYgMS43IDEuMy0xLjIuNy0zLjcgMC01LjMt'
    b'MS42LTMuOC04LjQtNC43LTguNy04LjgtLjMtMy41IDUuMS01LjIgNi4zLTguNS41LTEuNy42'
    b'LTMuNyAwLTUuMy0yLjgtNi42LTE0LjUtNy0xNi42LTEzLjctLjktMyA2LTYuNSA2LjgtNi45'
    b'IDQuNC0xLjkgOS43IDIuNyAxNCAuOCAzLTEuMiA2LjEtNC4xIDYtNy4zIDAtMy40LTMuNi02'
    b'LjMtNi44LTcuNy02LjEtMi42LTE2LjIgNi0yMCAuNS0zLjQtNS4xIDguNy0xMS4xIDctMTct'
    b'LjctMi45LTctNS4zLTctNS4zcy02LjEgMi40LTYuOSA1LjNjLTEuNiA1LjkgMTAuNSAxMS45'
    b'IDcgMTctMy43IDUuNS0xMy44LTMuMS0yMC0uNS0zLjEgMS40LTYuOCA0LjMtNi44IDcuNyAw'
    b'IDMuMiAzLjEgNiA2IDcuMyA0LjMgMS45IDkuNy0yLjcgMTQtLjguOS40IDcuNyA0IDYuOCA2'
    b'LjktMiA2LjctMTMuNyA3LTE2LjUgMTMuN2E3LjggNy44IDAgMCAwIDAgNS4zYzEuMSAzLjMg'
    b'Ni42IDUgNi4zIDguNS0uMyA0LjEtNy4yIDUtOC43IDguOC0uNyAxLjYtMS40IDQuMSAwIDUu'
    b'MyAzIDIuNSA3LjctMS41IDExLjYtMS43IDIuNC0uMiA3LjMgMCA3LjMgMHM0LjgtLjIgNy4z'
    b'IDB6Ii8+CiAgICAgIDxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik0xOTUzLjcgOTUzLjVzLTcuMS0z'
    b'LTEwLjgtNC4zYTI1OCAyNTggMCAwIDAtMjAtNi41Yy02LjYtMS44LTEzLjItMy43LTIwLTQu'
    b'NS0xNC42LTEuNi00NC0uMi00NC0uMnMtMjkuNC0xLjQtNDQgLjJjLTYuOC44LTEzLjUgMi43'
    b'LTIwIDQuNWEyNTggMjU4IDAgMCAwLTMwLjkgMTAuOE0xOTY2IDczMXMtMTItNC44LTE4LjEt'
    b'Ni45Yy01LjEtMS43LTEwLjItMy41LTE1LjUtNC44LTYuNC0xLjYtMTIuOS0yLjYtMTkuNC0z'
    b'LjVhMzg3LjEgMzg3LjEgMCAwIDAtNTQuMS0zLjRzLTE3LjIuMS0yNS44LjZhMzc2LjUgMzc2'
    b'LjUgMCAwIDAtNDcuOCA2LjNjLTUuMiAxLjMtMTAuMyAzLTE1LjQgNC44LTYuMSAyLjEtMTgg'
    b'Ni45LTE4IDYuOW0tMTQuMiAxMjAuNHMxNy41LTYgMjYuNC04LjdjOS4xLTIuOCAxOC4yLTYg'
    b'MjcuNS04IDExLjItMi41IDIyLjYtMy43IDM0LTUgMTEtMS4xIDMzLjMtMi4zIDMzLjMtMi4z'
    b'czIyLjIgMS4yIDMzLjMgMi40YzExLjMgMS4yIDIyLjggMi40IDM0IDQuOCA5LjMgMiAxOC4z'
    b'IDUuMyAyNy41IDguMWwyNi40IDguNyIvPgogICAgPC9nPgogICAgPGcgZmlsbD0iI2NjYyIg'
    b'dHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTIzKSBzY2FsZSguMTkyKSI+CiAgICAgIDxnIGlkPSJ2'
    b'YS1iIj4KICAgICAgICA8cGF0aCBkPSJtMTUzMy4zIDkwNCAxMDEuMiA4Ni44cy01LjIgMTEu'
    b'Mi03LjMgMTdhMTQyLjYgMTQyLjYgMCAwIDAtOS4zIDQxbC0xMTgtMTA4YzEuNy0yNC43IDE1'
    b'LjYtMzMuNSAzMy40LTM2Ljh6Ii8+CiAgICAgICAgPHBhdGggZD0ibTE1MTkgOTU4LjItMjQu'
    b'MyAyNy4yIDE1LjIgMTQuNi0yMy41IDIyLjgtMTUuMi0xNS4xLTI1LjUgMjcuMi0uMiAzMy43'
    b'IDU4IDQ1LjUgMjAuMS0xNC45LTEuMS0zMi4zIDE1LjQgOC42IDE1LjUtOS40LjggMjkuMS0x'
    b'Mi42LTkuMS0xMy43IDE4LTEuNCAzMiA0My43IDM5IDUzLTQ3LjEtNC0xNC4xLTIuMi0xMi43'
    b'LTEuMy0yNS4xIDItMjcuNXoiLz4KICAgICAgICA8cGF0aCBkPSJtMTQ5NC43IDk4NS40LS42'
    b'IDMwIDE1LjYtMTUuM3oiLz4KICAgICAgICA8cGF0aCBmaWxsPSJub25lIiBkPSJtMTU3MiAx'
    b'MTQwLjQtMS45IDM0LjNtLTE4LjYtMTM5LjcuNiAzMS44bS0xNC44LTE3LjMuOSAyNS44bS0x'
    b'NC41LTM2LjMuNiAyOW0tMjEuNCAxNS4yLjMgMzAuNm0yNC43LTkuNyA0NCAzNyA0NS4xLTM5'
    b'LjZtLTE3MS02Ni45IDU3LjYgNDkuMiAxOC45LTE2LjktMTUtMTIuNiAxNi43LTE1LjcgMTIu'
    b'OSAxMS4xIDE0LjUtMTQuOCAxOSAxOC4zLTE3LjIgMTMuNCAxNiAxNC42LTE1LjIgMTQiLz4K'
    b'ICAgICAgICA8cGF0aCBkPSJtMTkwMS4zIDEyMjkuMyA0OC43IDQ0LjYgMTAuNyAzMS41LTYy'
    b'LjYtNi43LTM1LjctMzUuMy0zOC0zNS4yLTE2NC0xNDIuMXMzLjUtMTMuMSA1LjYtMTkuNWMz'
    b'LjItOS4zIDYuOS0xOC40IDEwLjYtMjcuNWwzLTYuOCAxODMgMTYyLjN6Ii8+CiAgICAgICAg'
    b'PHBhdGggZD0iTTE5NDIuNyAxMjM2YzI3IDM4IDcyLjcgNzMuNyA4Ni41IDkwLjkgMTMuOSAx'
    b'Ny4yIDIyLjggMzMuNSAyLjYgNTUuNXMtNDMgOS41LTYxLjEtMi42Yy0xOC4xLTEyLTQ5LjYt'
    b'NTEuMy05NC44LTgxLjN6Ii8+CiAgICAgICAgPHBhdGggZD0ibTE5MjYuNyAxMjk5LjgtMzUu'
    b'Mi0xNm00MS0zOC4yYzIuNCA4IC41IDE2LjggMy42IDI0LjQgMyA3LjYgMTQgMjAgMTQgMjBz'
    b'LTcgMS0xMC4zIDIuMmMtNC43IDEuOS0xMiAyLjctMTMuMSA3LjctMSA0LjMgNCA4IDcgMTEu'
    b'MiAzIDMuMSA2LjcgNS40IDEwLjQgNy42IDYuMSAzLjYgMTIuNCA3LjYgMTkuNCA4LjkgOC43'
    b'IDEuNiAyNS4xLTEwLjggMjYuNi0yIC42IDMuNi03LjQgMS4zLTEwLjcgMy03LjggMy44LTEx'
    b'LjYgMTItNC44IDE3LjggNC40IDMuNyAxMS4zIDIuNCAxNyAyLjkgNS41LjQgMTEuNy0yLjgg'
    b'MTYuNSAwIDUuNiAzLjIgMTIuNyAxMSA5LjcgMTYuOC0zIDYtMTQuNSA1LjgtMjAgMi00LTMt'
    b'Mi45LTkuNS0zLjUtMTQuNHYtNC40Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjE1NC43IiBj'
    b'eT0iMTQ4MC4xIiByPSIxMjkuNyIvPgogICAgICAgIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0y'
    b'MTA2LjEgMTQ4NS43YTQwLjUgNDAuNSAwIDEgMCA0MC41IDQwLjRsMTQtLjZhNDAuNSA0MC41'
    b'IDAgMSAwIDQwLjUtNDAuNWwuNi03LjlhNDAuNSA0MC41IDAgMSAwLTQwLjUtNDAuNWwtMTQt'
    b'MS4yYTQwLjUgNDAuNSAwIDEgMC00MC41IDQwLjV6Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0i'
    b'MjE1NC43IiBjeT0iMTQ0Ni4xIiByPSIxNC42Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjE4'
    b'OS40IiBjeT0iMTQ4MC4xIiByPSIxNC42Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjE1NS4z'
    b'IiBjeT0iMTUxMS4yIiByPSIxNC42Ii8+CiAgICAgICAgPGNpcmNsZSBjeD0iMjExOS4zIiBj'
    b'eT0iMTQ4MC4xIiByPSIxNC42Ii8+CiAgICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTIx'
    b'NTIuMiAxNTU4LjRjLTUuMyAxMS0xMi42IDE2LTIxLjkgMjJhNjMuMiA2My4yIDAgMCAwIDQz'
    b'LjggMCA1NCA1NCAwIDAgMS0yMS45LTIyem0tNzYuNS04MC4yYy0xMS01LjMtMTYtMTIuNi0y'
    b'Mi0yMmE2My4yIDYzLjIgMCAwIDAgMCA0NCA1MyA1MyAwIDAgMSAyMi0yMnptMTU5LjIgMy42'
    b'YzExLTUuMyAxNi0xMi42IDIyLTIxLjlhNjMuMiA2My4yIDAgMCAxIDAgNDMuOWMtNC43LTku'
    b'My0xMi0xNi0yMi0yMnptLTc4LjQtODAuOGMtNS4zLTExLTEyLjYtMTYtMjItMjJhNjMuMiA2'
    b'My4yIDAgMCAxIDQ0IDAgNTMgNTMgMCAwIDAtMjIgMjJ6Ii8+CiAgICAgIDwvZz4KICAgICAg'
    b'PGcgZmlsbD0iI2NlOWQwOSI+CiAgICAgICAgPGcgaWQ9InZhLWMiPgogICAgICAgICAgPHBh'
    b'dGggZD0iTTE1MzMuNSA5MDMuOHMuNy01IDAtNy40YTIyLjYgMjIuNiAwIDAgMC02LjYtMTAu'
    b'MiAxOS42IDE5LjYgMCAwIDAtOS4yLTQuNiAyNC41IDI0LjUgMCAwIDAtMTcuNyA0LjJsLTE1'
    b'IDYuMi01LjUgMTcuN3MtMy4yIDUuNi00IDguN2EyMyAyMyAwIDAgMC0uNSAxMC4xYzEgMy45'
    b'IDMuMiA3LjYgNi4zIDEwLjJhMTkgMTkgMCAwIDAgMTAuMyA0IDI4IDI4IDAgMCAwIDguMy0x'
    b'LjljMS42LTE4LjYgOS45LTMyLjggMzMuNS0zNi45eiIvPgogICAgICAgICAgPHBhdGggZD0i'
    b'bTE1MDAuMyA4ODUuNi0zOC44LTE3LTMuMSAzIDIxIDM4LjJzNi04LjcgOS40LTEyLjdjMy42'
    b'LTQuMSAxMS41LTExLjUgMTEuNS0xMS41eiIvPgogICAgICAgICAgPGNpcmNsZSBjeD0iMTQ1'
    b'Ny4zIiBjeT0iODY1LjMiIHI9IjE2Ii8+CiAgICAgICAgICA8cGF0aCBkPSJNMTU2Ni4yIDkz'
    b'Mi4zYzMuNCAyOCA3LjMgNTUuOSAxNiA4My44bDMxIDI4LjVjLTYuNS0yOS4zLTE4LjQtNTgu'
    b'NS0xOC4zLTg3Ljd6Ii8+CiAgICAgICAgICA8cGF0aCBkPSJtMTYxMyA5NzIuNC04NS40LTYu'
    b'NCAyNy4yIDI1IDc4IDMuMyAxLjItNHptMTA1LjQgOTQuNmE2MS45IDYxLjkgMCAwIDAtMzcu'
    b'OSAzN2MtNi40LjctMTIuMy43LTE0LjQtNGE1OC41IDU4LjUgMCAwIDEgMzUuNy00Ny44YzE1'
    b'LTIuOCAxMi4yIDguOSAxNi42IDE0Ljd6bTI3LjUgMjUuOGE2MS45IDYxLjkgMCAwIDAtMzcu'
    b'OSAzNy4yYy02LjMuNS0xMi4zLjYtMTQuNC00LjFhNTguNSA1OC41IDAgMCAxIDM1LjgtNDcu'
    b'OGMxNS0yLjggMTIuMSA4LjkgMTYuNSAxNC43em0zMTIuOCAyNjEuOWE3MiA3MiAwIDAgMC0x'
    b'NS4xIDEuNWMuMyA4LTMgMTYuNi0xMS44IDI2LjJhMzMuNCAzMy40IDAgMCAxLTIzLjcgMTJz'
    b'LTIuOCAxNy43IDIuNiAyMy4zYzYuMyA2LjYgMjcuMSAzLjkgMjcuMSAzLjlsMS44LTEuMWEx'
    b'MjkuNyAxMjkuNyAwIDAgMSAzMS45LTM5LjhsLjMtMS4zczMtMTYuNS0yLjEtMjEuNWMtMi40'
    b'LTIuMy02LjYtMy0xMSAweiIvPgogICAgICAgICAgPGNpcmNsZSBjeD0iMjI1NC41IiBjeT0i'
    b'MTM3NS40IiByPSIxNy43Ii8+CiAgICAgICAgICA8Y2lyY2xlIGN4PSIyMjYwLjYiIGN5PSIx'
    b'NTgwIiByPSIxNy43Ii8+CiAgICAgICAgICA8Y2lyY2xlIGN4PSIyMDYyLjEiIGN5PSIxNTkx'
    b'LjYiIHI9IjE3LjciLz4KICAgICAgICA8L2c+CiAgICAgIDwvZz4KICAgIDwvZz4KICAgIDxn'
    b'IGZpbGw9IiNjZTlkMDkiIHRyYW5zZm9ybT0ibWF0cml4KC0uMTkyIDAgMCAuMTkyIDgzNyAw'
    b'KSI+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9'
    b'IjEwMCUiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtYyIgd2lkdGg9IjEwMCUiIGhl'
    b'aWdodD0iMTAwJSIgZmlsbD0iI2NjYyIvPgogICAgPC9nPgogICAgPGcgZmlsbD0iI2ZhMDIw'
    b'NCIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTIzKSBzY2FsZSguMTkyKSI+CiAgICAgIDxwYXRo'
    b'IGlkPSJ2YS1kIiBkPSJNMTg2OS4yIDExNzUuOGMwIDUuNC00LjUgNy40LTEzLjMgNy40LTgu'
    b'NyAwLTEyLjctMi41LTEyLjctNy45czQtNi43IDEyLjctNi43YzguOCAwIDEzLjMgMS44IDEz'
    b'LjMgNy4yeiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1kIiB3aWR0aD0iMTAwJSIg'
    b'aGVpZ2h0PSIxMDAlIiB4PSI2LjQiIHk9IjE0LjMiLz4KICAgICAgPHBhdGggZD0iTTE4Nzcu'
    b'MyAxMjA4LjdjLTEuNyA1LTYuNyA1LjYtMTUgMi43LTguMi0zLTExLjItNi42LTkuNC0xMS43'
    b'IDEuOC01IDYtNSAxNC4zLTIuMSA4LjIgMi45IDEyIDYgMTAuMSAxMXoiLz4KICAgICAgPHBh'
    b'dGggaWQ9InZhLWUiIGQ9Ik0xODc3LjUgMTIyMi41Yy0xIDUuMy01LjkgNi40LTE0LjQgNC43'
    b'LTguNi0xLjctMTItNS0xMS0xMC4zIDEtNS4zIDUuMy01LjggMTMuOC00IDguNiAxLjcgMTIu'
    b'NyA0LjMgMTEuNiA5LjZ6Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWUiIHdpZHRo'
    b'PSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjQiIHk9IjE2LjEiLz4KICAgICAgPHBhdGggZD0i'
    b'TTE5MjEuNyAxMjE2LjJjLTIuNi0uNy0yLjMtNS4zLTEuNi03LjkgMS4yLTQgOC40LTkuMSA4'
    b'LjQtOS4xczEuOCA1LjYgMSA4LjJjLTEuMiAzLjctNCA5LjgtNy44IDguOHoiLz4KICAgICAg'
    b'PHBhdGggZD0iTTE5MTIuMyAxMjI0LjRjLTIuOC0uNi0zLjItNS41LTIuNS04LjMgMS4yLTQu'
    b'MyA5LjctOS4zIDkuNy05LjNzMS41IDYgLjUgOC44Yy0xLjMgMy43LTMuOSA5LjctNy43IDgu'
    b'OHptLTEwLjggMTUuNmMtNC4zLTEuMS0zLjgtOC44LTIuNi0xMyAxLTMuNiAzLjctOS4yIDcu'
    b'Mi04LjMgNC4yIDEgNC4yIDguMyAzLjEgMTIuNS0uOSAzLjgtNCA5LjgtNy43IDguOHoiLz4K'
    b'ICAgICAgPHBhdGggZD0iTTE4ODguNyAxMjUyLjJjLTQuMi0xLTYtNy42LTUuMS0xMS45Ljkt'
    b'NC40IDUuMy0xMC40IDkuNy05LjQgNC41IDEgNiA4LjMgNSAxMi44LTEgNC4xLTUuNCA5LjQt'
    b'OS42IDguNXptLTIuMiA3LjRjLTEgNS03LjUgNi44LTExLjUgNS41LTQuMS0xLjMtOS41LTcu'
    b'MS04LjQtMTIuNSAxLjItNS40IDguMi02LjggMTIuMy01LjIgMy45IDEuNSA4LjcgNy4yIDcu'
    b'NiAxMi4yem0tODUtNDkuM3M1LjEgMi41IDcuMyA0LjhjMi4zIDIuNCA1LjEgMy4zIDMuNyA2'
    b'LjktMS40IDMuNi01LjggMi40LTguMS0uMi0yLjEtMi4zLTMtMTEuNS0zLTExLjV6bTI1LjMg'
    b'OC43YzUuMyAxLjEgNS4xIDcuMiAyLjUgMTEtMi44IDMuOC0xMC45IDguOS0xNi40IDcuOC01'
    b'LjUtMS4xLTQuOC03LjgtMS44LTExLjcgMi45LTMuNiAxMC42LTggMTUuNy03eiIvPgogICAg'
    b'ICA8cGF0aCBpZD0idmEtZiIgZD0iTTE4NDQuMyAxMjMwLjVjNC44IDIuMiAzLjQgOC4xIDAg'
    b'MTEuMi0zLjYgMy4yLTEyLjYgNi4zLTE3LjcgNC01LjItMi4yLTMtOC42LjgtMTEuNyAzLjYt'
    b'MyAxMi01LjYgMTYuOS0zLjV6Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWYiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjE0IiB5PSIxMC43Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0xODYzIDEyNTAuN2M0LjguNyA2IDcuNCA0LjYgMTEuNy0xLjYgNC41LTcuNSAxMC42'
    b'LTEyLjUgOS44LTUuMS0uOC02LTgtNC4yLTEyLjYgMS42LTQuMiA3LjMtOS43IDEyLTl6Ii8+'
    b'CiAgICAgIDxwYXRoIGQ9Ik0xODc1LjEgMTI2NS4zYzQgMi4zIDMgOS42LjQgMTMuNi0yLjcg'
    b'NC4xLTkuOCA4LjYtMTQgNi4yLTQuMi0yLjUtMi43LTEwLjMuMi0xNC40IDIuOC0zLjggOS41'
    b'LTcuNiAxMy40LTUuNHptLTg2LjEtMzkuOWM0LjMtLjMgNy4yIDYgNy4xIDEwLjYgMCA0Ljkt'
    b'My4zIDEyLjQtNy43IDEyLjgtNC41LjQtNy4zLTYuNy03LTExLjYuMS00LjYgMy40LTExLjQg'
    b'Ny42LTExLjh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xODAzIDEyMzcuN2M0IC45IDUgNy44IDMu'
    b'NSAxMi4yLTEuNiA0LjYtNyAxMC44LTExLjMgOS44LTQuNC0xLTUtOC42LTMuMi0xMy4yIDEu'
    b'Ni00LjMgNi44LTkuOCAxMS04Ljl6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xODE1LjggMTI0Ni4y'
    b'YzUgMS4yIDYgOS44IDQuMiAxNS4zLTEuOCA1LjctOC4yIDEzLjQtMTMuNCAxMi4yLTUuMi0x'
    b'LjMtNS44LTEwLjctMy43LTE2LjUgMS45LTUuMyA4LTEyLjEgMTIuOS0xMXoiLz4KICAgICAg'
    b'PHBhdGggZD0iTTE4MjYuMiAxMjU2LjhjNS0uNiA5IDcgOS4zIDEyLjguMyA2LTMgMTUuNC04'
    b'LjIgMTYtNS4zLjctOS4yLTcuOS05LjMtMTQtLjEtNS42IDMuMy0xNC4yIDguMi0xNC44eiIv'
    b'PgogICAgICA8cGF0aCBpZD0idmEtZyIgZD0iTTE4MzguNiAxMjY1LjdjNC41LS42IDguMiA1'
    b'LjggOC40IDEwLjUuMyA1LTIuNyAxMi44LTcuNCAxMy40LTQuOS42LTguNC02LjYtOC41LTEx'
    b'LjYgMC00LjcgMy0xMS44IDcuNS0xMi4zeiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2'
    b'YS1nIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxMi44IiB5PSIxMC40Ii8+CiAg'
    b'ICAgIDxwYXRoIGlkPSJ2YS1oIiBkPSJNMTkyOS4zIDEyNTAuOWMtMy4zIDIuOC05LjcuMy0x'
    b'Mi42LTIuOS0zLjEtMy4zLTUuMy0xMC41LTEuOC0xMy41IDMuNC0zIDEwLjIuMiAxMy4yIDMu'
    b'NiAyLjcgMy4zIDQuNCAxMCAxLjIgMTIuOHoiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIj'
    b'dmEtaCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iLTciIHk9IjEyLjgiLz4KICAg'
    b'ICAgPHVzZSB4bGluazpocmVmPSIjdmEtaCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIg'
    b'eD0iLTE5LjUiIHk9IjIzLjUiLz4KICAgICAgPHBhdGggZD0iTTE5MDUuMiAxMjgxLjJjLTEu'
    b'MSA0LjEtOCA1LjYtMTIuMSA0LjUtNC40LTEtMTAuMi01LjgtOS0xMC4yIDEuMy00LjQgOC43'
    b'LTUuNiAxMy00LjMgNC4yIDEuMiA5LjIgNS45IDggMTB6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0x'
    b'ODg3LjIgMTI3OC4yYzMuNiAyLjUgMi44IDEwLjUuNCAxNC45LTIuNiA0LjUtOSA5LjUtMTIu'
    b'OSA2LjgtMy45LTIuNy0yLjUtMTEuMy4yLTE1LjggMi41LTQuMiA4LjctOC40IDEyLjMtNnoi'
    b'Lz4KICAgICAgPHBhdGggZD0iTTE4NjkuNiAxMjg3LjVjNCAyLjQgMyA5LjYuNCAxMy42LTIu'
    b'NyA0LjEtOS44IDguNi0xNCA2LjItNC4yLTIuNS0yLjctMTAuMy4yLTE0LjQgMi44LTMuOCA5'
    b'LjUtNy42IDEzLjQtNS40eiIvPgogICAgICA8cGF0aCBpZD0idmEtaSIgZD0iTTE4MzEuMyAx'
    b'MzEzYy0zLjQgMy4xLS43IDExLjIgMi44IDE1LjIgMy43IDQuMiAxMS44IDguMSAxNS40IDQu'
    b'NyAzLjUtMy40LjMtMTItMy42LTE2LjEtMy43LTMuOS0xMS4yLTctMTQuNi0zLjl6Ii8+CiAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHg9Ii03LjMiIHk9IjEzLjgiLz4KICAgICAgPHBhdGggaWQ9InZhLWoiIGQ9Ik0xODIwLjgg'
    b'MTMzOS41Yy00LjMgMS44LTQuOCAxMC4yLTMgMTUuMyAxLjggNS4zIDcuOSAxMS45IDEyLjUg'
    b'MTAgNC42LTEuOCA0LjctMTEgMi42LTE2LjMtMi00LjktNy44LTEwLjctMTItOXoiLz4KICAg'
    b'ICAgPHVzZSB4bGluazpocmVmPSIjdmEtaiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIg'
    b'eD0iLTEwLjUiIHk9IjE0LjkiLz4KICAgICAgPHBhdGggaWQ9InZhLWsiIGQ9Ik0xODAyLjcg'
    b'MTM3MWMtNC42IDEtNi41IDkuMy01LjUgMTQuNiAxIDUuNSA2IDEzIDEwLjggMTEuOSA0Ljgt'
    b'MS4xIDYuNC0xMC4yIDUuMi0xNS43LTEuMi01LjEtNi0xMS44LTEwLjUtMTAuOHoiLz4KICAg'
    b'ICAgPHVzZSB4bGluazpocmVmPSIjdmEtayIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIg'
    b'eD0iLTEwLjEiIHk9IjE1LjkiLz4KICAgICAgPHBhdGggaWQ9InZhLWwiIGQ9Ik0xNzg0IDE0'
    b'MDMuM2MtNC42LjItOCA4LTggMTMuMyAwIDUuNiAzLjUgMTMuOSA4LjQgMTMuNyA1LS4yIDgu'
    b'Mi04LjggOC0xNC41LS4yLTUuMy0zLjctMTIuNy04LjMtMTIuNXoiLz4KICAgICAgPHVzZSB4'
    b'bGluazpocmVmPSIjdmEtbCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iLTEwLjMi'
    b'IHk9IjE5LjIiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtbCIgd2lkdGg9IjEwMCUi'
    b'IGhlaWdodD0iMTAwJSIgeD0iLTIyLjQiIHk9IjM3Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJl'
    b'Zj0iI3ZhLWwiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii0zNC45IiB5PSI1Mi4z'
    b'Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWwiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9'
    b'IjEwMCUiIHg9Ii00Ny44IiB5PSI2Ni41Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3Zh'
    b'LWwiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii02MiIgeT0iNzguMSIvPgogICAg'
    b'ICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1sIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4'
    b'PSItNzUuNiIgeT0iOTAuNiIvPgogICAgICA8cGF0aCBkPSJtMTY5Mi44IDE1MDAuMi01LjMg'
    b'MjAuNnMzIDcuMyA2IDdjNS41LS42IDctOSA4LTE0LjUgMS04LjQtOC43LTEzLjEtOC43LTEz'
    b'LjF6bTMyNC40IDEzLjFjMS42IDYgMTUuMyAxMS4zIDE1LjMgMTEuM2wtNi43LTI3LjhjLTUu'
    b'Ny4yLTkuNSAxMi40LTguNiAxNi40eiIvPgogICAgICA8cGF0aCBkPSJNMjAxNiAxNDkxYy00'
    b'LjMtMS44LTEwLjUgNC0xMi43IDguOS0yLjMgNS4xLTIuNCAxNCAyLjIgMTUuOSA0LjYgMS44'
    b'IDExLTQuOCAxMy4xLTEwIDItNSAxLjctMTMuMS0yLjYtMTQuOXoiLz4KICAgICAgPHBhdGgg'
    b'aWQ9InZhLW0iIGQ9Ik0yMDAwLjggMTQ3OC43Yy00LjctLjMtOC43IDcuMi05LjIgMTIuNS0u'
    b'NSA1LjYgMi4yIDE0LjEgNy4xIDE0LjQgNSAuMiA5LTggOS4zLTEzLjcuMy01LjMtMi42LTEz'
    b'LTcuMi0xMy4yeiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1tIiB3aWR0aD0iMTAw'
    b'JSIgaGVpZ2h0PSIxMDAlIiB4PSItMTMuNCIgeT0iLTEzLjciLz4KICAgICAgPHVzZSB4bGlu'
    b'azpocmVmPSIjdmEtbSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iLTI1LjkiIHk9'
    b'Ii0yOS4yIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLW0iIHdpZHRoPSIxMDAlIiBo'
    b'ZWlnaHQ9IjEwMCUiIHg9Ii0zOC43IiB5PSItNDIuMyIvPgogICAgICA8dXNlIHhsaW5rOmhy'
    b'ZWY9IiN2YS1tIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSItNDkiIHk9Ii02MC4z'
    b'Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLW0iIHdpZHRoPSIxMDAlIiBoZWlnaHQ9'
    b'IjEwMCUiIHg9Ii02MC4zIiB5PSItNzYuNCIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2'
    b'YS1tIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSItNzAuNiIgeT0iLTkzLjUiLz4K'
    b'ICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtbSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAw'
    b'JSIgeD0iLTc5LjgiIHk9Ii0xMTMuMyIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1t'
    b'IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSItODkuOCIgeT0iLTEzMS4yIi8+CiAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLW0iIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHg9Ii05OCIgeT0iLTE1Mi41Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xODgzLjggMTMwNC42cy0x'
    b'LjYgMjYuNiA4IDI4LjNjNi4xIDEuMSAxMC45LTE0LjkgMTAuOS0xNC45eiIvPgogICAgICA8'
    b'cGF0aCBpZD0idmEtbiIgZD0iTTE4NjIgMTYxMC44Yy0yLjkgMy42IDEgMTEuMiA1IDE0Ljcg'
    b'NC4zIDMuNiAxMi45IDYuMiAxNS45IDIuMyAzLTMuOS0xLjUtMTEuOS02LTE1LjQtNC0zLjIt'
    b'MTItNS4zLTE0LjktMS42eiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1uIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxOC4zIiB5PSItMi4yIi8+CiAgICAgIDx1c2Ug'
    b'eGxpbms6aHJlZj0iI3ZhLW4iIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjM2Ljgi'
    b'IHk9Ii01LjgiLz4KICAgICAgPHBhdGggaWQ9InZhLW8iIGQ9Ik0xOTE2LjIgMTYwMy44Yy0y'
    b'LjMgNCAyLjYgMTEgNy4xIDEzLjggNC44IDMgMTMuNyA0LjMgMTYgMCAyLjUtNC40LTMuMi0x'
    b'MS42LTguMS0xNC40LTQuNi0yLjYtMTIuOC0zLjQtMTUgLjZ6Ii8+CiAgICAgIDx1c2UgeGxp'
    b'bms6aHJlZj0iI3ZhLW8iIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjIwIiB5PSIt'
    b'My4yIi8+CiAgICAgIDxwYXRoIGlkPSJ2YS1wIiBkPSJNMTk1My41IDE1OTUuNGMtMiA0LjMg'
    b'My42IDEwLjcgOC40IDEzLjEgNSAyLjUgMTQgMyAxNi0xLjVzLTQuNC0xMS4yLTkuNS0xMy41'
    b'Yy00LjgtMi4yLTEzLTIuMy0xNSAyeiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1w'
    b'IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxOC45IiB5PSItNS42Ii8+CiAgICAg'
    b'IDxwYXRoIGlkPSJ2YS1xIiBkPSJNMTk5MS4zIDE1ODMuOWMtMS43IDQuNCA0LjIgMTAuNSA5'
    b'LjEgMTIuNSA1LjIgMi4yIDE0LjIgMi4yIDE1LjktMi40IDEuNy00LjctNS0xMS0xMC4zLTEz'
    b'LTUtMS44LTEzLjEtMS40LTE0LjcgMi45eiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2'
    b'YS1xIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxOS4yIiB5PSItNi4yIi8+CiAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXEiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHg9IjM3LjciIHk9Ii0xNCIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1xIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI1Ny41IiB5PSItMjIuMiIvPgogICAgICA8dXNl'
    b'IHhsaW5rOmhyZWY9IiN2YS1xIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI3Ny41'
    b'IiB5PSItMjguNiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1xIiB3aWR0aD0iMTAw'
    b'JSIgaGVpZ2h0PSIxMDAlIiB4PSI3OS45IiB5PSItNDQuMyIvPgogICAgICA8cGF0aCBkPSJN'
    b'MjA2Ni43IDE1MzQuOXMxMy42IDIgMTQuOC0yLjljMS42LTYuNS0xNS40LTEyLjctMTUuNC0x'
    b'Mi43eiIvPgogICAgICA8cGF0aCBpZD0idmEtciIgZD0iTTE3MDEuNiAxNTc1LjZjLTQgMi41'
    b'LTMgMTAuOS0uNCAxNS41IDIuNyA0LjkgOS44IDEwLjQgMTQgNy44IDQuMi0yLjYgMi44LTEx'
    b'LjctLjItMTYuNS0yLjctNC41LTkuNC05LjItMTMuNC02Ljh6Ii8+CiAgICAgIDx1c2UgeGxp'
    b'bms6aHJlZj0iI3ZhLXIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjE4LjkiIHk9'
    b'IjcuOCIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1yIiB3aWR0aD0iMTAwJSIgaGVp'
    b'Z2h0PSIxMDAlIiB4PSIzNyIgeT0iMTAuNiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2'
    b'YS1yIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI1Ni44IiB5PSIxNS41Ii8+CiAg'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHg9Ijc0LjciIHk9IjE4LjEiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtciIgd2lk'
    b'dGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iOTIuMyIgeT0iMjEuNyIvPgogICAgICA8dXNl'
    b'IHhsaW5rOmhyZWY9IiN2YS1yIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxMTAu'
    b'NCIgeT0iMjYuNyIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1yIiB3aWR0aD0iMTAw'
    b'JSIgaGVpZ2h0PSIxMDAlIiB4PSIxMjguMyIgeT0iMjkuOSIvPgogICAgICA8dXNlIHhsaW5r'
    b'OmhyZWY9IiN2YS1yIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxNDYuNiIgeT0i'
    b'MzIuNyIvPgogICAgICA8cGF0aCBkPSJNMTY0OC4yIDE1MTcuNWMtNC4yLTIuMS0xMSAzLTEz'
    b'LjYgNy42LTIuNyA1LTMuOCAxMy44LjYgMTYgNC40IDIuMyAxMS41LTMuNiAxNC04LjYgMi41'
    b'LTQuNyAzLTEyLjktMS0xNXoiLz4KICAgICAgPHBhdGggZD0iTTE2NDIgMTUzNC40Yy00LjQt'
    b'MS42LTEwLjQgNC40LTEyLjQgOS40LTIgNS4yLTIgMTQuMSAyLjcgMTUuOCA0LjcgMS42IDEw'
    b'LjktNS4yIDEyLjgtMTAuNSAxLjgtNSAxLjMtMTMuMS0zLTE0Ljd6Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Ik0xNjQ3LjcgMTU1MGMtNC41LTEuMi0xMCA1LjMtMTEuNSAxMC40LTEuNiA1LjQtLjYg'
    b'MTQuMyA0LjIgMTUuNSA0LjggMS4yIDEwLjMtNi4xIDExLjgtMTEuNiAxLjMtNS4xIDAtMTMu'
    b'Mi00LjUtMTQuNHoiLz4KICAgICAgPHBhdGggZD0iTTE2NjIuNCAxNTU2LjNjLTQuNS0xLjMt'
    b'MTAuMiA1LTExLjkgMTAtMS43IDUuNC0xIDE0LjMgMy43IDE1LjcgNC43IDEuNCAxMC41LTUu'
    b'OCAxMi4xLTExLjIgMS41LTUgLjUtMTMuMi00LTE0LjV6Ii8+CiAgICAgIDxwYXRoIGlkPSJ2'
    b'YS1zIiBkPSJNMTY3MiAxNTU4LjhjLTQuNiAxLjEtNi4zIDkuNC01LjIgMTQuNyAxLjEgNS41'
    b'IDYuMiAxMi44IDExIDExLjYgNC44LTEuMiA2LjItMTAuMyA0LjgtMTUuOC0xLjItNS02LjIt'
    b'MTEuNi0xMC43LTEwLjV6Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXMiIHdpZHRo'
    b'PSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjE2LjgiIHk9IjYuMiIvPgogICAgICA8dXNlIHhs'
    b'aW5rOmhyZWY9IiN2YS1pIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI4LjYiIHk9'
    b'Ii0xMS4yIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBo'
    b'ZWlnaHQ9IjEwMCUiIHg9IjQuNyIgeT0iNi41Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0i'
    b'I3ZhLWkiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjQuOSIgeT0iMjYuNyIvPgog'
    b'ICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1pIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAl'
    b'IiB4PSI0LjciIHk9IjQ3LjkiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtaSIgd2lk'
    b'dGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iNS42IiB5PSI2OC42Ii8+CiAgICAgIDx1c2Ug'
    b'eGxpbms6aHJlZj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjIuMiIg'
    b'eT0iODcuNyIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1pIiB3aWR0aD0iMTAwJSIg'
    b'aGVpZ2h0PSIxMDAlIiB4PSI0LjciIHk9IjEwOS4xIi8+CiAgICAgIDx1c2UgeGxpbms6aHJl'
    b'Zj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjIuMiIgeT0iMTI2LjQi'
    b'Lz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtaSIgd2lkdGg9IjEwMCUiIGhlaWdodD0i'
    b'MTAwJSIgeD0iNC43IiB5PSIxNDMuNSIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1p'
    b'IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI0LjciIHk9IjE2My45Ii8+CiAgICAg'
    b'IDx1c2UgeGxpbms6aHJlZj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9'
    b'IjMuNCIgeT0iMTgzLjkiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtaSIgd2lkdGg9'
    b'IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iMy43IiB5PSIyMDMuMSIvPgogICAgICA8dXNlIHhs'
    b'aW5rOmhyZWY9IiN2YS1pIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSI0LjQiIHk9'
    b'IjIyMy41Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBo'
    b'ZWlnaHQ9IjEwMCUiIHg9IjQuNCIgeT0iMjQzLjMiLz4KICAgICAgPHVzZSB4bGluazpocmVm'
    b'PSIjdmEtaSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iMy43IiB5PSIyNjMuMSIv'
    b'PgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1pIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIx'
    b'MDAlIiB4PSIyLjUiIHk9IjI4My4yIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWki'
    b'IHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjIuNSIgeT0iMzA1LjEiLz4KICAgICAg'
    b'PHVzZSB4bGluazpocmVmPSIjdmEtaSIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0i'
    b'MS45IiB5PSIzMjcuOSIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS1pIiB3aWR0aD0i'
    b'MTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxLjkiIHk9IjM0OS4zIi8+CiAgICAgIDx1c2UgeGxp'
    b'bms6aHJlZj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjEuOSIgeT0i'
    b'MzY5Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLWkiIHdpZHRoPSIxMDAlIiBoZWln'
    b'aHQ9IjEwMCUiIHg9IjEuMyIgeT0iMzkxLjMiLz4KICAgICAgPHBhdGggaWQ9InZhLXQiIGQ9'
    b'Ik0xODgyLjIgMTMwMy4yYzIuNSAzLjctMS4zIDEwLjgtNS4xIDE0LTQgMy4yLTEyIDUuNC0x'
    b'NC41IDEuNS0yLjYtNCAxLjktMTEuNCA2LTE0LjYgNC0zIDExLjItNC42IDEzLjYtMXoiLz4K'
    b'ICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtdCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAw'
    b'JSIgeD0iMi43IiB5PSIxNi4xIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXQiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjIuNCIgeT0iMzQuMSIvPgogICAgICA8dXNl'
    b'IHhsaW5rOmhyZWY9IiN2YS10IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIyLjEi'
    b'IHk9IjUyLjQiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtdCIgd2lkdGg9IjEwMCUi'
    b'IGhlaWdodD0iMTAwJSIgeD0iMS44IiB5PSI2OS4xIi8+CiAgICAgIDx1c2UgeGxpbms6aHJl'
    b'Zj0iI3ZhLXQiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjIuNyIgeT0iODcuMSIv'
    b'PgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS10IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIx'
    b'MDAlIiB4PSIxLjUiIHk9IjEwNC40Ii8+CiAgICAgIDxwYXRoIGQ9Ik0xODgzLjMgMTQyNmMy'
    b'LjYgMy45LTEuNSAxMS4zLTUuNyAxNC41LTQuNSAzLjQtMTMuMiA1LjctMTYgMS42LTIuOS00'
    b'IDItMTEuOCA2LjYtMTUgNC40LTMuMSAxMi40LTQuOCAxNS0xeiIvPgogICAgICA8cGF0aCBp'
    b'ZD0idmEtdSIgZD0iTTE4ODIgMTQ0My42YzMuNSAzLjIuOCAxMS4zLTIuNyAxNS4zLTMuNyA0'
    b'LjItMTEuOCA4LTE1LjMgNC43LTMuNi0zLjUtLjMtMTIgMy42LTE2LjIgMy42LTMuOCAxMS4x'
    b'LTcgMTQuNS0zLjh6Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXUiIHdpZHRoPSIx'
    b'MDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii42IiB5PSIyMC40Ii8+CiAgICAgIDx1c2UgeGxpbms6'
    b'aHJlZj0iI3ZhLXUiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii45IiB5PSI0MC41'
    b'Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXUiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9'
    b'IjEwMCUiIHg9Ii4zIiB5PSI2Mi4xIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXUi'
    b'IHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii45IiB5PSI4Mi4yIi8+CiAgICAgIDx1'
    b'c2UgeGxpbms6aHJlZj0iI3ZhLXUiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii4z'
    b'IiB5PSIxMDIuNiIvPgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS11IiB3aWR0aD0iMTAw'
    b'JSIgaGVpZ2h0PSIxMDAlIiB4PSIuNiIgeT0iMTIzIi8+CiAgICAgIDx1c2UgeGxpbms6aHJl'
    b'Zj0iI3ZhLXUiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii42IiB5PSIxNDMuNyIv'
    b'PgogICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2YS11IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIx'
    b'MDAlIiB4PSItLjMiIHk9IjE2NC40Ii8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZhLXUi'
    b'IHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii45IiB5PSIxODMuMyIvPgogICAgICA8'
    b'dXNlIHhsaW5rOmhyZWY9IiN2YS11IiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIu'
    b'OSIgeT0iMjAzLjEiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmEtdSIgd2lkdGg9IjEw'
    b'MCUiIGhlaWdodD0iMTAwJSIgeD0iLjMiIHk9IjIyNC40Ii8+CiAgICAgIDx1c2UgeGxpbms6'
    b'aHJlZj0iI3ZhLXUiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii4zIiB5PSIyNDUu'
    b'NCIvPgogICAgPC9nPgogICAgPGcgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMTIzKSBzY2FsZSgu'
    b'MTkyKSI+CiAgICAgIDxwYXRoIGZpbGw9IiNmYTAyMDQiIGQ9Ik0xODQ5LjYgMTg0OC4zYTc3'
    b'IDc3IDAgMCAwIDQ4LjMuNGwtMTcuNS0yOCIvPgogICAgICA8cGF0aCBmaWxsPSIjY2U5ZDA5'
    b'IiBkPSJtMTg4OC4zIDE3NzYuMi0zMS43LTguMnMuNC0zNS4yIDIwLjQtMzIuMWMxNi42IDIu'
    b'NSAxMiA0MC4zIDExLjMgNDAuM3oiLz4KICAgICAgPGNpcmNsZSBjeD0iMTg3Mi45IiBjeT0i'
    b'MTcyMyIgcj0iMTIuOSIgZmlsbD0iI2NlOWQwOSIvPgogICAgICA8cGF0aCBmaWxsPSIjZmEw'
    b'MjA0IiBkPSJNMTg4NS40IDE3OTEuOWM3IDE3LjggMTEuMyAzMy4yIDQuNyA1My4zbTcuNiAz'
    b'LjVjLTEwLjItOC4zLTM2LjYtNS45LTQ4LS40LTQuNCAwLTE2LjQtODMuMiAyNS43LTgxLjIg'
    b'MzguOCAyIDI1IDgyIDIyLjMgODEuNnoiLz4KICAgIDwvZz4KICAgIDxnIHRyYW5zZm9ybT0i'
    b'dHJhbnNsYXRlKDEyMykgc2NhbGUoLjE5MikiPgogICAgICA8cGF0aCBmaWxsPSIjZmEwMjA0'
    b'IiBkPSJNMTgxNS4yIDE4NjYuM2E0NyA0NyAwIDAgMCA1NC4yLjVsLTQwLjItNDIiLz4KICAg'
    b'ICAgPGNpcmNsZSBjeD0iMTg0My40IiBjeT0iMTczOC4zIiByPSIxMi45IiBmaWxsPSIjY2U5'
    b'ZDA5Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiNjZTlkMDkiIGQ9Im0xODU5LjMgMTc4MC0zMi43'
    b'LS42cy00LjItMjYuNiAxNi4yLTI3LjhjMTYuOS0xIDE3LjIgMjguNCAxNi41IDI4LjR6Ii8+'
    b'CiAgICAgIDxwYXRoIGZpbGw9IiNmYTAyMDQiIGQ9Ik0xODQzLjYgMTg2MC43Yy02LjMtMTMu'
    b'OS02LjktMzEtNS4yLTQ5LjVtLTkuNCA1MC40Yy03LjctMTMuMi05LjEtMzAtMy01MS4ybTQz'
    b'LjQgNTYuNmMtNS02LjItNDAuMy04LjgtNTQuMS0uNC01IDAtMTguNi05My44IDI5LTkxLjUg'
    b'NDMuNiAyLjEgMjggOTIuMyAyNSA5MS45eiIvPgogICAgPC9nPgogIDwvZz4KPC9zdmc+Cg==', 'VA')

VA = b64_VA
index.append("VA")
index.append("VAT")
index.append("Holy See")
catalog["VA"] = VA
catalog["VAT"] = VA
catalog["Holy See"] = VA
country["Holy See"] = ('VA', 'VAT', 0)
lookup["VA"] = ('VA', 'VAT', 'Holy See', 0)
lookup["Vatican City Holy See"] = ('VA', 'VAT', 'Holy See', 0)
lookup["VAT"] = ('VA', 'VAT', 'Holy See', 0)
lookup["Holy See"] = ('VA', 'VAT', 'Holy See', 0)
details["VA"] = {"continent":"Europe","capital":"Vatican City","currency":"Euro","web":".va","lang":"la | it | fr","tz":"+01:00","altname":""}
#----------------------------------------------------------------------
b64_VC = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXZjIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIj4K'
    b'ICAgIDxwYXRoIGZpbGw9IiNmNGYxMDAiIGQ9Ik0wIDBoNjQwdjQ4MEgweiIvPgogICAgPHBh'
    b'dGggZmlsbD0iIzE5OWEwMCIgZD0iTTQ5MCAwaDE1MHY0ODBINDkweiIvPgogICAgPHBhdGgg'
    b'ZmlsbD0iIzAwNThhYSIgZD0iTTAgMGgxNTB2NDgwSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIj'
    b'MTk5YTAwIiBkPSJtMjU5LjMgMTMwLTQ2LjQgNzEuMyA0NC43IDc0LjQgNDMuOC03My43LTQy'
    b'LjEtNzJ6bTEyMS4yIDAtNDYuMyA3MS4zIDQ0LjcgNzQuNCA0My44LTczLjctNDIuMi03Mnpt'
    b'LTYxLjIgOTcuMy00Ni40IDcxLjQgNDQuOCA3NC40IDQzLjgtNzMuNy00Mi4yLTcyeiIvPgog'
    b'IDwvZz4KPC9zdmc+Cg==', 'VC')

VC = b64_VC
index.append("VC")
index.append("VCT")
index.append("Saint Vincent Grenadines")
catalog["VC"] = VC
catalog["VCT"] = VC
catalog["Saint Vincent Grenadines"] = VC
country["Saint Vincent Grenadines"] = ('VC', 'VCT', 0)
lookup["VC"] = ('VC', 'VCT', 'Saint Vincent Grenadines', 0)
lookup["Kingstown Saint Vincent Grenadines"] = ('VC', 'VCT', 'Saint Vincent Grenadines', 0)
lookup["VCT"] = ('VC', 'VCT', 'Saint Vincent Grenadines', 0)
lookup["Saint Vincent Grenadines"] = ('VC', 'VCT', 'Saint Vincent Grenadines', 0)
details["VC"] = {"continent":"Americas","capital":"Kingstown","currency":"East Caribbean Dollar","web":".vc","lang":"en-VC | fr","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_VE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy12ZSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGcgaWQ9InZlLWQiIHRyYW5zZm9ybT0i'
    b'dHJhbnNsYXRlKDAgLTM2KSI+CiAgICAgIDxnIGlkPSJ2ZS1jIj4KICAgICAgICA8ZyBpZD0i'
    b'dmUtYiI+CiAgICAgICAgICA8cGF0aCBpZD0idmUtYSIgZmlsbD0iI2ZmZiIgZD0iTTAtNS0x'
    b'LjUtLjJsMi44Ljl6Ii8+CiAgICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2ZS1hIiB3aWR0'
    b'aD0iMTgwIiBoZWlnaHQ9IjEyMCIgdHJhbnNmb3JtPSJzY2FsZSgtMSAxKSIvPgogICAgICAg'
    b'IDwvZz4KICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiN2ZS1iIiB3aWR0aD0iMTgwIiBoZWln'
    b'aHQ9IjEyMCIgdHJhbnNmb3JtPSJyb3RhdGUoNzIpIi8+CiAgICAgIDwvZz4KICAgICAgPHVz'
    b'ZSB4bGluazpocmVmPSIjdmUtYiIgd2lkdGg9IjE4MCIgaGVpZ2h0PSIxMjAiIHRyYW5zZm9y'
    b'bT0icm90YXRlKC03MikiLz4KICAgICAgPHVzZSB4bGluazpocmVmPSIjdmUtYyIgd2lkdGg9'
    b'IjE4MCIgaGVpZ2h0PSIxMjAiIHRyYW5zZm9ybT0icm90YXRlKDE0NCkiLz4KICAgIDwvZz4K'
    b'ICA8L2RlZnM+CiAgPHBhdGggZmlsbD0iI2NmMTQyYiIgZD0iTTAgMGg2NDB2NDgwSDB6Ii8+'
    b'CiAgPHBhdGggZmlsbD0iIzAwMjQ3ZCIgZD0iTTAgMGg2NDB2MzIwSDB6Ii8+CiAgPHBhdGgg'
    b'ZmlsbD0iI2ZjMCIgZD0iTTAgMGg2NDB2MTYwSDB6Ii8+CiAgPGcgaWQ9InZlLWYiIHRyYW5z'
    b'Zm9ybT0ibWF0cml4KDQgMCAwIDQgMzIwIDMzNikiPgogICAgPGcgaWQ9InZlLWUiPgogICAg'
    b'ICA8dXNlIHhsaW5rOmhyZWY9IiN2ZS1kIiB3aWR0aD0iMTgwIiBoZWlnaHQ9IjEyMCIgdHJh'
    b'bnNmb3JtPSJyb3RhdGUoMTApIi8+CiAgICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZlLWQiIHdp'
    b'ZHRoPSIxODAiIGhlaWdodD0iMTIwIiB0cmFuc2Zvcm09InJvdGF0ZSgzMCkiLz4KICAgIDwv'
    b'Zz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZlLWUiIHdpZHRoPSIxODAiIGhlaWdodD0iMTIw'
    b'IiB0cmFuc2Zvcm09InJvdGF0ZSg0MCkiLz4KICA8L2c+CiAgPHVzZSB4bGluazpocmVmPSIj'
    b'dmUtZiIgd2lkdGg9IjE4MCIgaGVpZ2h0PSIxMjAiIHRyYW5zZm9ybT0icm90YXRlKC04MCAz'
    b'MjAgMzM2KSIvPgo8L3N2Zz4K', 'VE')

VE = b64_VE
index.append("VE")
index.append("VEN")
index.append("Venezuela")
catalog["VE"] = VE
catalog["VEN"] = VE
catalog["Venezuela"] = VE
country["Venezuela"] = ('VE', 'VEN', 0)
lookup["VE"] = ('VE', 'VEN', 'Venezuela', 0)
lookup["Caracas Venezuela"] = ('VE', 'VEN', 'Venezuela', 0)
lookup["VEN"] = ('VE', 'VEN', 'Venezuela', 0)
lookup["Venezuela"] = ('VE', 'VEN', 'Venezuela', 0)
details["VE"] = {"continent":"Americas","capital":"Caracas","currency":"Bolívar","web":".ve","lang":"es-VE","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_VG = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy12ZyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGxpbmVhckdyYWRpZW50IGlkPSJ2Zy1h'
    b'IiB4MT0iMTAzLjEiIHgyPSI5Mi42IiB5MT0iMTExLjMiIHkyPSIxMDcuOCIgZ3JhZGllbnRU'
    b'cmFuc2Zvcm09Im1hdHJpeCguOTk2MTQgMCAwIDIuMjUyNTUgNzAzLjggLTc1KSIgZ3JhZGll'
    b'bnRVbml0cz0idXNlclNwYWNlT25Vc2UiPgogICAgICA8c3RvcCBvZmZzZXQ9IjAiIHN0b3At'
    b'Y29sb3I9InJlZCIvPgogICAgICA8c3RvcCBvZmZzZXQ9IjEiIHN0b3AtY29sb3I9IiNmZjAi'
    b'Lz4KICAgIDwvbGluZWFyR3JhZGllbnQ+CiAgPC9kZWZzPgogIDxwYXRoIGZpbGw9IiMwMDYi'
    b'IGQ9Ik0wIDBoNjQwdjQ4MEgwWiIvPgogIDxwYXRoIGZpbGw9IiMwMTIxNjkiIGQ9Ik0wIDBo'
    b'MzIwdjI0MEgwWiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Im0zNy41IDAgMTIyIDkwLjVM'
    b'MjgxIDBoMzl2MzFsLTEyMCA4OS41IDEyMCA4OVYyNDBoLTQwbC0xMjAtODkuNUw0MC41IDI0'
    b'MEgwdi0zMGwxMTkuNS04OUwwIDMyVjBaIi8+CiAgPHBhdGggZmlsbD0iI2M4MTAyZSIgZD0i'
    b'TTIxMiAxNDAuNSAzMjAgMjIwdjIwbC0xMzUuNS05OS41Wm0tOTIgMTAgMyAxNy41LTk2IDcy'
    b'SDBaTTMyMCAwdjEuNWwtMTI0LjUgOTQgMS0yMkwyOTUgMFpNMCAwbDExOS41IDg4aC0zMEww'
    b'IDIxWiIvPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0xMjAuNSAwdjI0MGg4MFYwWk0wIDgw'
    b'djgwaDMyMFY4MFoiLz4KICA8cGF0aCBmaWxsPSIjYzgxMDJlIiBkPSJNMCA5Ni41djQ4aDMy'
    b'MHYtNDh6TTEzNi41IDB2MjQwaDQ4VjBaIi8+CiAgPGcgdHJhbnNmb3JtPSJ0cmFuc2xhdGUo'
    b'LTIxNy41IC05LjQpIHNjYWxlKC43NzQ5NykiPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0i'
    b'bTc3Ni4zIDE0NCAyNTAuNC0uOS0uNSAyMjNzOC44IDM0LTEwNSA4NS41YzQwLjktNC4yIDg1'
    b'LjUtNDcuOCA4NS41LTQ3LjhzMTguMS0yMy4zIDI3LTEwLjNjOC44IDEzIDE3LjEgMTkuNiAy'
    b'My42IDI0LjcgNi41IDUgMTEuNiAxOSAxLjkgMjkuMi05LjggMTAuMy0yNS4xIDExLjYtMjku'
    b'My0uOS02LjUgMy4zLTQ2LjQgNTEuNi0xMjguMiA1My45QzgxOC41IDQ5OSA3NzMgNDQ2IDc3'
    b'MyA0NDZzLTExLjEgMTcuNy0yNyAzLjhjLTE1LjMtMTguMi0zLjctMjkuOC0zLjctMjkuOHMx'
    b'My03LjQgMTYuOC0xMi41YzYtNyA3LjktMTYuMyAxOC0xNi4zIDEyLjIgMSAxNi44IDEwLjcg'
    b'MTYuOCAxMC43czQxLjggNDQuMSA4Ni45IDQ5LjdjLTEwMS43LTQ4LjgtMTA1LjUtNzktMTA1'
    b'LTg2LjRsLjUtMjIxLjF6Ii8+CiAgICA8cGF0aCBmaWxsPSIjMDA2MTI5IiBzdHJva2U9IiMw'
    b'MDAiIHN0cm9rZS13aWR0aD0iMS45IiBkPSJtNzgyLjMgMTUwLjEgMjM4LjgtMS40djIxNC42'
    b'Yy41IDI4LTQ2LjUgNTYuMy0xMTkuOSA5Mi41LTc1LjctMzktMTE5LjQtNjIuNy0xMTkuOC05'
    b'M2wuOS0yMTIuN3oiLz4KICAgIDxnIGlkPSJ2Zy1iIiBmaWxsPSIjZmZjNzJjIiBzdHJva2U9'
    b'IiMwMDAiIHN0cm9rZS13aWR0aD0iLjkiPgogICAgICA8cGF0aCBmaWxsPSJub25lIiBzdHJv'
    b'a2U9IiNmZmM3MmMiIHN0cm9rZS13aWR0aD0iMS45IiBkPSJtODE0LjggMTgxLjggMTQtMjAu'
    b'NyAxNC4zIDIwLjgiLz4KICAgICAgPHBhdGggZD0iTTgzMS43IDE3NGEyLjggMi44IDAgMSAx'
    b'LTUuNiAwIDIuOCAyLjggMCAwIDEgNS42IDB6Ii8+CiAgICAgIDxwYXRoIGQ9Ik04MTcuNCAx'
    b'OTcuMWgyMS45cy4zLTIuOC0yLjMtNC41YzExLjUtMS42IDguNS0xMS42IDE4LTEyLjIgMiAu'
    b'My01IDQuMy01IDQuM3MtNS43IDQtMyA2LjFjMiAxLjcgMy0xIDMuMi0zIC4zLTIgOS4zLTMu'
    b'MyA4LTktMi4xLTQuNy0xNC43IDMuMi0xNC43IDMuMmwtOS0uMWMtLjYtMS0zLTUtNS42LTUt'
    b'MyAwLTUuMiA1LTUuMiA1aC0yMC4zcy0uNyA1LjMgOS42IDYuM2MyLjMgMyA0LjEgMy44IDYu'
    b'MiA0LjYtMS40IDEuMS0xLjggMi41LTEuOCA0LjN6bTEuNi00LjRoMTguMiIvPgogICAgICA8'
    b'cGF0aCBkPSJNODEwLjcgMTgyczEuNCA4LjUgOC4yIDEwLjUiLz4KICAgICAgPHBhdGggZmls'
    b'bD0idXJsKCN2Zy1hKSIgZD0iTTgwOS42IDE4MS44Yy42LTMuMiAxLjktMy44IDMuMi04IC4y'
    b'LTQtMy4yLTMuNS0yLjItNiAxLjgtMi45LjktNS42LTIuNS03LjcuNyAzLjctNC40IDcuMi00'
    b'LjQgMTAuMiAwIDMgMi42IDIuNCAyLjMgNyAuMiAyLjYtLjcgMi0xIDQuNWg0LjZ6Ii8+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik04MzEuNSAxNjEuN2EyLjYgMi42IDAgMSAxLTUuMiAwIDIuNiAyLjYg'
    b'MCAwIDEgNS4yIDB6Ii8+CiAgICA8L2c+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN2Zy1iIiB3'
    b'aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSItLjgiIHk9IjQxLjMiLz4KICAgIDx1c2Ug'
    b'eGxpbms6aHJlZj0iI3ZnLWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9Ii0xLjEi'
    b'IHk9IjgyIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN2Zy1iIiB3aWR0aD0iMTAwJSIgaGVp'
    b'Z2h0PSIxMDAlIiB4PSIyNS42IiB5PSIxMjYuMSIvPgogICAgPHVzZSB4bGluazpocmVmPSIj'
    b'dmctYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iLTQuNiIgeT0iMTYyLjIiLz4K'
    b'ICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZnLWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUi'
    b'IHg9Ii0zLjgiIHk9IjIwNC44Ii8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN2Zy1iIiB3aWR0'
    b'aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiB4PSIxNDYuMyIgeT0iLjciLz4KICAgIDx1c2UgeGxp'
    b'bms6aHJlZj0iI3ZnLWIiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjE0NC45IiB5'
    b'PSI0MS4yIi8+CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN2Zy1iIiB3aWR0aD0iMTAwJSIgaGVp'
    b'Z2h0PSIxMDAlIiB4PSIxNDMuMSIgeT0iODIuNyIvPgogICAgPHVzZSB4bGluazpocmVmPSIj'
    b'dmctYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgeD0iMTQ1LjIiIHk9IjEyMy40Ii8+'
    b'CiAgICA8dXNlIHhsaW5rOmhyZWY9IiN2Zy1iIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAl'
    b'IiB4PSIxNDQuNyIgeT0iMTY0LjIiLz4KICAgIDx1c2UgeGxpbms6aHJlZj0iI3ZnLWIiIHdp'
    b'ZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIHg9IjE0NC45IiB5PSIyMDUuMiIvPgogICAgPGcg'
    b'ZmlsbD0iI2ZmYzZiNSIgc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9Ii45Ij4KICAgICAg'
    b'PHBhdGggZmlsbD0iI2ZmYzcyYyIgZD0iTTkxNS44IDQwNi4zczUuNyAxMy4yIDEyLjIgNWM2'
    b'LjUtOCA0LjItMTEuNSA0LjItMTEuNWwtMTQuNi03LjktNC4zIDkgMi41IDUuNHoiLz4KICAg'
    b'ICAgPHBhdGggZD0iTTkyOC40IDQwNC42czEgLjEgMS43LTEuM2MuOC0xLjQtMS43LTItMi45'
    b'LTMuNmwtMS4yIDIuNXptLTMzLTMuNi0xMi44IDdzLTYuNCAxLjMtNi44IDBjLS41LTEuMi4x'
    b'LTIuMyAzLjUtMi41IDMuMy0uMSAxMi4zLTguNCAxMi4zLTguNGwzLjggNHptLjItMjI3Ljku'
    b'NCA0LjZjLjIgMS42LTIuNSA1LTIuNiA0LjgtLjItLjItMS41LjItMS4zIDEuMS4xIDEgMiAx'
    b'LjMgMiAxLjNzLS43IDMuMyAwIDMuNWMuOC4xLTIgNC4yIDAgNS4zIDIuMSAxLjEgNS42IDIu'
    b'NiA3LjIgMi4zIDEuNi0uNCAwIDYuMSAwIDYuMWwtNC41IDkuNSAyNC40LTIuNS01LThzLTIu'
    b'NC0xLjctMS44LTYuM2MuNy00LjUtLjMtMjUuMy0uMy0yNS4zbC0xNy40LTIuNC0xLjEgNnpt'
    b'LTQuNSAzNi4ycy03LjkgMy42LTcuNiAxMy40Yy0yIDkuNS0zLjEgMTktMy4xIDE5cy05LjQg'
    b'MTAuNi0xMi4yIDE0LjVjLTIuOSAzLjgtNy4yIDExLjUtOC43IDEzLjYtMS42IDItNy44IDgu'
    b'OC03LjcgMTEuNC4yIDIuNS0xLjQgMTMuOCA0LjggMTUgMS42LjcgNi43LTEzIDYuNy0xM3Mu'
    b'My01LjgtMS41LTdjLTEuNy0xIDMuOC00LjggMy44LTQuOGwxMy05LjdjMi40LTIgOC45LTku'
    b'MiA4LjktOS4ybDMuNi00My4yeiIvPgogICAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNOTAw'
    b'LjIgMjAxLjhzMiA1LjYgNi42IDQuNiAxMC01LjIgMTAtNS4yIDQuMy0uMiA0LjkuNWMuNi42'
    b'IDExLjYgMTEuMiAxMS4yIDE0LjUtLjMgMy40LTUgMi40LTYuOCA0LjYtMS43IDIuMi00LjYg'
    b'Ny44LTMuOCAxMiAuOCA0IDMuMiA5LjQgMi45IDExLjUtLjMgMi0yIDIuNy0yIDMuOCAwIDEg'
    b'MS40IDMgMS40IDUgMCAyLjEtMiA1LjEtMS42IDcuMi4zIDIgLjQgOCAuNCA4bC0uNCAyOHMx'
    b'LjYuOSAxLjcgMi41Yy4yIDEuNSAxMC44IDQ3LjYgMTAuOCA0Ny42cy0uNSAxLjUtMS42IDEu'
    b'M2MtMS4xLS4yIDQuMyA3LjEgNC40IDkuMi4yIDIgNS42IDE4LjIgNS40IDIwLjQtLjEgMi4y'
    b'LTEgNy4yLTEuNCA3LjMtLjUuMiAzLjUgMTAuMiAyLjggMTEuNy0uNiAxLjYtNyAxLjUtNyAx'
    b'LjVsLTEuOC0uNHMuMSAyLjEtMS4xIDIuM2MtMS4zLjEtMTAuNi0uNS0xMC42LS41cy0yLjcg'
    b'NC4xLTQuMyA0Yy0xLjYtLjItMy43LTMtNC4xLTIuNi0uNS41IDEuNCAzLjIgMSA0LS42Ljgt'
    b'OC42IDIuNS0xMC4yLTEuMy0xLjYtMy44IDEtMi44LjQtMy42LS40LS44LTQtMi45LTUuMi0y'
    b'LjMtMSAuNyAyLjkgMS42IDIuNyAzLjItLjEgMS42LTMuNSA0LTQuNyA0LTEuMyAwLTQuMy01'
    b'LjktOC44LTUuMy00LjQuNy03LjIgMS44LTcuMiAxLjhzLTUuMyAyLjItNy41IDEuN2MtMi4y'
    b'LS40LTMuMi0yLjItMy4yLTMuMSAwLTEgMS42LTUuMSAxLjUtNi40LS4yLTEuMi0xLjUtMi41'
    b'LTEuNS00LjQgMC0yIDMuNy04LjQgMy43LTguNGwtLjItMjkuMnMtMy4zIDAtMy41LTJjLS4x'
    b'LTIgNS4xLTQ2LjEgNi00OWwyLjgtMTNzLTIuNCAxLjItMi42IDBjLS4xLTEgNy4yLTI2LjIg'
    b'Ny4yLTI2LjJzMS4yLTEyLjYgMS4yLTE1LjljMC0zLjMtLjYtNy45LS42LTcuOXMtNi41LTIu'
    b'OC02LjctN2MtLjYtNi43IDYuMi0xMC40IDctMTIuNmwzLjItOXMzLjUtNiA5LjItNi45eiIv'
    b'PgogICAgICA8cGF0aCBmaWxsPSIjZmZjNzJjIiBkPSJNODk3LjggNDAzcy0xNS40IDgtMTcu'
    b'NiA4LjdjLTIuMi42LTMuNi0yLjctMS40LTMuMyAyLjItLjcgNS43LTEgNS43LTFzLTUuMi00'
    b'LjEtNS00LjNsNy4yLTIuNmMuMiAwIDIuMiA0IDMuNiAzLjhhMzEgMzEgMCAwIDAgNS42LTMu'
    b'NWwxLjkgMi4yeiIvPgogICAgICA8cGF0aCBkPSJNOTE5LjQgNDA3LjRjMS41IDEuOSAyIDUu'
    b'MSA1LjQgMy4yIDMuMy0xLjktMS43LTUuNC0xLjctNS40eiIvPgogICAgICA8cGF0aCBkPSJN'
    b'OTI1LjUgNDA3LjFzMS42IDEuMyAzLS4yYzEuNC0xLjQtMi44LTQuNC0yLjgtNC40bC0yLjEg'
    b'Mi40em02LjgtMTkwLjFjLjIgMCA1LjIgMTUuNiA1LjkgMTkuNi42IDQgMi43IDE5LjggMS45'
    b'IDIyLS44IDIuMi04LjkgMTIuOC05LjggMTUuNS0xIDIuNy02LjcgMTMtNi43IDEzcy0xLjQg'
    b'MTAuMi0yIDEwLjZjLS43LjUgMS42IDMgMS40IDMuOC0uMyAxLTQuNiA1LjQtNi41IDUtMi0u'
    b'NS01LTIuNy01LTQuOC0uMy0yIDAtOC45IDEuNS0xMC42IDEuNC0xLjggOC45LTE5LjMgOS4z'
    b'LTIwLjQuNS0xLjIgNi44LTE1IDctMTcuMy4yLTIuNC0yLTcuOS00LjItOS45LTUtMTQuNy0z'
    b'LTIzLjUgNy4yLTI2LjV6Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiM5YzUxMDAiIGQ9Ik04OTUg'
    b'MTcyLjJzMy42LjUgNS41LS42IDQuMS0xLjYgNS43LjZjMS42IDIuMiAyLjcgMiAyLjcgMnMt'
    b'Mi40IDYgMCA2LjZjMi4zLjYgMy41LjYgMy42IDEuNC4yLjgtMiAyLjUtMS40IDMuMy42Ljgg'
    b'MS43IDEuNyAxLjkgMi40LjEuNi0xLjQgMy4zLTEgNCAuNS42IDIgMy4xIDIuOSAzLjEgMSAw'
    b'IC4zIDQgMy4yIDMgMi44LTEgMi43LTMuNSAyLjctMy41czMtLjQgMy44LTMuMWMuNy0yLjcg'
    b'Mi42LTMuNCAyLjYtMy40czMuOC0yLTEuMi01LjJjMC0yMi4yLTE0LjYtMTkuOC0xNC42LTE5'
    b'LjhzLTEuNy00LTQuNi0zLjVjLTIuOC41LTMgMy44LTUgMy41LTIuMS0uMy0yLjYtMS43LTIu'
    b'Ny0xLjYtLjIuMi0yIDMuNC0yIDQuMSAwIC44LTUuNS0xLTUgMyAuNSA0LjIgMy4yIDQgMyAz'
    b'Ljd6Ii8+CiAgICAgIDxnIGZpbGw9Im5vbmUiPgogICAgICAgIDxwYXRoIGQ9Ik05MjAuOCAy'
    b'MDhzLTE0LjEgOS0xMy44IDEyLjJtMTctMTAuNnMtMy4yIDMuNS0zLjQgMy41bTcuNi4zcy03'
    b'IDUuNy01LjkgOS4zbS0yNy0xNS41cy0yLjEgNC4zLTEuNiA1LjdjLjQgMS40IDQgNi44IDQu'
    b'NCAxMC4xLjUgMy40IDAgNS43IDAgNS43bS02LjUtMTMuNnMuNiA1IDEuNiA2IDMuNSA1LjMg'
    b'My44IDdtLTYuNyA4LjFzNC4yIDIgOC01LjltNi4xLTUuNWMtLjEgMC0zIDcuNyAyLjEgMTAu'
    b'NiA1IDIuOSA4LjkgMi41IDExIDEuNyAyLjMtLjcgNC43LTIuMiA0LjctMi4ybS0yMC0uNnMu'
    b'MyAxMC40IDE1LjcgMjAuN20tMTUtMTAuOXMtLjIgOS4yIDUuOCAxMy4zbS05LTI0LjFzLTQu'
    b'NiAxMy43LTguMyAxNW02LjktNXMtLjIgOS44LTEuNSAxMy4zbS0xLjIgMi40czMuMSA0IDYu'
    b'NiAzLjZjMy41LS4zIDUtNC40IDcuMy0zLjggMi40LjcgNC42IDIuNiAxMC4xIDIuMW0tNy45'
    b'IDQuMXMwIDguMSAxLjUgOC45YzEuNC44LjcgOC4yLjcgOC4ybS0yMS41LTIwLjlzLS4yIDcu'
    b'Ni0xLjEgMTAuM2MtMSAyLjctMi45IDcuMy0yLjUgMTEuM20tNi4xIDQuNGMuOC0uMyAzLjUt'
    b'Mi43IDMuNS0yLjdtMS40IDEuN3MtNi44IDI5LjItNC45IDQ2LjZtNi41LTQ1LjFzLTMuNSAy'
    b'MS44LTEuOSAyNm0uMi0yNi43IDEzLjMgMW0xLjktMS44czMuNiAyIDguNyAxLjZtLTEwLjMg'
    b'OS4xcy0uNiAzNy4zLTEuNiA0NS42bTIxLjEtMzcuMXM0LjEgMzIuOCA2LjUgMzUuOG0tMTQu'
    b'NC0zMS43czIuNSAyOSA0IDMxLjZtLTQwIDEwLjFzNS0xLjYgOS40LTYuM2M1IDYuOCAxMi44'
    b'LjMgMTIuOC4zczEyIDguMiAxNy40LTFjOC4zIDUuNCAxMi40LS44IDEyLjQtLjhzMyA0LjYg'
    b'NS4yIDQuMW0tMTMuMSAzLjJzNi4xIDI5IDE1LjMgMzcuMiIvPgogICAgICAgIDxwYXRoIGQ9'
    b'Ik04ODkgMzQ3LjdzLjcgMjQuMiAyLjEgNDEuM20tMy4zLTEzLjlzLS44IDE1LjgtMS43IDE3'
    b'bS03LjYgMS41czEuNyA2LjkgMTAuNC41YzguNy02LjMgOC45IDIuNCA5LjIgMy4zLjMgMSAx'
    b'LjcgNy44IDUgMi4xbTctOS4zcy0xLjQgMTQgMTEuMSAzLjhjMTIuNS0xMC4zIDE0LjYtLjIg'
    b'MTUgM20tMjUuOS0yMzAuMnMtMS4xIDcgNi4zIDYuM2MtMSAzLjkgMiA1LjEgMiA1LjFtNS40'
    b'IDQuM2MuMiAwIDMuNCAyIDAgNC42bS0xMC43LjlzMS42IDIgMy4zIDEuNWMxLjgtLjUgNC42'
    b'IDEuNyA0LjYgMS43czIuNC44IDIuNy4zbS0yMC4zIDIuNXM1LjQgMi4xIDktNi40bS0xOC45'
    b'LTIuNiAzLjEuMk04NTguNSAyODVsLjMgNi45bS02LjgtNy41czQuNSA3LjUgNCAxMS40Ii8+'
    b'CiAgICAgICAgPHBhdGggc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0iTTg5NC4xIDE4OC4y'
    b'aDIuOWwtMi41IDEuMU05MTEuNyAzMDBzMy4zLS40IDMuMiA1LjJjMi4xLTcgNi40LTcuMSA2'
    b'LjQtNy4xIi8+CiAgICAgICAgPHBhdGggc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjciIGQ9Ik04OTguMSAxNzkuM2MuNSAwIDIuMi0uNiAyLjUtLjEuNC40LTEu'
    b'OS44LTIuNS4xeiIvPgogICAgICA8L2c+CiAgICA8L2c+CiAgICA8ZyBmaWxsPSJub25lIiBz'
    b'dHJva2U9IiMwMDAiIHN0cm9rZS13aWR0aD0iMS45Ij4KICAgICAgPHBhdGggZmlsbD0iI2Zm'
    b'YzcyYyIgZD0iTTkwMC4zIDQ1OC42YTE2MC40IDE2MC40IDAgMCAwIDEwOS42LTUwLjdjLS40'
    b'LS40IDguOS0xMy40IDE2LjMtMTEuNiA3LjQgMS45IDE4LjEgMjMuNyAzMS4xIDI4LjQgNi41'
    b'IDEwLjItMS44IDE5LjUtNC42IDIxLjMtMi44IDEuOS0xNS40IDctMTcuMi0uNC0xLjktNy41'
    b'LTUuNi02LTUuNi02cy01OS41IDU4LTEyOC4yIDU1LjdjLTcxIC40LTEyOS42LTU1LjgtMTI5'
    b'LjYtNTUuOGwtNS4xIDUuNnMtNS42IDYtOC40IDUuNmMtMi44LS41LTE0LjktOC40LTE1Ljgt'
    b'MTYuMy0xLTcuOSA3LjQtMTMgNy40LTEzczIwLjUtMTUuOCAyMi44LTI0LjFjNC43LTQuNyAx'
    b'My41IDMuMiAxMy41IDMuMnM1My45IDYxLjggMTEzLjggNTh6Ii8+CiAgICAgIDxwYXRoIGQ9'
    b'Ik03NDguOSA0MjIuNnM1LjUtMS40IDcuNS45IDE2IDE2IDE2IDE2Ii8+CiAgICAgIDxwYXRo'
    b'IGQ9Im03NjEuNSA0MjkuMS01LjYgNC4xczE0IDIuOCAxMC44IDEybTI4NS42LTIzcy0yLjct'
    b'MS41LTcgMS43Yy00LjQgMy4zLTE1LjMgMTUuNS0xNS4zIDE1LjUiLz4KICAgICAgPHBhdGgg'
    b'ZD0ibTEwMzkuOSA0MjguNyA2IDQuNnMtMTIuNS45LTkuOCAxMi43Ii8+CiAgICA8L2c+CiAg'
    b'ICA8cGF0aCBkPSJNODE5LjcgNDM3LjRjLS40IDEtMS40IDAtMi4yLjItMiAwLTMuOCAxLjQt'
    b'NS42IDIuNGwtMTguNCAxMC43Yy0uNi0uMi0uNS0uNy0uMy0xLjJsNS0yM2MuMi0xLjMuNi0z'
    b'LS43LTQtLjUtLjQuMy0xLjEuNy0uNGw5LjQgNi43Yy0uMy45LS45LjItMS40LS4xLTEuMy0x'
    b'LjMtMi45LS4xLTIuOCAxLjVsLTMuNCAxNS4xYzQuMi0yLjQgOC40LTQuOCAxMi42LTcuNCAx'
    b'LjQtLjYgMi41LTIuNiAxLTMuOC0uNi0uNC0xLjYtMS4zLS42LTEuNWw2LjcgNC44em02LjYg'
    b'MzJjLS4yLjYtLjUuNy0xIC4zbC0xMS02Yy4xLS43LjQtLjguOS0uNCAxIC43IDIuNiAxIDMu'
    b'NC0uMmw0LTcuMyA1LjYtMTAuMmMuOC0xLjMtLjEtMi44LTEuMy0zLjMtLjQtLjItMS0uNC0u'
    b'NS0uOC4yLS4zLjguMyAxLjEuNGwxMC42IDUuOGMtLjEuNi0uNC43LS45LjMtMS0uNy0yLjYt'
    b'MS0zLjQuMmwtNCA3LjMtNS42IDEwLjJjLS44IDEuMi4xIDIuOCAxLjMgMy4zbC44LjR6bTQy'
    b'LjYtMTAtMyA4LjRjLTEuMy0uMS0uNC0xLjctLjgtMi41YTkuNSA5LjUgMCAwIDAtNy04LjJj'
    b'LTMtLjgtNiAuNy03LjggMy4xYTIyLjkgMjIuOSAwIDAgMC00LjQgMTIuMiA3IDcgMCAwIDAg'
    b'My4yIDYuNCAxMCAxMCAwIDAgMCA1LjkgMS41bDIuMS02LjNjLjMtMS40LTEuMi0yLjMtMi4z'
    b'LTIuNi0uMi0uNC4yLTEgLjctLjVsMTEgNGMwIDEuMy0xLjYtLjItMi41LjQtMS4zLjUtMS40'
    b'IDIuMS0yIDMuM2wtMS4zIDMuOGMtNSAuMy0xMC0uNy0xNC40LTMuMi00LjEtMi42LTctNy43'
    b'LTYuMS0xMi43LjYtNC4zIDMuMy04LjMgNy4yLTEwLjIgMy42LTIgOC0xLjkgMTEuOC0uNCAy'
    b'IC43IDMuOCAyIDUuNCAzLjQgMSAxLjMgMi44IDEuMyAzLjYtLjFsLjcuMm0xNy45IDI4Ljhj'
    b'MCAuNCAwIC45LS42LjZsLTEyLjYtMS45YzAtLjUgMC0uOS42LS42IDEgLjIgMi42LjIgMy0x'
    b'IC42LTEuNy43LTMuNSAxLTUuMmwyLjItMTQuNmMuMy0xIDAtMi4yLTEuMS0yLjYtLjctLjMt'
    b'MS4zLS4zLTItLjUgMC0uNCAwLS44LjYtLjZsMTIuNiAyYzAgLjQgMCAuOC0uNi42LTEtLjMt'
    b'Mi41LS4yLTMgMS0uNiAxLjYtLjcgMy40LTEgNS4xbC0yLjIgMTQuNmMtLjMgMSAwIDIuMyAx'
    b'LjIgMi43bDIgLjR6TTkyMSA0ODBsLS41IDguOS0yMi42IDEuMWMtLjEtLjUgMC0uOC42LS43'
    b'IDEuMSAwIDIuNi0uNSAyLjgtMS44bC0uMy02LjYtLjctMTMuNGMuMS0xLjMtMS0yLjMtMi4z'
    b'LTIuMi0uNC0uMi0xLjUuNC0xLjQtLjMtLjItLjYuNy0uMyAxLS40bDEyLjYtLjdjMCAuNiAw'
    b'IC45LS43LjgtMS4xIDAtMi42LjItMyAxLjYtLjEgMS45LjEgMy44LjIgNS43bC43IDE0YzAg'
    b'MS4xIDEgMi4yIDIuMiAyIDEuOC0uMSAzLjcgMCA1LjUtLjUgMi41LS43IDMuOC0zLjIgNC41'
    b'LTUuNS41LS42IDAtMi4yIDEtMmguNG0xNy41LTIxLjhjLS42IDAtLjMuOC0uNSAxLjItMSA3'
    b'LjUtMS45IDE1LTMgMjIuNC0uMiAxLjctLjYgMy42LTIuMiA0LjQtLjYuMy0uMSAxLjIuNS43'
    b'bDcuNS0yLjNjLS4xLTEuMi0xLjYgMC0yLjQtLjMtMS43IDAtMi0yLjEtMS43LTMuNCAwLTEg'
    b'LjItMS44LjMtMi43bDguNi0yLjZjMS4xIDEuNCAyLjMgMi43IDMuMyA0LjIuOCAxLjQtMSAy'
    b'LTIgMi4zLS42IDAtLjIgMSAuMy42bDExLjMtMy40YzAtMS4zLTEuNiAwLTIuMy0xLTIuMi0x'
    b'LjUtMy43LTMuNy01LjQtNS43bC0xMi4zLTE0LjR6bTAgOSA2IDcuMy03LjMgMi4yIDEuMy05'
    b'LjV6bTM4LjYtMjUuOCAzLjMgNmMtMSAxLTEuNi0xLjEtMi41LTEuNGE0LjcgNC43IDAgMCAw'
    b'LTUuNS0uNWwtMiAxLjEgOS44IDE4LjNjLjUgMS41IDIuNCAxLjggMy43IDEgLjQtLjQuOS0u'
    b'NiAxIC4xLTEuNiAxLTMuNSAxLjktNS4yIDIuOGwtNi41IDMuNWMtLjUtLjUtLjItLjguNC0x'
    b'YTIuNCAyLjQgMCAwIDAgMS4xLTMuN2wtOS43LTE4Yy0xLjggMS00IDEuOC00LjUgNC0uNSAx'
    b'LjUuMiAzLjIuMiA0LjQtLjUuNi0uNy0uMi0xLS42bC0yLjctNS4yIDIwLjEtMTAuOHptMTUu'
    b'My05LjEgNi4yIDguM2MxLjQtMSAyLjYtMi42IDIuMi00LjQuMi0xLjQtMS44LTMtMS4xLTQg'
    b'LjQtLjIuNy44IDEgMS4xbDcuMiA5LjVjLTEgMS0xLjYtMS4xLTIuNi0xLjQtMS40LTEtMy4z'
    b'LTEuNS00LjgtLjQtMS4xLjQtMSAxLS4zIDEuNyAxLjYgMi4xIDMuMiA0LjQgNSA2LjUgMSAx'
    b'IDIuNCAwIDMuMy0uOCAyLjQtMS42IDQuNS00LjIgNC40LTcuMi4yLTEuNC0uNy0yLjgtLjct'
    b'NCAuNi0uNy43LjQgMSAuOGwzLjQgNi0xNy42IDEzLjNjLS43LS41IDAtLjkuNS0xLjIgMS42'
    b'LTEgMS4xLTMuMSAwLTQuMkw5ODguMSA0MzdjLTEtMS4zLTIuOC0uNi0zLjcuMy0uNS42LTEt'
    b'LjUtLjMtLjZsMTYuNS0xMi41IDQuNSA2Yy0xIDEtMi0xLjMtMy4xLTEuNC0yLjItMS4yLTQu'
    b'OC0uMy02LjYgMS4ybC0zLjEgMi4zIi8+CiAgPC9nPgo8L3N2Zz4K', 'VG')

VG = b64_VG
index.append("VG")
index.append("VGB")
index.append("British Virgin Islands")
catalog["VG"] = VG
catalog["VGB"] = VG
catalog["British Virgin Islands"] = VG
country["British Virgin Islands"] = ('VG', 'VGB', 0)
lookup["VG"] = ('VG', 'VGB', 'British Virgin Islands', 0)
lookup["Road Town British Virgin Islands"] = ('VG', 'VGB', 'British Virgin Islands', 0)
lookup["VGB"] = ('VG', 'VGB', 'British Virgin Islands', 0)
lookup["British Virgin Islands"] = ('VG', 'VGB', 'British Virgin Islands', 0)
details["VG"] = {"continent":"Americas","capital":"Road Town","currency":"US Dollar","web":".vg","lang":"en-VG","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_VI = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy12aSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxwYXRoIGZpbGw9IiNmZmYiIGQ9Ik0wIDBoNjQwdjQ4MEgw'
    b'eiIvPgogIDxwYXRoIGZpbGw9IiMzNjk0NDMiIHN0cm9rZT0iIzAxMDAwMiIgc3Ryb2tlLW1p'
    b'dGVybGltaXQ9IjEwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTIwNC4zIDMxNXMtLjUtMy42'
    b'IDYuMi02LjFjNi42LTIuNiA3LjItMTIuMiA1LjgtMTguNiAwIDAtMy40IDYtNy43IDguMSAw'
    b'IDAtNi44IDMuNi03LjIgMTAuNCAwIDAgMCAyLjUtLjUgNC41LS4zIDEtMy40LTguNiAyLjQt'
    b'MTUuOCA2LTcuMyA3LjYtMTMuMyAyLjktMjUgMCAwLS41IDctNS4xIDExLjEtNC43IDQtNS4z'
    b'IDQuNC01LjIgMTQgMCAwIDAgMy40LTEuNyA0LjUgMCAwLTMuNi01LjMtNC42LTguOC0xLTMu'
    b'NS0xLjQtNSAyLjgtOSAwIDAgMTMuMi04LjcgMy43LTI3LjQgMCAwLS4zIDYuNC01IDEwLjIt'
    b'NC41IDMuOS00LjIgNi40LTQuNCAxMy0uMiA2LjctLjYgNi4yLTEuMSA3LjIgMCAwLTguNS0x'
    b'NS42LTItMjMuOCA2LjUtOC4zIDEwLjItMTAgMy0yNS40IDAgMCAuMyA4LTUuNSAxMS44LTUu'
    b'NyA0LTQuNCAxMy00LjQgMTNzLjQgMy41LS44IDZjMCAwLTguMS0xNS45LS40LTI0LjQgNi42'
    b'LTcuMyA3LTEyLjQgMy41LTIyLjYgMCAwLS40IDQuNy00IDcuMy0zLjcgMi42LTYuNiA1LjEt'
    b'NS45IDE1IDAgMCAuMyA3LS42IDkgMCAwLTMuNC02LjQtNC40LTEwLjUtMS00LjItMS4zLTYu'
    b'NiAxLjItMTAuN3MxMi41LTE2IC42LTMzYzAgMC0uMyA1LjUtMy40IDEwLjUtMyA1LTEuNiAx'
    b'MC45LTEgMTUuNC43IDQuNS0xLjUgOC45LTEuNSA4LjlzLTUuMi05LjUtNC0yMC40YzEtMTEt'
    b'My40LTIwLTEzLjUtMjYuNCAwIDAtNy4zIDE3IDIuNyAyNS43IDAgMCA4LjUgOC40IDEwLjcg'
    b'MTguNiAwIDAtNi41LS42LTEyLjMtMTItNS45LTExLjQtMTgtOS42LTE4LjgtOS43IDAgMCAy'
    b'IDE3LjYgMjAuNiAyMi42IDAgMCAxMiAyIDE0LjIgMTAuOCAwIDAgMiA2IDIuOCA5LjIgMCAw'
    b'LTMuOC0xLjUtNy4zLTYuNy0zLjUtNS0zLTUuNy0xNC44LTYuOSAwIDAtNC43LS41LTcuMi0z'
    b'LjkgMCAwIDUgMTguNiAxNy43IDE4LjUgMCAwIDExLjYtMS4zIDE4IDE0bC0yLjktMmMtMS43'
    b'LTEuMS02LTMuMy0xNC41LTIuM3MtMTAuOS0uNC0xMy0xYzAgMCA4LjYgMTUuNyAyMC43IDEx'
    b'IDEyLjItNC43IDE4IDEyLjQgMTguMiAxMi43IDAgMC0xLjctMS4yLTMuOC0zLjMtMi4yLTIu'
    b'MS02LjYtNC43LTE1LTIgMCAwLTYuMSAyLjMtMTIuMy40IDAgMCA2IDExLjUgMTkuOCA5LjVh'
    b'MTUuMSAxNS4xIDAgMCAxIDE3LjMgMTAuMnMtMS44LTEtMy0yYy0xLjMtMS02LTMuNy0xNi0u'
    b'OC0xMCAzLTEzLjYtLjQtMTMuNi0uNHM1LjUgMTAgMTYuMiAxMS4zYzAgMCA2LS4xIDguNC0x'
    b'IDIuNS0xIDkuMi0yLjUgMTMuOCA0LjIgMCAwLTEuMy4yLTMuMi0uNyAwIDAtNy0yLjUtMTIu'
    b'NSAyIDAgMC00LjggNC45LTExLjYgNCAwIDAgOC44IDguNSAyMi44IDEuMyAwIDAgNC43LTMu'
    b'NCA4LjItLjggMy41IDIuNyAxMS41LTIuNiAxMS41LTIuNnoiLz4KICA8ZyBmaWxsPSIjZjRj'
    b'NTNkIiBzdHJva2U9IiMwMTAwMDIiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgc3Ryb2tlLXdp'
    b'ZHRoPSIxLjUiPgogICAgPHBhdGggZD0iTTI4Mi4yIDEwMy43cy0xLjYtMTQuNSAxMC0xNmEz'
    b'OCAzOCAwIDAgMSAxOCAxLjJsNS41IDEwLjYtMiA3LjItNy40IDMuNHMxLjMtMTEtOC44LTEx'
    b'LjJjLTIuNiAwLTQgMS04LjEuM3MtNi4zIDMuOC03LjIgNC41eiIvPgogICAgPHBhdGggZD0i'
    b'TTM2My44IDEzOS42Yy0xLjggMi4yLTguNyAzLTguNyAzczcuMSA1LjUgMTAuMiAxMy4zYzMg'
    b'Ny43LTgyLjQgMC04Mi40IDBzMy44LTIuNiA2LjMtNy42YzAgMC0zLjggMS40LTcuNi0yLjQg'
    b'MCAwIDIuOCAxIDYuNS00LjYgMCAwIDUuNS03IDkuNC05IDAgMC0xLjggMS4yLTYuMS0xLjIg'
    b'MCAwIDcuNC0xIDEwLTEzLjUgMCAwIC41LTIuOCAzLjMtNyAyLjgtNCAyLjIuOSA3LjQtNS40'
    b'IDAgMCAyLjQtNC40LjMtNy0yLTIuOC00LjMtMS44LTguNi00LjQtNC40LTIuNi02LjMtNC00'
    b'LjgtOHM1LjMtMy40IDUuOS0zLjQuOC0zLjUgNS41LTUuOSAxNy40LTEuMyAxOS4yLS4zYzIg'
    b'MSA5LjUgMy4zIDE0IDE0LjUgNC40IDExLjItMS4yIDE1LjQgMTAuOCAzMi40IDAgMC00Ljgg'
    b'MS03LjkgMCAwIDAgNi4zIDExLjIgMTcuMyAxNi41eiIvPgogICAgPHBhdGggZmlsbD0ibm9u'
    b'ZSIgZD0iTTMxMSA5Mi4yYy0xMC0uNS02LjEtOS44LTYuMS05LjgiLz4KICAgIDxwYXRoIGQ9'
    b'Ik0zMjggOTMuNXMtMS43LS44LTMuMi0yLjhjLTItMi43LTYuNy00LTkuMS0xLjQgMCAwLTIu'
    b'NSAyLjgtNC44IDMgMCAwIDIuNi43IDQuMyAyLjMgMS43IDEuNiAzLjUgMi44IDYuMSAyLjQg'
    b'Mi42LS4zIDMtMS43IDQuMi0yLjUgMS4zLS44IDIuNS0xIDIuNS0xeiIvPgogIDwvZz4KICA8'
    b'cGF0aCBmaWxsPSIjMzY5NDQzIiBzdHJva2U9IiMwMTAwMDIiIHN0cm9rZS1taXRlcmxpbWl0'
    b'PSIxMCIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0yMDIuOCAzMzYuNXMtLjItNi40IDcuOC02'
    b'LjhsMjMuNSAzMi43cy0uOSAyLjEtMTEuNSAxLjljMCAwLTEuMiAwLTEuOCAxLjItLjkgMi0x'
    b'OC0yOS0xOC0yOXoiLz4KICA8ZyBpZD0idmktYSIgZmlsbD0iI2Y0YzUzZCIgc3Ryb2tlPSIj'
    b'MDEwMDAyIiBzdHJva2Utd2lkdGg9IjEwIiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgzLjYgMjYu'
    b'Mikgc2NhbGUoLjE1MDU1KSI+CiAgICA8cGF0aCBkPSJNMTQ5NSAxODA3LjlzLTQ5LjkgODUu'
    b'Ni0xMTAuMiA4N2MwIDAtMTAzLjctMTIuNi0xMzMgMTQuNS0yMC41IDE4LjktNDEuNCAzNC41'
    b'LTUwIDgyLjgtOC40IDQ4LjMgMTYuNSA1OC43IDIyLjQgNjAuOCAwIDAgNC42IDM0LjUgMzgu'
    b'NyAyNS41IDAgMCAyIDM2IDYyLjIgMTguNyA2MC4zLTE3LjMgODUuMy0xMS44IDk3LTcxLjgg'
    b'MTEuOS02MC4xIDIyLjgtNTkuMSAzMy41LTY2LjMgMTQuNC05LjcgNDEuNS0xOC44IDYxLjYt'
    b'MzAuNCAxOC0xMC40IDg3LjItNDUuNiAxMTAuOC00OC4zIDIzLjYtMi44IDE4LjQtODIuMiAx'
    b'OC40LTgyLjJoLTYxbC0yOS41LTQzLjUtNjEgNTMuMnptMTkyLTQyOS40cy02MSA0OS43LTEx'
    b'Mi4yIDBjMCAwLTIwLjYgMjQuOC02MiAxNy42LTQxLjItNy4zLTQ4LjEtMjktNTItNDEuNCAw'
    b'IDAtMzUuOCAyMC44LTY2IDQuMy0zMC0xNi40LTMwLTQxLjMtMzAtNDEuM3MtNTIuNSAxMC40'
    b'LTc5LjQtMjUuMmMtMjYuOS0zNS41LTEwLjUtNzAuNyA0LTc0LjkgMCAwLTU2LjcgMTQuOS03'
    b'Mi4yLTMzLjhhNTYgNTYgMCAwIDEgMTYuNC02Mi44cy0xMTkuNC0uNi0xNjguNC0zOGMwIDAt'
    b'NDAuNy0yNS42LTE2LjQtNTIuNSAwIDAtMTA3LjUtMTcuMi0xMzQuNC02MCAwIDAtMTEuOC0x'
    b'MS44LTcuOS0zMi41IDAgMCAuNy0xMS43IDEyLjUtMTIuNCAwIDAtMTIyLjYtMTktMTU4LTU5'
    b'LjQgMCAwLTE3LTE4LjYtOC41LTQzLjUgMCAwIDEuOC02LjUgNC43LTExIDAgMC0xMTEuNi0y'
    b'My41LTE2Ni42LTczLjIgMCAwLTMxLjgtMjguMy0xNS40LTY2LjMgMCAwLTE4Ni41LTUxLTE0'
    b'My4zLTEzMy4yIDAgMC04Ny4yLTI4LjMtNTkuNi0xMDcgMCAwLTcyLjEtMzYuNi00MC43LTk0'
    b'LjYgMzAuMS01NS41IDEyMi42IDkuNyAyMzIgNDAgMCAwIDI5Ni40IDkzLjIgNDQyLjMgMTE4'
    b'bDQxNC42IDYxNy4zIDI0MS45IDkzLjIgMjQuNSAxNzIuNnoiLz4KICAgIDxwYXRoIGQ9Ik0x'
    b'Njg5LjkgOTIzLjlzLTM4LjktMjkuMi0xMDguMiA1LjFjMCAwLTIzLjMgMTYuMS00MS43LTEu'
    b'NWEzNy4zIDM3LjMgMCAwIDEgNC4zLTU3LjVjNTEuNy0zOC4zIDcwLjgtMTUzLjItNy44LTIw'
    b'MC45IDAgMC0xMTQtNjcuNi01MzIuMy0xNzQgMCAwLTM1LTkuOC01My44LTUuMWE1MiA1MiAw'
    b'IDAgMC0zNy42IDM3LjhTODk0IDU4MS4xIDk1NyA2MTEuNmMwIDAgMjguNCAxMyA1Ny43IDIx'
    b'LjQgMCAwLTMyLjItNy00NiAyNC44LTEzIDMwLjQgNiA2MS41IDY1IDgxLjUgMCAwIDE2IDYu'
    b'MiAzOC43IDExLjcgMCAwLTUwLjUgMTQuNS0yNi4yIDU1LjMgMCAwIDIxLjYgNDIuOCA5OCA1'
    b'MC40IDAgMC01NyA2LjItMTYuOCA2MC40IDAgMCAxNy43IDI5LjcgNzMuNCA0MC43IDAgMC00'
    b'Mi4yIDEuNC0yMSAzOS4zIDIxLjQgMzggNzEuNSA1OS40IDEyMC45IDYyLjkgMCAwIDI2Ljcg'
    b'MS40IDQ1LjQtMi44IDAgMC00NyAyMy41LTE5LjQgNjIuOCAwIDAgMjAuMyAyOCA3MS4xIDI2'
    b'LjYgMCAwLTEzLjEgNDQgMjQuMSA2MC42IDI5IDEzIDUzLjEtNy44IDUzLjEtNy44cy05Ljgg'
    b'NDcuMSAzMi41IDYzLjdjMCAwIDIxLjEgMTAuOSA1Mi42IDAgMCAwIDI0IDUzLjkgMTA5LjYg'
    b'MTYgODUuNi0zNy43IDIwLjItMzU1LjEgMjAuMi0zNTUuMXptNSA0ODkuNHMtMTIuNSA2Ny40'
    b'LTExMiAxNTIuMmMwIDAtNzYuOCA2Ny43LTc0LjkgMTQ1LjcgMiA3OS41LTEzLjcgODguNC00'
    b'My45IDExNS4zIDAgMCA2Mi4zIDQuOSA5Mi40LTM2LjYgMCAwLTEuMyA2OS0xMC41IDc1LjMg'
    b'MCAwIDE5LjYgMS4yIDQ3LjktMjkuNyAwIDAgMTctMTggMzIuOC0yNC45IDAgMC0xOC40IDQ3'
    b'LjctNCA5MS45IDAgMCA0LjYtMTcuMyAyOC45LTI0LjkgMCAwIDQ0LTkgNjEtNzIuNSAwIDAg'
    b'MTEuMS00MiA4MC03OS40IDAgMCA3OC0yOS40IDc2LTY3LjgtMi0zOC41LTE3My42LTI0NC42'
    b'LTE3My42LTI0NC42eiIvPgogICAgPHBhdGggc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBkPSJN'
    b'MjA1Ni41IDIyODIuMnMtMTcuOSA3OC44LTgwIDcyLjVjMCAwLTQzLjktNC4yLTQwLjYtNzcu'
    b'NCAwIDAtNjQuOSAzNC42LTc1LjQtNTEgMCAwLTU5IDEzLjctNTguMy02Ni4zIDAgMC01NSA5'
    b'LjYtNDguNS02MS41IDAgMC01OS43IDE2LTU5LjctNTEgMCAwLTEzOS42LTIzLjIgMTUxLjQt'
    b'Mjg4LjZsMjU5LjYgMTU0LjYtNDguNSAzNjguN3oiLz4KICAgIDxwYXRoIGQ9Ik0yMDg1LjQg'
    b'MTkyOC4zcy00My4zIDM4LjQtNzQuMS0xOWMwIDAtNDItMi00OC41LTMzLjggMCAwLTM0LjEt'
    b'My40LTQwLjctMzUuOSAwIDAtNDYuNS00LjgtNDUuMi00NC4xIDAgMC04NC42LTYuNiAwLTEw'
    b'Mi40IDg0LjYtOTUuOCAyMjguMSAxNTkgMjI4LjEgMTU5bC0xOS42IDc2LjJ6bTQ4LjItMjMu'
    b'OGM0MiAwIDg5LjUgMjYyIDc3LjIgNDE5LjktNC41IDU3LjMtMzUuMiAxMDQuMS03Ny4yIDEw'
    b'NC4xcy03Mi42LTQ2LjgtNzctMTA0LjFjLTEyLjQtMTU3LjkgMzUuMS00MTkuOSA3Ny00MTku'
    b'OSIvPgogICAgPGVsbGlwc2UgY3g9IjIxMzMuNiIgY3k9IjE5MDIuNSIgcng9IjU4IiByeT0i'
    b'ODYiLz4KICAgIDxwYXRoIGZpbGw9Im5vbmUiIHN0cm9rZS1taXRlcmxpbWl0PSIxMCIgZD0i'
    b'TTE5MzUuOSAyMjc3LjNzNi42LTEzOC43IDEyNi44LTMzNy42bS0yMDIuMiAyODYuNnMtMTgu'
    b'Ny04MC4xIDE1MC44LTMxN2MwIDAtMTkuNy01Ni41IDQwLjYtOTIuOE0xODAyLjIgMjE2MHMt'
    b'NS4zLTg2LjcgMTYwLjYtMjg0LjVjMCAwLTE0LjctNTEgNDUuNC05MS44bS0yNTQuNSAzMTQu'
    b'OHM2LjItODcuNiAxNjguNC0yNTguOWMwIDAtOC01Mi40IDUwLTg0LjltLTI3OCAyOTIuOHMx'
    b'MS43LTEwMC4xIDE4Mi44LTI1MmMwIDAtNS45LTM5LjQgNTEuMS03OS40Ii8+CiAgICA8cGF0'
    b'aCBmaWxsPSJub25lIiBkPSJNMzcyLjMgNDMyczEzNC4zIDc3LjggNTUyLjkgMTU1LjZNNDMx'
    b'LjkgNTM5Uzc5NS42IDY1Ny42IDk2NSA2NzIuMm0tMzg5LjkgMHMyMTMuNCA2NyA0NjMuMyAx'
    b'MDkuM20tMjgxLjIgMzAuM3MyNDEgNTcuOSAzNTYuMiA2Ny41TTkxOSA5MjUuNnMyMDMuOSA0'
    b'Mi41IDI1NS41IDQ3LjZtLTEyNS43IDU3LjNzMTQ4LjggMjIuNiAyMDggMjEuNG0tMjMuMiA2'
    b'OXM2MC4yLTIuOCA4OS4xLTcuNm0tMzMuNCAxMDQuM3M1MS4yLTEzLjggODEuMy0zMy4xbS01'
    b'LjkgMTMzLjJzMzkuNC0xNS4yIDU4LjQtNTYuNm0zNy43IDkzLjZzMzAuNC0yNy4zIDMyLjQt'
    b'NTcuN204MS42IDgxLjVzLTExLjQtOS45LTMuNi01Mi43bS0xMS4xLTYyLjhzLTYtMTIuMi00'
    b'LTMxLjZtLTIxMS01ODEuM3M2OC44IDI3LjYgOTEuNyA2NS42YzIzIDM4IDcuOSA3NC45IDAg'
    b'OTYtMy45IDEwLjctNTIuNCAxMDQuMiA0LjYgMTcxLjlNMTM0NiAxMDU3cy40LS4zIDI0LjYt'
    b'OG0tMTY5LjgtOTEuNHM0MSA4LjIgODEuMyA4LjZtLTEzOC0xMDkuOHM0OC4yIDQuOSA5My41'
    b'IDQuMm0tMTY1LjItMTA5LjhzNjkuNSAxMy44IDEwNi44IDE0LjVNMTAxNC43IDYzM3M4NS43'
    b'IDI0LjQgMTQ5LjQgMzMuMW0xNDEuNiA1MC40cy02MS42IDU3LjMgMTIuNSAxMTAuNWMwIDAt'
    b'MzAuOCA0OC4zIDMwLjggOTguN20tMTYuNCAyMy44cy05LjIgOTIuMiAxMDMuNiA5Mi4yYzAg'
    b'MC0yMS43IDgyLjEgODcuMiA3OS40IDAgMCAxMi40IDY1LjYgOTEgNTIuNE0xNDQxLjMgMTg5'
    b'NXMtMTcuOSA0LTU2LjYgMG0tMTA4LjggNDguM3MtNTQuNC04LjMtNTEuOCAxMDkuOG04NC42'
    b'LTgyLjlzLTQ5LjItNi4yLTQ2IDEwOC40bTUyMC43LTM4NC41cy0yMy42IDQuOC00MCAyMy41'
    b'Yy0xNi4zIDE4LjYtNDcuOCAxNS4xLTQ3LjggMTUuMXMxNy0xMy44IDIzLTQ4LjNjNS44LTM0'
    b'LjUgMjQuOS00NC45IDI0LjktNDQuOW0tNTYuMy0zMi42cy0yMy42IDQuOC00MCAyMy40Yy0x'
    b'Ni40IDE4LjctNDcuOSAxNS4yLTQ3LjkgMTUuMnMxNy0xMy44IDIzLTQ4LjNjNS45LTM0LjUg'
    b'MjQuOS00NC45IDI0LjktNDQuOW0yMy43IDE4OC41cy0yMC42IDQuMy0zNC45IDIwLjVjLTE0'
    b'LjMgMTYuMy00MS44IDEzLjMtNDEuOCAxMy4zczE1LTEyIDIwLTQyLjJjNS4yLTMwLjEgMjEu'
    b'OC0zOS4yIDIxLjgtMzkuMiIvPgogIDwvZz4KICA8dXNlIHhsaW5rOmhyZWY9IiN2aS1hIiB3'
    b'aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBzdHJva2U9IiMwMTAwMDIiIHN0cm9rZS13aWR0'
    b'aD0iMTAiIHRyYW5zZm9ybT0ibWF0cml4KC0xIDAgMCAxIDY0Ny4yIDApIi8+CiAgPHBhdGgg'
    b'ZmlsbD0iIzAwODFjNiIgc3Ryb2tlPSIjMDEwMDAyIiBzdHJva2UtbWl0ZXJsaW1pdD0iMTAi'
    b'IHN0cm9rZS13aWR0aD0iMS41IiBkPSJtNDY2IDI1Ni0xNC4zIDYxLjctNS45LTQuMiAxNC01'
    b'OS4yLTkuOC4yIDIzLjEtNDIuMyAxLjUgNDguN3ptMzcgMTMtNDMgNTAuOC00LjYtNS4yIDQy'
    b'LjgtNTAuMi04LjctNC42IDM5LjItMjYtMjAuMyA0My44eiIvPgogIDxwYXRoIGZpbGw9IiMw'
    b'MDgxYzYiIHN0cm9rZT0iIzAxMDAwMiIgc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBzdHJva2Ut'
    b'd2lkdGg9IjEuNSIgZD0ibTQ5Mi42IDI0Mi0zOC41IDc0LTUuOS0zLjUgMzguNy03My44LTku'
    b'NC0yLjQgMzIuNy0zNC42LTEwLjUgNDcuNXptLTQ4IDk2LjYtMi45IDExLjcgOCA4LTExLjIg'
    b'NDctMTAtMTMuMy0xNC42IDYuOCAxMS4xLTQ3IDEwLjQtMyAyLjYtMTEuN3MzLjItMS4yIDYu'
    b'NiAxLjV6Ii8+CiAgPHBhdGggZmlsbD0iIzAwODFjNiIgc3Ryb2tlPSIjMDEwMDAyIiBzdHJv'
    b'a2UtbWl0ZXJsaW1pdD0iMTAiIHN0cm9rZS13aWR0aD0iMS41IiBkPSJtNDQ3LjMgMzMwLjgt'
    b'NS43IDEwLjYgNS43IDkuNy0yMi40IDQyLjUtNi4zLTE1LjYtMTUuOSAyLjYgMjIuNC00Mi40'
    b'aDEwLjdsNS41LTEwLjZzNCAwIDYgMy4yeiIvPgogIDxwYXRoIGZpbGw9IiMwMDgxYzYiIHN0'
    b'cm9rZT0iIzAxMDAwMiIgc3Ryb2tlLW1pdGVybGltaXQ9IjEwIiBzdHJva2Utd2lkdGg9IjEu'
    b'NSIgZD0ibTQ0OC4yIDMzMy45LTE1IDE5LjIgMy40IDEwLjgtMzAuOSAzNi0yLjgtMTYuNi0x'
    b'Ni0xLjIgMzAuOC0zNiAxMC40IDIuNSAxNi0yMC40czQuNCAyLjIgNC4xIDUuN3ptLTM4Mi43'
    b'LTQ1YzMuNi0xLjUgNi4yLTIuOSA2LjItNi43IDAtMS0uNS0zLTEuNS02LjFMNDYgMjAyYTU5'
    b'IDU5IDAgMCAwLTMtNy45Yy0xLjEtMi0zLjItMi45LTYuMS00aDMwLjdjLTMuMyAxLjUtNi40'
    b'IDIuNy02LjMgNi4zIDAgMS4zLjQgMy4yIDEuMSA1LjdsMTguNiA1OCAxOC41LTU4YTIwIDIw'
    b'IDAgMCAwIDEuMS01LjdjMC0zLjctMy4yLTUtNi4zLTYuNGgyOS44Yy0yLjcgMS4xLTUgMi02'
    b'IDQuMWE2MyA2MyAwIDAgMC0zLjEgOEw5MC44IDI3NmEzNy45IDM3LjkgMCAwIDAtMS41IDYu'
    b'MXMtMS4xIDQuNyA2LjIgNi43aC0zMHptNTE1LjMtNy42di04My43YzAtMS40LS4zLTIuNS0u'
    b'OC0zLjNzLTIuNS0zLTUuNS00LjJoMjcuN2ExMS41IDExLjUgMCAwIDAtNS41IDQuMmMtLjUu'
    b'OC0uNyAxLjktLjcgMy4zdjgzLjdjMCAxLjUuMiAyLjYuNyAzLjQuNS44IDIuNSAyLjggNS41'
    b'IDQuMmgtMjcuN2MzLTEuNCA1LTMuNCA1LjUtNC4yLjUtLjguOC0xLjkuOC0zLjR6Ii8+CiAg'
    b'PHBhdGggZmlsbD0iI2ZmZiIgc3Ryb2tlPSIjMDEwMDAyIiBzdHJva2Utd2lkdGg9IjEuNSIg'
    b'ZD0iTTMyNC44IDMwOS44UzM5OSAyNzYuOSAzOTkuMSAyMDFIMjUwLjVjLjIgNzYgNzQuMyAx'
    b'MDguOCA3NC4zIDEwOC44eiIvPgogIDxwYXRoIGZpbGw9IiNhNjAwMzIiIHN0cm9rZT0iIzAx'
    b'MDAwMiIgc3Ryb2tlLXdpZHRoPSIxLjUiIGQ9Ik0yNjIgMjAxdjQ4LjVzNS42IDExLjMgMTEu'
    b'NCAxOC4zVjIwMUgyNjJ6bTIyLjggMHY4MHM3LjIgNyAxMS40IDEwLjRWMjAxaC0xMS40em0y'
    b'Mi45IDB2OTguOXM4LjEgNS4yIDExLjQgN3YtMTA2aC0xMS40em04MCAwdjQ4LjVzLTUuNyAx'
    b'MS4zLTExLjUgMTguM1YyMDFoMTEuNXptLTIyLjkgMHY4MHMtNy4xIDctMTEuNCAxMC40VjIw'
    b'MWgxMS40em0tMjIuOCAwdjk4LjlzLTguMiA1LjItMTEuNSA3di0xMDZIMzQyeiIvPgogIDxw'
    b'YXRoIGZpbGw9IiMxNjI2NjciIHN0cm9rZT0iIzAxMDAwMiIgc3Ryb2tlLW1pdGVybGltaXQ9'
    b'IjEwIiBzdHJva2Utd2lkdGg9IjEuNSIgZD0iTTM5OS4xIDE0NS44cy0zNi40IDE5LTc0LjMt'
    b'MS42Yy0zNy45IDIwLjYtNzQuMyAxLjYtNzQuMyAxLjZWMjAxaDE0OC42di01NS4yeiIvPgo8'
    b'L3N2Zz4K', 'VI')

VI = b64_VI
index.append("VI")
index.append("VIR")
index.append("Virgin Islands US")
catalog["VI"] = VI
catalog["VIR"] = VI
catalog["Virgin Islands US"] = VI
country["Virgin Islands US"] = ('VI', 'VIR', 0)
lookup["VI"] = ('VI', 'VIR', 'Virgin Islands US', 0)
lookup["Charlotte Amalie Virgin Islands US"] = ('VI', 'VIR', 'Virgin Islands US', 0)
lookup["VIR"] = ('VI', 'VIR', 'Virgin Islands US', 0)
lookup["Virgin Islands US"] = ('VI', 'VIR', 'Virgin Islands US', 0)
details["VI"] = {"continent":"Americas","capital":"Charlotte Amalie","currency":"US Dollar","web":".vi","lang":"en-VI","tz":"-04:00","altname":""}
#----------------------------------------------------------------------
b64_VN = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXZuIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InZuLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTg1LjMgMGg2ODIu'
    b'NnY1MTJILTg1LjN6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCN2bi1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoODApIHNjYWxlKC45Mzc1KSI+CiAgICA8cGF0aCBmaWxsPSIjZGEyNTFkIiBkPSJNLTEy'
    b'OCAwaDc2OHY1MTJoLTc2OHoiLz4KICAgIDxwYXRoIGZpbGw9IiNmZjAiIGQ9Ik0zNDkuNiAz'
    b'ODEgMjYwIDMxNC4zbC04OSA2Ny4zTDIwNCAyNzJsLTg5LTY3LjcgMTEwLjEtMSAzNC4yLTEw'
    b'OS40TDI5NCAyMDNsMTEwLjEuMS04OC41IDY4LjQgMzMuOSAxMDkuNnoiLz4KICA8L2c+Cjwv'
    b'c3ZnPgo=', 'VN')

VN = b64_VN
index.append("VN")
index.append("VNM")
index.append("Viet Nam")
catalog["VN"] = VN
catalog["VNM"] = VN
catalog["Viet Nam"] = VN
country["Viet Nam"] = ('VN', 'VNM', 0)
lookup["VN"] = ('VN', 'VNM', 'Viet Nam', 0)
lookup["Hanoi Viet Nam"] = ('VN', 'VNM', 'Viet Nam', 0)
lookup["VNM"] = ('VN', 'VNM', 'Viet Nam', 0)
lookup["Viet Nam"] = ('VN', 'VNM', 'Viet Nam', 0)
details["VN"] = {"continent":"Asia","capital":"Hanoi","currency":"Dong","web":".vn","lang":"vi | en | fr | zh | km","tz":"+07:00","altname":""}
#----------------------------------------------------------------------
b64_VU = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy12dSIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGNsaXBQYXRoIGlkPSJ2dS1hIj4KICAg'
    b'ICAgPHBhdGggZD0iTTAgMHY0NzVsNDIwLTE5NWg0ODB2LTg1SDQyMFoiLz4KICAgIDwvY2xp'
    b'cFBhdGg+CiAgPC9kZWZzPgogIDxwYXRoIGZpbGw9IiMwMDk1NDMiIGQ9Ik0wIDBoNjQwdjQ4'
    b'MEgweiIvPgogIDxwYXRoIGZpbGw9IiNkMjEwMzQiIGQ9Ik0wIDBoNjQwdjI0MEgweiIvPgog'
    b'IDxnIGNsaXAtcGF0aD0idXJsKCN2dS1hKSIgdHJhbnNmb3JtPSJzY2FsZSguNzExMTEgMS4w'
    b'MTA1MykiPgogICAgPHBhdGggc3Ryb2tlPSIjZmRjZTEyIiBzdHJva2Utd2lkdGg9IjExMCIg'
    b'ZD0ibTAgMCA0MjAgMTk1aDQ4MHY4NUg0MjBMMCA0NzUiLz4KICAgIDxwYXRoIGZpbGw9Im5v'
    b'bmUiIHN0cm9rZT0iIzAwMCIgc3Ryb2tlLXdpZHRoPSI2MCIgZD0ibTAgMCA0MjAgMTk1aDQ4'
    b'MG0wIDg1SDQyMEwwIDQ3NSIvPgogIDwvZz4KICA8ZyBmaWxsPSIjZmRjZTEyIiB0cmFuc2Zv'
    b'cm09InRyYW5zbGF0ZSgtMjIpIHNjYWxlKDEuMDEwNTMpIj4KICAgIDxwYXRoIGQ9Ik0xMDYu'
    b'OSAyODN2MjdjMjMuNSAwIDY5LjctMTggNjkuNy03Ni4xIDAtNTguMS00OS4zLTY4LjktNjQt'
    b'NjguOS0xNC44IDAtNjAuMyAxMC42LTYwLjMgNTggMCA0Ny42IDQ0LjcgNTIgNTMuNSA1MiA4'
    b'LjggMCA0MS44LTggMzgtNDMuNmEzNS41IDM1LjUgMCAwIDEtMzUuNCAzMS41Yy0yNCAwLTM5'
    b'LTE3LjgtMzktMzUuNCAwLTE3LjYgMTQuNi00MS4yIDM5LjktNDEuMiAyNS4zIDAgNDMuOCAy'
    b'Mi41IDQzLjggNDUuMSAwIDIyLjctMTcuOCA1MS41LTQ2LjIgNTEuNXoiLz4KICAgIDxnIGlk'
    b'PSJ2dS1iIj4KICAgICAgPHBhdGggc3Ryb2tlPSIjZmRjZTEyIiBzdHJva2Utd2lkdGg9Ii44'
    b'IiBkPSJtODYuMiAyNDcuNyAxLjQgMXMxMS4yLTI1LjUgNDEuMS00My42Yy0zLjggMi0yMy44'
    b'IDEyLTQyLjUgNDIuNnoiLz4KICAgICAgPHBhdGggZD0iTTg5LjEgMjQzLjNzLTMuNC03LS40'
    b'LTEwLjJjMy0zLjEgMS43IDguMyAxLjcgOC4zbDEuMy0xLjlzLTItOC42LjItMTAuNGMyLjMt'
    b'MS45IDEuMiA4LjMgMS4yIDguM2wxLjQtMS44cy0xLjUtOC40LjctMTBjMi4zLTEuNi45IDgg'
    b'LjkgOGwxLjYtMnMtMS4yLTggMS41LTkuOWMyLjctMS45LjMgNy42LjMgNy42bDEuOC0ycy0u'
    b'OC03LjMgMS41LTljMi4zLTEuNi40IDcgLjQgN2wxLjYtMS44cy0uNS02LjggMS43LTguNGMy'
    b'LjMtMS42LjIgNi41LjIgNi41bDEuNy0xLjZzLS40LTYuOSAyLjQtOC4yYzIuOC0xLjMtLjUg'
    b'Ni40LS41IDYuNGwyLTEuNnMuNS04IDIuOS04LjdjMi40LS44LTEgNy0xIDdsMS43LTEuNHMu'
    b'OS02LjggMy41LTcuNmMyLjctLjktMS42IDYuMi0xLjYgNi4ybDEuNy0xLjNzMS45LTYuOCA0'
    b'LjQtNy42YzIuNC0uNy0yLjYgNi41LTIuNiA2LjVsMS43LTEuMnMyLjctNi4yIDUtNi42YzIu'
    b'MS0uNC0yLjYgNS4xLTIuNiA1LjFsMi4xLTEuMnMzLjUtNi40IDQuOC00LjVjMS4yIDItNSA0'
    b'LjktNSA0LjlsLTIgMS4yczcuNS0zLjYgOC40LTEuOGMuOSAxLjgtMTAuMyAzLTEwLjMgM2wt'
    b'MS44IDEuMnM3LjUtMiA2LjYtLjFjLTEgMS45LTguNCAxLjUtOC40IDEuNWwtMS43IDEuMnM3'
    b'LjUtMS44IDYuNSAwYy0xIDEuNi04LjMgMS41LTguMyAxLjVsLTEuOCAxLjVzNy4zLTIgNi4y'
    b'LjNjLTEgMi4yLTkuNCAyLjEtOS40IDIuMWwtMiAyczcuNy0yLjcgNy0uNmMtLjYgMi05LjQg'
    b'My05LjQgM2wtMiAyczguMy0yLjcgNS44LS4yYy0yLjQgMi42LTguNSAzLjItOC41IDMuMmwt'
    b'Mi4zIDNzOC4yLTUgNy0yLjJjLTEuMSAyLjgtOS4yIDQuNy05LjIgNC43bC0xLjYgMnM3LjQt'
    b'NC4zIDYuNi0yYy0uNyAyLjUtOC42IDUtOC42IDVsLTEuMyAxLjhzOC43LTUuMiA4LTIuNWMt'
    b'LjggMi42LTkuMSA0LjUtOS4xIDQuNWwtMSAxLjdzOC00LjcgOC0yLjRjLjIgMi4yLTkuNCA0'
    b'LjQtOS40IDQuNGwtLjItMS45eiIvPgogICAgPC9nPgogICAgPHVzZSB4bGluazpocmVmPSIj'
    b'dnUtYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgdHJhbnNmb3JtPSJtYXRyaXgoLTEg'
    b'MCAwIDEgMjIwIDApIi8+CiAgPC9nPgo8L3N2Zz4K', 'VU')

VU = b64_VU
index.append("VU")
index.append("VUT")
index.append("Vanuatu")
catalog["VU"] = VU
catalog["VUT"] = VU
catalog["Vanuatu"] = VU
country["Vanuatu"] = ('VU', 'VUT', 0)
lookup["VU"] = ('VU', 'VUT', 'Vanuatu', 0)
lookup["Port Vila Vanuatu"] = ('VU', 'VUT', 'Vanuatu', 0)
lookup["VUT"] = ('VU', 'VUT', 'Vanuatu', 0)
lookup["Vanuatu"] = ('VU', 'VUT', 'Vanuatu', 0)
details["VU"] = {"continent":"Oceania","capital":"Port Vila","currency":"Vatu","web":".vu","lang":"bi | en-VU | fr-VU","tz":"+11:00","altname":""}
#----------------------------------------------------------------------
b64_WF = EmbeddedSvgImage(
    b'PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiID8+DQo8IURPQ1RZUEUgc3Zn'
    b'IFBVQkxJQyAiLS8vVzNDLy9EVEQgU1ZHIDEuMS8vRU4iICJodHRwOi8vd3d3LnczLm9yZy9H'
    b'cmFwaGljcy9TVkcvMS4xL0RURC9zdmcxMS5kdGQiPg0KPHN2ZyB3aWR0aD0iMzg2cHQiIGhl'
    b'aWdodD0iMzAycHQiIHZpZXdCb3g9IjAgMCAzODYgMzAyIiB2ZXJzaW9uPSIxLjEiIHhtbG5z'
    b'PSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+DQo8cGF0aCBmaWxsPSIjM2I1YWEzIiBz'
    b'dHJva2U9IiMzYjVhYTMiIHN0cm9rZS13aWR0aD0iMC4wOTM3NSIgb3BhY2l0eT0iMS4wMCIg'
    b'ZD0iIE0gMC4wIDAuMCBMIDMxLjggMC4wIEMgMzEuNyAyNi45IDMxLjggNTMuOCAzMS43IDgw'
    b'LjcgQyAyMS4xIDgwLjggMTAuNiA4MC43IDAuMCA4MC44IEwgMC4wIDAuMCBaIiAvPg0KPHBh'
    b'dGggZmlsbD0iI2ZmZmZmZiIgc3Ryb2tlPSIjZmZmZmZmIiBzdHJva2Utd2lkdGg9IjAuMDkz'
    b'NzUiIG9wYWNpdHk9IjEuMDAiIGQ9IiBNIDMxLjggMC4wIEwgNjQuMiAwLjAgQyA2NC4zIDI2'
    b'LjkgNjQuMiA1My44IDY0LjMgODAuNyBDIDc1LjQgODAuOCA4Ni42IDgwLjggOTcuNyA4MC43'
    b'IEMgOTcuOCA1My44IDk3LjcgMjYuOSA5Ny44IDAuMCBMIDEwMi4wIDAuMCBDIDEwMi4wIDI4'
    b'LjEgMTAyLjAgNTYuMSAxMDIuMCA4NC4yIEMgNjguMCA4NC4zIDM0LjAgODQuMiAwLjAgODQu'
    b'MiBMIDAuMCA4MC44IEMgMTAuNiA4MC43IDIxLjEgODAuOCAzMS43IDgwLjcgQyAzMS44IDUz'
    b'LjggMzEuNyAyNi45IDMxLjggMC4wIFoiIC8+DQo8cGF0aCBmaWxsPSIjYmUwMDI3IiBzdHJv'
    b'a2U9IiNiZTAwMjciIHN0cm9rZS13aWR0aD0iMC4wOTM3NSIgb3BhY2l0eT0iMS4wMCIgZD0i'
    b'IE0gNjQuMiAwLjAgTCA5Ny44IDAuMCBDIDk3LjcgMjYuOSA5Ny44IDUzLjggOTcuNyA4MC43'
    b'IEMgODYuNiA4MC44IDc1LjQgODAuOCA2NC4zIDgwLjcgQyA2NC4yIDUzLjggNjQuMyAyNi45'
    b'IDY0LjIgMC4wIFoiIC8+DQo8cGF0aCBmaWxsPSIjYmUwMDI3IiBzdHJva2U9IiNiZTAwMjci'
    b'IHN0cm9rZS13aWR0aD0iMC4wOTM3NSIgb3BhY2l0eT0iMS4wMCIgZD0iIE0gMTAyLjAgMC4w'
    b'IEwgMzg2LjAgMC4wIEwgMzg2LjAgMjk5LjAgQyAyNTcuMyAyOTkuMCAxMjguNyAyOTkuMCAw'
    b'LjAgMjk5LjAgTCAwLjAgODQuMiBDIDM0LjAgODQuMiA2OC4wIDg0LjMgMTAyLjAgODQuMiBD'
    b'IDEwMi4wIDU2LjEgMTAyLjAgMjguMSAxMDIuMCAwLjAgTSAxNzMuNyA3Ni4zIEMgMTkxLjIg'
    b'OTguNCAyMDIuMSAxMjUuOCAyMDQuMSAxNTQuMCBDIDE3NS41IDE1MS42IDE0OC4yIDE0MC40'
    b'IDEyNC4zIDEyNC45IEMgMTI0LjIgMTUxLjUgMTI0LjMgMTc4LjIgMTI0LjIgMjA0LjggQyAx'
    b'NDYuNyAxODYuNCAxNzUuMiAxNzUuOCAyMDQuMSAxNzQuMCBDIDIwMS45IDIwMy4wIDE5MC43'
    b'IDIzMS4xIDE3Mi44IDI1NC4wIEMgMTk5LjYgMjU0LjAgMjI2LjUgMjU0LjAgMjUzLjMgMjU0'
    b'LjAgQyAyMzguMSAyMzAuMCAyMjYuNyAyMDIuOSAyMjQuNCAxNzQuNCBDIDI1Mi41IDE3Ni45'
    b'IDI3OS42IDE4OC4yIDMwMi4wIDIwNS40IEMgMzAyLjAgMTc4LjUgMzAyLjAgMTUxLjcgMzAy'
    b'LjAgMTI0LjggQyAyNzguNiAxMzkuOCAyNTIuMiAxNTAuOCAyMjQuNCAxNTMuNyBDIDIyNy4y'
    b'IDEyNS45IDIzOC40IDk5LjcgMjUzLjIgNzYuMyBDIDIyNi43IDc2LjIgMjAwLjIgNzYuMiAx'
    b'NzMuNyA3Ni4zIFoiIC8+DQo8cGF0aCBmaWxsPSIjZmZmZmZmIiBzdHJva2U9IiNmZmZmZmYi'
    b'IHN0cm9rZS13aWR0aD0iMC4wOTM3NSIgb3BhY2l0eT0iMS4wMCIgZD0iIE0gMTczLjcgNzYu'
    b'MyBDIDIwMC4yIDc2LjIgMjI2LjcgNzYuMiAyNTMuMiA3Ni4zIEMgMjM4LjQgOTkuNyAyMjcu'
    b'MiAxMjUuOSAyMjQuNCAxNTMuNyBDIDI1Mi4yIDE1MC44IDI3OC42IDEzOS44IDMwMi4wIDEy'
    b'NC44IEMgMzAyLjAgMTUxLjcgMzAyLjAgMTc4LjUgMzAyLjAgMjA1LjQgQyAyNzkuNiAxODgu'
    b'MiAyNTIuNSAxNzYuOSAyMjQuNCAxNzQuNCBDIDIyNi43IDIwMi45IDIzOC4xIDIzMC4wIDI1'
    b'My4zIDI1NC4wIEMgMjI2LjUgMjU0LjAgMTk5LjYgMjU0LjAgMTcyLjggMjU0LjAgQyAxOTAu'
    b'NyAyMzEuMSAyMDEuOSAyMDMuMCAyMDQuMSAxNzQuMCBDIDE3NS4yIDE3NS44IDE0Ni43IDE4'
    b'Ni40IDEyNC4yIDIwNC44IEMgMTI0LjMgMTc4LjIgMTI0LjIgMTUxLjUgMTI0LjMgMTI0Ljkg'
    b'QyAxNDguMiAxNDAuNCAxNzUuNSAxNTEuNiAyMDQuMSAxNTQuMCBDIDIwMi4xIDEyNS44IDE5'
    b'MS4yIDk4LjQgMTczLjcgNzYuMyBaIiAvPg0KPHBhdGggZmlsbD0iIzVmMDAxMyIgc3Ryb2tl'
    b'PSIjNWYwMDEzIiBzdHJva2Utd2lkdGg9IjAuMDkzNzUiIG9wYWNpdHk9IjEuMDAiIGQ9IiBN'
    b'IDAuMCAyOTkuMCBDIDEyOC43IDI5OS4wIDI1Ny4zIDI5OS4wIDM4Ni4wIDI5OS4wIEwgMzg2'
    b'LjAgMzAwLjAgQyAzMDIuMyAzMDAuMyAyMTguNyAzMDAuMSAxMzUuMCAzMDAuMiBDIDkwLjAg'
    b'MzAwLjEgNDUuMCAzMDAuMyAwLjAgMzAwLjAgTCAwLjAgMjk5LjAgWiIgLz4NCjxwYXRoIGZp'
    b'bGw9IiM4MDgwODAiIHN0cm9rZT0iIzgwODA4MCIgc3Ryb2tlLXdpZHRoPSIwLjA5Mzc1IiBv'
    b'cGFjaXR5PSIxLjAwIiBkPSIgTSAwLjAgMzAwLjAgQyA0NS4wIDMwMC4zIDkwLjAgMzAwLjEg'
    b'MTM1LjAgMzAwLjIgQyAyMTguNyAzMDAuMSAzMDIuMyAzMDAuMyAzODYuMCAzMDAuMCBMIDM4'
    b'Ni4wIDMwMS4wIEMgMjk4LjMgMzAwLjcgMjEwLjcgMzAwLjkgMTIzLjAgMzAwLjkgQyA4Mi4w'
    b'IDMwMC45IDQxLjAgMzAwLjcgMC4wIDMwMS4wIEwgMC4wIDMwMC4wIFoiIC8+DQo8cGF0aCBm'
    b'aWxsPSIjZmZmZmZmIiBzdHJva2U9IiNmZmZmZmYiIHN0cm9rZS13aWR0aD0iMC4wOTM3NSIg'
    b'b3BhY2l0eT0iMS4wMCIgZD0iIE0gMC4wIDMwMS4wIEMgNDEuMCAzMDAuNyA4Mi4wIDMwMC45'
    b'IDEyMy4wIDMwMC45IEMgMjEwLjcgMzAwLjkgMjk4LjMgMzAwLjcgMzg2LjAgMzAxLjAgTCAz'
    b'ODYuMCAzMDIuMCBMIDAuMCAzMDIuMCBMIDAuMCAzMDEuMCBaIiAvPg0KPC9zdmc+DQo=', 'WF')

WF = b64_WF
index.append("WF")
index.append("WLF")
index.append("Wallis and Futuna Islands")
catalog["WF"] = WF
catalog["WLF"] = WF
catalog["Wallis and Futuna Islands"] = WF
country["Wallis and Futuna Islands"] = ('WF', 'WLF', 0)
lookup["WF"] = ('WF', 'WLF', 'Wallis and Futuna Islands', 0)
lookup["Mata Utu Wallis and Futuna Islands"] = ('WF', 'WLF', 'Wallis and Futuna Islands', 0)
lookup["WLF"] = ('WF', 'WLF', 'Wallis and Futuna Islands', 0)
lookup["Wallis and Futuna Islands"] = ('WF', 'WLF', 'Wallis and Futuna Islands', 0)
details["WF"] = {"continent":"Oceania","capital":"Mata Utu","currency":"CFP Franc","web":".wf","lang":"wls | fud | fr-WF","tz":"+12:00","altname":""}
#----------------------------------------------------------------------
b64_WS = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXdzIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNMCAwaDY0'
    b'MHY0ODBIMHoiLz4KICAgIDxwYXRoIGZpbGw9IiMwMDJiN2YiIGQ9Ik0wIDBoMzIwdjI0MEgw'
    b'eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0ibTE4MCAyMjkuMy0yMC43LTE0LTE5Ljkg'
    b'MTQuMSA2LjUtMjQuOS0xOS0xNS4yIDI0LjUtMS41IDguMS0yMy42IDguOCAyNCAyNCAuNy0x'
    b'OSAxNi4zem0tMy42LTE2NS42TDE1OS44IDUzbC0xNiAxMC40IDQuNC0yMC0xNC42LTEyLjcg'
    b'MTkuNC0xLjYgNy4yLTE4LjYgNy40IDE4LjcgMTkuMSAxLjdMMTcyIDQ0LjN6bS03MyA1OS41'
    b'LTE2LTExLTE2LjcgMTEgNS4yLTE5LjRMNjAuOCA5MSA4MCA5MGw3LTE5IDYuOCAxOC45IDE5'
    b'LjYgMS4xLTE1IDEyLjV6TTI1MCAxMTBsLTE1LjQtMTAtMTUgMTAgNC40LTE4LjMtMTQtMTEu'
    b'OCAxOC4zLTEuNSA2LjMtMTcuMiA3IDE3LjQgMTcuNyAxLTEzLjcgMTIuM3ptLTQzLjEgNDMu'
    b'NC0xMC4zLTYuNC0xMC4zIDYuNiAyLjctMTIuMy05LjItOC4zIDEyLTEgNC42LTExLjYgNC45'
    b'IDExLjYgMTEuOSAxLTkuMSA4LjN6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'WS')

WS = b64_WS
index.append("WS")
index.append("WSM")
index.append("Samoa")
catalog["WS"] = WS
catalog["WSM"] = WS
catalog["Samoa"] = WS
country["Samoa"] = ('WS', 'WSM', 0)
lookup["WS"] = ('WS', 'WSM', 'Samoa', 0)
lookup["Apia Samoa"] = ('WS', 'WSM', 'Samoa', 0)
lookup["WSM"] = ('WS', 'WSM', 'Samoa', 0)
lookup["Samoa"] = ('WS', 'WSM', 'Samoa', 0)
details["WS"] = {"continent":"Oceania","capital":"Apia","currency":"Tala","web":".ws","lang":"sm | en-WS","tz":"+13:00","altname":""}
#----------------------------------------------------------------------
b64_YE = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXllIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBz'
    b'dHJva2Utd2lkdGg9IjFwdCI+CiAgICA8cGF0aCBmaWxsPSIjZmZmIiBkPSJNMCAwaDY0MHY0'
    b'NzIuOEgweiIvPgogICAgPHBhdGggZmlsbD0iI2YxMDYwMCIgZD0iTTAgMGg2NDB2MTU3LjRI'
    b'MHoiLz4KICAgIDxwYXRoIGQ9Ik0wIDMyMi42aDY0MFY0ODBIMHoiLz4KICA8L2c+Cjwvc3Zn'
    b'Pgo=', 'YE')

YE = b64_YE
index.append("YE")
index.append("YEM")
index.append("Yemen")
catalog["YE"] = YE
catalog["YEM"] = YE
catalog["Yemen"] = YE
country["Yemen"] = ('YE', 'YEM', 0)
lookup["YE"] = ('YE', 'YEM', 'Yemen', 0)
lookup["Sanaa Yemen"] = ('YE', 'YEM', 'Yemen', 0)
lookup["YEM"] = ('YE', 'YEM', 'Yemen', 0)
lookup["Yemen"] = ('YE', 'YEM', 'Yemen', 0)
details["YE"] = {"continent":"Asia","capital":"Sanaa","currency":"Yemeni Rial","web":".ye","lang":"ar-YE","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_YT = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXl0IiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAg'
    b'MGg2NDB2NDgwSDB6Ii8+CiAgPHBhdGggZmlsbD0iIzAwMjY1NCIgZD0iTTAgMGgyMTMuM3Y0'
    b'ODBIMHoiLz4KICA8cGF0aCBmaWxsPSIjY2UxMTI2IiBkPSJNNDI2LjcgMEg2NDB2NDgwSDQy'
    b'Ni43eiIvPgo8L3N2Zz4K', 'YT')

YT = b64_YT
index.append("YT")
index.append("MYT")
index.append("Mayotte")
catalog["YT"] = YT
catalog["MYT"] = YT
catalog["Mayotte"] = YT
country["Mayotte"] = ('YT', 'MYT', 0)
lookup["YT"] = ('YT', 'MYT', 'Mayotte', 0)
lookup["Mamoudzou Mayotte"] = ('YT', 'MYT', 'Mayotte', 0)
lookup["MYT"] = ('YT', 'MYT', 'Mayotte', 0)
lookup["Mayotte"] = ('YT', 'MYT', 'Mayotte', 0)
details["YT"] = {"continent":"Africa","capital":"Mamoudzou","currency":"Euro","web":".yt","lang":"fr-YT","tz":"+03:00","altname":""}
#----------------------------------------------------------------------
b64_ZA = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXphIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InphLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTcxLjkgMGg2ODIu'
    b'N3Y1MTJILTcxLjl6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBjbGlwLXBh'
    b'dGg9InVybCgjemEtYSkiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDY3LjQpIHNjYWxlKC45Mzc0'
    b'OCkiPgogICAgPGcgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2Utd2lkdGg9IjFwdCI+CiAg'
    b'ICAgIDxwYXRoIGQ9Ik0tNzEuOSA0MDcuOFYxMDQuNEwxNTQgMjU2LjEtNzIgNDA3Ljh6Ii8+'
    b'CiAgICAgIDxwYXRoIGZpbGw9IiMwMDBjOGEiIGQ9Im04Mi4yIDUxMi4xIDI1My42LTE3MC42'
    b'SDY5NlY1MTJIODIuMnoiLz4KICAgICAgPHBhdGggZmlsbD0iI2UxMzkyZCIgZD0iTTY2IDBo'
    b'NjMwdjE3MC44SDMzNS43UzY5LjMtMS43IDY2IDB6Ii8+CiAgICAgIDxwYXRoIGZpbGw9IiNm'
    b'ZmI5MTUiIGQ9Ik0tNzEuOSA2NHY0MC40TDE1NCAyNTYtNzIgNDA3Ljh2NDAuM2wyODQuNS0x'
    b'OTJMLTcyIDY0eiIvPgogICAgICA8cGF0aCBmaWxsPSIjMDA3ODQ3IiBkPSJNLTcxLjkgNjRW'
    b'MGg5NWwzMDEuMiAyMDRoMzcxLjh2MTA0LjJIMzI0LjNMMjMgNTEyaC05NC45di02My45bDI4'
    b'NC40LTE5MkwtNzEuOCA2NHoiLz4KICAgICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTIzIDBo'
    b'NTkuMmwyNTMuNiAxNzAuN0g2OTZWMjA0SDMyNC4zTDIzIC4xem0wIDUxMi4xaDU5LjJsMjUz'
    b'LjYtMTcwLjZINjk2di0zMy4ySDMyNC4zTDIzIDUxMnoiLz4KICAgIDwvZz4KICA8L2c+Cjwv'
    b'c3ZnPgo=', 'ZA')

ZA = b64_ZA
index.append("ZA")
index.append("ZAF")
index.append("South Africa")
catalog["ZA"] = ZA
catalog["ZAF"] = ZA
catalog["South Africa"] = ZA
country["South Africa"] = ('ZA', 'ZAF', 0)
lookup["ZA"] = ('ZA', 'ZAF', 'South Africa', 0)
lookup["Pretoria South Africa"] = ('ZA', 'ZAF', 'South Africa', 0)
lookup["ZAF"] = ('ZA', 'ZAF', 'South Africa', 0)
lookup["South Africa"] = ('ZA', 'ZAF', 'South Africa', 0)
details["ZA"] = {"continent":"Africa","capital":"Pretoria","currency":"Rand","web":".za","lang":"zu | xh | af | nso | en-ZA | tn | st | ts | ss | ve | nr","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_ZM = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGlkPSJmbGFnLWljb25z'
    b'LXptIiB2aWV3Qm94PSIwIDAgNjQwIDQ4MCI+CiAgPGRlZnM+CiAgICA8Y2xpcFBhdGggaWQ9'
    b'InptLWEiPgogICAgICA8cGF0aCBmaWxsLW9wYWNpdHk9Ii43IiBkPSJNLTE3MC43IDBINTEy'
    b'djUxMmgtNjgyLjd6Ii8+CiAgICA8L2NsaXBQYXRoPgogIDwvZGVmcz4KICA8ZyBmaWxsLXJ1'
    b'bGU9ImV2ZW5vZGQiIGNsaXAtcGF0aD0idXJsKCN6bS1hKSIgdHJhbnNmb3JtPSJ0cmFuc2xh'
    b'dGUoMTYwKSBzY2FsZSguOTM3NSkiPgogICAgPHBhdGggZmlsbD0iIzE5OGEwMCIgZD0iTS0y'
    b'NTYgMGg3Njh2NTEyaC03Njh6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZWY3ZDAwIiBkPSJNNDIx'
    b'LjkgMTg0SDUxMnYzMjhoLTkwLjF6Ii8+CiAgICA8cGF0aCBkPSJNMzMxLjkgMTgzLjhoOTB2'
    b'MzI4aC05MHoiLz4KICAgIDxwYXRoIGZpbGw9IiNkZTIwMTAiIGQ9Ik0yNDAgMTg0aDkxLjl2'
    b'MzI4aC05MnoiLz4KICAgIDxnIGZpbGw9IiNlZjdkMDAiIHN0cm9rZT0iIzAwMCI+CiAgICAg'
    b'IDxwYXRoIHN0cm9rZS1saW5lam9pbj0icm91bmQiIGQ9Ik00NTEuNiA2NS42czM0LTE0LjUg'
    b'MzcuMi0xNy41YzEuNSAxLjgtMTMuNiAyMC00Mi45IDI2LjcgMjYuNi02LjIgNDkuMy0yNiA1'
    b'NC0yNS40IDEuMy4zIDEgMTkuMy02MCAzNS44IDQyLjItMTEgNjYuNy0zMS40IDY2LjQtMjku'
    b'Mi4zLjUtNC4yIDE2LTQxLjEgMjguMSAxMC4zLTIuNCAzOC4zLTE5LjQgMzgtMTYuMS45IDEu'
    b'My0yNyAzNy4yLTc3LjYgMjUuNSA0MC40IDEwLjUgNjYuNS0xNC44IDcwLjItMTQuMy44LjEt'
    b'Ny40IDIyLTU4LjIgMjMuNCAyNC4zLTIuNSAxNy4zLS4xIDE3LjMtLjFzLTE0LjMgMTEuMi0z'
    b'MS43IDMuNmMxMy42IDMuNyAxNS4xIDMuOSAxNS40IDUtLjkgMS42LTEyIDMuOC0yMi45LTIg'
    b'OC43IDMuNiAxNi41IDQuMiAxNi42IDUuNS0uMS40LTUuNiAzLjYtMTAuNiAxLjMtNC45LTIu'
    b'Mi01MC4zLTMwLjEtNTAuMy0zMC4xbDc3LjQtMjEuMyAyLjggMXptLTkxIDc1LjZjLTYuOCAw'
    b'LTcgNi03IDZzLS41LjUtLjIgMy40bDEuNy0yLjZjLjguMSAzLjkgMSA4LjgtMi44LTQuNSA0'
    b'LjctMS44IDYuNC0xLjggNi40cy0xIDMuNyAyLjQgNC40Yy0xLTEuNS0uNC0yLjgtLjQtMi44'
    b'czQuOC0uNSA0LjUtNi4zYy4xIDUuMyAzIDYuNiAzIDYuNnMwIDIuOSAzLjEgMy4yYy0xLjYt'
    b'MS41LTEuMy0zLjgtMS4zLTMuOHM0LTMgLjctOGMyLTEuMiAzLjctNC41IDMuNy00LjVzLTIu'
    b'OC0xLjItNC4xLTIuMmMtLjYtMS4zIDAtOC41IDAtOC41bC0xLjgtOS4zLTQuOCAxNC41Yy4y'
    b'LTIgLjMgNi4zLTYuNSA2LjN6Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lam9pbj0icm91'
    b'bmQiIGQ9Ik0zOTQuMiAxMjAuM2MuMi4xIDUuMSA1LjYgOS45IDUuMyAxLjgtMS41LTMuNy00'
    b'LjctMy43LTUuNSAyIDEuOCAxMC4xIDguOCAxNS40IDYuMyAyLTMtMy44LTIuNS0xMC4yLTEw'
    b'LjYgNC41IDMgMTUuNyA5LjUgMjEgNyAyLjEtMi40LTExLjctOS45LTE2LjQtMTUuN2wtMTIt'
    b'Ni4xLTE2LjIgMTMuMyAxMi4zIDZ6Ii8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJy'
    b'b3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgZD0iTTM3NS45IDc0LjhzNS41LTMuMiAy'
    b'Ny42LTEuNmMyLjQuMyAxNS00LjMgMTkuMS01LjcgNi40LTEuMiAyNy01LjYgMzIuNC05Ljgg'
    b'NC0uNS0xIDcuMS02IDktNS4yIDIuMy0yNC4xIDguOS0zMC45IDggOC4xLjEgMy42IDYuNy05'
    b'LjggMy42IDYuNCAzLjYgNCA0LjIgNCA0LjJzLTExLjMuNi0xNC4zLTJjNy42IDIuOSA0LjQg'
    b'NCA0LjQgNHMtNy43LjctMTEuMy0xYzUuNSAxLjcgMi43IDIuNyAyLjcgMi43cy00LjUuOC04'
    b'LjItLjZjLTMuOC0xLjMtOS40LTEwLjctOS43LTEwLjd6Ii8+CiAgICAgIDxwYXRoIHN0cm9r'
    b'ZS1saW5lam9pbj0icm91bmQiIGQ9Im0zODQuNyAxMjMuNC44IDE0LjYtLjggMS4yYy0uMy40'
    b'LTEwLjMtMS42LTkgNiAwIDMuMiAwIDQgMi4yIDUuNy0uNS0yLS40LTMuNS0uNC0zLjVzMi45'
    b'IDEuNyA1LjYtM2MtMS45IDQuNi0uNiA2LjMtLjEgNi40LjQuOC0uOCA0LjUgMyA0LjQtMS41'
    b'LTEuNC0uOC0zLjQtLjgtMy40czQtLjYgMi42LTcuN2MxLjQtMS40IDIgMCAyIDBzLjQgNC4y'
    b'IDMuOSAzLjNjMS41LjktLjMgMy4yLS4zIDMuMnMyLjUgMCAzLjMtMmMuNy0yLjIgMS42LTYt'
    b'Mi41LTcuNi0uNS0xLjUgMS42LTEuNiAxLjYtMS42czIuNi45IDMuNCAyLjIuNS0zLjQtMi44'
    b'LTRjLTQgMC00LjItLjktNC4yLTFsLTEtMTMuNy02LjUuNXoiLz4KICAgICAgPHBhdGggc3Ry'
    b'b2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIiBzdHJva2Utd2lk'
    b'dGg9IjEuMSIgZD0iTTM5OC42IDEzNS44YzAtLjctNi44LTkuOS01LTExIDEuNy4zIDQuNSA0'
    b'LjUgNi45IDMuMS0uNy0xLjYtMi44LS43LTUuMS00LjktMi40LTQuOC0yLjctMTEuOS0xMS0x'
    b'OS42IDUuNCA4LjIgMTcuNCAxMyAxOCAxMC42cy0xMC43LTExLjQtMTAuMS0xMy42YzIuMiA0'
    b'LjQgMTMuNCAxNC40IDIxLjYgMTMuNi42LTItNi43LTUuOC04LjYtOS40LTUuMy0zLjYtMTku'
    b'NC0xNS43LTE5LjYtMTguNWEzMy4zIDMzLjMgMCAwIDAtOS45LTEwLjYgNSA1IDAgMCAxLS44'
    b'LTEuN2MtMy4yLTcuNSAxLTEwIDMuNS0xMC4zIDItLjMgMi42IDAgNC0uN2wtNS4xLTJjMi4z'
    b'IDEuNyA4IC4yIDYuOCA1IDIuNS0xIDcuOS03LjQtNi4xLTguOC00LjYtNS4yLTIzLjMtOC4y'
    b'LTI4IDE0LjYuNC4zLjYuNiAxLjggMS40LTYtMi44LTIxLjktNS0yNy42LTYtMTUuNi00LjQt'
    b'MzEuNy0xNS4yLTMzLjItMTMuOS0yIDEgOS40IDExLjYgOC44IDExLjhhMjYzIDI2MyAwIDAg'
    b'MC0yNy41LTEzLjZjLTYtMi4yLTExLjktNy40LTEyLjUtNi40LTIuMiA0LjUgOS41IDE1Ljkg'
    b'MTEuNyAxNy4yIDIuMiAxLjMgMTkuMyA5LjMgMTkgOS40LTI1LjgtMTEuNy0zMC0xMy45LTMx'
    b'LjQtMTUuMi0yLjMtLjUtNy44LTgtOS4zLTcuNS0uOS44LjggMTIuNiAxMy4xIDE4IDIgMS40'
    b'IDI2LjQgMTAuMSAyNi4yIDEwLjggMCAuMi0yOC0xMS41LTI5LTEyLTUuNC0yLTEyLTkuNC0x'
    b'My4yLTguNi0xLjIuOCAzIDguOCA4LjQgMTEuMyAyLjkgMS4yIDEzLjggNi42IDIzLjYgMTAg'
    b'LjYuMy0xNy43LTYuOS0yNi41LTEwLjUtNC0yLjItNS44LTUtNi40LTQuNC0xIC42IDEuNCAx'
    b'Mi40IDI5LjcgMTkgLjcuNCAxMC0yLjEgOS41LTEuOGExMTMuMyAxMTMuMyAwIDAgMS0xNS44'
    b'IDIuOGMtLjMuOCAxLjggNSAxNi40IDQuMiAxLjgtLjEgMTItMy43IDExLjEtM2ExNzQgMTc0'
    b'IDAgMCAxLTE0LjggNC45Yy0uOSAwLTUuNi42LTUuOCAxLS4yLjggMy41IDMuOCAxMS4zIDQu'
    b'MiA3IC40IDIwLjItNC4yIDIwLTMuOS0uNC4zLTEyLjggNC42LTEzLjEgNC44LS41LjMtNSAu'
    b'NS01LjIuOS0uNC45IDYuNiA3LjQgMjcuMS40LTIgMi44LTEyIDQuNy0xMiA1LjIgMCAuNCAy'
    b'LjIgMi41IDUuNyAzLjMgMS43LjQgNC4xLjMgNi4zIDAgNC0uOCA4LTIuMyAxMy4zLTcuMi42'
    b'IDEuNS0xMy4xIDguNS0xMi41IDkuMSAzIDIuOCAxMi45LS4zIDEzLjUtLjcuNy0uMyAxOS0x'
    b'MC43IDE5LTEyIC4zIDEuNi0yMy43IDE0LjctMjMuNCAxNS4yIDEuNSAyLjQgOS43LS4xIDEw'
    b'LS40bDEwLjgtNS44Yy4zLS4xLTExLjggNy0xMC44IDguMi0uNSA0LjcgMTktMy4yIDIwLjUt'
    b'NC4yLjctLjUtOS40IDQuNC05LjQgNi43IDMuMyA1LjUgMTMuNyAzLjggMTUuMyAyLjYuOC0u'
    b'Ni0xIDQtLjQgMy42YTE2IDE2IDAgMCAwIDMtNC4zYy0uMiAxLjYtMS40IDQtMiA2LjgtLjcg'
    b'Mi43LS45IDUuOS0xLjggOS4yLS4yIDEuNCA2LjQtMi45IDUuNC0xMy4yLjYgNS40LTIgMTUu'
    b'NC0xLjMgMTYgMS4zIDEgNS4yLTUgNS42LTkuMSAxLjEgMiAzLjUgNi4zIDUuNiA3LjMtLjIt'
    b'My4xIDAtMy0xLTYgLjYtNC4xLjctOS43LjgtMTYuMSA1LjYgMTAuNyA3LjkgMTUuMyA2LjMg'
    b'MjMuNSAxLjcuNyA0LjMtNS44IDQuMS05YTEzLjMgMTMuMyAwIDAgMCAxMS41IDEwLjJ6Ii8+'
    b'CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJy'
    b'b3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0zMDUuNCA2Ny43cy0zLjkgMi45LTguNiAy'
    b'LjdjMS4yIDQuOCAxMSAxLjEgMTEgMS4xcy00LjcgNS4zLTguMSA2LjFjMiAxLjcgMTAuNiAx'
    b'LjEgMTIgLjMgMS40LS45IDQtNC4yIDQtNC4ycy04LjggMTAuMi0xMCAxMC4xYy0uMyAxLjIg'
    b'OS4xLjggMTEtMSAyLTEuOCA3LTQuNCA3LTQuNHMtMTMgOS0xMy41IDljNC44IDEuMiAxNC41'
    b'LTEuNiAyMC43LTUuNC05LjIgNi4xLTEwIDcuMi0xNC43IDkuMyA0LjIuOSA2LjMgMy43IDIw'
    b'LjMtMi40IDgtMy44IDEyLjYtMTAuOCAxMi42LTEwLjhhODEuNyA4MS43IDAgMCAxLTIxLjYg'
    b'MThjLS41IDEgOS40IDUuMiAyMS45LTcuOSIvPgogICAgICA8cGF0aCBzdHJva2UtbGluZWNh'
    b'cD0icm91bmQiIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJNMzczLjQgOTZzLjkgNCA0LjMgNyAz'
    b'LjYgNiAzLjYgNm0tOS41LTM5czEuMSAzLjcgNC42IDZjMy42IDIuMiA5IDkuNCA5LjMgMTAu'
    b'Ny40IDEuNSAyLjUgMTIuNiAyLjMgMTMuOG0tMzcuOC0yNWMuMiAxLjUtNSA4LjMgMi4yIDE2'
    b'LjQtNi42IDgtNi42IDktNi42IDlzMy43IDIgMTAuMi0zLjZjMTAuOCAxMy4yIDcuMiAxOS4y'
    b'IDcuMiAxOS4yIi8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tl'
    b'LWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tlLXdpZHRoPSIxLjEiIGQ9Ik0zNjIuMyAxMDcuMnMt'
    b'MS0xLjQuOC02LjdjMS42IDIgMy40IDIuMyA0LjEgMyAuOC45IDkgMiA5LjQgNy41Ii8+CiAg'
    b'ICAgIDxwYXRoIHN0cm9rZS13aWR0aD0iMS4xIiBkPSJNMzcxLjkgNTcuNWMwLS40LTEuNy00'
    b'LTcuOC40IDMuMy4yIDYuNSAyLjEgNy44LS40eiIvPgogICAgICA8cGF0aCBzdHJva2UtbGlu'
    b'ZWpvaW49InJvdW5kIiBzdHJva2Utd2lkdGg9IjEuMSIgZD0iTTQzMC4xIDczLjVjLjMuMiAx'
    b'OC4yIDQgMjQuMiAyLjEtNy42IDEwLjItMjIuOSAzLjMtMjIuOSAzLjMgNy41IDIuMiA3Ljgg'
    b'MiAxMC4yIDQuMi44IDItMTMuOCAxLTE4LjUtMS43IDEzLjMgNC4yIDEzLjYgNCAxNCA1LjUu'
    b'NiAyLjMtMjEuOC0uNi0yMy43LTMuNSA2IDQuNiA5LjIgNS41IDEyLjUgNy42LTQgMS44LTEx'
    b'LjUgMy42LTI1LjItNi4xIDE4IDE2LjQgMzQuMyAxNS40IDM2LjkgMTguMy02LjMgOS4zLTMw'
    b'LjctNS41LTQxLjktMTNzMjQuNSAxOC4xIDI3LjggMTcuN2MtMS42IDIuNS0xMy40LjMtMTQu'
    b'Mi0xIi8+CiAgICAgIDxwYXRoIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLXdpZHRo'
    b'PSIxLjEiIGQ9Ik00MzQuNyA5MC43Yy0yIC4zLTguMy4zLTkuMi4xIi8+CiAgICAgIDxwYXRo'
    b'IHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIgc3Ryb2tl'
    b'LXdpZHRoPSIxLjEiIGQ9Ik0zMDAuMSA2NXMxMy42IDcuMiAxOS40IDYuN2ExMCAxMCAwIDAg'
    b'MS0zLjggMmMxLjQuNiA1LjQgMi43IDExLjQgMS40bC0zLjMgM3M1LjIgMiAxMS0xYTQ2LjQg'
    b'NDYuNCAwIDAgMC0yLjggMy43bDQuMS4zIi8+CiAgICA8L2c+CiAgPC9nPgo8L3N2Zz4K', 'ZM')

ZM = b64_ZM
index.append("ZM")
index.append("ZMB")
index.append("Zambia")
catalog["ZM"] = ZM
catalog["ZMB"] = ZM
catalog["Zambia"] = ZM
country["Zambia"] = ('ZM', 'ZMB', 0)
lookup["ZM"] = ('ZM', 'ZMB', 'Zambia', 0)
lookup["Lusaka Zambia"] = ('ZM', 'ZMB', 'Zambia', 0)
lookup["ZMB"] = ('ZM', 'ZMB', 'Zambia', 0)
lookup["Zambia"] = ('ZM', 'ZMB', 'Zambia', 0)
details["ZM"] = {"continent":"Africa","capital":"Lusaka","currency":"Zambian Kwacha","web":".zm","lang":"en-ZM | bem | loz | lun | lue | ny | toi","tz":"+02:00","altname":""}
#----------------------------------------------------------------------
b64_ZW = EmbeddedSvgImage(
    b'PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJo'
    b'dHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiBpZD0iZmxhZy1pY29ucy16dyIgdmlld0Jv'
    b'eD0iMCAwIDY0MCA0ODAiPgogIDxkZWZzPgogICAgPGNsaXBQYXRoIGlkPSJ6dy1hIj4KICAg'
    b'ICAgPHJlY3Qgd2lkdGg9IjU0NiIgaGVpZ2h0PSI0MjAuMSIgeD0iMS45IiB5PSIuMSIgZmls'
    b'bD0iIzAwZiIgZmlsbC1ydWxlPSJldmVub2RkIiByeT0iMCIvPgogICAgPC9jbGlwUGF0aD4K'
    b'ICA8L2RlZnM+CiAgPGcgY2xpcC1wYXRoPSJ1cmwoI3p3LWEpIiB0cmFuc2Zvcm09Im1hdHJp'
    b'eCgxLjE3MjIgMCAwIDEuMTQyNiAtMi4zIC0uMSkiPgogICAgPHBhdGggZmlsbD0iIzAwNjQw'
    b'MCIgZD0iTTAgMGg4NDB2NDIwSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZmZkMjAwIiBkPSJN'
    b'MCA2MGg4NDB2MzAwSDB6Ii8+CiAgICA8cGF0aCBmaWxsPSIjZDQwMDAwIiBkPSJNMCAxMjBo'
    b'ODQwdjE4MEgweiIvPgogICAgPHBhdGggZD0iTTAgMTgwaDg0MHY2MEgweiIvPgogICAgPHBh'
    b'dGggc3Ryb2tlPSIjMDAwIiBzdHJva2Utd2lkdGg9IjIwIiBkPSJNMCAwdjQyMGwyODAtMjEw'
    b'eiIvPgogICAgPHBhdGggZmlsbD0iI2ZmZiIgZD0iTTAgMHY0MjBsMjgwLTIxMHoiLz4KICAg'
    b'IDxwYXRoIGZpbGw9IiNkNDAwMDAiIGQ9Ik0xMDYuNSAxMDQuNCAxNjIgMjc1LjEgMTYuOCAx'
    b'NjkuNmgxNzkuNUw1MSAyNzUuMXoiLz4KICAgIDxwYXRoIGZpbGw9IiNmYzAiIGQ9Im04Mi44'
    b'IDI1My43IDkuOC0xLjggMTguMS0uNyA2LjcuNiAxNSAyLjUgMS4xLTEuNVYyNDJsMS44LTku'
    b'MyAzLTkuNCAzLjMtNy41IDQuMi03LjggNi44IDEuN2gxLjhsLjItMS4zLTE0LjQtMTIuMy0x'
    b'NS0xMS41LTIxLjctMTYuMi0yLS41LTIuMy0xNy0xLjctNS4xLTIuMy0yLTQuMy0xLjQtNC44'
    b'LjItMi4yIDEuMi00LjYgMS0yLjQuNC0xLjYgMS45LS4yIDIuNCA2LjcuMiAxLjcuNy0uMi43'
    b'LTMuOC41LTEuOC42IDIuMSAxLjYgMi4yLjggMi44IDEgLjYgMiAuMiAyNS44LTEuNSA0LS41'
    b'IDcuNSAyLjIgOS01LjYgNi40TDc3IDIxNmwtLjYgMy41LTEuNyAzLjUtLjIgMi4yIDEuMSAy'
    b'LjQgNC4zIDE0LjIgMi4yIDExLjd6Ii8+CiAgICA8cGF0aCBkPSJNODggMTQyYy0xLjggMC0y'
    b'LjYuMi00LjMgMS4xYTEwLjggMTAuOCAwIDAgMS00LjYgMS40Yy0yLjUgMC00LjUgMS44LTQu'
    b'NSA0LjF2MS41bDMuNi0uMWMxMC42LjMgMSAxLjMuMiAxLjQtMi42LjUuNiAyLjYgMy43IDMu'
    b'NyAzLjMgMSAzLjEuNCAzLjEgMTUgMCAxMS45IDAgMTMuNi0xIDE2LjMtMS4zIDQtMS4zIDEw'
    b'IDAgMTQgLjYgMS42IDEgMyAxIDMuMyAwIC4yLTEuNiAyLjEtMy41IDQuMy0zLjUgNC01LjYg'
    b'OC4xLTUuNiAxMWE2IDYgMCAwIDEtMSAyLjZjLTEuMyAxLjctMS4zIDQuNi0uMSA1LjcgMS4z'
    b'IDEuMiA2LjYgMjEuOCA2LjcgMjUuNyAwIDEuNC4yIDEuNCA4LjMtLjIgNi42LTEuMyAyMi4x'
    b'LTEuNiAzMC0uNiAzLjYuNSA3LjggMS4zIDkuMyAxLjYgNC44IDEuMyA0LjYgMS41IDQuNi00'
    b'LjNhNzQgNzQgMCAwIDEgNS4xLTI2LjcgOTQuNyA5NC43IDAgMCAxIDYuOS0xNHMxLjguMiA0'
    b'IC44YzQuMSAxIDUuMy45IDUuMy0xIDAtMS00LjMtNC42LTI1LjQtMjFhNDMyLjIgNDMyLjIg'
    b'MCAwIDAtMjYuMy0xOS45Yy0uNiAwLTEuMi0uMy0xLjMtLjdsLTEuNS05LjVjLS43LTQuOS0x'
    b'LjctOS43LTIuMS0xMC43LTEuNC0zLTQuMS00LjUtOC42LTQuOGEzMS4yIDMxLjIgMCAwIDAt'
    b'MiAwem0uMSAxaDJjNi42LjQgNy44IDIuMiA5LjYgMTRhMTczIDE3MyAwIDAgMSAxLjIgOS40'
    b'YzAgLjgtLjkgMS44LTMuMiAzLjNhNDYuOCA0Ni44IDAgMCAwLTEwIDkuNWwtMS4zIDEuOC0u'
    b'My00LjJWMTY1Yy4zLTguNyAwLTkuNS0yLjgtMTAuNS0yLjMtLjgtNS4zLTEuNi00LjUtMi4x'
    b'IDEtLjYgMi0uMiA0LjQtLjkgMS0uMi45LS4xLjctLjktLjItMS4zLTEuNi0yLTUuMy0xLjgt'
    b'MyAuMi0zLjMuMS0zLjEtLjcuNC0xLjYgMi0yLjYgNC41LTIuOWExMy40IDEzLjQgMCAwIDAg'
    b'NC40LTEuMyA3IDcgMCAwIDEgMy43LTF6bTE0LjkgMjUuOGguNGMxLjcuMyA1MC44IDM4Ljcg'
    b'NTAuOCAzOS44IDAgLjQtLjQuNy0xIC43LS40IDAtMTIuOS0zLjUtMjcuNy03LjgtMjMuNi03'
    b'LTI3LTgtMjgtOS4zYTUuMSA1LjEgMCAwIDEtLjEtNi4yIDUgNSAwIDAgMCAxLTJjMC0xLjIt'
    b'Mi41IDEuOC0zIDMuNS0uNSAyIC41IDUuNCAyIDYuNS42LjUgNS4xIDIgMTAgMy41IDguNCAy'
    b'LjQgOSAyLjcgOS40IDQuMSAxIDMuMy0yLjUgNy4yLTcuNSA4LjNhMTQuNiAxNC42IDAgMCAw'
    b'LTUuMiAyLjQgNjguMiA2OC4yIDAgMCAxLTE3LjIgMTAuNGMtLjQuMy0uOSAxLjktMS4yIDMu'
    b'NC0uNiAzLjMtLjggMy44LTEuOCAzLjgtLjUgMC0uNi0uMy0uMi0xLjQuNy0yIC42LTQuNC0u'
    b'MS00LjQtLjUgMC0uNy43LS43IDEuOCAwIDEtLjMgMi4yLS43IDIuNS0uNS42LS42LjItLjQt'
    b'Mi4zLjItMS43LjEtMy0uMS0zLS41IDAtMS40IDIuNS0xLjcgNC43LS4yIDEuMy0uMiAxLjMt'
    b'LjYtLjMtLjMtMS4yLS4yLTIgLjctMy41YTkgOSAwIDAgMCAxLTMuNWMwLTEuMyAxLTIuNiA1'
    b'LjctNy4zIDMtMy4xIDYuNy03IDgtOC43IDIuMy0yLjggMi40LTMgMi4zLTUuOSAwLTEuNi0u'
    b'Mi0zLjEtLjQtMy4zLS42LS42LTEuNCAyLjYtMSA0LjMuMiAxLjYgMCAyLjEtMy4zIDZhMTEz'
    b'LjIgMTEzLjIgMCAwIDEtNy41IDcuOGMtMy45IDMuNi01LjMgNS42LTUuMyA3LjQgMCAuNi0u'
    b'NCAyLTEgMy4zcy0uOCAyLjYtLjYgMi45Yy4yLjMgMCAuMy0uMyAwLS41LS41LS41LTEuMy0u'
    b'MS0zYTcgNyAwIDAgMCAuMi0yLjZjLS41LTEtMS4yLjItMS41IDIuNy0uMiAxLjQtLjUgMi41'
    b'LS44IDIuMy0uNy0uNC0uNS0zIC40LTQuNC41LS43IDEtMi4zIDEuMy0zLjYuNy0zLjcgMi4z'
    b'LTYuNyA1LjgtMTAuN2E1Ny41IDU3LjUgMCAwIDAgMy4yLTMuOGwtMS0zLjNhMjUgMjUgMCAw'
    b'IDEtLjItMTMuN2MxLjMtMy44IDMuOS03LjYgOC0xMS43IDQtMy45IDcuOS02LjMgMTAtNi40'
    b'em0xNSAzMi4yYS45LjYgMCAwIDEgMSAuNi45LjYgMCAwIDEtMS43IDAgLjkuNiAwIDAgMSAu'
    b'Ny0uNnptMi41LjNhLjkuNiAwIDAgMSAxIC42LjkuNiAwIDAgMS0xLjcgMCAuOS42IDAgMCAx'
    b'IC43LS42em0yLjYuNWEuOS42IDAgMCAxIDEgLjYuOS42IDAgMCAxLTEuNyAwIC45LjYgMCAw'
    b'IDEgLjctLjZ6bTIuNC41YS45LjYgMCAwIDEgMSAuNi45LjYgMCAwIDEtMS43IDAgLjkuNiAw'
    b'IDAgMSAuNy0uNnptLTYuMy42YS45LjYgMCAwIDEgMSAuNi45LjYgMCAwIDEtMS43IDAgLjku'
    b'NiAwIDAgMSAuNy0uNnptMi40LjRhLjkuNiAwIDAgMSAxIC42LjkuNiAwIDAgMS0xLjcgMCAu'
    b'OS42IDAgMCAxIC43LS42em01LjIuMmEuOS42IDAgMCAxIDEgLjYuOS42IDAgMCAxLTEuNyAw'
    b'IC45LjYgMCAwIDEgLjctLjZ6bS0yLjcgMGEuOS42IDAgMCAxIDEgLjYuOS42IDAgMCAxLTEu'
    b'NyAwIC45LjYgMCAwIDEgLjctLjZ6bTUgLjZjLjEgMCAzLjcuOCA4IDJsNy45IDIuMy0xLjUg'
    b'Mi43YTk2LjIgOTYuMiAwIDAgMC0yLjQgNC40Yy0xIDItMS4yIDItNiAuOS01LjItMS4yLTEz'
    b'LjQtMi4zLTIxLjgtM2wtOC0uNyAzLTEuMWE1MC40IDUwLjQgMCAwIDAgNS4zLTIuNGMyLTEu'
    b'MSAyLjgtMS4zIDUuOS0xIDQuNS4zIDcuNS0uNiA4LjctMi40bDEtMS43em0tOC44LjZhLjku'
    b'NiAwIDAgMSAxIC42LjkuNiAwIDAgMS0xLjcgMCAuOS42IDAgMCAxIC43LS42em01LjYgMGEu'
    b'OS42IDAgMCAxIDEgLjYuOS42IDAgMCAxLTEuNiAwIC45LjYgMCAwIDEgLjctLjZ6bS04IDBh'
    b'LjkuNiAwIDAgMSAxIC42LjkuNiAwIDAgMS0xLjcgMCAuOS42IDAgMCAxIC43LS41em01LjMu'
    b'MmEuOS42IDAgMCAxIDEgLjUuOS42IDAgMCAxLTEuNyAwIC45LjYgMCAwIDEgLjctLjV6bS02'
    b'LjYgMS4xYS45LjYgMCAwIDEgMSAuNi45LjYgMCAwIDEtMS43IDAgLjkuNiAwIDAgMSAuNy0u'
    b'NnptMi41IDBhLjkuNiAwIDAgMSAxIC43LjkuNiAwIDAgMS0xLjcgMCAuOS42IDAgMCAxIC43'
    b'LS42em0yLjYuMmEuOS42IDAgMCAxIDEgLjUuOS42IDAgMCAxLTEuNyAwIC45LjYgMCAwIDEg'
    b'LjctLjV6bTIuOCAwYS45LjYgMCAwIDEgMSAuNi45LjYgMCAwIDEtMS43IDAgLjkuNiAwIDAg'
    b'MSAuNy0uNnptLTIwLjMgOC4xYTE5MS4yIDE5MS4yIDAgMCAxIDM1LjEgNC4yYy4xLjEtLjYg'
    b'Mi41LTEuNyA1LjRsLTIgNmMtLjEuNS0uOC41LTIuNS4zLTguMy0xLjMtMzIuMy0xLjItNDEu'
    b'NS4yLTUuMy44LTYgLjctNS42LS40bDEtMy41LjYtMi43TDkzIDIyMWE2My40IDYzLjQgMCAw'
    b'IDAgMTAuMi02LjVoLjl6bS0yNyAxNC4yYy4zIDAgLjkuMyAxLjYuOCAxIC42IDIuMiAxLjEg'
    b'Mi43IDEuMSAyLjYgMCA0IDMuNyA2LjIgMTZsLjggNC40Yy4yIDEgMCAxLjItMi4zIDEuNy0y'
    b'LjguNi0zLjUuNy0zLjUuMyAwLTEtMi44LTEzLjctNC0xOC4yYTk2LjkgOTYuOSAwIDAgMS0x'
    b'LjYtNiAuMS4xIDAgMCAxIC4xIDB6bTI4LjYgMmgyLjlsLTEgMWMtMS43IDItMi41IDIuMS0z'
    b'LjcuOGE1IDUgMCAwIDEtMS0xLjVjMC0uMiAxLjMtLjQgMi44LS40em02LjEgMGg1LjRsLTEu'
    b'MiAxLjJjLTEuNCAxLjYtMS41IDEuNi0zIDBsLTEuMi0xLjN6bTguMiAwaDEuM2MuNyAwIDIg'
    b'MCAyLjguMmwxLjUuMy0xLjQgMS4zYy0uOC43LTEuNSAxLjMtMS42IDEuMmwtMS40LTEuNi0x'
    b'LjItMS41em04LjUuMyAxLjIuM2MuNy4yIDIuMi4zIDMuMy40aDJsLTEuNSAxLjNhOC45IDgu'
    b'OSAwIDAgMS0xLjggMS4zYy0uMSAwLTEtLjgtMS43LTEuN2wtMS41LTEuNnptLTMwLjIuMWgu'
    b'MmMuMS4yLS4zIDEtMSAxLjdsLTEgMS40LTEuNS0xLjItMS41LTEuMyAyLjQtLjMgMi40LS4z'
    b'em0yLjMuMiAxLjYgMS40IDEuNiAxLjUtMyAuMi0zIC4xIDEuNC0xLjUgMS40LTEuN3ptMTgg'
    b'MGMuMyAwIC41LjEuOC4zYTYuNiA2LjYgMCAwIDEgMS4zIDEuN2MuNC44LjMgMS0xIDFsLTIu'
    b'NS0uNS0xLjItLjMgMS4zLTEuM2MuNi0uNiAxLTEgMS40LTF6bS04LjMgMGMuNSAwIDEgLjMg'
    b'MS42IDEuMy43IDEuMS43IDEuMS0yIDEuMWgtMi43bDEuNC0xLjNjLjctLjcgMS4zLTEgMS43'
    b'LTF6bTE3IC4yIDEuMiAxLjJjMS40IDEuMyAxLjYgMi4xLjYgMmwtMi44LS4zLTIuMi0uMiAx'
    b'LjYtMS4zIDEuNi0xLjR6bS0zNS4yLjdjLjIgMCAxIC41IDEuNiAxLjJsMS4yIDEuMy0yLjUu'
    b'NC0zLjUuNWMtLjcuMi0uNS0uMyAxLTEuNiAxLTEgMi0xLjggMi4yLTEuOHptLTMuNyAwaC40'
    b'Yy44LjIuOC40LS42IDEuOGwtMS41IDEuNS0uNS0xLjNjLS40LTEtLjMtMS4zLjYtMS43YTQu'
    b'OCA0LjggMCAwIDEgMS42LS4zem00NiAxLjhjLjIgMCAuMi4yIDAgLjYtLjIuOC0xLjEgMS0x'
    b'LjEuMiAwLS4yLjMtLjUuNy0uN2guM3ptLTIxLjQgMS42YzcuNyAwIDE1LjUuMiAxNy40LjQg'
    b'My4xLjQgMy40LjUgMy40IDEuNyAwIDEuNC0uNCAxLjUtNC42LjgtMS4yLS4zLTYuMy0uNy0x'
    b'MS4yLTEuMWExNDkuNiAxNDkuNiAwIDAgMC0yOC41IDFjLTEuOS4yLTIuNCAwLTIuNC0uNiAw'
    b'LTEuMyAxMC4yLTIuMiAyNS45LTIuMnptLTEwLjMgMi45aDUuNGwtMS4yIDEuM2MtMS41IDEu'
    b'Ni0xLjYgMS42LTMgMGwtMS4yLTEuM3ptNyAwIDEuNCAxLjQgMS40IDEuNi0yLjkuMWgtMi45'
    b'bDEuNS0xLjYgMS40LTEuNXptMi4xIDBoNS40bC0xLjIgMS4zYy0xLjQgMS42LTEuNSAxLjYt'
    b'MyAwbC0xLjItMS4zem0tMTIuOCAwYy4yIDAgMCAuNS0uNyAxLjUtLjcuOS0xLjQgMS42LTEu'
    b'NSAxLjYtLjIgMC0uOS0uNi0xLjUtMS4zbC0xLjItMS4zSDk2YTkgOSAwIDAgMCAyLjctLjQg'
    b'MSAxIDAgMCAxIC40IDB6bTIgLjUgMS4zIDEuMiAxLjUgMS4zLTIuNi4yLTIuOS4yIDEuNC0x'
    b'LjUgMS4zLTEuNHptMTcuNCAwIDEuNCAxLjZjMS42IDEuNyAxLjUgMS44LTIuMSAxLjFsLTEu'
    b'Ny0uMyAxLjItMS4yIDEuMi0xLjJ6bTIgMGgyLjRjMi42IDAgMi45LjQgMS40IDEuOC0xLjIg'
    b'MS0xLjIgMS0yLjYtLjVsLTEuMi0xLjN6bS0zMC42LjVjMS4yIDAgMS4xLjEtLjQgMS42LTEu'
    b'MSAxLjEtMS4yIDEuMS0xLjYuMy0uMy0xIC42LTEuOCAyLTEuOXptMzguOC4yYy40IDAgMS4y'
    b'IDAgMiAuMmwyLjMuNC0xLjMgMS4yLTEuMiAxLjItMS4xLTEuNC0xLTEuNmguM3ptLTM2IC41'
    b'Yy4zIDAgLjYuMiAxLjEuNyAxIDEgMSAxIC4yIDEuNGE4IDggMCAwIDEtMi40LjRIOTBsMS4z'
    b'LTEuNGMuNy0uNyAxLTEgMS4zLTEuMXptMzQuMS4zYy40IDAgLjcuMiAxLjIgMWwuOSAxLjJo'
    b'LTIuMWMtMS40IDAtMi0uMi0yLS42LjItLjQuNy0xIDEuMy0xLjNsLjctLjN6bTYuNCAxLjNj'
    b'LjIgMCAuMi4yLjIuNSAwIDEtLjkgMS43LTEuMyAxLS4xLS4zLjEtLjguNS0xLjFsLjYtLjR6'
    b'bS0yNS45IDEuMmM4LjcgMCAxOC4zLjYgMjQgMS42bDEuNi4zdjQuNGMwIDMuMy0uMiA0LjQt'
    b'LjcgNC40bC01LTFhMTI2IDEyNiAwIDAgMC0zNS0xbC0yLjMuMy0uNi0zLjdhMjEgMjEgMCAw'
    b'IDEtLjQtMy44czIuMy0uNSA1LS44YzMuMy0uNSA4LjItLjcgMTMuNC0uN3oiLz4KICAgIDxw'
    b'YXRoIGlkPSJ6dy1iIiBkPSJNMTI0LjggMjE3LjhjLTMgMC01LjEgMi4xLTUuMSA1LjIgMCA0'
    b'LjggNS40IDcuMiA4LjYgMy44czEtOS0zLjUtOXptMCAxLjJhNCA0IDAgMCAxIDQgNGMwIDMt'
    b'My4zIDUtNiAzLjctMi43LTEuNS0yLjUtNi4xLjQtNy4zYTQuMyA0LjMgMCAwIDEgMS41LS40'
    b'eiIvPgogICAgPHVzZSB4bGluazpocmVmPSIjenctYiIgd2lkdGg9IjEwMCUiIGhlaWdodD0i'
    b'MTAwJSIgeD0iLTIwLjEiIHk9Ii0uNiIvPgogICAgPHBhdGggZD0iTTg4IDE0NS4zYTEuNyAx'
    b'LjggMCAwIDAtMS42IDEuNyAxLjcgMS44IDAgMSAwIDMuNSAwIDEuNyAxLjggMCAwIDAtMS45'
    b'LTEuN3ptLjEuNmExLjIgMS4xIDAgMCAxIDEuMiAxLjEgMS4yIDEuMSAwIDEgMS0yLjQgMCAx'
    b'LjIgMS4xIDAgMCAxIDEuMi0xLjF6Ii8+CiAgPC9nPgo8L3N2Zz4K', 'ZW')

ZW = b64_ZW
index.append("ZW")
index.append("ZWE")
index.append("Zimbabwe")
catalog["ZW"] = ZW
catalog["ZWE"] = ZW
catalog["Zimbabwe"] = ZW
country["Zimbabwe"] = ('ZW', 'ZWE', 0)
lookup["ZW"] = ('ZW', 'ZWE', 'Zimbabwe', 0)
lookup["Harare Zimbabwe"] = ('ZW', 'ZWE', 'Zimbabwe', 0)
lookup["ZWE"] = ('ZW', 'ZWE', 'Zimbabwe', 0)
lookup["Zimbabwe"] = ('ZW', 'ZWE', 'Zimbabwe', 0)
details["ZW"] = {"continent":"Africa","capital":"Harare","currency":"Zimbabwe Dollar","web":".zw","lang":"en-ZW | sn | nr | nd","tz":"+02:00","altname":""}


#
#----------- Additional Functions -----------#
#

Regional_Entries = [i for i in country.values() if i[-1]]
Regional_Names = [k for k,v in country.items() if v[-1]]
Country_Entries = [i for i in country.values() if not i[-1]]
Country_Names = [k for k,v in country.items() if not v[-1]]

def lookupiso2(val):
    try:
        iso2, _, _, _ = lookup.get(val)
        return iso2
    except Exception:
        return None

def lookupiso3(val):
    try:
        _, iso3, _, _ = lookup.get(val)
        return iso3
    except Exception:
        return None

def lookupname(val):
    try:
        _, _, name, _ = lookup.get(val)
        return name
    except Exception:
        return None

def isregional(val):
    try:
        _, _, _, regional = lookup.get(val)
        return regional
    except Exception:
        return None

def lookupbasecountry(val):
    try:
        iso2 = lookupiso2(val)[:2]
        if iso2:
            return lookup[iso2]
        else:
            return None
    except Exception:
        return None


#----------- End Additional Functions -----------#


# Languages
language = {}
language["aar"] = ['Afar']
language["aa"] = ['Afar']
language["abk"] = ['Abkhazian']
language["ab"] = ['Abkhazian']
language["ace"] = ['Achinese']
language["ach"] = ['Acoli']
language["ada"] = ['Adangme']
language["ady"] = ['Adyghe - Adygei']
language["afa"] = ['Afro-Asiatic languages']
language["afh"] = ['Afrihili']
language["afr"] = ['Afrikaans']
language["af"] = ['Afrikaans']
language["ain"] = ['Ainu']
language["aka"] = ['Akan']
language["ak"] = ['Akan']
language["akk"] = ['Akkadian']
language["ale"] = ['Aleut']
language["alg"] = ['Algonquian languages']
language["alt"] = ['Southern Altai']
language["amh"] = ['Amharic']
language["am"] = ['Amharic']
language["ang"] = ['English Old (ca.450–1100)']
language["anp"] = ['Angika']
language["apa"] = ['Apache languages']
language["ara"] = ['Arabic']
language["ar"] = ['Arabic']
language["arc"] = ['Official Aramaic (700–300 BCE) - Imperial Aramaic (700–300 BCE)']
language["arg"] = ['Aragonese']
language["an"] = ['Aragonese']
language["arn"] = ['Mapudungun - Mapuche']
language["arp"] = ['Arapaho']
language["art"] = ['Artificial languages']
language["arw"] = ['Arawak']
language["asm"] = ['Assamese']
language["as"] = ['Assamese']
language["ast"] = ['Asturian - Bable - Leonese - Asturleonese']
language["ath"] = ['Athapascan languages']
language["aus"] = ['Australian languages']
language["ava"] = ['Avaric']
language["av"] = ['Avaric']
language["ave"] = ['Avestan']
language["ae"] = ['Avestan']
language["awa"] = ['Awadhi']
language["aym"] = ['Aymara']
language["ay"] = ['Aymara']
language["aze"] = ['Azerbaijani']
language["az"] = ['Azerbaijani']
language["bad"] = ['Banda languages']
language["bai"] = ['Bamileke languages']
language["bak"] = ['Bashkir']
language["ba"] = ['Bashkir']
language["bal"] = ['Baluchi']
language["bam"] = ['Bambara']
language["bm"] = ['Bambara']
language["ban"] = ['Balinese']
language["bas"] = ['Basa']
language["bat"] = ['Baltic languages']
language["bej"] = ['Beja - Bedawiyet']
language["bel"] = ['Belarusian']
language["be"] = ['Belarusian']
language["bem"] = ['Bemba']
language["ben"] = ['Bengali']
language["bn"] = ['Bengali']
language["ber"] = ['Berber languages']
language["bho"] = ['Bhojpuri']
language["bih"] = ['Bihari languages']
language["bik"] = ['Bikol']
language["bin"] = ['Bini - Edo']
language["bis"] = ['Bislama']
language["bi"] = ['Bislama']
language["bla"] = ['Siksika']
language["bnt"] = ['Bantu languages']
language["bod"] = ['Tibetan']
language["bo"] = ['Tibetan']
language["bos"] = ['Bosnian']
language["bs"] = ['Bosnian']
language["bra"] = ['Braj']
language["bre"] = ['Breton']
language["br"] = ['Breton']
language["btk"] = ['Batak languages']
language["bua"] = ['Buriat']
language["bug"] = ['Buginese']
language["bul"] = ['Bulgarian']
language["bg"] = ['Bulgarian']
language["byn"] = ['Blin - Bilin']
language["cad"] = ['Caddo']
language["cai"] = ['Central American Indian languages']
language["car"] = ['Galibi Carib']
language["cat"] = ['Catalan - Valencian']
language["ca"] = ['Catalan - Valencian']
language["cau"] = ['Caucasian languages']
language["ceb"] = ['Cebuano']
language["cel"] = ['Celtic languages']
language["ces"] = ['Czech']
language["cs"] = ['Czech']
language["cha"] = ['Chamorro']
language["ch"] = ['Chamorro']
language["chb"] = ['Chibcha']
language["che"] = ['Chechen']
language["ce"] = ['Chechen']
language["chg"] = ['Chagatai']
language["chk"] = ['Chuukese']
language["chm"] = ['Mari']
language["chn"] = ['Chinook jargon']
language["cho"] = ['Choctaw']
language["chp"] = ['Chipewyan - Dene Suline']
language["chr"] = ['Cherokee']
language["chu"] = ['Church Slavic - Old Slavonic - Church Slavonic - Old Bulgarian - Old Church Slavonic']
language["cu"] = ['Church Slavic - Old Slavonic - Church Slavonic - Old Bulgarian - Old Church Slavonic']
language["chv"] = ['Chuvash']
language["cv"] = ['Chuvash']
language["chy"] = ['Cheyenne']
language["cmc"] = ['Chamic languages']
language["cnr"] = ['Montenegrin']
language["cop"] = ['Coptic']
language["cor"] = ['Cornish']
language["kw"] = ['Cornish']
language["cos"] = ['Corsican']
language["co"] = ['Corsican']
language["cpe"] = ['Creoles and pidgins English based']
language["cpf"] = ['Creoles and pidgins French-based']
language["cpp"] = ['Creoles and pidgins Portuguese-based']
language["cre"] = ['Cree']
language["cr"] = ['Cree']
language["crh"] = ['Crimean Tatar - Crimean Turkish']
language["crp"] = ['Creoles and pidgins']
language["csb"] = ['Kashubian']
language["cus"] = ['Cushitic languages']
language["cym"] = ['Welsh']
language["cy"] = ['Welsh']
language["dak"] = ['Dakota']
language["dan"] = ['Danish']
language["da"] = ['Danish']
language["dar"] = ['Dargwa']
language["day"] = ['Land Dayak languages']
language["del"] = ['Delaware']
language["den"] = ['Slave (Athapascan)']
language["deu"] = ['German']
language["de"] = ['German']
language["dgr"] = ['Dogrib']
language["din"] = ['Dinka']
language["div"] = ['Divehi - Dhivehi - Maldivian']
language["dv"] = ['Divehi - Dhivehi - Maldivian']
language["doi"] = ['Dogri']
language["dra"] = ['Dravidian languages']
language["dsb"] = ['Lower Sorbian']
language["dua"] = ['Duala']
language["dum"] = ['Dutch Middle (ca. 1050–1350)']
language["dyu"] = ['Dyula']
language["dzo"] = ['Dzongkha']
language["dz"] = ['Dzongkha']
language["efi"] = ['Efik']
language["egy"] = ['Egyptian (Ancient)']
language["eka"] = ['Ekajuk']
language["ell"] = ['Greek Modern (1453–)']
language["el"] = ['Greek Modern (1453–)']
language["elx"] = ['Elamite']
language["eng"] = ['English']
language["en"] = ['English']
language["enm"] = ['English Middle (1100–1500)']
language["epo"] = ['Esperanto']
language["eo"] = ['Esperanto']
language["est"] = ['Estonian']
language["et"] = ['Estonian']
language["eus"] = ['Basque']
language["eu"] = ['Basque']
language["ewe"] = ['Ewe']
language["ee"] = ['Ewe']
language["ewo"] = ['Ewondo']
language["fan"] = ['Fang']
language["fao"] = ['Faroese']
language["fo"] = ['Faroese']
language["fas"] = ['Persian']
language["fa"] = ['Persian']
language["fat"] = ['Fanti']
language["fij"] = ['Fijian']
language["fj"] = ['Fijian']
language["fil"] = ['Filipino - Pilipino']
language["fin"] = ['Finnish']
language["fi"] = ['Finnish']
language["fiu"] = ['Finno-Ugrian languages']
language["fon"] = ['Fon']
language["fra"] = ['French']
language["fr"] = ['French']
language["frm"] = ['French Middle (ca. 1400–1600)']
language["fro"] = ['French Old (842–ca. 1400)']
language["frp"] = ['Franco-Provençal Patois or ArpitanProvençal']
language["frr"] = ['Northern Frisian']
language["frs"] = ['East Frisian Low Saxon']
language["fry"] = ['Western Frisian']
language["fy"] = ['Western Frisian']
language["ful"] = ['Fulah']
language["ff"] = ['Fulah']
language["fur"] = ['Friulian']
language["gaa"] = ['Ga']
language["gay"] = ['Gayo']
language["gba"] = ['Gbaya']
language["gem"] = ['Germanic languages']
language["gez"] = ['Geez']
language["gil"] = ['Gilbertese']
language["gla"] = ['Gaelic - Scottish Gaelic']
language["gd"] = ['Gaelic - Scottish Gaelic']
language["gle"] = ['Irish']
language["ga"] = ['Irish']
language["glg"] = ['Galician']
language["gl"] = ['Galician']
language["glv"] = ['Manx']
language["gv"] = ['Manx']
language["gmh"] = ['German Middle High (ca. 1050–1500)']
language["goh"] = ['German Old High (ca. 750–1050)']
language["gon"] = ['Gondi']
language["gor"] = ['Gorontalo']
language["got"] = ['Gothic']
language["grb"] = ['Grebo']
language["grc"] = ['Greek Ancient (to 1453)']
language["grn"] = ['Guarani']
language["gn"] = ['Guarani']
language["gsw"] = ['Swiss German - Alemannic - Alsatian']
language["guj"] = ['Gujarati']
language["gu"] = ['Gujarati']
language["gwi"] = ["Gwich'in"]
language["hai"] = ['Haida']
language["hat"] = ['Haitian - Haitian Creole']
language["ht"] = ['Haitian - Haitian Creole']
language["hau"] = ['Hausa']
language["ha"] = ['Hausa']
language["haw"] = ['Hawaiian']
language["heb"] = ['Hebrew']
language["he"] = ['Hebrew']
language["her"] = ['Herero']
language["hz"] = ['Herero']
language["hil"] = ['Hiligaynon']
language["him"] = ['Himachali languages - Pahari languages']
language["hin"] = ['Hindi']
language["hi"] = ['Hindi']
language["hit"] = ['Hittite']
language["hmn"] = ['Hmong - Mong']
language["hmo"] = ['Hiri Motu']
language["ho"] = ['Hiri Motu']
language["hrv"] = ['Croatian']
language["hr"] = ['Croatian']
language["hsb"] = ['Upper Sorbian']
language["hun"] = ['Hungarian']
language["hu"] = ['Hungarian']
language["hup"] = ['Hupa']
language["hye"] = ['Armenian']
language["hy"] = ['Armenian']
language["iba"] = ['Iban']
language["ibo"] = ['Igbo']
language["ig"] = ['Igbo']
language["ido"] = ['Ido']
language["io"] = ['Ido']
language["iii"] = ['Sichuan Yi - Nuosu']
language["ii"] = ['Sichuan Yi - Nuosu']
language["ijo"] = ['Ijo languages']
language["iku"] = ['Inuktitut']
language["iu"] = ['Inuktitut']
language["ile"] = ['Interlingue - Occidental']
language["ie"] = ['Interlingue - Occidental']
language["ilo"] = ['Iloko']
language["ina"] = ['Interlingua (International Auxiliary Language Association)']
language["ia"] = ['Interlingua (International Auxiliary Language Association)']
language["inc"] = ['Indo-Aryan languages']
language["ind"] = ['Indonesian']
language["id"] = ['Indonesian']
language["ine"] = ['Indo-European languages']
language["inh"] = ['Ingush']
language["ipk"] = ['Inupiaq']
language["ik"] = ['Inupiaq']
language["ira"] = ['Iranian languages']
language["iro"] = ['Iroquoian languages']
language["isl"] = ['Icelandic']
language["is"] = ['Icelandic']
language["ita"] = ['Italian']
language["it"] = ['Italian']
language["jav"] = ['Javanese']
language["jv"] = ['Javanese']
language["jbo"] = ['Lojban']
language["jpn"] = ['Japanese']
language["ja"] = ['Japanese']
language["jpr"] = ['Judeo-Persian']
language["jrb"] = ['Judeo-Arabic']
language["kaa"] = ['Kara-Kalpak']
language["kab"] = ['Kabyle']
language["kac"] = ['Kachin - Jingpho']
language["kal"] = ['Kalaallisut - Greenlandic']
language["kl"] = ['Kalaallisut - Greenlandic']
language["kam"] = ['Kamba']
language["kan"] = ['Kannada']
language["kn"] = ['Kannada']
language["kar"] = ['Karen languages']
language["kas"] = ['Kashmiri']
language["ks"] = ['Kashmiri']
language["kat"] = ['Georgian']
language["ka"] = ['Georgian']
language["kau"] = ['Kanuri']
language["kr"] = ['Kanuri']
language["kaw"] = ['Kawi']
language["kaz"] = ['Kazakh']
language["kk"] = ['Kazakh']
language["kbd"] = ['Kabardian']
language["kha"] = ['Khasi']
language["khi"] = ['Khoisan languages']
language["khm"] = ['Central Khmer']
language["km"] = ['Central Khmer']
language["kho"] = ['Khotanese - Sakan']
language["kik"] = ['Kikuyu - Gikuyu']
language["ki"] = ['Kikuyu - Gikuyu']
language["kin"] = ['Kinyarwanda']
language["rw"] = ['Kinyarwanda']
language["kir"] = ['Kirghiz - Kyrgyz']
language["ky"] = ['Kirghiz - Kyrgyz']
language["kmb"] = ['Kimbundu']
language["kok"] = ['Konkani']
language["kom"] = ['Komi']
language["kv"] = ['Komi']
language["kon"] = ['Kongo']
language["kg"] = ['Kongo']
language["kor"] = ['Korean']
language["ko"] = ['Korean']
language["kos"] = ['Kosraean']
language["kpe"] = ['Kpelle']
language["krc"] = ['Karachay-Balkar']
language["krl"] = ['Karelian']
language["kro"] = ['Kru languages']
language["kru"] = ['Kurukh']
language["kua"] = ['Kuanyama - Kwanyama']
language["kj"] = ['Kuanyama - Kwanyama']
language["kum"] = ['Kumyk']
language["kur"] = ['Kurdish']
language["ku"] = ['Kurdish']
language["kut"] = ['Kutenai']
language["lad"] = ['Ladino']
language["lah"] = ['Lahnda']
language["lam"] = ['Lamba']
language["lao"] = ['Lao']
language["lo"] = ['Lao']
language["lat"] = ['Latin']
language["la"] = ['Latin']
language["lav"] = ['Latvian']
language["lv"] = ['Latvian']
language["lez"] = ['Lezghian']
language["lim"] = ['Limburgan - Limburger - Limburgish']
language["li"] = ['Limburgan - Limburger - Limburgish']
language["lin"] = ['Lingala']
language["ln"] = ['Lingala']
language["lit"] = ['Lithuanian']
language["lt"] = ['Lithuanian']
language["lol"] = ['Mongo']
language["loz"] = ['Lozi']
language["ltz"] = ['Luxembourgish - Letzeburgesch']
language["lb"] = ['Luxembourgish - Letzeburgesch']
language["lua"] = ['Luba-Lulua']
language["lub"] = ['Luba-Katanga']
language["lu"] = ['Luba-Katanga']
language["lug"] = ['Ganda']
language["lg"] = ['Ganda']
language["lui"] = ['Luiseno']
language["lun"] = ['Lunda']
language["luo"] = ['Luo (Kenya and Tanzania)']
language["lus"] = ['Lushai']
language["mad"] = ['Madurese']
language["mag"] = ['Magahi']
language["mah"] = ['Marshallese']
language["mh"] = ['Marshallese']
language["mai"] = ['Maithili']
language["mak"] = ['Makasar']
language["mal"] = ['Malayalam']
language["ml"] = ['Malayalam']
language["man"] = ['Mandingo']
language["map"] = ['Austronesian languages']
language["mar"] = ['Marathi']
language["mr"] = ['Marathi']
language["mas"] = ['Masai']
language["mdf"] = ['Moksha']
language["mdr"] = ['Mandar']
language["men"] = ['Mende']
language["mga"] = ['Irish Middle (900–1200)']
language["mic"] = ["Mi'kmaq - Micmac"]
language["min"] = ['Minangkabau']
language["mis"] = ['Uncoded languages']
language["mkd"] = ['Macedonian']
language["mk"] = ['Macedonian']
language["mkh"] = ['Mon-Khmer languages']
language["mlg"] = ['Malagasy']
language["mg"] = ['Malagasy']
language["mlt"] = ['Maltese']
language["mt"] = ['Maltese']
language["mnc"] = ['Manchu']
language["mni"] = ['Manipuri']
language["mno"] = ['Manobo languages']
language["moh"] = ['Mohawk']
language["mon"] = ['Mongolian']
language["mn"] = ['Mongolian']
language["mos"] = ['Mossi']
language["mri"] = ['Māori']
language["mi"] = ['Māori']
language["msa"] = ['Malay']
language["ms"] = ['Malay']
language["mul"] = ['Multiple languages']
language["mun"] = ['Munda languages']
language["mus"] = ['Creek']
language["mwl"] = ['Mirandese']
language["mwr"] = ['Marwari']
language["mya"] = ['Burmese']
language["my"] = ['Burmese']
language["myn"] = ['Mayan languages']
language["myv"] = ['Erzya']
language["nah"] = ['Nahuatl languages']
language["nai"] = ['North American Indian languages']
language["nap"] = ['Neapolitan']
language["nau"] = ['Nauru']
language["na"] = ['Nauru']
language["nav"] = ['Navajo - Navaho']
language["nv"] = ['Navajo - Navaho']
language["nbl"] = ['Ndebele South - South Ndebele']
language["nr"] = ['Ndebele South - South Ndebele']
language["nde"] = ['Ndebele North - North Ndebele']
language["nd"] = ['Ndebele North - North Ndebele']
language["ndo"] = ['Ndonga']
language["ng"] = ['Ndonga']
language["nds"] = ['Low German - Low Saxon - German Low - Saxon Low']
language["nep"] = ['Nepali']
language["ne"] = ['Nepali']
language["new"] = ['Nepal Bhasa - Newari']
language["nia"] = ['Nias']
language["nic"] = ['Niger-Kordofanian languages']
language["niu"] = ['Niuean']
language["nld"] = ['Dutch - Flemish']
language["nl"] = ['Dutch - Flemish']
language["nno"] = ['Norwegian Nynorsk - Nynorsk Norwegian']
language["nn"] = ['Norwegian Nynorsk - Nynorsk Norwegian']
language["nob"] = ['Bokmål Norwegian - Norwegian Bokmål']
language["nb"] = ['Bokmål Norwegian - Norwegian Bokmål']
language["nog"] = ['Nogai']
language["non"] = ['Norse Old']
language["nor"] = ['Norwegian']
language["no"] = ['Norwegian']
language["nqo"] = ["N'Ko"]
language["nso"] = ['Pedi - Sepedi - Northern Sotho']
language["nub"] = ['Nubian languages']
language["nwc"] = ['Classical Newari - Old Newari - Classical Nepal Bhasa']
language["nya"] = ['Chichewa - Chewa - Nyanja']
language["ny"] = ['Chichewa - Chewa - Nyanja']
language["nym"] = ['Nyamwezi']
language["nyn"] = ['Nyankole']
language["nyo"] = ['Nyoro']
language["nzi"] = ['Nzima']
language["oci"] = ['Occitan (post 1500)']
language["oc"] = ['Occitan (post 1500)']
language["oji"] = ['Ojibwa']
language["oj"] = ['Ojibwa']
language["ori"] = ['Oriya']
language["or"] = ['Oriya']
language["orm"] = ['Oromo']
language["om"] = ['Oromo']
language["osa"] = ['Osage']
language["oss"] = ['Ossetian - Ossetic']
language["os"] = ['Ossetian - Ossetic']
language["ota"] = ['Turkish Ottoman (1500–1928)']
language["oto"] = ['Otomian languages']
language["paa"] = ['Papuan languages']
language["pag"] = ['Pangasinan']
language["pal"] = ['Pahlavi']
language["pam"] = ['Pampanga - Kapampangan']
language["pan"] = ['Panjabi - Punjabi']
language["pa"] = ['Panjabi - Punjabi']
language["pap"] = ['Papiamento']
language["pau"] = ['Palauan']
language["peo"] = ['Persian Old (c. 600–400 B.C.)']
language["phi"] = ['Philippine languages']
language["phn"] = ['Phoenician']
language["pli"] = ['Pali']
language["pi"] = ['Pali']
language["pol"] = ['Polish']
language["pl"] = ['Polish']
language["pon"] = ['Pohnpeian']
language["por"] = ['Portuguese']
language["pt"] = ['Portuguese']
language["pov"] = ['Crioulo']
language["pra"] = ['Prakrit languages']
language["pro"] = ['Provençal Old (to 1500) - Old Occitan (to 1500)']
language["pus"] = ['Pushto - Pashto']
language["ps"] = ['Pushto - Pashto']
language["qaa-qtz"] = ['Reserved for local use']
language["que"] = ['Quechua']
language["qu"] = ['Quechua']
language["raj"] = ['Rajasthani']
language["rap"] = ['Rapanui']
language["rar"] = ['Rarotongan - Cook Islands Māori']
language["roa"] = ['Romance languages']
language["roh"] = ['Romansh']
language["rm"] = ['Romansh']
language["rom"] = ['Romany']
language["ron"] = ['Romanian - Moldavian - Moldovan']
language["ro"] = ['Romanian - Moldavian - Moldovan']
language["run"] = ['Rundi']
language["rn"] = ['Rundi']
language["rup"] = ['Aromanian - Arumanian - Macedo-Romanian[b]']
language["rus"] = ['Russian']
language["ru"] = ['Russian']
language["sad"] = ['Sandawe']
language["sag"] = ['Sango']
language["sg"] = ['Sango']
language["sah"] = ['Yakut']
language["sai"] = ['South American Indian languages']
language["sal"] = ['Salishan languages']
language["sam"] = ['Samaritan Aramaic']
language["san"] = ['Sanskrit']
language["sa"] = ['Sanskrit']
language["sas"] = ['Sasak']
language["sat"] = ['Santali']
language["scn"] = ['Sicilian']
language["sco"] = ['Scots']
language["sel"] = ['Selkup']
language["sem"] = ['Semitic languages']
language["sga"] = ['Irish Old (to 900)']
language["sgn"] = ['Sign Languages']
language["shn"] = ['Shan']
language["sid"] = ['Sidamo']
language["sin"] = ['Sinhala - Sinhalese']
language["si"] = ['Sinhala - Sinhalese']
language["sio"] = ['Siouan languages']
language["sit"] = ['Sino-Tibetan languages']
language["sla"] = ['Slavic languages']
language["slk"] = ['Slovak']
language["sk"] = ['Slovak']
language["slv"] = ['Slovenian']
language["sl"] = ['Slovenian']
language["sma"] = ['Southern Sami']
language["sme"] = ['Northern Sami']
language["se"] = ['Northern Sami']
language["smi"] = ['Sami languages']
language["smj"] = ['Lule Sami']
language["smn"] = ['Inari Sami']
language["smo"] = ['Samoan']
language["sm"] = ['Samoan']
language["sms"] = ['Skolt Sami']
language["sna"] = ['Shona']
language["sn"] = ['Shona']
language["snd"] = ['Sindhi']
language["sd"] = ['Sindhi']
language["snk"] = ['Soninke']
language["sog"] = ['Sogdian']
language["som"] = ['Somali']
language["so"] = ['Somali']
language["son"] = ['Songhai languages']
language["sot"] = ['Sotho Southern']
language["st"] = ['Sotho Southern']
language["spa"] = ['Spanish - Castilian']
language["es"] = ['Spanish - Castilian']
language["sqi"] = ['Albanian']
language["sq"] = ['Albanian']
language["srd"] = ['Sardinian']
language["sc"] = ['Sardinian']
language["srn"] = ['Sranan Tongo']
language["srp"] = ['Serbian']
language["sr"] = ['Serbian']
language["srr"] = ['Serer']
language["ssa"] = ['Nilo-Saharan languages']
language["ssw"] = ['Swati']
language["ss"] = ['Swati']
language["suk"] = ['Sukuma']
language["sun"] = ['Sundanese']
language["su"] = ['Sundanese']
language["sus"] = ['Susu']
language["sux"] = ['Sumerian']
language["swa"] = ['Swahili']
language["sw"] = ['Swahili']
language["swe"] = ['Swedish']
language["sv"] = ['Swedish']
language["syc"] = ['Classical Syriac']
language["syr"] = ['Syriac']
language["tah"] = ['Tahitian']
language["ty"] = ['Tahitian']
language["tai"] = ['Tai languages']
language["tam"] = ['Tamil']
language["ta"] = ['Tamil']
language["tat"] = ['Tatar']
language["tt"] = ['Tatar']
language["tel"] = ['Telugu']
language["te"] = ['Telugu']
language["tem"] = ['Timne']
language["ter"] = ['Tereno']
language["tet"] = ['Tetum']
language["tgk"] = ['Tajik']
language["tg"] = ['Tajik']
language["tgl"] = ['Tagalog']
language["tl"] = ['Tagalog']
language["tha"] = ['Thai']
language["th"] = ['Thai']
language["tig"] = ['Tigre']
language["tir"] = ['Tigrinya']
language["ti"] = ['Tigrinya']
language["tiv"] = ['Tiv']
language["tkl"] = ['Tokelau']
language["tlh"] = ['Klingon - tlhIngan-Hol']
language["tli"] = ['Tlingit']
language["tmh"] = ['Tamashek']
language["tog"] = ['Tonga (Nyasa)']
language["ton"] = ['Tonga (Tonga Islands)']
language["to"] = ['Tonga (Tonga Islands)']
language["tpi"] = ['Tok Pisin']
language["tsi"] = ['Tsimshian']
language["tsn"] = ['Tswana']
language["tn"] = ['Tswana']
language["tso"] = ['Tsonga']
language["ts"] = ['Tsonga']
language["tuk"] = ['Turkmen']
language["tk"] = ['Turkmen']
language["tum"] = ['Tumbuka']
language["tup"] = ['Tupi languages']
language["tur"] = ['Turkish']
language["tr"] = ['Turkish']
language["tut"] = ['Altaic languages']
language["tvl"] = ['Tuvalu']
language["twi"] = ['Twi']
language["tw"] = ['Twi']
language["tyv"] = ['Tuvinian']
language["udm"] = ['Udmurt']
language["uga"] = ['Ugaritic']
language["uig"] = ['Uighur - Uyghur']
language["ug"] = ['Uighur - Uyghur']
language["ukr"] = ['Ukrainian']
language["uk"] = ['Ukrainian']
language["umb"] = ['Umbundu']
language["und"] = ['Undetermined']
language["urd"] = ['Urdu']
language["ur"] = ['Urdu']
language["uzb"] = ['Uzbek']
language["uz"] = ['Uzbek']
language["vai"] = ['Vai']
language["ven"] = ['Venda']
language["ve"] = ['Venda']
language["vie"] = ['Vietnamese']
language["vi"] = ['Vietnamese']
language["vol"] = ['Volapük']
language["vo"] = ['Volapük']
language["vot"] = ['Votic']
language["wak"] = ['Wakashan languages']
language["wal"] = ['Wolaitta - Wolaytta']
language["war"] = ['Waray']
language["was"] = ['Washo']
language["wen"] = ['Sorbian languages']
language["wln"] = ['Walloon']
language["wa"] = ['Walloon']
language["wol"] = ['Wolof']
language["wo"] = ['Wolof']
language["xal"] = ['Kalmyk - Oirat']
language["xho"] = ['Xhosa']
language["xh"] = ['Xhosa']
language["yao"] = ['Yao']
language["yap"] = ['Yapese']
language["yid"] = ['Yiddish']
language["yi"] = ['Yiddish']
language["yor"] = ['Yoruba']
language["yo"] = ['Yoruba']
language["ypk"] = ['Yupik languages']
language["zap"] = ['Zapotec']
language["zbl"] = ['Blissymbols - Blissymbolics - Bliss']
language["zen"] = ['Zenaga']
language["zgh"] = ['Standard Moroccan Tamazight']
language["zha"] = ['Zhuang - Chuang']
language["za"] = ['Zhuang - Chuang']
language["zho"] = ['Chinese']
language["zh"] = ['Chinese']
language["znd"] = ['Zande languages']
language["zul"] = ['Zulu']
language["zu"] = ['Zulu']
language["zun"] = ['Zuni']
language["zxx"] = ['No linguistic content - Not applicable']
language["zza"] = ['Zaza - Dimili - Dimli - Kirdki - Kirmanjki - Zazaki']



# Timezones
timezone = {}
timezone["AD"] = ['Europe/Andorra']
timezone["AE"] = ['Asia/Dubai']
timezone["AF"] = ['Asia/Kabul']
timezone["AG"] = ['America/Antigua']
timezone["AI"] = ['America/Anguilla']
timezone["AL"] = ['Europe/Tirane']
timezone["AM"] = ['Asia/Yerevan']
timezone["AO"] = ['Africa/Luanda']
timezone["AQ1"] = ['Antarctica/Casey']
timezone["AQ10"] = ['Antarctica/Vostok']
timezone["AQ2"] = ['Antarctica/Davis']
timezone["AQ3"] = ['Antarctica/DumontDUrville']
timezone["AQ4"] = ['Antarctica/Mawson']
timezone["AQ5"] = ['Antarctica/McMurdo']
timezone["AQ6"] = ['Antarctica/Palmer']
timezone["AQ7"] = ['Antarctica/Rothera']
timezone["AQ8"] = ['Antarctica/Syowa']
timezone["AQ9"] = ['Antarctica/Troll']
timezone["AR"] = ['America/Argentina/Buenos_Aires']
timezone["AR1"] = ['America/Argentina/Catamarca']
timezone["AR10"] = ['America/Argentina/Tucuman']
timezone["AR11"] = ['America/Argentina/Ushuaia']
timezone["AR2"] = ['America/Argentina/Cordoba']
timezone["AR3"] = ['America/Argentina/Jujuy']
timezone["AR4"] = ['America/Argentina/La_Rioja']
timezone["AR5"] = ['America/Argentina/Mendoza']
timezone["AR6"] = ['America/Argentina/Rio_Gallegos']
timezone["AR7"] = ['America/Argentina/Salta']
timezone["AR8"] = ['America/Argentina/San_Juan']
timezone["AR9"] = ['America/Argentina/San_Luis']
timezone["AS"] = ['Pacific/Pago_Pago']
timezone["AT"] = ['Europe/Vienna']
timezone["AU"] = ['Australia/Sydney']
timezone["AU1"] = ['Antarctica/Macquarie']
timezone["AU2"] = ['Australia/Brisbane']
timezone["AU3"] = ['Australia/Broken_Hill']
timezone["AU4"] = ['Australia/Eucla']
timezone["AU5"] = ['Australia/Lindeman']
timezone["AU6"] = ['Australia/Lord_Howe']
timezone["AU_ACT"] = ['Australia/Sydney']
timezone["AU_NSW"] = ['Australia/Sydney']
timezone["AU_NT"] = ['Australia/Darwin']
timezone["AU_QLD"] = ['Australia/Sydney']
timezone["AU_SA"] = ['Australia/Adelaide']
timezone["AU_TAS"] = ['Australia/Hobart']
timezone["AU_VIC"] = ['Australia/Melbourne']
timezone["AU_WA"] = ['Australia/Perth']
timezone["AW"] = ['America/Aruba']
timezone["AX"] = ['Europe/Mariehamn']
timezone["AZ"] = ['Asia/Baku']
timezone["BA"] = ['Europe/Sarajevo']
timezone["BB"] = ['America/Barbados']
timezone["BD"] = ['Asia/Dhaka']
timezone["BE"] = ['Europe/Brussels']
timezone["BF"] = ['Africa/Ouagadougou']
timezone["BG"] = ['Europe/Sofia']
timezone["BH"] = ['Asia/Bahrain']
timezone["BI"] = ['Africa/Bujumbura']
timezone["BJ"] = ['Africa/Porto-Novo']
timezone["BL"] = ['America/St_Barthelemy']
timezone["BM"] = ['Atlantic/Bermuda']
timezone["BN"] = ['Asia/Brunei']
timezone["BO"] = ['America/La_Paz']
timezone["BQ"] = ['America/Kralendijk']
timezone["BR"] = ['America/Sao_Paulo']
timezone["BRPE"] = ['America/Recife']
timezone["BRRO"] = ['America/Porto_Velho']
timezone["BS"] = ['America/Nassau']
timezone["BT"] = ['Asia/Thimphu']
timezone["BW"] = ['Africa/Gaborone']
timezone["BY"] = ['Europe/Minsk']
timezone["BZ"] = ['America/Belize']
timezone["CA1"] = ['America/Atikokan']
timezone["CA10"] = ['America/Rankin_Inlet']
timezone["CA11"] = ['America/Resolute']
timezone["CA12"] = ['America/Swift_Current']
timezone["CA13"] = ['Canada/Atlantic']
timezone["CA14"] = ['Canada/Central']
timezone["CA15"] = ['Canada/Eastern']
timezone["CA16"] = ['Canada/Mountain']
timezone["CA17"] = ['Canada/Newfoundland']
timezone["CA18"] = ['Canada/Pacific']
timezone["CA19"] = ['Canada/Saskatchewan']
timezone["CA2"] = ['America/Blanc-Sablon']
timezone["CA20"] = ['Canada/Yukon']
timezone["CA3"] = ['America/Cambridge_Bay']
timezone["CA4"] = ['America/Creston']
timezone["CA5"] = ['America/Dawson']
timezone["CA6"] = ['America/Dawson_Creek']
timezone["CA7"] = ['America/Fort_Nelson']
timezone["CA8"] = ['America/Glace_Bay']
timezone["CA9"] = ['America/Goose_Bay']
timezone["CA_AB"] = ['America/Edmonton']
timezone["CA_BC"] = ['America/Vancouver']
timezone["CA_MB"] = ['America/Winnipeg']
timezone["CA_NB"] = ['America/Moncton']
timezone["CA_NL"] = ['America/St_Johns']
timezone["CA_NS"] = ['America/Halifax']
timezone["CA_NT"] = ['America/Inuvik']
timezone["CA_NU"] = ['America/Iqaluit']
timezone["CA_ON"] = ['America/Toronto']
timezone["CA_PE"] = ['America/Halifax']
timezone["CA_QC"] = ['America/Toronto']
timezone["CA_SK"] = ['America/Regina']
timezone["CA_YT"] = ['America/Whitehorse']
timezone["CC"] = ['Indian/Cocos']
timezone["CD"] = ['Africa/Kinshasa']
timezone["CD1"] = ['Africa/Lubumbashi']
timezone["CF"] = ['Africa/Bangui']
timezone["CG"] = ['Africa/Brazzaville']
timezone["CH"] = ['Europe/Zurich']
timezone["CI"] = ['Africa/Abidjan']
timezone["CK"] = ['Pacific/Rarotonga']
timezone["CL"] = ['America/Santiago']
timezone["CL1"] = ['America/Punta_Arenas']
timezone["CL2"] = ['Pacific/Easter']
timezone["CM"] = ['Africa/Douala']
timezone["CN"] = ['Asia/Shanghai']
timezone["CN1"] = ['Asia/Urumqi']
timezone["CO"] = ['America/Bogota']
timezone["CR"] = ['America/Costa_Rica']
timezone["CU"] = ['America/Havana']
timezone["CV"] = ['Atlantic/Cape_Verde']
timezone["CW"] = ['America/Curacao']
timezone["CX"] = ['Indian/Christmas']
timezone["CY"] = ['Asia/Nicosia']
timezone["CY1"] = ['Asia/Famagusta']
timezone["CZ"] = ['Europe/Prague']
timezone["DE"] = ['Europe/Berlin']
timezone["DE1"] = ['Europe/Busingen']
timezone["DJ"] = ['Africa/Djibouti']
timezone["DK"] = ['Europe/Copenhagen']
timezone["DM"] = ['America/Dominica']
timezone["DO"] = ['America/Santo_Domingo']
timezone["DZ"] = ['Africa/Algiers']
timezone["EC"] = ['Pacific/Galapagos']
timezone["EE"] = ['Europe/Tallinn']
timezone["EG"] = ['Africa/Cairo']
timezone["ER"] = ['Africa/Asmara']
timezone["ES"] = ['Europe/Madrid']
timezone["ES1"] = ['Africa/Ceuta']
timezone["ES_CN"] = ['Atlantic/Canary']
timezone["ET"] = ['Africa/Addis_Ababa']
timezone["FI"] = ['Europe/Helsinki']
timezone["FJ"] = ['Pacific/Fiji']
timezone["FK"] = ['Atlantic/Stanley']
timezone["FM"] = ['Pacific/Kosrae']
timezone["FM1"] = ['Pacific/Chuuk']
timezone["FM2"] = ['Pacific/Pohnpei']
timezone["FO"] = ['Atlantic/Faroe']
timezone["FR"] = ['Europe/Paris']
timezone["GA"] = ['Africa/Libreville']
timezone["GB"] = ['Europe/London']
timezone["GD"] = ['America/Grenada']
timezone["GE"] = ['Asia/Tbilisi']
timezone["GF"] = ['America/Cayenne']
timezone["GG"] = ['Europe/Guernsey']
timezone["GH"] = ['Africa/Accra']
timezone["GI"] = ['Europe/Gibraltar']
timezone["GL"] = ['America/Nuuk']
timezone["GL1"] = ['America/Danmarkshavn']
timezone["GL2"] = ['America/Scoresbysund']
timezone["GL3"] = ['America/Thule']
timezone["GM"] = ['Africa/Banjul']
timezone["GN"] = ['Africa/Conakry']
timezone["GP"] = ['America/Guadeloupe']
timezone["GQ"] = ['Africa/Malabo']
timezone["GR"] = ['Europe/Athens']
timezone["GS"] = ['Atlantic/South_Georgia']
timezone["GT"] = ['America/Guatemala']
timezone["GU"] = ['Pacific/Guam']
timezone["GW"] = ['Africa/Bissau']
timezone["GY"] = ['America/Guyana']
timezone["HK"] = ['Asia/Hong_Kong']
timezone["HN"] = ['America/Tegucigalpa']
timezone["HR"] = ['Europe/Zagreb']
timezone["HT"] = ['America/Port-au-Prince']
timezone["HU"] = ['Europe/Budapest']
timezone["ID"] = ['Asia/Jakarta']
timezone["ID1"] = ['Asia/Jayapura']
timezone["ID2"] = ['Asia/Makassar']
timezone["ID3"] = ['Asia/Pontianak']
timezone["IE"] = ['Europe/Dublin']
timezone["IL"] = ['Asia/Jerusalem']
timezone["IM"] = ['Europe/Isle_of_Man']
timezone["IN"] = ['Asia/Kolkata']
timezone["IO"] = ['Indian/Chagos']
timezone["IQ"] = ['Asia/Baghdad']
timezone["IR"] = ['Asia/Tehran']
timezone["IS"] = ['Atlantic/Reykjavik']
timezone["IT"] = ['Europe/Rome']
timezone["JE"] = ['Europe/Jersey']
timezone["JM"] = ['America/Jamaica']
timezone["JO"] = ['Asia/Amman']
timezone["JP"] = ['Asia/Tokyo']
timezone["KE"] = ['Africa/Nairobi']
timezone["KG"] = ['Asia/Bishkek']
timezone["KH"] = ['Asia/Phnom_Penh']
timezone["KI"] = ['Pacific/Tarawa']
timezone["KM"] = ['Indian/Comoro']
timezone["KN"] = ['America/St_Kitts']
timezone["KP"] = ['Asia/Pyongyang']
timezone["KR"] = ['Asia/Seoul']
timezone["KW"] = ['Asia/Kuwait']
timezone["KY"] = ['America/Cayman']
timezone["KZ"] = ['Asia/Almaty']
timezone["KZ1"] = ['Asia/Aqtau']
timezone["KZ2"] = ['Asia/Aqtobe']
timezone["KZ3"] = ['Asia/Atyrau']
timezone["KZ4"] = ['Asia/Oral']
timezone["KZ5"] = ['Asia/Qostanay']
timezone["KZ6"] = ['Asia/Qyzylorda']
timezone["LA"] = ['Asia/Vientiane']
timezone["LB"] = ['Asia/Beirut']
timezone["LC"] = ['America/St_Lucia']
timezone["LI"] = ['Europe/Vaduz']
timezone["LK"] = ['Asia/Colombo']
timezone["LR"] = ['Africa/Monrovia']
timezone["LS"] = ['Africa/Maseru']
timezone["LT"] = ['Europe/Vilnius']
timezone["LU"] = ['Europe/Luxembourg']
timezone["LV"] = ['Europe/Riga']
timezone["LY"] = ['Africa/Tripoli']
timezone["MA"] = ['Africa/Casablanca']
timezone["MA1"] = ['Africa/El_Aaiun']
timezone["MC"] = ['Europe/Monaco']
timezone["MD"] = ['Europe/Chisinau']
timezone["ME"] = ['Europe/Podgorica']
timezone["MF"] = ['America/Marigot']
timezone["MG"] = ['Indian/Antananarivo']
timezone["MH"] = ['Pacific/Kwajalein']
timezone["MH1"] = ['Pacific/Majuro']
timezone["MK"] = ['Europe/Skopje']
timezone["ML"] = ['Africa/Bamako']
timezone["MM"] = ['Asia/Yangon']
timezone["MN"] = ['Asia/Ulaanbaatar']
timezone["MN1"] = ['Asia/Choibalsan']
timezone["MN2"] = ['Asia/Hovd']
timezone["MO"] = ['Asia/Macau']
timezone["MP"] = ['Pacific/Saipan']
timezone["MQ"] = ['America/Martinique']
timezone["MR"] = ['Africa/Nouakchott']
timezone["MS"] = ['America/Montserrat']
timezone["MT"] = ['Europe/Malta']
timezone["MU"] = ['Indian/Mauritius']
timezone["MV"] = ['Indian/Maldives']
timezone["MW"] = ['Africa/Blantyre']
timezone["MX"] = ['America/Mexico_City']
timezone["MX1"] = ['America/Bahia_Banderas']
timezone["MX10"] = ['America/Ojinaga']
timezone["MX11"] = ['America/Tijuana']
timezone["MX2"] = ['America/Cancun']
timezone["MX3"] = ['America/Chihuahua']
timezone["MX4"] = ['America/Ciudad_Juarez']
timezone["MX5"] = ['America/Hermosillo']
timezone["MX6"] = ['America/Matamoros']
timezone["MX7"] = ['America/Mazatlan']
timezone["MX8"] = ['America/Merida']
timezone["MX9"] = ['America/Monterrey']
timezone["MY"] = ['Asia/Kuala_Lumpur']
timezone["MY1"] = ['Asia/Kuching']
timezone["MZ"] = ['Africa/Maputo']
timezone["NA"] = ['Africa/Windhoek']
timezone["NC"] = ['Pacific/Noumea']
timezone["NE"] = ['Africa/Niamey']
timezone["NF"] = ['Pacific/Norfolk']
timezone["NG"] = ['Africa/Lagos']
timezone["NI"] = ['America/Managua']
timezone["NL"] = ['Europe/Amsterdam']
timezone["NO"] = ['Europe/Oslo']
timezone["NP"] = ['Asia/Kathmandu']
timezone["NR"] = ['Pacific/Nauru']
timezone["NU"] = ['Pacific/Niue']
timezone["NZ"] = ['Pacific/Auckland']
timezone["NZ1"] = ['Pacific/Chatham']
timezone["OM"] = ['Asia/Muscat']
timezone["PA"] = ['America/Panama']
timezone["PE"] = ['America/Lima']
timezone["PF"] = ['Pacific/Marquesas']
timezone["PF1"] = ['Pacific/Gambier']
timezone["PF2"] = ['Pacific/Tahiti']
timezone["PG"] = ['Pacific/Port_Moresby']
timezone["PG1"] = ['Pacific/Bougainville']
timezone["PH"] = ['Asia/Manila']
timezone["PK"] = ['Asia/Karachi']
timezone["PL"] = ['Europe/Warsaw']
timezone["PM"] = ['America/Miquelon']
timezone["PN"] = ['Pacific/Pitcairn']
timezone["PR"] = ['America/Puerto_Rico']
timezone["PS"] = ['Asia/Gaza']
timezone["PS1"] = ['Asia/Hebron']
timezone["PT"] = ['Europe/Lisbon']
timezone["PT1"] = ['Atlantic/Azores']
timezone["PT2"] = ['Atlantic/Madeira']
timezone["PW"] = ['Pacific/Palau']
timezone["PY"] = ['America/Asuncion']
timezone["QA"] = ['Asia/Qatar']
timezone["RE"] = ['Indian/Reunion']
timezone["RO"] = ['Europe/Bucharest']
timezone["RS"] = ['Europe/Belgrade']
timezone["RU"] = ['Europe/Moscow']
timezone["RU_AD"] = ['Europe/Moscow']
timezone["RU_AL"] = ['Asia/Krasnoyarsk']
timezone["RU_ALT"] = ['Asia/Krasnoyarsk']
timezone["RU_AMU"] = ['Asia/Yakutsk']
timezone["RU_ARK"] = ['Europe/Moscow']
timezone["RU_AST"] = ['Europe/Samara']
timezone["RU_BA"] = ['Asia/Yekaterinburg']
timezone["RU_BEL"] = ['Europe/Moscow']
timezone["RU_BRY"] = ['Europe/Moscow']
timezone["RU_BU"] = ['Asia/Irkutsk']
timezone["RU_CE"] = ['Europe/Moscow']
timezone["RU_CHE"] = ['Asia/Yekaterinburg']
timezone["RU_CHU"] = ['Asia/Anadyr']
timezone["RU_CU"] = ['Europe/Moscow']
timezone["RU_DA"] = ['Europe/Moscow']
timezone["RU_IN"] = ['Europe/Moscow']
timezone["RU_IRK"] = ['Asia/Irkutsk']
timezone["RU_IVA"] = ['Europe/Moscow']
timezone["RU_KAM"] = ['Asia/Kamchatka']
timezone["RU_KB"] = ['Europe/Moscow']
timezone["RU_KC"] = ['Europe/Moscow']
timezone["RU_KDA"] = ['Europe/Moscow']
timezone["RU_KEM"] = ['Asia/Krasnoyarsk']
timezone["RU_KGD"] = ['Europe/Moscow']
timezone["RU_KGN"] = ['Asia/Yekaterinburg']
timezone["RU_KHA"] = ['Asia/Vladivostok']
timezone["RU_KHM"] = ['Asia/Yekaterinburg']
timezone["RU_KIR"] = ['Europe/Moscow']
timezone["RU_KK"] = ['Asia/Krasnoyarsk']
timezone["RU_KL"] = ['Europe/Moscow']
timezone["RU_KLU"] = ['Europe/Moscow']
timezone["RU_KO"] = ['Europe/Moscow']
timezone["RU_KOS"] = ['Europe/Moscow']
timezone["RU_KR"] = ['Europe/Moscow']
timezone["RU_KRS"] = ['Europe/Moscow']
timezone["RU_KYA"] = ['Asia/Krasnoyarsk']
timezone["RU_LEN"] = ['Europe/Moscow']
timezone["RU_LIP"] = ['Europe/Moscow']
timezone["RU_MAG"] = ['Asia/Magadan']
timezone["RU_ME"] = ['Europe/Moscow']
timezone["RU_MO"] = ['Europe/Moscow']
timezone["RU_MOS"] = ['Europe/Moscow']
timezone["RU_MOW"] = ['Europe/Moscow']
timezone["RU_MUR"] = ['Europe/Moscow']
timezone["RU_NEN"] = ['Europe/Moscow']
timezone["RU_NGR"] = ['Europe/Moscow']
timezone["RU_NIZ"] = ['Europe/Moscow']
timezone["RU_NVS"] = ['Asia/Krasnoyarsk']
timezone["RU_OMS"] = ['Asia/Omsk']
timezone["RU_ORE"] = ['Asia/Yekaterinburg']
timezone["RU_ORL"] = ['Europe/Moscow']
timezone["RU_PER"] = ['Asia/Yekaterinburg']
timezone["RU_PNZ"] = ['Europe/Moscow']
timezone["RU_PRI"] = ['Asia/Vladivostok']
timezone["RU_PSK"] = ['Europe/Moscow']
timezone["RU_ROS"] = ['Europe/Moscow']
timezone["RU_RYA"] = ['Europe/Moscow']
timezone["RU_SA"] = ['Asia/Yakutsk']
timezone["RU_SAK"] = ['Asia/Magadan']
timezone["RU_SAM"] = ['Europe/Samara']
timezone["RU_SAR"] = ['Europe/Samara']
timezone["RU_SE"] = ['Europe/Moscow']
timezone["RU_SMO"] = ['Europe/Moscow']
timezone["RU_SPE"] = ['Europe/Moscow']
timezone["RU_STA"] = ['Europe/Moscow']
timezone["RU_SVE"] = ['Asia/Yekaterinburg']
timezone["RU_TA"] = ['Europe/Moscow']
timezone["RU_TAM"] = ['Europe/Moscow']
timezone["RU_TOM"] = ['Asia/Tomsk']
timezone["RU_TUL"] = ['Europe/Moscow']
timezone["RU_TVE"] = ['Europe/Moscow']
timezone["RU_TY"] = ['Asia/Krasnoyarsk']
timezone["RU_TYU"] = ['Asia/Yekaterinburg']
timezone["RU_UD"] = ['Europe/Samara']
timezone["RU_ULY"] = ['Europe/Samara']
timezone["RU_VGG"] = ['Europe/Moscow']
timezone["RU_VLA"] = ['Europe/Moscow']
timezone["RU_VLG"] = ['Europe/Moscow']
timezone["RU_VOR"] = ['Europe/Moscow']
timezone["RU_YAN"] = ['Asia/Yekaterinburg']
timezone["RU_YAR"] = ['Europe/Moscow']
timezone["RU_YEV"] = ['Asia/Vladivostok']
timezone["RU_ZAB"] = ['Asia/Yakutsk']
timezone["RW"] = ['Africa/Kigali']
timezone["SA"] = ['Asia/Riyadh']
timezone["SB"] = ['Pacific/Guadalcanal']
timezone["SC"] = ['Indian/Mahe']
timezone["SD"] = ['Africa/Khartoum']
timezone["SE"] = ['Europe/Stockholm']
timezone["SG"] = ['Asia/Singapore']
timezone["SH"] = ['Atlantic/St_Helena']
timezone["SI"] = ['Europe/Ljubljana']
timezone["SJ"] = ['Arctic/Longyearbyen']
timezone["SK"] = ['Europe/Bratislava']
timezone["SL"] = ['Africa/Freetown']
timezone["SM"] = ['Europe/San_Marino']
timezone["SN"] = ['Africa/Dakar']
timezone["SO"] = ['Africa/Mogadishu']
timezone["SR"] = ['America/Paramaribo']
timezone["SS"] = ['Africa/Juba']
timezone["ST"] = ['Africa/Sao_Tome']
timezone["SV"] = ['America/El_Salvador']
timezone["SX"] = ['America/Lower_Princes']
timezone["SY"] = ['Asia/Damascus']
timezone["SZ"] = ['Africa/Mbabane']
timezone["TC"] = ['America/Grand_Turk']
timezone["TD"] = ['Africa/Ndjamena']
timezone["TF"] = ['Indian/Kerguelen']
timezone["TG"] = ['Africa/Lome']
timezone["TH"] = ['Asia/Bangkok']
timezone["TJ"] = ['Asia/Dushanbe']
timezone["TK"] = ['Pacific/Fakaofo']
timezone["TL"] = ['Asia/Dili']
timezone["TM"] = ['Asia/Ashgabat']
timezone["TN"] = ['Africa/Tunis']
timezone["TO"] = ['Pacific/Tongatapu']
timezone["TR"] = ['Europe/Istanbul']
timezone["TT"] = ['America/Port_of_Spain']
timezone["TV"] = ['Pacific/Funafuti']
timezone["TW"] = ['Asia/Taipei']
timezone["TZ"] = ['Africa/Dar_es_Salaam']
timezone["UA"] = ['Europe/Kyiv']
timezone["UG"] = ['Africa/Kampala']
timezone["UM"] = ['Pacific/Midway']
timezone["UM1"] = ['Pacific/Wake']
timezone["US"] = ['America/New_York']
timezone["US1"] = ['America/Denver']
timezone["US10"] = ['America/Indiana/Winamac']
timezone["US11"] = ['America/Juneau']
timezone["US12"] = ['America/Kentucky/Louisville']
timezone["US13"] = ['America/Kentucky/Monticello']
timezone["US14"] = ['America/Menominee']
timezone["US15"] = ['America/Metlakatla']
timezone["US16"] = ['America/Nome']
timezone["US17"] = ['America/North_Dakota/Beulah']
timezone["US18"] = ['America/North_Dakota/Center']
timezone["US19"] = ['America/North_Dakota/New_Salem']
timezone["US20"] = ['America/Sitka']
timezone["US21"] = ['America/Yakutat']
timezone["US22"] = ['US/Alaska']
timezone["US23"] = ['US/Aleutian']
timezone["US24"] = ['US/Arizona']
timezone["US25"] = ['US/Central']
timezone["US26"] = ['US/East-Indiana']
timezone["US27"] = ['US/Eastern']
timezone["US28"] = ['US/Hawaii']
timezone["US29"] = ['US/Indiana-Starke']
timezone["US30"] = ['US/Michigan']
timezone["US31"] = ['US/Mountain']
timezone["US32"] = ['US/Pacific']
timezone["US33"] = ['US/Samoa']
timezone["US4"] = ['America/Indiana/Knox']
timezone["US5"] = ['America/Indiana/Marengo']
timezone["US6"] = ['America/Indiana/Petersburg']
timezone["US7"] = ['America/Indiana/Tell_City']
timezone["US8"] = ['America/Indiana/Vevay']
timezone["US9"] = ['America/Indiana/Vincennes']
timezone["US_AK"] = ['America/Anchorage']
timezone["US_AL"] = ['America/Chicago']
timezone["US_AR"] = ['America/Chicago']
timezone["US_AZ"] = ['America/Phoenix']
timezone["US_CA"] = ['America/Los_Angeles']
timezone["US_CO"] = ['America/Phoenix']
timezone["US_CT"] = ['America/New_York']
timezone["US_DC"] = ['America/New_York']
timezone["US_DE"] = ['America/New_York']
timezone["US_FL"] = ['America/New_York']
timezone["US_GA"] = ['America/New_York']
timezone["US_HI"] = ['Pacific/Honolulu']
timezone["US_IA"] = ['America/Chicago']
timezone["US_ID"] = ['America/Boise']
timezone["US_IL"] = ['America/Chicago']
timezone["US_IN"] = ['America/Indiana/Indianapolis']
timezone["US_KS"] = ['America/Chicago']
timezone["US_KY"] = ['America/Chicago']
timezone["US_LA"] = ['America/Chicago']
timezone["US_MA"] = ['America/New_York']
timezone["US_MD"] = ['America/New_York']
timezone["US_ME"] = ['America/New_York']
timezone["US_MI"] = ['America/Detroit']
timezone["US_MN"] = ['America/Chicago']
timezone["US_MO"] = ['America/Chicago']
timezone["US_MS"] = ['America/Chicago']
timezone["US_MT"] = ['America/Phoenix']
timezone["US_NC"] = ['America/New_York']
timezone["US_ND"] = ['America/Chicago']
timezone["US_NE"] = ['America/Chicago']
timezone["US_NH"] = ['America/New_York']
timezone["US_NJ"] = ['America/New_York']
timezone["US_NM"] = ['America/Phoenix']
timezone["US_NV"] = ['America/Los_Angeles']
timezone["US_NY"] = ['America/New_York']
timezone["US_OH"] = ['America/New_York']
timezone["US_OK"] = ['America/Chicago']
timezone["US_OR"] = ['America/Los_Angeles']
timezone["US_PA"] = ['America/New_York']
timezone["US_RI"] = ['America/New_York']
timezone["US_SC"] = ['America/New_York']
timezone["US_SD"] = ['America/Chicago']
timezone["US_TN"] = ['America/Chicago']
timezone["US_TX"] = ['America/Chicago']
timezone["US_UT"] = ['America/Phoenix']
timezone["US_VA"] = ['America/New_York']
timezone["US_VT"] = ['America/New_York']
timezone["US_WA"] = ['America/Los_Angeles']
timezone["US_WI"] = ['America/Chicago']
timezone["US_WV"] = ['America/New_York']
timezone["US_WY"] = ['America/Phoenix']
timezone["UY"] = ['America/Montevideo']
timezone["UZ"] = ['Asia/Tashkent']
timezone["VA"] = ['Europe/Vatican']
timezone["VC"] = ['America/St_Vincent']
timezone["VE"] = ['America/Caracas']
timezone["VG"] = ['America/Tortola']
timezone["VI"] = ['America/St_Thomas']
timezone["VN"] = ['Asia/Ho_Chi_Minh']
timezone["VU"] = ['Pacific/Efate']
timezone["WF"] = ['Pacific/Wallis']
timezone["WS"] = ['Pacific/Apia']
timezone["YE"] = ['Asia/Aden']
timezone["YT"] = ['Indian/Mayotte']
timezone["ZA"] = ['Africa/Johannesburg']
timezone["ZM"] = ['Africa/Lusaka']
timezone["ZW"] = ['Africa/Harare']

